#include "tree_sitter/parser.h"

#if defined(__GNUC__) || defined(__clang__)
#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
#endif

#ifdef _MSC_VER
#pragma optimize("", off)
#elif defined(__clang__)
#pragma clang optimize off
#elif defined(__GNUC__)
#pragma GCC optimize ("O0")
#endif

#define LANGUAGE_VERSION 14
#define STATE_COUNT 10002
#define LARGE_STATE_COUNT 4750
#define SYMBOL_COUNT 500
#define ALIAS_COUNT 3
#define TOKEN_COUNT 217
#define EXTERNAL_TOKEN_COUNT 12
#define FIELD_COUNT 26
#define MAX_ALIAS_SEQUENCE_LENGTH 15
#define PRODUCTION_ID_COUNT 228

enum ts_symbol_identifiers {
  sym__identifier_token = 1,
  anon_sym_extern = 2,
  anon_sym_alias = 3,
  anon_sym_SEMI = 4,
  anon_sym_global = 5,
  anon_sym_using = 6,
  anon_sym_unsafe = 7,
  anon_sym_EQ = 8,
  anon_sym_static = 9,
  anon_sym_LBRACK = 10,
  anon_sym_assembly = 11,
  anon_sym_module = 12,
  anon_sym_COLON = 13,
  anon_sym_COMMA = 14,
  anon_sym_RBRACK = 15,
  anon_sym_LPAREN = 16,
  anon_sym_RPAREN = 17,
  anon_sym_field = 18,
  anon_sym_event = 19,
  anon_sym_method = 20,
  anon_sym_param = 21,
  anon_sym_property = 22,
  anon_sym_return = 23,
  anon_sym_type = 24,
  anon_sym_namespace = 25,
  anon_sym_class = 26,
  anon_sym_ref = 27,
  anon_sym_struct = 28,
  anon_sym_enum = 29,
  anon_sym_LBRACE = 30,
  anon_sym_RBRACE = 31,
  anon_sym_interface = 32,
  anon_sym_delegate = 33,
  anon_sym_record = 34,
  anon_sym_abstract = 35,
  anon_sym_async = 36,
  anon_sym_const = 37,
  anon_sym_file = 38,
  anon_sym_fixed = 39,
  anon_sym_internal = 40,
  anon_sym_new = 41,
  anon_sym_override = 42,
  anon_sym_partial = 43,
  anon_sym_private = 44,
  anon_sym_protected = 45,
  anon_sym_public = 46,
  anon_sym_readonly = 47,
  anon_sym_required = 48,
  anon_sym_sealed = 49,
  anon_sym_virtual = 50,
  anon_sym_volatile = 51,
  anon_sym_LT = 52,
  anon_sym_GT = 53,
  anon_sym_in = 54,
  anon_sym_out = 55,
  anon_sym_where = 56,
  anon_sym_QMARK = 57,
  anon_sym_notnull = 58,
  anon_sym_unmanaged = 59,
  anon_sym_operator = 60,
  anon_sym_checked = 61,
  anon_sym_BANG = 62,
  anon_sym_TILDE = 63,
  anon_sym_PLUS_PLUS = 64,
  anon_sym_DASH_DASH = 65,
  anon_sym_true = 66,
  anon_sym_false = 67,
  anon_sym_PLUS = 68,
  anon_sym_DASH = 69,
  anon_sym_STAR = 70,
  anon_sym_SLASH = 71,
  anon_sym_PERCENT = 72,
  anon_sym_CARET = 73,
  anon_sym_PIPE = 74,
  anon_sym_AMP = 75,
  anon_sym_LT_LT = 76,
  anon_sym_GT_GT = 77,
  anon_sym_GT_GT_GT = 78,
  anon_sym_EQ_EQ = 79,
  anon_sym_BANG_EQ = 80,
  anon_sym_GT_EQ = 81,
  anon_sym_LT_EQ = 82,
  anon_sym_implicit = 83,
  anon_sym_explicit = 84,
  anon_sym_get = 85,
  anon_sym_set = 86,
  anon_sym_add = 87,
  anon_sym_remove = 88,
  anon_sym_init = 89,
  anon_sym_this = 90,
  anon_sym_DOT = 91,
  anon_sym_scoped = 92,
  anon_sym_params = 93,
  anon_sym_base = 94,
  anon_sym_EQ_GT = 95,
  anon_sym_COLON_COLON = 96,
  anon_sym_var = 97,
  anon_sym_managed = 98,
  anon_sym_Cdecl = 99,
  anon_sym_Stdcall = 100,
  anon_sym_Thiscall = 101,
  anon_sym_Fastcall = 102,
  sym_predefined_type = 103,
  anon_sym_break = 104,
  anon_sym_unchecked = 105,
  anon_sym_continue = 106,
  anon_sym_do = 107,
  anon_sym_while = 108,
  anon_sym_for = 109,
  anon_sym_lock = 110,
  anon_sym_yield = 111,
  anon_sym_switch = 112,
  anon_sym_case = 113,
  anon_sym_default = 114,
  anon_sym_throw = 115,
  anon_sym_try = 116,
  anon_sym_catch = 117,
  anon_sym_when = 118,
  anon_sym_finally = 119,
  anon_sym_await = 120,
  anon_sym_foreach = 121,
  anon_sym_goto = 122,
  anon_sym_if = 123,
  anon_sym_else = 124,
  sym_discard = 125,
  anon_sym_DOT_DOT = 126,
  anon_sym_not = 127,
  anon_sym_and = 128,
  anon_sym_or = 129,
  anon_sym_PLUS_EQ = 130,
  anon_sym_DASH_EQ = 131,
  anon_sym_STAR_EQ = 132,
  anon_sym_SLASH_EQ = 133,
  anon_sym_PERCENT_EQ = 134,
  anon_sym_AMP_EQ = 135,
  anon_sym_CARET_EQ = 136,
  anon_sym_PIPE_EQ = 137,
  anon_sym_LT_LT_EQ = 138,
  anon_sym_GT_GT_EQ = 139,
  anon_sym_GT_GT_GT_EQ = 140,
  anon_sym_QMARK_QMARK_EQ = 141,
  anon_sym_AMP_AMP = 142,
  anon_sym_PIPE_PIPE = 143,
  anon_sym_QMARK_QMARK = 144,
  anon_sym_from = 145,
  anon_sym_into = 146,
  anon_sym_join = 147,
  anon_sym_on = 148,
  anon_sym_equals = 149,
  anon_sym_let = 150,
  anon_sym_orderby = 151,
  anon_sym_ascending = 152,
  anon_sym_descending = 153,
  anon_sym_group = 154,
  anon_sym_by = 155,
  anon_sym_select = 156,
  anon_sym_as = 157,
  anon_sym_is = 158,
  aux_sym_interpolation_format_clause_token1 = 159,
  anon_sym_DASH_GT = 160,
  anon_sym_stackalloc = 161,
  anon_sym_with = 162,
  anon_sym_sizeof = 163,
  anon_sym_typeof = 164,
  anon_sym___makeref = 165,
  anon_sym___reftype = 166,
  anon_sym___refvalue = 167,
  sym_null_literal = 168,
  anon_sym_SQUOTE = 169,
  sym_character_literal_content = 170,
  sym_integer_literal = 171,
  sym_real_literal = 172,
  anon_sym_DQUOTE = 173,
  aux_sym_string_literal_content_token1 = 174,
  aux_sym_string_literal_content_token2 = 175,
  sym_escape_sequence = 176,
  sym_string_literal_encoding = 177,
  sym_verbatim_string_literal = 178,
  aux_sym_raw_string_literal_token1 = 179,
  aux_sym_preproc_if_token1 = 180,
  aux_sym_preproc_if_token2 = 181,
  aux_sym_preproc_if_token3 = 182,
  aux_sym_preproc_else_token1 = 183,
  aux_sym_preproc_elif_token1 = 184,
  sym_preproc_arg = 185,
  aux_sym_preproc_region_token1 = 186,
  aux_sym_preproc_endregion_token1 = 187,
  aux_sym_preproc_line_token1 = 188,
  anon_sym_hidden = 189,
  aux_sym_preproc_pragma_token1 = 190,
  anon_sym_warning = 191,
  anon_sym_disable = 192,
  anon_sym_restore = 193,
  anon_sym_checksum = 194,
  aux_sym_preproc_nullable_token1 = 195,
  anon_sym_enable = 196,
  anon_sym_annotations = 197,
  anon_sym_warnings = 198,
  aux_sym_preproc_error_token1 = 199,
  aux_sym_preproc_warning_token1 = 200,
  aux_sym_preproc_define_token1 = 201,
  aux_sym_preproc_undef_token1 = 202,
  sym_shebang_directive = 203,
  sym_comment = 204,
  sym__optional_semi = 205,
  sym_interpolation_regular_start = 206,
  sym_interpolation_verbatim_start = 207,
  sym_interpolation_raw_start = 208,
  sym_interpolation_start_quote = 209,
  sym_interpolation_end_quote = 210,
  sym_interpolation_open_brace = 211,
  sym_interpolation_close_brace = 212,
  sym_interpolation_string_content = 213,
  sym_raw_string_start = 214,
  sym_raw_string_end = 215,
  sym_raw_string_content = 216,
  sym_compilation_unit = 217,
  sym__top_level_item = 218,
  sym_global_statement = 219,
  sym_extern_alias_directive = 220,
  sym_using_directive = 221,
  sym_global_attribute = 222,
  sym_attribute = 223,
  sym_attribute_argument_list = 224,
  sym_attribute_argument = 225,
  sym_attribute_list = 226,
  sym_attribute_target_specifier = 227,
  sym_namespace_declaration = 228,
  sym_file_scoped_namespace_declaration = 229,
  sym_type_declaration = 230,
  sym_class_declaration = 231,
  sym_struct_declaration = 232,
  sym_enum_declaration = 233,
  sym_enum_member_declaration_list = 234,
  sym_enum_member_declaration = 235,
  sym_interface_declaration = 236,
  sym_delegate_declaration = 237,
  sym_record_declaration = 238,
  sym_record_base = 239,
  sym_primary_constructor_base_type = 240,
  sym_modifier = 241,
  sym_type_parameter_list = 242,
  sym_type_parameter = 243,
  sym_base_list = 244,
  sym_type_parameter_constraints_clause = 245,
  sym_type_parameter_constraint = 246,
  sym_constructor_constraint = 247,
  sym_operator_declaration = 248,
  sym_conversion_operator_declaration = 249,
  sym_declaration_list = 250,
  sym_declaration = 251,
  sym_field_declaration = 252,
  sym_constructor_declaration = 253,
  sym_destructor_declaration = 254,
  sym_method_declaration = 255,
  sym_event_declaration = 256,
  sym_event_field_declaration = 257,
  sym_accessor_list = 258,
  sym_accessor_declaration = 259,
  sym_indexer_declaration = 260,
  sym_bracketed_parameter_list = 261,
  sym_property_declaration = 262,
  sym_explicit_interface_specifier = 263,
  sym_parameter_list = 264,
  sym_parameter = 265,
  sym__parameter_array = 266,
  sym_constructor_initializer = 267,
  sym_argument_list = 268,
  sym_tuple_pattern = 269,
  sym_argument = 270,
  sym_block = 271,
  sym_arrow_expression_clause = 272,
  sym__function_body = 273,
  sym_variable_declaration = 274,
  sym_using_variable_declaration = 275,
  sym_variable_declarator = 276,
  sym_using_variable_declarator = 277,
  sym_bracketed_argument_list = 278,
  sym__name = 279,
  sym_alias_qualified_name = 280,
  sym__simple_name = 281,
  sym_qualified_name = 282,
  sym_generic_name = 283,
  sym_type_argument_list = 284,
  sym_type = 285,
  sym_implicit_type = 286,
  sym_array_type = 287,
  sym__array_base_type = 288,
  sym_array_rank_specifier = 289,
  sym_nullable_type = 290,
  sym_pointer_type = 291,
  sym__pointer_base_type = 292,
  sym_function_pointer_type = 293,
  sym_calling_convention = 294,
  sym_function_pointer_parameter = 295,
  sym_ref_type = 296,
  sym__ref_base_type = 297,
  sym_scoped_type = 298,
  sym__scoped_base_type = 299,
  sym_tuple_type = 300,
  sym_tuple_element = 301,
  sym_statement = 302,
  sym_break_statement = 303,
  sym_checked_statement = 304,
  sym_continue_statement = 305,
  sym_do_statement = 306,
  sym_empty_statement = 307,
  sym_expression_statement = 308,
  sym_fixed_statement = 309,
  sym_for_statement = 310,
  sym_return_statement = 311,
  sym_lock_statement = 312,
  sym_yield_statement = 313,
  sym_switch_statement = 314,
  sym_switch_body = 315,
  sym_switch_section = 316,
  sym_throw_statement = 317,
  sym_try_statement = 318,
  sym_catch_clause = 319,
  sym_catch_declaration = 320,
  sym_catch_filter_clause = 321,
  sym_finally_clause = 322,
  sym_unsafe_statement = 323,
  sym_using_statement = 324,
  sym_foreach_statement = 325,
  sym_goto_statement = 326,
  sym_labeled_statement = 327,
  sym_if_statement = 328,
  sym_while_statement = 329,
  sym_local_declaration_statement = 330,
  sym_local_function_statement = 331,
  sym_pattern = 332,
  sym_constant_pattern = 333,
  sym_parenthesized_pattern = 334,
  sym_var_pattern = 335,
  sym_type_pattern = 336,
  sym_list_pattern = 337,
  sym_recursive_pattern = 338,
  sym_positional_pattern_clause = 339,
  sym_property_pattern_clause = 340,
  sym_subpattern = 341,
  sym_relational_pattern = 342,
  sym_negated_pattern = 343,
  sym_and_pattern = 344,
  sym_or_pattern = 345,
  sym_declaration_pattern = 346,
  sym__variable_designation = 347,
  sym_parenthesized_variable_designation = 348,
  sym_expression = 349,
  sym_non_lvalue_expression = 350,
  sym_lvalue_expression = 351,
  sym__expression_statement_expression = 352,
  sym_assignment_expression = 353,
  sym_binary_expression = 354,
  sym_postfix_unary_expression = 355,
  sym_prefix_unary_expression = 356,
  sym__pointer_indirection_expression = 357,
  sym_query_expression = 358,
  sym_from_clause = 359,
  sym__query_body = 360,
  sym__query_clause = 361,
  sym_join_clause = 362,
  sym__join_header = 363,
  sym__join_body = 364,
  sym_join_into_clause = 365,
  sym_let_clause = 366,
  sym_order_by_clause = 367,
  sym__ordering = 368,
  sym_where_clause = 369,
  sym__select_or_group_clause = 370,
  sym_group_clause = 371,
  sym_select_clause = 372,
  sym_conditional_expression = 373,
  sym_conditional_access_expression = 374,
  sym_as_expression = 375,
  sym_is_expression = 376,
  sym_is_pattern_expression = 377,
  sym_cast_expression = 378,
  sym_checked_expression = 379,
  sym_invocation_expression = 380,
  sym_switch_expression = 381,
  sym_switch_expression_arm = 382,
  sym_when_clause = 383,
  sym_await_expression = 384,
  sym_throw_expression = 385,
  sym_element_access_expression = 386,
  sym_interpolated_string_expression = 387,
  sym__interpolated_string_content = 388,
  sym__interpolated_verbatim_string_content = 389,
  sym__interpolated_raw_string_content = 390,
  sym_interpolation = 391,
  sym_interpolation_alignment_clause = 392,
  sym_interpolation_format_clause = 393,
  sym_member_access_expression = 394,
  sym_member_binding_expression = 395,
  sym_object_creation_expression = 396,
  sym_parenthesized_expression = 397,
  sym__parenthesized_lvalue_expression = 398,
  sym_lambda_expression = 399,
  sym__lambda_parameters = 400,
  sym_array_creation_expression = 401,
  sym_anonymous_method_expression = 402,
  sym_anonymous_object_creation_expression = 403,
  sym__anonymous_object_member_declarator = 404,
  sym_implicit_array_creation_expression = 405,
  sym_implicit_object_creation_expression = 406,
  sym_implicit_stackalloc_expression = 407,
  sym_initializer_expression = 408,
  sym_declaration_expression = 409,
  sym_default_expression = 410,
  sym_with_expression = 411,
  sym_with_initializer = 412,
  sym_sizeof_expression = 413,
  sym_typeof_expression = 414,
  sym_makeref_expression = 415,
  sym_ref_expression = 416,
  sym_reftype_expression = 417,
  sym_refvalue_expression = 418,
  sym_stackalloc_expression = 419,
  sym_range_expression = 420,
  sym_tuple_expression = 421,
  sym_literal = 422,
  sym_character_literal = 423,
  sym_string_literal = 424,
  sym_string_literal_content = 425,
  sym_raw_string_literal = 426,
  sym_boolean_literal = 427,
  sym_identifier = 428,
  sym__reserved_identifier = 429,
  sym_preproc_if = 430,
  sym_preproc_else = 431,
  sym_preproc_elif = 432,
  sym_preproc_if_in_top_level = 433,
  sym_preproc_else_in_top_level = 434,
  sym_preproc_elif_in_top_level = 435,
  sym_preproc_if_in_expression = 436,
  sym_preproc_else_in_expression = 437,
  sym_preproc_elif_in_expression = 438,
  sym_preproc_if_in_enum_member_declaration = 439,
  sym_preproc_else_in_enum_member_declaration = 440,
  sym_preproc_elif_in_enum_member_declaration = 441,
  sym__preproc_expression = 442,
  sym_preproc_parenthesized_expression = 443,
  sym_preproc_unary_expression = 444,
  sym_preproc_binary_expression = 445,
  sym_preproc_region = 446,
  sym_preproc_endregion = 447,
  sym_preproc_line = 448,
  sym_preproc_pragma = 449,
  sym_preproc_nullable = 450,
  sym_preproc_error = 451,
  sym_preproc_warning = 452,
  sym_preproc_define = 453,
  sym_preproc_undef = 454,
  aux_sym_compilation_unit_repeat1 = 455,
  aux_sym_global_attribute_repeat1 = 456,
  aux_sym_attribute_argument_list_repeat1 = 457,
  aux_sym_class_declaration_repeat1 = 458,
  aux_sym_class_declaration_repeat2 = 459,
  aux_sym_class_declaration_repeat3 = 460,
  aux_sym_enum_member_declaration_list_repeat1 = 461,
  aux_sym_record_base_repeat1 = 462,
  aux_sym_type_parameter_list_repeat1 = 463,
  aux_sym_base_list_repeat1 = 464,
  aux_sym_type_parameter_constraints_clause_repeat1 = 465,
  aux_sym_declaration_list_repeat1 = 466,
  aux_sym_accessor_list_repeat1 = 467,
  aux_sym_bracketed_parameter_list_repeat1 = 468,
  aux_sym__parameter_type_with_modifiers_repeat1 = 469,
  aux_sym_argument_list_repeat1 = 470,
  aux_sym_tuple_pattern_repeat1 = 471,
  aux_sym_block_repeat1 = 472,
  aux_sym_variable_declaration_repeat1 = 473,
  aux_sym_using_variable_declaration_repeat1 = 474,
  aux_sym_type_argument_list_repeat1 = 475,
  aux_sym_type_argument_list_repeat2 = 476,
  aux_sym_array_rank_specifier_repeat1 = 477,
  aux_sym_function_pointer_type_repeat1 = 478,
  aux_sym_calling_convention_repeat1 = 479,
  aux_sym_tuple_type_repeat1 = 480,
  aux_sym_for_statement_repeat1 = 481,
  aux_sym_switch_body_repeat1 = 482,
  aux_sym_try_statement_repeat1 = 483,
  aux_sym_list_pattern_repeat1 = 484,
  aux_sym_positional_pattern_clause_repeat1 = 485,
  aux_sym_parenthesized_variable_designation_repeat1 = 486,
  aux_sym__query_body_repeat1 = 487,
  aux_sym__query_body_repeat2 = 488,
  aux_sym_order_by_clause_repeat1 = 489,
  aux_sym_switch_expression_repeat1 = 490,
  aux_sym_interpolated_string_expression_repeat1 = 491,
  aux_sym_interpolated_string_expression_repeat2 = 492,
  aux_sym_interpolated_string_expression_repeat3 = 493,
  aux_sym_lambda_expression_repeat1 = 494,
  aux_sym_anonymous_object_creation_expression_repeat1 = 495,
  aux_sym_with_expression_repeat1 = 496,
  aux_sym_string_literal_repeat1 = 497,
  aux_sym_preproc_if_in_top_level_repeat1 = 498,
  aux_sym_preproc_pragma_repeat1 = 499,
  alias_sym_element_binding_expression = 500,
  alias_sym_implicit_parameter = 501,
  alias_sym_interpolation_quote = 502,
};

static const char * const ts_symbol_names[] = {
  [ts_builtin_sym_end] = "end",
  [sym__identifier_token] = "_identifier_token",
  [anon_sym_extern] = "extern",
  [anon_sym_alias] = "alias",
  [anon_sym_SEMI] = ";",
  [anon_sym_global] = "global",
  [anon_sym_using] = "using",
  [anon_sym_unsafe] = "unsafe",
  [anon_sym_EQ] = "=",
  [anon_sym_static] = "static",
  [anon_sym_LBRACK] = "[",
  [anon_sym_assembly] = "assembly",
  [anon_sym_module] = "module",
  [anon_sym_COLON] = ":",
  [anon_sym_COMMA] = ",",
  [anon_sym_RBRACK] = "]",
  [anon_sym_LPAREN] = "(",
  [anon_sym_RPAREN] = ")",
  [anon_sym_field] = "field",
  [anon_sym_event] = "event",
  [anon_sym_method] = "method",
  [anon_sym_param] = "param",
  [anon_sym_property] = "property",
  [anon_sym_return] = "return",
  [anon_sym_type] = "type",
  [anon_sym_namespace] = "namespace",
  [anon_sym_class] = "class",
  [anon_sym_ref] = "ref",
  [anon_sym_struct] = "struct",
  [anon_sym_enum] = "enum",
  [anon_sym_LBRACE] = "{",
  [anon_sym_RBRACE] = "}",
  [anon_sym_interface] = "interface",
  [anon_sym_delegate] = "delegate",
  [anon_sym_record] = "record",
  [anon_sym_abstract] = "abstract",
  [anon_sym_async] = "async",
  [anon_sym_const] = "const",
  [anon_sym_file] = "file",
  [anon_sym_fixed] = "fixed",
  [anon_sym_internal] = "internal",
  [anon_sym_new] = "new",
  [anon_sym_override] = "override",
  [anon_sym_partial] = "partial",
  [anon_sym_private] = "private",
  [anon_sym_protected] = "protected",
  [anon_sym_public] = "public",
  [anon_sym_readonly] = "readonly",
  [anon_sym_required] = "required",
  [anon_sym_sealed] = "sealed",
  [anon_sym_virtual] = "virtual",
  [anon_sym_volatile] = "volatile",
  [anon_sym_LT] = "<",
  [anon_sym_GT] = ">",
  [anon_sym_in] = "in",
  [anon_sym_out] = "out",
  [anon_sym_where] = "where",
  [anon_sym_QMARK] = "\?",
  [anon_sym_notnull] = "notnull",
  [anon_sym_unmanaged] = "unmanaged",
  [anon_sym_operator] = "operator",
  [anon_sym_checked] = "checked",
  [anon_sym_BANG] = "!",
  [anon_sym_TILDE] = "~",
  [anon_sym_PLUS_PLUS] = "++",
  [anon_sym_DASH_DASH] = "--",
  [anon_sym_true] = "true",
  [anon_sym_false] = "false",
  [anon_sym_PLUS] = "+",
  [anon_sym_DASH] = "-",
  [anon_sym_STAR] = "*",
  [anon_sym_SLASH] = "/",
  [anon_sym_PERCENT] = "%",
  [anon_sym_CARET] = "^",
  [anon_sym_PIPE] = "|",
  [anon_sym_AMP] = "&",
  [anon_sym_LT_LT] = "<<",
  [anon_sym_GT_GT] = ">>",
  [anon_sym_GT_GT_GT] = ">>>",
  [anon_sym_EQ_EQ] = "==",
  [anon_sym_BANG_EQ] = "!=",
  [anon_sym_GT_EQ] = ">=",
  [anon_sym_LT_EQ] = "<=",
  [anon_sym_implicit] = "implicit",
  [anon_sym_explicit] = "explicit",
  [anon_sym_get] = "get",
  [anon_sym_set] = "set",
  [anon_sym_add] = "add",
  [anon_sym_remove] = "remove",
  [anon_sym_init] = "init",
  [anon_sym_this] = "this",
  [anon_sym_DOT] = ".",
  [anon_sym_scoped] = "scoped",
  [anon_sym_params] = "params",
  [anon_sym_base] = "base",
  [anon_sym_EQ_GT] = "=>",
  [anon_sym_COLON_COLON] = "::",
  [anon_sym_var] = "var",
  [anon_sym_managed] = "managed",
  [anon_sym_Cdecl] = "Cdecl",
  [anon_sym_Stdcall] = "Stdcall",
  [anon_sym_Thiscall] = "Thiscall",
  [anon_sym_Fastcall] = "Fastcall",
  [sym_predefined_type] = "predefined_type",
  [anon_sym_break] = "break",
  [anon_sym_unchecked] = "unchecked",
  [anon_sym_continue] = "continue",
  [anon_sym_do] = "do",
  [anon_sym_while] = "while",
  [anon_sym_for] = "for",
  [anon_sym_lock] = "lock",
  [anon_sym_yield] = "yield",
  [anon_sym_switch] = "switch",
  [anon_sym_case] = "case",
  [anon_sym_default] = "default",
  [anon_sym_throw] = "throw",
  [anon_sym_try] = "try",
  [anon_sym_catch] = "catch",
  [anon_sym_when] = "when",
  [anon_sym_finally] = "finally",
  [anon_sym_await] = "await",
  [anon_sym_foreach] = "foreach",
  [anon_sym_goto] = "goto",
  [anon_sym_if] = "if",
  [anon_sym_else] = "else",
  [sym_discard] = "discard",
  [anon_sym_DOT_DOT] = "..",
  [anon_sym_not] = "not",
  [anon_sym_and] = "and",
  [anon_sym_or] = "or",
  [anon_sym_PLUS_EQ] = "+=",
  [anon_sym_DASH_EQ] = "-=",
  [anon_sym_STAR_EQ] = "*=",
  [anon_sym_SLASH_EQ] = "/=",
  [anon_sym_PERCENT_EQ] = "%=",
  [anon_sym_AMP_EQ] = "&=",
  [anon_sym_CARET_EQ] = "^=",
  [anon_sym_PIPE_EQ] = "|=",
  [anon_sym_LT_LT_EQ] = "<<=",
  [anon_sym_GT_GT_EQ] = ">>=",
  [anon_sym_GT_GT_GT_EQ] = ">>>=",
  [anon_sym_QMARK_QMARK_EQ] = "\?\?=",
  [anon_sym_AMP_AMP] = "&&",
  [anon_sym_PIPE_PIPE] = "||",
  [anon_sym_QMARK_QMARK] = "\?\?",
  [anon_sym_from] = "from",
  [anon_sym_into] = "into",
  [anon_sym_join] = "join",
  [anon_sym_on] = "on",
  [anon_sym_equals] = "equals",
  [anon_sym_let] = "let",
  [anon_sym_orderby] = "orderby",
  [anon_sym_ascending] = "ascending",
  [anon_sym_descending] = "descending",
  [anon_sym_group] = "group",
  [anon_sym_by] = "by",
  [anon_sym_select] = "select",
  [anon_sym_as] = "as",
  [anon_sym_is] = "is",
  [aux_sym_interpolation_format_clause_token1] = "interpolation_format_clause_token1",
  [anon_sym_DASH_GT] = "->",
  [anon_sym_stackalloc] = "stackalloc",
  [anon_sym_with] = "with",
  [anon_sym_sizeof] = "sizeof",
  [anon_sym_typeof] = "typeof",
  [anon_sym___makeref] = "__makeref",
  [anon_sym___reftype] = "__reftype",
  [anon_sym___refvalue] = "__refvalue",
  [sym_null_literal] = "null_literal",
  [anon_sym_SQUOTE] = "'",
  [sym_character_literal_content] = "character_literal_content",
  [sym_integer_literal] = "integer_literal",
  [sym_real_literal] = "real_literal",
  [anon_sym_DQUOTE] = "\"",
  [aux_sym_string_literal_content_token1] = "string_literal_content_token1",
  [aux_sym_string_literal_content_token2] = "string_literal_content_token2",
  [sym_escape_sequence] = "escape_sequence",
  [sym_string_literal_encoding] = "string_literal_encoding",
  [sym_verbatim_string_literal] = "verbatim_string_literal",
  [aux_sym_raw_string_literal_token1] = "raw_string_literal_token1",
  [aux_sym_preproc_if_token1] = "#if",
  [aux_sym_preproc_if_token2] = "preproc_if_token2",
  [aux_sym_preproc_if_token3] = "#endif",
  [aux_sym_preproc_else_token1] = "#else",
  [aux_sym_preproc_elif_token1] = "#elif",
  [sym_preproc_arg] = "preproc_arg",
  [aux_sym_preproc_region_token1] = "#region",
  [aux_sym_preproc_endregion_token1] = "#endregion",
  [aux_sym_preproc_line_token1] = "#line",
  [anon_sym_hidden] = "hidden",
  [aux_sym_preproc_pragma_token1] = "#pragma",
  [anon_sym_warning] = "warning",
  [anon_sym_disable] = "disable",
  [anon_sym_restore] = "restore",
  [anon_sym_checksum] = "checksum",
  [aux_sym_preproc_nullable_token1] = "#nullable",
  [anon_sym_enable] = "enable",
  [anon_sym_annotations] = "annotations",
  [anon_sym_warnings] = "warnings",
  [aux_sym_preproc_error_token1] = "#error",
  [aux_sym_preproc_warning_token1] = "#warning",
  [aux_sym_preproc_define_token1] = "#define",
  [aux_sym_preproc_undef_token1] = "#undef",
  [sym_shebang_directive] = "shebang_directive",
  [sym_comment] = "comment",
  [sym__optional_semi] = "_optional_semi",
  [sym_interpolation_regular_start] = "interpolation_start",
  [sym_interpolation_verbatim_start] = "interpolation_start",
  [sym_interpolation_raw_start] = "interpolation_start",
  [sym_interpolation_start_quote] = "\"",
  [sym_interpolation_end_quote] = "\"",
  [sym_interpolation_open_brace] = "interpolation_brace",
  [sym_interpolation_close_brace] = "interpolation_brace",
  [sym_interpolation_string_content] = "string_content",
  [sym_raw_string_start] = "raw_string_start",
  [sym_raw_string_end] = "raw_string_end",
  [sym_raw_string_content] = "raw_string_content",
  [sym_compilation_unit] = "compilation_unit",
  [sym__top_level_item] = "_top_level_item",
  [sym_global_statement] = "global_statement",
  [sym_extern_alias_directive] = "extern_alias_directive",
  [sym_using_directive] = "using_directive",
  [sym_global_attribute] = "global_attribute",
  [sym_attribute] = "attribute",
  [sym_attribute_argument_list] = "attribute_argument_list",
  [sym_attribute_argument] = "attribute_argument",
  [sym_attribute_list] = "attribute_list",
  [sym_attribute_target_specifier] = "attribute_target_specifier",
  [sym_namespace_declaration] = "namespace_declaration",
  [sym_file_scoped_namespace_declaration] = "file_scoped_namespace_declaration",
  [sym_type_declaration] = "type_declaration",
  [sym_class_declaration] = "class_declaration",
  [sym_struct_declaration] = "struct_declaration",
  [sym_enum_declaration] = "enum_declaration",
  [sym_enum_member_declaration_list] = "enum_member_declaration_list",
  [sym_enum_member_declaration] = "enum_member_declaration",
  [sym_interface_declaration] = "interface_declaration",
  [sym_delegate_declaration] = "delegate_declaration",
  [sym_record_declaration] = "record_declaration",
  [sym_record_base] = "base_list",
  [sym_primary_constructor_base_type] = "primary_constructor_base_type",
  [sym_modifier] = "modifier",
  [sym_type_parameter_list] = "type_parameter_list",
  [sym_type_parameter] = "type_parameter",
  [sym_base_list] = "base_list",
  [sym_type_parameter_constraints_clause] = "type_parameter_constraints_clause",
  [sym_type_parameter_constraint] = "type_parameter_constraint",
  [sym_constructor_constraint] = "constructor_constraint",
  [sym_operator_declaration] = "operator_declaration",
  [sym_conversion_operator_declaration] = "conversion_operator_declaration",
  [sym_declaration_list] = "declaration_list",
  [sym_declaration] = "declaration",
  [sym_field_declaration] = "field_declaration",
  [sym_constructor_declaration] = "constructor_declaration",
  [sym_destructor_declaration] = "destructor_declaration",
  [sym_method_declaration] = "method_declaration",
  [sym_event_declaration] = "event_declaration",
  [sym_event_field_declaration] = "event_field_declaration",
  [sym_accessor_list] = "accessor_list",
  [sym_accessor_declaration] = "accessor_declaration",
  [sym_indexer_declaration] = "indexer_declaration",
  [sym_bracketed_parameter_list] = "bracketed_parameter_list",
  [sym_property_declaration] = "property_declaration",
  [sym_explicit_interface_specifier] = "explicit_interface_specifier",
  [sym_parameter_list] = "parameter_list",
  [sym_parameter] = "parameter",
  [sym__parameter_array] = "_parameter_array",
  [sym_constructor_initializer] = "constructor_initializer",
  [sym_argument_list] = "argument_list",
  [sym_tuple_pattern] = "tuple_pattern",
  [sym_argument] = "argument",
  [sym_block] = "block",
  [sym_arrow_expression_clause] = "arrow_expression_clause",
  [sym__function_body] = "_function_body",
  [sym_variable_declaration] = "variable_declaration",
  [sym_using_variable_declaration] = "variable_declaration",
  [sym_variable_declarator] = "variable_declarator",
  [sym_using_variable_declarator] = "variable_declarator",
  [sym_bracketed_argument_list] = "bracketed_argument_list",
  [sym__name] = "_name",
  [sym_alias_qualified_name] = "alias_qualified_name",
  [sym__simple_name] = "_simple_name",
  [sym_qualified_name] = "qualified_name",
  [sym_generic_name] = "generic_name",
  [sym_type_argument_list] = "type_argument_list",
  [sym_type] = "type",
  [sym_implicit_type] = "implicit_type",
  [sym_array_type] = "array_type",
  [sym__array_base_type] = "_array_base_type",
  [sym_array_rank_specifier] = "array_rank_specifier",
  [sym_nullable_type] = "nullable_type",
  [sym_pointer_type] = "pointer_type",
  [sym__pointer_base_type] = "_pointer_base_type",
  [sym_function_pointer_type] = "function_pointer_type",
  [sym_calling_convention] = "calling_convention",
  [sym_function_pointer_parameter] = "function_pointer_parameter",
  [sym_ref_type] = "ref_type",
  [sym__ref_base_type] = "_ref_base_type",
  [sym_scoped_type] = "scoped_type",
  [sym__scoped_base_type] = "_scoped_base_type",
  [sym_tuple_type] = "tuple_type",
  [sym_tuple_element] = "tuple_element",
  [sym_statement] = "statement",
  [sym_break_statement] = "break_statement",
  [sym_checked_statement] = "checked_statement",
  [sym_continue_statement] = "continue_statement",
  [sym_do_statement] = "do_statement",
  [sym_empty_statement] = "empty_statement",
  [sym_expression_statement] = "expression_statement",
  [sym_fixed_statement] = "fixed_statement",
  [sym_for_statement] = "for_statement",
  [sym_return_statement] = "return_statement",
  [sym_lock_statement] = "lock_statement",
  [sym_yield_statement] = "yield_statement",
  [sym_switch_statement] = "switch_statement",
  [sym_switch_body] = "switch_body",
  [sym_switch_section] = "switch_section",
  [sym_throw_statement] = "throw_statement",
  [sym_try_statement] = "try_statement",
  [sym_catch_clause] = "catch_clause",
  [sym_catch_declaration] = "catch_declaration",
  [sym_catch_filter_clause] = "catch_filter_clause",
  [sym_finally_clause] = "finally_clause",
  [sym_unsafe_statement] = "unsafe_statement",
  [sym_using_statement] = "using_statement",
  [sym_foreach_statement] = "foreach_statement",
  [sym_goto_statement] = "goto_statement",
  [sym_labeled_statement] = "labeled_statement",
  [sym_if_statement] = "if_statement",
  [sym_while_statement] = "while_statement",
  [sym_local_declaration_statement] = "local_declaration_statement",
  [sym_local_function_statement] = "local_function_statement",
  [sym_pattern] = "pattern",
  [sym_constant_pattern] = "constant_pattern",
  [sym_parenthesized_pattern] = "parenthesized_pattern",
  [sym_var_pattern] = "var_pattern",
  [sym_type_pattern] = "type_pattern",
  [sym_list_pattern] = "list_pattern",
  [sym_recursive_pattern] = "recursive_pattern",
  [sym_positional_pattern_clause] = "positional_pattern_clause",
  [sym_property_pattern_clause] = "property_pattern_clause",
  [sym_subpattern] = "subpattern",
  [sym_relational_pattern] = "relational_pattern",
  [sym_negated_pattern] = "negated_pattern",
  [sym_and_pattern] = "and_pattern",
  [sym_or_pattern] = "or_pattern",
  [sym_declaration_pattern] = "declaration_pattern",
  [sym__variable_designation] = "_variable_designation",
  [sym_parenthesized_variable_designation] = "parenthesized_variable_designation",
  [sym_expression] = "expression",
  [sym_non_lvalue_expression] = "non_lvalue_expression",
  [sym_lvalue_expression] = "lvalue_expression",
  [sym__expression_statement_expression] = "_expression_statement_expression",
  [sym_assignment_expression] = "assignment_expression",
  [sym_binary_expression] = "binary_expression",
  [sym_postfix_unary_expression] = "postfix_unary_expression",
  [sym_prefix_unary_expression] = "prefix_unary_expression",
  [sym__pointer_indirection_expression] = "prefix_unary_expression",
  [sym_query_expression] = "query_expression",
  [sym_from_clause] = "from_clause",
  [sym__query_body] = "_query_body",
  [sym__query_clause] = "_query_clause",
  [sym_join_clause] = "join_clause",
  [sym__join_header] = "_join_header",
  [sym__join_body] = "_join_body",
  [sym_join_into_clause] = "join_into_clause",
  [sym_let_clause] = "let_clause",
  [sym_order_by_clause] = "order_by_clause",
  [sym__ordering] = "_ordering",
  [sym_where_clause] = "where_clause",
  [sym__select_or_group_clause] = "_select_or_group_clause",
  [sym_group_clause] = "group_clause",
  [sym_select_clause] = "select_clause",
  [sym_conditional_expression] = "conditional_expression",
  [sym_conditional_access_expression] = "conditional_access_expression",
  [sym_as_expression] = "as_expression",
  [sym_is_expression] = "is_expression",
  [sym_is_pattern_expression] = "is_pattern_expression",
  [sym_cast_expression] = "cast_expression",
  [sym_checked_expression] = "checked_expression",
  [sym_invocation_expression] = "invocation_expression",
  [sym_switch_expression] = "switch_expression",
  [sym_switch_expression_arm] = "switch_expression_arm",
  [sym_when_clause] = "when_clause",
  [sym_await_expression] = "await_expression",
  [sym_throw_expression] = "throw_expression",
  [sym_element_access_expression] = "element_access_expression",
  [sym_interpolated_string_expression] = "interpolated_string_expression",
  [sym__interpolated_string_content] = "_interpolated_string_content",
  [sym__interpolated_verbatim_string_content] = "_interpolated_verbatim_string_content",
  [sym__interpolated_raw_string_content] = "_interpolated_raw_string_content",
  [sym_interpolation] = "interpolation",
  [sym_interpolation_alignment_clause] = "interpolation_alignment_clause",
  [sym_interpolation_format_clause] = "interpolation_format_clause",
  [sym_member_access_expression] = "member_access_expression",
  [sym_member_binding_expression] = "member_binding_expression",
  [sym_object_creation_expression] = "object_creation_expression",
  [sym_parenthesized_expression] = "parenthesized_expression",
  [sym__parenthesized_lvalue_expression] = "parenthesized_expression",
  [sym_lambda_expression] = "lambda_expression",
  [sym__lambda_parameters] = "_lambda_parameters",
  [sym_array_creation_expression] = "array_creation_expression",
  [sym_anonymous_method_expression] = "anonymous_method_expression",
  [sym_anonymous_object_creation_expression] = "anonymous_object_creation_expression",
  [sym__anonymous_object_member_declarator] = "_anonymous_object_member_declarator",
  [sym_implicit_array_creation_expression] = "implicit_array_creation_expression",
  [sym_implicit_object_creation_expression] = "implicit_object_creation_expression",
  [sym_implicit_stackalloc_expression] = "implicit_stackalloc_expression",
  [sym_initializer_expression] = "initializer_expression",
  [sym_declaration_expression] = "declaration_expression",
  [sym_default_expression] = "default_expression",
  [sym_with_expression] = "with_expression",
  [sym_with_initializer] = "with_initializer",
  [sym_sizeof_expression] = "sizeof_expression",
  [sym_typeof_expression] = "typeof_expression",
  [sym_makeref_expression] = "makeref_expression",
  [sym_ref_expression] = "ref_expression",
  [sym_reftype_expression] = "reftype_expression",
  [sym_refvalue_expression] = "refvalue_expression",
  [sym_stackalloc_expression] = "stackalloc_expression",
  [sym_range_expression] = "range_expression",
  [sym_tuple_expression] = "tuple_expression",
  [sym_literal] = "literal",
  [sym_character_literal] = "character_literal",
  [sym_string_literal] = "string_literal",
  [sym_string_literal_content] = "string_literal_content",
  [sym_raw_string_literal] = "raw_string_literal",
  [sym_boolean_literal] = "boolean_literal",
  [sym_identifier] = "identifier",
  [sym__reserved_identifier] = "_reserved_identifier",
  [sym_preproc_if] = "preproc_if",
  [sym_preproc_else] = "preproc_else",
  [sym_preproc_elif] = "preproc_elif",
  [sym_preproc_if_in_top_level] = "preproc_if",
  [sym_preproc_else_in_top_level] = "preproc_else",
  [sym_preproc_elif_in_top_level] = "preproc_elif",
  [sym_preproc_if_in_expression] = "preproc_if",
  [sym_preproc_else_in_expression] = "preproc_else",
  [sym_preproc_elif_in_expression] = "preproc_elif",
  [sym_preproc_if_in_enum_member_declaration] = "preproc_if",
  [sym_preproc_else_in_enum_member_declaration] = "preproc_else",
  [sym_preproc_elif_in_enum_member_declaration] = "preproc_elif",
  [sym__preproc_expression] = "_preproc_expression",
  [sym_preproc_parenthesized_expression] = "parenthesized_expression",
  [sym_preproc_unary_expression] = "unary_expression",
  [sym_preproc_binary_expression] = "binary_expression",
  [sym_preproc_region] = "preproc_region",
  [sym_preproc_endregion] = "preproc_endregion",
  [sym_preproc_line] = "preproc_line",
  [sym_preproc_pragma] = "preproc_pragma",
  [sym_preproc_nullable] = "preproc_nullable",
  [sym_preproc_error] = "preproc_error",
  [sym_preproc_warning] = "preproc_warning",
  [sym_preproc_define] = "preproc_define",
  [sym_preproc_undef] = "preproc_undef",
  [aux_sym_compilation_unit_repeat1] = "compilation_unit_repeat1",
  [aux_sym_global_attribute_repeat1] = "global_attribute_repeat1",
  [aux_sym_attribute_argument_list_repeat1] = "attribute_argument_list_repeat1",
  [aux_sym_class_declaration_repeat1] = "class_declaration_repeat1",
  [aux_sym_class_declaration_repeat2] = "class_declaration_repeat2",
  [aux_sym_class_declaration_repeat3] = "class_declaration_repeat3",
  [aux_sym_enum_member_declaration_list_repeat1] = "enum_member_declaration_list_repeat1",
  [aux_sym_record_base_repeat1] = "record_base_repeat1",
  [aux_sym_type_parameter_list_repeat1] = "type_parameter_list_repeat1",
  [aux_sym_base_list_repeat1] = "base_list_repeat1",
  [aux_sym_type_parameter_constraints_clause_repeat1] = "type_parameter_constraints_clause_repeat1",
  [aux_sym_declaration_list_repeat1] = "declaration_list_repeat1",
  [aux_sym_accessor_list_repeat1] = "accessor_list_repeat1",
  [aux_sym_bracketed_parameter_list_repeat1] = "bracketed_parameter_list_repeat1",
  [aux_sym__parameter_type_with_modifiers_repeat1] = "_parameter_type_with_modifiers_repeat1",
  [aux_sym_argument_list_repeat1] = "argument_list_repeat1",
  [aux_sym_tuple_pattern_repeat1] = "tuple_pattern_repeat1",
  [aux_sym_block_repeat1] = "block_repeat1",
  [aux_sym_variable_declaration_repeat1] = "variable_declaration_repeat1",
  [aux_sym_using_variable_declaration_repeat1] = "using_variable_declaration_repeat1",
  [aux_sym_type_argument_list_repeat1] = "type_argument_list_repeat1",
  [aux_sym_type_argument_list_repeat2] = "type_argument_list_repeat2",
  [aux_sym_array_rank_specifier_repeat1] = "array_rank_specifier_repeat1",
  [aux_sym_function_pointer_type_repeat1] = "function_pointer_type_repeat1",
  [aux_sym_calling_convention_repeat1] = "calling_convention_repeat1",
  [aux_sym_tuple_type_repeat1] = "tuple_type_repeat1",
  [aux_sym_for_statement_repeat1] = "for_statement_repeat1",
  [aux_sym_switch_body_repeat1] = "switch_body_repeat1",
  [aux_sym_try_statement_repeat1] = "try_statement_repeat1",
  [aux_sym_list_pattern_repeat1] = "list_pattern_repeat1",
  [aux_sym_positional_pattern_clause_repeat1] = "positional_pattern_clause_repeat1",
  [aux_sym_parenthesized_variable_designation_repeat1] = "parenthesized_variable_designation_repeat1",
  [aux_sym__query_body_repeat1] = "_query_body_repeat1",
  [aux_sym__query_body_repeat2] = "_query_body_repeat2",
  [aux_sym_order_by_clause_repeat1] = "order_by_clause_repeat1",
  [aux_sym_switch_expression_repeat1] = "switch_expression_repeat1",
  [aux_sym_interpolated_string_expression_repeat1] = "interpolated_string_expression_repeat1",
  [aux_sym_interpolated_string_expression_repeat2] = "interpolated_string_expression_repeat2",
  [aux_sym_interpolated_string_expression_repeat3] = "interpolated_string_expression_repeat3",
  [aux_sym_lambda_expression_repeat1] = "lambda_expression_repeat1",
  [aux_sym_anonymous_object_creation_expression_repeat1] = "anonymous_object_creation_expression_repeat1",
  [aux_sym_with_expression_repeat1] = "with_expression_repeat1",
  [aux_sym_string_literal_repeat1] = "string_literal_repeat1",
  [aux_sym_preproc_if_in_top_level_repeat1] = "preproc_if_in_top_level_repeat1",
  [aux_sym_preproc_pragma_repeat1] = "preproc_pragma_repeat1",
  [alias_sym_element_binding_expression] = "element_binding_expression",
  [alias_sym_implicit_parameter] = "implicit_parameter",
  [alias_sym_interpolation_quote] = "interpolation_quote",
};

static const TSSymbol ts_symbol_map[] = {
  [ts_builtin_sym_end] = ts_builtin_sym_end,
  [sym__identifier_token] = sym__identifier_token,
  [anon_sym_extern] = anon_sym_extern,
  [anon_sym_alias] = anon_sym_alias,
  [anon_sym_SEMI] = anon_sym_SEMI,
  [anon_sym_global] = anon_sym_global,
  [anon_sym_using] = anon_sym_using,
  [anon_sym_unsafe] = anon_sym_unsafe,
  [anon_sym_EQ] = anon_sym_EQ,
  [anon_sym_static] = anon_sym_static,
  [anon_sym_LBRACK] = anon_sym_LBRACK,
  [anon_sym_assembly] = anon_sym_assembly,
  [anon_sym_module] = anon_sym_module,
  [anon_sym_COLON] = anon_sym_COLON,
  [anon_sym_COMMA] = anon_sym_COMMA,
  [anon_sym_RBRACK] = anon_sym_RBRACK,
  [anon_sym_LPAREN] = anon_sym_LPAREN,
  [anon_sym_RPAREN] = anon_sym_RPAREN,
  [anon_sym_field] = anon_sym_field,
  [anon_sym_event] = anon_sym_event,
  [anon_sym_method] = anon_sym_method,
  [anon_sym_param] = anon_sym_param,
  [anon_sym_property] = anon_sym_property,
  [anon_sym_return] = anon_sym_return,
  [anon_sym_type] = anon_sym_type,
  [anon_sym_namespace] = anon_sym_namespace,
  [anon_sym_class] = anon_sym_class,
  [anon_sym_ref] = anon_sym_ref,
  [anon_sym_struct] = anon_sym_struct,
  [anon_sym_enum] = anon_sym_enum,
  [anon_sym_LBRACE] = anon_sym_LBRACE,
  [anon_sym_RBRACE] = anon_sym_RBRACE,
  [anon_sym_interface] = anon_sym_interface,
  [anon_sym_delegate] = anon_sym_delegate,
  [anon_sym_record] = anon_sym_record,
  [anon_sym_abstract] = anon_sym_abstract,
  [anon_sym_async] = anon_sym_async,
  [anon_sym_const] = anon_sym_const,
  [anon_sym_file] = anon_sym_file,
  [anon_sym_fixed] = anon_sym_fixed,
  [anon_sym_internal] = anon_sym_internal,
  [anon_sym_new] = anon_sym_new,
  [anon_sym_override] = anon_sym_override,
  [anon_sym_partial] = anon_sym_partial,
  [anon_sym_private] = anon_sym_private,
  [anon_sym_protected] = anon_sym_protected,
  [anon_sym_public] = anon_sym_public,
  [anon_sym_readonly] = anon_sym_readonly,
  [anon_sym_required] = anon_sym_required,
  [anon_sym_sealed] = anon_sym_sealed,
  [anon_sym_virtual] = anon_sym_virtual,
  [anon_sym_volatile] = anon_sym_volatile,
  [anon_sym_LT] = anon_sym_LT,
  [anon_sym_GT] = anon_sym_GT,
  [anon_sym_in] = anon_sym_in,
  [anon_sym_out] = anon_sym_out,
  [anon_sym_where] = anon_sym_where,
  [anon_sym_QMARK] = anon_sym_QMARK,
  [anon_sym_notnull] = anon_sym_notnull,
  [anon_sym_unmanaged] = anon_sym_unmanaged,
  [anon_sym_operator] = anon_sym_operator,
  [anon_sym_checked] = anon_sym_checked,
  [anon_sym_BANG] = anon_sym_BANG,
  [anon_sym_TILDE] = anon_sym_TILDE,
  [anon_sym_PLUS_PLUS] = anon_sym_PLUS_PLUS,
  [anon_sym_DASH_DASH] = anon_sym_DASH_DASH,
  [anon_sym_true] = anon_sym_true,
  [anon_sym_false] = anon_sym_false,
  [anon_sym_PLUS] = anon_sym_PLUS,
  [anon_sym_DASH] = anon_sym_DASH,
  [anon_sym_STAR] = anon_sym_STAR,
  [anon_sym_SLASH] = anon_sym_SLASH,
  [anon_sym_PERCENT] = anon_sym_PERCENT,
  [anon_sym_CARET] = anon_sym_CARET,
  [anon_sym_PIPE] = anon_sym_PIPE,
  [anon_sym_AMP] = anon_sym_AMP,
  [anon_sym_LT_LT] = anon_sym_LT_LT,
  [anon_sym_GT_GT] = anon_sym_GT_GT,
  [anon_sym_GT_GT_GT] = anon_sym_GT_GT_GT,
  [anon_sym_EQ_EQ] = anon_sym_EQ_EQ,
  [anon_sym_BANG_EQ] = anon_sym_BANG_EQ,
  [anon_sym_GT_EQ] = anon_sym_GT_EQ,
  [anon_sym_LT_EQ] = anon_sym_LT_EQ,
  [anon_sym_implicit] = anon_sym_implicit,
  [anon_sym_explicit] = anon_sym_explicit,
  [anon_sym_get] = anon_sym_get,
  [anon_sym_set] = anon_sym_set,
  [anon_sym_add] = anon_sym_add,
  [anon_sym_remove] = anon_sym_remove,
  [anon_sym_init] = anon_sym_init,
  [anon_sym_this] = anon_sym_this,
  [anon_sym_DOT] = anon_sym_DOT,
  [anon_sym_scoped] = anon_sym_scoped,
  [anon_sym_params] = anon_sym_params,
  [anon_sym_base] = anon_sym_base,
  [anon_sym_EQ_GT] = anon_sym_EQ_GT,
  [anon_sym_COLON_COLON] = anon_sym_COLON_COLON,
  [anon_sym_var] = anon_sym_var,
  [anon_sym_managed] = anon_sym_managed,
  [anon_sym_Cdecl] = anon_sym_Cdecl,
  [anon_sym_Stdcall] = anon_sym_Stdcall,
  [anon_sym_Thiscall] = anon_sym_Thiscall,
  [anon_sym_Fastcall] = anon_sym_Fastcall,
  [sym_predefined_type] = sym_predefined_type,
  [anon_sym_break] = anon_sym_break,
  [anon_sym_unchecked] = anon_sym_unchecked,
  [anon_sym_continue] = anon_sym_continue,
  [anon_sym_do] = anon_sym_do,
  [anon_sym_while] = anon_sym_while,
  [anon_sym_for] = anon_sym_for,
  [anon_sym_lock] = anon_sym_lock,
  [anon_sym_yield] = anon_sym_yield,
  [anon_sym_switch] = anon_sym_switch,
  [anon_sym_case] = anon_sym_case,
  [anon_sym_default] = anon_sym_default,
  [anon_sym_throw] = anon_sym_throw,
  [anon_sym_try] = anon_sym_try,
  [anon_sym_catch] = anon_sym_catch,
  [anon_sym_when] = anon_sym_when,
  [anon_sym_finally] = anon_sym_finally,
  [anon_sym_await] = anon_sym_await,
  [anon_sym_foreach] = anon_sym_foreach,
  [anon_sym_goto] = anon_sym_goto,
  [anon_sym_if] = anon_sym_if,
  [anon_sym_else] = anon_sym_else,
  [sym_discard] = sym_discard,
  [anon_sym_DOT_DOT] = anon_sym_DOT_DOT,
  [anon_sym_not] = anon_sym_not,
  [anon_sym_and] = anon_sym_and,
  [anon_sym_or] = anon_sym_or,
  [anon_sym_PLUS_EQ] = anon_sym_PLUS_EQ,
  [anon_sym_DASH_EQ] = anon_sym_DASH_EQ,
  [anon_sym_STAR_EQ] = anon_sym_STAR_EQ,
  [anon_sym_SLASH_EQ] = anon_sym_SLASH_EQ,
  [anon_sym_PERCENT_EQ] = anon_sym_PERCENT_EQ,
  [anon_sym_AMP_EQ] = anon_sym_AMP_EQ,
  [anon_sym_CARET_EQ] = anon_sym_CARET_EQ,
  [anon_sym_PIPE_EQ] = anon_sym_PIPE_EQ,
  [anon_sym_LT_LT_EQ] = anon_sym_LT_LT_EQ,
  [anon_sym_GT_GT_EQ] = anon_sym_GT_GT_EQ,
  [anon_sym_GT_GT_GT_EQ] = anon_sym_GT_GT_GT_EQ,
  [anon_sym_QMARK_QMARK_EQ] = anon_sym_QMARK_QMARK_EQ,
  [anon_sym_AMP_AMP] = anon_sym_AMP_AMP,
  [anon_sym_PIPE_PIPE] = anon_sym_PIPE_PIPE,
  [anon_sym_QMARK_QMARK] = anon_sym_QMARK_QMARK,
  [anon_sym_from] = anon_sym_from,
  [anon_sym_into] = anon_sym_into,
  [anon_sym_join] = anon_sym_join,
  [anon_sym_on] = anon_sym_on,
  [anon_sym_equals] = anon_sym_equals,
  [anon_sym_let] = anon_sym_let,
  [anon_sym_orderby] = anon_sym_orderby,
  [anon_sym_ascending] = anon_sym_ascending,
  [anon_sym_descending] = anon_sym_descending,
  [anon_sym_group] = anon_sym_group,
  [anon_sym_by] = anon_sym_by,
  [anon_sym_select] = anon_sym_select,
  [anon_sym_as] = anon_sym_as,
  [anon_sym_is] = anon_sym_is,
  [aux_sym_interpolation_format_clause_token1] = aux_sym_interpolation_format_clause_token1,
  [anon_sym_DASH_GT] = anon_sym_DASH_GT,
  [anon_sym_stackalloc] = anon_sym_stackalloc,
  [anon_sym_with] = anon_sym_with,
  [anon_sym_sizeof] = anon_sym_sizeof,
  [anon_sym_typeof] = anon_sym_typeof,
  [anon_sym___makeref] = anon_sym___makeref,
  [anon_sym___reftype] = anon_sym___reftype,
  [anon_sym___refvalue] = anon_sym___refvalue,
  [sym_null_literal] = sym_null_literal,
  [anon_sym_SQUOTE] = anon_sym_SQUOTE,
  [sym_character_literal_content] = sym_character_literal_content,
  [sym_integer_literal] = sym_integer_literal,
  [sym_real_literal] = sym_real_literal,
  [anon_sym_DQUOTE] = anon_sym_DQUOTE,
  [aux_sym_string_literal_content_token1] = aux_sym_string_literal_content_token1,
  [aux_sym_string_literal_content_token2] = aux_sym_string_literal_content_token2,
  [sym_escape_sequence] = sym_escape_sequence,
  [sym_string_literal_encoding] = sym_string_literal_encoding,
  [sym_verbatim_string_literal] = sym_verbatim_string_literal,
  [aux_sym_raw_string_literal_token1] = aux_sym_raw_string_literal_token1,
  [aux_sym_preproc_if_token1] = aux_sym_preproc_if_token1,
  [aux_sym_preproc_if_token2] = aux_sym_preproc_if_token2,
  [aux_sym_preproc_if_token3] = aux_sym_preproc_if_token3,
  [aux_sym_preproc_else_token1] = aux_sym_preproc_else_token1,
  [aux_sym_preproc_elif_token1] = aux_sym_preproc_elif_token1,
  [sym_preproc_arg] = sym_preproc_arg,
  [aux_sym_preproc_region_token1] = aux_sym_preproc_region_token1,
  [aux_sym_preproc_endregion_token1] = aux_sym_preproc_endregion_token1,
  [aux_sym_preproc_line_token1] = aux_sym_preproc_line_token1,
  [anon_sym_hidden] = anon_sym_hidden,
  [aux_sym_preproc_pragma_token1] = aux_sym_preproc_pragma_token1,
  [anon_sym_warning] = anon_sym_warning,
  [anon_sym_disable] = anon_sym_disable,
  [anon_sym_restore] = anon_sym_restore,
  [anon_sym_checksum] = anon_sym_checksum,
  [aux_sym_preproc_nullable_token1] = aux_sym_preproc_nullable_token1,
  [anon_sym_enable] = anon_sym_enable,
  [anon_sym_annotations] = anon_sym_annotations,
  [anon_sym_warnings] = anon_sym_warnings,
  [aux_sym_preproc_error_token1] = aux_sym_preproc_error_token1,
  [aux_sym_preproc_warning_token1] = aux_sym_preproc_warning_token1,
  [aux_sym_preproc_define_token1] = aux_sym_preproc_define_token1,
  [aux_sym_preproc_undef_token1] = aux_sym_preproc_undef_token1,
  [sym_shebang_directive] = sym_shebang_directive,
  [sym_comment] = sym_comment,
  [sym__optional_semi] = sym__optional_semi,
  [sym_interpolation_regular_start] = sym_interpolation_regular_start,
  [sym_interpolation_verbatim_start] = sym_interpolation_regular_start,
  [sym_interpolation_raw_start] = sym_interpolation_regular_start,
  [sym_interpolation_start_quote] = anon_sym_DQUOTE,
  [sym_interpolation_end_quote] = anon_sym_DQUOTE,
  [sym_interpolation_open_brace] = sym_interpolation_open_brace,
  [sym_interpolation_close_brace] = sym_interpolation_open_brace,
  [sym_interpolation_string_content] = sym_interpolation_string_content,
  [sym_raw_string_start] = sym_raw_string_start,
  [sym_raw_string_end] = sym_raw_string_end,
  [sym_raw_string_content] = sym_raw_string_content,
  [sym_compilation_unit] = sym_compilation_unit,
  [sym__top_level_item] = sym__top_level_item,
  [sym_global_statement] = sym_global_statement,
  [sym_extern_alias_directive] = sym_extern_alias_directive,
  [sym_using_directive] = sym_using_directive,
  [sym_global_attribute] = sym_global_attribute,
  [sym_attribute] = sym_attribute,
  [sym_attribute_argument_list] = sym_attribute_argument_list,
  [sym_attribute_argument] = sym_attribute_argument,
  [sym_attribute_list] = sym_attribute_list,
  [sym_attribute_target_specifier] = sym_attribute_target_specifier,
  [sym_namespace_declaration] = sym_namespace_declaration,
  [sym_file_scoped_namespace_declaration] = sym_file_scoped_namespace_declaration,
  [sym_type_declaration] = sym_type_declaration,
  [sym_class_declaration] = sym_class_declaration,
  [sym_struct_declaration] = sym_struct_declaration,
  [sym_enum_declaration] = sym_enum_declaration,
  [sym_enum_member_declaration_list] = sym_enum_member_declaration_list,
  [sym_enum_member_declaration] = sym_enum_member_declaration,
  [sym_interface_declaration] = sym_interface_declaration,
  [sym_delegate_declaration] = sym_delegate_declaration,
  [sym_record_declaration] = sym_record_declaration,
  [sym_record_base] = sym_base_list,
  [sym_primary_constructor_base_type] = sym_primary_constructor_base_type,
  [sym_modifier] = sym_modifier,
  [sym_type_parameter_list] = sym_type_parameter_list,
  [sym_type_parameter] = sym_type_parameter,
  [sym_base_list] = sym_base_list,
  [sym_type_parameter_constraints_clause] = sym_type_parameter_constraints_clause,
  [sym_type_parameter_constraint] = sym_type_parameter_constraint,
  [sym_constructor_constraint] = sym_constructor_constraint,
  [sym_operator_declaration] = sym_operator_declaration,
  [sym_conversion_operator_declaration] = sym_conversion_operator_declaration,
  [sym_declaration_list] = sym_declaration_list,
  [sym_declaration] = sym_declaration,
  [sym_field_declaration] = sym_field_declaration,
  [sym_constructor_declaration] = sym_constructor_declaration,
  [sym_destructor_declaration] = sym_destructor_declaration,
  [sym_method_declaration] = sym_method_declaration,
  [sym_event_declaration] = sym_event_declaration,
  [sym_event_field_declaration] = sym_event_field_declaration,
  [sym_accessor_list] = sym_accessor_list,
  [sym_accessor_declaration] = sym_accessor_declaration,
  [sym_indexer_declaration] = sym_indexer_declaration,
  [sym_bracketed_parameter_list] = sym_bracketed_parameter_list,
  [sym_property_declaration] = sym_property_declaration,
  [sym_explicit_interface_specifier] = sym_explicit_interface_specifier,
  [sym_parameter_list] = sym_parameter_list,
  [sym_parameter] = sym_parameter,
  [sym__parameter_array] = sym__parameter_array,
  [sym_constructor_initializer] = sym_constructor_initializer,
  [sym_argument_list] = sym_argument_list,
  [sym_tuple_pattern] = sym_tuple_pattern,
  [sym_argument] = sym_argument,
  [sym_block] = sym_block,
  [sym_arrow_expression_clause] = sym_arrow_expression_clause,
  [sym__function_body] = sym__function_body,
  [sym_variable_declaration] = sym_variable_declaration,
  [sym_using_variable_declaration] = sym_variable_declaration,
  [sym_variable_declarator] = sym_variable_declarator,
  [sym_using_variable_declarator] = sym_variable_declarator,
  [sym_bracketed_argument_list] = sym_bracketed_argument_list,
  [sym__name] = sym__name,
  [sym_alias_qualified_name] = sym_alias_qualified_name,
  [sym__simple_name] = sym__simple_name,
  [sym_qualified_name] = sym_qualified_name,
  [sym_generic_name] = sym_generic_name,
  [sym_type_argument_list] = sym_type_argument_list,
  [sym_type] = sym_type,
  [sym_implicit_type] = sym_implicit_type,
  [sym_array_type] = sym_array_type,
  [sym__array_base_type] = sym__array_base_type,
  [sym_array_rank_specifier] = sym_array_rank_specifier,
  [sym_nullable_type] = sym_nullable_type,
  [sym_pointer_type] = sym_pointer_type,
  [sym__pointer_base_type] = sym__pointer_base_type,
  [sym_function_pointer_type] = sym_function_pointer_type,
  [sym_calling_convention] = sym_calling_convention,
  [sym_function_pointer_parameter] = sym_function_pointer_parameter,
  [sym_ref_type] = sym_ref_type,
  [sym__ref_base_type] = sym__ref_base_type,
  [sym_scoped_type] = sym_scoped_type,
  [sym__scoped_base_type] = sym__scoped_base_type,
  [sym_tuple_type] = sym_tuple_type,
  [sym_tuple_element] = sym_tuple_element,
  [sym_statement] = sym_statement,
  [sym_break_statement] = sym_break_statement,
  [sym_checked_statement] = sym_checked_statement,
  [sym_continue_statement] = sym_continue_statement,
  [sym_do_statement] = sym_do_statement,
  [sym_empty_statement] = sym_empty_statement,
  [sym_expression_statement] = sym_expression_statement,
  [sym_fixed_statement] = sym_fixed_statement,
  [sym_for_statement] = sym_for_statement,
  [sym_return_statement] = sym_return_statement,
  [sym_lock_statement] = sym_lock_statement,
  [sym_yield_statement] = sym_yield_statement,
  [sym_switch_statement] = sym_switch_statement,
  [sym_switch_body] = sym_switch_body,
  [sym_switch_section] = sym_switch_section,
  [sym_throw_statement] = sym_throw_statement,
  [sym_try_statement] = sym_try_statement,
  [sym_catch_clause] = sym_catch_clause,
  [sym_catch_declaration] = sym_catch_declaration,
  [sym_catch_filter_clause] = sym_catch_filter_clause,
  [sym_finally_clause] = sym_finally_clause,
  [sym_unsafe_statement] = sym_unsafe_statement,
  [sym_using_statement] = sym_using_statement,
  [sym_foreach_statement] = sym_foreach_statement,
  [sym_goto_statement] = sym_goto_statement,
  [sym_labeled_statement] = sym_labeled_statement,
  [sym_if_statement] = sym_if_statement,
  [sym_while_statement] = sym_while_statement,
  [sym_local_declaration_statement] = sym_local_declaration_statement,
  [sym_local_function_statement] = sym_local_function_statement,
  [sym_pattern] = sym_pattern,
  [sym_constant_pattern] = sym_constant_pattern,
  [sym_parenthesized_pattern] = sym_parenthesized_pattern,
  [sym_var_pattern] = sym_var_pattern,
  [sym_type_pattern] = sym_type_pattern,
  [sym_list_pattern] = sym_list_pattern,
  [sym_recursive_pattern] = sym_recursive_pattern,
  [sym_positional_pattern_clause] = sym_positional_pattern_clause,
  [sym_property_pattern_clause] = sym_property_pattern_clause,
  [sym_subpattern] = sym_subpattern,
  [sym_relational_pattern] = sym_relational_pattern,
  [sym_negated_pattern] = sym_negated_pattern,
  [sym_and_pattern] = sym_and_pattern,
  [sym_or_pattern] = sym_or_pattern,
  [sym_declaration_pattern] = sym_declaration_pattern,
  [sym__variable_designation] = sym__variable_designation,
  [sym_parenthesized_variable_designation] = sym_parenthesized_variable_designation,
  [sym_expression] = sym_expression,
  [sym_non_lvalue_expression] = sym_non_lvalue_expression,
  [sym_lvalue_expression] = sym_lvalue_expression,
  [sym__expression_statement_expression] = sym__expression_statement_expression,
  [sym_assignment_expression] = sym_assignment_expression,
  [sym_binary_expression] = sym_binary_expression,
  [sym_postfix_unary_expression] = sym_postfix_unary_expression,
  [sym_prefix_unary_expression] = sym_prefix_unary_expression,
  [sym__pointer_indirection_expression] = sym_prefix_unary_expression,
  [sym_query_expression] = sym_query_expression,
  [sym_from_clause] = sym_from_clause,
  [sym__query_body] = sym__query_body,
  [sym__query_clause] = sym__query_clause,
  [sym_join_clause] = sym_join_clause,
  [sym__join_header] = sym__join_header,
  [sym__join_body] = sym__join_body,
  [sym_join_into_clause] = sym_join_into_clause,
  [sym_let_clause] = sym_let_clause,
  [sym_order_by_clause] = sym_order_by_clause,
  [sym__ordering] = sym__ordering,
  [sym_where_clause] = sym_where_clause,
  [sym__select_or_group_clause] = sym__select_or_group_clause,
  [sym_group_clause] = sym_group_clause,
  [sym_select_clause] = sym_select_clause,
  [sym_conditional_expression] = sym_conditional_expression,
  [sym_conditional_access_expression] = sym_conditional_access_expression,
  [sym_as_expression] = sym_as_expression,
  [sym_is_expression] = sym_is_expression,
  [sym_is_pattern_expression] = sym_is_pattern_expression,
  [sym_cast_expression] = sym_cast_expression,
  [sym_checked_expression] = sym_checked_expression,
  [sym_invocation_expression] = sym_invocation_expression,
  [sym_switch_expression] = sym_switch_expression,
  [sym_switch_expression_arm] = sym_switch_expression_arm,
  [sym_when_clause] = sym_when_clause,
  [sym_await_expression] = sym_await_expression,
  [sym_throw_expression] = sym_throw_expression,
  [sym_element_access_expression] = sym_element_access_expression,
  [sym_interpolated_string_expression] = sym_interpolated_string_expression,
  [sym__interpolated_string_content] = sym__interpolated_string_content,
  [sym__interpolated_verbatim_string_content] = sym__interpolated_verbatim_string_content,
  [sym__interpolated_raw_string_content] = sym__interpolated_raw_string_content,
  [sym_interpolation] = sym_interpolation,
  [sym_interpolation_alignment_clause] = sym_interpolation_alignment_clause,
  [sym_interpolation_format_clause] = sym_interpolation_format_clause,
  [sym_member_access_expression] = sym_member_access_expression,
  [sym_member_binding_expression] = sym_member_binding_expression,
  [sym_object_creation_expression] = sym_object_creation_expression,
  [sym_parenthesized_expression] = sym_parenthesized_expression,
  [sym__parenthesized_lvalue_expression] = sym_parenthesized_expression,
  [sym_lambda_expression] = sym_lambda_expression,
  [sym__lambda_parameters] = sym__lambda_parameters,
  [sym_array_creation_expression] = sym_array_creation_expression,
  [sym_anonymous_method_expression] = sym_anonymous_method_expression,
  [sym_anonymous_object_creation_expression] = sym_anonymous_object_creation_expression,
  [sym__anonymous_object_member_declarator] = sym__anonymous_object_member_declarator,
  [sym_implicit_array_creation_expression] = sym_implicit_array_creation_expression,
  [sym_implicit_object_creation_expression] = sym_implicit_object_creation_expression,
  [sym_implicit_stackalloc_expression] = sym_implicit_stackalloc_expression,
  [sym_initializer_expression] = sym_initializer_expression,
  [sym_declaration_expression] = sym_declaration_expression,
  [sym_default_expression] = sym_default_expression,
  [sym_with_expression] = sym_with_expression,
  [sym_with_initializer] = sym_with_initializer,
  [sym_sizeof_expression] = sym_sizeof_expression,
  [sym_typeof_expression] = sym_typeof_expression,
  [sym_makeref_expression] = sym_makeref_expression,
  [sym_ref_expression] = sym_ref_expression,
  [sym_reftype_expression] = sym_reftype_expression,
  [sym_refvalue_expression] = sym_refvalue_expression,
  [sym_stackalloc_expression] = sym_stackalloc_expression,
  [sym_range_expression] = sym_range_expression,
  [sym_tuple_expression] = sym_tuple_expression,
  [sym_literal] = sym_literal,
  [sym_character_literal] = sym_character_literal,
  [sym_string_literal] = sym_string_literal,
  [sym_string_literal_content] = sym_string_literal_content,
  [sym_raw_string_literal] = sym_raw_string_literal,
  [sym_boolean_literal] = sym_boolean_literal,
  [sym_identifier] = sym_identifier,
  [sym__reserved_identifier] = sym__reserved_identifier,
  [sym_preproc_if] = sym_preproc_if,
  [sym_preproc_else] = sym_preproc_else,
  [sym_preproc_elif] = sym_preproc_elif,
  [sym_preproc_if_in_top_level] = sym_preproc_if,
  [sym_preproc_else_in_top_level] = sym_preproc_else,
  [sym_preproc_elif_in_top_level] = sym_preproc_elif,
  [sym_preproc_if_in_expression] = sym_preproc_if,
  [sym_preproc_else_in_expression] = sym_preproc_else,
  [sym_preproc_elif_in_expression] = sym_preproc_elif,
  [sym_preproc_if_in_enum_member_declaration] = sym_preproc_if,
  [sym_preproc_else_in_enum_member_declaration] = sym_preproc_else,
  [sym_preproc_elif_in_enum_member_declaration] = sym_preproc_elif,
  [sym__preproc_expression] = sym__preproc_expression,
  [sym_preproc_parenthesized_expression] = sym_parenthesized_expression,
  [sym_preproc_unary_expression] = sym_preproc_unary_expression,
  [sym_preproc_binary_expression] = sym_binary_expression,
  [sym_preproc_region] = sym_preproc_region,
  [sym_preproc_endregion] = sym_preproc_endregion,
  [sym_preproc_line] = sym_preproc_line,
  [sym_preproc_pragma] = sym_preproc_pragma,
  [sym_preproc_nullable] = sym_preproc_nullable,
  [sym_preproc_error] = sym_preproc_error,
  [sym_preproc_warning] = sym_preproc_warning,
  [sym_preproc_define] = sym_preproc_define,
  [sym_preproc_undef] = sym_preproc_undef,
  [aux_sym_compilation_unit_repeat1] = aux_sym_compilation_unit_repeat1,
  [aux_sym_global_attribute_repeat1] = aux_sym_global_attribute_repeat1,
  [aux_sym_attribute_argument_list_repeat1] = aux_sym_attribute_argument_list_repeat1,
  [aux_sym_class_declaration_repeat1] = aux_sym_class_declaration_repeat1,
  [aux_sym_class_declaration_repeat2] = aux_sym_class_declaration_repeat2,
  [aux_sym_class_declaration_repeat3] = aux_sym_class_declaration_repeat3,
  [aux_sym_enum_member_declaration_list_repeat1] = aux_sym_enum_member_declaration_list_repeat1,
  [aux_sym_record_base_repeat1] = aux_sym_record_base_repeat1,
  [aux_sym_type_parameter_list_repeat1] = aux_sym_type_parameter_list_repeat1,
  [aux_sym_base_list_repeat1] = aux_sym_base_list_repeat1,
  [aux_sym_type_parameter_constraints_clause_repeat1] = aux_sym_type_parameter_constraints_clause_repeat1,
  [aux_sym_declaration_list_repeat1] = aux_sym_declaration_list_repeat1,
  [aux_sym_accessor_list_repeat1] = aux_sym_accessor_list_repeat1,
  [aux_sym_bracketed_parameter_list_repeat1] = aux_sym_bracketed_parameter_list_repeat1,
  [aux_sym__parameter_type_with_modifiers_repeat1] = aux_sym__parameter_type_with_modifiers_repeat1,
  [aux_sym_argument_list_repeat1] = aux_sym_argument_list_repeat1,
  [aux_sym_tuple_pattern_repeat1] = aux_sym_tuple_pattern_repeat1,
  [aux_sym_block_repeat1] = aux_sym_block_repeat1,
  [aux_sym_variable_declaration_repeat1] = aux_sym_variable_declaration_repeat1,
  [aux_sym_using_variable_declaration_repeat1] = aux_sym_using_variable_declaration_repeat1,
  [aux_sym_type_argument_list_repeat1] = aux_sym_type_argument_list_repeat1,
  [aux_sym_type_argument_list_repeat2] = aux_sym_type_argument_list_repeat2,
  [aux_sym_array_rank_specifier_repeat1] = aux_sym_array_rank_specifier_repeat1,
  [aux_sym_function_pointer_type_repeat1] = aux_sym_function_pointer_type_repeat1,
  [aux_sym_calling_convention_repeat1] = aux_sym_calling_convention_repeat1,
  [aux_sym_tuple_type_repeat1] = aux_sym_tuple_type_repeat1,
  [aux_sym_for_statement_repeat1] = aux_sym_for_statement_repeat1,
  [aux_sym_switch_body_repeat1] = aux_sym_switch_body_repeat1,
  [aux_sym_try_statement_repeat1] = aux_sym_try_statement_repeat1,
  [aux_sym_list_pattern_repeat1] = aux_sym_list_pattern_repeat1,
  [aux_sym_positional_pattern_clause_repeat1] = aux_sym_positional_pattern_clause_repeat1,
  [aux_sym_parenthesized_variable_designation_repeat1] = aux_sym_parenthesized_variable_designation_repeat1,
  [aux_sym__query_body_repeat1] = aux_sym__query_body_repeat1,
  [aux_sym__query_body_repeat2] = aux_sym__query_body_repeat2,
  [aux_sym_order_by_clause_repeat1] = aux_sym_order_by_clause_repeat1,
  [aux_sym_switch_expression_repeat1] = aux_sym_switch_expression_repeat1,
  [aux_sym_interpolated_string_expression_repeat1] = aux_sym_interpolated_string_expression_repeat1,
  [aux_sym_interpolated_string_expression_repeat2] = aux_sym_interpolated_string_expression_repeat2,
  [aux_sym_interpolated_string_expression_repeat3] = aux_sym_interpolated_string_expression_repeat3,
  [aux_sym_lambda_expression_repeat1] = aux_sym_lambda_expression_repeat1,
  [aux_sym_anonymous_object_creation_expression_repeat1] = aux_sym_anonymous_object_creation_expression_repeat1,
  [aux_sym_with_expression_repeat1] = aux_sym_with_expression_repeat1,
  [aux_sym_string_literal_repeat1] = aux_sym_string_literal_repeat1,
  [aux_sym_preproc_if_in_top_level_repeat1] = aux_sym_preproc_if_in_top_level_repeat1,
  [aux_sym_preproc_pragma_repeat1] = aux_sym_preproc_pragma_repeat1,
  [alias_sym_element_binding_expression] = alias_sym_element_binding_expression,
  [alias_sym_implicit_parameter] = alias_sym_implicit_parameter,
  [alias_sym_interpolation_quote] = alias_sym_interpolation_quote,
};

static const TSSymbolMetadata ts_symbol_metadata[] = {
  [ts_builtin_sym_end] = {
    .visible = false,
    .named = true,
  },
  [sym__identifier_token] = {
    .visible = false,
    .named = true,
  },
  [anon_sym_extern] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_alias] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SEMI] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_global] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_using] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_unsafe] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_static] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_assembly] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_module] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COMMA] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_field] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_event] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_method] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_param] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_property] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_return] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_type] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_namespace] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_class] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ref] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_struct] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_enum] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_interface] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_delegate] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_record] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_abstract] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_async] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_const] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_file] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_fixed] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_internal] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_new] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_override] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_partial] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_private] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_protected] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_public] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_readonly] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_required] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_sealed] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_virtual] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_volatile] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_in] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_out] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_where] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_QMARK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_notnull] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_unmanaged] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_operator] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_checked] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BANG] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_TILDE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS_PLUS] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_true] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_false] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SLASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PERCENT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_CARET] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_LT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_GT_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BANG_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_implicit] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_explicit] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_get] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_set] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_add] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_remove] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_init] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_this] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_scoped] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_params] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_base] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_var] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_managed] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Cdecl] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Stdcall] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Thiscall] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Fastcall] = {
    .visible = true,
    .named = false,
  },
  [sym_predefined_type] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_break] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_unchecked] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_continue] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_do] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_while] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_for] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_lock] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_yield] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_switch] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_case] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_default] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_throw] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_try] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_catch] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_when] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_finally] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_await] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_foreach] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_goto] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_if] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_else] = {
    .visible = true,
    .named = false,
  },
  [sym_discard] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_DOT_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_not] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_and] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_or] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SLASH_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PERCENT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_CARET_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_LT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_GT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_GT_GT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_QMARK_QMARK_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_QMARK_QMARK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_from] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_into] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_join] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_on] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_equals] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_let] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_orderby] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ascending] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_descending] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_group] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_by] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_select] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_as] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_is] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_interpolation_format_clause_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_DASH_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_stackalloc] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_with] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_sizeof] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_typeof] = {
    .visible = true,
    .named = false,
  },
  [anon_sym___makeref] = {
    .visible = true,
    .named = false,
  },
  [anon_sym___reftype] = {
    .visible = true,
    .named = false,
  },
  [anon_sym___refvalue] = {
    .visible = true,
    .named = false,
  },
  [sym_null_literal] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_SQUOTE] = {
    .visible = true,
    .named = false,
  },
  [sym_character_literal_content] = {
    .visible = true,
    .named = true,
  },
  [sym_integer_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_real_literal] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_string_literal_content_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_string_literal_content_token2] = {
    .visible = false,
    .named = false,
  },
  [sym_escape_sequence] = {
    .visible = true,
    .named = true,
  },
  [sym_string_literal_encoding] = {
    .visible = true,
    .named = true,
  },
  [sym_verbatim_string_literal] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_raw_string_literal_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_if_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_preproc_if_token2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_if_token3] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_preproc_else_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_preproc_elif_token1] = {
    .visible = true,
    .named = false,
  },
  [sym_preproc_arg] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_preproc_region_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_preproc_endregion_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_preproc_line_token1] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_hidden] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_preproc_pragma_token1] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_warning] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_disable] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_restore] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_checksum] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_preproc_nullable_token1] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_enable] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_annotations] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_warnings] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_preproc_error_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_preproc_warning_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_preproc_define_token1] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_preproc_undef_token1] = {
    .visible = true,
    .named = false,
  },
  [sym_shebang_directive] = {
    .visible = true,
    .named = true,
  },
  [sym_comment] = {
    .visible = true,
    .named = true,
  },
  [sym__optional_semi] = {
    .visible = false,
    .named = true,
  },
  [sym_interpolation_regular_start] = {
    .visible = true,
    .named = true,
  },
  [sym_interpolation_verbatim_start] = {
    .visible = true,
    .named = true,
  },
  [sym_interpolation_raw_start] = {
    .visible = true,
    .named = true,
  },
  [sym_interpolation_start_quote] = {
    .visible = true,
    .named = false,
  },
  [sym_interpolation_end_quote] = {
    .visible = true,
    .named = false,
  },
  [sym_interpolation_open_brace] = {
    .visible = true,
    .named = true,
  },
  [sym_interpolation_close_brace] = {
    .visible = true,
    .named = true,
  },
  [sym_interpolation_string_content] = {
    .visible = true,
    .named = true,
  },
  [sym_raw_string_start] = {
    .visible = true,
    .named = true,
  },
  [sym_raw_string_end] = {
    .visible = true,
    .named = true,
  },
  [sym_raw_string_content] = {
    .visible = true,
    .named = true,
  },
  [sym_compilation_unit] = {
    .visible = true,
    .named = true,
  },
  [sym__top_level_item] = {
    .visible = false,
    .named = true,
  },
  [sym_global_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_extern_alias_directive] = {
    .visible = true,
    .named = true,
  },
  [sym_using_directive] = {
    .visible = true,
    .named = true,
  },
  [sym_global_attribute] = {
    .visible = true,
    .named = true,
  },
  [sym_attribute] = {
    .visible = true,
    .named = true,
  },
  [sym_attribute_argument_list] = {
    .visible = true,
    .named = true,
  },
  [sym_attribute_argument] = {
    .visible = true,
    .named = true,
  },
  [sym_attribute_list] = {
    .visible = true,
    .named = true,
  },
  [sym_attribute_target_specifier] = {
    .visible = true,
    .named = true,
  },
  [sym_namespace_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_file_scoped_namespace_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_type_declaration] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_class_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_struct_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_enum_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_enum_member_declaration_list] = {
    .visible = true,
    .named = true,
  },
  [sym_enum_member_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_interface_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_delegate_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_record_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_record_base] = {
    .visible = true,
    .named = true,
  },
  [sym_primary_constructor_base_type] = {
    .visible = true,
    .named = true,
  },
  [sym_modifier] = {
    .visible = true,
    .named = true,
  },
  [sym_type_parameter_list] = {
    .visible = true,
    .named = true,
  },
  [sym_type_parameter] = {
    .visible = true,
    .named = true,
  },
  [sym_base_list] = {
    .visible = true,
    .named = true,
  },
  [sym_type_parameter_constraints_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_type_parameter_constraint] = {
    .visible = true,
    .named = true,
  },
  [sym_constructor_constraint] = {
    .visible = true,
    .named = true,
  },
  [sym_operator_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_conversion_operator_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_declaration_list] = {
    .visible = true,
    .named = true,
  },
  [sym_declaration] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_field_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_constructor_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_destructor_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_method_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_event_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_event_field_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_accessor_list] = {
    .visible = true,
    .named = true,
  },
  [sym_accessor_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_indexer_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_bracketed_parameter_list] = {
    .visible = true,
    .named = true,
  },
  [sym_property_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_explicit_interface_specifier] = {
    .visible = true,
    .named = true,
  },
  [sym_parameter_list] = {
    .visible = true,
    .named = true,
  },
  [sym_parameter] = {
    .visible = true,
    .named = true,
  },
  [sym__parameter_array] = {
    .visible = false,
    .named = true,
  },
  [sym_constructor_initializer] = {
    .visible = true,
    .named = true,
  },
  [sym_argument_list] = {
    .visible = true,
    .named = true,
  },
  [sym_tuple_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_argument] = {
    .visible = true,
    .named = true,
  },
  [sym_block] = {
    .visible = true,
    .named = true,
  },
  [sym_arrow_expression_clause] = {
    .visible = true,
    .named = true,
  },
  [sym__function_body] = {
    .visible = false,
    .named = true,
  },
  [sym_variable_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_using_variable_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_variable_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_using_variable_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_bracketed_argument_list] = {
    .visible = true,
    .named = true,
  },
  [sym__name] = {
    .visible = false,
    .named = true,
  },
  [sym_alias_qualified_name] = {
    .visible = true,
    .named = true,
  },
  [sym__simple_name] = {
    .visible = false,
    .named = true,
  },
  [sym_qualified_name] = {
    .visible = true,
    .named = true,
  },
  [sym_generic_name] = {
    .visible = true,
    .named = true,
  },
  [sym_type_argument_list] = {
    .visible = true,
    .named = true,
  },
  [sym_type] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_implicit_type] = {
    .visible = true,
    .named = true,
  },
  [sym_array_type] = {
    .visible = true,
    .named = true,
  },
  [sym__array_base_type] = {
    .visible = false,
    .named = true,
  },
  [sym_array_rank_specifier] = {
    .visible = true,
    .named = true,
  },
  [sym_nullable_type] = {
    .visible = true,
    .named = true,
  },
  [sym_pointer_type] = {
    .visible = true,
    .named = true,
  },
  [sym__pointer_base_type] = {
    .visible = false,
    .named = true,
  },
  [sym_function_pointer_type] = {
    .visible = true,
    .named = true,
  },
  [sym_calling_convention] = {
    .visible = true,
    .named = true,
  },
  [sym_function_pointer_parameter] = {
    .visible = true,
    .named = true,
  },
  [sym_ref_type] = {
    .visible = true,
    .named = true,
  },
  [sym__ref_base_type] = {
    .visible = false,
    .named = true,
  },
  [sym_scoped_type] = {
    .visible = true,
    .named = true,
  },
  [sym__scoped_base_type] = {
    .visible = false,
    .named = true,
  },
  [sym_tuple_type] = {
    .visible = true,
    .named = true,
  },
  [sym_tuple_element] = {
    .visible = true,
    .named = true,
  },
  [sym_statement] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_break_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_checked_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_continue_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_do_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_empty_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_expression_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_fixed_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_for_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_return_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_lock_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_yield_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_switch_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_switch_body] = {
    .visible = true,
    .named = true,
  },
  [sym_switch_section] = {
    .visible = true,
    .named = true,
  },
  [sym_throw_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_try_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_catch_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_catch_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_catch_filter_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_finally_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_unsafe_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_using_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_foreach_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_goto_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_labeled_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_if_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_while_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_local_declaration_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_local_function_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_pattern] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_constant_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_parenthesized_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_var_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_type_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_list_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_recursive_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_positional_pattern_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_property_pattern_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_subpattern] = {
    .visible = true,
    .named = true,
  },
  [sym_relational_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_negated_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_and_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_or_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_declaration_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym__variable_designation] = {
    .visible = false,
    .named = true,
  },
  [sym_parenthesized_variable_designation] = {
    .visible = true,
    .named = true,
  },
  [sym_expression] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_non_lvalue_expression] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_lvalue_expression] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym__expression_statement_expression] = {
    .visible = false,
    .named = true,
  },
  [sym_assignment_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_binary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_postfix_unary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_prefix_unary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym__pointer_indirection_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_query_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_from_clause] = {
    .visible = true,
    .named = true,
  },
  [sym__query_body] = {
    .visible = false,
    .named = true,
  },
  [sym__query_clause] = {
    .visible = false,
    .named = true,
  },
  [sym_join_clause] = {
    .visible = true,
    .named = true,
  },
  [sym__join_header] = {
    .visible = false,
    .named = true,
  },
  [sym__join_body] = {
    .visible = false,
    .named = true,
  },
  [sym_join_into_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_let_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_order_by_clause] = {
    .visible = true,
    .named = true,
  },
  [sym__ordering] = {
    .visible = false,
    .named = true,
  },
  [sym_where_clause] = {
    .visible = true,
    .named = true,
  },
  [sym__select_or_group_clause] = {
    .visible = false,
    .named = true,
  },
  [sym_group_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_select_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_conditional_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_conditional_access_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_as_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_is_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_is_pattern_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_cast_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_checked_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_invocation_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_switch_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_switch_expression_arm] = {
    .visible = true,
    .named = true,
  },
  [sym_when_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_await_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_throw_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_element_access_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_interpolated_string_expression] = {
    .visible = true,
    .named = true,
  },
  [sym__interpolated_string_content] = {
    .visible = false,
    .named = true,
  },
  [sym__interpolated_verbatim_string_content] = {
    .visible = false,
    .named = true,
  },
  [sym__interpolated_raw_string_content] = {
    .visible = false,
    .named = true,
  },
  [sym_interpolation] = {
    .visible = true,
    .named = true,
  },
  [sym_interpolation_alignment_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_interpolation_format_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_member_access_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_member_binding_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_object_creation_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_parenthesized_expression] = {
    .visible = true,
    .named = true,
  },
  [sym__parenthesized_lvalue_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_lambda_expression] = {
    .visible = true,
    .named = true,
  },
  [sym__lambda_parameters] = {
    .visible = false,
    .named = true,
  },
  [sym_array_creation_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_anonymous_method_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_anonymous_object_creation_expression] = {
    .visible = true,
    .named = true,
  },
  [sym__anonymous_object_member_declarator] = {
    .visible = false,
    .named = true,
  },
  [sym_implicit_array_creation_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_implicit_object_creation_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_implicit_stackalloc_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_initializer_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_declaration_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_default_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_with_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_with_initializer] = {
    .visible = true,
    .named = true,
  },
  [sym_sizeof_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_typeof_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_makeref_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_ref_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_reftype_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_refvalue_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_stackalloc_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_range_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_tuple_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_literal] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_character_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_string_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_string_literal_content] = {
    .visible = true,
    .named = true,
  },
  [sym_raw_string_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_boolean_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym__reserved_identifier] = {
    .visible = false,
    .named = true,
  },
  [sym_preproc_if] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_else] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_elif] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_if_in_top_level] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_else_in_top_level] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_elif_in_top_level] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_if_in_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_else_in_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_elif_in_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_if_in_enum_member_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_else_in_enum_member_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_elif_in_enum_member_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym__preproc_expression] = {
    .visible = false,
    .named = true,
  },
  [sym_preproc_parenthesized_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_unary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_binary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_region] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_endregion] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_line] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_pragma] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_nullable] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_error] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_warning] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_define] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_undef] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_compilation_unit_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_global_attribute_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_attribute_argument_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_class_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_class_declaration_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_class_declaration_repeat3] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_enum_member_declaration_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_record_base_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_type_parameter_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_base_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_type_parameter_constraints_clause_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_declaration_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_accessor_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_bracketed_parameter_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__parameter_type_with_modifiers_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_argument_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_tuple_pattern_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_block_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_variable_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_using_variable_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_type_argument_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_type_argument_list_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_array_rank_specifier_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_function_pointer_type_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_calling_convention_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_tuple_type_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_for_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_switch_body_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_try_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_list_pattern_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_positional_pattern_clause_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_parenthesized_variable_designation_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__query_body_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__query_body_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_order_by_clause_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_switch_expression_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_interpolated_string_expression_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_interpolated_string_expression_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_interpolated_string_expression_repeat3] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_lambda_expression_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_anonymous_object_creation_expression_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_with_expression_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_string_literal_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_if_in_top_level_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_preproc_pragma_repeat1] = {
    .visible = false,
    .named = false,
  },
  [alias_sym_element_binding_expression] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_implicit_parameter] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_interpolation_quote] = {
    .visible = true,
    .named = true,
  },
};

enum ts_field_identifiers {
  field_accessors = 1,
  field_alias = 2,
  field_alternative = 3,
  field_argument = 4,
  field_arguments = 5,
  field_body = 6,
  field_condition = 7,
  field_consequence = 8,
  field_content = 9,
  field_expression = 10,
  field_function = 11,
  field_initializer = 12,
  field_left = 13,
  field_name = 14,
  field_operator = 15,
  field_parameters = 16,
  field_pattern = 17,
  field_qualifier = 18,
  field_rank = 19,
  field_returns = 20,
  field_right = 21,
  field_subscript = 22,
  field_type = 23,
  field_type_parameters = 24,
  field_update = 25,
  field_value = 26,
};

static const char * const ts_field_names[] = {
  [0] = NULL,
  [field_accessors] = "accessors",
  [field_alias] = "alias",
  [field_alternative] = "alternative",
  [field_argument] = "argument",
  [field_arguments] = "arguments",
  [field_body] = "body",
  [field_condition] = "condition",
  [field_consequence] = "consequence",
  [field_content] = "content",
  [field_expression] = "expression",
  [field_function] = "function",
  [field_initializer] = "initializer",
  [field_left] = "left",
  [field_name] = "name",
  [field_operator] = "operator",
  [field_parameters] = "parameters",
  [field_pattern] = "pattern",
  [field_qualifier] = "qualifier",
  [field_rank] = "rank",
  [field_returns] = "returns",
  [field_right] = "right",
  [field_subscript] = "subscript",
  [field_type] = "type",
  [field_type_parameters] = "type_parameters",
  [field_update] = "update",
  [field_value] = "value",
};

static const TSFieldMapSlice ts_field_map_slices[PRODUCTION_ID_COUNT] = {
  [4] = {.index = 0, .length = 1},
  [5] = {.index = 1, .length = 1},
  [6] = {.index = 2, .length = 1},
  [7] = {.index = 3, .length = 1},
  [8] = {.index = 4, .length = 2},
  [9] = {.index = 6, .length = 2},
  [10] = {.index = 8, .length = 2},
  [11] = {.index = 10, .length = 1},
  [13] = {.index = 11, .length = 2},
  [14] = {.index = 13, .length = 2},
  [15] = {.index = 15, .length = 1},
  [16] = {.index = 16, .length = 1},
  [17] = {.index = 17, .length = 1},
  [18] = {.index = 18, .length = 2},
  [19] = {.index = 20, .length = 2},
  [20] = {.index = 22, .length = 2},
  [21] = {.index = 24, .length = 2},
  [22] = {.index = 26, .length = 2},
  [23] = {.index = 28, .length = 2},
  [24] = {.index = 30, .length = 3},
  [25] = {.index = 33, .length = 1},
  [26] = {.index = 33, .length = 1},
  [27] = {.index = 34, .length = 2},
  [28] = {.index = 36, .length = 2},
  [29] = {.index = 38, .length = 2},
  [31] = {.index = 40, .length = 1},
  [32] = {.index = 41, .length = 2},
  [33] = {.index = 43, .length = 2},
  [34] = {.index = 45, .length = 4},
  [35] = {.index = 49, .length = 4},
  [36] = {.index = 53, .length = 2},
  [37] = {.index = 55, .length = 2},
  [38] = {.index = 57, .length = 3},
  [39] = {.index = 60, .length = 1},
  [40] = {.index = 61, .length = 3},
  [41] = {.index = 64, .length = 1},
  [42] = {.index = 65, .length = 4},
  [43] = {.index = 69, .length = 1},
  [44] = {.index = 70, .length = 2},
  [45] = {.index = 72, .length = 1},
  [46] = {.index = 73, .length = 2},
  [47] = {.index = 75, .length = 1},
  [48] = {.index = 76, .length = 1},
  [49] = {.index = 77, .length = 2},
  [50] = {.index = 79, .length = 2},
  [51] = {.index = 81, .length = 2},
  [52] = {.index = 83, .length = 3},
  [53] = {.index = 86, .length = 1},
  [54] = {.index = 87, .length = 3},
  [55] = {.index = 90, .length = 2},
  [56] = {.index = 92, .length = 2},
  [57] = {.index = 94, .length = 1},
  [58] = {.index = 95, .length = 2},
  [59] = {.index = 97, .length = 2},
  [60] = {.index = 99, .length = 1},
  [61] = {.index = 100, .length = 2},
  [62] = {.index = 102, .length = 2},
  [63] = {.index = 104, .length = 5},
  [64] = {.index = 109, .length = 4},
  [65] = {.index = 113, .length = 3},
  [66] = {.index = 116, .length = 2},
  [67] = {.index = 118, .length = 3},
  [68] = {.index = 121, .length = 4},
  [69] = {.index = 125, .length = 2},
  [70] = {.index = 127, .length = 3},
  [71] = {.index = 130, .length = 3},
  [72] = {.index = 133, .length = 2},
  [73] = {.index = 135, .length = 2},
  [74] = {.index = 137, .length = 2},
  [75] = {.index = 139, .length = 3},
  [76] = {.index = 142, .length = 1},
  [77] = {.index = 143, .length = 4},
  [78] = {.index = 147, .length = 1},
  [79] = {.index = 148, .length = 1},
  [80] = {.index = 149, .length = 2},
  [81] = {.index = 151, .length = 2},
  [82] = {.index = 153, .length = 5},
  [83] = {.index = 158, .length = 2},
  [84] = {.index = 160, .length = 2},
  [85] = {.index = 162, .length = 3},
  [86] = {.index = 165, .length = 3},
  [87] = {.index = 168, .length = 1},
  [88] = {.index = 169, .length = 5},
  [89] = {.index = 174, .length = 4},
  [90] = {.index = 178, .length = 4},
  [91] = {.index = 182, .length = 3},
  [92] = {.index = 185, .length = 3},
  [93] = {.index = 188, .length = 3},
  [94] = {.index = 191, .length = 3},
  [95] = {.index = 194, .length = 3},
  [96] = {.index = 197, .length = 4},
  [97] = {.index = 201, .length = 3},
  [98] = {.index = 204, .length = 3},
  [99] = {.index = 207, .length = 2},
  [100] = {.index = 209, .length = 2},
  [101] = {.index = 211, .length = 2},
  [102] = {.index = 213, .length = 3},
  [103] = {.index = 216, .length = 1},
  [104] = {.index = 217, .length = 2},
  [105] = {.index = 219, .length = 2},
  [106] = {.index = 221, .length = 2},
  [107] = {.index = 223, .length = 2},
  [108] = {.index = 225, .length = 3},
  [109] = {.index = 228, .length = 3},
  [110] = {.index = 231, .length = 2},
  [111] = {.index = 233, .length = 2},
  [112] = {.index = 235, .length = 3},
  [113] = {.index = 238, .length = 4},
  [114] = {.index = 242, .length = 5},
  [115] = {.index = 247, .length = 2},
  [116] = {.index = 249, .length = 3},
  [117] = {.index = 252, .length = 3},
  [118] = {.index = 255, .length = 1},
  [119] = {.index = 256, .length = 5},
  [120] = {.index = 261, .length = 4},
  [121] = {.index = 265, .length = 3},
  [122] = {.index = 268, .length = 2},
  [123] = {.index = 270, .length = 3},
  [124] = {.index = 273, .length = 3},
  [125] = {.index = 276, .length = 4},
  [126] = {.index = 280, .length = 3},
  [127] = {.index = 283, .length = 3},
  [128] = {.index = 286, .length = 4},
  [129] = {.index = 290, .length = 3},
  [130] = {.index = 293, .length = 2},
  [131] = {.index = 295, .length = 5},
  [132] = {.index = 300, .length = 4},
  [133] = {.index = 304, .length = 3},
  [134] = {.index = 307, .length = 3},
  [135] = {.index = 310, .length = 4},
  [136] = {.index = 314, .length = 3},
  [137] = {.index = 317, .length = 3},
  [138] = {.index = 320, .length = 2},
  [139] = {.index = 322, .length = 2},
  [140] = {.index = 324, .length = 3},
  [141] = {.index = 327, .length = 3},
  [142] = {.index = 330, .length = 3},
  [143] = {.index = 333, .length = 3},
  [144] = {.index = 336, .length = 3},
  [145] = {.index = 339, .length = 3},
  [146] = {.index = 342, .length = 4},
  [147] = {.index = 346, .length = 2},
  [148] = {.index = 348, .length = 3},
  [149] = {.index = 351, .length = 2},
  [150] = {.index = 353, .length = 3},
  [151] = {.index = 356, .length = 4},
  [152] = {.index = 360, .length = 5},
  [153] = {.index = 365, .length = 3},
  [154] = {.index = 368, .length = 4},
  [155] = {.index = 372, .length = 3},
  [156] = {.index = 375, .length = 5},
  [157] = {.index = 380, .length = 4},
  [158] = {.index = 384, .length = 2},
  [159] = {.index = 386, .length = 5},
  [160] = {.index = 391, .length = 4},
  [161] = {.index = 395, .length = 3},
  [162] = {.index = 398, .length = 2},
  [163] = {.index = 400, .length = 3},
  [164] = {.index = 403, .length = 4},
  [165] = {.index = 407, .length = 3},
  [166] = {.index = 410, .length = 3},
  [167] = {.index = 413, .length = 4},
  [168] = {.index = 417, .length = 3},
  [169] = {.index = 420, .length = 5},
  [170] = {.index = 425, .length = 4},
  [171] = {.index = 429, .length = 2},
  [172] = {.index = 431, .length = 3},
  [173] = {.index = 434, .length = 3},
  [174] = {.index = 437, .length = 4},
  [175] = {.index = 441, .length = 3},
  [176] = {.index = 444, .length = 3},
  [177] = {.index = 447, .length = 2},
  [178] = {.index = 449, .length = 4},
  [179] = {.index = 453, .length = 4},
  [180] = {.index = 457, .length = 4},
  [181] = {.index = 461, .length = 4},
  [182] = {.index = 465, .length = 4},
  [183] = {.index = 469, .length = 4},
  [184] = {.index = 473, .length = 2},
  [185] = {.index = 475, .length = 2},
  [186] = {.index = 477, .length = 3},
  [187] = {.index = 480, .length = 3},
  [188] = {.index = 483, .length = 4},
  [189] = {.index = 487, .length = 5},
  [190] = {.index = 492, .length = 4},
  [191] = {.index = 496, .length = 2},
  [192] = {.index = 498, .length = 4},
  [193] = {.index = 502, .length = 3},
  [194] = {.index = 505, .length = 5},
  [195] = {.index = 510, .length = 4},
  [196] = {.index = 514, .length = 5},
  [197] = {.index = 519, .length = 4},
  [198] = {.index = 523, .length = 2},
  [199] = {.index = 525, .length = 3},
  [200] = {.index = 528, .length = 4},
  [201] = {.index = 532, .length = 3},
  [202] = {.index = 535, .length = 3},
  [203] = {.index = 538, .length = 4},
  [204] = {.index = 542, .length = 3},
  [205] = {.index = 545, .length = 5},
  [206] = {.index = 550, .length = 4},
  [207] = {.index = 554, .length = 5},
  [208] = {.index = 559, .length = 5},
  [209] = {.index = 564, .length = 5},
  [210] = {.index = 569, .length = 2},
  [211] = {.index = 571, .length = 2},
  [212] = {.index = 573, .length = 3},
  [213] = {.index = 576, .length = 4},
  [214] = {.index = 580, .length = 5},
  [215] = {.index = 585, .length = 4},
  [216] = {.index = 589, .length = 4},
  [217] = {.index = 593, .length = 3},
  [218] = {.index = 596, .length = 5},
  [219] = {.index = 601, .length = 4},
  [220] = {.index = 605, .length = 5},
  [221] = {.index = 610, .length = 4},
  [222] = {.index = 614, .length = 6},
  [223] = {.index = 620, .length = 2},
  [224] = {.index = 622, .length = 3},
  [225] = {.index = 625, .length = 4},
  [226] = {.index = 629, .length = 5},
  [227] = {.index = 634, .length = 4},
};

static const TSFieldMapEntry ts_field_map_entries[] = {
  [0] =
    {field_name, 0},
  [1] =
    {field_type, 0},
  [2] =
    {field_type, 1},
  [3] =
    {field_body, 1},
  [4] =
    {field_rank, 1},
    {field_type, 0},
  [6] =
    {field_arguments, 1},
    {field_function, 0},
  [8] =
    {field_expression, 0},
    {field_subscript, 1},
  [10] =
    {field_content, 1},
  [11] =
    {field_name, 1},
    {field_type, 0},
  [13] =
    {field_name, 1, .inherited = true},
    {field_type, 1, .inherited = true},
  [15] =
    {field_name, 1},
  [16] =
    {field_type, 2},
  [17] =
    {field_parameters, 1},
  [18] =
    {field_arguments, 2},
    {field_type, 1},
  [20] =
    {field_initializer, 2},
    {field_type, 1},
  [22] =
    {field_expression, 0},
    {field_name, 2},
  [24] =
    {field_body, 2},
    {field_value, 1},
  [26] =
    {field_argument, 1},
    {field_operator, 0},
  [28] =
    {field_name, 2},
    {field_qualifier, 0},
  [30] =
    {field_left, 0},
    {field_operator, 1},
    {field_right, 2},
  [33] =
    {field_condition, 0},
  [34] =
    {field_expression, 0},
    {field_pattern, 2},
  [36] =
    {field_body, 2},
    {field_parameters, 0},
  [38] =
    {field_alias, 0},
    {field_name, 2},
  [40] =
    {field_name, 2},
  [41] =
    {field_name, 2},
    {field_type, 1},
  [43] =
    {field_name, 2, .inherited = true},
    {field_type, 2, .inherited = true},
  [45] =
    {field_name, 0, .inherited = true},
    {field_name, 1, .inherited = true},
    {field_type, 0, .inherited = true},
    {field_type, 1, .inherited = true},
  [49] =
    {field_name, 1, .inherited = true},
    {field_name, 2, .inherited = true},
    {field_type, 1, .inherited = true},
    {field_type, 2, .inherited = true},
  [53] =
    {field_type, 1},
    {field_value, 3},
  [55] =
    {field_body, 2},
    {field_name, 1},
  [57] =
    {field_arguments, 2},
    {field_initializer, 3},
    {field_type, 1},
  [60] =
    {field_condition, 1},
  [61] =
    {field_body, 3},
    {field_parameters, 1},
    {field_type, 0},
  [64] =
    {field_body, 0},
  [65] =
    {field_body, 3, .inherited = true},
    {field_name, 1},
    {field_parameters, 2},
    {field_type, 0},
  [69] =
    {field_name, 1, .inherited = true},
  [70] =
    {field_name, 1, .inherited = true},
    {field_type, 0},
  [72] =
    {field_type, 1, .inherited = true},
  [73] =
    {field_body, 3},
    {field_parameters, 1},
  [75] =
    {field_parameters, 2},
  [76] =
    {field_body, 4},
  [77] =
    {field_name, 3},
    {field_type, 2},
  [79] =
    {field_body, 3},
    {field_name, 1},
  [81] =
    {field_body, 3},
    {field_name, 2},
  [83] =
    {field_body, 3},
    {field_name, 1},
    {field_type_parameters, 2},
  [86] =
    {field_returns, 3},
  [87] =
    {field_name, 2},
    {field_parameters, 3},
    {field_type, 1},
  [90] =
    {field_body, 4},
    {field_condition, 2},
  [92] =
    {field_body, 4},
    {field_value, 2},
  [94] =
    {field_body, 2},
  [95] =
    {field_condition, 2},
    {field_consequence, 4},
  [97] =
    {field_alternative, 3},
    {field_condition, 1},
  [99] =
    {field_name, 2, .inherited = true},
  [100] =
    {field_name, 0, .inherited = true},
    {field_name, 1, .inherited = true},
  [102] =
    {field_name, 1},
    {field_name, 2, .inherited = true},
  [104] =
    {field_body, 4, .inherited = true},
    {field_name, 1},
    {field_parameters, 3},
    {field_type, 0},
    {field_type_parameters, 2},
  [109] =
    {field_body, 4, .inherited = true},
    {field_name, 1},
    {field_parameters, 2},
    {field_type, 0},
  [113] =
    {field_alternative, 4},
    {field_condition, 0},
    {field_consequence, 2},
  [116] =
    {field_name, 2, .inherited = true},
    {field_type, 0},
  [118] =
    {field_body, 4},
    {field_parameters, 2},
    {field_type, 1},
  [121] =
    {field_body, 4, .inherited = true},
    {field_name, 2},
    {field_parameters, 3},
    {field_type, 1},
  [125] =
    {field_body, 4},
    {field_parameters, 2},
  [127] =
    {field_accessors, 2},
    {field_name, 1},
    {field_type, 0},
  [130] =
    {field_body, 2, .inherited = true},
    {field_name, 0},
    {field_parameters, 1},
  [133] =
    {field_body, 4},
    {field_name, 1},
  [135] =
    {field_body, 4},
    {field_name, 2},
  [137] =
    {field_name, 0},
    {field_value, 2},
  [139] =
    {field_body, 4},
    {field_name, 1},
    {field_type_parameters, 2},
  [142] =
    {field_returns, 4},
  [143] =
    {field_name, 2},
    {field_parameters, 4},
    {field_type, 1},
    {field_type_parameters, 3},
  [147] =
    {field_body, 5},
  [148] =
    {field_body, 3},
  [149] =
    {field_type, 4},
    {field_value, 2},
  [151] =
    {field_alternative, 4},
    {field_condition, 1},
  [153] =
    {field_body, 5, .inherited = true},
    {field_name, 1},
    {field_parameters, 3},
    {field_type, 0},
    {field_type_parameters, 2},
  [158] =
    {field_name, 3, .inherited = true},
    {field_type, 0},
  [160] =
    {field_body, 4},
    {field_name, 3},
  [162] =
    {field_body, 4},
    {field_name, 2},
    {field_type_parameters, 3},
  [165] =
    {field_name, 3},
    {field_parameters, 4},
    {field_type, 2},
  [168] =
    {field_name, 3},
  [169] =
    {field_body, 5, .inherited = true},
    {field_name, 2},
    {field_parameters, 4},
    {field_type, 1},
    {field_type_parameters, 3},
  [174] =
    {field_body, 5, .inherited = true},
    {field_name, 2},
    {field_parameters, 3},
    {field_type, 1},
  [178] =
    {field_body, 5, .inherited = true},
    {field_name, 3},
    {field_parameters, 4},
    {field_type, 2},
  [182] =
    {field_body, 5},
    {field_parameters, 3},
    {field_type, 2},
  [185] =
    {field_accessors, 3},
    {field_name, 2},
    {field_type, 1},
  [188] =
    {field_body, 3, .inherited = true},
    {field_name, 1},
    {field_parameters, 2},
  [191] =
    {field_accessors, 3},
    {field_parameters, 2},
    {field_type, 0},
  [194] =
    {field_accessors, 3},
    {field_name, 2},
    {field_type, 0},
  [197] =
    {field_body, 3, .inherited = true},
    {field_name, 1},
    {field_parameters, 2},
    {field_returns, 0},
  [201] =
    {field_name, 1},
    {field_type, 0},
    {field_value, 2},
  [204] =
    {field_body, 3, .inherited = true},
    {field_name, 0},
    {field_parameters, 1},
  [207] =
    {field_body, 5},
    {field_name, 1},
  [209] =
    {field_body, 5},
    {field_name, 2},
  [211] =
    {field_name, 1},
    {field_value, 3},
  [213] =
    {field_body, 5},
    {field_name, 1},
    {field_type_parameters, 2},
  [216] =
    {field_returns, 5},
  [217] =
    {field_body, 1},
    {field_condition, 4},
  [219] =
    {field_body, 6},
    {field_update, 4},
  [221] =
    {field_body, 6},
    {field_condition, 3},
  [223] =
    {field_body, 6},
    {field_initializer, 2},
  [225] =
    {field_body, 6},
    {field_left, 2},
    {field_right, 4},
  [228] =
    {field_alternative, 6},
    {field_condition, 2},
    {field_consequence, 4},
  [231] =
    {field_name, 1, .inherited = true},
    {field_name, 2, .inherited = true},
  [233] =
    {field_body, 5},
    {field_name, 3},
  [235] =
    {field_body, 5},
    {field_name, 2},
    {field_type_parameters, 3},
  [238] =
    {field_name, 3},
    {field_parameters, 5},
    {field_type, 2},
    {field_type_parameters, 4},
  [242] =
    {field_body, 6, .inherited = true},
    {field_name, 2},
    {field_parameters, 4},
    {field_type, 1},
    {field_type_parameters, 3},
  [247] =
    {field_body, 5},
    {field_name, 4},
  [249] =
    {field_body, 5},
    {field_name, 3},
    {field_type_parameters, 4},
  [252] =
    {field_name, 4},
    {field_parameters, 5},
    {field_type, 3},
  [255] =
    {field_name, 4},
  [256] =
    {field_body, 6, .inherited = true},
    {field_name, 3},
    {field_parameters, 5},
    {field_type, 2},
    {field_type_parameters, 4},
  [261] =
    {field_body, 6, .inherited = true},
    {field_name, 3},
    {field_parameters, 4},
    {field_type, 2},
  [265] =
    {field_body, 4, .inherited = true},
    {field_name, 2},
    {field_parameters, 3},
  [268] =
    {field_name, 3},
    {field_type, 1},
  [270] =
    {field_accessors, 4},
    {field_name, 3},
    {field_type, 1},
  [273] =
    {field_body, 4, .inherited = true},
    {field_parameters, 3},
    {field_type, 2},
  [276] =
    {field_body, 4, .inherited = true},
    {field_operator, 2},
    {field_parameters, 3},
    {field_type, 0},
  [280] =
    {field_parameters, 2},
    {field_type, 0},
    {field_value, 3},
  [283] =
    {field_accessors, 4},
    {field_parameters, 3},
    {field_type, 0},
  [286] =
    {field_body, 4, .inherited = true},
    {field_name, 2},
    {field_parameters, 3},
    {field_returns, 0},
  [290] =
    {field_name, 2},
    {field_type, 0},
    {field_value, 3},
  [293] =
    {field_body, 1, .inherited = true},
    {field_name, 0},
  [295] =
    {field_body, 4, .inherited = true},
    {field_name, 1},
    {field_parameters, 3},
    {field_returns, 0},
    {field_type_parameters, 2},
  [300] =
    {field_body, 4, .inherited = true},
    {field_name, 1},
    {field_parameters, 2},
    {field_returns, 0},
  [304] =
    {field_accessors, 4},
    {field_name, 3},
    {field_type, 2},
  [307] =
    {field_accessors, 4},
    {field_parameters, 3},
    {field_type, 1},
  [310] =
    {field_body, 4, .inherited = true},
    {field_name, 2},
    {field_parameters, 3},
    {field_returns, 1},
  [314] =
    {field_name, 2},
    {field_type, 1},
    {field_value, 3},
  [317] =
    {field_body, 4, .inherited = true},
    {field_name, 1},
    {field_parameters, 2},
  [320] =
    {field_body, 6},
    {field_name, 1},
  [322] =
    {field_body, 6},
    {field_name, 2},
  [324] =
    {field_body, 7},
    {field_update, 4},
    {field_update, 5},
  [327] =
    {field_body, 7},
    {field_condition, 3},
    {field_update, 5},
  [330] =
    {field_body, 7},
    {field_initializer, 2},
    {field_update, 5},
  [333] =
    {field_body, 7},
    {field_condition, 4},
    {field_initializer, 2},
  [336] =
    {field_body, 7},
    {field_initializer, 2},
    {field_initializer, 3},
  [339] =
    {field_body, 7},
    {field_left, 3},
    {field_right, 5},
  [342] =
    {field_body, 7},
    {field_left, 3},
    {field_right, 5},
    {field_type, 2},
  [346] =
    {field_body, 6},
    {field_name, 3},
  [348] =
    {field_body, 6},
    {field_name, 2},
    {field_type_parameters, 3},
  [351] =
    {field_body, 6},
    {field_name, 4},
  [353] =
    {field_body, 6},
    {field_name, 3},
    {field_type_parameters, 4},
  [356] =
    {field_name, 4},
    {field_parameters, 6},
    {field_type, 3},
    {field_type_parameters, 5},
  [360] =
    {field_body, 7, .inherited = true},
    {field_name, 3},
    {field_parameters, 5},
    {field_type, 2},
    {field_type_parameters, 4},
  [365] =
    {field_body, 5, .inherited = true},
    {field_parameters, 4},
    {field_type, 3},
  [368] =
    {field_body, 5, .inherited = true},
    {field_operator, 3},
    {field_parameters, 4},
    {field_type, 0},
  [372] =
    {field_parameters, 3},
    {field_type, 0},
    {field_value, 4},
  [375] =
    {field_body, 5, .inherited = true},
    {field_name, 2},
    {field_parameters, 4},
    {field_returns, 0},
    {field_type_parameters, 3},
  [380] =
    {field_body, 5, .inherited = true},
    {field_name, 2},
    {field_parameters, 3},
    {field_returns, 0},
  [384] =
    {field_body, 2, .inherited = true},
    {field_name, 1},
  [386] =
    {field_body, 5, .inherited = true},
    {field_name, 1},
    {field_parameters, 3},
    {field_returns, 0},
    {field_type_parameters, 2},
  [391] =
    {field_accessors, 2},
    {field_name, 1},
    {field_type, 0},
    {field_value, 4},
  [395] =
    {field_body, 5, .inherited = true},
    {field_name, 3},
    {field_parameters, 4},
  [398] =
    {field_name, 4},
    {field_type, 2},
  [400] =
    {field_accessors, 5},
    {field_name, 4},
    {field_type, 2},
  [403] =
    {field_body, 5, .inherited = true},
    {field_operator, 3},
    {field_parameters, 4},
    {field_type, 1},
  [407] =
    {field_parameters, 3},
    {field_type, 1},
    {field_value, 4},
  [410] =
    {field_accessors, 5},
    {field_parameters, 4},
    {field_type, 1},
  [413] =
    {field_body, 5, .inherited = true},
    {field_name, 3},
    {field_parameters, 4},
    {field_returns, 1},
  [417] =
    {field_name, 3},
    {field_type, 1},
    {field_value, 4},
  [420] =
    {field_body, 5, .inherited = true},
    {field_name, 2},
    {field_parameters, 4},
    {field_returns, 1},
    {field_type_parameters, 3},
  [425] =
    {field_body, 5, .inherited = true},
    {field_name, 2},
    {field_parameters, 3},
    {field_returns, 1},
  [429] =
    {field_name, 4},
    {field_type, 3},
  [431] =
    {field_accessors, 5},
    {field_name, 4},
    {field_type, 3},
  [434] =
    {field_accessors, 5},
    {field_parameters, 4},
    {field_type, 2},
  [437] =
    {field_body, 5, .inherited = true},
    {field_name, 3},
    {field_parameters, 4},
    {field_returns, 2},
  [441] =
    {field_name, 3},
    {field_type, 2},
    {field_value, 4},
  [444] =
    {field_body, 5, .inherited = true},
    {field_name, 2},
    {field_parameters, 3},
  [447] =
    {field_body, 7},
    {field_name, 2},
  [449] =
    {field_body, 8},
    {field_condition, 3},
    {field_update, 5},
    {field_update, 6},
  [453] =
    {field_body, 8},
    {field_initializer, 2},
    {field_update, 5},
    {field_update, 6},
  [457] =
    {field_body, 8},
    {field_condition, 4},
    {field_initializer, 2},
    {field_update, 6},
  [461] =
    {field_body, 8},
    {field_initializer, 2},
    {field_initializer, 3},
    {field_update, 6},
  [465] =
    {field_body, 8},
    {field_condition, 5},
    {field_initializer, 2},
    {field_initializer, 3},
  [469] =
    {field_body, 8},
    {field_left, 4},
    {field_right, 6},
    {field_type, 3},
  [473] =
    {field_body, 7},
    {field_name, 3},
  [475] =
    {field_body, 7},
    {field_name, 4},
  [477] =
    {field_body, 7},
    {field_name, 3},
    {field_type_parameters, 4},
  [480] =
    {field_body, 6, .inherited = true},
    {field_parameters, 5},
    {field_type, 4},
  [483] =
    {field_body, 6, .inherited = true},
    {field_operator, 4},
    {field_parameters, 5},
    {field_type, 0},
  [487] =
    {field_body, 6, .inherited = true},
    {field_name, 2},
    {field_parameters, 4},
    {field_returns, 0},
    {field_type_parameters, 3},
  [492] =
    {field_accessors, 3},
    {field_name, 2},
    {field_type, 0},
    {field_value, 5},
  [496] =
    {field_body, 3, .inherited = true},
    {field_name, 2},
  [498] =
    {field_body, 6, .inherited = true},
    {field_operator, 4},
    {field_parameters, 5},
    {field_type, 1},
  [502] =
    {field_parameters, 4},
    {field_type, 1},
    {field_value, 5},
  [505] =
    {field_body, 6, .inherited = true},
    {field_name, 3},
    {field_parameters, 5},
    {field_returns, 1},
    {field_type_parameters, 4},
  [510] =
    {field_body, 6, .inherited = true},
    {field_name, 3},
    {field_parameters, 4},
    {field_returns, 1},
  [514] =
    {field_body, 6, .inherited = true},
    {field_name, 2},
    {field_parameters, 4},
    {field_returns, 1},
    {field_type_parameters, 3},
  [519] =
    {field_accessors, 3},
    {field_name, 2},
    {field_type, 1},
    {field_value, 5},
  [523] =
    {field_name, 5},
    {field_type, 3},
  [525] =
    {field_accessors, 6},
    {field_name, 5},
    {field_type, 3},
  [528] =
    {field_body, 6, .inherited = true},
    {field_operator, 4},
    {field_parameters, 5},
    {field_type, 2},
  [532] =
    {field_parameters, 4},
    {field_type, 2},
    {field_value, 5},
  [535] =
    {field_accessors, 6},
    {field_parameters, 5},
    {field_type, 2},
  [538] =
    {field_body, 6, .inherited = true},
    {field_name, 4},
    {field_parameters, 5},
    {field_returns, 2},
  [542] =
    {field_name, 4},
    {field_type, 2},
    {field_value, 5},
  [545] =
    {field_body, 6, .inherited = true},
    {field_name, 3},
    {field_parameters, 5},
    {field_returns, 2},
    {field_type_parameters, 4},
  [550] =
    {field_body, 6, .inherited = true},
    {field_name, 3},
    {field_parameters, 4},
    {field_returns, 2},
  [554] =
    {field_body, 9},
    {field_condition, 4},
    {field_initializer, 2},
    {field_update, 6},
    {field_update, 7},
  [559] =
    {field_body, 9},
    {field_initializer, 2},
    {field_initializer, 3},
    {field_update, 6},
    {field_update, 7},
  [564] =
    {field_body, 9},
    {field_condition, 5},
    {field_initializer, 2},
    {field_initializer, 3},
    {field_update, 7},
  [569] =
    {field_body, 8},
    {field_name, 3},
  [571] =
    {field_body, 8},
    {field_name, 4},
  [573] =
    {field_body, 7, .inherited = true},
    {field_parameters, 6},
    {field_type, 5},
  [576] =
    {field_body, 7, .inherited = true},
    {field_operator, 5},
    {field_parameters, 6},
    {field_type, 1},
  [580] =
    {field_body, 7, .inherited = true},
    {field_name, 3},
    {field_parameters, 5},
    {field_returns, 1},
    {field_type_parameters, 4},
  [585] =
    {field_accessors, 4},
    {field_name, 3},
    {field_type, 1},
    {field_value, 6},
  [589] =
    {field_body, 7, .inherited = true},
    {field_operator, 5},
    {field_parameters, 6},
    {field_type, 2},
  [593] =
    {field_parameters, 5},
    {field_type, 2},
    {field_value, 6},
  [596] =
    {field_body, 7, .inherited = true},
    {field_name, 4},
    {field_parameters, 6},
    {field_returns, 2},
    {field_type_parameters, 5},
  [601] =
    {field_body, 7, .inherited = true},
    {field_name, 4},
    {field_parameters, 5},
    {field_returns, 2},
  [605] =
    {field_body, 7, .inherited = true},
    {field_name, 3},
    {field_parameters, 5},
    {field_returns, 2},
    {field_type_parameters, 4},
  [610] =
    {field_accessors, 4},
    {field_name, 3},
    {field_type, 2},
    {field_value, 6},
  [614] =
    {field_body, 10},
    {field_condition, 5},
    {field_initializer, 2},
    {field_initializer, 3},
    {field_update, 7},
    {field_update, 8},
  [620] =
    {field_body, 9},
    {field_name, 4},
  [622] =
    {field_body, 8, .inherited = true},
    {field_parameters, 7},
    {field_type, 6},
  [625] =
    {field_body, 8, .inherited = true},
    {field_operator, 6},
    {field_parameters, 7},
    {field_type, 2},
  [629] =
    {field_body, 8, .inherited = true},
    {field_name, 4},
    {field_parameters, 6},
    {field_returns, 2},
    {field_type_parameters, 5},
  [634] =
    {field_accessors, 5},
    {field_name, 4},
    {field_type, 2},
    {field_value, 7},
};

static const TSSymbol ts_alias_sequences[PRODUCTION_ID_COUNT][MAX_ALIAS_SEQUENCE_LENGTH] = {
  [0] = {0},
  [1] = {
    [0] = sym_modifier,
  },
  [2] = {
    [0] = alias_sym_element_binding_expression,
  },
  [3] = {
    [0] = alias_sym_implicit_parameter,
  },
  [12] = {
    [1] = alias_sym_interpolation_quote,
    [2] = alias_sym_interpolation_quote,
  },
  [25] = {
    [2] = alias_sym_element_binding_expression,
  },
  [30] = {
    [1] = alias_sym_interpolation_quote,
    [3] = alias_sym_interpolation_quote,
  },
};

static const uint16_t ts_non_terminal_alias_map[] = {
  sym_bracketed_argument_list, 2,
    sym_bracketed_argument_list,
    alias_sym_element_binding_expression,
  sym_identifier, 2,
    sym_identifier,
    alias_sym_implicit_parameter,
  0,
};

static const TSStateId ts_primary_state_ids[STATE_COUNT] = {
  [0] = 0,
  [1] = 1,
  [2] = 2,
  [3] = 2,
  [4] = 4,
  [5] = 2,
  [6] = 2,
  [7] = 7,
  [8] = 7,
  [9] = 7,
  [10] = 10,
  [11] = 11,
  [12] = 7,
  [13] = 13,
  [14] = 14,
  [15] = 15,
  [16] = 16,
  [17] = 17,
  [18] = 18,
  [19] = 19,
  [20] = 20,
  [21] = 21,
  [22] = 22,
  [23] = 21,
  [24] = 24,
  [25] = 21,
  [26] = 26,
  [27] = 27,
  [28] = 21,
  [29] = 29,
  [30] = 30,
  [31] = 21,
  [32] = 21,
  [33] = 21,
  [34] = 21,
  [35] = 21,
  [36] = 21,
  [37] = 37,
  [38] = 38,
  [39] = 39,
  [40] = 39,
  [41] = 38,
  [42] = 39,
  [43] = 38,
  [44] = 38,
  [45] = 39,
  [46] = 38,
  [47] = 38,
  [48] = 39,
  [49] = 39,
  [50] = 38,
  [51] = 39,
  [52] = 38,
  [53] = 38,
  [54] = 39,
  [55] = 39,
  [56] = 38,
  [57] = 39,
  [58] = 38,
  [59] = 39,
  [60] = 60,
  [61] = 61,
  [62] = 62,
  [63] = 60,
  [64] = 64,
  [65] = 65,
  [66] = 66,
  [67] = 67,
  [68] = 68,
  [69] = 69,
  [70] = 70,
  [71] = 71,
  [72] = 72,
  [73] = 73,
  [74] = 74,
  [75] = 75,
  [76] = 76,
  [77] = 77,
  [78] = 78,
  [79] = 79,
  [80] = 80,
  [81] = 81,
  [82] = 82,
  [83] = 83,
  [84] = 84,
  [85] = 85,
  [86] = 86,
  [87] = 87,
  [88] = 88,
  [89] = 89,
  [90] = 90,
  [91] = 61,
  [92] = 62,
  [93] = 60,
  [94] = 64,
  [95] = 65,
  [96] = 66,
  [97] = 67,
  [98] = 98,
  [99] = 69,
  [100] = 70,
  [101] = 71,
  [102] = 72,
  [103] = 73,
  [104] = 74,
  [105] = 75,
  [106] = 76,
  [107] = 77,
  [108] = 78,
  [109] = 79,
  [110] = 80,
  [111] = 81,
  [112] = 82,
  [113] = 83,
  [114] = 84,
  [115] = 85,
  [116] = 86,
  [117] = 87,
  [118] = 88,
  [119] = 89,
  [120] = 90,
  [121] = 61,
  [122] = 62,
  [123] = 60,
  [124] = 64,
  [125] = 65,
  [126] = 66,
  [127] = 67,
  [128] = 98,
  [129] = 69,
  [130] = 70,
  [131] = 71,
  [132] = 72,
  [133] = 73,
  [134] = 74,
  [135] = 75,
  [136] = 76,
  [137] = 77,
  [138] = 78,
  [139] = 79,
  [140] = 80,
  [141] = 81,
  [142] = 82,
  [143] = 83,
  [144] = 84,
  [145] = 85,
  [146] = 86,
  [147] = 90,
  [148] = 61,
  [149] = 65,
  [150] = 66,
  [151] = 67,
  [152] = 62,
  [153] = 87,
  [154] = 98,
  [155] = 69,
  [156] = 70,
  [157] = 71,
  [158] = 72,
  [159] = 73,
  [160] = 74,
  [161] = 75,
  [162] = 76,
  [163] = 88,
  [164] = 64,
  [165] = 77,
  [166] = 78,
  [167] = 79,
  [168] = 80,
  [169] = 81,
  [170] = 89,
  [171] = 82,
  [172] = 83,
  [173] = 84,
  [174] = 85,
  [175] = 86,
  [176] = 87,
  [177] = 88,
  [178] = 89,
  [179] = 90,
  [180] = 68,
  [181] = 68,
  [182] = 68,
  [183] = 98,
  [184] = 184,
  [185] = 185,
  [186] = 184,
  [187] = 185,
  [188] = 184,
  [189] = 184,
  [190] = 184,
  [191] = 191,
  [192] = 192,
  [193] = 193,
  [194] = 193,
  [195] = 193,
  [196] = 193,
  [197] = 193,
  [198] = 193,
  [199] = 193,
  [200] = 193,
  [201] = 193,
  [202] = 193,
  [203] = 193,
  [204] = 193,
  [205] = 193,
  [206] = 193,
  [207] = 193,
  [208] = 193,
  [209] = 193,
  [210] = 193,
  [211] = 193,
  [212] = 193,
  [213] = 193,
  [214] = 193,
  [215] = 193,
  [216] = 193,
  [217] = 193,
  [218] = 193,
  [219] = 193,
  [220] = 193,
  [221] = 193,
  [222] = 192,
  [223] = 191,
  [224] = 224,
  [225] = 224,
  [226] = 192,
  [227] = 191,
  [228] = 191,
  [229] = 192,
  [230] = 191,
  [231] = 192,
  [232] = 191,
  [233] = 192,
  [234] = 191,
  [235] = 192,
  [236] = 191,
  [237] = 192,
  [238] = 191,
  [239] = 192,
  [240] = 191,
  [241] = 192,
  [242] = 192,
  [243] = 191,
  [244] = 192,
  [245] = 191,
  [246] = 192,
  [247] = 191,
  [248] = 191,
  [249] = 191,
  [250] = 192,
  [251] = 192,
  [252] = 191,
  [253] = 192,
  [254] = 191,
  [255] = 192,
  [256] = 256,
  [257] = 191,
  [258] = 192,
  [259] = 191,
  [260] = 191,
  [261] = 192,
  [262] = 192,
  [263] = 191,
  [264] = 192,
  [265] = 191,
  [266] = 192,
  [267] = 256,
  [268] = 192,
  [269] = 191,
  [270] = 192,
  [271] = 192,
  [272] = 256,
  [273] = 256,
  [274] = 256,
  [275] = 191,
  [276] = 191,
  [277] = 191,
  [278] = 192,
  [279] = 192,
  [280] = 192,
  [281] = 191,
  [282] = 191,
  [283] = 192,
  [284] = 191,
  [285] = 192,
  [286] = 286,
  [287] = 191,
  [288] = 192,
  [289] = 192,
  [290] = 191,
  [291] = 192,
  [292] = 191,
  [293] = 191,
  [294] = 192,
  [295] = 191,
  [296] = 296,
  [297] = 191,
  [298] = 192,
  [299] = 192,
  [300] = 192,
  [301] = 296,
  [302] = 191,
  [303] = 296,
  [304] = 304,
  [305] = 304,
  [306] = 192,
  [307] = 191,
  [308] = 308,
  [309] = 309,
  [310] = 310,
  [311] = 296,
  [312] = 191,
  [313] = 192,
  [314] = 304,
  [315] = 296,
  [316] = 309,
  [317] = 304,
  [318] = 191,
  [319] = 310,
  [320] = 296,
  [321] = 191,
  [322] = 309,
  [323] = 192,
  [324] = 309,
  [325] = 192,
  [326] = 326,
  [327] = 191,
  [328] = 192,
  [329] = 329,
  [330] = 330,
  [331] = 326,
  [332] = 191,
  [333] = 192,
  [334] = 191,
  [335] = 335,
  [336] = 192,
  [337] = 329,
  [338] = 330,
  [339] = 326,
  [340] = 191,
  [341] = 192,
  [342] = 191,
  [343] = 326,
  [344] = 335,
  [345] = 192,
  [346] = 330,
  [347] = 326,
  [348] = 326,
  [349] = 192,
  [350] = 191,
  [351] = 192,
  [352] = 330,
  [353] = 191,
  [354] = 191,
  [355] = 330,
  [356] = 330,
  [357] = 357,
  [358] = 358,
  [359] = 358,
  [360] = 360,
  [361] = 357,
  [362] = 362,
  [363] = 363,
  [364] = 358,
  [365] = 362,
  [366] = 362,
  [367] = 362,
  [368] = 358,
  [369] = 362,
  [370] = 357,
  [371] = 358,
  [372] = 363,
  [373] = 357,
  [374] = 357,
  [375] = 375,
  [376] = 376,
  [377] = 377,
  [378] = 378,
  [379] = 376,
  [380] = 375,
  [381] = 375,
  [382] = 377,
  [383] = 377,
  [384] = 375,
  [385] = 375,
  [386] = 375,
  [387] = 378,
  [388] = 376,
  [389] = 377,
  [390] = 375,
  [391] = 375,
  [392] = 378,
  [393] = 378,
  [394] = 375,
  [395] = 376,
  [396] = 378,
  [397] = 376,
  [398] = 377,
  [399] = 375,
  [400] = 375,
  [401] = 378,
  [402] = 376,
  [403] = 378,
  [404] = 375,
  [405] = 376,
  [406] = 377,
  [407] = 377,
  [408] = 377,
  [409] = 378,
  [410] = 377,
  [411] = 375,
  [412] = 378,
  [413] = 378,
  [414] = 376,
  [415] = 377,
  [416] = 375,
  [417] = 375,
  [418] = 375,
  [419] = 375,
  [420] = 378,
  [421] = 376,
  [422] = 377,
  [423] = 375,
  [424] = 378,
  [425] = 375,
  [426] = 376,
  [427] = 375,
  [428] = 375,
  [429] = 375,
  [430] = 378,
  [431] = 376,
  [432] = 377,
  [433] = 376,
  [434] = 375,
  [435] = 378,
  [436] = 375,
  [437] = 376,
  [438] = 375,
  [439] = 376,
  [440] = 377,
  [441] = 377,
  [442] = 378,
  [443] = 375,
  [444] = 375,
  [445] = 376,
  [446] = 378,
  [447] = 375,
  [448] = 377,
  [449] = 375,
  [450] = 375,
  [451] = 378,
  [452] = 375,
  [453] = 375,
  [454] = 376,
  [455] = 375,
  [456] = 375,
  [457] = 377,
  [458] = 375,
  [459] = 378,
  [460] = 375,
  [461] = 378,
  [462] = 375,
  [463] = 376,
  [464] = 464,
  [465] = 378,
  [466] = 378,
  [467] = 378,
  [468] = 376,
  [469] = 377,
  [470] = 376,
  [471] = 377,
  [472] = 376,
  [473] = 375,
  [474] = 377,
  [475] = 378,
  [476] = 378,
  [477] = 378,
  [478] = 376,
  [479] = 377,
  [480] = 376,
  [481] = 376,
  [482] = 375,
  [483] = 377,
  [484] = 377,
  [485] = 377,
  [486] = 377,
  [487] = 377,
  [488] = 488,
  [489] = 489,
  [490] = 378,
  [491] = 377,
  [492] = 376,
  [493] = 375,
  [494] = 375,
  [495] = 376,
  [496] = 377,
  [497] = 376,
  [498] = 375,
  [499] = 375,
  [500] = 377,
  [501] = 375,
  [502] = 375,
  [503] = 378,
  [504] = 464,
  [505] = 378,
  [506] = 378,
  [507] = 376,
  [508] = 377,
  [509] = 376,
  [510] = 376,
  [511] = 375,
  [512] = 512,
  [513] = 512,
  [514] = 514,
  [515] = 514,
  [516] = 514,
  [517] = 514,
  [518] = 514,
  [519] = 514,
  [520] = 514,
  [521] = 521,
  [522] = 521,
  [523] = 523,
  [524] = 521,
  [525] = 521,
  [526] = 521,
  [527] = 521,
  [528] = 521,
  [529] = 521,
  [530] = 521,
  [531] = 521,
  [532] = 521,
  [533] = 521,
  [534] = 521,
  [535] = 521,
  [536] = 521,
  [537] = 521,
  [538] = 521,
  [539] = 521,
  [540] = 521,
  [541] = 521,
  [542] = 521,
  [543] = 521,
  [544] = 521,
  [545] = 521,
  [546] = 521,
  [547] = 521,
  [548] = 521,
  [549] = 521,
  [550] = 521,
  [551] = 521,
  [552] = 521,
  [553] = 521,
  [554] = 521,
  [555] = 521,
  [556] = 521,
  [557] = 521,
  [558] = 521,
  [559] = 521,
  [560] = 521,
  [561] = 521,
  [562] = 521,
  [563] = 521,
  [564] = 521,
  [565] = 521,
  [566] = 521,
  [567] = 521,
  [568] = 521,
  [569] = 521,
  [570] = 521,
  [571] = 521,
  [572] = 521,
  [573] = 521,
  [574] = 521,
  [575] = 521,
  [576] = 521,
  [577] = 521,
  [578] = 578,
  [579] = 578,
  [580] = 578,
  [581] = 578,
  [582] = 578,
  [583] = 578,
  [584] = 578,
  [585] = 585,
  [586] = 586,
  [587] = 587,
  [588] = 586,
  [589] = 589,
  [590] = 585,
  [591] = 589,
  [592] = 586,
  [593] = 586,
  [594] = 587,
  [595] = 585,
  [596] = 587,
  [597] = 585,
  [598] = 586,
  [599] = 587,
  [600] = 585,
  [601] = 589,
  [602] = 589,
  [603] = 586,
  [604] = 587,
  [605] = 587,
  [606] = 606,
  [607] = 585,
  [608] = 589,
  [609] = 609,
  [610] = 610,
  [611] = 611,
  [612] = 610,
  [613] = 613,
  [614] = 613,
  [615] = 615,
  [616] = 609,
  [617] = 615,
  [618] = 609,
  [619] = 615,
  [620] = 609,
  [621] = 615,
  [622] = 609,
  [623] = 609,
  [624] = 624,
  [625] = 625,
  [626] = 626,
  [627] = 624,
  [628] = 625,
  [629] = 625,
  [630] = 625,
  [631] = 631,
  [632] = 624,
  [633] = 625,
  [634] = 624,
  [635] = 624,
  [636] = 625,
  [637] = 624,
  [638] = 625,
  [639] = 625,
  [640] = 640,
  [641] = 641,
  [642] = 642,
  [643] = 643,
  [644] = 641,
  [645] = 640,
  [646] = 640,
  [647] = 640,
  [648] = 648,
  [649] = 640,
  [650] = 640,
  [651] = 640,
  [652] = 652,
  [653] = 640,
  [654] = 640,
  [655] = 640,
  [656] = 656,
  [657] = 640,
  [658] = 640,
  [659] = 640,
  [660] = 640,
  [661] = 661,
  [662] = 641,
  [663] = 663,
  [664] = 640,
  [665] = 640,
  [666] = 661,
  [667] = 641,
  [668] = 656,
  [669] = 656,
  [670] = 640,
  [671] = 671,
  [672] = 672,
  [673] = 640,
  [674] = 674,
  [675] = 661,
  [676] = 661,
  [677] = 663,
  [678] = 656,
  [679] = 643,
  [680] = 656,
  [681] = 641,
  [682] = 642,
  [683] = 640,
  [684] = 643,
  [685] = 663,
  [686] = 648,
  [687] = 648,
  [688] = 663,
  [689] = 640,
  [690] = 656,
  [691] = 641,
  [692] = 640,
  [693] = 640,
  [694] = 640,
  [695] = 648,
  [696] = 674,
  [697] = 640,
  [698] = 640,
  [699] = 640,
  [700] = 640,
  [701] = 640,
  [702] = 640,
  [703] = 640,
  [704] = 640,
  [705] = 640,
  [706] = 674,
  [707] = 640,
  [708] = 640,
  [709] = 642,
  [710] = 661,
  [711] = 674,
  [712] = 661,
  [713] = 640,
  [714] = 642,
  [715] = 640,
  [716] = 640,
  [717] = 640,
  [718] = 643,
  [719] = 640,
  [720] = 640,
  [721] = 640,
  [722] = 640,
  [723] = 640,
  [724] = 640,
  [725] = 640,
  [726] = 640,
  [727] = 727,
  [728] = 727,
  [729] = 640,
  [730] = 640,
  [731] = 731,
  [732] = 732,
  [733] = 733,
  [734] = 734,
  [735] = 735,
  [736] = 736,
  [737] = 737,
  [738] = 731,
  [739] = 739,
  [740] = 740,
  [741] = 732,
  [742] = 733,
  [743] = 734,
  [744] = 735,
  [745] = 736,
  [746] = 731,
  [747] = 735,
  [748] = 740,
  [749] = 732,
  [750] = 732,
  [751] = 733,
  [752] = 731,
  [753] = 753,
  [754] = 734,
  [755] = 735,
  [756] = 736,
  [757] = 731,
  [758] = 731,
  [759] = 736,
  [760] = 740,
  [761] = 732,
  [762] = 731,
  [763] = 733,
  [764] = 731,
  [765] = 731,
  [766] = 734,
  [767] = 735,
  [768] = 740,
  [769] = 732,
  [770] = 736,
  [771] = 737,
  [772] = 733,
  [773] = 739,
  [774] = 753,
  [775] = 734,
  [776] = 735,
  [777] = 736,
  [778] = 731,
  [779] = 740,
  [780] = 732,
  [781] = 733,
  [782] = 740,
  [783] = 732,
  [784] = 733,
  [785] = 734,
  [786] = 735,
  [787] = 736,
  [788] = 734,
  [789] = 731,
  [790] = 735,
  [791] = 740,
  [792] = 732,
  [793] = 733,
  [794] = 734,
  [795] = 735,
  [796] = 736,
  [797] = 736,
  [798] = 731,
  [799] = 740,
  [800] = 732,
  [801] = 733,
  [802] = 734,
  [803] = 735,
  [804] = 736,
  [805] = 731,
  [806] = 731,
  [807] = 731,
  [808] = 731,
  [809] = 732,
  [810] = 731,
  [811] = 740,
  [812] = 812,
  [813] = 731,
  [814] = 732,
  [815] = 733,
  [816] = 740,
  [817] = 732,
  [818] = 734,
  [819] = 735,
  [820] = 733,
  [821] = 736,
  [822] = 822,
  [823] = 734,
  [824] = 735,
  [825] = 736,
  [826] = 731,
  [827] = 731,
  [828] = 733,
  [829] = 740,
  [830] = 740,
  [831] = 732,
  [832] = 733,
  [833] = 734,
  [834] = 735,
  [835] = 736,
  [836] = 732,
  [837] = 733,
  [838] = 740,
  [839] = 732,
  [840] = 733,
  [841] = 734,
  [842] = 735,
  [843] = 736,
  [844] = 731,
  [845] = 731,
  [846] = 733,
  [847] = 740,
  [848] = 731,
  [849] = 732,
  [850] = 733,
  [851] = 734,
  [852] = 735,
  [853] = 740,
  [854] = 732,
  [855] = 736,
  [856] = 733,
  [857] = 734,
  [858] = 735,
  [859] = 736,
  [860] = 731,
  [861] = 734,
  [862] = 731,
  [863] = 735,
  [864] = 740,
  [865] = 732,
  [866] = 733,
  [867] = 734,
  [868] = 735,
  [869] = 736,
  [870] = 731,
  [871] = 740,
  [872] = 732,
  [873] = 740,
  [874] = 874,
  [875] = 736,
  [876] = 733,
  [877] = 877,
  [878] = 740,
  [879] = 732,
  [880] = 731,
  [881] = 733,
  [882] = 734,
  [883] = 735,
  [884] = 736,
  [885] = 731,
  [886] = 734,
  [887] = 735,
  [888] = 736,
  [889] = 740,
  [890] = 732,
  [891] = 733,
  [892] = 734,
  [893] = 735,
  [894] = 736,
  [895] = 731,
  [896] = 731,
  [897] = 731,
  [898] = 731,
  [899] = 733,
  [900] = 731,
  [901] = 737,
  [902] = 740,
  [903] = 903,
  [904] = 731,
  [905] = 731,
  [906] = 732,
  [907] = 731,
  [908] = 908,
  [909] = 812,
  [910] = 733,
  [911] = 822,
  [912] = 740,
  [913] = 740,
  [914] = 732,
  [915] = 732,
  [916] = 731,
  [917] = 917,
  [918] = 733,
  [919] = 734,
  [920] = 735,
  [921] = 736,
  [922] = 917,
  [923] = 923,
  [924] = 733,
  [925] = 925,
  [926] = 734,
  [927] = 740,
  [928] = 908,
  [929] = 732,
  [930] = 930,
  [931] = 917,
  [932] = 733,
  [933] = 812,
  [934] = 740,
  [935] = 732,
  [936] = 733,
  [937] = 734,
  [938] = 735,
  [939] = 736,
  [940] = 822,
  [941] = 740,
  [942] = 732,
  [943] = 740,
  [944] = 733,
  [945] = 734,
  [946] = 946,
  [947] = 734,
  [948] = 735,
  [949] = 736,
  [950] = 731,
  [951] = 731,
  [952] = 734,
  [953] = 740,
  [954] = 732,
  [955] = 733,
  [956] = 734,
  [957] = 735,
  [958] = 736,
  [959] = 732,
  [960] = 735,
  [961] = 740,
  [962] = 732,
  [963] = 732,
  [964] = 734,
  [965] = 735,
  [966] = 736,
  [967] = 731,
  [968] = 731,
  [969] = 736,
  [970] = 731,
  [971] = 731,
  [972] = 740,
  [973] = 732,
  [974] = 733,
  [975] = 734,
  [976] = 735,
  [977] = 736,
  [978] = 731,
  [979] = 734,
  [980] = 740,
  [981] = 732,
  [982] = 733,
  [983] = 734,
  [984] = 735,
  [985] = 736,
  [986] = 731,
  [987] = 735,
  [988] = 736,
  [989] = 733,
  [990] = 731,
  [991] = 731,
  [992] = 735,
  [993] = 822,
  [994] = 735,
  [995] = 736,
  [996] = 917,
  [997] = 731,
  [998] = 877,
  [999] = 731,
  [1000] = 736,
  [1001] = 903,
  [1002] = 1002,
  [1003] = 740,
  [1004] = 925,
  [1005] = 740,
  [1006] = 908,
  [1007] = 732,
  [1008] = 930,
  [1009] = 732,
  [1010] = 1010,
  [1011] = 1011,
  [1012] = 740,
  [1013] = 740,
  [1014] = 740,
  [1015] = 734,
  [1016] = 946,
  [1017] = 734,
  [1018] = 732,
  [1019] = 735,
  [1020] = 925,
  [1021] = 946,
  [1022] = 908,
  [1023] = 733,
  [1024] = 930,
  [1025] = 946,
  [1026] = 732,
  [1027] = 733,
  [1028] = 731,
  [1029] = 1029,
  [1030] = 1030,
  [1031] = 740,
  [1032] = 877,
  [1033] = 1029,
  [1034] = 732,
  [1035] = 733,
  [1036] = 946,
  [1037] = 734,
  [1038] = 735,
  [1039] = 735,
  [1040] = 731,
  [1041] = 731,
  [1042] = 736,
  [1043] = 925,
  [1044] = 740,
  [1045] = 731,
  [1046] = 733,
  [1047] = 733,
  [1048] = 736,
  [1049] = 740,
  [1050] = 732,
  [1051] = 733,
  [1052] = 734,
  [1053] = 735,
  [1054] = 736,
  [1055] = 877,
  [1056] = 731,
  [1057] = 734,
  [1058] = 740,
  [1059] = 732,
  [1060] = 733,
  [1061] = 734,
  [1062] = 735,
  [1063] = 736,
  [1064] = 903,
  [1065] = 734,
  [1066] = 740,
  [1067] = 732,
  [1068] = 736,
  [1069] = 732,
  [1070] = 733,
  [1071] = 735,
  [1072] = 733,
  [1073] = 734,
  [1074] = 735,
  [1075] = 736,
  [1076] = 731,
  [1077] = 731,
  [1078] = 877,
  [1079] = 739,
  [1080] = 734,
  [1081] = 735,
  [1082] = 735,
  [1083] = 731,
  [1084] = 753,
  [1085] = 740,
  [1086] = 732,
  [1087] = 734,
  [1088] = 733,
  [1089] = 734,
  [1090] = 735,
  [1091] = 736,
  [1092] = 734,
  [1093] = 737,
  [1094] = 731,
  [1095] = 731,
  [1096] = 903,
  [1097] = 1030,
  [1098] = 735,
  [1099] = 736,
  [1100] = 930,
  [1101] = 731,
  [1102] = 740,
  [1103] = 732,
  [1104] = 733,
  [1105] = 734,
  [1106] = 735,
  [1107] = 736,
  [1108] = 731,
  [1109] = 812,
  [1110] = 735,
  [1111] = 731,
  [1112] = 734,
  [1113] = 1029,
  [1114] = 1030,
  [1115] = 740,
  [1116] = 735,
  [1117] = 946,
  [1118] = 732,
  [1119] = 740,
  [1120] = 736,
  [1121] = 736,
  [1122] = 1122,
  [1123] = 733,
  [1124] = 740,
  [1125] = 1029,
  [1126] = 1030,
  [1127] = 732,
  [1128] = 877,
  [1129] = 740,
  [1130] = 733,
  [1131] = 822,
  [1132] = 736,
  [1133] = 734,
  [1134] = 734,
  [1135] = 735,
  [1136] = 735,
  [1137] = 736,
  [1138] = 739,
  [1139] = 736,
  [1140] = 753,
  [1141] = 731,
  [1142] = 736,
  [1143] = 736,
  [1144] = 732,
  [1145] = 1145,
  [1146] = 734,
  [1147] = 740,
  [1148] = 731,
  [1149] = 733,
  [1150] = 733,
  [1151] = 1151,
  [1152] = 1152,
  [1153] = 1153,
  [1154] = 1154,
  [1155] = 1155,
  [1156] = 1156,
  [1157] = 1157,
  [1158] = 1158,
  [1159] = 1159,
  [1160] = 1160,
  [1161] = 1161,
  [1162] = 1162,
  [1163] = 1163,
  [1164] = 1164,
  [1165] = 1165,
  [1166] = 1166,
  [1167] = 1167,
  [1168] = 1151,
  [1169] = 1169,
  [1170] = 1170,
  [1171] = 1171,
  [1172] = 1172,
  [1173] = 1173,
  [1174] = 1171,
  [1175] = 1175,
  [1176] = 1157,
  [1177] = 1158,
  [1178] = 1159,
  [1179] = 1160,
  [1180] = 1161,
  [1181] = 1162,
  [1182] = 1163,
  [1183] = 1164,
  [1184] = 1165,
  [1185] = 1166,
  [1186] = 1167,
  [1187] = 1151,
  [1188] = 1169,
  [1189] = 1170,
  [1190] = 1171,
  [1191] = 1172,
  [1192] = 1192,
  [1193] = 1193,
  [1194] = 1173,
  [1195] = 1195,
  [1196] = 1196,
  [1197] = 1172,
  [1198] = 1157,
  [1199] = 1158,
  [1200] = 1159,
  [1201] = 1160,
  [1202] = 1161,
  [1203] = 1162,
  [1204] = 1163,
  [1205] = 1164,
  [1206] = 1165,
  [1207] = 1166,
  [1208] = 1167,
  [1209] = 1151,
  [1210] = 1169,
  [1211] = 1170,
  [1212] = 1171,
  [1213] = 1172,
  [1214] = 1173,
  [1215] = 1157,
  [1216] = 1158,
  [1217] = 1159,
  [1218] = 1160,
  [1219] = 1161,
  [1220] = 1162,
  [1221] = 1163,
  [1222] = 1164,
  [1223] = 1165,
  [1224] = 1166,
  [1225] = 1167,
  [1226] = 1151,
  [1227] = 1169,
  [1228] = 1170,
  [1229] = 1171,
  [1230] = 1172,
  [1231] = 1173,
  [1232] = 1157,
  [1233] = 1158,
  [1234] = 1159,
  [1235] = 1160,
  [1236] = 1161,
  [1237] = 1162,
  [1238] = 1163,
  [1239] = 1164,
  [1240] = 1165,
  [1241] = 1166,
  [1242] = 1167,
  [1243] = 1151,
  [1244] = 1169,
  [1245] = 1170,
  [1246] = 1171,
  [1247] = 1173,
  [1248] = 1248,
  [1249] = 1249,
  [1250] = 1250,
  [1251] = 1251,
  [1252] = 1157,
  [1253] = 1158,
  [1254] = 1254,
  [1255] = 1255,
  [1256] = 1250,
  [1257] = 1257,
  [1258] = 1159,
  [1259] = 1160,
  [1260] = 1161,
  [1261] = 1162,
  [1262] = 1163,
  [1263] = 1164,
  [1264] = 1165,
  [1265] = 1166,
  [1266] = 1167,
  [1267] = 1151,
  [1268] = 1169,
  [1269] = 1170,
  [1270] = 1155,
  [1271] = 1171,
  [1272] = 1195,
  [1273] = 1196,
  [1274] = 1274,
  [1275] = 1157,
  [1276] = 1172,
  [1277] = 1277,
  [1278] = 1257,
  [1279] = 1279,
  [1280] = 1280,
  [1281] = 1173,
  [1282] = 1158,
  [1283] = 1283,
  [1284] = 1284,
  [1285] = 1279,
  [1286] = 1286,
  [1287] = 1287,
  [1288] = 1280,
  [1289] = 1289,
  [1290] = 1173,
  [1291] = 1250,
  [1292] = 1251,
  [1293] = 1159,
  [1294] = 1160,
  [1295] = 1161,
  [1296] = 1162,
  [1297] = 1163,
  [1298] = 1164,
  [1299] = 1165,
  [1300] = 1166,
  [1301] = 1167,
  [1302] = 1151,
  [1303] = 1169,
  [1304] = 1171,
  [1305] = 1157,
  [1306] = 1158,
  [1307] = 1251,
  [1308] = 1170,
  [1309] = 1172,
  [1310] = 1173,
  [1311] = 1157,
  [1312] = 1158,
  [1313] = 1159,
  [1314] = 1160,
  [1315] = 1161,
  [1316] = 1162,
  [1317] = 1163,
  [1318] = 1164,
  [1319] = 1165,
  [1320] = 1166,
  [1321] = 1167,
  [1322] = 1151,
  [1323] = 1169,
  [1324] = 1170,
  [1325] = 1171,
  [1326] = 1172,
  [1327] = 1327,
  [1328] = 1173,
  [1329] = 1329,
  [1330] = 1330,
  [1331] = 1283,
  [1332] = 1157,
  [1333] = 1158,
  [1334] = 1159,
  [1335] = 1160,
  [1336] = 1161,
  [1337] = 1162,
  [1338] = 1163,
  [1339] = 1164,
  [1340] = 1165,
  [1341] = 1166,
  [1342] = 1167,
  [1343] = 1151,
  [1344] = 1169,
  [1345] = 1170,
  [1346] = 1171,
  [1347] = 1172,
  [1348] = 1173,
  [1349] = 1349,
  [1350] = 1157,
  [1351] = 1158,
  [1352] = 1159,
  [1353] = 1160,
  [1354] = 1161,
  [1355] = 1162,
  [1356] = 1163,
  [1357] = 1164,
  [1358] = 1165,
  [1359] = 1166,
  [1360] = 1167,
  [1361] = 1151,
  [1362] = 1169,
  [1363] = 1170,
  [1364] = 1364,
  [1365] = 1171,
  [1366] = 1173,
  [1367] = 1367,
  [1368] = 1368,
  [1369] = 1157,
  [1370] = 1158,
  [1371] = 1159,
  [1372] = 1160,
  [1373] = 1161,
  [1374] = 1162,
  [1375] = 1163,
  [1376] = 1164,
  [1377] = 1165,
  [1378] = 1166,
  [1379] = 1167,
  [1380] = 1151,
  [1381] = 1169,
  [1382] = 1170,
  [1383] = 1171,
  [1384] = 1173,
  [1385] = 1284,
  [1386] = 1250,
  [1387] = 1251,
  [1388] = 1157,
  [1389] = 1158,
  [1390] = 1159,
  [1391] = 1391,
  [1392] = 1160,
  [1393] = 1161,
  [1394] = 1162,
  [1395] = 1163,
  [1396] = 1164,
  [1397] = 1165,
  [1398] = 1166,
  [1399] = 1167,
  [1400] = 1151,
  [1401] = 1169,
  [1402] = 1170,
  [1403] = 1155,
  [1404] = 1404,
  [1405] = 1171,
  [1406] = 1406,
  [1407] = 1172,
  [1408] = 1173,
  [1409] = 1409,
  [1410] = 1283,
  [1411] = 1286,
  [1412] = 1159,
  [1413] = 1160,
  [1414] = 1161,
  [1415] = 1162,
  [1416] = 1163,
  [1417] = 1164,
  [1418] = 1165,
  [1419] = 1166,
  [1420] = 1167,
  [1421] = 1169,
  [1422] = 1171,
  [1423] = 1157,
  [1424] = 1158,
  [1425] = 1170,
  [1426] = 1426,
  [1427] = 1172,
  [1428] = 1428,
  [1429] = 1173,
  [1430] = 1159,
  [1431] = 1160,
  [1432] = 1161,
  [1433] = 1162,
  [1434] = 1163,
  [1435] = 1164,
  [1436] = 1165,
  [1437] = 1166,
  [1438] = 1167,
  [1439] = 1151,
  [1440] = 1169,
  [1441] = 1171,
  [1442] = 1157,
  [1443] = 1158,
  [1444] = 1170,
  [1445] = 1173,
  [1446] = 1157,
  [1447] = 1158,
  [1448] = 1159,
  [1449] = 1160,
  [1450] = 1161,
  [1451] = 1162,
  [1452] = 1163,
  [1453] = 1164,
  [1454] = 1165,
  [1455] = 1166,
  [1456] = 1167,
  [1457] = 1151,
  [1458] = 1169,
  [1459] = 1170,
  [1460] = 1460,
  [1461] = 1171,
  [1462] = 1173,
  [1463] = 1250,
  [1464] = 1251,
  [1465] = 1289,
  [1466] = 1157,
  [1467] = 1158,
  [1468] = 1159,
  [1469] = 1160,
  [1470] = 1161,
  [1471] = 1162,
  [1472] = 1163,
  [1473] = 1164,
  [1474] = 1165,
  [1475] = 1166,
  [1476] = 1167,
  [1477] = 1151,
  [1478] = 1169,
  [1479] = 1479,
  [1480] = 1170,
  [1481] = 1155,
  [1482] = 1171,
  [1483] = 1483,
  [1484] = 1172,
  [1485] = 1485,
  [1486] = 1173,
  [1487] = 1487,
  [1488] = 1283,
  [1489] = 1489,
  [1490] = 1490,
  [1491] = 1491,
  [1492] = 1159,
  [1493] = 1160,
  [1494] = 1161,
  [1495] = 1162,
  [1496] = 1163,
  [1497] = 1164,
  [1498] = 1165,
  [1499] = 1166,
  [1500] = 1167,
  [1501] = 1151,
  [1502] = 1169,
  [1503] = 1171,
  [1504] = 1157,
  [1505] = 1158,
  [1506] = 1170,
  [1507] = 1172,
  [1508] = 1173,
  [1509] = 1159,
  [1510] = 1160,
  [1511] = 1161,
  [1512] = 1162,
  [1513] = 1163,
  [1514] = 1164,
  [1515] = 1165,
  [1516] = 1166,
  [1517] = 1167,
  [1518] = 1151,
  [1519] = 1169,
  [1520] = 1171,
  [1521] = 1157,
  [1522] = 1158,
  [1523] = 1170,
  [1524] = 1173,
  [1525] = 1157,
  [1526] = 1158,
  [1527] = 1160,
  [1528] = 1161,
  [1529] = 1162,
  [1530] = 1163,
  [1531] = 1164,
  [1532] = 1165,
  [1533] = 1166,
  [1534] = 1167,
  [1535] = 1151,
  [1536] = 1169,
  [1537] = 1170,
  [1538] = 1171,
  [1539] = 1173,
  [1540] = 1540,
  [1541] = 1250,
  [1542] = 1251,
  [1543] = 1157,
  [1544] = 1158,
  [1545] = 1159,
  [1546] = 1160,
  [1547] = 1161,
  [1548] = 1162,
  [1549] = 1163,
  [1550] = 1164,
  [1551] = 1165,
  [1552] = 1166,
  [1553] = 1167,
  [1554] = 1151,
  [1555] = 1169,
  [1556] = 1170,
  [1557] = 1155,
  [1558] = 1171,
  [1559] = 1172,
  [1560] = 1560,
  [1561] = 1173,
  [1562] = 1562,
  [1563] = 1283,
  [1564] = 1159,
  [1565] = 1160,
  [1566] = 1161,
  [1567] = 1162,
  [1568] = 1163,
  [1569] = 1164,
  [1570] = 1165,
  [1571] = 1166,
  [1572] = 1167,
  [1573] = 1151,
  [1574] = 1169,
  [1575] = 1171,
  [1576] = 1157,
  [1577] = 1158,
  [1578] = 1170,
  [1579] = 1172,
  [1580] = 1173,
  [1581] = 1159,
  [1582] = 1160,
  [1583] = 1161,
  [1584] = 1162,
  [1585] = 1163,
  [1586] = 1164,
  [1587] = 1165,
  [1588] = 1166,
  [1589] = 1167,
  [1590] = 1151,
  [1591] = 1169,
  [1592] = 1171,
  [1593] = 1157,
  [1594] = 1158,
  [1595] = 1170,
  [1596] = 1173,
  [1597] = 1157,
  [1598] = 1158,
  [1599] = 1159,
  [1600] = 1160,
  [1601] = 1161,
  [1602] = 1162,
  [1603] = 1163,
  [1604] = 1164,
  [1605] = 1165,
  [1606] = 1166,
  [1607] = 1167,
  [1608] = 1151,
  [1609] = 1169,
  [1610] = 1170,
  [1611] = 1171,
  [1612] = 1173,
  [1613] = 1250,
  [1614] = 1251,
  [1615] = 1615,
  [1616] = 1157,
  [1617] = 1158,
  [1618] = 1159,
  [1619] = 1160,
  [1620] = 1161,
  [1621] = 1162,
  [1622] = 1163,
  [1623] = 1164,
  [1624] = 1165,
  [1625] = 1166,
  [1626] = 1167,
  [1627] = 1151,
  [1628] = 1169,
  [1629] = 1170,
  [1630] = 1155,
  [1631] = 1171,
  [1632] = 1632,
  [1633] = 1172,
  [1634] = 1173,
  [1635] = 1283,
  [1636] = 1636,
  [1637] = 1159,
  [1638] = 1160,
  [1639] = 1161,
  [1640] = 1162,
  [1641] = 1163,
  [1642] = 1164,
  [1643] = 1165,
  [1644] = 1166,
  [1645] = 1167,
  [1646] = 1151,
  [1647] = 1169,
  [1648] = 1171,
  [1649] = 1649,
  [1650] = 1157,
  [1651] = 1158,
  [1652] = 1170,
  [1653] = 1152,
  [1654] = 1172,
  [1655] = 1173,
  [1656] = 1159,
  [1657] = 1160,
  [1658] = 1161,
  [1659] = 1162,
  [1660] = 1163,
  [1661] = 1164,
  [1662] = 1165,
  [1663] = 1166,
  [1664] = 1167,
  [1665] = 1151,
  [1666] = 1169,
  [1667] = 1171,
  [1668] = 1157,
  [1669] = 1158,
  [1670] = 1170,
  [1671] = 1173,
  [1672] = 1157,
  [1673] = 1158,
  [1674] = 1159,
  [1675] = 1160,
  [1676] = 1161,
  [1677] = 1162,
  [1678] = 1163,
  [1679] = 1164,
  [1680] = 1165,
  [1681] = 1166,
  [1682] = 1167,
  [1683] = 1151,
  [1684] = 1169,
  [1685] = 1170,
  [1686] = 1171,
  [1687] = 1173,
  [1688] = 1250,
  [1689] = 1251,
  [1690] = 1157,
  [1691] = 1158,
  [1692] = 1159,
  [1693] = 1160,
  [1694] = 1161,
  [1695] = 1162,
  [1696] = 1163,
  [1697] = 1164,
  [1698] = 1165,
  [1699] = 1166,
  [1700] = 1167,
  [1701] = 1151,
  [1702] = 1169,
  [1703] = 1170,
  [1704] = 1155,
  [1705] = 1171,
  [1706] = 1706,
  [1707] = 1172,
  [1708] = 1173,
  [1709] = 1283,
  [1710] = 1159,
  [1711] = 1160,
  [1712] = 1161,
  [1713] = 1162,
  [1714] = 1163,
  [1715] = 1164,
  [1716] = 1165,
  [1717] = 1166,
  [1718] = 1167,
  [1719] = 1151,
  [1720] = 1169,
  [1721] = 1171,
  [1722] = 1722,
  [1723] = 1157,
  [1724] = 1158,
  [1725] = 1170,
  [1726] = 1172,
  [1727] = 1173,
  [1728] = 1159,
  [1729] = 1160,
  [1730] = 1161,
  [1731] = 1162,
  [1732] = 1163,
  [1733] = 1164,
  [1734] = 1165,
  [1735] = 1166,
  [1736] = 1167,
  [1737] = 1151,
  [1738] = 1169,
  [1739] = 1171,
  [1740] = 1157,
  [1741] = 1158,
  [1742] = 1170,
  [1743] = 1173,
  [1744] = 1157,
  [1745] = 1158,
  [1746] = 1159,
  [1747] = 1160,
  [1748] = 1161,
  [1749] = 1162,
  [1750] = 1163,
  [1751] = 1164,
  [1752] = 1165,
  [1753] = 1166,
  [1754] = 1167,
  [1755] = 1151,
  [1756] = 1169,
  [1757] = 1170,
  [1758] = 1171,
  [1759] = 1173,
  [1760] = 1250,
  [1761] = 1251,
  [1762] = 1157,
  [1763] = 1158,
  [1764] = 1159,
  [1765] = 1160,
  [1766] = 1161,
  [1767] = 1162,
  [1768] = 1163,
  [1769] = 1164,
  [1770] = 1165,
  [1771] = 1166,
  [1772] = 1167,
  [1773] = 1151,
  [1774] = 1169,
  [1775] = 1170,
  [1776] = 1155,
  [1777] = 1171,
  [1778] = 1172,
  [1779] = 1173,
  [1780] = 1283,
  [1781] = 1781,
  [1782] = 1159,
  [1783] = 1160,
  [1784] = 1161,
  [1785] = 1162,
  [1786] = 1163,
  [1787] = 1164,
  [1788] = 1165,
  [1789] = 1166,
  [1790] = 1167,
  [1791] = 1151,
  [1792] = 1169,
  [1793] = 1171,
  [1794] = 1172,
  [1795] = 1157,
  [1796] = 1158,
  [1797] = 1170,
  [1798] = 1173,
  [1799] = 1157,
  [1800] = 1158,
  [1801] = 1159,
  [1802] = 1160,
  [1803] = 1161,
  [1804] = 1162,
  [1805] = 1163,
  [1806] = 1164,
  [1807] = 1165,
  [1808] = 1166,
  [1809] = 1167,
  [1810] = 1151,
  [1811] = 1169,
  [1812] = 1170,
  [1813] = 1171,
  [1814] = 1173,
  [1815] = 1250,
  [1816] = 1251,
  [1817] = 1157,
  [1818] = 1158,
  [1819] = 1159,
  [1820] = 1160,
  [1821] = 1161,
  [1822] = 1162,
  [1823] = 1163,
  [1824] = 1164,
  [1825] = 1165,
  [1826] = 1166,
  [1827] = 1167,
  [1828] = 1151,
  [1829] = 1169,
  [1830] = 1170,
  [1831] = 1155,
  [1832] = 1171,
  [1833] = 1172,
  [1834] = 1173,
  [1835] = 1283,
  [1836] = 1159,
  [1837] = 1160,
  [1838] = 1161,
  [1839] = 1162,
  [1840] = 1163,
  [1841] = 1164,
  [1842] = 1165,
  [1843] = 1166,
  [1844] = 1167,
  [1845] = 1151,
  [1846] = 1169,
  [1847] = 1171,
  [1848] = 1157,
  [1849] = 1158,
  [1850] = 1170,
  [1851] = 1250,
  [1852] = 1251,
  [1853] = 1173,
  [1854] = 1250,
  [1855] = 1251,
  [1856] = 1157,
  [1857] = 1158,
  [1858] = 1159,
  [1859] = 1160,
  [1860] = 1161,
  [1861] = 1162,
  [1862] = 1163,
  [1863] = 1164,
  [1864] = 1165,
  [1865] = 1166,
  [1866] = 1167,
  [1867] = 1151,
  [1868] = 1169,
  [1869] = 1170,
  [1870] = 1155,
  [1871] = 1171,
  [1872] = 1172,
  [1873] = 1173,
  [1874] = 1283,
  [1875] = 1159,
  [1876] = 1160,
  [1877] = 1161,
  [1878] = 1162,
  [1879] = 1163,
  [1880] = 1164,
  [1881] = 1165,
  [1882] = 1166,
  [1883] = 1167,
  [1884] = 1151,
  [1885] = 1169,
  [1886] = 1171,
  [1887] = 1157,
  [1888] = 1158,
  [1889] = 1170,
  [1890] = 1173,
  [1891] = 1159,
  [1892] = 1157,
  [1893] = 1250,
  [1894] = 1251,
  [1895] = 1158,
  [1896] = 1155,
  [1897] = 1283,
  [1898] = 1250,
  [1899] = 1251,
  [1900] = 1155,
  [1901] = 1283,
  [1902] = 1250,
  [1903] = 1251,
  [1904] = 1155,
  [1905] = 1283,
  [1906] = 1250,
  [1907] = 1251,
  [1908] = 1155,
  [1909] = 1283,
  [1910] = 1250,
  [1911] = 1251,
  [1912] = 1155,
  [1913] = 1283,
  [1914] = 1250,
  [1915] = 1251,
  [1916] = 1155,
  [1917] = 1283,
  [1918] = 1250,
  [1919] = 1251,
  [1920] = 1250,
  [1921] = 1251,
  [1922] = 1250,
  [1923] = 1251,
  [1924] = 1250,
  [1925] = 1251,
  [1926] = 1250,
  [1927] = 1251,
  [1928] = 1250,
  [1929] = 1251,
  [1930] = 1250,
  [1931] = 1251,
  [1932] = 1250,
  [1933] = 1251,
  [1934] = 1250,
  [1935] = 1251,
  [1936] = 1250,
  [1937] = 1251,
  [1938] = 1250,
  [1939] = 1251,
  [1940] = 1250,
  [1941] = 1251,
  [1942] = 1250,
  [1943] = 1251,
  [1944] = 1250,
  [1945] = 1251,
  [1946] = 1250,
  [1947] = 1251,
  [1948] = 1250,
  [1949] = 1251,
  [1950] = 1250,
  [1951] = 1251,
  [1952] = 1250,
  [1953] = 1251,
  [1954] = 1250,
  [1955] = 1251,
  [1956] = 1250,
  [1957] = 1250,
  [1958] = 1251,
  [1959] = 1479,
  [1960] = 1487,
  [1961] = 1489,
  [1962] = 1490,
  [1963] = 1562,
  [1964] = 1636,
  [1965] = 1649,
  [1966] = 1154,
  [1967] = 1172,
  [1968] = 1159,
  [1969] = 1274,
  [1970] = 1160,
  [1971] = 1404,
  [1972] = 1406,
  [1973] = 1161,
  [1974] = 1162,
  [1975] = 1483,
  [1976] = 1157,
  [1977] = 1158,
  [1978] = 1159,
  [1979] = 1160,
  [1980] = 1161,
  [1981] = 1162,
  [1982] = 1163,
  [1983] = 1164,
  [1984] = 1165,
  [1985] = 1166,
  [1986] = 1163,
  [1987] = 1167,
  [1988] = 1151,
  [1989] = 1169,
  [1990] = 1170,
  [1991] = 1164,
  [1992] = 1171,
  [1993] = 1165,
  [1994] = 1166,
  [1995] = 1173,
  [1996] = 1167,
  [1997] = 1151,
  [1998] = 1157,
  [1999] = 1158,
  [2000] = 1159,
  [2001] = 1160,
  [2002] = 1161,
  [2003] = 1162,
  [2004] = 1163,
  [2005] = 1164,
  [2006] = 1165,
  [2007] = 1166,
  [2008] = 1169,
  [2009] = 1167,
  [2010] = 1151,
  [2011] = 1169,
  [2012] = 1170,
  [2013] = 1160,
  [2014] = 1171,
  [2015] = 1170,
  [2016] = 1173,
  [2017] = 1155,
  [2018] = 1161,
  [2019] = 1159,
  [2020] = 1160,
  [2021] = 1161,
  [2022] = 1162,
  [2023] = 1163,
  [2024] = 1164,
  [2025] = 1165,
  [2026] = 1166,
  [2027] = 1167,
  [2028] = 1151,
  [2029] = 1169,
  [2030] = 1171,
  [2031] = 1157,
  [2032] = 1158,
  [2033] = 1162,
  [2034] = 1170,
  [2035] = 1173,
  [2036] = 1157,
  [2037] = 1158,
  [2038] = 1159,
  [2039] = 1160,
  [2040] = 1161,
  [2041] = 1162,
  [2042] = 1163,
  [2043] = 1164,
  [2044] = 1165,
  [2045] = 1166,
  [2046] = 1167,
  [2047] = 1151,
  [2048] = 1169,
  [2049] = 1170,
  [2050] = 1171,
  [2051] = 1173,
  [2052] = 1171,
  [2053] = 1157,
  [2054] = 1158,
  [2055] = 1170,
  [2056] = 1173,
  [2057] = 1159,
  [2058] = 1160,
  [2059] = 1161,
  [2060] = 1162,
  [2061] = 1163,
  [2062] = 1164,
  [2063] = 1165,
  [2064] = 1166,
  [2065] = 1167,
  [2066] = 1151,
  [2067] = 1169,
  [2068] = 1171,
  [2069] = 1157,
  [2070] = 1158,
  [2071] = 1170,
  [2072] = 1173,
  [2073] = 1159,
  [2074] = 1160,
  [2075] = 1161,
  [2076] = 1162,
  [2077] = 1163,
  [2078] = 1164,
  [2079] = 1165,
  [2080] = 1166,
  [2081] = 1167,
  [2082] = 1151,
  [2083] = 1169,
  [2084] = 1171,
  [2085] = 1157,
  [2086] = 1158,
  [2087] = 1170,
  [2088] = 1250,
  [2089] = 1155,
  [2090] = 1163,
  [2091] = 1283,
  [2092] = 1250,
  [2093] = 1250,
  [2094] = 1250,
  [2095] = 1250,
  [2096] = 1479,
  [2097] = 1487,
  [2098] = 1489,
  [2099] = 1490,
  [2100] = 1562,
  [2101] = 1636,
  [2102] = 1649,
  [2103] = 1274,
  [2104] = 1172,
  [2105] = 1404,
  [2106] = 1406,
  [2107] = 1483,
  [2108] = 1164,
  [2109] = 1250,
  [2110] = 1479,
  [2111] = 1487,
  [2112] = 1489,
  [2113] = 1490,
  [2114] = 1562,
  [2115] = 1636,
  [2116] = 1649,
  [2117] = 1274,
  [2118] = 1404,
  [2119] = 1406,
  [2120] = 1483,
  [2121] = 1165,
  [2122] = 1479,
  [2123] = 1636,
  [2124] = 1649,
  [2125] = 1166,
  [2126] = 1479,
  [2127] = 1636,
  [2128] = 1649,
  [2129] = 1167,
  [2130] = 1151,
  [2131] = 1169,
  [2132] = 1173,
  [2133] = 1159,
  [2134] = 1160,
  [2135] = 1161,
  [2136] = 1162,
  [2137] = 1163,
  [2138] = 1164,
  [2139] = 1165,
  [2140] = 1166,
  [2141] = 1167,
  [2142] = 1151,
  [2143] = 1169,
  [2144] = 1154,
  [2145] = 1171,
  [2146] = 1255,
  [2147] = 1173,
  [2148] = 1250,
  [2149] = 1155,
  [2150] = 1283,
  [2151] = 1283,
  [2152] = 1250,
  [2153] = 1155,
  [2154] = 1283,
  [2155] = 1157,
  [2156] = 1158,
  [2157] = 1170,
  [2158] = 1173,
  [2159] = 1159,
  [2160] = 1160,
  [2161] = 1161,
  [2162] = 1162,
  [2163] = 1163,
  [2164] = 1164,
  [2165] = 1165,
  [2166] = 1166,
  [2167] = 1167,
  [2168] = 1151,
  [2169] = 1169,
  [2170] = 1171,
  [2171] = 1250,
  [2172] = 1154,
  [2173] = 1154,
  [2174] = 1255,
  [2175] = 1154,
  [2176] = 1255,
  [2177] = 1154,
  [2178] = 1170,
  [2179] = 1154,
  [2180] = 1154,
  [2181] = 1154,
  [2182] = 1154,
  [2183] = 1154,
  [2184] = 1154,
  [2185] = 1154,
  [2186] = 1154,
  [2187] = 1154,
  [2188] = 1154,
  [2189] = 1154,
  [2190] = 1154,
  [2191] = 1154,
  [2192] = 1560,
  [2193] = 1152,
  [2194] = 1192,
  [2195] = 1560,
  [2196] = 1152,
  [2197] = 1192,
  [2198] = 1560,
  [2199] = 1152,
  [2200] = 1192,
  [2201] = 1152,
  [2202] = 1159,
  [2203] = 2203,
  [2204] = 2204,
  [2205] = 2203,
  [2206] = 2204,
  [2207] = 2204,
  [2208] = 2203,
  [2209] = 2209,
  [2210] = 2210,
  [2211] = 2211,
  [2212] = 2209,
  [2213] = 2210,
  [2214] = 2214,
  [2215] = 2215,
  [2216] = 2216,
  [2217] = 2211,
  [2218] = 2218,
  [2219] = 2219,
  [2220] = 2220,
  [2221] = 2221,
  [2222] = 2222,
  [2223] = 2223,
  [2224] = 2224,
  [2225] = 2225,
  [2226] = 2226,
  [2227] = 2227,
  [2228] = 2228,
  [2229] = 2229,
  [2230] = 2230,
  [2231] = 2231,
  [2232] = 2232,
  [2233] = 2233,
  [2234] = 2234,
  [2235] = 2235,
  [2236] = 2236,
  [2237] = 2237,
  [2238] = 2238,
  [2239] = 2239,
  [2240] = 2240,
  [2241] = 2241,
  [2242] = 2242,
  [2243] = 2243,
  [2244] = 2244,
  [2245] = 2245,
  [2246] = 2246,
  [2247] = 2247,
  [2248] = 2248,
  [2249] = 2249,
  [2250] = 2250,
  [2251] = 2251,
  [2252] = 2252,
  [2253] = 2253,
  [2254] = 2254,
  [2255] = 2255,
  [2256] = 2256,
  [2257] = 2257,
  [2258] = 2258,
  [2259] = 2259,
  [2260] = 2260,
  [2261] = 2215,
  [2262] = 2262,
  [2263] = 2263,
  [2264] = 2264,
  [2265] = 2219,
  [2266] = 2266,
  [2267] = 2267,
  [2268] = 2218,
  [2269] = 2269,
  [2270] = 2270,
  [2271] = 2271,
  [2272] = 2272,
  [2273] = 2273,
  [2274] = 2214,
  [2275] = 2275,
  [2276] = 2276,
  [2277] = 2277,
  [2278] = 2278,
  [2279] = 2279,
  [2280] = 2280,
  [2281] = 2281,
  [2282] = 2282,
  [2283] = 2283,
  [2284] = 2220,
  [2285] = 2285,
  [2286] = 2286,
  [2287] = 2287,
  [2288] = 2288,
  [2289] = 2289,
  [2290] = 2290,
  [2291] = 2291,
  [2292] = 2292,
  [2293] = 2293,
  [2294] = 2294,
  [2295] = 2295,
  [2296] = 2296,
  [2297] = 2297,
  [2298] = 2298,
  [2299] = 2216,
  [2300] = 2300,
  [2301] = 2301,
  [2302] = 2302,
  [2303] = 2303,
  [2304] = 2304,
  [2305] = 2305,
  [2306] = 2306,
  [2307] = 2307,
  [2308] = 2308,
  [2309] = 2309,
  [2310] = 2310,
  [2311] = 2311,
  [2312] = 2312,
  [2313] = 2313,
  [2314] = 2314,
  [2315] = 2315,
  [2316] = 2316,
  [2317] = 2317,
  [2318] = 2318,
  [2319] = 2319,
  [2320] = 2320,
  [2321] = 2321,
  [2322] = 2322,
  [2323] = 2323,
  [2324] = 2324,
  [2325] = 2325,
  [2326] = 2326,
  [2327] = 2327,
  [2328] = 2328,
  [2329] = 2329,
  [2330] = 2330,
  [2331] = 2331,
  [2332] = 2332,
  [2333] = 2333,
  [2334] = 2334,
  [2335] = 2335,
  [2336] = 2336,
  [2337] = 2337,
  [2338] = 2338,
  [2339] = 2339,
  [2340] = 2340,
  [2341] = 2341,
  [2342] = 2342,
  [2343] = 2343,
  [2344] = 2344,
  [2345] = 2345,
  [2346] = 2346,
  [2347] = 2347,
  [2348] = 2348,
  [2349] = 2349,
  [2350] = 2350,
  [2351] = 2351,
  [2352] = 2352,
  [2353] = 2353,
  [2354] = 2354,
  [2355] = 2355,
  [2356] = 2356,
  [2357] = 2357,
  [2358] = 2358,
  [2359] = 2359,
  [2360] = 2360,
  [2361] = 2361,
  [2362] = 2362,
  [2363] = 2363,
  [2364] = 2364,
  [2365] = 2365,
  [2366] = 2366,
  [2367] = 2367,
  [2368] = 2368,
  [2369] = 2369,
  [2370] = 2370,
  [2371] = 2371,
  [2372] = 2372,
  [2373] = 2373,
  [2374] = 2374,
  [2375] = 2375,
  [2376] = 2376,
  [2377] = 2377,
  [2378] = 2378,
  [2379] = 2379,
  [2380] = 2380,
  [2381] = 2381,
  [2382] = 2382,
  [2383] = 2383,
  [2384] = 2384,
  [2385] = 2385,
  [2386] = 2386,
  [2387] = 2387,
  [2388] = 2388,
  [2389] = 2389,
  [2390] = 2390,
  [2391] = 2391,
  [2392] = 2392,
  [2393] = 2393,
  [2394] = 2394,
  [2395] = 2395,
  [2396] = 2396,
  [2397] = 2397,
  [2398] = 2398,
  [2399] = 2399,
  [2400] = 2400,
  [2401] = 2401,
  [2402] = 2402,
  [2403] = 2403,
  [2404] = 2404,
  [2405] = 2405,
  [2406] = 2406,
  [2407] = 2407,
  [2408] = 2408,
  [2409] = 2409,
  [2410] = 2410,
  [2411] = 2411,
  [2412] = 2412,
  [2413] = 2413,
  [2414] = 2414,
  [2415] = 2415,
  [2416] = 2416,
  [2417] = 2417,
  [2418] = 2418,
  [2419] = 2419,
  [2420] = 2420,
  [2421] = 2421,
  [2422] = 2422,
  [2423] = 2423,
  [2424] = 2424,
  [2425] = 2425,
  [2426] = 2426,
  [2427] = 2427,
  [2428] = 2428,
  [2429] = 2429,
  [2430] = 2430,
  [2431] = 2431,
  [2432] = 2432,
  [2433] = 2433,
  [2434] = 2434,
  [2435] = 2273,
  [2436] = 2226,
  [2437] = 2300,
  [2438] = 2252,
  [2439] = 2301,
  [2440] = 2230,
  [2441] = 2225,
  [2442] = 2275,
  [2443] = 2286,
  [2444] = 2302,
  [2445] = 2253,
  [2446] = 2254,
  [2447] = 2255,
  [2448] = 2297,
  [2449] = 2285,
  [2450] = 2450,
  [2451] = 2231,
  [2452] = 2258,
  [2453] = 2210,
  [2454] = 2272,
  [2455] = 2306,
  [2456] = 2259,
  [2457] = 2260,
  [2458] = 2264,
  [2459] = 2266,
  [2460] = 2277,
  [2461] = 2233,
  [2462] = 2223,
  [2463] = 2279,
  [2464] = 2269,
  [2465] = 2234,
  [2466] = 2235,
  [2467] = 2295,
  [2468] = 2267,
  [2469] = 2278,
  [2470] = 2209,
  [2471] = 2236,
  [2472] = 2281,
  [2473] = 2282,
  [2474] = 2287,
  [2475] = 2250,
  [2476] = 2291,
  [2477] = 2221,
  [2478] = 2303,
  [2479] = 2227,
  [2480] = 2288,
  [2481] = 2289,
  [2482] = 2228,
  [2483] = 2290,
  [2484] = 2251,
  [2485] = 2237,
  [2486] = 2238,
  [2487] = 2296,
  [2488] = 2298,
  [2489] = 2239,
  [2490] = 2240,
  [2491] = 2248,
  [2492] = 2229,
  [2493] = 2270,
  [2494] = 2249,
  [2495] = 2304,
  [2496] = 2292,
  [2497] = 2241,
  [2498] = 2222,
  [2499] = 2283,
  [2500] = 2242,
  [2501] = 2243,
  [2502] = 2293,
  [2503] = 2271,
  [2504] = 2280,
  [2505] = 2305,
  [2506] = 2232,
  [2507] = 2244,
  [2508] = 2224,
  [2509] = 2245,
  [2510] = 2246,
  [2511] = 2276,
  [2512] = 2247,
  [2513] = 2256,
  [2514] = 2345,
  [2515] = 2384,
  [2516] = 2385,
  [2517] = 2386,
  [2518] = 2387,
  [2519] = 2388,
  [2520] = 2389,
  [2521] = 2390,
  [2522] = 2391,
  [2523] = 2392,
  [2524] = 2393,
  [2525] = 2394,
  [2526] = 2395,
  [2527] = 2396,
  [2528] = 2397,
  [2529] = 2332,
  [2530] = 2429,
  [2531] = 2430,
  [2532] = 2431,
  [2533] = 2432,
  [2534] = 2433,
  [2535] = 2398,
  [2536] = 2399,
  [2537] = 2400,
  [2538] = 2333,
  [2539] = 2351,
  [2540] = 2424,
  [2541] = 2401,
  [2542] = 2402,
  [2543] = 2403,
  [2544] = 2404,
  [2545] = 2405,
  [2546] = 2406,
  [2547] = 2407,
  [2548] = 2408,
  [2549] = 2409,
  [2550] = 2410,
  [2551] = 2411,
  [2552] = 2412,
  [2553] = 2413,
  [2554] = 2414,
  [2555] = 2415,
  [2556] = 2416,
  [2557] = 2418,
  [2558] = 2419,
  [2559] = 2420,
  [2560] = 2421,
  [2561] = 2340,
  [2562] = 2341,
  [2563] = 2342,
  [2564] = 2371,
  [2565] = 2307,
  [2566] = 2328,
  [2567] = 2352,
  [2568] = 2353,
  [2569] = 2354,
  [2570] = 2355,
  [2571] = 2356,
  [2572] = 2357,
  [2573] = 2334,
  [2574] = 2358,
  [2575] = 2359,
  [2576] = 2360,
  [2577] = 2335,
  [2578] = 2336,
  [2579] = 2337,
  [2580] = 2417,
  [2581] = 2581,
  [2582] = 2343,
  [2583] = 2344,
  [2584] = 2361,
  [2585] = 2585,
  [2586] = 2363,
  [2587] = 2364,
  [2588] = 2365,
  [2589] = 2366,
  [2590] = 2309,
  [2591] = 2367,
  [2592] = 2338,
  [2593] = 2426,
  [2594] = 2368,
  [2595] = 2339,
  [2596] = 2369,
  [2597] = 2370,
  [2598] = 2434,
  [2599] = 2372,
  [2600] = 2373,
  [2601] = 2374,
  [2602] = 2375,
  [2603] = 2310,
  [2604] = 2427,
  [2605] = 2346,
  [2606] = 2347,
  [2607] = 2376,
  [2608] = 2425,
  [2609] = 2428,
  [2610] = 2311,
  [2611] = 2312,
  [2612] = 2313,
  [2613] = 2314,
  [2614] = 2315,
  [2615] = 2316,
  [2616] = 2317,
  [2617] = 2318,
  [2618] = 2319,
  [2619] = 2320,
  [2620] = 2321,
  [2621] = 2621,
  [2622] = 2308,
  [2623] = 2377,
  [2624] = 2378,
  [2625] = 2379,
  [2626] = 2211,
  [2627] = 2380,
  [2628] = 2381,
  [2629] = 2382,
  [2630] = 2383,
  [2631] = 2348,
  [2632] = 2330,
  [2633] = 2349,
  [2634] = 2350,
  [2635] = 2331,
  [2636] = 2636,
  [2637] = 2322,
  [2638] = 2323,
  [2639] = 2324,
  [2640] = 2325,
  [2641] = 2326,
  [2642] = 2423,
  [2643] = 2362,
  [2644] = 2644,
  [2645] = 2645,
  [2646] = 2646,
  [2647] = 2647,
  [2648] = 2220,
  [2649] = 2218,
  [2650] = 2219,
  [2651] = 2215,
  [2652] = 2214,
  [2653] = 2216,
  [2654] = 2654,
  [2655] = 2223,
  [2656] = 2251,
  [2657] = 2254,
  [2658] = 2269,
  [2659] = 2270,
  [2660] = 2234,
  [2661] = 2235,
  [2662] = 2271,
  [2663] = 2256,
  [2664] = 2272,
  [2665] = 2273,
  [2666] = 2236,
  [2667] = 2275,
  [2668] = 2224,
  [2669] = 2276,
  [2670] = 2277,
  [2671] = 2279,
  [2672] = 2280,
  [2673] = 2253,
  [2674] = 2222,
  [2675] = 2225,
  [2676] = 2226,
  [2677] = 2227,
  [2678] = 2283,
  [2679] = 2228,
  [2680] = 2229,
  [2681] = 2230,
  [2682] = 2231,
  [2683] = 2306,
  [2684] = 2285,
  [2685] = 2233,
  [2686] = 2286,
  [2687] = 2252,
  [2688] = 2288,
  [2689] = 2289,
  [2690] = 2290,
  [2691] = 2292,
  [2692] = 2237,
  [2693] = 2238,
  [2694] = 2239,
  [2695] = 2240,
  [2696] = 2295,
  [2697] = 2296,
  [2698] = 2241,
  [2699] = 2242,
  [2700] = 2243,
  [2701] = 2297,
  [2702] = 2298,
  [2703] = 2300,
  [2704] = 2301,
  [2705] = 2302,
  [2706] = 2304,
  [2707] = 2305,
  [2708] = 2232,
  [2709] = 2244,
  [2710] = 2245,
  [2711] = 2246,
  [2712] = 2247,
  [2713] = 2248,
  [2714] = 2249,
  [2715] = 2267,
  [2716] = 2255,
  [2717] = 2250,
  [2718] = 2258,
  [2719] = 2259,
  [2720] = 2260,
  [2721] = 2264,
  [2722] = 2266,
  [2723] = 2278,
  [2724] = 2281,
  [2725] = 2282,
  [2726] = 2287,
  [2727] = 2291,
  [2728] = 2221,
  [2729] = 2303,
  [2730] = 2293,
  [2731] = 2654,
  [2732] = 2732,
  [2733] = 2450,
  [2734] = 2734,
  [2735] = 2735,
  [2736] = 2734,
  [2737] = 2734,
  [2738] = 2738,
  [2739] = 2734,
  [2740] = 2734,
  [2741] = 2734,
  [2742] = 2738,
  [2743] = 2743,
  [2744] = 2744,
  [2745] = 2745,
  [2746] = 2746,
  [2747] = 2747,
  [2748] = 2748,
  [2749] = 2749,
  [2750] = 2750,
  [2751] = 2734,
  [2752] = 2734,
  [2753] = 2753,
  [2754] = 2754,
  [2755] = 2748,
  [2756] = 2756,
  [2757] = 2757,
  [2758] = 2757,
  [2759] = 2757,
  [2760] = 2760,
  [2761] = 2756,
  [2762] = 2757,
  [2763] = 2738,
  [2764] = 2754,
  [2765] = 2760,
  [2766] = 2757,
  [2767] = 2757,
  [2768] = 2738,
  [2769] = 2738,
  [2770] = 2734,
  [2771] = 2734,
  [2772] = 2760,
  [2773] = 2738,
  [2774] = 2734,
  [2775] = 2754,
  [2776] = 2748,
  [2777] = 2738,
  [2778] = 2738,
  [2779] = 2779,
  [2780] = 2780,
  [2781] = 2781,
  [2782] = 2757,
  [2783] = 2738,
  [2784] = 2738,
  [2785] = 2785,
  [2786] = 2738,
  [2787] = 2754,
  [2788] = 2738,
  [2789] = 2760,
  [2790] = 2790,
  [2791] = 2791,
  [2792] = 2748,
  [2793] = 2734,
  [2794] = 2738,
  [2795] = 2795,
  [2796] = 2734,
  [2797] = 2757,
  [2798] = 2756,
  [2799] = 2754,
  [2800] = 2795,
  [2801] = 2760,
  [2802] = 2756,
  [2803] = 2743,
  [2804] = 2744,
  [2805] = 2805,
  [2806] = 2760,
  [2807] = 2748,
  [2808] = 2753,
  [2809] = 2795,
  [2810] = 2748,
  [2811] = 2811,
  [2812] = 2744,
  [2813] = 2795,
  [2814] = 2805,
  [2815] = 2815,
  [2816] = 2743,
  [2817] = 2815,
  [2818] = 2745,
  [2819] = 2757,
  [2820] = 2743,
  [2821] = 2746,
  [2822] = 2749,
  [2823] = 2748,
  [2824] = 2754,
  [2825] = 2744,
  [2826] = 2757,
  [2827] = 2827,
  [2828] = 2811,
  [2829] = 2760,
  [2830] = 2756,
  [2831] = 2756,
  [2832] = 2760,
  [2833] = 2750,
  [2834] = 2757,
  [2835] = 2748,
  [2836] = 2757,
  [2837] = 2757,
  [2838] = 2760,
  [2839] = 2747,
  [2840] = 2840,
  [2841] = 2841,
  [2842] = 2842,
  [2843] = 2843,
  [2844] = 2756,
  [2845] = 2754,
  [2846] = 2756,
  [2847] = 2841,
  [2848] = 2848,
  [2849] = 2754,
  [2850] = 2757,
  [2851] = 2757,
  [2852] = 2756,
  [2853] = 2757,
  [2854] = 2842,
  [2855] = 2855,
  [2856] = 2734,
  [2857] = 2857,
  [2858] = 2840,
  [2859] = 2756,
  [2860] = 2760,
  [2861] = 2760,
  [2862] = 2756,
  [2863] = 2757,
  [2864] = 2757,
  [2865] = 2760,
  [2866] = 2757,
  [2867] = 2867,
  [2868] = 2757,
  [2869] = 2869,
  [2870] = 2734,
  [2871] = 2871,
  [2872] = 2757,
  [2873] = 2760,
  [2874] = 2874,
  [2875] = 2811,
  [2876] = 2756,
  [2877] = 2811,
  [2878] = 2757,
  [2879] = 2879,
  [2880] = 2754,
  [2881] = 2874,
  [2882] = 2756,
  [2883] = 2883,
  [2884] = 2734,
  [2885] = 2885,
  [2886] = 2879,
  [2887] = 2887,
  [2888] = 2869,
  [2889] = 2757,
  [2890] = 2757,
  [2891] = 2757,
  [2892] = 2757,
  [2893] = 2756,
  [2894] = 2757,
  [2895] = 2757,
  [2896] = 2734,
  [2897] = 2827,
  [2898] = 2898,
  [2899] = 2757,
  [2900] = 2757,
  [2901] = 2756,
  [2902] = 2902,
  [2903] = 2903,
  [2904] = 2841,
  [2905] = 2760,
  [2906] = 2906,
  [2907] = 2841,
  [2908] = 2756,
  [2909] = 2909,
  [2910] = 2757,
  [2911] = 2756,
  [2912] = 2760,
  [2913] = 2913,
  [2914] = 2871,
  [2915] = 2756,
  [2916] = 2757,
  [2917] = 2756,
  [2918] = 2756,
  [2919] = 2919,
  [2920] = 2920,
  [2921] = 2921,
  [2922] = 2734,
  [2923] = 2921,
  [2924] = 2734,
  [2925] = 2734,
  [2926] = 2743,
  [2927] = 2754,
  [2928] = 2744,
  [2929] = 2929,
  [2930] = 2760,
  [2931] = 2929,
  [2932] = 2760,
  [2933] = 2757,
  [2934] = 2757,
  [2935] = 2929,
  [2936] = 2929,
  [2937] = 2929,
  [2938] = 2753,
  [2939] = 2757,
  [2940] = 2760,
  [2941] = 2747,
  [2942] = 2760,
  [2943] = 2734,
  [2944] = 2749,
  [2945] = 2746,
  [2946] = 2734,
  [2947] = 2947,
  [2948] = 2948,
  [2949] = 2757,
  [2950] = 2760,
  [2951] = 2757,
  [2952] = 2952,
  [2953] = 2753,
  [2954] = 2757,
  [2955] = 2757,
  [2956] = 2956,
  [2957] = 2750,
  [2958] = 2958,
  [2959] = 2795,
  [2960] = 2760,
  [2961] = 2961,
  [2962] = 2962,
  [2963] = 2963,
  [2964] = 2795,
  [2965] = 2958,
  [2966] = 2966,
  [2967] = 2757,
  [2968] = 2968,
  [2969] = 2969,
  [2970] = 2970,
  [2971] = 2971,
  [2972] = 2972,
  [2973] = 2973,
  [2974] = 2795,
  [2975] = 2760,
  [2976] = 2805,
  [2977] = 2760,
  [2978] = 2978,
  [2979] = 2734,
  [2980] = 2795,
  [2981] = 2745,
  [2982] = 2757,
  [2983] = 2757,
  [2984] = 2760,
  [2985] = 2805,
  [2986] = 2760,
  [2987] = 2987,
  [2988] = 2963,
  [2989] = 2734,
  [2990] = 2990,
  [2991] = 2734,
  [2992] = 2992,
  [2993] = 2734,
  [2994] = 2994,
  [2995] = 2995,
  [2996] = 2996,
  [2997] = 2734,
  [2998] = 2734,
  [2999] = 2999,
  [3000] = 2999,
  [3001] = 3001,
  [3002] = 3002,
  [3003] = 2750,
  [3004] = 3004,
  [3005] = 2746,
  [3006] = 2734,
  [3007] = 3007,
  [3008] = 3008,
  [3009] = 2743,
  [3010] = 2745,
  [3011] = 2734,
  [3012] = 3012,
  [3013] = 2734,
  [3014] = 3014,
  [3015] = 3015,
  [3016] = 3016,
  [3017] = 2747,
  [3018] = 3018,
  [3019] = 2744,
  [3020] = 3020,
  [3021] = 2749,
  [3022] = 3022,
  [3023] = 3023,
  [3024] = 3024,
  [3025] = 2999,
  [3026] = 3018,
  [3027] = 3008,
  [3028] = 2795,
  [3029] = 2805,
  [3030] = 3002,
  [3031] = 2805,
  [3032] = 2795,
  [3033] = 2990,
  [3034] = 2795,
  [3035] = 2795,
  [3036] = 2795,
  [3037] = 2795,
  [3038] = 2795,
  [3039] = 2795,
  [3040] = 2805,
  [3041] = 2805,
  [3042] = 2805,
  [3043] = 2805,
  [3044] = 2805,
  [3045] = 2795,
  [3046] = 3022,
  [3047] = 2805,
  [3048] = 2795,
  [3049] = 3020,
  [3050] = 3001,
  [3051] = 2795,
  [3052] = 2795,
  [3053] = 2805,
  [3054] = 3007,
  [3055] = 2795,
  [3056] = 3016,
  [3057] = 2795,
  [3058] = 2795,
  [3059] = 2805,
  [3060] = 2795,
  [3061] = 2795,
  [3062] = 2795,
  [3063] = 2795,
  [3064] = 2805,
  [3065] = 2805,
  [3066] = 2734,
  [3067] = 2795,
  [3068] = 2795,
  [3069] = 2795,
  [3070] = 2795,
  [3071] = 2734,
  [3072] = 2795,
  [3073] = 2805,
  [3074] = 2795,
  [3075] = 2734,
  [3076] = 2840,
  [3077] = 2805,
  [3078] = 2795,
  [3079] = 2795,
  [3080] = 2734,
  [3081] = 2842,
  [3082] = 2805,
  [3083] = 2795,
  [3084] = 2840,
  [3085] = 2842,
  [3086] = 2734,
  [3087] = 2795,
  [3088] = 2805,
  [3089] = 2795,
  [3090] = 2805,
  [3091] = 2734,
  [3092] = 3092,
  [3093] = 3092,
  [3094] = 3094,
  [3095] = 3095,
  [3096] = 2855,
  [3097] = 3094,
  [3098] = 3098,
  [3099] = 3099,
  [3100] = 3092,
  [3101] = 3095,
  [3102] = 3099,
  [3103] = 2840,
  [3104] = 2919,
  [3105] = 3092,
  [3106] = 2842,
  [3107] = 3098,
  [3108] = 3094,
  [3109] = 3098,
  [3110] = 3110,
  [3111] = 2842,
  [3112] = 2919,
  [3113] = 3095,
  [3114] = 3099,
  [3115] = 3094,
  [3116] = 3098,
  [3117] = 3095,
  [3118] = 3099,
  [3119] = 3110,
  [3120] = 2840,
  [3121] = 2871,
  [3122] = 2879,
  [3123] = 2920,
  [3124] = 2840,
  [3125] = 3125,
  [3126] = 3125,
  [3127] = 2840,
  [3128] = 2840,
  [3129] = 2874,
  [3130] = 2842,
  [3131] = 2842,
  [3132] = 2874,
  [3133] = 3125,
  [3134] = 3125,
  [3135] = 2879,
  [3136] = 2869,
  [3137] = 2871,
  [3138] = 2842,
  [3139] = 2869,
  [3140] = 2879,
  [3141] = 2840,
  [3142] = 3024,
  [3143] = 2840,
  [3144] = 2842,
  [3145] = 2743,
  [3146] = 2869,
  [3147] = 2842,
  [3148] = 2840,
  [3149] = 2871,
  [3150] = 2753,
  [3151] = 2840,
  [3152] = 2304,
  [3153] = 2842,
  [3154] = 2842,
  [3155] = 2871,
  [3156] = 2840,
  [3157] = 2840,
  [3158] = 2920,
  [3159] = 2874,
  [3160] = 2305,
  [3161] = 2842,
  [3162] = 2842,
  [3163] = 2840,
  [3164] = 2994,
  [3165] = 2744,
  [3166] = 2221,
  [3167] = 2842,
  [3168] = 2869,
  [3169] = 2874,
  [3170] = 2840,
  [3171] = 2842,
  [3172] = 2879,
  [3173] = 2879,
  [3174] = 3174,
  [3175] = 3007,
  [3176] = 3176,
  [3177] = 2746,
  [3178] = 2744,
  [3179] = 2754,
  [3180] = 3016,
  [3181] = 3023,
  [3182] = 3182,
  [3183] = 2744,
  [3184] = 2874,
  [3185] = 2869,
  [3186] = 2743,
  [3187] = 3008,
  [3188] = 2750,
  [3189] = 3001,
  [3190] = 3002,
  [3191] = 3012,
  [3192] = 2871,
  [3193] = 2745,
  [3194] = 3020,
  [3195] = 2753,
  [3196] = 2987,
  [3197] = 2871,
  [3198] = 3198,
  [3199] = 3015,
  [3200] = 2962,
  [3201] = 3201,
  [3202] = 3202,
  [3203] = 2753,
  [3204] = 2869,
  [3205] = 3022,
  [3206] = 3206,
  [3207] = 2874,
  [3208] = 2749,
  [3209] = 2879,
  [3210] = 2744,
  [3211] = 2999,
  [3212] = 2879,
  [3213] = 2990,
  [3214] = 3023,
  [3215] = 3215,
  [3216] = 2747,
  [3217] = 2992,
  [3218] = 3218,
  [3219] = 2999,
  [3220] = 3018,
  [3221] = 2743,
  [3222] = 2874,
  [3223] = 2999,
  [3224] = 2743,
  [3225] = 2869,
  [3226] = 2871,
  [3227] = 2338,
  [3228] = 2391,
  [3229] = 2952,
  [3230] = 2392,
  [3231] = 2393,
  [3232] = 2394,
  [3233] = 2395,
  [3234] = 2969,
  [3235] = 2396,
  [3236] = 2972,
  [3237] = 3022,
  [3238] = 2397,
  [3239] = 2973,
  [3240] = 2947,
  [3241] = 2398,
  [3242] = 2399,
  [3243] = 2400,
  [3244] = 2990,
  [3245] = 2961,
  [3246] = 3246,
  [3247] = 3247,
  [3248] = 2322,
  [3249] = 2401,
  [3250] = 2402,
  [3251] = 2403,
  [3252] = 2404,
  [3253] = 2405,
  [3254] = 2406,
  [3255] = 2407,
  [3256] = 2408,
  [3257] = 2409,
  [3258] = 2410,
  [3259] = 2323,
  [3260] = 2324,
  [3261] = 2411,
  [3262] = 2412,
  [3263] = 2413,
  [3264] = 2414,
  [3265] = 2415,
  [3266] = 2416,
  [3267] = 3018,
  [3268] = 2418,
  [3269] = 2419,
  [3270] = 2420,
  [3271] = 2421,
  [3272] = 2968,
  [3273] = 2874,
  [3274] = 3274,
  [3275] = 3275,
  [3276] = 3276,
  [3277] = 3277,
  [3278] = 2879,
  [3279] = 2869,
  [3280] = 3280,
  [3281] = 3281,
  [3282] = 3282,
  [3283] = 3283,
  [3284] = 3284,
  [3285] = 3285,
  [3286] = 3286,
  [3287] = 2871,
  [3288] = 2340,
  [3289] = 2341,
  [3290] = 2342,
  [3291] = 2343,
  [3292] = 2344,
  [3293] = 2345,
  [3294] = 2215,
  [3295] = 2218,
  [3296] = 2346,
  [3297] = 2347,
  [3298] = 3012,
  [3299] = 3299,
  [3300] = 3300,
  [3301] = 3301,
  [3302] = 3302,
  [3303] = 3303,
  [3304] = 3304,
  [3305] = 3305,
  [3306] = 3306,
  [3307] = 3307,
  [3308] = 3308,
  [3309] = 3309,
  [3310] = 3310,
  [3311] = 3311,
  [3312] = 3312,
  [3313] = 3313,
  [3314] = 3314,
  [3315] = 3315,
  [3316] = 3316,
  [3317] = 3317,
  [3318] = 3318,
  [3319] = 3319,
  [3320] = 2348,
  [3321] = 2654,
  [3322] = 2349,
  [3323] = 2963,
  [3324] = 3324,
  [3325] = 2350,
  [3326] = 2749,
  [3327] = 3327,
  [3328] = 2746,
  [3329] = 2749,
  [3330] = 2906,
  [3331] = 2750,
  [3332] = 3332,
  [3333] = 3333,
  [3334] = 3334,
  [3335] = 3335,
  [3336] = 3336,
  [3337] = 3337,
  [3338] = 3338,
  [3339] = 3339,
  [3340] = 3340,
  [3341] = 2351,
  [3342] = 3342,
  [3343] = 2745,
  [3344] = 2747,
  [3345] = 2352,
  [3346] = 2353,
  [3347] = 2354,
  [3348] = 2355,
  [3349] = 3349,
  [3350] = 3350,
  [3351] = 3351,
  [3352] = 3352,
  [3353] = 3353,
  [3354] = 3354,
  [3355] = 3355,
  [3356] = 3356,
  [3357] = 3357,
  [3358] = 3358,
  [3359] = 3359,
  [3360] = 2874,
  [3361] = 2879,
  [3362] = 2869,
  [3363] = 2871,
  [3364] = 3364,
  [3365] = 3015,
  [3366] = 3366,
  [3367] = 3367,
  [3368] = 2883,
  [3369] = 2885,
  [3370] = 2898,
  [3371] = 2356,
  [3372] = 2357,
  [3373] = 2874,
  [3374] = 2879,
  [3375] = 2869,
  [3376] = 2871,
  [3377] = 2903,
  [3378] = 2358,
  [3379] = 2359,
  [3380] = 2874,
  [3381] = 2879,
  [3382] = 2869,
  [3383] = 2360,
  [3384] = 2871,
  [3385] = 2743,
  [3386] = 2744,
  [3387] = 3387,
  [3388] = 3388,
  [3389] = 3389,
  [3390] = 3390,
  [3391] = 3391,
  [3392] = 3392,
  [3393] = 2746,
  [3394] = 3394,
  [3395] = 2978,
  [3396] = 3396,
  [3397] = 3397,
  [3398] = 3398,
  [3399] = 3399,
  [3400] = 3400,
  [3401] = 3401,
  [3402] = 3402,
  [3403] = 3403,
  [3404] = 3404,
  [3405] = 3405,
  [3406] = 3406,
  [3407] = 2874,
  [3408] = 2887,
  [3409] = 2879,
  [3410] = 2869,
  [3411] = 2871,
  [3412] = 3412,
  [3413] = 3413,
  [3414] = 3414,
  [3415] = 3415,
  [3416] = 3416,
  [3417] = 3417,
  [3418] = 3418,
  [3419] = 3419,
  [3420] = 3420,
  [3421] = 3421,
  [3422] = 2874,
  [3423] = 3423,
  [3424] = 2879,
  [3425] = 2869,
  [3426] = 2871,
  [3427] = 2325,
  [3428] = 2874,
  [3429] = 2874,
  [3430] = 2879,
  [3431] = 3431,
  [3432] = 2869,
  [3433] = 3433,
  [3434] = 3434,
  [3435] = 2871,
  [3436] = 3436,
  [3437] = 2326,
  [3438] = 2750,
  [3439] = 2328,
  [3440] = 2330,
  [3441] = 2331,
  [3442] = 2879,
  [3443] = 2869,
  [3444] = 2745,
  [3445] = 2902,
  [3446] = 2361,
  [3447] = 2362,
  [3448] = 2363,
  [3449] = 2364,
  [3450] = 2365,
  [3451] = 2366,
  [3452] = 2367,
  [3453] = 2368,
  [3454] = 2332,
  [3455] = 2871,
  [3456] = 2747,
  [3457] = 2909,
  [3458] = 2369,
  [3459] = 2913,
  [3460] = 2370,
  [3461] = 2434,
  [3462] = 2372,
  [3463] = 2373,
  [3464] = 2374,
  [3465] = 2999,
  [3466] = 2375,
  [3467] = 2426,
  [3468] = 2376,
  [3469] = 2333,
  [3470] = 2377,
  [3471] = 2378,
  [3472] = 2379,
  [3473] = 2380,
  [3474] = 2381,
  [3475] = 2382,
  [3476] = 2963,
  [3477] = 2383,
  [3478] = 2334,
  [3479] = 2335,
  [3480] = 3020,
  [3481] = 2336,
  [3482] = 3206,
  [3483] = 2999,
  [3484] = 3002,
  [3485] = 2999,
  [3486] = 2956,
  [3487] = 2337,
  [3488] = 2966,
  [3489] = 2970,
  [3490] = 2971,
  [3491] = 2428,
  [3492] = 2429,
  [3493] = 2430,
  [3494] = 2431,
  [3495] = 2432,
  [3496] = 2433,
  [3497] = 2371,
  [3498] = 2307,
  [3499] = 2992,
  [3500] = 3016,
  [3501] = 2948,
  [3502] = 2339,
  [3503] = 2384,
  [3504] = 2309,
  [3505] = 2385,
  [3506] = 2310,
  [3507] = 3001,
  [3508] = 2386,
  [3509] = 2387,
  [3510] = 3510,
  [3511] = 2311,
  [3512] = 2388,
  [3513] = 2312,
  [3514] = 2313,
  [3515] = 2314,
  [3516] = 2315,
  [3517] = 2316,
  [3518] = 2317,
  [3519] = 2318,
  [3520] = 2319,
  [3521] = 2320,
  [3522] = 3007,
  [3523] = 2321,
  [3524] = 3008,
  [3525] = 2389,
  [3526] = 2390,
  [3527] = 3527,
  [3528] = 2995,
  [3529] = 3014,
  [3530] = 3024,
  [3531] = 2996,
  [3532] = 2994,
  [3533] = 3004,
  [3534] = 2962,
  [3535] = 2999,
  [3536] = 2999,
  [3537] = 2999,
  [3538] = 2999,
  [3539] = 2963,
  [3540] = 2999,
  [3541] = 2999,
  [3542] = 2987,
  [3543] = 2999,
  [3544] = 2963,
  [3545] = 2999,
  [3546] = 2215,
  [3547] = 2994,
  [3548] = 2999,
  [3549] = 2999,
  [3550] = 3007,
  [3551] = 3024,
  [3552] = 2999,
  [3553] = 3018,
  [3554] = 2999,
  [3555] = 2999,
  [3556] = 3022,
  [3557] = 3557,
  [3558] = 2990,
  [3559] = 2999,
  [3560] = 2218,
  [3561] = 3561,
  [3562] = 2753,
  [3563] = 3008,
  [3564] = 3012,
  [3565] = 3565,
  [3566] = 3002,
  [3567] = 3567,
  [3568] = 3568,
  [3569] = 3016,
  [3570] = 3023,
  [3571] = 3571,
  [3572] = 2744,
  [3573] = 2754,
  [3574] = 3574,
  [3575] = 3574,
  [3576] = 3576,
  [3577] = 3001,
  [3578] = 2743,
  [3579] = 3020,
  [3580] = 3580,
  [3581] = 3574,
  [3582] = 3582,
  [3583] = 3206,
  [3584] = 2753,
  [3585] = 3565,
  [3586] = 3586,
  [3587] = 2952,
  [3588] = 2956,
  [3589] = 3589,
  [3590] = 2920,
  [3591] = 2902,
  [3592] = 3571,
  [3593] = 2969,
  [3594] = 3576,
  [3595] = 3595,
  [3596] = 2906,
  [3597] = 2749,
  [3598] = 2947,
  [3599] = 2972,
  [3600] = 3600,
  [3601] = 2883,
  [3602] = 2961,
  [3603] = 2973,
  [3604] = 3604,
  [3605] = 3565,
  [3606] = 2885,
  [3607] = 2746,
  [3608] = 2966,
  [3609] = 2750,
  [3610] = 2743,
  [3611] = 2978,
  [3612] = 2970,
  [3613] = 2754,
  [3614] = 2745,
  [3615] = 2909,
  [3616] = 2747,
  [3617] = 2898,
  [3618] = 3618,
  [3619] = 2913,
  [3620] = 2948,
  [3621] = 2971,
  [3622] = 3568,
  [3623] = 2903,
  [3624] = 2887,
  [3625] = 2744,
  [3626] = 3626,
  [3627] = 3627,
  [3628] = 3628,
  [3629] = 3629,
  [3630] = 3630,
  [3631] = 2971,
  [3632] = 2909,
  [3633] = 3633,
  [3634] = 3634,
  [3635] = 2218,
  [3636] = 3636,
  [3637] = 3637,
  [3638] = 3638,
  [3639] = 2887,
  [3640] = 3640,
  [3641] = 3641,
  [3642] = 3642,
  [3643] = 2883,
  [3644] = 3644,
  [3645] = 3645,
  [3646] = 3646,
  [3647] = 2885,
  [3648] = 2749,
  [3649] = 3649,
  [3650] = 3650,
  [3651] = 2747,
  [3652] = 2654,
  [3653] = 3653,
  [3654] = 2898,
  [3655] = 2952,
  [3656] = 3656,
  [3657] = 3657,
  [3658] = 3658,
  [3659] = 3659,
  [3660] = 3660,
  [3661] = 3661,
  [3662] = 3662,
  [3663] = 3663,
  [3664] = 2750,
  [3665] = 3665,
  [3666] = 3666,
  [3667] = 3667,
  [3668] = 3668,
  [3669] = 3669,
  [3670] = 3670,
  [3671] = 3671,
  [3672] = 3672,
  [3673] = 2969,
  [3674] = 3674,
  [3675] = 3675,
  [3676] = 3676,
  [3677] = 2972,
  [3678] = 3678,
  [3679] = 3679,
  [3680] = 2956,
  [3681] = 2970,
  [3682] = 3682,
  [3683] = 3683,
  [3684] = 3684,
  [3685] = 3685,
  [3686] = 3686,
  [3687] = 3687,
  [3688] = 3688,
  [3689] = 3689,
  [3690] = 3690,
  [3691] = 3691,
  [3692] = 3692,
  [3693] = 3693,
  [3694] = 2947,
  [3695] = 3695,
  [3696] = 3696,
  [3697] = 2948,
  [3698] = 2903,
  [3699] = 3699,
  [3700] = 3700,
  [3701] = 3701,
  [3702] = 3565,
  [3703] = 3703,
  [3704] = 2204,
  [3705] = 3705,
  [3706] = 2913,
  [3707] = 2906,
  [3708] = 3708,
  [3709] = 3709,
  [3710] = 2745,
  [3711] = 3711,
  [3712] = 3712,
  [3713] = 3713,
  [3714] = 3714,
  [3715] = 2746,
  [3716] = 3716,
  [3717] = 3717,
  [3718] = 2902,
  [3719] = 3719,
  [3720] = 3720,
  [3721] = 3721,
  [3722] = 3722,
  [3723] = 3723,
  [3724] = 2215,
  [3725] = 2966,
  [3726] = 2961,
  [3727] = 3727,
  [3728] = 3728,
  [3729] = 3729,
  [3730] = 3730,
  [3731] = 2978,
  [3732] = 2973,
  [3733] = 3733,
  [3734] = 3705,
  [3735] = 3689,
  [3736] = 3695,
  [3737] = 3737,
  [3738] = 3671,
  [3739] = 3206,
  [3740] = 3740,
  [3741] = 3692,
  [3742] = 3565,
  [3743] = 3690,
  [3744] = 2992,
  [3745] = 3649,
  [3746] = 3746,
  [3747] = 3659,
  [3748] = 3015,
  [3749] = 3661,
  [3750] = 3663,
  [3751] = 3674,
  [3752] = 3565,
  [3753] = 3753,
  [3754] = 3708,
  [3755] = 3679,
  [3756] = 3675,
  [3757] = 3711,
  [3758] = 3713,
  [3759] = 3672,
  [3760] = 3670,
  [3761] = 2204,
  [3762] = 3688,
  [3763] = 3637,
  [3764] = 3714,
  [3765] = 3717,
  [3766] = 3660,
  [3767] = 3683,
  [3768] = 3723,
  [3769] = 3669,
  [3770] = 3693,
  [3771] = 3709,
  [3772] = 3712,
  [3773] = 3684,
  [3774] = 3642,
  [3775] = 3665,
  [3776] = 3633,
  [3777] = 3696,
  [3778] = 3636,
  [3779] = 3779,
  [3780] = 3641,
  [3781] = 3719,
  [3782] = 3645,
  [3783] = 3686,
  [3784] = 3687,
  [3785] = 3656,
  [3786] = 3786,
  [3787] = 3685,
  [3788] = 3662,
  [3789] = 3565,
  [3790] = 3699,
  [3791] = 3700,
  [3792] = 3703,
  [3793] = 3657,
  [3794] = 3730,
  [3795] = 3565,
  [3796] = 2654,
  [3797] = 3206,
  [3798] = 3798,
  [3799] = 3799,
  [3800] = 3565,
  [3801] = 3018,
  [3802] = 3802,
  [3803] = 3803,
  [3804] = 3804,
  [3805] = 3805,
  [3806] = 3557,
  [3807] = 3807,
  [3808] = 2920,
  [3809] = 3809,
  [3810] = 3809,
  [3811] = 3809,
  [3812] = 3812,
  [3813] = 3565,
  [3814] = 3809,
  [3815] = 3809,
  [3816] = 3809,
  [3817] = 3809,
  [3818] = 3809,
  [3819] = 3809,
  [3820] = 3809,
  [3821] = 3809,
  [3822] = 3809,
  [3823] = 3809,
  [3824] = 3809,
  [3825] = 3809,
  [3826] = 3826,
  [3827] = 3809,
  [3828] = 3809,
  [3829] = 3809,
  [3830] = 3809,
  [3831] = 3809,
  [3832] = 3809,
  [3833] = 3809,
  [3834] = 3557,
  [3835] = 3809,
  [3836] = 3561,
  [3837] = 3809,
  [3838] = 3567,
  [3839] = 3809,
  [3840] = 3809,
  [3841] = 3809,
  [3842] = 3809,
  [3843] = 3809,
  [3844] = 3826,
  [3845] = 3809,
  [3846] = 3809,
  [3847] = 3809,
  [3848] = 3809,
  [3849] = 3809,
  [3850] = 2753,
  [3851] = 3568,
  [3852] = 3571,
  [3853] = 3809,
  [3854] = 3809,
  [3855] = 3855,
  [3856] = 3855,
  [3857] = 3565,
  [3858] = 3812,
  [3859] = 3809,
  [3860] = 2753,
  [3861] = 3809,
  [3862] = 3206,
  [3863] = 3576,
  [3864] = 3809,
  [3865] = 3809,
  [3866] = 3586,
  [3867] = 3582,
  [3868] = 3565,
  [3869] = 2743,
  [3870] = 3809,
  [3871] = 2744,
  [3872] = 3809,
  [3873] = 2754,
  [3874] = 3809,
  [3875] = 3809,
  [3876] = 3809,
  [3877] = 3809,
  [3878] = 3809,
  [3879] = 3809,
  [3880] = 2971,
  [3881] = 2947,
  [3882] = 3023,
  [3883] = 3626,
  [3884] = 2990,
  [3885] = 2970,
  [3886] = 2745,
  [3887] = 2902,
  [3888] = 3001,
  [3889] = 2920,
  [3890] = 2961,
  [3891] = 2747,
  [3892] = 2909,
  [3893] = 2913,
  [3894] = 2753,
  [3895] = 2743,
  [3896] = 3007,
  [3897] = 3008,
  [3898] = 3565,
  [3899] = 2744,
  [3900] = 2749,
  [3901] = 2746,
  [3902] = 3012,
  [3903] = 3565,
  [3904] = 2992,
  [3905] = 2750,
  [3906] = 3002,
  [3907] = 2743,
  [3908] = 3618,
  [3909] = 2745,
  [3910] = 2747,
  [3911] = 2744,
  [3912] = 3015,
  [3913] = 3626,
  [3914] = 3618,
  [3915] = 2654,
  [3916] = 2885,
  [3917] = 3561,
  [3918] = 3589,
  [3919] = 2898,
  [3920] = 3576,
  [3921] = 2948,
  [3922] = 3020,
  [3923] = 2903,
  [3924] = 2956,
  [3925] = 2746,
  [3926] = 3567,
  [3927] = 3568,
  [3928] = 3600,
  [3929] = 2978,
  [3930] = 2887,
  [3931] = 3565,
  [3932] = 3582,
  [3933] = 2952,
  [3934] = 2749,
  [3935] = 3600,
  [3936] = 2743,
  [3937] = 3627,
  [3938] = 3016,
  [3939] = 2744,
  [3940] = 3206,
  [3941] = 3589,
  [3942] = 3595,
  [3943] = 2906,
  [3944] = 3018,
  [3945] = 2966,
  [3946] = 2754,
  [3947] = 2750,
  [3948] = 3022,
  [3949] = 2969,
  [3950] = 2972,
  [3951] = 3595,
  [3952] = 3571,
  [3953] = 2973,
  [3954] = 2883,
  [3955] = 3669,
  [3956] = 3660,
  [3957] = 3957,
  [3958] = 2966,
  [3959] = 2749,
  [3960] = 3565,
  [3961] = 2970,
  [3962] = 2971,
  [3963] = 3565,
  [3964] = 2746,
  [3965] = 2215,
  [3966] = 3966,
  [3967] = 3666,
  [3968] = 3638,
  [3969] = 2218,
  [3970] = 3662,
  [3971] = 2883,
  [3972] = 3671,
  [3973] = 2885,
  [3974] = 3690,
  [3975] = 3975,
  [3976] = 2898,
  [3977] = 2948,
  [3978] = 3674,
  [3979] = 2903,
  [3980] = 3630,
  [3981] = 3981,
  [3982] = 3982,
  [3983] = 3983,
  [3984] = 2961,
  [3985] = 3634,
  [3986] = 3986,
  [3987] = 3987,
  [3988] = 3988,
  [3989] = 3989,
  [3990] = 3990,
  [3991] = 3637,
  [3992] = 2909,
  [3993] = 3993,
  [3994] = 3679,
  [3995] = 3995,
  [3996] = 3653,
  [3997] = 3997,
  [3998] = 2750,
  [3999] = 3729,
  [4000] = 3672,
  [4001] = 3688,
  [4002] = 3668,
  [4003] = 3685,
  [4004] = 2920,
  [4005] = 3689,
  [4006] = 3642,
  [4007] = 2745,
  [4008] = 3645,
  [4009] = 3649,
  [4010] = 2747,
  [4011] = 3659,
  [4012] = 3661,
  [4013] = 3663,
  [4014] = 3675,
  [4015] = 3676,
  [4016] = 3691,
  [4017] = 3711,
  [4018] = 3717,
  [4019] = 3665,
  [4020] = 3713,
  [4021] = 3692,
  [4022] = 3701,
  [4023] = 3720,
  [4024] = 2204,
  [4025] = 3995,
  [4026] = 3640,
  [4027] = 3997,
  [4028] = 3714,
  [4029] = 4029,
  [4030] = 3641,
  [4031] = 2906,
  [4032] = 2978,
  [4033] = 3696,
  [4034] = 3656,
  [4035] = 4035,
  [4036] = 2887,
  [4037] = 3684,
  [4038] = 3565,
  [4039] = 3586,
  [4040] = 4040,
  [4041] = 3699,
  [4042] = 3700,
  [4043] = 4043,
  [4044] = 3682,
  [4045] = 2952,
  [4046] = 3703,
  [4047] = 3723,
  [4048] = 3721,
  [4049] = 3728,
  [4050] = 2969,
  [4051] = 2972,
  [4052] = 4052,
  [4053] = 3709,
  [4054] = 2973,
  [4055] = 2947,
  [4056] = 3722,
  [4057] = 3705,
  [4058] = 3730,
  [4059] = 3720,
  [4060] = 3708,
  [4061] = 3686,
  [4062] = 3727,
  [4063] = 3687,
  [4064] = 3670,
  [4065] = 4065,
  [4066] = 3719,
  [4067] = 4067,
  [4068] = 4068,
  [4069] = 3565,
  [4070] = 4070,
  [4071] = 3638,
  [4072] = 2913,
  [4073] = 3657,
  [4074] = 3693,
  [4075] = 3667,
  [4076] = 3650,
  [4077] = 3636,
  [4078] = 3695,
  [4079] = 3627,
  [4080] = 3712,
  [4081] = 3716,
  [4082] = 4082,
  [4083] = 4083,
  [4084] = 3683,
  [4085] = 2956,
  [4086] = 4086,
  [4087] = 4087,
  [4088] = 4088,
  [4089] = 3633,
  [4090] = 2902,
  [4091] = 4091,
  [4092] = 4092,
  [4093] = 4093,
  [4094] = 4094,
  [4095] = 4092,
  [4096] = 3642,
  [4097] = 3649,
  [4098] = 3659,
  [4099] = 3685,
  [4100] = 4100,
  [4101] = 3689,
  [4102] = 3692,
  [4103] = 3696,
  [4104] = 3699,
  [4105] = 3700,
  [4106] = 3703,
  [4107] = 3661,
  [4108] = 3663,
  [4109] = 3675,
  [4110] = 3705,
  [4111] = 3708,
  [4112] = 3719,
  [4113] = 3712,
  [4114] = 3721,
  [4115] = 3711,
  [4116] = 2654,
  [4117] = 3982,
  [4118] = 3713,
  [4119] = 3714,
  [4120] = 3986,
  [4121] = 3693,
  [4122] = 4067,
  [4123] = 2735,
  [4124] = 4068,
  [4125] = 3729,
  [4126] = 2735,
  [4127] = 3727,
  [4128] = 4128,
  [4129] = 4129,
  [4130] = 4082,
  [4131] = 3723,
  [4132] = 3653,
  [4133] = 3668,
  [4134] = 3730,
  [4135] = 3565,
  [4136] = 4092,
  [4137] = 3987,
  [4138] = 3557,
  [4139] = 3676,
  [4140] = 3691,
  [4141] = 4093,
  [4142] = 4094,
  [4143] = 4128,
  [4144] = 4129,
  [4145] = 4145,
  [4146] = 3565,
  [4147] = 4083,
  [4148] = 3640,
  [4149] = 3565,
  [4150] = 3650,
  [4151] = 3586,
  [4152] = 3637,
  [4153] = 3966,
  [4154] = 3672,
  [4155] = 3981,
  [4156] = 3983,
  [4157] = 4086,
  [4158] = 2992,
  [4159] = 3015,
  [4160] = 3716,
  [4161] = 4088,
  [4162] = 4091,
  [4163] = 4070,
  [4164] = 3989,
  [4165] = 3990,
  [4166] = 4035,
  [4167] = 4040,
  [4168] = 3728,
  [4169] = 4092,
  [4170] = 3717,
  [4171] = 4093,
  [4172] = 4094,
  [4173] = 4128,
  [4174] = 4129,
  [4175] = 4145,
  [4176] = 3722,
  [4177] = 3630,
  [4178] = 3565,
  [4179] = 3206,
  [4180] = 4052,
  [4181] = 4092,
  [4182] = 4043,
  [4183] = 3688,
  [4184] = 3709,
  [4185] = 4093,
  [4186] = 4094,
  [4187] = 4128,
  [4188] = 4129,
  [4189] = 4145,
  [4190] = 3957,
  [4191] = 3636,
  [4192] = 4092,
  [4193] = 4093,
  [4194] = 4094,
  [4195] = 4128,
  [4196] = 4129,
  [4197] = 4145,
  [4198] = 4029,
  [4199] = 3565,
  [4200] = 3565,
  [4201] = 4092,
  [4202] = 4093,
  [4203] = 4094,
  [4204] = 4128,
  [4205] = 4129,
  [4206] = 4145,
  [4207] = 4065,
  [4208] = 3565,
  [4209] = 4092,
  [4210] = 4093,
  [4211] = 4094,
  [4212] = 4128,
  [4213] = 4129,
  [4214] = 4145,
  [4215] = 3565,
  [4216] = 3565,
  [4217] = 4092,
  [4218] = 3641,
  [4219] = 4093,
  [4220] = 4094,
  [4221] = 4128,
  [4222] = 4129,
  [4223] = 4145,
  [4224] = 3565,
  [4225] = 4092,
  [4226] = 4093,
  [4227] = 4092,
  [4228] = 4093,
  [4229] = 4092,
  [4230] = 2204,
  [4231] = 4093,
  [4232] = 4092,
  [4233] = 4093,
  [4234] = 4092,
  [4235] = 4093,
  [4236] = 4092,
  [4237] = 4093,
  [4238] = 4092,
  [4239] = 4093,
  [4240] = 4092,
  [4241] = 4093,
  [4242] = 4092,
  [4243] = 4093,
  [4244] = 4092,
  [4245] = 4093,
  [4246] = 4092,
  [4247] = 4093,
  [4248] = 4092,
  [4249] = 3206,
  [4250] = 4093,
  [4251] = 3669,
  [4252] = 4092,
  [4253] = 3634,
  [4254] = 4093,
  [4255] = 4092,
  [4256] = 4093,
  [4257] = 4092,
  [4258] = 4093,
  [4259] = 4092,
  [4260] = 4093,
  [4261] = 4092,
  [4262] = 4093,
  [4263] = 4092,
  [4264] = 4093,
  [4265] = 4092,
  [4266] = 4093,
  [4267] = 4092,
  [4268] = 4093,
  [4269] = 4092,
  [4270] = 4093,
  [4271] = 4092,
  [4272] = 4093,
  [4273] = 4092,
  [4274] = 4093,
  [4275] = 4092,
  [4276] = 4093,
  [4277] = 4093,
  [4278] = 4092,
  [4279] = 4093,
  [4280] = 4092,
  [4281] = 4093,
  [4282] = 4092,
  [4283] = 4093,
  [4284] = 4092,
  [4285] = 4093,
  [4286] = 4092,
  [4287] = 3645,
  [4288] = 4093,
  [4289] = 4093,
  [4290] = 2215,
  [4291] = 3656,
  [4292] = 2218,
  [4293] = 3682,
  [4294] = 4294,
  [4295] = 3695,
  [4296] = 3628,
  [4297] = 4092,
  [4298] = 4093,
  [4299] = 4092,
  [4300] = 3633,
  [4301] = 4093,
  [4302] = 4092,
  [4303] = 3657,
  [4304] = 3660,
  [4305] = 4093,
  [4306] = 4092,
  [4307] = 4093,
  [4308] = 4092,
  [4309] = 3662,
  [4310] = 4093,
  [4311] = 4092,
  [4312] = 4312,
  [4313] = 3671,
  [4314] = 4093,
  [4315] = 4092,
  [4316] = 4093,
  [4317] = 4092,
  [4318] = 3665,
  [4319] = 4093,
  [4320] = 4092,
  [4321] = 4093,
  [4322] = 4322,
  [4323] = 3670,
  [4324] = 3683,
  [4325] = 3684,
  [4326] = 3686,
  [4327] = 3674,
  [4328] = 3687,
  [4329] = 3690,
  [4330] = 4145,
  [4331] = 4092,
  [4332] = 3679,
  [4333] = 3993,
  [4334] = 3565,
  [4335] = 3565,
  [4336] = 3567,
  [4337] = 3565,
  [4338] = 3582,
  [4339] = 4339,
  [4340] = 4340,
  [4341] = 3628,
  [4342] = 3565,
  [4343] = 2992,
  [4344] = 3565,
  [4345] = 3565,
  [4346] = 3565,
  [4347] = 4347,
  [4348] = 3015,
  [4349] = 2304,
  [4350] = 2734,
  [4351] = 3733,
  [4352] = 4352,
  [4353] = 4353,
  [4354] = 3561,
  [4355] = 4355,
  [4356] = 2305,
  [4357] = 4357,
  [4358] = 2215,
  [4359] = 2218,
  [4360] = 3565,
  [4361] = 3557,
  [4362] = 4352,
  [4363] = 2221,
  [4364] = 3565,
  [4365] = 4340,
  [4366] = 4340,
  [4367] = 4367,
  [4368] = 3855,
  [4369] = 3565,
  [4370] = 3855,
  [4371] = 4371,
  [4372] = 4372,
  [4373] = 3567,
  [4374] = 4372,
  [4375] = 4372,
  [4376] = 4376,
  [4377] = 3568,
  [4378] = 3565,
  [4379] = 4372,
  [4380] = 4367,
  [4381] = 4367,
  [4382] = 4372,
  [4383] = 4372,
  [4384] = 4340,
  [4385] = 4372,
  [4386] = 4340,
  [4387] = 4372,
  [4388] = 4372,
  [4389] = 3582,
  [4390] = 3855,
  [4391] = 4391,
  [4392] = 4392,
  [4393] = 4372,
  [4394] = 4372,
  [4395] = 4367,
  [4396] = 4372,
  [4397] = 3733,
  [4398] = 4367,
  [4399] = 3565,
  [4400] = 4372,
  [4401] = 4372,
  [4402] = 4367,
  [4403] = 3746,
  [4404] = 4372,
  [4405] = 3586,
  [4406] = 4367,
  [4407] = 4367,
  [4408] = 4408,
  [4409] = 4409,
  [4410] = 4410,
  [4411] = 4411,
  [4412] = 3571,
  [4413] = 4413,
  [4414] = 4414,
  [4415] = 3855,
  [4416] = 4416,
  [4417] = 4417,
  [4418] = 4418,
  [4419] = 4419,
  [4420] = 4420,
  [4421] = 4372,
  [4422] = 4422,
  [4423] = 4423,
  [4424] = 4424,
  [4425] = 4367,
  [4426] = 4426,
  [4427] = 4372,
  [4428] = 4372,
  [4429] = 4372,
  [4430] = 4430,
  [4431] = 4431,
  [4432] = 4432,
  [4433] = 4433,
  [4434] = 4434,
  [4435] = 4367,
  [4436] = 4340,
  [4437] = 4437,
  [4438] = 4438,
  [4439] = 4372,
  [4440] = 4372,
  [4441] = 3737,
  [4442] = 3786,
  [4443] = 4367,
  [4444] = 4372,
  [4445] = 4367,
  [4446] = 3576,
  [4447] = 4367,
  [4448] = 3740,
  [4449] = 4372,
  [4450] = 4450,
  [4451] = 4372,
  [4452] = 4367,
  [4453] = 4372,
  [4454] = 4372,
  [4455] = 3779,
  [4456] = 3561,
  [4457] = 4340,
  [4458] = 3565,
  [4459] = 4372,
  [4460] = 4432,
  [4461] = 4418,
  [4462] = 4411,
  [4463] = 4391,
  [4464] = 3626,
  [4465] = 4408,
  [4466] = 4414,
  [4467] = 3746,
  [4468] = 3565,
  [4469] = 4419,
  [4470] = 4420,
  [4471] = 4438,
  [4472] = 3786,
  [4473] = 3565,
  [4474] = 4410,
  [4475] = 4450,
  [4476] = 4413,
  [4477] = 4477,
  [4478] = 4478,
  [4479] = 4479,
  [4480] = 4450,
  [4481] = 4481,
  [4482] = 4482,
  [4483] = 4422,
  [4484] = 4423,
  [4485] = 4424,
  [4486] = 4426,
  [4487] = 3565,
  [4488] = 4414,
  [4489] = 3565,
  [4490] = 3627,
  [4491] = 3600,
  [4492] = 4416,
  [4493] = 3779,
  [4494] = 4392,
  [4495] = 4422,
  [4496] = 3803,
  [4497] = 3807,
  [4498] = 4416,
  [4499] = 4430,
  [4500] = 4070,
  [4501] = 4431,
  [4502] = 4410,
  [4503] = 3737,
  [4504] = 4409,
  [4505] = 4434,
  [4506] = 4437,
  [4507] = 3589,
  [4508] = 4438,
  [4509] = 4509,
  [4510] = 4434,
  [4511] = 4423,
  [4512] = 4424,
  [4513] = 2744,
  [4514] = 4376,
  [4515] = 4430,
  [4516] = 3618,
  [4517] = 4431,
  [4518] = 3565,
  [4519] = 4417,
  [4520] = 4520,
  [4521] = 4376,
  [4522] = 4437,
  [4523] = 3595,
  [4524] = 4417,
  [4525] = 4432,
  [4526] = 4418,
  [4527] = 4419,
  [4528] = 3740,
  [4529] = 2743,
  [4530] = 4530,
  [4531] = 4420,
  [4532] = 4532,
  [4533] = 4530,
  [4534] = 4426,
  [4535] = 4530,
  [4536] = 4408,
  [4537] = 4532,
  [4538] = 4409,
  [4539] = 4413,
  [4540] = 4540,
  [4541] = 3565,
  [4542] = 4532,
  [4543] = 4433,
  [4544] = 4411,
  [4545] = 4433,
  [4546] = 4419,
  [4547] = 3981,
  [4548] = 3983,
  [4549] = 3640,
  [4550] = 3997,
  [4551] = 4091,
  [4552] = 4376,
  [4553] = 4450,
  [4554] = 4554,
  [4555] = 4035,
  [4556] = 4040,
  [4557] = 4086,
  [4558] = 4558,
  [4559] = 3989,
  [4560] = 3990,
  [4561] = 3682,
  [4562] = 3987,
  [4563] = 4563,
  [4564] = 3695,
  [4565] = 3666,
  [4566] = 4558,
  [4567] = 4558,
  [4568] = 3721,
  [4569] = 3728,
  [4570] = 4558,
  [4571] = 4477,
  [4572] = 3988,
  [4573] = 4573,
  [4574] = 2920,
  [4575] = 3685,
  [4576] = 4408,
  [4577] = 4478,
  [4578] = 3633,
  [4579] = 4558,
  [4580] = 4410,
  [4581] = 3650,
  [4582] = 3982,
  [4583] = 4583,
  [4584] = 4479,
  [4585] = 3986,
  [4586] = 3665,
  [4587] = 4409,
  [4588] = 4411,
  [4589] = 4413,
  [4590] = 3670,
  [4591] = 4591,
  [4592] = 3683,
  [4593] = 3684,
  [4594] = 3803,
  [4595] = 3686,
  [4596] = 4558,
  [4597] = 4558,
  [4598] = 4416,
  [4599] = 4417,
  [4600] = 4418,
  [4601] = 4420,
  [4602] = 3705,
  [4603] = 3997,
  [4604] = 4604,
  [4605] = 4558,
  [4606] = 3687,
  [4607] = 3703,
  [4608] = 4067,
  [4609] = 4068,
  [4610] = 4082,
  [4611] = 4088,
  [4612] = 4043,
  [4613] = 4029,
  [4614] = 4065,
  [4615] = 2734,
  [4616] = 3717,
  [4617] = 4422,
  [4618] = 4423,
  [4619] = 4424,
  [4620] = 3722,
  [4621] = 3690,
  [4622] = 4558,
  [4623] = 4426,
  [4624] = 3693,
  [4625] = 4558,
  [4626] = 3727,
  [4627] = 4627,
  [4628] = 4604,
  [4629] = 3667,
  [4630] = 3993,
  [4631] = 3712,
  [4632] = 4558,
  [4633] = 4052,
  [4634] = 3807,
  [4635] = 3729,
  [4636] = 4391,
  [4637] = 3638,
  [4638] = 4627,
  [4639] = 4558,
  [4640] = 4558,
  [4641] = 4604,
  [4642] = 4558,
  [4643] = 3637,
  [4644] = 4644,
  [4645] = 4558,
  [4646] = 4392,
  [4647] = 4647,
  [4648] = 3672,
  [4649] = 3716,
  [4650] = 3630,
  [4651] = 4604,
  [4652] = 4558,
  [4653] = 3634,
  [4654] = 3699,
  [4655] = 3719,
  [4656] = 3700,
  [4657] = 3688,
  [4658] = 4558,
  [4659] = 4558,
  [4660] = 4604,
  [4661] = 4558,
  [4662] = 2215,
  [4663] = 3957,
  [4664] = 3701,
  [4665] = 4604,
  [4666] = 4558,
  [4667] = 4558,
  [4668] = 4604,
  [4669] = 4481,
  [4670] = 4482,
  [4671] = 3692,
  [4672] = 3642,
  [4673] = 3669,
  [4674] = 4430,
  [4675] = 4558,
  [4676] = 3708,
  [4677] = 3689,
  [4678] = 4558,
  [4679] = 4431,
  [4680] = 4432,
  [4681] = 4433,
  [4682] = 4558,
  [4683] = 4434,
  [4684] = 3649,
  [4685] = 4437,
  [4686] = 3659,
  [4687] = 4687,
  [4688] = 3661,
  [4689] = 4438,
  [4690] = 3663,
  [4691] = 4558,
  [4692] = 4558,
  [4693] = 4558,
  [4694] = 4558,
  [4695] = 3668,
  [4696] = 4558,
  [4697] = 4558,
  [4698] = 4558,
  [4699] = 3987,
  [4700] = 4558,
  [4701] = 3675,
  [4702] = 3676,
  [4703] = 3691,
  [4704] = 4704,
  [4705] = 3711,
  [4706] = 4627,
  [4707] = 3713,
  [4708] = 3714,
  [4709] = 3723,
  [4710] = 4710,
  [4711] = 4558,
  [4712] = 3730,
  [4713] = 3696,
  [4714] = 3720,
  [4715] = 3997,
  [4716] = 4558,
  [4717] = 3636,
  [4718] = 4558,
  [4719] = 3641,
  [4720] = 4720,
  [4721] = 3645,
  [4722] = 3656,
  [4723] = 4723,
  [4724] = 4083,
  [4725] = 4725,
  [4726] = 3657,
  [4727] = 2734,
  [4728] = 4558,
  [4729] = 3997,
  [4730] = 3653,
  [4731] = 4731,
  [4732] = 3660,
  [4733] = 3662,
  [4734] = 4558,
  [4735] = 4558,
  [4736] = 2204,
  [4737] = 4627,
  [4738] = 3671,
  [4739] = 3674,
  [4740] = 2218,
  [4741] = 4604,
  [4742] = 4558,
  [4743] = 4710,
  [4744] = 3679,
  [4745] = 4704,
  [4746] = 4710,
  [4747] = 4704,
  [4748] = 3966,
  [4749] = 3709,
  [4750] = 4750,
  [4751] = 4450,
  [4752] = 4416,
  [4753] = 4753,
  [4754] = 3987,
  [4755] = 4753,
  [4756] = 4417,
  [4757] = 4753,
  [4758] = 4758,
  [4759] = 4759,
  [4760] = 4760,
  [4761] = 4759,
  [4762] = 4759,
  [4763] = 4763,
  [4764] = 4764,
  [4765] = 2754,
  [4766] = 4766,
  [4767] = 4408,
  [4768] = 4409,
  [4769] = 4411,
  [4770] = 4413,
  [4771] = 4416,
  [4772] = 4417,
  [4773] = 4418,
  [4774] = 4419,
  [4775] = 4420,
  [4776] = 4430,
  [4777] = 4431,
  [4778] = 4432,
  [4779] = 4433,
  [4780] = 4434,
  [4781] = 4437,
  [4782] = 4438,
  [4783] = 4753,
  [4784] = 4759,
  [4785] = 4785,
  [4786] = 2753,
  [4787] = 4409,
  [4788] = 4753,
  [4789] = 4753,
  [4790] = 4758,
  [4791] = 4759,
  [4792] = 4760,
  [4793] = 4785,
  [4794] = 4794,
  [4795] = 4750,
  [4796] = 4796,
  [4797] = 4796,
  [4798] = 4798,
  [4799] = 4411,
  [4800] = 4753,
  [4801] = 4759,
  [4802] = 4753,
  [4803] = 4477,
  [4804] = 4478,
  [4805] = 4753,
  [4806] = 4806,
  [4807] = 4758,
  [4808] = 4418,
  [4809] = 4760,
  [4810] = 4785,
  [4811] = 4414,
  [4812] = 4753,
  [4813] = 4479,
  [4814] = 4796,
  [4815] = 4413,
  [4816] = 4423,
  [4817] = 4753,
  [4818] = 4758,
  [4819] = 4760,
  [4820] = 4785,
  [4821] = 4750,
  [4822] = 4753,
  [4823] = 4796,
  [4824] = 2734,
  [4825] = 4419,
  [4826] = 4753,
  [4827] = 4759,
  [4828] = 4796,
  [4829] = 4753,
  [4830] = 4759,
  [4831] = 4431,
  [4832] = 4391,
  [4833] = 4408,
  [4834] = 4392,
  [4835] = 4376,
  [4836] = 4753,
  [4837] = 4432,
  [4838] = 4753,
  [4839] = 4434,
  [4840] = 4759,
  [4841] = 4376,
  [4842] = 4753,
  [4843] = 4753,
  [4844] = 4844,
  [4845] = 4753,
  [4846] = 4753,
  [4847] = 4409,
  [4848] = 4759,
  [4849] = 4753,
  [4850] = 4437,
  [4851] = 4759,
  [4852] = 4416,
  [4853] = 3586,
  [4854] = 4753,
  [4855] = 3987,
  [4856] = 4438,
  [4857] = 4759,
  [4858] = 4753,
  [4859] = 4753,
  [4860] = 4753,
  [4861] = 4753,
  [4862] = 4759,
  [4863] = 4798,
  [4864] = 4753,
  [4865] = 4422,
  [4866] = 4753,
  [4867] = 4420,
  [4868] = 4408,
  [4869] = 4759,
  [4870] = 4753,
  [4871] = 4798,
  [4872] = 4759,
  [4873] = 4753,
  [4874] = 4759,
  [4875] = 4759,
  [4876] = 4759,
  [4877] = 4759,
  [4878] = 4424,
  [4879] = 4759,
  [4880] = 4437,
  [4881] = 4759,
  [4882] = 4753,
  [4883] = 4759,
  [4884] = 4410,
  [4885] = 4753,
  [4886] = 4438,
  [4887] = 4759,
  [4888] = 4759,
  [4889] = 4889,
  [4890] = 4413,
  [4891] = 4753,
  [4892] = 4759,
  [4893] = 4420,
  [4894] = 4376,
  [4895] = 4753,
  [4896] = 4896,
  [4897] = 4481,
  [4898] = 4482,
  [4899] = 4422,
  [4900] = 4410,
  [4901] = 4901,
  [4902] = 4391,
  [4903] = 4764,
  [4904] = 4904,
  [4905] = 4417,
  [4906] = 4422,
  [4907] = 4423,
  [4908] = 4424,
  [4909] = 4426,
  [4910] = 4392,
  [4911] = 4759,
  [4912] = 4794,
  [4913] = 4450,
  [4914] = 4423,
  [4915] = 4753,
  [4916] = 4424,
  [4917] = 4411,
  [4918] = 4430,
  [4919] = 4418,
  [4920] = 4753,
  [4921] = 4426,
  [4922] = 4431,
  [4923] = 4432,
  [4924] = 4426,
  [4925] = 4720,
  [4926] = 4720,
  [4927] = 4563,
  [4928] = 4433,
  [4929] = 4753,
  [4930] = 3557,
  [4931] = 4763,
  [4932] = 4758,
  [4933] = 4796,
  [4934] = 4419,
  [4935] = 4760,
  [4936] = 4785,
  [4937] = 4753,
  [4938] = 4430,
  [4939] = 4450,
  [4940] = 4940,
  [4941] = 4794,
  [4942] = 4753,
  [4943] = 4410,
  [4944] = 4434,
  [4945] = 4433,
  [4946] = 4563,
  [4947] = 2920,
  [4948] = 4481,
  [4949] = 4414,
  [4950] = 4434,
  [4951] = 3561,
  [4952] = 4409,
  [4953] = 4376,
  [4954] = 4070,
  [4955] = 4437,
  [4956] = 4438,
  [4957] = 4479,
  [4958] = 2992,
  [4959] = 4411,
  [4960] = 4450,
  [4961] = 4478,
  [4962] = 3015,
  [4963] = 4413,
  [4964] = 4416,
  [4965] = 4478,
  [4966] = 4479,
  [4967] = 4420,
  [4968] = 4482,
  [4969] = 4422,
  [4970] = 4423,
  [4971] = 4482,
  [4972] = 3582,
  [4973] = 4410,
  [4974] = 4417,
  [4975] = 4424,
  [4976] = 3567,
  [4977] = 4430,
  [4978] = 4477,
  [4979] = 2734,
  [4980] = 4431,
  [4981] = 4432,
  [4982] = 4426,
  [4983] = 4408,
  [4984] = 4418,
  [4985] = 4477,
  [4986] = 4419,
  [4987] = 4433,
  [4988] = 4481,
  [4989] = 4419,
  [4990] = 3989,
  [4991] = 4432,
  [4992] = 4563,
  [4993] = 4040,
  [4994] = 4434,
  [4995] = 3987,
  [4996] = 4417,
  [4997] = 4418,
  [4998] = 2747,
  [4999] = 4999,
  [5000] = 3987,
  [5001] = 2746,
  [5002] = 4088,
  [5003] = 4376,
  [5004] = 4083,
  [5005] = 3957,
  [5006] = 4423,
  [5007] = 2956,
  [5008] = 4426,
  [5009] = 4420,
  [5010] = 4720,
  [5011] = 4410,
  [5012] = 3982,
  [5013] = 4433,
  [5014] = 2969,
  [5015] = 4438,
  [5016] = 2734,
  [5017] = 4437,
  [5018] = 4424,
  [5019] = 2749,
  [5020] = 3993,
  [5021] = 4065,
  [5022] = 4052,
  [5023] = 3986,
  [5024] = 4391,
  [5025] = 2745,
  [5026] = 4029,
  [5027] = 3966,
  [5028] = 4392,
  [5029] = 4082,
  [5030] = 4416,
  [5031] = 4409,
  [5032] = 4086,
  [5033] = 3981,
  [5034] = 3983,
  [5035] = 4091,
  [5036] = 4043,
  [5037] = 3990,
  [5038] = 4431,
  [5039] = 4067,
  [5040] = 4408,
  [5041] = 4430,
  [5042] = 4413,
  [5043] = 4411,
  [5044] = 2750,
  [5045] = 4035,
  [5046] = 4068,
  [5047] = 4422,
  [5048] = 4450,
  [5049] = 4434,
  [5050] = 4430,
  [5051] = 5051,
  [5052] = 4720,
  [5053] = 4414,
  [5054] = 4419,
  [5055] = 4422,
  [5056] = 4420,
  [5057] = 4450,
  [5058] = 4431,
  [5059] = 3987,
  [5060] = 3989,
  [5061] = 3990,
  [5062] = 4376,
  [5063] = 4409,
  [5064] = 4418,
  [5065] = 3557,
  [5066] = 4450,
  [5067] = 4408,
  [5068] = 4423,
  [5069] = 4424,
  [5070] = 4430,
  [5071] = 4413,
  [5072] = 4431,
  [5073] = 4432,
  [5074] = 4432,
  [5075] = 4426,
  [5076] = 2920,
  [5077] = 4433,
  [5078] = 4411,
  [5079] = 4408,
  [5080] = 4410,
  [5081] = 4409,
  [5082] = 4411,
  [5083] = 4563,
  [5084] = 4426,
  [5085] = 4413,
  [5086] = 4433,
  [5087] = 4434,
  [5088] = 4434,
  [5089] = 4437,
  [5090] = 4438,
  [5091] = 4437,
  [5092] = 2754,
  [5093] = 4416,
  [5094] = 4416,
  [5095] = 4417,
  [5096] = 4418,
  [5097] = 4450,
  [5098] = 4419,
  [5099] = 4420,
  [5100] = 4376,
  [5101] = 5101,
  [5102] = 4410,
  [5103] = 4410,
  [5104] = 4391,
  [5105] = 4414,
  [5106] = 4392,
  [5107] = 4477,
  [5108] = 4408,
  [5109] = 4424,
  [5110] = 4422,
  [5111] = 4423,
  [5112] = 4424,
  [5113] = 4430,
  [5114] = 4431,
  [5115] = 4432,
  [5116] = 5116,
  [5117] = 4426,
  [5118] = 4433,
  [5119] = 4478,
  [5120] = 5120,
  [5121] = 4437,
  [5122] = 4438,
  [5123] = 4409,
  [5124] = 4411,
  [5125] = 4479,
  [5126] = 4413,
  [5127] = 4438,
  [5128] = 2972,
  [5129] = 4416,
  [5130] = 4417,
  [5131] = 4418,
  [5132] = 4419,
  [5133] = 4420,
  [5134] = 4422,
  [5135] = 4417,
  [5136] = 4423,
  [5137] = 4376,
  [5138] = 4481,
  [5139] = 4482,
  [5140] = 5140,
  [5141] = 3586,
  [5142] = 4420,
  [5143] = 4438,
  [5144] = 4423,
  [5145] = 4424,
  [5146] = 4430,
  [5147] = 2754,
  [5148] = 4409,
  [5149] = 4450,
  [5150] = 4411,
  [5151] = 4450,
  [5152] = 4431,
  [5153] = 2734,
  [5154] = 4432,
  [5155] = 4410,
  [5156] = 3567,
  [5157] = 4426,
  [5158] = 4410,
  [5159] = 4433,
  [5160] = 4424,
  [5161] = 4413,
  [5162] = 4376,
  [5163] = 4450,
  [5164] = 4414,
  [5165] = 3561,
  [5166] = 5166,
  [5167] = 2743,
  [5168] = 4434,
  [5169] = 4408,
  [5170] = 4417,
  [5171] = 5166,
  [5172] = 4419,
  [5173] = 2744,
  [5174] = 4422,
  [5175] = 5166,
  [5176] = 4423,
  [5177] = 3586,
  [5178] = 4432,
  [5179] = 2734,
  [5180] = 4434,
  [5181] = 4414,
  [5182] = 4391,
  [5183] = 4424,
  [5184] = 3568,
  [5185] = 4409,
  [5186] = 4376,
  [5187] = 5166,
  [5188] = 4411,
  [5189] = 2743,
  [5190] = 4376,
  [5191] = 4422,
  [5192] = 4477,
  [5193] = 4478,
  [5194] = 4479,
  [5195] = 4481,
  [5196] = 4482,
  [5197] = 4437,
  [5198] = 4413,
  [5199] = 4438,
  [5200] = 2744,
  [5201] = 4430,
  [5202] = 4426,
  [5203] = 3571,
  [5204] = 4416,
  [5205] = 4423,
  [5206] = 4430,
  [5207] = 4438,
  [5208] = 4431,
  [5209] = 4408,
  [5210] = 3582,
  [5211] = 4432,
  [5212] = 4408,
  [5213] = 4418,
  [5214] = 4431,
  [5215] = 4426,
  [5216] = 4409,
  [5217] = 4411,
  [5218] = 4416,
  [5219] = 2753,
  [5220] = 4433,
  [5221] = 3576,
  [5222] = 4413,
  [5223] = 5166,
  [5224] = 4416,
  [5225] = 4434,
  [5226] = 4417,
  [5227] = 4420,
  [5228] = 4410,
  [5229] = 4392,
  [5230] = 4418,
  [5231] = 4422,
  [5232] = 4437,
  [5233] = 4419,
  [5234] = 4433,
  [5235] = 4420,
  [5236] = 4418,
  [5237] = 4417,
  [5238] = 5166,
  [5239] = 4419,
  [5240] = 2973,
  [5241] = 4414,
  [5242] = 4437,
  [5243] = 2909,
  [5244] = 5244,
  [5245] = 4417,
  [5246] = 4416,
  [5247] = 4424,
  [5248] = 4434,
  [5249] = 4408,
  [5250] = 2948,
  [5251] = 2966,
  [5252] = 4437,
  [5253] = 2972,
  [5254] = 2746,
  [5255] = 2920,
  [5256] = 4376,
  [5257] = 4417,
  [5258] = 4720,
  [5259] = 2961,
  [5260] = 4422,
  [5261] = 5244,
  [5262] = 2970,
  [5263] = 4418,
  [5264] = 4563,
  [5265] = 4423,
  [5266] = 5266,
  [5267] = 4408,
  [5268] = 2961,
  [5269] = 2734,
  [5270] = 2992,
  [5271] = 4426,
  [5272] = 2948,
  [5273] = 4416,
  [5274] = 4426,
  [5275] = 4438,
  [5276] = 4416,
  [5277] = 5244,
  [5278] = 3618,
  [5279] = 4424,
  [5280] = 4423,
  [5281] = 4419,
  [5282] = 4420,
  [5283] = 4426,
  [5284] = 4417,
  [5285] = 4392,
  [5286] = 2903,
  [5287] = 4376,
  [5288] = 4422,
  [5289] = 4409,
  [5290] = 2883,
  [5291] = 4392,
  [5292] = 4376,
  [5293] = 4376,
  [5294] = 4417,
  [5295] = 2971,
  [5296] = 4423,
  [5297] = 4411,
  [5298] = 4563,
  [5299] = 4422,
  [5300] = 4424,
  [5301] = 4414,
  [5302] = 3989,
  [5303] = 4418,
  [5304] = 4419,
  [5305] = 5305,
  [5306] = 4411,
  [5307] = 4408,
  [5308] = 5244,
  [5309] = 4430,
  [5310] = 4410,
  [5311] = 4431,
  [5312] = 4432,
  [5313] = 4430,
  [5314] = 4431,
  [5315] = 4418,
  [5316] = 4432,
  [5317] = 4419,
  [5318] = 4433,
  [5319] = 4409,
  [5320] = 4409,
  [5321] = 2971,
  [5322] = 4434,
  [5323] = 4438,
  [5324] = 4422,
  [5325] = 2902,
  [5326] = 4434,
  [5327] = 4437,
  [5328] = 4411,
  [5329] = 4418,
  [5330] = 4411,
  [5331] = 4430,
  [5332] = 4438,
  [5333] = 4416,
  [5334] = 2952,
  [5335] = 2952,
  [5336] = 2906,
  [5337] = 4410,
  [5338] = 3595,
  [5339] = 2973,
  [5340] = 4391,
  [5341] = 2956,
  [5342] = 2887,
  [5343] = 3990,
  [5344] = 4413,
  [5345] = 2885,
  [5346] = 2920,
  [5347] = 4450,
  [5348] = 4070,
  [5349] = 2969,
  [5350] = 4392,
  [5351] = 2805,
  [5352] = 3627,
  [5353] = 2947,
  [5354] = 2947,
  [5355] = 4414,
  [5356] = 4450,
  [5357] = 2898,
  [5358] = 4437,
  [5359] = 2745,
  [5360] = 2978,
  [5361] = 2747,
  [5362] = 5244,
  [5363] = 4426,
  [5364] = 4410,
  [5365] = 2992,
  [5366] = 3600,
  [5367] = 3626,
  [5368] = 5244,
  [5369] = 4409,
  [5370] = 4419,
  [5371] = 4720,
  [5372] = 4420,
  [5373] = 2734,
  [5374] = 4410,
  [5375] = 4423,
  [5376] = 4424,
  [5377] = 2750,
  [5378] = 4414,
  [5379] = 3015,
  [5380] = 4413,
  [5381] = 4413,
  [5382] = 4437,
  [5383] = 3589,
  [5384] = 2913,
  [5385] = 2970,
  [5386] = 4430,
  [5387] = 2753,
  [5388] = 4477,
  [5389] = 4478,
  [5390] = 4479,
  [5391] = 4481,
  [5392] = 4482,
  [5393] = 4432,
  [5394] = 4433,
  [5395] = 4450,
  [5396] = 4420,
  [5397] = 4413,
  [5398] = 4433,
  [5399] = 4431,
  [5400] = 5400,
  [5401] = 4432,
  [5402] = 3987,
  [5403] = 4438,
  [5404] = 4431,
  [5405] = 4391,
  [5406] = 5406,
  [5407] = 4450,
  [5408] = 2749,
  [5409] = 3987,
  [5410] = 4391,
  [5411] = 4433,
  [5412] = 4434,
  [5413] = 4408,
  [5414] = 4420,
  [5415] = 4432,
  [5416] = 4420,
  [5417] = 4422,
  [5418] = 4423,
  [5419] = 4430,
  [5420] = 4431,
  [5421] = 4432,
  [5422] = 4426,
  [5423] = 4433,
  [5424] = 4434,
  [5425] = 4437,
  [5426] = 4438,
  [5427] = 4067,
  [5428] = 4068,
  [5429] = 4082,
  [5430] = 4088,
  [5431] = 4043,
  [5432] = 4029,
  [5433] = 4065,
  [5434] = 5434,
  [5435] = 3993,
  [5436] = 4052,
  [5437] = 3957,
  [5438] = 3982,
  [5439] = 3986,
  [5440] = 4408,
  [5441] = 4430,
  [5442] = 4431,
  [5443] = 4432,
  [5444] = 4433,
  [5445] = 4410,
  [5446] = 4434,
  [5447] = 4437,
  [5448] = 4438,
  [5449] = 4409,
  [5450] = 4411,
  [5451] = 4413,
  [5452] = 4416,
  [5453] = 2963,
  [5454] = 4417,
  [5455] = 4418,
  [5456] = 4419,
  [5457] = 4420,
  [5458] = 4376,
  [5459] = 4430,
  [5460] = 4431,
  [5461] = 4432,
  [5462] = 4433,
  [5463] = 4434,
  [5464] = 4437,
  [5465] = 4438,
  [5466] = 5466,
  [5467] = 2215,
  [5468] = 5434,
  [5469] = 3989,
  [5470] = 3990,
  [5471] = 5471,
  [5472] = 4563,
  [5473] = 2966,
  [5474] = 4408,
  [5475] = 4422,
  [5476] = 4423,
  [5477] = 4426,
  [5478] = 5434,
  [5479] = 2218,
  [5480] = 4422,
  [5481] = 4423,
  [5482] = 4430,
  [5483] = 4431,
  [5484] = 4432,
  [5485] = 4426,
  [5486] = 4433,
  [5487] = 4434,
  [5488] = 4437,
  [5489] = 4438,
  [5490] = 4408,
  [5491] = 4410,
  [5492] = 4409,
  [5493] = 4411,
  [5494] = 4413,
  [5495] = 4416,
  [5496] = 4417,
  [5497] = 4418,
  [5498] = 4419,
  [5499] = 4420,
  [5500] = 4376,
  [5501] = 4410,
  [5502] = 2920,
  [5503] = 2204,
  [5504] = 4720,
  [5505] = 4422,
  [5506] = 4423,
  [5507] = 4426,
  [5508] = 4410,
  [5509] = 3987,
  [5510] = 4422,
  [5511] = 4423,
  [5512] = 4424,
  [5513] = 4430,
  [5514] = 4431,
  [5515] = 4432,
  [5516] = 4426,
  [5517] = 4433,
  [5518] = 4410,
  [5519] = 4434,
  [5520] = 4437,
  [5521] = 4438,
  [5522] = 4411,
  [5523] = 4413,
  [5524] = 4416,
  [5525] = 4417,
  [5526] = 4418,
  [5527] = 4419,
  [5528] = 4420,
  [5529] = 3717,
  [5530] = 3722,
  [5531] = 3727,
  [5532] = 4422,
  [5533] = 4423,
  [5534] = 4426,
  [5535] = 4410,
  [5536] = 3688,
  [5537] = 3709,
  [5538] = 3669,
  [5539] = 3640,
  [5540] = 3682,
  [5541] = 3695,
  [5542] = 3666,
  [5543] = 3721,
  [5544] = 3728,
  [5545] = 3633,
  [5546] = 3650,
  [5547] = 3665,
  [5548] = 3670,
  [5549] = 3683,
  [5550] = 3684,
  [5551] = 3686,
  [5552] = 3687,
  [5553] = 4422,
  [5554] = 4423,
  [5555] = 4426,
  [5556] = 4410,
  [5557] = 3690,
  [5558] = 3693,
  [5559] = 3712,
  [5560] = 4391,
  [5561] = 3637,
  [5562] = 3672,
  [5563] = 3716,
  [5564] = 3630,
  [5565] = 3634,
  [5566] = 3642,
  [5567] = 3649,
  [5568] = 3659,
  [5569] = 3661,
  [5570] = 3663,
  [5571] = 3668,
  [5572] = 3675,
  [5573] = 3676,
  [5574] = 3691,
  [5575] = 3711,
  [5576] = 3713,
  [5577] = 3714,
  [5578] = 3723,
  [5579] = 3730,
  [5580] = 3636,
  [5581] = 3987,
  [5582] = 3641,
  [5583] = 3645,
  [5584] = 3656,
  [5585] = 3657,
  [5586] = 3660,
  [5587] = 3662,
  [5588] = 3671,
  [5589] = 3674,
  [5590] = 5434,
  [5591] = 3679,
  [5592] = 4422,
  [5593] = 4423,
  [5594] = 4424,
  [5595] = 4430,
  [5596] = 4431,
  [5597] = 4432,
  [5598] = 4426,
  [5599] = 4433,
  [5600] = 4376,
  [5601] = 4410,
  [5602] = 4434,
  [5603] = 4437,
  [5604] = 4438,
  [5605] = 3685,
  [5606] = 4392,
  [5607] = 3701,
  [5608] = 4450,
  [5609] = 4409,
  [5610] = 4411,
  [5611] = 4408,
  [5612] = 4409,
  [5613] = 4478,
  [5614] = 4479,
  [5615] = 3689,
  [5616] = 4481,
  [5617] = 4482,
  [5618] = 3692,
  [5619] = 4419,
  [5620] = 4376,
  [5621] = 4450,
  [5622] = 4416,
  [5623] = 3696,
  [5624] = 4417,
  [5625] = 3987,
  [5626] = 4563,
  [5627] = 4376,
  [5628] = 4418,
  [5629] = 3699,
  [5630] = 4419,
  [5631] = 3700,
  [5632] = 3703,
  [5633] = 4420,
  [5634] = 3705,
  [5635] = 3667,
  [5636] = 4424,
  [5637] = 4408,
  [5638] = 4409,
  [5639] = 3708,
  [5640] = 4408,
  [5641] = 4409,
  [5642] = 4411,
  [5643] = 4413,
  [5644] = 4416,
  [5645] = 4417,
  [5646] = 4418,
  [5647] = 4419,
  [5648] = 4420,
  [5649] = 4376,
  [5650] = 4720,
  [5651] = 3719,
  [5652] = 4376,
  [5653] = 4450,
  [5654] = 4414,
  [5655] = 4424,
  [5656] = 4414,
  [5657] = 4450,
  [5658] = 4408,
  [5659] = 4430,
  [5660] = 4431,
  [5661] = 4433,
  [5662] = 4434,
  [5663] = 4437,
  [5664] = 4438,
  [5665] = 4409,
  [5666] = 4411,
  [5667] = 4413,
  [5668] = 4416,
  [5669] = 4417,
  [5670] = 4418,
  [5671] = 4419,
  [5672] = 4420,
  [5673] = 4376,
  [5674] = 3653,
  [5675] = 4408,
  [5676] = 4414,
  [5677] = 4410,
  [5678] = 4391,
  [5679] = 4414,
  [5680] = 4392,
  [5681] = 4409,
  [5682] = 4391,
  [5683] = 4411,
  [5684] = 4424,
  [5685] = 4413,
  [5686] = 4408,
  [5687] = 4430,
  [5688] = 4431,
  [5689] = 4432,
  [5690] = 4433,
  [5691] = 4434,
  [5692] = 4437,
  [5693] = 4438,
  [5694] = 4409,
  [5695] = 4411,
  [5696] = 4413,
  [5697] = 4416,
  [5698] = 4417,
  [5699] = 4418,
  [5700] = 4419,
  [5701] = 4420,
  [5702] = 4376,
  [5703] = 4416,
  [5704] = 4417,
  [5705] = 4392,
  [5706] = 4418,
  [5707] = 4419,
  [5708] = 4420,
  [5709] = 4424,
  [5710] = 4391,
  [5711] = 4414,
  [5712] = 4392,
  [5713] = 4450,
  [5714] = 4450,
  [5715] = 4424,
  [5716] = 4422,
  [5717] = 4423,
  [5718] = 4424,
  [5719] = 4426,
  [5720] = 3987,
  [5721] = 4563,
  [5722] = 4391,
  [5723] = 4392,
  [5724] = 4450,
  [5725] = 4424,
  [5726] = 4376,
  [5727] = 4450,
  [5728] = 4450,
  [5729] = 4450,
  [5730] = 3729,
  [5731] = 3638,
  [5732] = 4414,
  [5733] = 4408,
  [5734] = 4430,
  [5735] = 4431,
  [5736] = 4432,
  [5737] = 4433,
  [5738] = 4434,
  [5739] = 4437,
  [5740] = 4438,
  [5741] = 4409,
  [5742] = 4411,
  [5743] = 4413,
  [5744] = 4086,
  [5745] = 4416,
  [5746] = 4417,
  [5747] = 4720,
  [5748] = 4418,
  [5749] = 4419,
  [5750] = 4420,
  [5751] = 3720,
  [5752] = 5434,
  [5753] = 4477,
  [5754] = 2805,
  [5755] = 4477,
  [5756] = 4478,
  [5757] = 4479,
  [5758] = 4481,
  [5759] = 4482,
  [5760] = 4422,
  [5761] = 4423,
  [5762] = 4424,
  [5763] = 4430,
  [5764] = 4431,
  [5765] = 4432,
  [5766] = 4426,
  [5767] = 4433,
  [5768] = 4410,
  [5769] = 4434,
  [5770] = 4437,
  [5771] = 4438,
  [5772] = 4083,
  [5773] = 3966,
  [5774] = 3981,
  [5775] = 3983,
  [5776] = 4411,
  [5777] = 4091,
  [5778] = 4477,
  [5779] = 4478,
  [5780] = 4479,
  [5781] = 4481,
  [5782] = 4482,
  [5783] = 4413,
  [5784] = 4035,
  [5785] = 4040,
  [5786] = 4416,
  [5787] = 4417,
  [5788] = 4418,
  [5789] = 4413,
  [5790] = 4408,
  [5791] = 5791,
  [5792] = 4376,
  [5793] = 4720,
  [5794] = 5794,
  [5795] = 4450,
  [5796] = 5796,
  [5797] = 4422,
  [5798] = 4423,
  [5799] = 4430,
  [5800] = 4431,
  [5801] = 4432,
  [5802] = 4426,
  [5803] = 4433,
  [5804] = 4434,
  [5805] = 4437,
  [5806] = 4438,
  [5807] = 4477,
  [5808] = 4450,
  [5809] = 4416,
  [5810] = 4408,
  [5811] = 4410,
  [5812] = 4409,
  [5813] = 4411,
  [5814] = 4413,
  [5815] = 4416,
  [5816] = 4417,
  [5817] = 4418,
  [5818] = 4419,
  [5819] = 4420,
  [5820] = 4376,
  [5821] = 5821,
  [5822] = 5822,
  [5823] = 4417,
  [5824] = 4416,
  [5825] = 4418,
  [5826] = 5794,
  [5827] = 4422,
  [5828] = 4419,
  [5829] = 4423,
  [5830] = 4424,
  [5831] = 4430,
  [5832] = 4431,
  [5833] = 5796,
  [5834] = 4432,
  [5835] = 4478,
  [5836] = 4479,
  [5837] = 4426,
  [5838] = 4420,
  [5839] = 5839,
  [5840] = 4433,
  [5841] = 4422,
  [5842] = 4423,
  [5843] = 4430,
  [5844] = 4431,
  [5845] = 4432,
  [5846] = 4426,
  [5847] = 4433,
  [5848] = 4434,
  [5849] = 4437,
  [5850] = 4438,
  [5851] = 4410,
  [5852] = 4434,
  [5853] = 4437,
  [5854] = 4438,
  [5855] = 4408,
  [5856] = 4410,
  [5857] = 4409,
  [5858] = 4411,
  [5859] = 4413,
  [5860] = 4416,
  [5861] = 4417,
  [5862] = 4418,
  [5863] = 4419,
  [5864] = 4420,
  [5865] = 4376,
  [5866] = 5866,
  [5867] = 5867,
  [5868] = 5868,
  [5869] = 5869,
  [5870] = 5839,
  [5871] = 5871,
  [5872] = 5794,
  [5873] = 4408,
  [5874] = 5796,
  [5875] = 5796,
  [5876] = 4422,
  [5877] = 4423,
  [5878] = 4430,
  [5879] = 4431,
  [5880] = 4432,
  [5881] = 4426,
  [5882] = 4433,
  [5883] = 4434,
  [5884] = 4437,
  [5885] = 4438,
  [5886] = 4481,
  [5887] = 5821,
  [5888] = 4410,
  [5889] = 4409,
  [5890] = 4411,
  [5891] = 4413,
  [5892] = 4416,
  [5893] = 4417,
  [5894] = 4418,
  [5895] = 4419,
  [5896] = 4420,
  [5897] = 4376,
  [5898] = 4482,
  [5899] = 4422,
  [5900] = 5796,
  [5901] = 4423,
  [5902] = 4424,
  [5903] = 5796,
  [5904] = 4430,
  [5905] = 5839,
  [5906] = 5796,
  [5907] = 4431,
  [5908] = 5466,
  [5909] = 5796,
  [5910] = 4432,
  [5911] = 5796,
  [5912] = 4426,
  [5913] = 4433,
  [5914] = 4434,
  [5915] = 4437,
  [5916] = 5916,
  [5917] = 4408,
  [5918] = 4438,
  [5919] = 5794,
  [5920] = 5920,
  [5921] = 5794,
  [5922] = 4422,
  [5923] = 4423,
  [5924] = 4424,
  [5925] = 4430,
  [5926] = 4431,
  [5927] = 4432,
  [5928] = 4426,
  [5929] = 4433,
  [5930] = 2805,
  [5931] = 4420,
  [5932] = 4409,
  [5933] = 4070,
  [5934] = 5796,
  [5935] = 5935,
  [5936] = 2992,
  [5937] = 3015,
  [5938] = 4422,
  [5939] = 4423,
  [5940] = 4430,
  [5941] = 4431,
  [5942] = 4432,
  [5943] = 4426,
  [5944] = 4433,
  [5945] = 4434,
  [5946] = 4437,
  [5947] = 4438,
  [5948] = 5796,
  [5949] = 5949,
  [5950] = 4410,
  [5951] = 4434,
  [5952] = 4437,
  [5953] = 4438,
  [5954] = 4411,
  [5955] = 5955,
  [5956] = 4413,
  [5957] = 5821,
  [5958] = 5822,
  [5959] = 4408,
  [5960] = 4410,
  [5961] = 4409,
  [5962] = 4411,
  [5963] = 4413,
  [5964] = 4416,
  [5965] = 4417,
  [5966] = 4418,
  [5967] = 4419,
  [5968] = 4420,
  [5969] = 4376,
  [5970] = 4413,
  [5971] = 5971,
  [5972] = 5871,
  [5973] = 5920,
  [5974] = 5974,
  [5975] = 5796,
  [5976] = 4416,
  [5977] = 4411,
  [5978] = 5949,
  [5979] = 5822,
  [5980] = 5839,
  [5981] = 4417,
  [5982] = 5794,
  [5983] = 5796,
  [5984] = 4417,
  [5985] = 4408,
  [5986] = 4409,
  [5987] = 5796,
  [5988] = 4422,
  [5989] = 4423,
  [5990] = 4430,
  [5991] = 4431,
  [5992] = 5871,
  [5993] = 5920,
  [5994] = 4432,
  [5995] = 4426,
  [5996] = 4433,
  [5997] = 4434,
  [5998] = 4437,
  [5999] = 4438,
  [6000] = 6000,
  [6001] = 4376,
  [6002] = 4450,
  [6003] = 5796,
  [6004] = 4418,
  [6005] = 4408,
  [6006] = 4410,
  [6007] = 4409,
  [6008] = 4411,
  [6009] = 4413,
  [6010] = 4416,
  [6011] = 4417,
  [6012] = 4418,
  [6013] = 4419,
  [6014] = 4420,
  [6015] = 4376,
  [6016] = 4419,
  [6017] = 5821,
  [6018] = 5822,
  [6019] = 4563,
  [6020] = 2978,
  [6021] = 4418,
  [6022] = 4720,
  [6023] = 4410,
  [6024] = 5796,
  [6025] = 4414,
  [6026] = 4419,
  [6027] = 4720,
  [6028] = 5794,
  [6029] = 4420,
  [6030] = 5871,
  [6031] = 5920,
  [6032] = 5974,
  [6033] = 6033,
  [6034] = 5796,
  [6035] = 6035,
  [6036] = 6036,
  [6037] = 5796,
  [6038] = 4414,
  [6039] = 5974,
  [6040] = 4424,
  [6041] = 4409,
  [6042] = 4450,
  [6043] = 4563,
  [6044] = 4411,
  [6045] = 4376,
  [6046] = 5796,
  [6047] = 4414,
  [6048] = 4424,
  [6049] = 4450,
  [6050] = 5796,
  [6051] = 6051,
  [6052] = 5796,
  [6053] = 4424,
  [6054] = 4450,
  [6055] = 5796,
  [6056] = 4414,
  [6057] = 4424,
  [6058] = 4450,
  [6059] = 5796,
  [6060] = 4414,
  [6061] = 4424,
  [6062] = 4450,
  [6063] = 5916,
  [6064] = 4414,
  [6065] = 3586,
  [6066] = 6066,
  [6067] = 6067,
  [6068] = 4422,
  [6069] = 4423,
  [6070] = 4430,
  [6071] = 4431,
  [6072] = 4432,
  [6073] = 4426,
  [6074] = 4433,
  [6075] = 3987,
  [6076] = 5974,
  [6077] = 5839,
  [6078] = 4434,
  [6079] = 4437,
  [6080] = 4438,
  [6081] = 6000,
  [6082] = 5796,
  [6083] = 4424,
  [6084] = 4450,
  [6085] = 5794,
  [6086] = 4408,
  [6087] = 4410,
  [6088] = 4409,
  [6089] = 4411,
  [6090] = 4413,
  [6091] = 4416,
  [6092] = 4417,
  [6093] = 4563,
  [6094] = 4418,
  [6095] = 6000,
  [6096] = 6000,
  [6097] = 4419,
  [6098] = 4420,
  [6099] = 4376,
  [6100] = 4413,
  [6101] = 4477,
  [6102] = 4478,
  [6103] = 4479,
  [6104] = 4481,
  [6105] = 4482,
  [6106] = 5796,
  [6107] = 4477,
  [6108] = 4478,
  [6109] = 4479,
  [6110] = 4481,
  [6111] = 4482,
  [6112] = 4477,
  [6113] = 4478,
  [6114] = 4479,
  [6115] = 4481,
  [6116] = 4482,
  [6117] = 5839,
  [6118] = 4477,
  [6119] = 4478,
  [6120] = 4479,
  [6121] = 4481,
  [6122] = 4482,
  [6123] = 5949,
  [6124] = 5949,
  [6125] = 6125,
  [6126] = 4438,
  [6127] = 6127,
  [6128] = 4438,
  [6129] = 5916,
  [6130] = 6130,
  [6131] = 6131,
  [6132] = 4419,
  [6133] = 2805,
  [6134] = 4420,
  [6135] = 4426,
  [6136] = 4433,
  [6137] = 6137,
  [6138] = 4434,
  [6139] = 2842,
  [6140] = 4437,
  [6141] = 4438,
  [6142] = 5955,
  [6143] = 4417,
  [6144] = 4392,
  [6145] = 6145,
  [6146] = 3989,
  [6147] = 3990,
  [6148] = 4391,
  [6149] = 3628,
  [6150] = 4423,
  [6151] = 4392,
  [6152] = 6152,
  [6153] = 4376,
  [6154] = 4450,
  [6155] = 6155,
  [6156] = 4418,
  [6157] = 4720,
  [6158] = 2840,
  [6159] = 4563,
  [6160] = 4422,
  [6161] = 4424,
  [6162] = 6162,
  [6163] = 2805,
  [6164] = 4563,
  [6165] = 6165,
  [6166] = 6166,
  [6167] = 6167,
  [6168] = 4563,
  [6169] = 4391,
  [6170] = 6166,
  [6171] = 6171,
  [6172] = 4430,
  [6173] = 6173,
  [6174] = 4392,
  [6175] = 6173,
  [6176] = 4376,
  [6177] = 4450,
  [6178] = 4431,
  [6179] = 6179,
  [6180] = 4432,
  [6181] = 2805,
  [6182] = 4408,
  [6183] = 4410,
  [6184] = 4720,
  [6185] = 6185,
  [6186] = 6130,
  [6187] = 4409,
  [6188] = 4411,
  [6189] = 4450,
  [6190] = 4413,
  [6191] = 4416,
  [6192] = 6192,
  [6193] = 4417,
  [6194] = 6194,
  [6195] = 6127,
  [6196] = 3987,
  [6197] = 4720,
  [6198] = 3987,
  [6199] = 4563,
  [6200] = 4391,
  [6201] = 6201,
  [6202] = 3015,
  [6203] = 4418,
  [6204] = 2992,
  [6205] = 6131,
  [6206] = 3015,
  [6207] = 6207,
  [6208] = 4419,
  [6209] = 6209,
  [6210] = 6210,
  [6211] = 6211,
  [6212] = 6212,
  [6213] = 4408,
  [6214] = 4430,
  [6215] = 4431,
  [6216] = 4432,
  [6217] = 4433,
  [6218] = 4434,
  [6219] = 4437,
  [6220] = 4438,
  [6221] = 2999,
  [6222] = 4420,
  [6223] = 6223,
  [6224] = 4416,
  [6225] = 4437,
  [6226] = 6210,
  [6227] = 4422,
  [6228] = 6228,
  [6229] = 5971,
  [6230] = 4720,
  [6231] = 5791,
  [6232] = 4423,
  [6233] = 6233,
  [6234] = 6234,
  [6235] = 6152,
  [6236] = 6162,
  [6237] = 3987,
  [6238] = 4563,
  [6239] = 4376,
  [6240] = 4424,
  [6241] = 3989,
  [6242] = 3990,
  [6243] = 4410,
  [6244] = 4409,
  [6245] = 4411,
  [6246] = 4413,
  [6247] = 4430,
  [6248] = 6209,
  [6249] = 4416,
  [6250] = 4417,
  [6251] = 4720,
  [6252] = 4418,
  [6253] = 4419,
  [6254] = 4422,
  [6255] = 4423,
  [6256] = 4424,
  [6257] = 4426,
  [6258] = 4420,
  [6259] = 6212,
  [6260] = 4426,
  [6261] = 2999,
  [6262] = 4431,
  [6263] = 6263,
  [6264] = 4408,
  [6265] = 4410,
  [6266] = 4409,
  [6267] = 6233,
  [6268] = 6234,
  [6269] = 6269,
  [6270] = 4411,
  [6271] = 4413,
  [6272] = 6233,
  [6273] = 6234,
  [6274] = 4416,
  [6275] = 4417,
  [6276] = 4418,
  [6277] = 4432,
  [6278] = 3987,
  [6279] = 6279,
  [6280] = 6234,
  [6281] = 4433,
  [6282] = 4408,
  [6283] = 4419,
  [6284] = 6284,
  [6285] = 6035,
  [6286] = 6233,
  [6287] = 6210,
  [6288] = 6234,
  [6289] = 4420,
  [6290] = 4391,
  [6291] = 6234,
  [6292] = 4434,
  [6293] = 4437,
  [6294] = 4392,
  [6295] = 4410,
  [6296] = 6210,
  [6297] = 4376,
  [6298] = 4450,
  [6299] = 4422,
  [6300] = 4423,
  [6301] = 4424,
  [6302] = 4430,
  [6303] = 4431,
  [6304] = 4563,
  [6305] = 4432,
  [6306] = 4426,
  [6307] = 4433,
  [6308] = 4409,
  [6309] = 4411,
  [6310] = 4434,
  [6311] = 4413,
  [6312] = 4720,
  [6313] = 6313,
  [6314] = 4563,
  [6315] = 4416,
  [6316] = 4422,
  [6317] = 6317,
  [6318] = 4423,
  [6319] = 4424,
  [6320] = 4430,
  [6321] = 4431,
  [6322] = 4432,
  [6323] = 4426,
  [6324] = 4433,
  [6325] = 4410,
  [6326] = 4434,
  [6327] = 4437,
  [6328] = 4438,
  [6329] = 4417,
  [6330] = 4411,
  [6331] = 4720,
  [6332] = 4413,
  [6333] = 4416,
  [6334] = 4417,
  [6335] = 4418,
  [6336] = 4419,
  [6337] = 4420,
  [6338] = 4418,
  [6339] = 4419,
  [6340] = 4420,
  [6341] = 6317,
  [6342] = 6313,
  [6343] = 6343,
  [6344] = 2999,
  [6345] = 6345,
  [6346] = 6346,
  [6347] = 6279,
  [6348] = 6317,
  [6349] = 6349,
  [6350] = 6317,
  [6351] = 6351,
  [6352] = 6352,
  [6353] = 6353,
  [6354] = 6317,
  [6355] = 6355,
  [6356] = 4409,
  [6357] = 6357,
  [6358] = 6317,
  [6359] = 6359,
  [6360] = 6317,
  [6361] = 6317,
  [6362] = 6317,
  [6363] = 6317,
  [6364] = 6317,
  [6365] = 6365,
  [6366] = 6317,
  [6367] = 6317,
  [6368] = 6317,
  [6369] = 6317,
  [6370] = 6317,
  [6371] = 6317,
  [6372] = 6317,
  [6373] = 6317,
  [6374] = 6317,
  [6375] = 6317,
  [6376] = 6345,
  [6377] = 6346,
  [6378] = 6317,
  [6379] = 6353,
  [6380] = 6355,
  [6381] = 6317,
  [6382] = 6382,
  [6383] = 6383,
  [6384] = 6384,
  [6385] = 6385,
  [6386] = 6317,
  [6387] = 6387,
  [6388] = 6388,
  [6389] = 6352,
  [6390] = 6351,
  [6391] = 3987,
  [6392] = 6392,
  [6393] = 5466,
  [6394] = 6317,
  [6395] = 4430,
  [6396] = 4431,
  [6397] = 4432,
  [6398] = 4433,
  [6399] = 4434,
  [6400] = 4437,
  [6401] = 4438,
  [6402] = 6392,
  [6403] = 4411,
  [6404] = 6343,
  [6405] = 4413,
  [6406] = 4416,
  [6407] = 6407,
  [6408] = 6408,
  [6409] = 4417,
  [6410] = 6410,
  [6411] = 4418,
  [6412] = 4419,
  [6413] = 6413,
  [6414] = 4420,
  [6415] = 6388,
  [6416] = 6317,
  [6417] = 6417,
  [6418] = 4408,
  [6419] = 6392,
  [6420] = 6420,
  [6421] = 6421,
  [6422] = 6345,
  [6423] = 6384,
  [6424] = 4720,
  [6425] = 6385,
  [6426] = 4422,
  [6427] = 6317,
  [6428] = 4423,
  [6429] = 6429,
  [6430] = 6382,
  [6431] = 6431,
  [6432] = 6432,
  [6433] = 4424,
  [6434] = 4430,
  [6435] = 4431,
  [6436] = 4432,
  [6437] = 4426,
  [6438] = 4433,
  [6439] = 4410,
  [6440] = 4434,
  [6441] = 4437,
  [6442] = 4438,
  [6443] = 5466,
  [6444] = 4408,
  [6445] = 6317,
  [6446] = 4409,
  [6447] = 4409,
  [6448] = 4411,
  [6449] = 6383,
  [6450] = 6317,
  [6451] = 4413,
  [6452] = 6388,
  [6453] = 4416,
  [6454] = 6365,
  [6455] = 4417,
  [6456] = 6421,
  [6457] = 4408,
  [6458] = 6317,
  [6459] = 4409,
  [6460] = 6317,
  [6461] = 4720,
  [6462] = 6317,
  [6463] = 6317,
  [6464] = 4418,
  [6465] = 4419,
  [6466] = 6466,
  [6467] = 4720,
  [6468] = 6317,
  [6469] = 3987,
  [6470] = 4420,
  [6471] = 6392,
  [6472] = 6343,
  [6473] = 6473,
  [6474] = 4563,
  [6475] = 6407,
  [6476] = 6408,
  [6477] = 6413,
  [6478] = 6478,
  [6479] = 6479,
  [6480] = 6384,
  [6481] = 6429,
  [6482] = 6385,
  [6483] = 6431,
  [6484] = 6484,
  [6485] = 6313,
  [6486] = 6313,
  [6487] = 6317,
  [6488] = 3987,
  [6489] = 6392,
  [6490] = 4478,
  [6491] = 4479,
  [6492] = 6492,
  [6493] = 6343,
  [6494] = 4563,
  [6495] = 4481,
  [6496] = 4482,
  [6497] = 6407,
  [6498] = 6408,
  [6499] = 6413,
  [6500] = 6351,
  [6501] = 4422,
  [6502] = 6317,
  [6503] = 4423,
  [6504] = 4424,
  [6505] = 4430,
  [6506] = 4431,
  [6507] = 4432,
  [6508] = 4426,
  [6509] = 4433,
  [6510] = 4410,
  [6511] = 4434,
  [6512] = 4437,
  [6513] = 4438,
  [6514] = 6352,
  [6515] = 4411,
  [6516] = 4413,
  [6517] = 2920,
  [6518] = 4416,
  [6519] = 4376,
  [6520] = 4417,
  [6521] = 4450,
  [6522] = 6317,
  [6523] = 3987,
  [6524] = 6392,
  [6525] = 4418,
  [6526] = 4419,
  [6527] = 4420,
  [6528] = 4563,
  [6529] = 6359,
  [6530] = 6359,
  [6531] = 4376,
  [6532] = 4450,
  [6533] = 6317,
  [6534] = 6351,
  [6535] = 6392,
  [6536] = 6429,
  [6537] = 6431,
  [6538] = 6538,
  [6539] = 6365,
  [6540] = 4408,
  [6541] = 6317,
  [6542] = 3987,
  [6543] = 6392,
  [6544] = 4563,
  [6545] = 6345,
  [6546] = 6546,
  [6547] = 4376,
  [6548] = 4450,
  [6549] = 6317,
  [6550] = 3987,
  [6551] = 6392,
  [6552] = 4563,
  [6553] = 6407,
  [6554] = 4376,
  [6555] = 4450,
  [6556] = 6317,
  [6557] = 6392,
  [6558] = 6346,
  [6559] = 6413,
  [6560] = 4376,
  [6561] = 4450,
  [6562] = 6317,
  [6563] = 6392,
  [6564] = 6408,
  [6565] = 6353,
  [6566] = 6566,
  [6567] = 6392,
  [6568] = 6392,
  [6569] = 6392,
  [6570] = 6392,
  [6571] = 6392,
  [6572] = 6572,
  [6573] = 6392,
  [6574] = 6355,
  [6575] = 6429,
  [6576] = 6431,
  [6577] = 6392,
  [6578] = 6317,
  [6579] = 6432,
  [6580] = 2754,
  [6581] = 4720,
  [6582] = 6582,
  [6583] = 6351,
  [6584] = 4422,
  [6585] = 6352,
  [6586] = 5466,
  [6587] = 6359,
  [6588] = 6317,
  [6589] = 4423,
  [6590] = 4376,
  [6591] = 4424,
  [6592] = 4430,
  [6593] = 4431,
  [6594] = 4432,
  [6595] = 6420,
  [6596] = 6492,
  [6597] = 4422,
  [6598] = 4423,
  [6599] = 4424,
  [6600] = 4426,
  [6601] = 4410,
  [6602] = 6365,
  [6603] = 6473,
  [6604] = 4426,
  [6605] = 4408,
  [6606] = 4433,
  [6607] = 4410,
  [6608] = 4434,
  [6609] = 4437,
  [6610] = 4438,
  [6611] = 4411,
  [6612] = 6345,
  [6613] = 6346,
  [6614] = 6392,
  [6615] = 6353,
  [6616] = 6355,
  [6617] = 6382,
  [6618] = 6383,
  [6619] = 6384,
  [6620] = 6385,
  [6621] = 6382,
  [6622] = 4413,
  [6623] = 6317,
  [6624] = 6421,
  [6625] = 4416,
  [6626] = 4417,
  [6627] = 4418,
  [6628] = 6383,
  [6629] = 4419,
  [6630] = 4420,
  [6631] = 6384,
  [6632] = 6317,
  [6633] = 6392,
  [6634] = 4409,
  [6635] = 6385,
  [6636] = 4478,
  [6637] = 4479,
  [6638] = 4481,
  [6639] = 4482,
  [6640] = 6640,
  [6641] = 6420,
  [6642] = 6492,
  [6643] = 6473,
  [6644] = 4478,
  [6645] = 4479,
  [6646] = 4481,
  [6647] = 4482,
  [6648] = 4477,
  [6649] = 6388,
  [6650] = 6420,
  [6651] = 6492,
  [6652] = 6473,
  [6653] = 4408,
  [6654] = 6345,
  [6655] = 6384,
  [6656] = 6385,
  [6657] = 4478,
  [6658] = 4479,
  [6659] = 4481,
  [6660] = 4482,
  [6661] = 4422,
  [6662] = 2855,
  [6663] = 4477,
  [6664] = 6492,
  [6665] = 6317,
  [6666] = 4423,
  [6667] = 4424,
  [6668] = 4430,
  [6669] = 4431,
  [6670] = 4432,
  [6671] = 4426,
  [6672] = 4477,
  [6673] = 6492,
  [6674] = 4433,
  [6675] = 4410,
  [6676] = 6676,
  [6677] = 4434,
  [6678] = 4437,
  [6679] = 4477,
  [6680] = 4438,
  [6681] = 4409,
  [6682] = 4411,
  [6683] = 6683,
  [6684] = 6421,
  [6685] = 4450,
  [6686] = 6686,
  [6687] = 6317,
  [6688] = 4720,
  [6689] = 4413,
  [6690] = 6410,
  [6691] = 2999,
  [6692] = 6692,
  [6693] = 2842,
  [6694] = 6692,
  [6695] = 6692,
  [6696] = 3737,
  [6697] = 6692,
  [6698] = 6698,
  [6699] = 3740,
  [6700] = 6692,
  [6701] = 6692,
  [6702] = 3786,
  [6703] = 6692,
  [6704] = 6692,
  [6705] = 6692,
  [6706] = 6692,
  [6707] = 6692,
  [6708] = 6692,
  [6709] = 6692,
  [6710] = 2743,
  [6711] = 2744,
  [6712] = 2999,
  [6713] = 6692,
  [6714] = 2999,
  [6715] = 6692,
  [6716] = 2871,
  [6717] = 6692,
  [6718] = 6692,
  [6719] = 6692,
  [6720] = 2203,
  [6721] = 2840,
  [6722] = 6692,
  [6723] = 6692,
  [6724] = 2874,
  [6725] = 2999,
  [6726] = 6692,
  [6727] = 6692,
  [6728] = 2999,
  [6729] = 6692,
  [6730] = 2999,
  [6731] = 2855,
  [6732] = 6692,
  [6733] = 2869,
  [6734] = 6692,
  [6735] = 6692,
  [6736] = 6692,
  [6737] = 2204,
  [6738] = 6738,
  [6739] = 3779,
  [6740] = 6692,
  [6741] = 6692,
  [6742] = 6692,
  [6743] = 2855,
  [6744] = 6692,
  [6745] = 3746,
  [6746] = 2879,
  [6747] = 6692,
  [6748] = 6279,
  [6749] = 6749,
  [6750] = 6750,
  [6751] = 6751,
  [6752] = 6752,
  [6753] = 6753,
  [6754] = 6754,
  [6755] = 6279,
  [6756] = 6756,
  [6757] = 6757,
  [6758] = 6758,
  [6759] = 2999,
  [6760] = 6760,
  [6761] = 6761,
  [6762] = 6698,
  [6763] = 2999,
  [6764] = 2999,
  [6765] = 2999,
  [6766] = 6766,
  [6767] = 6767,
  [6768] = 6760,
  [6769] = 2920,
  [6770] = 2874,
  [6771] = 2992,
  [6772] = 2871,
  [6773] = 6766,
  [6774] = 2879,
  [6775] = 2827,
  [6776] = 2869,
  [6777] = 6777,
  [6778] = 6778,
  [6779] = 6779,
  [6780] = 6778,
  [6781] = 6781,
  [6782] = 6782,
  [6783] = 6781,
  [6784] = 6784,
  [6785] = 6466,
  [6786] = 6784,
  [6787] = 6778,
  [6788] = 6779,
  [6789] = 6778,
  [6790] = 6790,
  [6791] = 6791,
  [6792] = 6782,
  [6793] = 6781,
  [6794] = 6784,
  [6795] = 2748,
  [6796] = 6781,
  [6797] = 6797,
  [6798] = 6779,
  [6799] = 6799,
  [6800] = 6799,
  [6801] = 6779,
  [6802] = 6802,
  [6803] = 6778,
  [6804] = 6804,
  [6805] = 6805,
  [6806] = 6781,
  [6807] = 6807,
  [6808] = 6779,
  [6809] = 6809,
  [6810] = 6810,
  [6811] = 6811,
  [6812] = 6811,
  [6813] = 6813,
  [6814] = 6814,
  [6815] = 6815,
  [6816] = 6809,
  [6817] = 6811,
  [6818] = 6818,
  [6819] = 6818,
  [6820] = 6820,
  [6821] = 6821,
  [6822] = 6822,
  [6823] = 6823,
  [6824] = 6824,
  [6825] = 6811,
  [6826] = 2962,
  [6827] = 6811,
  [6828] = 6809,
  [6829] = 6829,
  [6830] = 6829,
  [6831] = 6831,
  [6832] = 6829,
  [6833] = 6833,
  [6834] = 6834,
  [6835] = 6835,
  [6836] = 6836,
  [6837] = 6829,
  [6838] = 6829,
  [6839] = 6831,
  [6840] = 6829,
  [6841] = 6829,
  [6842] = 6829,
  [6843] = 6831,
  [6844] = 6844,
  [6845] = 6829,
  [6846] = 6829,
  [6847] = 6836,
  [6848] = 6829,
  [6849] = 6835,
  [6850] = 6850,
  [6851] = 6851,
  [6852] = 6835,
  [6853] = 6829,
  [6854] = 6854,
  [6855] = 6836,
  [6856] = 6829,
  [6857] = 6857,
  [6858] = 6829,
  [6859] = 6829,
  [6860] = 6829,
  [6861] = 6829,
  [6862] = 6854,
  [6863] = 6829,
  [6864] = 6864,
  [6865] = 6865,
  [6866] = 6866,
  [6867] = 6829,
  [6868] = 6844,
  [6869] = 6829,
  [6870] = 6854,
  [6871] = 6829,
  [6872] = 6829,
  [6873] = 6829,
  [6874] = 6829,
  [6875] = 6875,
  [6876] = 6829,
  [6877] = 6829,
  [6878] = 6829,
  [6879] = 6844,
  [6880] = 6854,
  [6881] = 6829,
  [6882] = 6829,
  [6883] = 6829,
  [6884] = 6829,
  [6885] = 6831,
  [6886] = 6829,
  [6887] = 6829,
  [6888] = 6829,
  [6889] = 3015,
  [6890] = 6831,
  [6891] = 6829,
  [6892] = 6829,
  [6893] = 6829,
  [6894] = 6854,
  [6895] = 6829,
  [6896] = 6829,
  [6897] = 6833,
  [6898] = 6829,
  [6899] = 6829,
  [6900] = 6829,
  [6901] = 6901,
  [6902] = 6857,
  [6903] = 6829,
  [6904] = 6904,
  [6905] = 6829,
  [6906] = 6829,
  [6907] = 6829,
  [6908] = 6829,
  [6909] = 6829,
  [6910] = 2999,
  [6911] = 2999,
  [6912] = 2999,
  [6913] = 2999,
  [6914] = 2999,
  [6915] = 2999,
  [6916] = 2999,
  [6917] = 2999,
  [6918] = 2999,
  [6919] = 6919,
  [6920] = 2999,
  [6921] = 2999,
  [6922] = 2999,
  [6923] = 6923,
  [6924] = 6924,
  [6925] = 2999,
  [6926] = 2999,
  [6927] = 2999,
  [6928] = 2999,
  [6929] = 6929,
  [6930] = 2963,
  [6931] = 6929,
  [6932] = 2999,
  [6933] = 2999,
  [6934] = 2999,
  [6935] = 6935,
  [6936] = 6936,
  [6937] = 2999,
  [6938] = 6938,
  [6939] = 6939,
  [6940] = 2963,
  [6941] = 2999,
  [6942] = 6938,
  [6943] = 2999,
  [6944] = 2963,
  [6945] = 6945,
  [6946] = 6935,
  [6947] = 6947,
  [6948] = 2999,
  [6949] = 6929,
  [6950] = 2999,
  [6951] = 6935,
  [6952] = 6929,
  [6953] = 2963,
  [6954] = 6935,
  [6955] = 2999,
  [6956] = 6956,
  [6957] = 6956,
  [6958] = 2855,
  [6959] = 6959,
  [6960] = 6960,
  [6961] = 6961,
  [6962] = 6956,
  [6963] = 2855,
  [6964] = 6964,
  [6965] = 6960,
  [6966] = 6961,
  [6967] = 6956,
  [6968] = 2855,
  [6969] = 6960,
  [6970] = 3628,
  [6971] = 6961,
  [6972] = 6972,
  [6973] = 6956,
  [6974] = 2855,
  [6975] = 6960,
  [6976] = 6961,
  [6977] = 6961,
  [6978] = 6978,
  [6979] = 6956,
  [6980] = 2855,
  [6981] = 6960,
  [6982] = 6961,
  [6983] = 6936,
  [6984] = 6956,
  [6985] = 2855,
  [6986] = 6960,
  [6987] = 6961,
  [6988] = 6956,
  [6989] = 2855,
  [6990] = 6960,
  [6991] = 6961,
  [6992] = 6956,
  [6993] = 2855,
  [6994] = 6960,
  [6995] = 6961,
  [6996] = 6956,
  [6997] = 2855,
  [6998] = 6960,
  [6999] = 6956,
  [7000] = 6961,
  [7001] = 6956,
  [7002] = 2855,
  [7003] = 6960,
  [7004] = 6961,
  [7005] = 2855,
  [7006] = 6956,
  [7007] = 2855,
  [7008] = 6960,
  [7009] = 6961,
  [7010] = 6956,
  [7011] = 2855,
  [7012] = 6960,
  [7013] = 6961,
  [7014] = 6956,
  [7015] = 2855,
  [7016] = 6960,
  [7017] = 6961,
  [7018] = 6956,
  [7019] = 2855,
  [7020] = 6960,
  [7021] = 6961,
  [7022] = 6956,
  [7023] = 2855,
  [7024] = 6960,
  [7025] = 6961,
  [7026] = 7026,
  [7027] = 6956,
  [7028] = 2855,
  [7029] = 6960,
  [7030] = 6961,
  [7031] = 6956,
  [7032] = 6956,
  [7033] = 2855,
  [7034] = 6960,
  [7035] = 6961,
  [7036] = 6956,
  [7037] = 2855,
  [7038] = 6960,
  [7039] = 6961,
  [7040] = 6956,
  [7041] = 2855,
  [7042] = 6960,
  [7043] = 6961,
  [7044] = 6956,
  [7045] = 2855,
  [7046] = 6960,
  [7047] = 6961,
  [7048] = 2855,
  [7049] = 6956,
  [7050] = 2855,
  [7051] = 6960,
  [7052] = 6961,
  [7053] = 6956,
  [7054] = 2855,
  [7055] = 6960,
  [7056] = 6961,
  [7057] = 6956,
  [7058] = 2855,
  [7059] = 6960,
  [7060] = 6961,
  [7061] = 6956,
  [7062] = 2855,
  [7063] = 6960,
  [7064] = 6961,
  [7065] = 6956,
  [7066] = 2855,
  [7067] = 6960,
  [7068] = 6961,
  [7069] = 6956,
  [7070] = 2855,
  [7071] = 6960,
  [7072] = 6960,
  [7073] = 6956,
  [7074] = 2855,
  [7075] = 6960,
  [7076] = 6961,
  [7077] = 6956,
  [7078] = 2855,
  [7079] = 6960,
  [7080] = 6961,
  [7081] = 6956,
  [7082] = 2855,
  [7083] = 6960,
  [7084] = 6961,
  [7085] = 6956,
  [7086] = 2855,
  [7087] = 6960,
  [7088] = 6961,
  [7089] = 6959,
  [7090] = 6978,
  [7091] = 6956,
  [7092] = 2855,
  [7093] = 6960,
  [7094] = 6961,
  [7095] = 6956,
  [7096] = 2855,
  [7097] = 6960,
  [7098] = 6961,
  [7099] = 6956,
  [7100] = 2855,
  [7101] = 6960,
  [7102] = 6961,
  [7103] = 6960,
  [7104] = 7104,
  [7105] = 6956,
  [7106] = 2855,
  [7107] = 6959,
  [7108] = 6960,
  [7109] = 6978,
  [7110] = 7026,
  [7111] = 6960,
  [7112] = 7104,
  [7113] = 6961,
  [7114] = 6961,
  [7115] = 7115,
  [7116] = 6960,
  [7117] = 6961,
  [7118] = 6972,
  [7119] = 6959,
  [7120] = 6956,
  [7121] = 2855,
  [7122] = 6960,
  [7123] = 6961,
  [7124] = 6961,
  [7125] = 6956,
  [7126] = 6960,
  [7127] = 7026,
  [7128] = 6956,
  [7129] = 6961,
  [7130] = 2855,
  [7131] = 6956,
  [7132] = 2855,
  [7133] = 6960,
  [7134] = 6959,
  [7135] = 6961,
  [7136] = 6978,
  [7137] = 6960,
  [7138] = 7115,
  [7139] = 6956,
  [7140] = 6961,
  [7141] = 6960,
  [7142] = 6961,
  [7143] = 6956,
  [7144] = 2855,
  [7145] = 6960,
  [7146] = 6961,
  [7147] = 6956,
  [7148] = 7148,
  [7149] = 6960,
  [7150] = 6961,
  [7151] = 6956,
  [7152] = 2855,
  [7153] = 6960,
  [7154] = 6961,
  [7155] = 6956,
  [7156] = 2855,
  [7157] = 6960,
  [7158] = 6961,
  [7159] = 6956,
  [7160] = 2855,
  [7161] = 6960,
  [7162] = 6961,
  [7163] = 6956,
  [7164] = 7164,
  [7165] = 2855,
  [7166] = 6961,
  [7167] = 7167,
  [7168] = 7168,
  [7169] = 7169,
  [7170] = 7168,
  [7171] = 7171,
  [7172] = 7172,
  [7173] = 7172,
  [7174] = 7174,
  [7175] = 7172,
  [7176] = 7168,
  [7177] = 7177,
  [7178] = 7178,
  [7179] = 7172,
  [7180] = 7180,
  [7181] = 7181,
  [7182] = 7174,
  [7183] = 7172,
  [7184] = 7178,
  [7185] = 7172,
  [7186] = 7181,
  [7187] = 7172,
  [7188] = 7172,
  [7189] = 7167,
  [7190] = 7172,
  [7191] = 7172,
  [7192] = 7172,
  [7193] = 7172,
  [7194] = 7194,
  [7195] = 7172,
  [7196] = 7168,
  [7197] = 7181,
  [7198] = 7172,
  [7199] = 7168,
  [7200] = 7200,
  [7201] = 7177,
  [7202] = 7172,
  [7203] = 7167,
  [7204] = 7167,
  [7205] = 7167,
  [7206] = 7206,
  [7207] = 7168,
  [7208] = 7208,
  [7209] = 7209,
  [7210] = 7172,
  [7211] = 7181,
  [7212] = 7168,
  [7213] = 7171,
  [7214] = 7172,
  [7215] = 7172,
  [7216] = 7172,
  [7217] = 7178,
  [7218] = 7168,
  [7219] = 7181,
  [7220] = 7172,
  [7221] = 7172,
  [7222] = 7172,
  [7223] = 7172,
  [7224] = 7172,
  [7225] = 7168,
  [7226] = 7168,
  [7227] = 7172,
  [7228] = 7181,
  [7229] = 7181,
  [7230] = 7168,
  [7231] = 7181,
  [7232] = 7232,
  [7233] = 7172,
  [7234] = 7177,
  [7235] = 7172,
  [7236] = 7172,
  [7237] = 7167,
  [7238] = 7181,
  [7239] = 7172,
  [7240] = 7172,
  [7241] = 7172,
  [7242] = 7171,
  [7243] = 7168,
  [7244] = 7181,
  [7245] = 7172,
  [7246] = 7181,
  [7247] = 7172,
  [7248] = 7172,
  [7249] = 7172,
  [7250] = 7172,
  [7251] = 7167,
  [7252] = 7181,
  [7253] = 7208,
  [7254] = 7172,
  [7255] = 7172,
  [7256] = 7172,
  [7257] = 7167,
  [7258] = 7172,
  [7259] = 7168,
  [7260] = 7181,
  [7261] = 7177,
  [7262] = 7172,
  [7263] = 7172,
  [7264] = 7172,
  [7265] = 7172,
  [7266] = 7174,
  [7267] = 7167,
  [7268] = 7181,
  [7269] = 7172,
  [7270] = 7168,
  [7271] = 7172,
  [7272] = 7181,
  [7273] = 7177,
  [7274] = 7172,
  [7275] = 7208,
  [7276] = 7172,
  [7277] = 7174,
  [7278] = 7278,
  [7279] = 7172,
  [7280] = 7172,
  [7281] = 7281,
  [7282] = 7172,
  [7283] = 7172,
  [7284] = 7177,
  [7285] = 7172,
  [7286] = 7172,
  [7287] = 7168,
  [7288] = 7174,
  [7289] = 7172,
  [7290] = 7172,
  [7291] = 3779,
  [7292] = 3786,
  [7293] = 7293,
  [7294] = 3737,
  [7295] = 7295,
  [7296] = 7296,
  [7297] = 7297,
  [7298] = 7298,
  [7299] = 3746,
  [7300] = 3740,
  [7301] = 7301,
  [7302] = 7302,
  [7303] = 7303,
  [7304] = 7304,
  [7305] = 7305,
  [7306] = 7302,
  [7307] = 7302,
  [7308] = 7302,
  [7309] = 7309,
  [7310] = 7310,
  [7311] = 7311,
  [7312] = 7312,
  [7313] = 7302,
  [7314] = 7314,
  [7315] = 7315,
  [7316] = 7316,
  [7317] = 7317,
  [7318] = 7318,
  [7319] = 7318,
  [7320] = 7320,
  [7321] = 7321,
  [7322] = 7316,
  [7323] = 7302,
  [7324] = 7320,
  [7325] = 7325,
  [7326] = 7326,
  [7327] = 7327,
  [7328] = 7321,
  [7329] = 7329,
  [7330] = 7330,
  [7331] = 7331,
  [7332] = 7314,
  [7333] = 7302,
  [7334] = 7302,
  [7335] = 7302,
  [7336] = 7302,
  [7337] = 7337,
  [7338] = 7338,
  [7339] = 7339,
  [7340] = 7340,
  [7341] = 7341,
  [7342] = 7302,
  [7343] = 7302,
  [7344] = 7327,
  [7345] = 7314,
  [7346] = 7325,
  [7347] = 7347,
  [7348] = 7312,
  [7349] = 7329,
  [7350] = 7338,
  [7351] = 7301,
  [7352] = 7317,
  [7353] = 7303,
  [7354] = 7304,
  [7355] = 7305,
  [7356] = 7311,
  [7357] = 7309,
  [7358] = 7310,
  [7359] = 7359,
  [7360] = 7302,
  [7361] = 7303,
  [7362] = 7315,
  [7363] = 7316,
  [7364] = 7317,
  [7365] = 7318,
  [7366] = 7320,
  [7367] = 7321,
  [7368] = 7329,
  [7369] = 7325,
  [7370] = 7326,
  [7371] = 7327,
  [7372] = 7372,
  [7373] = 7301,
  [7374] = 7374,
  [7375] = 7375,
  [7376] = 7315,
  [7377] = 7326,
  [7378] = 7302,
  [7379] = 7302,
  [7380] = 7314,
  [7381] = 7338,
  [7382] = 7312,
  [7383] = 7383,
  [7384] = 7309,
  [7385] = 7385,
  [7386] = 7386,
  [7387] = 7302,
  [7388] = 7341,
  [7389] = 7302,
  [7390] = 7305,
  [7391] = 7391,
  [7392] = 7302,
  [7393] = 7304,
  [7394] = 7394,
  [7395] = 7302,
  [7396] = 7396,
  [7397] = 7310,
  [7398] = 7302,
  [7399] = 7311,
  [7400] = 7400,
  [7401] = 7401,
  [7402] = 7402,
  [7403] = 7403,
  [7404] = 7404,
  [7405] = 7405,
  [7406] = 7406,
  [7407] = 7407,
  [7408] = 7408,
  [7409] = 7409,
  [7410] = 7410,
  [7411] = 7411,
  [7412] = 7412,
  [7413] = 7413,
  [7414] = 7413,
  [7415] = 7413,
  [7416] = 7413,
  [7417] = 7413,
  [7418] = 7413,
  [7419] = 7413,
  [7420] = 7413,
  [7421] = 7413,
  [7422] = 7413,
  [7423] = 7413,
  [7424] = 7413,
  [7425] = 7413,
  [7426] = 7413,
  [7427] = 7413,
  [7428] = 7413,
  [7429] = 7413,
  [7430] = 7413,
  [7431] = 7413,
  [7432] = 7413,
  [7433] = 7413,
  [7434] = 7413,
  [7435] = 7413,
  [7436] = 7413,
  [7437] = 7413,
  [7438] = 7413,
  [7439] = 7413,
  [7440] = 7413,
  [7441] = 7413,
  [7442] = 7413,
  [7443] = 7413,
  [7444] = 7413,
  [7445] = 7413,
  [7446] = 7413,
  [7447] = 7413,
  [7448] = 7413,
  [7449] = 7449,
  [7450] = 7449,
  [7451] = 7449,
  [7452] = 7452,
  [7453] = 7453,
  [7454] = 7449,
  [7455] = 7453,
  [7456] = 7449,
  [7457] = 7453,
  [7458] = 7452,
  [7459] = 7449,
  [7460] = 7453,
  [7461] = 7453,
  [7462] = 7452,
  [7463] = 7452,
  [7464] = 7452,
  [7465] = 7449,
  [7466] = 7452,
  [7467] = 7453,
  [7468] = 7449,
  [7469] = 7452,
  [7470] = 7452,
  [7471] = 7449,
  [7472] = 7449,
  [7473] = 7453,
  [7474] = 7453,
  [7475] = 7449,
  [7476] = 7449,
  [7477] = 7449,
  [7478] = 7452,
  [7479] = 7449,
  [7480] = 7452,
  [7481] = 7449,
  [7482] = 7453,
  [7483] = 7449,
  [7484] = 7453,
  [7485] = 7453,
  [7486] = 7452,
  [7487] = 7453,
  [7488] = 7453,
  [7489] = 7452,
  [7490] = 7452,
  [7491] = 7453,
  [7492] = 7453,
  [7493] = 7452,
  [7494] = 7452,
  [7495] = 7453,
  [7496] = 7453,
  [7497] = 7452,
  [7498] = 7452,
  [7499] = 7453,
  [7500] = 7449,
  [7501] = 7452,
  [7502] = 7452,
  [7503] = 7449,
  [7504] = 7449,
  [7505] = 7452,
  [7506] = 7453,
  [7507] = 7449,
  [7508] = 7453,
  [7509] = 7509,
  [7510] = 7510,
  [7511] = 7511,
  [7512] = 7512,
  [7513] = 7513,
  [7514] = 7514,
  [7515] = 7515,
  [7516] = 7513,
  [7517] = 7513,
  [7518] = 7518,
  [7519] = 7514,
  [7520] = 7518,
  [7521] = 7514,
  [7522] = 7515,
  [7523] = 7515,
  [7524] = 7518,
  [7525] = 7525,
  [7526] = 7526,
  [7527] = 7527,
  [7528] = 7528,
  [7529] = 7529,
  [7530] = 7530,
  [7531] = 7529,
  [7532] = 7532,
  [7533] = 7533,
  [7534] = 7525,
  [7535] = 7533,
  [7536] = 7536,
  [7537] = 7537,
  [7538] = 7536,
  [7539] = 7528,
  [7540] = 7536,
  [7541] = 7541,
  [7542] = 7532,
  [7543] = 7528,
  [7544] = 7541,
  [7545] = 7533,
  [7546] = 7529,
  [7547] = 7541,
  [7548] = 7532,
  [7549] = 7525,
  [7550] = 7550,
  [7551] = 7551,
  [7552] = 7552,
  [7553] = 7552,
  [7554] = 7554,
  [7555] = 7555,
  [7556] = 7554,
  [7557] = 7554,
  [7558] = 7555,
  [7559] = 7555,
  [7560] = 7555,
  [7561] = 7550,
  [7562] = 7551,
  [7563] = 7551,
  [7564] = 7552,
  [7565] = 7550,
  [7566] = 7566,
  [7567] = 7567,
  [7568] = 7568,
  [7569] = 7569,
  [7570] = 7570,
  [7571] = 7570,
  [7572] = 7572,
  [7573] = 7573,
  [7574] = 7574,
  [7575] = 7575,
  [7576] = 7576,
  [7577] = 7575,
  [7578] = 7578,
  [7579] = 7578,
  [7580] = 7580,
  [7581] = 7581,
  [7582] = 7582,
  [7583] = 7574,
  [7584] = 7584,
  [7585] = 7575,
  [7586] = 7586,
  [7587] = 7578,
  [7588] = 7588,
  [7589] = 7589,
  [7590] = 7590,
  [7591] = 7591,
  [7592] = 7567,
  [7593] = 7593,
  [7594] = 7594,
  [7595] = 7595,
  [7596] = 7596,
  [7597] = 7568,
  [7598] = 7569,
  [7599] = 7570,
  [7600] = 7594,
  [7601] = 7601,
  [7602] = 7567,
  [7603] = 7568,
  [7604] = 7595,
  [7605] = 7589,
  [7606] = 7606,
  [7607] = 7569,
  [7608] = 7608,
  [7609] = 7609,
  [7610] = 7574,
  [7611] = 7611,
  [7612] = 7575,
  [7613] = 7578,
  [7614] = 7614,
  [7615] = 7615,
  [7616] = 7616,
  [7617] = 7617,
  [7618] = 7586,
  [7619] = 7580,
  [7620] = 7590,
  [7621] = 7589,
  [7622] = 7622,
  [7623] = 7623,
  [7624] = 7581,
  [7625] = 7582,
  [7626] = 7626,
  [7627] = 7586,
  [7628] = 7588,
  [7629] = 7590,
  [7630] = 7622,
  [7631] = 7591,
  [7632] = 7594,
  [7633] = 7572,
  [7634] = 7595,
  [7635] = 7596,
  [7636] = 7584,
  [7637] = 7591,
  [7638] = 7638,
  [7639] = 7580,
  [7640] = 7640,
  [7641] = 7589,
  [7642] = 7642,
  [7643] = 7643,
  [7644] = 7644,
  [7645] = 7645,
  [7646] = 7646,
  [7647] = 7647,
  [7648] = 7648,
  [7649] = 7649,
  [7650] = 7650,
  [7651] = 7576,
  [7652] = 7572,
  [7653] = 7653,
  [7654] = 7573,
  [7655] = 7573,
  [7656] = 7581,
  [7657] = 7588,
  [7658] = 7573,
  [7659] = 7576,
  [7660] = 7622,
  [7661] = 7582,
  [7662] = 7574,
  [7663] = 7663,
  [7664] = 7567,
  [7665] = 7576,
  [7666] = 7568,
  [7667] = 7622,
  [7668] = 7569,
  [7669] = 7669,
  [7670] = 7670,
  [7671] = 7584,
  [7672] = 7596,
  [7673] = 7572,
  [7674] = 7570,
  [7675] = 7584,
  [7676] = 7676,
  [7677] = 7677,
  [7678] = 7678,
  [7679] = 7679,
  [7680] = 7680,
  [7681] = 7678,
  [7682] = 7679,
  [7683] = 7683,
  [7684] = 7684,
  [7685] = 7677,
  [7686] = 7686,
  [7687] = 7687,
  [7688] = 7678,
  [7689] = 7689,
  [7690] = 7690,
  [7691] = 7687,
  [7692] = 7692,
  [7693] = 7680,
  [7694] = 7694,
  [7695] = 7695,
  [7696] = 7679,
  [7697] = 7689,
  [7698] = 7698,
  [7699] = 7699,
  [7700] = 7677,
  [7701] = 7701,
  [7702] = 7686,
  [7703] = 7703,
  [7704] = 7684,
  [7705] = 7684,
  [7706] = 7686,
  [7707] = 7680,
  [7708] = 7689,
  [7709] = 7687,
  [7710] = 7710,
  [7711] = 2209,
  [7712] = 7712,
  [7713] = 7713,
  [7714] = 7714,
  [7715] = 7715,
  [7716] = 7716,
  [7717] = 7717,
  [7718] = 7718,
  [7719] = 7719,
  [7720] = 7714,
  [7721] = 7713,
  [7722] = 7722,
  [7723] = 7716,
  [7724] = 7724,
  [7725] = 7725,
  [7726] = 7726,
  [7727] = 2210,
  [7728] = 7726,
  [7729] = 7725,
  [7730] = 7715,
  [7731] = 7731,
  [7732] = 7719,
  [7733] = 7725,
  [7734] = 7734,
  [7735] = 7719,
  [7736] = 7736,
  [7737] = 7737,
  [7738] = 7738,
  [7739] = 7713,
  [7740] = 7724,
  [7741] = 7725,
  [7742] = 7742,
  [7743] = 7712,
  [7744] = 7714,
  [7745] = 7745,
  [7746] = 7718,
  [7747] = 7742,
  [7748] = 7722,
  [7749] = 7725,
  [7750] = 7710,
  [7751] = 7726,
  [7752] = 7716,
  [7753] = 7724,
  [7754] = 7754,
  [7755] = 7755,
  [7756] = 7713,
  [7757] = 7731,
  [7758] = 7745,
  [7759] = 7734,
  [7760] = 7710,
  [7761] = 7755,
  [7762] = 7755,
  [7763] = 7763,
  [7764] = 7754,
  [7765] = 7712,
  [7766] = 7766,
  [7767] = 7718,
  [7768] = 7763,
  [7769] = 7731,
  [7770] = 7715,
  [7771] = 7734,
  [7772] = 7754,
  [7773] = 7745,
  [7774] = 7763,
  [7775] = 7742,
  [7776] = 7722,
  [7777] = 7713,
  [7778] = 7778,
  [7779] = 7779,
  [7780] = 7780,
  [7781] = 7781,
  [7782] = 7782,
  [7783] = 7783,
  [7784] = 7784,
  [7785] = 7785,
  [7786] = 7786,
  [7787] = 7787,
  [7788] = 7788,
  [7789] = 7784,
  [7790] = 7790,
  [7791] = 7791,
  [7792] = 7792,
  [7793] = 7790,
  [7794] = 7794,
  [7795] = 7795,
  [7796] = 7796,
  [7797] = 7797,
  [7798] = 2743,
  [7799] = 7799,
  [7800] = 7800,
  [7801] = 7801,
  [7802] = 7802,
  [7803] = 7786,
  [7804] = 7804,
  [7805] = 7788,
  [7806] = 7784,
  [7807] = 7790,
  [7808] = 2744,
  [7809] = 7809,
  [7810] = 7810,
  [7811] = 7811,
  [7812] = 7812,
  [7813] = 7802,
  [7814] = 7804,
  [7815] = 7809,
  [7816] = 7810,
  [7817] = 7817,
  [7818] = 7781,
  [7819] = 7782,
  [7820] = 7781,
  [7821] = 7821,
  [7822] = 7822,
  [7823] = 7823,
  [7824] = 7800,
  [7825] = 7825,
  [7826] = 7826,
  [7827] = 7782,
  [7828] = 7799,
  [7829] = 7783,
  [7830] = 7830,
  [7831] = 7812,
  [7832] = 7832,
  [7833] = 7833,
  [7834] = 7834,
  [7835] = 7835,
  [7836] = 7836,
  [7837] = 7837,
  [7838] = 7838,
  [7839] = 7839,
  [7840] = 7840,
  [7841] = 7841,
  [7842] = 7842,
  [7843] = 7843,
  [7844] = 7844,
  [7845] = 7845,
  [7846] = 7821,
  [7847] = 7847,
  [7848] = 7822,
  [7849] = 7849,
  [7850] = 7832,
  [7851] = 7788,
  [7852] = 7852,
  [7853] = 7823,
  [7854] = 7854,
  [7855] = 7855,
  [7856] = 7856,
  [7857] = 7844,
  [7858] = 7839,
  [7859] = 7852,
  [7860] = 7860,
  [7861] = 7834,
  [7862] = 7835,
  [7863] = 7863,
  [7864] = 7844,
  [7865] = 7821,
  [7866] = 7822,
  [7867] = 7867,
  [7868] = 7868,
  [7869] = 7869,
  [7870] = 7825,
  [7871] = 7826,
  [7872] = 7872,
  [7873] = 7823,
  [7874] = 7839,
  [7875] = 7852,
  [7876] = 7876,
  [7877] = 7799,
  [7878] = 7878,
  [7879] = 7879,
  [7880] = 7791,
  [7881] = 7881,
  [7882] = 7882,
  [7883] = 7783,
  [7884] = 7881,
  [7885] = 7800,
  [7886] = 7868,
  [7887] = 7887,
  [7888] = 7888,
  [7889] = 7830,
  [7890] = 7878,
  [7891] = 7891,
  [7892] = 7791,
  [7893] = 7812,
  [7894] = 7894,
  [7895] = 7844,
  [7896] = 7896,
  [7897] = 2211,
  [7898] = 7839,
  [7899] = 7852,
  [7900] = 7832,
  [7901] = 7878,
  [7902] = 7833,
  [7903] = 7791,
  [7904] = 7904,
  [7905] = 7868,
  [7906] = 7906,
  [7907] = 7836,
  [7908] = 7825,
  [7909] = 7826,
  [7910] = 7834,
  [7911] = 7796,
  [7912] = 7878,
  [7913] = 7791,
  [7914] = 7835,
  [7915] = 7844,
  [7916] = 7881,
  [7917] = 7845,
  [7918] = 7836,
  [7919] = 7839,
  [7920] = 7852,
  [7921] = 7881,
  [7922] = 7778,
  [7923] = 7837,
  [7924] = 7838,
  [7925] = 7802,
  [7926] = 7804,
  [7927] = 6766,
  [7928] = 7868,
  [7929] = 7778,
  [7930] = 7930,
  [7931] = 7837,
  [7932] = 7932,
  [7933] = 7838,
  [7934] = 7809,
  [7935] = 7810,
  [7936] = 7936,
  [7937] = 7796,
  [7938] = 7830,
  [7939] = 7939,
  [7940] = 7845,
  [7941] = 7878,
  [7942] = 7942,
  [7943] = 2992,
  [7944] = 7844,
  [7945] = 7786,
  [7946] = 7868,
  [7947] = 7947,
  [7948] = 7868,
  [7949] = 7833,
  [7950] = 7950,
  [7951] = 7951,
  [7952] = 7952,
  [7953] = 7953,
  [7954] = 7954,
  [7955] = 7955,
  [7956] = 7956,
  [7957] = 7957,
  [7958] = 7958,
  [7959] = 7959,
  [7960] = 7960,
  [7961] = 7961,
  [7962] = 7962,
  [7963] = 7963,
  [7964] = 7964,
  [7965] = 7965,
  [7966] = 7966,
  [7967] = 7967,
  [7968] = 7968,
  [7969] = 7969,
  [7970] = 7970,
  [7971] = 7971,
  [7972] = 7969,
  [7973] = 7973,
  [7974] = 7974,
  [7975] = 7975,
  [7976] = 7976,
  [7977] = 7977,
  [7978] = 7978,
  [7979] = 7979,
  [7980] = 7980,
  [7981] = 7981,
  [7982] = 7982,
  [7983] = 7983,
  [7984] = 7984,
  [7985] = 7985,
  [7986] = 7986,
  [7987] = 4720,
  [7988] = 7988,
  [7989] = 7989,
  [7990] = 3729,
  [7991] = 7991,
  [7992] = 7992,
  [7993] = 7965,
  [7994] = 7994,
  [7995] = 7995,
  [7996] = 7996,
  [7997] = 7954,
  [7998] = 7998,
  [7999] = 7969,
  [8000] = 7957,
  [8001] = 7958,
  [8002] = 8002,
  [8003] = 7959,
  [8004] = 8004,
  [8005] = 8005,
  [8006] = 8006,
  [8007] = 8007,
  [8008] = 8008,
  [8009] = 8009,
  [8010] = 8010,
  [8011] = 8011,
  [8012] = 7981,
  [8013] = 7982,
  [8014] = 8014,
  [8015] = 7985,
  [8016] = 7988,
  [8017] = 7962,
  [8018] = 7963,
  [8019] = 7964,
  [8020] = 8020,
  [8021] = 7954,
  [8022] = 8022,
  [8023] = 7966,
  [8024] = 7954,
  [8025] = 7969,
  [8026] = 7968,
  [8027] = 7967,
  [8028] = 8028,
  [8029] = 8029,
  [8030] = 8030,
  [8031] = 8031,
  [8032] = 8032,
  [8033] = 8033,
  [8034] = 8034,
  [8035] = 8035,
  [8036] = 8036,
  [8037] = 7994,
  [8038] = 8038,
  [8039] = 7991,
  [8040] = 8040,
  [8041] = 7969,
  [8042] = 7950,
  [8043] = 8043,
  [8044] = 8044,
  [8045] = 8045,
  [8046] = 8046,
  [8047] = 8007,
  [8048] = 8048,
  [8049] = 8046,
  [8050] = 8050,
  [8051] = 8051,
  [8052] = 8052,
  [8053] = 7983,
  [8054] = 8054,
  [8055] = 8055,
  [8056] = 8056,
  [8057] = 8057,
  [8058] = 8050,
  [8059] = 7983,
  [8060] = 8038,
  [8061] = 7996,
  [8062] = 8062,
  [8063] = 8063,
  [8064] = 8031,
  [8065] = 7952,
  [8066] = 8005,
  [8067] = 8067,
  [8068] = 8010,
  [8069] = 7991,
  [8070] = 7992,
  [8071] = 7977,
  [8072] = 8029,
  [8073] = 8073,
  [8074] = 8074,
  [8075] = 8075,
  [8076] = 8034,
  [8077] = 8077,
  [8078] = 8078,
  [8079] = 8079,
  [8080] = 7956,
  [8081] = 7951,
  [8082] = 8082,
  [8083] = 7980,
  [8084] = 7968,
  [8085] = 8085,
  [8086] = 7977,
  [8087] = 7969,
  [8088] = 8088,
  [8089] = 8089,
  [8090] = 7995,
  [8091] = 8008,
  [8092] = 8009,
  [8093] = 8093,
  [8094] = 7995,
  [8095] = 7952,
  [8096] = 8008,
  [8097] = 8022,
  [8098] = 8009,
  [8099] = 8099,
  [8100] = 8100,
  [8101] = 8101,
  [8102] = 8102,
  [8103] = 8103,
  [8104] = 8104,
  [8105] = 7955,
  [8106] = 3653,
  [8107] = 8022,
  [8108] = 8030,
  [8109] = 8100,
  [8110] = 7957,
  [8111] = 8033,
  [8112] = 8028,
  [8113] = 8113,
  [8114] = 8079,
  [8115] = 8020,
  [8116] = 8032,
  [8117] = 8101,
  [8118] = 8103,
  [8119] = 8104,
  [8120] = 7958,
  [8121] = 8030,
  [8122] = 7992,
  [8123] = 8123,
  [8124] = 8035,
  [8125] = 8033,
  [8126] = 7979,
  [8127] = 7959,
  [8128] = 8128,
  [8129] = 8040,
  [8130] = 7991,
  [8131] = 7953,
  [8132] = 8043,
  [8133] = 8133,
  [8134] = 8134,
  [8135] = 8050,
  [8136] = 8029,
  [8137] = 7962,
  [8138] = 7963,
  [8139] = 7964,
  [8140] = 7979,
  [8141] = 8031,
  [8142] = 7950,
  [8143] = 8052,
  [8144] = 8099,
  [8145] = 7992,
  [8146] = 7971,
  [8147] = 7978,
  [8148] = 8034,
  [8149] = 7966,
  [8150] = 8133,
  [8151] = 8043,
  [8152] = 7973,
  [8153] = 7974,
  [8154] = 8045,
  [8155] = 7975,
  [8156] = 8156,
  [8157] = 7967,
  [8158] = 8007,
  [8159] = 8156,
  [8160] = 7992,
  [8161] = 7986,
  [8162] = 8162,
  [8163] = 8163,
  [8164] = 8164,
  [8165] = 8113,
  [8166] = 7961,
  [8167] = 8167,
  [8168] = 8038,
  [8169] = 8169,
  [8170] = 7986,
  [8171] = 8162,
  [8172] = 8172,
  [8173] = 2971,
  [8174] = 7971,
  [8175] = 8164,
  [8176] = 7973,
  [8177] = 7974,
  [8178] = 7975,
  [8179] = 8088,
  [8180] = 8113,
  [8181] = 8038,
  [8182] = 7953,
  [8183] = 7961,
  [8184] = 8184,
  [8185] = 7978,
  [8186] = 7970,
  [8187] = 7976,
  [8188] = 7981,
  [8189] = 7992,
  [8190] = 7982,
  [8191] = 8099,
  [8192] = 8192,
  [8193] = 8020,
  [8194] = 7985,
  [8195] = 7991,
  [8196] = 8063,
  [8197] = 7988,
  [8198] = 7970,
  [8199] = 7989,
  [8200] = 7976,
  [8201] = 8074,
  [8202] = 8167,
  [8203] = 8203,
  [8204] = 8028,
  [8205] = 8036,
  [8206] = 8032,
  [8207] = 8035,
  [8208] = 7965,
  [8209] = 8133,
  [8210] = 8067,
  [8211] = 8045,
  [8212] = 8040,
  [8213] = 8052,
  [8214] = 8075,
  [8215] = 7956,
  [8216] = 8167,
  [8217] = 8156,
  [8218] = 7955,
  [8219] = 8063,
  [8220] = 7989,
  [8221] = 7996,
  [8222] = 8020,
  [8223] = 8077,
  [8224] = 8224,
  [8225] = 8005,
  [8226] = 8162,
  [8227] = 8227,
  [8228] = 8067,
  [8229] = 8078,
  [8230] = 7952,
  [8231] = 8167,
  [8232] = 8079,
  [8233] = 8088,
  [8234] = 7952,
  [8235] = 8075,
  [8236] = 7991,
  [8237] = 4563,
  [8238] = 7951,
  [8239] = 8164,
  [8240] = 8240,
  [8241] = 8046,
  [8242] = 8074,
  [8243] = 8077,
  [8244] = 8078,
  [8245] = 7991,
  [8246] = 7894,
  [8247] = 8240,
  [8248] = 8248,
  [8249] = 8249,
  [8250] = 8250,
  [8251] = 8251,
  [8252] = 8252,
  [8253] = 8253,
  [8254] = 8254,
  [8255] = 8255,
  [8256] = 8256,
  [8257] = 8257,
  [8258] = 8258,
  [8259] = 4563,
  [8260] = 8257,
  [8261] = 8261,
  [8262] = 8249,
  [8263] = 8263,
  [8264] = 8264,
  [8265] = 8265,
  [8266] = 8249,
  [8267] = 8267,
  [8268] = 8268,
  [8269] = 8269,
  [8270] = 8263,
  [8271] = 2902,
  [8272] = 8254,
  [8273] = 8268,
  [8274] = 8274,
  [8275] = 8274,
  [8276] = 8276,
  [8277] = 8277,
  [8278] = 8278,
  [8279] = 8263,
  [8280] = 8253,
  [8281] = 8281,
  [8282] = 8282,
  [8283] = 8274,
  [8284] = 8276,
  [8285] = 8276,
  [8286] = 8286,
  [8287] = 8287,
  [8288] = 4563,
  [8289] = 8289,
  [8290] = 2909,
  [8291] = 8289,
  [8292] = 8292,
  [8293] = 8293,
  [8294] = 2913,
  [8295] = 8295,
  [8296] = 8282,
  [8297] = 8297,
  [8298] = 8298,
  [8299] = 8299,
  [8300] = 8254,
  [8301] = 8301,
  [8302] = 8255,
  [8303] = 8303,
  [8304] = 8253,
  [8305] = 8255,
  [8306] = 8256,
  [8307] = 8307,
  [8308] = 8308,
  [8309] = 2898,
  [8310] = 8310,
  [8311] = 8311,
  [8312] = 8312,
  [8313] = 2220,
  [8314] = 8287,
  [8315] = 8250,
  [8316] = 8316,
  [8317] = 2903,
  [8318] = 8318,
  [8319] = 8319,
  [8320] = 8251,
  [8321] = 8321,
  [8322] = 8322,
  [8323] = 8323,
  [8324] = 8308,
  [8325] = 8325,
  [8326] = 8326,
  [8327] = 8282,
  [8328] = 8289,
  [8329] = 8256,
  [8330] = 8252,
  [8331] = 8331,
  [8332] = 2219,
  [8333] = 8333,
  [8334] = 8282,
  [8335] = 4563,
  [8336] = 8336,
  [8337] = 8250,
  [8338] = 8338,
  [8339] = 8251,
  [8340] = 8340,
  [8341] = 8341,
  [8342] = 8303,
  [8343] = 8343,
  [8344] = 8287,
  [8345] = 8345,
  [8346] = 8346,
  [8347] = 2966,
  [8348] = 4720,
  [8349] = 8333,
  [8350] = 8326,
  [8351] = 8257,
  [8352] = 8352,
  [8353] = 8353,
  [8354] = 8354,
  [8355] = 8353,
  [8356] = 4720,
  [8357] = 8354,
  [8358] = 2216,
  [8359] = 8359,
  [8360] = 8360,
  [8361] = 8319,
  [8362] = 8303,
  [8363] = 8363,
  [8364] = 8364,
  [8365] = 8297,
  [8366] = 8343,
  [8367] = 8303,
  [8368] = 8289,
  [8369] = 8297,
  [8370] = 8303,
  [8371] = 8303,
  [8372] = 8282,
  [8373] = 8308,
  [8374] = 8303,
  [8375] = 8303,
  [8376] = 8287,
  [8377] = 2214,
  [8378] = 8252,
  [8379] = 8353,
  [8380] = 8354,
  [8381] = 8343,
  [8382] = 8268,
  [8383] = 4720,
  [8384] = 8384,
  [8385] = 8385,
  [8386] = 8386,
  [8387] = 8387,
  [8388] = 8388,
  [8389] = 8389,
  [8390] = 8390,
  [8391] = 8391,
  [8392] = 8392,
  [8393] = 8393,
  [8394] = 8394,
  [8395] = 8395,
  [8396] = 8396,
  [8397] = 8397,
  [8398] = 8394,
  [8399] = 8399,
  [8400] = 8399,
  [8401] = 8401,
  [8402] = 8385,
  [8403] = 8403,
  [8404] = 8404,
  [8405] = 8385,
  [8406] = 8406,
  [8407] = 8364,
  [8408] = 8408,
  [8409] = 8409,
  [8410] = 8410,
  [8411] = 8411,
  [8412] = 8412,
  [8413] = 8413,
  [8414] = 8414,
  [8415] = 8415,
  [8416] = 8412,
  [8417] = 8417,
  [8418] = 8418,
  [8419] = 8419,
  [8420] = 8420,
  [8421] = 8421,
  [8422] = 8396,
  [8423] = 8419,
  [8424] = 8397,
  [8425] = 8425,
  [8426] = 8426,
  [8427] = 8427,
  [8428] = 8428,
  [8429] = 8429,
  [8430] = 8430,
  [8431] = 8385,
  [8432] = 8432,
  [8433] = 8433,
  [8434] = 8428,
  [8435] = 8435,
  [8436] = 8436,
  [8437] = 8437,
  [8438] = 8438,
  [8439] = 8388,
  [8440] = 8440,
  [8441] = 8403,
  [8442] = 8413,
  [8443] = 8408,
  [8444] = 8444,
  [8445] = 8445,
  [8446] = 8446,
  [8447] = 8447,
  [8448] = 8410,
  [8449] = 8449,
  [8450] = 8450,
  [8451] = 8419,
  [8452] = 8404,
  [8453] = 8453,
  [8454] = 8430,
  [8455] = 8455,
  [8456] = 8419,
  [8457] = 8432,
  [8458] = 8385,
  [8459] = 8459,
  [8460] = 8460,
  [8461] = 8414,
  [8462] = 8413,
  [8463] = 8388,
  [8464] = 8464,
  [8465] = 8396,
  [8466] = 8466,
  [8467] = 8467,
  [8468] = 8468,
  [8469] = 8421,
  [8470] = 8426,
  [8471] = 8417,
  [8472] = 8472,
  [8473] = 8409,
  [8474] = 8390,
  [8475] = 8421,
  [8476] = 8476,
  [8477] = 8477,
  [8478] = 8478,
  [8479] = 8468,
  [8480] = 8426,
  [8481] = 8432,
  [8482] = 8482,
  [8483] = 8445,
  [8484] = 8466,
  [8485] = 8388,
  [8486] = 8486,
  [8487] = 3015,
  [8488] = 8488,
  [8489] = 8397,
  [8490] = 8490,
  [8491] = 8491,
  [8492] = 8492,
  [8493] = 8493,
  [8494] = 8494,
  [8495] = 8495,
  [8496] = 8496,
  [8497] = 8497,
  [8498] = 8498,
  [8499] = 8499,
  [8500] = 8500,
  [8501] = 8421,
  [8502] = 8502,
  [8503] = 8404,
  [8504] = 8504,
  [8505] = 8389,
  [8506] = 8506,
  [8507] = 8507,
  [8508] = 8464,
  [8509] = 8391,
  [8510] = 8394,
  [8511] = 8426,
  [8512] = 8399,
  [8513] = 8403,
  [8514] = 8408,
  [8515] = 8445,
  [8516] = 8516,
  [8517] = 8419,
  [8518] = 8466,
  [8519] = 8433,
  [8520] = 8390,
  [8521] = 8409,
  [8522] = 8494,
  [8523] = 8393,
  [8524] = 8524,
  [8525] = 8409,
  [8526] = 8401,
  [8527] = 8527,
  [8528] = 8385,
  [8529] = 8529,
  [8530] = 8409,
  [8531] = 8531,
  [8532] = 8468,
  [8533] = 8533,
  [8534] = 8534,
  [8535] = 8412,
  [8536] = 8421,
  [8537] = 8426,
  [8538] = 8432,
  [8539] = 8421,
  [8540] = 8426,
  [8541] = 8541,
  [8542] = 8414,
  [8543] = 8468,
  [8544] = 8544,
  [8545] = 8418,
  [8546] = 8404,
  [8547] = 8409,
  [8548] = 8548,
  [8549] = 8418,
  [8550] = 8412,
  [8551] = 8477,
  [8552] = 8552,
  [8553] = 8404,
  [8554] = 8430,
  [8555] = 8468,
  [8556] = 8556,
  [8557] = 8413,
  [8558] = 8558,
  [8559] = 8559,
  [8560] = 8428,
  [8561] = 8507,
  [8562] = 8562,
  [8563] = 8494,
  [8564] = 8401,
  [8565] = 8565,
  [8566] = 8566,
  [8567] = 8567,
  [8568] = 8395,
  [8569] = 8464,
  [8570] = 8570,
  [8571] = 8432,
  [8572] = 8572,
  [8573] = 8573,
  [8574] = 8574,
  [8575] = 8409,
  [8576] = 8576,
  [8577] = 8577,
  [8578] = 8406,
  [8579] = 8430,
  [8580] = 8412,
  [8581] = 8411,
  [8582] = 8445,
  [8583] = 8466,
  [8584] = 8394,
  [8585] = 8577,
  [8586] = 8399,
  [8587] = 8587,
  [8588] = 8286,
  [8589] = 8403,
  [8590] = 8421,
  [8591] = 8426,
  [8592] = 8408,
  [8593] = 8468,
  [8594] = 8468,
  [8595] = 8419,
  [8596] = 8433,
  [8597] = 8468,
  [8598] = 8598,
  [8599] = 8395,
  [8600] = 8430,
  [8601] = 8428,
  [8602] = 8432,
  [8603] = 8392,
  [8604] = 8468,
  [8605] = 8464,
  [8606] = 8606,
  [8607] = 8390,
  [8608] = 8494,
  [8609] = 8450,
  [8610] = 8610,
  [8611] = 8611,
  [8612] = 8316,
  [8613] = 8323,
  [8614] = 8507,
  [8615] = 8552,
  [8616] = 8394,
  [8617] = 8399,
  [8618] = 8562,
  [8619] = 8403,
  [8620] = 8408,
  [8621] = 8419,
  [8622] = 8622,
  [8623] = 8433,
  [8624] = 8401,
  [8625] = 8390,
  [8626] = 8385,
  [8627] = 8494,
  [8628] = 8628,
  [8629] = 8629,
  [8630] = 8421,
  [8631] = 8385,
  [8632] = 8426,
  [8633] = 8468,
  [8634] = 8634,
  [8635] = 8428,
  [8636] = 8507,
  [8637] = 8574,
  [8638] = 8395,
  [8639] = 8396,
  [8640] = 8445,
  [8641] = 8466,
  [8642] = 8606,
  [8643] = 8421,
  [8644] = 8426,
  [8645] = 8562,
  [8646] = 8397,
  [8647] = 8562,
  [8648] = 8421,
  [8649] = 8426,
  [8650] = 8468,
  [8651] = 8651,
  [8652] = 8401,
  [8653] = 8504,
  [8654] = 8388,
  [8655] = 8414,
  [8656] = 8406,
  [8657] = 8657,
  [8658] = 8411,
  [8659] = 8659,
  [8660] = 8433,
  [8661] = 8661,
  [8662] = 8421,
  [8663] = 8552,
  [8664] = 8426,
  [8665] = 8406,
  [8666] = 8418,
  [8667] = 8667,
  [8668] = 8468,
  [8669] = 8669,
  [8670] = 8404,
  [8671] = 8411,
  [8672] = 8281,
  [8673] = 8552,
  [8674] = 8421,
  [8675] = 8426,
  [8676] = 8388,
  [8677] = 8298,
  [8678] = 8421,
  [8679] = 8426,
  [8680] = 8299,
  [8681] = 8421,
  [8682] = 8409,
  [8683] = 8468,
  [8684] = 8412,
  [8685] = 8504,
  [8686] = 8686,
  [8687] = 8430,
  [8688] = 8466,
  [8689] = 8468,
  [8690] = 8403,
  [8691] = 8419,
  [8692] = 8433,
  [8693] = 8414,
  [8694] = 8694,
  [8695] = 8504,
  [8696] = 8428,
  [8697] = 8415,
  [8698] = 8507,
  [8699] = 8562,
  [8700] = 8401,
  [8701] = 8418,
  [8702] = 8494,
  [8703] = 8426,
  [8704] = 8395,
  [8705] = 2301,
  [8706] = 8706,
  [8707] = 2229,
  [8708] = 8708,
  [8709] = 8709,
  [8710] = 8710,
  [8711] = 2295,
  [8712] = 8712,
  [8713] = 8713,
  [8714] = 2236,
  [8715] = 2222,
  [8716] = 2246,
  [8717] = 8717,
  [8718] = 8708,
  [8719] = 8719,
  [8720] = 8720,
  [8721] = 8721,
  [8722] = 8722,
  [8723] = 2296,
  [8724] = 8724,
  [8725] = 8725,
  [8726] = 2253,
  [8727] = 8727,
  [8728] = 8728,
  [8729] = 8729,
  [8730] = 8730,
  [8731] = 8731,
  [8732] = 8732,
  [8733] = 8733,
  [8734] = 8734,
  [8735] = 8735,
  [8736] = 8736,
  [8737] = 8737,
  [8738] = 8736,
  [8739] = 2254,
  [8740] = 8740,
  [8741] = 8741,
  [8742] = 2280,
  [8743] = 2255,
  [8744] = 8744,
  [8745] = 8745,
  [8746] = 8746,
  [8747] = 8747,
  [8748] = 8748,
  [8749] = 8749,
  [8750] = 8750,
  [8751] = 2297,
  [8752] = 2298,
  [8753] = 8724,
  [8754] = 8749,
  [8755] = 2300,
  [8756] = 8724,
  [8757] = 2302,
  [8758] = 8758,
  [8759] = 8759,
  [8760] = 8760,
  [8761] = 8761,
  [8762] = 8762,
  [8763] = 8763,
  [8764] = 8721,
  [8765] = 8761,
  [8766] = 8746,
  [8767] = 8767,
  [8768] = 8768,
  [8769] = 2232,
  [8770] = 8759,
  [8771] = 8771,
  [8772] = 2256,
  [8773] = 8773,
  [8774] = 8761,
  [8775] = 8775,
  [8776] = 8749,
  [8777] = 3626,
  [8778] = 8759,
  [8779] = 8748,
  [8780] = 2269,
  [8781] = 8781,
  [8782] = 8782,
  [8783] = 8783,
  [8784] = 8784,
  [8785] = 8785,
  [8786] = 8786,
  [8787] = 2906,
  [8788] = 8768,
  [8789] = 8786,
  [8790] = 8749,
  [8791] = 8791,
  [8792] = 8709,
  [8793] = 8793,
  [8794] = 8712,
  [8795] = 2283,
  [8796] = 8796,
  [8797] = 8797,
  [8798] = 8798,
  [8799] = 8799,
  [8800] = 8800,
  [8801] = 2237,
  [8802] = 2238,
  [8803] = 8746,
  [8804] = 8745,
  [8805] = 8724,
  [8806] = 8806,
  [8807] = 8785,
  [8808] = 8808,
  [8809] = 8809,
  [8810] = 8810,
  [8811] = 8811,
  [8812] = 8759,
  [8813] = 8721,
  [8814] = 8814,
  [8815] = 2239,
  [8816] = 8816,
  [8817] = 8817,
  [8818] = 8730,
  [8819] = 8819,
  [8820] = 8748,
  [8821] = 8821,
  [8822] = 2240,
  [8823] = 8808,
  [8824] = 8824,
  [8825] = 8762,
  [8826] = 8826,
  [8827] = 8827,
  [8828] = 2883,
  [8829] = 8724,
  [8830] = 8722,
  [8831] = 2241,
  [8832] = 8745,
  [8833] = 8833,
  [8834] = 8834,
  [8835] = 8809,
  [8836] = 8712,
  [8837] = 8837,
  [8838] = 8736,
  [8839] = 8708,
  [8840] = 8840,
  [8841] = 8745,
  [8842] = 8729,
  [8843] = 2230,
  [8844] = 2285,
  [8845] = 2242,
  [8846] = 8746,
  [8847] = 8847,
  [8848] = 8759,
  [8849] = 2885,
  [8850] = 8816,
  [8851] = 8710,
  [8852] = 8724,
  [8853] = 8819,
  [8854] = 8854,
  [8855] = 8762,
  [8856] = 8713,
  [8857] = 8745,
  [8858] = 2270,
  [8859] = 8859,
  [8860] = 8840,
  [8861] = 2223,
  [8862] = 8862,
  [8863] = 2286,
  [8864] = 8814,
  [8865] = 2279,
  [8866] = 2228,
  [8867] = 8867,
  [8868] = 8868,
  [8869] = 8759,
  [8870] = 2887,
  [8871] = 8871,
  [8872] = 2227,
  [8873] = 8873,
  [8874] = 8874,
  [8875] = 8875,
  [8876] = 2231,
  [8877] = 8877,
  [8878] = 2247,
  [8879] = 2267,
  [8880] = 2306,
  [8881] = 2224,
  [8882] = 8746,
  [8883] = 8819,
  [8884] = 8709,
  [8885] = 2288,
  [8886] = 8761,
  [8887] = 2289,
  [8888] = 2290,
  [8889] = 2234,
  [8890] = 2292,
  [8891] = 2235,
  [8892] = 2243,
  [8893] = 8724,
  [8894] = 8854,
  [8895] = 8895,
  [8896] = 2248,
  [8897] = 8741,
  [8898] = 2293,
  [8899] = 8899,
  [8900] = 8900,
  [8901] = 8745,
  [8902] = 8713,
  [8903] = 8713,
  [8904] = 8904,
  [8905] = 2271,
  [8906] = 8722,
  [8907] = 8748,
  [8908] = 8834,
  [8909] = 2272,
  [8910] = 8708,
  [8911] = 8785,
  [8912] = 8840,
  [8913] = 2249,
  [8914] = 8914,
  [8915] = 2250,
  [8916] = 2226,
  [8917] = 8786,
  [8918] = 8730,
  [8919] = 8729,
  [8920] = 2244,
  [8921] = 2245,
  [8922] = 8736,
  [8923] = 8923,
  [8924] = 8816,
  [8925] = 2233,
  [8926] = 8862,
  [8927] = 8927,
  [8928] = 8722,
  [8929] = 8834,
  [8930] = 3600,
  [8931] = 8768,
  [8932] = 8786,
  [8933] = 8933,
  [8934] = 8786,
  [8935] = 8935,
  [8936] = 2273,
  [8937] = 8937,
  [8938] = 8938,
  [8939] = 8721,
  [8940] = 8940,
  [8941] = 8724,
  [8942] = 8942,
  [8943] = 8768,
  [8944] = 8944,
  [8945] = 8761,
  [8946] = 8862,
  [8947] = 8947,
  [8948] = 2258,
  [8949] = 8834,
  [8950] = 8950,
  [8951] = 8951,
  [8952] = 8952,
  [8953] = 8729,
  [8954] = 2251,
  [8955] = 8819,
  [8956] = 8956,
  [8957] = 2259,
  [8958] = 8809,
  [8959] = 8959,
  [8960] = 2260,
  [8961] = 2264,
  [8962] = 2275,
  [8963] = 8808,
  [8964] = 2303,
  [8965] = 2266,
  [8966] = 8786,
  [8967] = 8761,
  [8968] = 8814,
  [8969] = 8762,
  [8970] = 2278,
  [8971] = 8819,
  [8972] = 2281,
  [8973] = 8746,
  [8974] = 8854,
  [8975] = 2276,
  [8976] = 2277,
  [8977] = 8759,
  [8978] = 8862,
  [8979] = 2282,
  [8980] = 8819,
  [8981] = 2252,
  [8982] = 8749,
  [8983] = 2287,
  [8984] = 2291,
  [8985] = 8985,
  [8986] = 8759,
  [8987] = 8708,
  [8988] = 8988,
  [8989] = 8989,
  [8990] = 2225,
  [8991] = 8816,
  [8992] = 8741,
  [8993] = 8708,
  [8994] = 8808,
  [8995] = 8995,
  [8996] = 8996,
  [8997] = 8997,
  [8998] = 8998,
  [8999] = 8999,
  [9000] = 8998,
  [9001] = 9001,
  [9002] = 9001,
  [9003] = 9003,
  [9004] = 9001,
  [9005] = 9005,
  [9006] = 9006,
  [9007] = 9007,
  [9008] = 9008,
  [9009] = 9009,
  [9010] = 9010,
  [9011] = 9011,
  [9012] = 9006,
  [9013] = 9001,
  [9014] = 9014,
  [9015] = 9015,
  [9016] = 9016,
  [9017] = 9017,
  [9018] = 9018,
  [9019] = 9019,
  [9020] = 9020,
  [9021] = 9021,
  [9022] = 9022,
  [9023] = 9021,
  [9024] = 8997,
  [9025] = 9025,
  [9026] = 9026,
  [9027] = 9027,
  [9028] = 9027,
  [9029] = 9018,
  [9030] = 9030,
  [9031] = 8997,
  [9032] = 9032,
  [9033] = 8998,
  [9034] = 9034,
  [9035] = 9018,
  [9036] = 9021,
  [9037] = 9021,
  [9038] = 9038,
  [9039] = 9039,
  [9040] = 9006,
  [9041] = 9041,
  [9042] = 9042,
  [9043] = 9027,
  [9044] = 9044,
  [9045] = 9045,
  [9046] = 8997,
  [9047] = 8998,
  [9048] = 9048,
  [9049] = 9018,
  [9050] = 9006,
  [9051] = 9051,
  [9052] = 9034,
  [9053] = 9007,
  [9054] = 9054,
  [9055] = 9055,
  [9056] = 9056,
  [9057] = 9057,
  [9058] = 8997,
  [9059] = 8998,
  [9060] = 9060,
  [9061] = 8998,
  [9062] = 9022,
  [9063] = 9063,
  [9064] = 9018,
  [9065] = 9001,
  [9066] = 9021,
  [9067] = 9001,
  [9068] = 9068,
  [9069] = 9069,
  [9070] = 9070,
  [9071] = 9071,
  [9072] = 9008,
  [9073] = 9006,
  [9074] = 9074,
  [9075] = 9075,
  [9076] = 9018,
  [9077] = 9021,
  [9078] = 9078,
  [9079] = 9079,
  [9080] = 9080,
  [9081] = 9081,
  [9082] = 9018,
  [9083] = 9021,
  [9084] = 9084,
  [9085] = 9085,
  [9086] = 8997,
  [9087] = 9087,
  [9088] = 8998,
  [9089] = 8997,
  [9090] = 9020,
  [9091] = 9091,
  [9092] = 9001,
  [9093] = 9093,
  [9094] = 9006,
  [9095] = 8998,
  [9096] = 8997,
  [9097] = 9097,
  [9098] = 9098,
  [9099] = 9099,
  [9100] = 9006,
  [9101] = 9101,
  [9102] = 9102,
  [9103] = 9103,
  [9104] = 9104,
  [9105] = 9105,
  [9106] = 8997,
  [9107] = 9107,
  [9108] = 9001,
  [9109] = 8998,
  [9110] = 9001,
  [9111] = 9007,
  [9112] = 9112,
  [9113] = 9113,
  [9114] = 9114,
  [9115] = 9075,
  [9116] = 9116,
  [9117] = 9117,
  [9118] = 9006,
  [9119] = 9119,
  [9120] = 9018,
  [9121] = 9021,
  [9122] = 9006,
  [9123] = 9123,
  [9124] = 9018,
  [9125] = 9021,
  [9126] = 9126,
  [9127] = 9001,
  [9128] = 9021,
  [9129] = 8997,
  [9130] = 9045,
  [9131] = 8998,
  [9132] = 9021,
  [9133] = 9133,
  [9134] = 8997,
  [9135] = 9135,
  [9136] = 9136,
  [9137] = 9006,
  [9138] = 9138,
  [9139] = 8998,
  [9140] = 9006,
  [9141] = 9141,
  [9142] = 9142,
  [9143] = 9143,
  [9144] = 9144,
  [9145] = 9145,
  [9146] = 9146,
  [9147] = 8998,
  [9148] = 9001,
  [9149] = 9141,
  [9150] = 9150,
  [9151] = 9034,
  [9152] = 9152,
  [9153] = 9153,
  [9154] = 9154,
  [9155] = 9155,
  [9156] = 9018,
  [9157] = 9021,
  [9158] = 9001,
  [9159] = 9159,
  [9160] = 9160,
  [9161] = 9161,
  [9162] = 9162,
  [9163] = 8997,
  [9164] = 9164,
  [9165] = 8998,
  [9166] = 9166,
  [9167] = 9085,
  [9168] = 8997,
  [9169] = 9006,
  [9170] = 8997,
  [9171] = 8998,
  [9172] = 9172,
  [9173] = 9173,
  [9174] = 9001,
  [9175] = 8998,
  [9176] = 9001,
  [9177] = 9123,
  [9178] = 9034,
  [9179] = 9179,
  [9180] = 9180,
  [9181] = 9181,
  [9182] = 9182,
  [9183] = 9001,
  [9184] = 9018,
  [9185] = 9021,
  [9186] = 9186,
  [9187] = 9187,
  [9188] = 9018,
  [9189] = 9006,
  [9190] = 9190,
  [9191] = 8997,
  [9192] = 9192,
  [9193] = 8998,
  [9194] = 9194,
  [9195] = 9018,
  [9196] = 9006,
  [9197] = 9021,
  [9198] = 9015,
  [9199] = 9021,
  [9200] = 9018,
  [9201] = 9201,
  [9202] = 8997,
  [9203] = 9203,
  [9204] = 8998,
  [9205] = 9006,
  [9206] = 9025,
  [9207] = 9207,
  [9208] = 9162,
  [9209] = 9001,
  [9210] = 8997,
  [9211] = 9211,
  [9212] = 9048,
  [9213] = 9032,
  [9214] = 9214,
  [9215] = 9215,
  [9216] = 8999,
  [9217] = 9217,
  [9218] = 9218,
  [9219] = 9219,
  [9220] = 9001,
  [9221] = 9071,
  [9222] = 9001,
  [9223] = 9018,
  [9224] = 9224,
  [9225] = 9225,
  [9226] = 9021,
  [9227] = 9227,
  [9228] = 9228,
  [9229] = 9179,
  [9230] = 9021,
  [9231] = 9231,
  [9232] = 9201,
  [9233] = 8997,
  [9234] = 8998,
  [9235] = 9006,
  [9236] = 9018,
  [9237] = 9237,
  [9238] = 9018,
  [9239] = 9239,
  [9240] = 9181,
  [9241] = 9056,
  [9242] = 9162,
  [9243] = 9243,
  [9244] = 9021,
  [9245] = 9245,
  [9246] = 8997,
  [9247] = 9018,
  [9248] = 8997,
  [9249] = 9018,
  [9250] = 8998,
  [9251] = 8997,
  [9252] = 8998,
  [9253] = 9253,
  [9254] = 8998,
  [9255] = 9006,
  [9256] = 8997,
  [9257] = 9005,
  [9258] = 8998,
  [9259] = 9259,
  [9260] = 9260,
  [9261] = 9261,
  [9262] = 9262,
  [9263] = 9103,
  [9264] = 9006,
  [9265] = 9001,
  [9266] = 8998,
  [9267] = 9006,
  [9268] = 9018,
  [9269] = 9269,
  [9270] = 9270,
  [9271] = 9133,
  [9272] = 9141,
  [9273] = 9021,
  [9274] = 9218,
  [9275] = 9103,
  [9276] = 9276,
  [9277] = 9162,
  [9278] = 8997,
  [9279] = 9279,
  [9280] = 9280,
  [9281] = 8998,
  [9282] = 9269,
  [9283] = 9001,
  [9284] = 9001,
  [9285] = 9102,
  [9286] = 9286,
  [9287] = 9239,
  [9288] = 9288,
  [9289] = 9006,
  [9290] = 9290,
  [9291] = 9291,
  [9292] = 9018,
  [9293] = 9006,
  [9294] = 9294,
  [9295] = 9104,
  [9296] = 9021,
  [9297] = 9006,
  [9298] = 9298,
  [9299] = 9299,
  [9300] = 9298,
  [9301] = 9014,
  [9302] = 9302,
  [9303] = 9303,
  [9304] = 9021,
  [9305] = 9008,
  [9306] = 9306,
  [9307] = 9307,
  [9308] = 9007,
  [9309] = 8997,
  [9310] = 9006,
  [9311] = 3720,
  [9312] = 9312,
  [9313] = 9313,
  [9314] = 9314,
  [9315] = 8998,
  [9316] = 9006,
  [9317] = 9317,
  [9318] = 9318,
  [9319] = 9319,
  [9320] = 9018,
  [9321] = 9321,
  [9322] = 9182,
  [9323] = 9136,
  [9324] = 9001,
  [9325] = 9325,
  [9326] = 9160,
  [9327] = 9327,
  [9328] = 9328,
  [9329] = 9008,
  [9330] = 9330,
  [9331] = 9317,
  [9332] = 9027,
  [9333] = 9333,
  [9334] = 9001,
  [9335] = 9018,
  [9336] = 8998,
  [9337] = 9021,
  [9338] = 9057,
  [9339] = 9099,
  [9340] = 9307,
  [9341] = 8997,
  [9342] = 8998,
  [9343] = 9055,
  [9344] = 9006,
  [9345] = 8999,
  [9346] = 9005,
  [9347] = 9103,
  [9348] = 9001,
  [9349] = 9349,
  [9350] = 9001,
  [9351] = 9097,
  [9352] = 9166,
  [9353] = 9141,
  [9354] = 9192,
  [9355] = 9355,
  [9356] = 9356,
  [9357] = 9018,
  [9358] = 9270,
  [9359] = 9359,
  [9360] = 9038,
  [9361] = 9194,
  [9362] = 9018,
  [9363] = 9021,
  [9364] = 9021,
  [9365] = 9259,
  [9366] = 9366,
  [9367] = 9071,
  [9368] = 9218,
  [9369] = 8997,
  [9370] = 8998,
  [9371] = 9006,
  [9372] = 9372,
  [9373] = 9373,
  [9374] = 9001,
  [9375] = 9006,
  [9376] = 9376,
  [9377] = 9377,
  [9378] = 9378,
  [9379] = 9192,
  [9380] = 9380,
  [9381] = 9217,
  [9382] = 9382,
  [9383] = 9112,
  [9384] = 9376,
  [9385] = 9385,
  [9386] = 9114,
  [9387] = 9117,
  [9388] = 9388,
  [9389] = 9377,
  [9390] = 9018,
  [9391] = 9162,
  [9392] = 9380,
  [9393] = 9194,
  [9394] = 9021,
  [9395] = 9021,
  [9396] = 9014,
  [9397] = 9397,
  [9398] = 9398,
  [9399] = 9399,
  [9400] = 9217,
  [9401] = 9117,
  [9402] = 9302,
  [9403] = 9045,
  [9404] = 9102,
  [9405] = 9298,
  [9406] = 9010,
  [9407] = 9407,
  [9408] = 9138,
  [9409] = 9409,
  [9410] = 9142,
  [9411] = 9411,
  [9412] = 8997,
  [9413] = 9097,
  [9414] = 9279,
  [9415] = 9415,
  [9416] = 9416,
  [9417] = 9417,
  [9418] = 9418,
  [9419] = 9376,
  [9420] = 9032,
  [9421] = 9377,
  [9422] = 8998,
  [9423] = 9380,
  [9424] = 8997,
  [9425] = 9217,
  [9426] = 9426,
  [9427] = 8998,
  [9428] = 9428,
  [9429] = 9429,
  [9430] = 9430,
  [9431] = 9025,
  [9432] = 9432,
  [9433] = 9228,
  [9434] = 9006,
  [9435] = 9141,
  [9436] = 9436,
  [9437] = 9372,
  [9438] = 9438,
  [9439] = 9439,
  [9440] = 9056,
  [9441] = 9056,
  [9442] = 9442,
  [9443] = 9071,
  [9444] = 9006,
  [9445] = 9445,
  [9446] = 9446,
  [9447] = 9294,
  [9448] = 8997,
  [9449] = 9018,
  [9450] = 9154,
  [9451] = 9451,
  [9452] = 9126,
  [9453] = 9006,
  [9454] = 9432,
  [9455] = 9411,
  [9456] = 9093,
  [9457] = 9063,
  [9458] = 9048,
  [9459] = 9459,
  [9460] = 9039,
  [9461] = 9461,
  [9462] = 9462,
  [9463] = 9306,
  [9464] = 9074,
  [9465] = 9014,
  [9466] = 9466,
  [9467] = 9186,
  [9468] = 9228,
  [9469] = 9314,
  [9470] = 9001,
  [9471] = 8998,
  [9472] = 9472,
  [9473] = 9473,
  [9474] = 9474,
  [9475] = 9475,
  [9476] = 3638,
  [9477] = 9224,
  [9478] = 9105,
  [9479] = 9291,
  [9480] = 9480,
  [9481] = 9231,
  [9482] = 9001,
  [9483] = 9330,
  [9484] = 9484,
  [9485] = 9485,
  [9486] = 9486,
  [9487] = 9487,
  [9488] = 9051,
  [9489] = 9333,
  [9490] = 9439,
  [9491] = 9373,
  [9492] = 9011,
  [9493] = 9006,
  [9494] = 9070,
  [9495] = 9006,
  [9496] = 9224,
  [9497] = 8999,
  [9498] = 9021,
  [9499] = 9005,
  [9500] = 9034,
  [9501] = 9439,
  [9502] = 9153,
  [9503] = 9503,
  [9504] = 9039,
  [9505] = 9146,
  [9506] = 9506,
  [9507] = 9507,
  [9508] = 9105,
  [9509] = 9159,
  [9510] = 9445,
  [9511] = 9511,
  [9512] = 9135,
  [9513] = 9513,
  [9514] = 9085,
  [9515] = 9466,
  [9516] = 9291,
  [9517] = 9081,
  [9518] = 9484,
  [9519] = 9181,
  [9520] = 9045,
  [9521] = 9015,
  [9522] = 9014,
  [9523] = 9027,
  [9524] = 9038,
  [9525] = 9181,
  [9526] = 9261,
  [9527] = 9290,
  [9528] = 9528,
  [9529] = 9123,
  [9530] = 9303,
  [9531] = 9486,
  [9532] = 9011,
  [9533] = 9484,
  [9534] = 9018,
  [9535] = 9535,
  [9536] = 9536,
  [9537] = 9010,
  [9538] = 9071,
  [9539] = 9019,
  [9540] = 9020,
  [9541] = 9227,
  [9542] = 9192,
  [9543] = 9194,
  [9544] = 8997,
  [9545] = 9545,
  [9546] = 9021,
  [9547] = 9201,
  [9548] = 9548,
  [9549] = 9103,
  [9550] = 8997,
  [9551] = 9144,
  [9552] = 9426,
  [9553] = 9239,
  [9554] = 9269,
  [9555] = 9294,
  [9556] = 9556,
  [9557] = 9182,
  [9558] = 9318,
  [9559] = 9319,
  [9560] = 9560,
  [9561] = 9021,
  [9562] = 9459,
  [9563] = 9138,
  [9564] = 9564,
  [9565] = 9150,
  [9566] = 9080,
  [9567] = 9567,
  [9568] = 9186,
  [9569] = 9569,
  [9570] = 9014,
  [9571] = 9564,
  [9572] = 9231,
  [9573] = 9001,
  [9574] = 9001,
  [9575] = 9575,
  [9576] = 9034,
  [9577] = 9164,
  [9578] = 9578,
  [9579] = 9506,
  [9580] = 8997,
  [9581] = 9581,
  [9582] = 9018,
  [9583] = 9153,
  [9584] = 9581,
  [9585] = 9112,
  [9586] = 9586,
  [9587] = 9181,
  [9588] = 9588,
  [9589] = 9589,
  [9590] = 9590,
  [9591] = 9591,
  [9592] = 8998,
  [9593] = 9021,
  [9594] = 9010,
  [9595] = 9595,
  [9596] = 9192,
  [9597] = 9194,
  [9598] = 9586,
  [9599] = 9117,
  [9600] = 9600,
  [9601] = 9601,
  [9602] = 9306,
  [9603] = 9567,
  [9604] = 9001,
  [9605] = 9172,
  [9606] = 8997,
  [9607] = 8998,
  [9608] = 9608,
  [9609] = 9270,
  [9610] = 9180,
  [9611] = 9485,
  [9612] = 9006,
  [9613] = 9330,
  [9614] = 9008,
  [9615] = 9144,
  [9616] = 9007,
  [9617] = 9022,
  [9618] = 9276,
  [9619] = 9159,
  [9620] = 9150,
  [9621] = 9333,
  [9622] = 9015,
  [9623] = 9623,
  [9624] = 9080,
  [9625] = 9001,
  [9626] = 9207,
  [9627] = 9018,
  [9628] = 9021,
  [9629] = 9629,
  [9630] = 8997,
  [9631] = 8998,
  [9632] = 9006,
  [9633] = 9633,
  [9634] = 9001,
  [9635] = 9038,
  [9636] = 9006,
  [9637] = 9021,
  [9638] = 9018,
  [9639] = 9237,
  [9640] = 9219,
  [9641] = 9001,
  [9642] = 9057,
  [9643] = 9019,
  [9644] = 9142,
  [9645] = 8997,
  [9646] = 9018,
  [9647] = 9317,
  [9648] = 9018,
  [9649] = 9021,
  [9650] = 9650,
  [9651] = 9318,
  [9652] = 8998,
  [9653] = 9104,
  [9654] = 9136,
  [9655] = 9021,
  [9656] = 9015,
  [9657] = 8997,
  [9658] = 9146,
  [9659] = 9071,
  [9660] = 8998,
  [9661] = 9446,
  [9662] = 9588,
  [9663] = 9591,
  [9664] = 9664,
  [9665] = 9154,
  [9666] = 9451,
  [9667] = 9126,
  [9668] = 9432,
  [9669] = 9411,
  [9670] = 9093,
  [9671] = 9063,
  [9672] = 9006,
  [9673] = 9068,
  [9674] = 9180,
  [9675] = 9466,
  [9676] = 9001,
  [9677] = 9019,
  [9678] = 9678,
  [9679] = 8997,
  [9680] = 9319,
  [9681] = 9681,
  [9682] = 9682,
  [9683] = 9528,
  [9684] = 9160,
  [9685] = 9685,
  [9686] = 9686,
  [9687] = 9279,
  [9688] = 9314,
  [9689] = 9373,
  [9690] = 9472,
  [9691] = 9020,
  [9692] = 9001,
  [9693] = 9001,
  [9694] = 9694,
  [9695] = 8998,
  [9696] = 9359,
  [9697] = 9382,
  [9698] = 9018,
  [9699] = 9070,
  [9700] = 9511,
  [9701] = 9135,
  [9702] = 9397,
  [9703] = 9703,
  [9704] = 9032,
  [9705] = 9227,
  [9706] = 9018,
  [9707] = 9021,
  [9708] = 9664,
  [9709] = 9021,
  [9710] = 9068,
  [9711] = 9442,
  [9712] = 9243,
  [9713] = 9713,
  [9714] = 9461,
  [9715] = 9103,
  [9716] = 9006,
  [9717] = 9112,
  [9718] = 9535,
  [9719] = 8997,
  [9720] = 8998,
  [9721] = 9721,
  [9722] = 9545,
  [9723] = 9567,
  [9724] = 9487,
  [9725] = 9003,
  [9726] = 9262,
  [9727] = 9133,
  [9728] = 9276,
  [9729] = 9729,
  [9730] = 9172,
  [9731] = 9237,
  [9732] = 9307,
  [9733] = 9006,
  [9734] = 9734,
  [9735] = 9154,
  [9736] = 9451,
  [9737] = 9126,
  [9738] = 9432,
  [9739] = 9411,
  [9740] = 9093,
  [9741] = 9063,
  [9742] = 9380,
  [9743] = 9507,
  [9744] = 9114,
  [9745] = 9466,
  [9746] = 9207,
  [9747] = 9650,
  [9748] = 9376,
  [9749] = 9749,
  [9750] = 9377,
  [9751] = 9380,
  [9752] = 9418,
  [9753] = 9217,
  [9754] = 9186,
  [9755] = 9317,
  [9756] = 9026,
  [9757] = 8997,
  [9758] = 8998,
  [9759] = 9307,
  [9760] = 9511,
  [9761] = 9135,
  [9762] = 9451,
  [9763] = 9001,
  [9764] = 9299,
  [9765] = 9018,
  [9766] = 9003,
  [9767] = 9097,
  [9768] = 9001,
  [9769] = 9564,
  [9770] = 9535,
  [9771] = 9376,
  [9772] = 9545,
  [9773] = 9001,
  [9774] = 9018,
  [9775] = 9775,
  [9776] = 9228,
  [9777] = 9021,
  [9778] = 9006,
  [9779] = 9030,
  [9780] = 9164,
  [9781] = 9021,
  [9782] = 9377,
  [9783] = 9141,
  [9784] = 9432,
  [9785] = 9411,
  [9786] = 9093,
  [9787] = 9063,
  [9788] = 9019,
  [9789] = 9789,
  [9790] = 9466,
  [9791] = 9020,
  [9792] = 9792,
  [9793] = 8997,
  [9794] = 8998,
  [9795] = 9219,
  [9796] = 9218,
  [9797] = 9218,
  [9798] = 9166,
  [9799] = 8997,
  [9800] = 9325,
  [9801] = 9801,
  [9802] = 9511,
  [9803] = 9803,
  [9804] = 9162,
  [9805] = 9006,
  [9806] = 9071,
  [9807] = 9682,
  [9808] = 9694,
  [9809] = 9721,
  [9810] = 9327,
  [9811] = 9015,
  [9812] = 9093,
  [9813] = 9063,
  [9814] = 9014,
  [9815] = 9466,
  [9816] = 9056,
  [9817] = 9001,
  [9818] = 9001,
  [9819] = 8998,
  [9820] = 9535,
  [9821] = 9021,
  [9822] = 9298,
  [9823] = 9001,
  [9824] = 9824,
  [9825] = 9825,
  [9826] = 9511,
  [9827] = 9827,
  [9828] = 9027,
  [9829] = 9018,
  [9830] = 9018,
  [9831] = 9486,
  [9832] = 9018,
  [9833] = 9042,
  [9834] = 9021,
  [9835] = 9545,
  [9836] = 9019,
  [9837] = 9020,
  [9838] = 8997,
  [9839] = 8998,
  [9840] = 9840,
  [9841] = 9021,
  [9842] = 9243,
  [9843] = 9044,
  [9844] = 9027,
  [9845] = 9018,
  [9846] = 9511,
  [9847] = 9485,
  [9848] = 9006,
  [9849] = 9259,
  [9850] = 9850,
  [9851] = 9060,
  [9852] = 9852,
  [9853] = 9021,
  [9854] = 9487,
  [9855] = 9051,
  [9856] = 9001,
  [9857] = 9299,
  [9858] = 9071,
  [9859] = 9032,
  [9860] = 8997,
  [9861] = 9032,
  [9862] = 9006,
  [9863] = 9087,
  [9864] = 9511,
  [9865] = 9091,
  [9866] = 9001,
  [9867] = 8998,
  [9868] = 9262,
  [9869] = 9528,
  [9870] = 9018,
  [9871] = 9871,
  [9872] = 9872,
  [9873] = 9506,
  [9874] = 9302,
  [9875] = 9001,
  [9876] = 9021,
  [9877] = 9261,
  [9878] = 9290,
  [9879] = 9021,
  [9880] = 9056,
  [9881] = 9303,
  [9882] = 9426,
  [9883] = 9459,
  [9884] = 9018,
  [9885] = 8997,
  [9886] = 9014,
  [9887] = 9006,
  [9888] = 8998,
  [9889] = 9075,
  [9890] = 9018,
  [9891] = 9581,
  [9892] = 9586,
  [9893] = 9588,
  [9894] = 9591,
  [9895] = 9472,
  [9896] = 9896,
  [9897] = 9112,
  [9898] = 8997,
  [9899] = 9075,
  [9900] = 9006,
  [9901] = 9008,
  [9902] = 9007,
  [9903] = 9022,
  [9904] = 9569,
  [9905] = 9001,
  [9906] = 9356,
  [9907] = 9749,
  [9908] = 9018,
  [9909] = 9511,
  [9910] = 9827,
  [9911] = 9091,
  [9912] = 9018,
  [9913] = 8998,
  [9914] = 9021,
  [9915] = 9017,
  [9916] = 9325,
  [9917] = 8997,
  [9918] = 9006,
  [9919] = 9021,
  [9920] = 8997,
  [9921] = 9103,
  [9922] = 8998,
  [9923] = 8998,
  [9924] = 9372,
  [9925] = 9006,
  [9926] = 9001,
  [9927] = 9359,
  [9928] = 9382,
  [9929] = 9397,
  [9930] = 9442,
  [9931] = 9461,
  [9932] = 9099,
  [9933] = 9103,
  [9934] = 9569,
  [9935] = 9356,
  [9936] = 9507,
  [9937] = 9650,
  [9938] = 9018,
  [9939] = 9749,
  [9940] = 9017,
  [9941] = 9418,
  [9942] = 9445,
  [9943] = 9026,
  [9944] = 9006,
  [9945] = 9018,
  [9946] = 9569,
  [9947] = 9356,
  [9948] = 9664,
  [9949] = 9055,
  [9950] = 9017,
  [9951] = 9030,
  [9952] = 9021,
  [9953] = 9327,
  [9954] = 9356,
  [9955] = 9682,
  [9956] = 9356,
  [9957] = 9694,
  [9958] = 9356,
  [9959] = 9356,
  [9960] = 9721,
  [9961] = 9825,
  [9962] = 9415,
  [9963] = 9827,
  [9964] = 8997,
  [9965] = 9801,
  [9966] = 9416,
  [9967] = 9027,
  [9968] = 9021,
  [9969] = 8998,
  [9970] = 9006,
  [9971] = 9825,
  [9972] = 9415,
  [9973] = 9801,
  [9974] = 9416,
  [9975] = 9825,
  [9976] = 9415,
  [9977] = 9801,
  [9978] = 9416,
  [9979] = 9415,
  [9980] = 9415,
  [9981] = 9042,
  [9982] = 9044,
  [9983] = 9087,
  [9984] = 9179,
  [9985] = 9985,
  [9986] = 9986,
  [9987] = 9987,
  [9988] = 9988,
  [9989] = 9989,
  [9990] = 9990,
  [9991] = 9991,
  [9992] = 9992,
  [9993] = 9993,
  [9994] = 9994,
  [9995] = 9995,
  [9996] = 9996,
  [9997] = 9997,
  [9998] = 9998,
  [9999] = 9999,
  [10000] = 10000,
  [10001] = 10001,
};

static TSCharacterRange sym__identifier_token_character_set_2[] = {
  {'A', 'Z'}, {'\\', '\\'}, {'_', '_'}, {'a', 'z'}, {0xaa, 0xaa}, {0xb5, 0xb5}, {0xba, 0xba}, {0xc0, 0xd6},
  {0xd8, 0xf6}, {0xf8, 0x2c1}, {0x2c6, 0x2d1}, {0x2e0, 0x2e4}, {0x2ec, 0x2ec}, {0x2ee, 0x2ee}, {0x370, 0x374}, {0x376, 0x377},
  {0x37b, 0x37d}, {0x37f, 0x37f}, {0x386, 0x386}, {0x388, 0x38a}, {0x38c, 0x38c}, {0x38e, 0x3a1}, {0x3a3, 0x3f5}, {0x3f7, 0x481},
  {0x48a, 0x52f}, {0x531, 0x556}, {0x559, 0x559}, {0x560, 0x588}, {0x5d0, 0x5ea}, {0x5ef, 0x5f2}, {0x620, 0x64a}, {0x66e, 0x66f},
  {0x671, 0x6d3}, {0x6d5, 0x6d5}, {0x6e5, 0x6e6}, {0x6ee, 0x6ef}, {0x6fa, 0x6fc}, {0x6ff, 0x6ff}, {0x710, 0x710}, {0x712, 0x72f},
  {0x74d, 0x7a5}, {0x7b1, 0x7b1}, {0x7ca, 0x7ea}, {0x7f4, 0x7f5}, {0x7fa, 0x7fa}, {0x800, 0x815}, {0x81a, 0x81a}, {0x824, 0x824},
  {0x828, 0x828}, {0x840, 0x858}, {0x860, 0x86a}, {0x870, 0x887}, {0x889, 0x88e}, {0x8a0, 0x8c9}, {0x904, 0x939}, {0x93d, 0x93d},
  {0x950, 0x950}, {0x958, 0x961}, {0x971, 0x980}, {0x985, 0x98c}, {0x98f, 0x990}, {0x993, 0x9a8}, {0x9aa, 0x9b0}, {0x9b2, 0x9b2},
  {0x9b6, 0x9b9}, {0x9bd, 0x9bd}, {0x9ce, 0x9ce}, {0x9dc, 0x9dd}, {0x9df, 0x9e1}, {0x9f0, 0x9f1}, {0x9fc, 0x9fc}, {0xa05, 0xa0a},
  {0xa0f, 0xa10}, {0xa13, 0xa28}, {0xa2a, 0xa30}, {0xa32, 0xa33}, {0xa35, 0xa36}, {0xa38, 0xa39}, {0xa59, 0xa5c}, {0xa5e, 0xa5e},
  {0xa72, 0xa74}, {0xa85, 0xa8d}, {0xa8f, 0xa91}, {0xa93, 0xaa8}, {0xaaa, 0xab0}, {0xab2, 0xab3}, {0xab5, 0xab9}, {0xabd, 0xabd},
  {0xad0, 0xad0}, {0xae0, 0xae1}, {0xaf9, 0xaf9}, {0xb05, 0xb0c}, {0xb0f, 0xb10}, {0xb13, 0xb28}, {0xb2a, 0xb30}, {0xb32, 0xb33},
  {0xb35, 0xb39}, {0xb3d, 0xb3d}, {0xb5c, 0xb5d}, {0xb5f, 0xb61}, {0xb71, 0xb71}, {0xb83, 0xb83}, {0xb85, 0xb8a}, {0xb8e, 0xb90},
  {0xb92, 0xb95}, {0xb99, 0xb9a}, {0xb9c, 0xb9c}, {0xb9e, 0xb9f}, {0xba3, 0xba4}, {0xba8, 0xbaa}, {0xbae, 0xbb9}, {0xbd0, 0xbd0},
  {0xc05, 0xc0c}, {0xc0e, 0xc10}, {0xc12, 0xc28}, {0xc2a, 0xc39}, {0xc3d, 0xc3d}, {0xc58, 0xc5a}, {0xc5d, 0xc5d}, {0xc60, 0xc61},
  {0xc80, 0xc80}, {0xc85, 0xc8c}, {0xc8e, 0xc90}, {0xc92, 0xca8}, {0xcaa, 0xcb3}, {0xcb5, 0xcb9}, {0xcbd, 0xcbd}, {0xcdd, 0xcde},
  {0xce0, 0xce1}, {0xcf1, 0xcf2}, {0xd04, 0xd0c}, {0xd0e, 0xd10}, {0xd12, 0xd3a}, {0xd3d, 0xd3d}, {0xd4e, 0xd4e}, {0xd54, 0xd56},
  {0xd5f, 0xd61}, {0xd7a, 0xd7f}, {0xd85, 0xd96}, {0xd9a, 0xdb1}, {0xdb3, 0xdbb}, {0xdbd, 0xdbd}, {0xdc0, 0xdc6}, {0xe01, 0xe30},
  {0xe32, 0xe32}, {0xe40, 0xe46}, {0xe81, 0xe82}, {0xe84, 0xe84}, {0xe86, 0xe8a}, {0xe8c, 0xea3}, {0xea5, 0xea5}, {0xea7, 0xeb0},
  {0xeb2, 0xeb2}, {0xebd, 0xebd}, {0xec0, 0xec4}, {0xec6, 0xec6}, {0xedc, 0xedf}, {0xf00, 0xf00}, {0xf40, 0xf47}, {0xf49, 0xf6c},
  {0xf88, 0xf8c}, {0x1000, 0x102a}, {0x103f, 0x103f}, {0x1050, 0x1055}, {0x105a, 0x105d}, {0x1061, 0x1061}, {0x1065, 0x1066}, {0x106e, 0x1070},
  {0x1075, 0x1081}, {0x108e, 0x108e}, {0x10a0, 0x10c5}, {0x10c7, 0x10c7}, {0x10cd, 0x10cd}, {0x10d0, 0x10fa}, {0x10fc, 0x1248}, {0x124a, 0x124d},
  {0x1250, 0x1256}, {0x1258, 0x1258}, {0x125a, 0x125d}, {0x1260, 0x1288}, {0x128a, 0x128d}, {0x1290, 0x12b0}, {0x12b2, 0x12b5}, {0x12b8, 0x12be},
  {0x12c0, 0x12c0}, {0x12c2, 0x12c5}, {0x12c8, 0x12d6}, {0x12d8, 0x1310}, {0x1312, 0x1315}, {0x1318, 0x135a}, {0x1380, 0x138f}, {0x13a0, 0x13f5},
  {0x13f8, 0x13fd}, {0x1401, 0x166c}, {0x166f, 0x167f}, {0x1681, 0x169a}, {0x16a0, 0x16ea}, {0x16ee, 0x16f8}, {0x1700, 0x1711}, {0x171f, 0x1731},
  {0x1740, 0x1751}, {0x1760, 0x176c}, {0x176e, 0x1770}, {0x1780, 0x17b3}, {0x17d7, 0x17d7}, {0x17dc, 0x17dc}, {0x1820, 0x1878}, {0x1880, 0x18a8},
  {0x18aa, 0x18aa}, {0x18b0, 0x18f5}, {0x1900, 0x191e}, {0x1950, 0x196d}, {0x1970, 0x1974}, {0x1980, 0x19ab}, {0x19b0, 0x19c9}, {0x1a00, 0x1a16},
  {0x1a20, 0x1a54}, {0x1aa7, 0x1aa7}, {0x1b05, 0x1b33}, {0x1b45, 0x1b4c}, {0x1b83, 0x1ba0}, {0x1bae, 0x1baf}, {0x1bba, 0x1be5}, {0x1c00, 0x1c23},
  {0x1c4d, 0x1c4f}, {0x1c5a, 0x1c7d}, {0x1c80, 0x1c88}, {0x1c90, 0x1cba}, {0x1cbd, 0x1cbf}, {0x1ce9, 0x1cec}, {0x1cee, 0x1cf3}, {0x1cf5, 0x1cf6},
  {0x1cfa, 0x1cfa}, {0x1d00, 0x1dbf}, {0x1e00, 0x1f15}, {0x1f18, 0x1f1d}, {0x1f20, 0x1f45}, {0x1f48, 0x1f4d}, {0x1f50, 0x1f57}, {0x1f59, 0x1f59},
  {0x1f5b, 0x1f5b}, {0x1f5d, 0x1f5d}, {0x1f5f, 0x1f7d}, {0x1f80, 0x1fb4}, {0x1fb6, 0x1fbc}, {0x1fbe, 0x1fbe}, {0x1fc2, 0x1fc4}, {0x1fc6, 0x1fcc},
  {0x1fd0, 0x1fd3}, {0x1fd6, 0x1fdb}, {0x1fe0, 0x1fec}, {0x1ff2, 0x1ff4}, {0x1ff6, 0x1ffc}, {0x2071, 0x2071}, {0x207f, 0x207f}, {0x2090, 0x209c},
  {0x2102, 0x2102}, {0x2107, 0x2107}, {0x210a, 0x2113}, {0x2115, 0x2115}, {0x2118, 0x211d}, {0x2124, 0x2124}, {0x2126, 0x2126}, {0x2128, 0x2128},
  {0x212a, 0x2139}, {0x213c, 0x213f}, {0x2145, 0x2149}, {0x214e, 0x214e}, {0x2160, 0x2188}, {0x2c00, 0x2ce4}, {0x2ceb, 0x2cee}, {0x2cf2, 0x2cf3},
  {0x2d00, 0x2d25}, {0x2d27, 0x2d27}, {0x2d2d, 0x2d2d}, {0x2d30, 0x2d67}, {0x2d6f, 0x2d6f}, {0x2d80, 0x2d96}, {0x2da0, 0x2da6}, {0x2da8, 0x2dae},
  {0x2db0, 0x2db6}, {0x2db8, 0x2dbe}, {0x2dc0, 0x2dc6}, {0x2dc8, 0x2dce}, {0x2dd0, 0x2dd6}, {0x2dd8, 0x2dde}, {0x3005, 0x3007}, {0x3021, 0x3029},
  {0x3031, 0x3035}, {0x3038, 0x303c}, {0x3041, 0x3096}, {0x309d, 0x309f}, {0x30a1, 0x30fa}, {0x30fc, 0x30ff}, {0x3105, 0x312f}, {0x3131, 0x318e},
  {0x31a0, 0x31bf}, {0x31f0, 0x31ff}, {0x3400, 0x4dbf}, {0x4e00, 0xa48c}, {0xa4d0, 0xa4fd}, {0xa500, 0xa60c}, {0xa610, 0xa61f}, {0xa62a, 0xa62b},
  {0xa640, 0xa66e}, {0xa67f, 0xa69d}, {0xa6a0, 0xa6ef}, {0xa717, 0xa71f}, {0xa722, 0xa788}, {0xa78b, 0xa7ca}, {0xa7d0, 0xa7d1}, {0xa7d3, 0xa7d3},
  {0xa7d5, 0xa7d9}, {0xa7f2, 0xa801}, {0xa803, 0xa805}, {0xa807, 0xa80a}, {0xa80c, 0xa822}, {0xa840, 0xa873}, {0xa882, 0xa8b3}, {0xa8f2, 0xa8f7},
  {0xa8fb, 0xa8fb}, {0xa8fd, 0xa8fe}, {0xa90a, 0xa925}, {0xa930, 0xa946}, {0xa960, 0xa97c}, {0xa984, 0xa9b2}, {0xa9cf, 0xa9cf}, {0xa9e0, 0xa9e4},
  {0xa9e6, 0xa9ef}, {0xa9fa, 0xa9fe}, {0xaa00, 0xaa28}, {0xaa40, 0xaa42}, {0xaa44, 0xaa4b}, {0xaa60, 0xaa76}, {0xaa7a, 0xaa7a}, {0xaa7e, 0xaaaf},
  {0xaab1, 0xaab1}, {0xaab5, 0xaab6}, {0xaab9, 0xaabd}, {0xaac0, 0xaac0}, {0xaac2, 0xaac2}, {0xaadb, 0xaadd}, {0xaae0, 0xaaea}, {0xaaf2, 0xaaf4},
  {0xab01, 0xab06}, {0xab09, 0xab0e}, {0xab11, 0xab16}, {0xab20, 0xab26}, {0xab28, 0xab2e}, {0xab30, 0xab5a}, {0xab5c, 0xab69}, {0xab70, 0xabe2},
  {0xac00, 0xd7a3}, {0xd7b0, 0xd7c6}, {0xd7cb, 0xd7fb}, {0xf900, 0xfa6d}, {0xfa70, 0xfad9}, {0xfb00, 0xfb06}, {0xfb13, 0xfb17}, {0xfb1d, 0xfb1d},
  {0xfb1f, 0xfb28}, {0xfb2a, 0xfb36}, {0xfb38, 0xfb3c}, {0xfb3e, 0xfb3e}, {0xfb40, 0xfb41}, {0xfb43, 0xfb44}, {0xfb46, 0xfbb1}, {0xfbd3, 0xfc5d},
  {0xfc64, 0xfd3d}, {0xfd50, 0xfd8f}, {0xfd92, 0xfdc7}, {0xfdf0, 0xfdf9}, {0xfe71, 0xfe71}, {0xfe73, 0xfe73}, {0xfe77, 0xfe77}, {0xfe79, 0xfe79},
  {0xfe7b, 0xfe7b}, {0xfe7d, 0xfe7d}, {0xfe7f, 0xfefc}, {0xff21, 0xff3a}, {0xff41, 0xff5a}, {0xff66, 0xff9d}, {0xffa0, 0xffbe}, {0xffc2, 0xffc7},
  {0xffca, 0xffcf}, {0xffd2, 0xffd7}, {0xffda, 0xffdc}, {0x10000, 0x1000b}, {0x1000d, 0x10026}, {0x10028, 0x1003a}, {0x1003c, 0x1003d}, {0x1003f, 0x1004d},
  {0x10050, 0x1005d}, {0x10080, 0x100fa}, {0x10140, 0x10174}, {0x10280, 0x1029c}, {0x102a0, 0x102d0}, {0x10300, 0x1031f}, {0x1032d, 0x1034a}, {0x10350, 0x10375},
  {0x10380, 0x1039d}, {0x103a0, 0x103c3}, {0x103c8, 0x103cf}, {0x103d1, 0x103d5}, {0x10400, 0x1049d}, {0x104b0, 0x104d3}, {0x104d8, 0x104fb}, {0x10500, 0x10527},
  {0x10530, 0x10563}, {0x10570, 0x1057a}, {0x1057c, 0x1058a}, {0x1058c, 0x10592}, {0x10594, 0x10595}, {0x10597, 0x105a1}, {0x105a3, 0x105b1}, {0x105b3, 0x105b9},
  {0x105bb, 0x105bc}, {0x10600, 0x10736}, {0x10740, 0x10755}, {0x10760, 0x10767}, {0x10780, 0x10785}, {0x10787, 0x107b0}, {0x107b2, 0x107ba}, {0x10800, 0x10805},
  {0x10808, 0x10808}, {0x1080a, 0x10835}, {0x10837, 0x10838}, {0x1083c, 0x1083c}, {0x1083f, 0x10855}, {0x10860, 0x10876}, {0x10880, 0x1089e}, {0x108e0, 0x108f2},
  {0x108f4, 0x108f5}, {0x10900, 0x10915}, {0x10920, 0x10939}, {0x10980, 0x109b7}, {0x109be, 0x109bf}, {0x10a00, 0x10a00}, {0x10a10, 0x10a13}, {0x10a15, 0x10a17},
  {0x10a19, 0x10a35}, {0x10a60, 0x10a7c}, {0x10a80, 0x10a9c}, {0x10ac0, 0x10ac7}, {0x10ac9, 0x10ae4}, {0x10b00, 0x10b35}, {0x10b40, 0x10b55}, {0x10b60, 0x10b72},
  {0x10b80, 0x10b91}, {0x10c00, 0x10c48}, {0x10c80, 0x10cb2}, {0x10cc0, 0x10cf2}, {0x10d00, 0x10d23}, {0x10e80, 0x10ea9}, {0x10eb0, 0x10eb1}, {0x10f00, 0x10f1c},
  {0x10f27, 0x10f27}, {0x10f30, 0x10f45}, {0x10f70, 0x10f81}, {0x10fb0, 0x10fc4}, {0x10fe0, 0x10ff6}, {0x11003, 0x11037}, {0x11071, 0x11072}, {0x11075, 0x11075},
  {0x11083, 0x110af}, {0x110d0, 0x110e8}, {0x11103, 0x11126}, {0x11144, 0x11144}, {0x11147, 0x11147}, {0x11150, 0x11172}, {0x11176, 0x11176}, {0x11183, 0x111b2},
  {0x111c1, 0x111c4}, {0x111da, 0x111da}, {0x111dc, 0x111dc}, {0x11200, 0x11211}, {0x11213, 0x1122b}, {0x1123f, 0x11240}, {0x11280, 0x11286}, {0x11288, 0x11288},
  {0x1128a, 0x1128d}, {0x1128f, 0x1129d}, {0x1129f, 0x112a8}, {0x112b0, 0x112de}, {0x11305, 0x1130c}, {0x1130f, 0x11310}, {0x11313, 0x11328}, {0x1132a, 0x11330},
  {0x11332, 0x11333}, {0x11335, 0x11339}, {0x1133d, 0x1133d}, {0x11350, 0x11350}, {0x1135d, 0x11361}, {0x11400, 0x11434}, {0x11447, 0x1144a}, {0x1145f, 0x11461},
  {0x11480, 0x114af}, {0x114c4, 0x114c5}, {0x114c7, 0x114c7}, {0x11580, 0x115ae}, {0x115d8, 0x115db}, {0x11600, 0x1162f}, {0x11644, 0x11644}, {0x11680, 0x116aa},
  {0x116b8, 0x116b8}, {0x11700, 0x1171a}, {0x11740, 0x11746}, {0x11800, 0x1182b}, {0x118a0, 0x118df}, {0x118ff, 0x11906}, {0x11909, 0x11909}, {0x1190c, 0x11913},
  {0x11915, 0x11916}, {0x11918, 0x1192f}, {0x1193f, 0x1193f}, {0x11941, 0x11941}, {0x119a0, 0x119a7}, {0x119aa, 0x119d0}, {0x119e1, 0x119e1}, {0x119e3, 0x119e3},
  {0x11a00, 0x11a00}, {0x11a0b, 0x11a32}, {0x11a3a, 0x11a3a}, {0x11a50, 0x11a50}, {0x11a5c, 0x11a89}, {0x11a9d, 0x11a9d}, {0x11ab0, 0x11af8}, {0x11c00, 0x11c08},
  {0x11c0a, 0x11c2e}, {0x11c40, 0x11c40}, {0x11c72, 0x11c8f}, {0x11d00, 0x11d06}, {0x11d08, 0x11d09}, {0x11d0b, 0x11d30}, {0x11d46, 0x11d46}, {0x11d60, 0x11d65},
  {0x11d67, 0x11d68}, {0x11d6a, 0x11d89}, {0x11d98, 0x11d98}, {0x11ee0, 0x11ef2}, {0x11f02, 0x11f02}, {0x11f04, 0x11f10}, {0x11f12, 0x11f33}, {0x11fb0, 0x11fb0},
  {0x12000, 0x12399}, {0x12400, 0x1246e}, {0x12480, 0x12543}, {0x12f90, 0x12ff0}, {0x13000, 0x1342f}, {0x13441, 0x13446}, {0x14400, 0x14646}, {0x16800, 0x16a38},
  {0x16a40, 0x16a5e}, {0x16a70, 0x16abe}, {0x16ad0, 0x16aed}, {0x16b00, 0x16b2f}, {0x16b40, 0x16b43}, {0x16b63, 0x16b77}, {0x16b7d, 0x16b8f}, {0x16e40, 0x16e7f},
  {0x16f00, 0x16f4a}, {0x16f50, 0x16f50}, {0x16f93, 0x16f9f}, {0x16fe0, 0x16fe1}, {0x16fe3, 0x16fe3}, {0x17000, 0x187f7}, {0x18800, 0x18cd5}, {0x18d00, 0x18d08},
  {0x1aff0, 0x1aff3}, {0x1aff5, 0x1affb}, {0x1affd, 0x1affe}, {0x1b000, 0x1b122}, {0x1b132, 0x1b132}, {0x1b150, 0x1b152}, {0x1b155, 0x1b155}, {0x1b164, 0x1b167},
  {0x1b170, 0x1b2fb}, {0x1bc00, 0x1bc6a}, {0x1bc70, 0x1bc7c}, {0x1bc80, 0x1bc88}, {0x1bc90, 0x1bc99}, {0x1d400, 0x1d454}, {0x1d456, 0x1d49c}, {0x1d49e, 0x1d49f},
  {0x1d4a2, 0x1d4a2}, {0x1d4a5, 0x1d4a6}, {0x1d4a9, 0x1d4ac}, {0x1d4ae, 0x1d4b9}, {0x1d4bb, 0x1d4bb}, {0x1d4bd, 0x1d4c3}, {0x1d4c5, 0x1d505}, {0x1d507, 0x1d50a},
  {0x1d50d, 0x1d514}, {0x1d516, 0x1d51c}, {0x1d51e, 0x1d539}, {0x1d53b, 0x1d53e}, {0x1d540, 0x1d544}, {0x1d546, 0x1d546}, {0x1d54a, 0x1d550}, {0x1d552, 0x1d6a5},
  {0x1d6a8, 0x1d6c0}, {0x1d6c2, 0x1d6da}, {0x1d6dc, 0x1d6fa}, {0x1d6fc, 0x1d714}, {0x1d716, 0x1d734}, {0x1d736, 0x1d74e}, {0x1d750, 0x1d76e}, {0x1d770, 0x1d788},
  {0x1d78a, 0x1d7a8}, {0x1d7aa, 0x1d7c2}, {0x1d7c4, 0x1d7cb}, {0x1df00, 0x1df1e}, {0x1df25, 0x1df2a}, {0x1e030, 0x1e06d}, {0x1e100, 0x1e12c}, {0x1e137, 0x1e13d},
  {0x1e14e, 0x1e14e}, {0x1e290, 0x1e2ad}, {0x1e2c0, 0x1e2eb}, {0x1e4d0, 0x1e4eb}, {0x1e7e0, 0x1e7e6}, {0x1e7e8, 0x1e7eb}, {0x1e7ed, 0x1e7ee}, {0x1e7f0, 0x1e7fe},
  {0x1e800, 0x1e8c4}, {0x1e900, 0x1e943}, {0x1e94b, 0x1e94b}, {0x1ee00, 0x1ee03}, {0x1ee05, 0x1ee1f}, {0x1ee21, 0x1ee22}, {0x1ee24, 0x1ee24}, {0x1ee27, 0x1ee27},
  {0x1ee29, 0x1ee32}, {0x1ee34, 0x1ee37}, {0x1ee39, 0x1ee39}, {0x1ee3b, 0x1ee3b}, {0x1ee42, 0x1ee42}, {0x1ee47, 0x1ee47}, {0x1ee49, 0x1ee49}, {0x1ee4b, 0x1ee4b},
  {0x1ee4d, 0x1ee4f}, {0x1ee51, 0x1ee52}, {0x1ee54, 0x1ee54}, {0x1ee57, 0x1ee57}, {0x1ee59, 0x1ee59}, {0x1ee5b, 0x1ee5b}, {0x1ee5d, 0x1ee5d}, {0x1ee5f, 0x1ee5f},
  {0x1ee61, 0x1ee62}, {0x1ee64, 0x1ee64}, {0x1ee67, 0x1ee6a}, {0x1ee6c, 0x1ee72}, {0x1ee74, 0x1ee77}, {0x1ee79, 0x1ee7c}, {0x1ee7e, 0x1ee7e}, {0x1ee80, 0x1ee89},
  {0x1ee8b, 0x1ee9b}, {0x1eea1, 0x1eea3}, {0x1eea5, 0x1eea9}, {0x1eeab, 0x1eebb}, {0x20000, 0x2a6df}, {0x2a700, 0x2b739}, {0x2b740, 0x2b81d}, {0x2b820, 0x2cea1},
  {0x2ceb0, 0x2ebe0}, {0x2ebf0, 0x2ee5d}, {0x2f800, 0x2fa1d}, {0x30000, 0x3134a}, {0x31350, 0x323af},
};

static TSCharacterRange sym__identifier_token_character_set_3[] = {
  {'0', '9'}, {'A', 'Z'}, {'\\', '\\'}, {'_', '_'}, {'a', 'z'}, {0xaa, 0xaa}, {0xb5, 0xb5}, {0xb7, 0xb7},
  {0xba, 0xba}, {0xc0, 0xd6}, {0xd8, 0xf6}, {0xf8, 0x2c1}, {0x2c6, 0x2d1}, {0x2e0, 0x2e4}, {0x2ec, 0x2ec}, {0x2ee, 0x2ee},
  {0x300, 0x374}, {0x376, 0x377}, {0x37b, 0x37d}, {0x37f, 0x37f}, {0x386, 0x38a}, {0x38c, 0x38c}, {0x38e, 0x3a1}, {0x3a3, 0x3f5},
  {0x3f7, 0x481}, {0x483, 0x487}, {0x48a, 0x52f}, {0x531, 0x556}, {0x559, 0x559}, {0x560, 0x588}, {0x591, 0x5bd}, {0x5bf, 0x5bf},
  {0x5c1, 0x5c2}, {0x5c4, 0x5c5}, {0x5c7, 0x5c7}, {0x5d0, 0x5ea}, {0x5ef, 0x5f2}, {0x610, 0x61a}, {0x620, 0x669}, {0x66e, 0x6d3},
  {0x6d5, 0x6dc}, {0x6df, 0x6e8}, {0x6ea, 0x6fc}, {0x6ff, 0x6ff}, {0x710, 0x74a}, {0x74d, 0x7b1}, {0x7c0, 0x7f5}, {0x7fa, 0x7fa},
  {0x7fd, 0x7fd}, {0x800, 0x82d}, {0x840, 0x85b}, {0x860, 0x86a}, {0x870, 0x887}, {0x889, 0x88e}, {0x898, 0x8e1}, {0x8e3, 0x963},
  {0x966, 0x96f}, {0x971, 0x983}, {0x985, 0x98c}, {0x98f, 0x990}, {0x993, 0x9a8}, {0x9aa, 0x9b0}, {0x9b2, 0x9b2}, {0x9b6, 0x9b9},
  {0x9bc, 0x9c4}, {0x9c7, 0x9c8}, {0x9cb, 0x9ce}, {0x9d7, 0x9d7}, {0x9dc, 0x9dd}, {0x9df, 0x9e3}, {0x9e6, 0x9f1}, {0x9fc, 0x9fc},
  {0x9fe, 0x9fe}, {0xa01, 0xa03}, {0xa05, 0xa0a}, {0xa0f, 0xa10}, {0xa13, 0xa28}, {0xa2a, 0xa30}, {0xa32, 0xa33}, {0xa35, 0xa36},
  {0xa38, 0xa39}, {0xa3c, 0xa3c}, {0xa3e, 0xa42}, {0xa47, 0xa48}, {0xa4b, 0xa4d}, {0xa51, 0xa51}, {0xa59, 0xa5c}, {0xa5e, 0xa5e},
  {0xa66, 0xa75}, {0xa81, 0xa83}, {0xa85, 0xa8d}, {0xa8f, 0xa91}, {0xa93, 0xaa8}, {0xaaa, 0xab0}, {0xab2, 0xab3}, {0xab5, 0xab9},
  {0xabc, 0xac5}, {0xac7, 0xac9}, {0xacb, 0xacd}, {0xad0, 0xad0}, {0xae0, 0xae3}, {0xae6, 0xaef}, {0xaf9, 0xaff}, {0xb01, 0xb03},
  {0xb05, 0xb0c}, {0xb0f, 0xb10}, {0xb13, 0xb28}, {0xb2a, 0xb30}, {0xb32, 0xb33}, {0xb35, 0xb39}, {0xb3c, 0xb44}, {0xb47, 0xb48},
  {0xb4b, 0xb4d}, {0xb55, 0xb57}, {0xb5c, 0xb5d}, {0xb5f, 0xb63}, {0xb66, 0xb6f}, {0xb71, 0xb71}, {0xb82, 0xb83}, {0xb85, 0xb8a},
  {0xb8e, 0xb90}, {0xb92, 0xb95}, {0xb99, 0xb9a}, {0xb9c, 0xb9c}, {0xb9e, 0xb9f}, {0xba3, 0xba4}, {0xba8, 0xbaa}, {0xbae, 0xbb9},
  {0xbbe, 0xbc2}, {0xbc6, 0xbc8}, {0xbca, 0xbcd}, {0xbd0, 0xbd0}, {0xbd7, 0xbd7}, {0xbe6, 0xbef}, {0xc00, 0xc0c}, {0xc0e, 0xc10},
  {0xc12, 0xc28}, {0xc2a, 0xc39}, {0xc3c, 0xc44}, {0xc46, 0xc48}, {0xc4a, 0xc4d}, {0xc55, 0xc56}, {0xc58, 0xc5a}, {0xc5d, 0xc5d},
  {0xc60, 0xc63}, {0xc66, 0xc6f}, {0xc80, 0xc83}, {0xc85, 0xc8c}, {0xc8e, 0xc90}, {0xc92, 0xca8}, {0xcaa, 0xcb3}, {0xcb5, 0xcb9},
  {0xcbc, 0xcc4}, {0xcc6, 0xcc8}, {0xcca, 0xccd}, {0xcd5, 0xcd6}, {0xcdd, 0xcde}, {0xce0, 0xce3}, {0xce6, 0xcef}, {0xcf1, 0xcf3},
  {0xd00, 0xd0c}, {0xd0e, 0xd10}, {0xd12, 0xd44}, {0xd46, 0xd48}, {0xd4a, 0xd4e}, {0xd54, 0xd57}, {0xd5f, 0xd63}, {0xd66, 0xd6f},
  {0xd7a, 0xd7f}, {0xd81, 0xd83}, {0xd85, 0xd96}, {0xd9a, 0xdb1}, {0xdb3, 0xdbb}, {0xdbd, 0xdbd}, {0xdc0, 0xdc6}, {0xdca, 0xdca},
  {0xdcf, 0xdd4}, {0xdd6, 0xdd6}, {0xdd8, 0xddf}, {0xde6, 0xdef}, {0xdf2, 0xdf3}, {0xe01, 0xe3a}, {0xe40, 0xe4e}, {0xe50, 0xe59},
  {0xe81, 0xe82}, {0xe84, 0xe84}, {0xe86, 0xe8a}, {0xe8c, 0xea3}, {0xea5, 0xea5}, {0xea7, 0xebd}, {0xec0, 0xec4}, {0xec6, 0xec6},
  {0xec8, 0xece}, {0xed0, 0xed9}, {0xedc, 0xedf}, {0xf00, 0xf00}, {0xf18, 0xf19}, {0xf20, 0xf29}, {0xf35, 0xf35}, {0xf37, 0xf37},
  {0xf39, 0xf39}, {0xf3e, 0xf47}, {0xf49, 0xf6c}, {0xf71, 0xf84}, {0xf86, 0xf97}, {0xf99, 0xfbc}, {0xfc6, 0xfc6}, {0x1000, 0x1049},
  {0x1050, 0x109d}, {0x10a0, 0x10c5}, {0x10c7, 0x10c7}, {0x10cd, 0x10cd}, {0x10d0, 0x10fa}, {0x10fc, 0x1248}, {0x124a, 0x124d}, {0x1250, 0x1256},
  {0x1258, 0x1258}, {0x125a, 0x125d}, {0x1260, 0x1288}, {0x128a, 0x128d}, {0x1290, 0x12b0}, {0x12b2, 0x12b5}, {0x12b8, 0x12be}, {0x12c0, 0x12c0},
  {0x12c2, 0x12c5}, {0x12c8, 0x12d6}, {0x12d8, 0x1310}, {0x1312, 0x1315}, {0x1318, 0x135a}, {0x135d, 0x135f}, {0x1369, 0x1371}, {0x1380, 0x138f},
  {0x13a0, 0x13f5}, {0x13f8, 0x13fd}, {0x1401, 0x166c}, {0x166f, 0x167f}, {0x1681, 0x169a}, {0x16a0, 0x16ea}, {0x16ee, 0x16f8}, {0x1700, 0x1715},
  {0x171f, 0x1734}, {0x1740, 0x1753}, {0x1760, 0x176c}, {0x176e, 0x1770}, {0x1772, 0x1773}, {0x1780, 0x17d3}, {0x17d7, 0x17d7}, {0x17dc, 0x17dd},
  {0x17e0, 0x17e9}, {0x180b, 0x180d}, {0x180f, 0x1819}, {0x1820, 0x1878}, {0x1880, 0x18aa}, {0x18b0, 0x18f5}, {0x1900, 0x191e}, {0x1920, 0x192b},
  {0x1930, 0x193b}, {0x1946, 0x196d}, {0x1970, 0x1974}, {0x1980, 0x19ab}, {0x19b0, 0x19c9}, {0x19d0, 0x19da}, {0x1a00, 0x1a1b}, {0x1a20, 0x1a5e},
  {0x1a60, 0x1a7c}, {0x1a7f, 0x1a89}, {0x1a90, 0x1a99}, {0x1aa7, 0x1aa7}, {0x1ab0, 0x1abd}, {0x1abf, 0x1ace}, {0x1b00, 0x1b4c}, {0x1b50, 0x1b59},
  {0x1b6b, 0x1b73}, {0x1b80, 0x1bf3}, {0x1c00, 0x1c37}, {0x1c40, 0x1c49}, {0x1c4d, 0x1c7d}, {0x1c80, 0x1c88}, {0x1c90, 0x1cba}, {0x1cbd, 0x1cbf},
  {0x1cd0, 0x1cd2}, {0x1cd4, 0x1cfa}, {0x1d00, 0x1f15}, {0x1f18, 0x1f1d}, {0x1f20, 0x1f45}, {0x1f48, 0x1f4d}, {0x1f50, 0x1f57}, {0x1f59, 0x1f59},
  {0x1f5b, 0x1f5b}, {0x1f5d, 0x1f5d}, {0x1f5f, 0x1f7d}, {0x1f80, 0x1fb4}, {0x1fb6, 0x1fbc}, {0x1fbe, 0x1fbe}, {0x1fc2, 0x1fc4}, {0x1fc6, 0x1fcc},
  {0x1fd0, 0x1fd3}, {0x1fd6, 0x1fdb}, {0x1fe0, 0x1fec}, {0x1ff2, 0x1ff4}, {0x1ff6, 0x1ffc}, {0x200c, 0x200d}, {0x203f, 0x2040}, {0x2054, 0x2054},
  {0x2071, 0x2071}, {0x207f, 0x207f}, {0x2090, 0x209c}, {0x20d0, 0x20dc}, {0x20e1, 0x20e1}, {0x20e5, 0x20f0}, {0x2102, 0x2102}, {0x2107, 0x2107},
  {0x210a, 0x2113}, {0x2115, 0x2115}, {0x2118, 0x211d}, {0x2124, 0x2124}, {0x2126, 0x2126}, {0x2128, 0x2128}, {0x212a, 0x2139}, {0x213c, 0x213f},
  {0x2145, 0x2149}, {0x214e, 0x214e}, {0x2160, 0x2188}, {0x2c00, 0x2ce4}, {0x2ceb, 0x2cf3}, {0x2d00, 0x2d25}, {0x2d27, 0x2d27}, {0x2d2d, 0x2d2d},
  {0x2d30, 0x2d67}, {0x2d6f, 0x2d6f}, {0x2d7f, 0x2d96}, {0x2da0, 0x2da6}, {0x2da8, 0x2dae}, {0x2db0, 0x2db6}, {0x2db8, 0x2dbe}, {0x2dc0, 0x2dc6},
  {0x2dc8, 0x2dce}, {0x2dd0, 0x2dd6}, {0x2dd8, 0x2dde}, {0x2de0, 0x2dff}, {0x3005, 0x3007}, {0x3021, 0x302f}, {0x3031, 0x3035}, {0x3038, 0x303c},
  {0x3041, 0x3096}, {0x3099, 0x309a}, {0x309d, 0x309f}, {0x30a1, 0x30ff}, {0x3105, 0x312f}, {0x3131, 0x318e}, {0x31a0, 0x31bf}, {0x31f0, 0x31ff},
  {0x3400, 0x4dbf}, {0x4e00, 0xa48c}, {0xa4d0, 0xa4fd}, {0xa500, 0xa60c}, {0xa610, 0xa62b}, {0xa640, 0xa66f}, {0xa674, 0xa67d}, {0xa67f, 0xa6f1},
  {0xa717, 0xa71f}, {0xa722, 0xa788}, {0xa78b, 0xa7ca}, {0xa7d0, 0xa7d1}, {0xa7d3, 0xa7d3}, {0xa7d5, 0xa7d9}, {0xa7f2, 0xa827}, {0xa82c, 0xa82c},
  {0xa840, 0xa873}, {0xa880, 0xa8c5}, {0xa8d0, 0xa8d9}, {0xa8e0, 0xa8f7}, {0xa8fb, 0xa8fb}, {0xa8fd, 0xa92d}, {0xa930, 0xa953}, {0xa960, 0xa97c},
  {0xa980, 0xa9c0}, {0xa9cf, 0xa9d9}, {0xa9e0, 0xa9fe}, {0xaa00, 0xaa36}, {0xaa40, 0xaa4d}, {0xaa50, 0xaa59}, {0xaa60, 0xaa76}, {0xaa7a, 0xaac2},
  {0xaadb, 0xaadd}, {0xaae0, 0xaaef}, {0xaaf2, 0xaaf6}, {0xab01, 0xab06}, {0xab09, 0xab0e}, {0xab11, 0xab16}, {0xab20, 0xab26}, {0xab28, 0xab2e},
  {0xab30, 0xab5a}, {0xab5c, 0xab69}, {0xab70, 0xabea}, {0xabec, 0xabed}, {0xabf0, 0xabf9}, {0xac00, 0xd7a3}, {0xd7b0, 0xd7c6}, {0xd7cb, 0xd7fb},
  {0xf900, 0xfa6d}, {0xfa70, 0xfad9}, {0xfb00, 0xfb06}, {0xfb13, 0xfb17}, {0xfb1d, 0xfb28}, {0xfb2a, 0xfb36}, {0xfb38, 0xfb3c}, {0xfb3e, 0xfb3e},
  {0xfb40, 0xfb41}, {0xfb43, 0xfb44}, {0xfb46, 0xfbb1}, {0xfbd3, 0xfc5d}, {0xfc64, 0xfd3d}, {0xfd50, 0xfd8f}, {0xfd92, 0xfdc7}, {0xfdf0, 0xfdf9},
  {0xfe00, 0xfe0f}, {0xfe20, 0xfe2f}, {0xfe33, 0xfe34}, {0xfe4d, 0xfe4f}, {0xfe71, 0xfe71}, {0xfe73, 0xfe73}, {0xfe77, 0xfe77}, {0xfe79, 0xfe79},
  {0xfe7b, 0xfe7b}, {0xfe7d, 0xfe7d}, {0xfe7f, 0xfefc}, {0xff10, 0xff19}, {0xff21, 0xff3a}, {0xff3f, 0xff3f}, {0xff41, 0xff5a}, {0xff65, 0xffbe},
  {0xffc2, 0xffc7}, {0xffca, 0xffcf}, {0xffd2, 0xffd7}, {0xffda, 0xffdc}, {0x10000, 0x1000b}, {0x1000d, 0x10026}, {0x10028, 0x1003a}, {0x1003c, 0x1003d},
  {0x1003f, 0x1004d}, {0x10050, 0x1005d}, {0x10080, 0x100fa}, {0x10140, 0x10174}, {0x101fd, 0x101fd}, {0x10280, 0x1029c}, {0x102a0, 0x102d0}, {0x102e0, 0x102e0},
  {0x10300, 0x1031f}, {0x1032d, 0x1034a}, {0x10350, 0x1037a}, {0x10380, 0x1039d}, {0x103a0, 0x103c3}, {0x103c8, 0x103cf}, {0x103d1, 0x103d5}, {0x10400, 0x1049d},
  {0x104a0, 0x104a9}, {0x104b0, 0x104d3}, {0x104d8, 0x104fb}, {0x10500, 0x10527}, {0x10530, 0x10563}, {0x10570, 0x1057a}, {0x1057c, 0x1058a}, {0x1058c, 0x10592},
  {0x10594, 0x10595}, {0x10597, 0x105a1}, {0x105a3, 0x105b1}, {0x105b3, 0x105b9}, {0x105bb, 0x105bc}, {0x10600, 0x10736}, {0x10740, 0x10755}, {0x10760, 0x10767},
  {0x10780, 0x10785}, {0x10787, 0x107b0}, {0x107b2, 0x107ba}, {0x10800, 0x10805}, {0x10808, 0x10808}, {0x1080a, 0x10835}, {0x10837, 0x10838}, {0x1083c, 0x1083c},
  {0x1083f, 0x10855}, {0x10860, 0x10876}, {0x10880, 0x1089e}, {0x108e0, 0x108f2}, {0x108f4, 0x108f5}, {0x10900, 0x10915}, {0x10920, 0x10939}, {0x10980, 0x109b7},
  {0x109be, 0x109bf}, {0x10a00, 0x10a03}, {0x10a05, 0x10a06}, {0x10a0c, 0x10a13}, {0x10a15, 0x10a17}, {0x10a19, 0x10a35}, {0x10a38, 0x10a3a}, {0x10a3f, 0x10a3f},
  {0x10a60, 0x10a7c}, {0x10a80, 0x10a9c}, {0x10ac0, 0x10ac7}, {0x10ac9, 0x10ae6}, {0x10b00, 0x10b35}, {0x10b40, 0x10b55}, {0x10b60, 0x10b72}, {0x10b80, 0x10b91},
  {0x10c00, 0x10c48}, {0x10c80, 0x10cb2}, {0x10cc0, 0x10cf2}, {0x10d00, 0x10d27}, {0x10d30, 0x10d39}, {0x10e80, 0x10ea9}, {0x10eab, 0x10eac}, {0x10eb0, 0x10eb1},
  {0x10efd, 0x10f1c}, {0x10f27, 0x10f27}, {0x10f30, 0x10f50}, {0x10f70, 0x10f85}, {0x10fb0, 0x10fc4}, {0x10fe0, 0x10ff6}, {0x11000, 0x11046}, {0x11066, 0x11075},
  {0x1107f, 0x110ba}, {0x110c2, 0x110c2}, {0x110d0, 0x110e8}, {0x110f0, 0x110f9}, {0x11100, 0x11134}, {0x11136, 0x1113f}, {0x11144, 0x11147}, {0x11150, 0x11173},
  {0x11176, 0x11176}, {0x11180, 0x111c4}, {0x111c9, 0x111cc}, {0x111ce, 0x111da}, {0x111dc, 0x111dc}, {0x11200, 0x11211}, {0x11213, 0x11237}, {0x1123e, 0x11241},
  {0x11280, 0x11286}, {0x11288, 0x11288}, {0x1128a, 0x1128d}, {0x1128f, 0x1129d}, {0x1129f, 0x112a8}, {0x112b0, 0x112ea}, {0x112f0, 0x112f9}, {0x11300, 0x11303},
  {0x11305, 0x1130c}, {0x1130f, 0x11310}, {0x11313, 0x11328}, {0x1132a, 0x11330}, {0x11332, 0x11333}, {0x11335, 0x11339}, {0x1133b, 0x11344}, {0x11347, 0x11348},
  {0x1134b, 0x1134d}, {0x11350, 0x11350}, {0x11357, 0x11357}, {0x1135d, 0x11363}, {0x11366, 0x1136c}, {0x11370, 0x11374}, {0x11400, 0x1144a}, {0x11450, 0x11459},
  {0x1145e, 0x11461}, {0x11480, 0x114c5}, {0x114c7, 0x114c7}, {0x114d0, 0x114d9}, {0x11580, 0x115b5}, {0x115b8, 0x115c0}, {0x115d8, 0x115dd}, {0x11600, 0x11640},
  {0x11644, 0x11644}, {0x11650, 0x11659}, {0x11680, 0x116b8}, {0x116c0, 0x116c9}, {0x11700, 0x1171a}, {0x1171d, 0x1172b}, {0x11730, 0x11739}, {0x11740, 0x11746},
  {0x11800, 0x1183a}, {0x118a0, 0x118e9}, {0x118ff, 0x11906}, {0x11909, 0x11909}, {0x1190c, 0x11913}, {0x11915, 0x11916}, {0x11918, 0x11935}, {0x11937, 0x11938},
  {0x1193b, 0x11943}, {0x11950, 0x11959}, {0x119a0, 0x119a7}, {0x119aa, 0x119d7}, {0x119da, 0x119e1}, {0x119e3, 0x119e4}, {0x11a00, 0x11a3e}, {0x11a47, 0x11a47},
  {0x11a50, 0x11a99}, {0x11a9d, 0x11a9d}, {0x11ab0, 0x11af8}, {0x11c00, 0x11c08}, {0x11c0a, 0x11c36}, {0x11c38, 0x11c40}, {0x11c50, 0x11c59}, {0x11c72, 0x11c8f},
  {0x11c92, 0x11ca7}, {0x11ca9, 0x11cb6}, {0x11d00, 0x11d06}, {0x11d08, 0x11d09}, {0x11d0b, 0x11d36}, {0x11d3a, 0x11d3a}, {0x11d3c, 0x11d3d}, {0x11d3f, 0x11d47},
  {0x11d50, 0x11d59}, {0x11d60, 0x11d65}, {0x11d67, 0x11d68}, {0x11d6a, 0x11d8e}, {0x11d90, 0x11d91}, {0x11d93, 0x11d98}, {0x11da0, 0x11da9}, {0x11ee0, 0x11ef6},
  {0x11f00, 0x11f10}, {0x11f12, 0x11f3a}, {0x11f3e, 0x11f42}, {0x11f50, 0x11f59}, {0x11fb0, 0x11fb0}, {0x12000, 0x12399}, {0x12400, 0x1246e}, {0x12480, 0x12543},
  {0x12f90, 0x12ff0}, {0x13000, 0x1342f}, {0x13440, 0x13455}, {0x14400, 0x14646}, {0x16800, 0x16a38}, {0x16a40, 0x16a5e}, {0x16a60, 0x16a69}, {0x16a70, 0x16abe},
  {0x16ac0, 0x16ac9}, {0x16ad0, 0x16aed}, {0x16af0, 0x16af4}, {0x16b00, 0x16b36}, {0x16b40, 0x16b43}, {0x16b50, 0x16b59}, {0x16b63, 0x16b77}, {0x16b7d, 0x16b8f},
  {0x16e40, 0x16e7f}, {0x16f00, 0x16f4a}, {0x16f4f, 0x16f87}, {0x16f8f, 0x16f9f}, {0x16fe0, 0x16fe1}, {0x16fe3, 0x16fe4}, {0x16ff0, 0x16ff1}, {0x17000, 0x187f7},
  {0x18800, 0x18cd5}, {0x18d00, 0x18d08}, {0x1aff0, 0x1aff3}, {0x1aff5, 0x1affb}, {0x1affd, 0x1affe}, {0x1b000, 0x1b122}, {0x1b132, 0x1b132}, {0x1b150, 0x1b152},
  {0x1b155, 0x1b155}, {0x1b164, 0x1b167}, {0x1b170, 0x1b2fb}, {0x1bc00, 0x1bc6a}, {0x1bc70, 0x1bc7c}, {0x1bc80, 0x1bc88}, {0x1bc90, 0x1bc99}, {0x1bc9d, 0x1bc9e},
  {0x1cf00, 0x1cf2d}, {0x1cf30, 0x1cf46}, {0x1d165, 0x1d169}, {0x1d16d, 0x1d172}, {0x1d17b, 0x1d182}, {0x1d185, 0x1d18b}, {0x1d1aa, 0x1d1ad}, {0x1d242, 0x1d244},
  {0x1d400, 0x1d454}, {0x1d456, 0x1d49c}, {0x1d49e, 0x1d49f}, {0x1d4a2, 0x1d4a2}, {0x1d4a5, 0x1d4a6}, {0x1d4a9, 0x1d4ac}, {0x1d4ae, 0x1d4b9}, {0x1d4bb, 0x1d4bb},
  {0x1d4bd, 0x1d4c3}, {0x1d4c5, 0x1d505}, {0x1d507, 0x1d50a}, {0x1d50d, 0x1d514}, {0x1d516, 0x1d51c}, {0x1d51e, 0x1d539}, {0x1d53b, 0x1d53e}, {0x1d540, 0x1d544},
  {0x1d546, 0x1d546}, {0x1d54a, 0x1d550}, {0x1d552, 0x1d6a5}, {0x1d6a8, 0x1d6c0}, {0x1d6c2, 0x1d6da}, {0x1d6dc, 0x1d6fa}, {0x1d6fc, 0x1d714}, {0x1d716, 0x1d734},
  {0x1d736, 0x1d74e}, {0x1d750, 0x1d76e}, {0x1d770, 0x1d788}, {0x1d78a, 0x1d7a8}, {0x1d7aa, 0x1d7c2}, {0x1d7c4, 0x1d7cb}, {0x1d7ce, 0x1d7ff}, {0x1da00, 0x1da36},
  {0x1da3b, 0x1da6c}, {0x1da75, 0x1da75}, {0x1da84, 0x1da84}, {0x1da9b, 0x1da9f}, {0x1daa1, 0x1daaf}, {0x1df00, 0x1df1e}, {0x1df25, 0x1df2a}, {0x1e000, 0x1e006},
  {0x1e008, 0x1e018}, {0x1e01b, 0x1e021}, {0x1e023, 0x1e024}, {0x1e026, 0x1e02a}, {0x1e030, 0x1e06d}, {0x1e08f, 0x1e08f}, {0x1e100, 0x1e12c}, {0x1e130, 0x1e13d},
  {0x1e140, 0x1e149}, {0x1e14e, 0x1e14e}, {0x1e290, 0x1e2ae}, {0x1e2c0, 0x1e2f9}, {0x1e4d0, 0x1e4f9}, {0x1e7e0, 0x1e7e6}, {0x1e7e8, 0x1e7eb}, {0x1e7ed, 0x1e7ee},
  {0x1e7f0, 0x1e7fe}, {0x1e800, 0x1e8c4}, {0x1e8d0, 0x1e8d6}, {0x1e900, 0x1e94b}, {0x1e950, 0x1e959}, {0x1ee00, 0x1ee03}, {0x1ee05, 0x1ee1f}, {0x1ee21, 0x1ee22},
  {0x1ee24, 0x1ee24}, {0x1ee27, 0x1ee27}, {0x1ee29, 0x1ee32}, {0x1ee34, 0x1ee37}, {0x1ee39, 0x1ee39}, {0x1ee3b, 0x1ee3b}, {0x1ee42, 0x1ee42}, {0x1ee47, 0x1ee47},
  {0x1ee49, 0x1ee49}, {0x1ee4b, 0x1ee4b}, {0x1ee4d, 0x1ee4f}, {0x1ee51, 0x1ee52}, {0x1ee54, 0x1ee54}, {0x1ee57, 0x1ee57}, {0x1ee59, 0x1ee59}, {0x1ee5b, 0x1ee5b},
  {0x1ee5d, 0x1ee5d}, {0x1ee5f, 0x1ee5f}, {0x1ee61, 0x1ee62}, {0x1ee64, 0x1ee64}, {0x1ee67, 0x1ee6a}, {0x1ee6c, 0x1ee72}, {0x1ee74, 0x1ee77}, {0x1ee79, 0x1ee7c},
  {0x1ee7e, 0x1ee7e}, {0x1ee80, 0x1ee89}, {0x1ee8b, 0x1ee9b}, {0x1eea1, 0x1eea3}, {0x1eea5, 0x1eea9}, {0x1eeab, 0x1eebb}, {0x1fbf0, 0x1fbf9}, {0x20000, 0x2a6df},
  {0x2a700, 0x2b739}, {0x2b740, 0x2b81d}, {0x2b820, 0x2cea1}, {0x2ceb0, 0x2ebe0}, {0x2ebf0, 0x2ee5d}, {0x2f800, 0x2fa1d}, {0x30000, 0x3134a}, {0x31350, 0x323af},
  {0xe0100, 0xe01ef},
};

static bool ts_lex(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (eof) ADVANCE(132);
      ADVANCE_MAP(
        '!', 157,
        '"', 274,
        '#', 9,
        '%', 172,
        '&', 180,
        '\'', 258,
        '(', 141,
        ')', 142,
        '*', 168,
        '+', 162,
        ',', 139,
        '-', 164,
        '.', 193,
        '/', 170,
        '0', 263,
        ':', 138,
        ';', 133,
        '<', 146,
        '=', 134,
        '>', 151,
        '?', 154,
        '@', 12,
        '[', 136,
        '\\', 30,
        ']', 140,
        '^', 174,
        '{', 143,
        '|', 176,
        '}', 144,
        '~', 158,
        'U', 332,
        'u', 332,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ' ||
          lookahead == 0xa0 ||
          lookahead == 0x3000 ||
          lookahead == 0xfeff) SKIP(129);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(264);
      if (set_contains(sym__identifier_token_character_set_2, 669, lookahead)) ADVANCE(333);
      END_STATE();
    case 1:
      ADVANCE_MAP(
        '\n', 335,
        '!', 25,
        '"', 274,
        '#', 48,
        '&', 19,
        ',', 139,
        '/', 20,
        '0', 267,
        '=', 26,
        '@', 35,
        '\\', 31,
        '|', 98,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ' ||
          lookahead == 0xa0 ||
          lookahead == 0x3000 ||
          lookahead == 0xfeff) SKIP(1);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(268);
      if (set_contains(sym__identifier_token_character_set_2, 669, lookahead)) ADVANCE(333);
      END_STATE();
    case 2:
      if (lookahead == '\n') SKIP(11);
      if (lookahead == '"') ADVANCE(274);
      if (lookahead == '#') ADVANCE(285);
      if (lookahead == '/') ADVANCE(277);
      if (lookahead == '\\') ADVANCE(32);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ' ||
          lookahead == 0xa0 ||
          lookahead == 0x3000 ||
          lookahead == 0xfeff) ADVANCE(276);
      if (lookahead != 0) ADVANCE(318);
      END_STATE();
    case 3:
      if (lookahead == '\n') ADVANCE(336);
      if (lookahead == '#') ADVANCE(354);
      if (lookahead == '/') ADVANCE(346);
      if (lookahead == 0xa0 ||
          lookahead == 0x3000 ||
          lookahead == 0xfeff) ADVANCE(342);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(3);
      if (lookahead != 0) ADVANCE(396);
      END_STATE();
    case 4:
      ADVANCE_MAP(
        '!', 157,
        '"', 274,
        '#', 47,
        '%', 172,
        '&', 180,
        '(', 141,
        ')', 142,
        '*', 168,
        '+', 162,
        ',', 139,
        '-', 164,
        '.', 192,
        '/', 170,
        '0', 267,
        ':', 138,
        ';', 133,
        '<', 146,
        '=', 134,
        '>', 151,
        '?', 154,
        '@', 35,
        '[', 136,
        '\\', 31,
        ']', 140,
        '^', 174,
        '{', 143,
        '|', 176,
        '}', 144,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ' ||
          lookahead == 0xa0 ||
          lookahead == 0x3000 ||
          lookahead == 0xfeff) SKIP(4);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(268);
      if (set_contains(sym__identifier_token_character_set_2, 669, lookahead)) ADVANCE(333);
      END_STATE();
    case 5:
      ADVANCE_MAP(
        '!', 157,
        '#', 47,
        '%', 172,
        '&', 180,
        '(', 141,
        ')', 142,
        '*', 168,
        '+', 162,
        ',', 139,
        '-', 164,
        '.', 192,
        '/', 170,
        ':', 137,
        ';', 133,
        '<', 146,
        '=', 134,
        '>', 151,
        '?', 154,
        '@', 35,
        '[', 136,
        '\\', 31,
        ']', 140,
        '^', 174,
        '{', 143,
        '|', 176,
        '}', 144,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ' ||
          lookahead == 0xa0 ||
          lookahead == 0x3000 ||
          lookahead == 0xfeff) SKIP(5);
      if (set_contains(sym__identifier_token_character_set_2, 669, lookahead)) ADVANCE(333);
      END_STATE();
    case 6:
      ADVANCE_MAP(
        '!', 157,
        '#', 47,
        '%', 171,
        '&', 179,
        '(', 141,
        ')', 142,
        '*', 167,
        '+', 161,
        ',', 139,
        '-', 165,
        '.', 192,
        '/', 169,
        ':', 138,
        ';', 133,
        '<', 147,
        '=', 27,
        '>', 152,
        '?', 155,
        '@', 35,
        '[', 136,
        '\\', 31,
        ']', 140,
        '^', 173,
        '{', 143,
        '|', 177,
        '}', 144,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ' ||
          lookahead == 0xa0 ||
          lookahead == 0x3000 ||
          lookahead == 0xfeff) SKIP(6);
      if (set_contains(sym__identifier_token_character_set_2, 669, lookahead)) ADVANCE(333);
      END_STATE();
    case 7:
      ADVANCE_MAP(
        '!', 157,
        '#', 47,
        '%', 171,
        '&', 179,
        '(', 141,
        ')', 142,
        '*', 167,
        '+', 161,
        ',', 139,
        '-', 165,
        '.', 192,
        '/', 169,
        ':', 137,
        ';', 133,
        '<', 147,
        '=', 27,
        '>', 152,
        '?', 155,
        '@', 35,
        '[', 136,
        '\\', 31,
        ']', 140,
        '^', 173,
        '|', 177,
        '}', 144,
        'U', 332,
        'u', 332,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ' ||
          lookahead == 0xa0 ||
          lookahead == 0x3000 ||
          lookahead == 0xfeff) SKIP(7);
      if (set_contains(sym__identifier_token_character_set_2, 669, lookahead)) ADVANCE(333);
      END_STATE();
    case 8:
      ADVANCE_MAP(
        '!', 157,
        '#', 48,
        '%', 171,
        '&', 178,
        '*', 167,
        '+', 161,
        '-', 163,
        '/', 169,
        '<', 147,
        '=', 26,
        '>', 152,
        '@', 35,
        '\\', 31,
        '^', 173,
        '|', 175,
        '~', 158,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ' ||
          lookahead == 0xa0 ||
          lookahead == 0x3000 ||
          lookahead == 0xfeff) SKIP(8);
      if (set_contains(sym__identifier_token_character_set_2, 669, lookahead)) ADVANCE(333);
      END_STATE();
    case 9:
      ADVANCE_MAP(
        '!', 407,
        'd', 57,
        'e', 76,
        'i', 60,
        'l', 69,
        'n', 97,
        'p', 94,
        'r', 52,
        'u', 83,
        'w', 44,
        '\t', 46,
        ' ', 46,
      );
      END_STATE();
    case 10:
      ADVANCE_MAP(
        '!', 156,
        '#', 48,
        '\'', 258,
        '(', 141,
        ')', 142,
        '*', 167,
        ',', 139,
        '-', 166,
        '.', 191,
        '/', 20,
        '0', 267,
        ':', 138,
        ';', 133,
        '<', 145,
        '=', 135,
        '>', 149,
        '?', 153,
        '@', 35,
        '[', 136,
        '\\', 31,
        ']', 140,
        '{', 143,
        '}', 144,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ' ||
          lookahead == 0xa0 ||
          lookahead == 0x3000 ||
          lookahead == 0xfeff) SKIP(10);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(268);
      if (set_contains(sym__identifier_token_character_set_2, 669, lookahead)) ADVANCE(333);
      END_STATE();
    case 11:
      if (lookahead == '"') ADVANCE(274);
      if (lookahead == '#') ADVANCE(48);
      if (lookahead == '/') ADVANCE(20);
      if (lookahead == '\\') ADVANCE(34);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ' ||
          lookahead == 0xa0 ||
          lookahead == 0x3000 ||
          lookahead == 0xfeff) SKIP(11);
      END_STATE();
    case 12:
      if (lookahead == '"') ADVANCE(13);
      if (lookahead == '\\') ADVANCE(31);
      if (set_contains(sym__identifier_token_character_set_2, 669, lookahead)) ADVANCE(333);
      END_STATE();
    case 13:
      if (lookahead == '"') ADVANCE(330);
      if (lookahead != 0) ADVANCE(13);
      END_STATE();
    case 14:
      if (lookahead == '#') ADVANCE(354);
      if (lookahead == '/') ADVANCE(346);
      if (lookahead == 0xa0 ||
          lookahead == 0x3000 ||
          lookahead == 0xfeff) ADVANCE(343);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(14);
      if (lookahead != 0) ADVANCE(396);
      END_STATE();
    case 15:
      if (lookahead == '#') ADVANCE(261);
      if (lookahead == '/') ADVANCE(260);
      if (lookahead == '\\') ADVANCE(34);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ' ||
          lookahead == 0xa0 ||
          lookahead == 0x3000 ||
          lookahead == 0xfeff) ADVANCE(259);
      if (lookahead != 0 &&
          lookahead != '\'') ADVANCE(259);
      END_STATE();
    case 16:
      if (lookahead == '#') ADVANCE(222);
      if (lookahead == '/') ADVANCE(214);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ' ||
          lookahead == 0xa0 ||
          lookahead == 0x3000 ||
          lookahead == 0xfeff) ADVANCE(213);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '#' &&
          lookahead != '}') ADVANCE(256);
      END_STATE();
    case 17:
      ADVANCE_MAP(
        '#', 48,
        '(', 141,
        ')', 142,
        '*', 167,
        ',', 139,
        '-', 28,
        '.', 191,
        '/', 20,
        ':', 137,
        ';', 133,
        '<', 145,
        '=', 29,
        '>', 149,
        '?', 153,
        '@', 35,
        '[', 136,
        '\\', 31,
        ']', 140,
        '{', 143,
        '}', 144,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ' ||
          lookahead == 0xa0 ||
          lookahead == 0x3000 ||
          lookahead == 0xfeff) SKIP(17);
      if (set_contains(sym__identifier_token_character_set_2, 669, lookahead)) ADVANCE(333);
      END_STATE();
    case 18:
      if (lookahead == '#') ADVANCE(48);
      if (lookahead == '/') ADVANCE(20);
      if (lookahead == '\\') ADVANCE(34);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ' ||
          lookahead == 0xa0 ||
          lookahead == 0x3000 ||
          lookahead == 0xfeff) SKIP(18);
      END_STATE();
    case 19:
      if (lookahead == '&') ADVANCE(209);
      END_STATE();
    case 20:
      if (lookahead == '*') ADVANCE(22);
      if (lookahead == '/') ADVANCE(412);
      END_STATE();
    case 21:
      if (lookahead == '*') ADVANCE(21);
      if (lookahead == '/') ADVANCE(408);
      if (lookahead != 0) ADVANCE(22);
      END_STATE();
    case 22:
      if (lookahead == '*') ADVANCE(21);
      if (lookahead != 0) ADVANCE(22);
      END_STATE();
    case 23:
      if (lookahead == '*') ADVANCE(21);
      if (lookahead != 0) ADVANCE(341);
      END_STATE();
    case 24:
      if (lookahead == '8') ADVANCE(329);
      END_STATE();
    case 25:
      if (lookahead == '=') ADVANCE(188);
      END_STATE();
    case 26:
      if (lookahead == '=') ADVANCE(187);
      END_STATE();
    case 27:
      if (lookahead == '=') ADVANCE(187);
      if (lookahead == '>') ADVANCE(194);
      END_STATE();
    case 28:
      if (lookahead == '>') ADVANCE(257);
      END_STATE();
    case 29:
      if (lookahead == '>') ADVANCE(194);
      END_STATE();
    case 30:
      ADVANCE_MAP(
        'U', 323,
        'u', 321,
        'x', 320,
        '"', 325,
        '\'', 325,
        '0', 325,
        '?', 325,
        '\\', 325,
        'a', 325,
        'b', 325,
        'e', 325,
        'f', 325,
        'n', 325,
        'r', 325,
        't', 325,
        'v', 325,
      );
      if (lookahead != 0) ADVANCE(319);
      END_STATE();
    case 31:
      if (lookahead == 'U') ADVANCE(126);
      if (lookahead == 'u') ADVANCE(114);
      END_STATE();
    case 32:
      ADVANCE_MAP(
        'U', 324,
        'u', 322,
        'x', 320,
        '"', 325,
        '\'', 325,
        '0', 325,
        '?', 325,
        '\\', 325,
        'a', 325,
        'b', 325,
        'e', 325,
        'f', 325,
        'n', 325,
        'r', 325,
        't', 325,
        'v', 325,
      );
      if (lookahead != 0) ADVANCE(319);
      END_STATE();
    case 33:
      ADVANCE_MAP(
        'U', 125,
        'u', 113,
        'x', 106,
        '"', 325,
        '\'', 325,
        '0', 325,
        '?', 325,
        '\\', 325,
        'a', 325,
        'b', 325,
        'e', 325,
        'f', 325,
        'n', 325,
        'r', 325,
        't', 325,
        'v', 325,
      );
      END_STATE();
    case 34:
      ADVANCE_MAP(
        'U', 127,
        'u', 115,
        'x', 106,
        '"', 325,
        '\'', 325,
        '0', 325,
        '?', 325,
        '\\', 325,
        'a', 325,
        'b', 325,
        'e', 325,
        'f', 325,
        'n', 325,
        'r', 325,
        't', 325,
        'v', 325,
      );
      END_STATE();
    case 35:
      if (lookahead == '\\') ADVANCE(31);
      if (set_contains(sym__identifier_token_character_set_2, 669, lookahead)) ADVANCE(333);
      END_STATE();
    case 36:
      if (lookahead == '_') ADVANCE(36);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(264);
      END_STATE();
    case 37:
      if (lookahead == '_') ADVANCE(37);
      if (lookahead == '0' ||
          lookahead == '1') ADVANCE(265);
      END_STATE();
    case 38:
      if (lookahead == '_') ADVANCE(38);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(266);
      END_STATE();
    case 39:
      if (lookahead == '_') ADVANCE(39);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(272);
      END_STATE();
    case 40:
      if (lookahead == '_') ADVANCE(40);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(268);
      END_STATE();
    case 41:
      if (lookahead == 'a') ADVANCE(45);
      END_STATE();
    case 42:
      if (lookahead == 'a') ADVANCE(401);
      END_STATE();
    case 43:
      if (lookahead == 'a') ADVANCE(65);
      END_STATE();
    case 44:
      if (lookahead == 'a') ADVANCE(95);
      END_STATE();
    case 45:
      if (lookahead == 'b') ADVANCE(79);
      END_STATE();
    case 46:
      ADVANCE_MAP(
        'd', 57,
        'e', 76,
        'i', 60,
        'l', 69,
        'n', 97,
        'p', 94,
        'r', 52,
        'u', 83,
        'w', 44,
        '\t', 46,
        ' ', 46,
      );
      END_STATE();
    case 47:
      ADVANCE_MAP(
        'd', 57,
        'e', 76,
        'l', 69,
        'n', 97,
        'p', 94,
        'r', 52,
        'u', 83,
        'w', 44,
        '\t', 47,
        ' ', 47,
      );
      END_STATE();
    case 48:
      ADVANCE_MAP(
        'd', 57,
        'e', 84,
        'l', 69,
        'n', 97,
        'p', 94,
        'r', 52,
        'u', 83,
        'w', 44,
        '\t', 48,
        ' ', 48,
      );
      END_STATE();
    case 49:
      if (lookahead == 'd') ADVANCE(72);
      END_STATE();
    case 50:
      if (lookahead == 'd') ADVANCE(96);
      END_STATE();
    case 51:
      if (lookahead == 'd') ADVANCE(58);
      END_STATE();
    case 52:
      if (lookahead == 'e') ADVANCE(67);
      END_STATE();
    case 53:
      if (lookahead == 'e') ADVANCE(338);
      END_STATE();
    case 54:
      if (lookahead == 'e') ADVANCE(400);
      END_STATE();
    case 55:
      if (lookahead == 'e') ADVANCE(405);
      END_STATE();
    case 56:
      if (lookahead == 'e') ADVANCE(402);
      END_STATE();
    case 57:
      if (lookahead == 'e') ADVANCE(64);
      END_STATE();
    case 58:
      if (lookahead == 'e') ADVANCE(63);
      END_STATE();
    case 59:
      if (lookahead == 'e') ADVANCE(68);
      END_STATE();
    case 60:
      if (lookahead == 'f') ADVANCE(334);
      END_STATE();
    case 61:
      if (lookahead == 'f') ADVANCE(339);
      END_STATE();
    case 62:
      if (lookahead == 'f') ADVANCE(337);
      END_STATE();
    case 63:
      if (lookahead == 'f') ADVANCE(406);
      END_STATE();
    case 64:
      if (lookahead == 'f') ADVANCE(74);
      END_STATE();
    case 65:
      if (lookahead == 'g') ADVANCE(80);
      END_STATE();
    case 66:
      if (lookahead == 'g') ADVANCE(404);
      END_STATE();
    case 67:
      if (lookahead == 'g') ADVANCE(70);
      END_STATE();
    case 68:
      if (lookahead == 'g') ADVANCE(75);
      END_STATE();
    case 69:
      if (lookahead == 'i') ADVANCE(86);
      END_STATE();
    case 70:
      if (lookahead == 'i') ADVANCE(90);
      END_STATE();
    case 71:
      if (lookahead == 'i') ADVANCE(61);
      if (lookahead == 's') ADVANCE(53);
      END_STATE();
    case 72:
      if (lookahead == 'i') ADVANCE(62);
      if (lookahead == 'r') ADVANCE(59);
      END_STATE();
    case 73:
      if (lookahead == 'i') ADVANCE(85);
      END_STATE();
    case 74:
      if (lookahead == 'i') ADVANCE(87);
      END_STATE();
    case 75:
      if (lookahead == 'i') ADVANCE(91);
      END_STATE();
    case 76:
      if (lookahead == 'l') ADVANCE(71);
      if (lookahead == 'n') ADVANCE(49);
      if (lookahead == 'r') ADVANCE(92);
      END_STATE();
    case 77:
      if (lookahead == 'l') ADVANCE(78);
      END_STATE();
    case 78:
      if (lookahead == 'l') ADVANCE(41);
      END_STATE();
    case 79:
      if (lookahead == 'l') ADVANCE(56);
      END_STATE();
    case 80:
      if (lookahead == 'm') ADVANCE(42);
      END_STATE();
    case 81:
      if (lookahead == 'n') ADVANCE(398);
      END_STATE();
    case 82:
      if (lookahead == 'n') ADVANCE(399);
      END_STATE();
    case 83:
      if (lookahead == 'n') ADVANCE(51);
      END_STATE();
    case 84:
      if (lookahead == 'n') ADVANCE(50);
      if (lookahead == 'r') ADVANCE(92);
      END_STATE();
    case 85:
      if (lookahead == 'n') ADVANCE(66);
      END_STATE();
    case 86:
      if (lookahead == 'n') ADVANCE(54);
      END_STATE();
    case 87:
      if (lookahead == 'n') ADVANCE(55);
      END_STATE();
    case 88:
      if (lookahead == 'n') ADVANCE(73);
      END_STATE();
    case 89:
      if (lookahead == 'o') ADVANCE(93);
      END_STATE();
    case 90:
      if (lookahead == 'o') ADVANCE(81);
      END_STATE();
    case 91:
      if (lookahead == 'o') ADVANCE(82);
      END_STATE();
    case 92:
      if (lookahead == 'r') ADVANCE(89);
      END_STATE();
    case 93:
      if (lookahead == 'r') ADVANCE(403);
      END_STATE();
    case 94:
      if (lookahead == 'r') ADVANCE(43);
      END_STATE();
    case 95:
      if (lookahead == 'r') ADVANCE(88);
      END_STATE();
    case 96:
      if (lookahead == 'r') ADVANCE(59);
      END_STATE();
    case 97:
      if (lookahead == 'u') ADVANCE(77);
      END_STATE();
    case 98:
      if (lookahead == '|') ADVANCE(210);
      END_STATE();
    case 99:
      if (lookahead == '+' ||
          lookahead == '-') ADVANCE(101);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(273);
      END_STATE();
    case 100:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(272);
      END_STATE();
    case 101:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(273);
      END_STATE();
    case 102:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(333);
      END_STATE();
    case 103:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(325);
      END_STATE();
    case 104:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(328);
      END_STATE();
    case 105:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(326);
      END_STATE();
    case 106:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(104);
      END_STATE();
    case 107:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(105);
      END_STATE();
    case 108:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(102);
      END_STATE();
    case 109:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(103);
      END_STATE();
    case 110:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(107);
      END_STATE();
    case 111:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(108);
      END_STATE();
    case 112:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(109);
      END_STATE();
    case 113:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(110);
      END_STATE();
    case 114:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(111);
      END_STATE();
    case 115:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(112);
      END_STATE();
    case 116:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(114);
      END_STATE();
    case 117:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(113);
      END_STATE();
    case 118:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(115);
      END_STATE();
    case 119:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(117);
      END_STATE();
    case 120:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(116);
      END_STATE();
    case 121:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(118);
      END_STATE();
    case 122:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(119);
      END_STATE();
    case 123:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(120);
      END_STATE();
    case 124:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(121);
      END_STATE();
    case 125:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(122);
      END_STATE();
    case 126:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(123);
      END_STATE();
    case 127:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(124);
      END_STATE();
    case 128:
      if (lookahead != 0 &&
          lookahead != '*') ADVANCE(396);
      END_STATE();
    case 129:
      if (eof) ADVANCE(132);
      ADVANCE_MAP(
        '!', 157,
        '"', 274,
        '#', 9,
        '%', 172,
        '&', 180,
        '\'', 258,
        '(', 141,
        ')', 142,
        '*', 168,
        '+', 162,
        ',', 139,
        '-', 164,
        '.', 193,
        '/', 170,
        '0', 263,
        ':', 138,
        ';', 133,
        '<', 146,
        '=', 134,
        '>', 151,
        '?', 154,
        '@', 12,
        '[', 136,
        '\\', 33,
        ']', 140,
        '^', 174,
        '{', 143,
        '|', 176,
        '}', 144,
        '~', 158,
        'U', 332,
        'u', 332,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ' ||
          lookahead == 0xa0 ||
          lookahead == 0x3000 ||
          lookahead == 0xfeff) SKIP(129);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(264);
      if (set_contains(sym__identifier_token_character_set_2, 669, lookahead)) ADVANCE(333);
      END_STATE();
    case 130:
      if (eof) ADVANCE(132);
      ADVANCE_MAP(
        '!', 157,
        '"', 274,
        '#', 46,
        '%', 171,
        '&', 179,
        '\'', 258,
        '(', 141,
        ')', 142,
        '*', 167,
        '+', 161,
        ',', 139,
        '-', 165,
        '.', 193,
        '/', 169,
        '0', 263,
        ':', 137,
        ';', 133,
        '<', 147,
        '=', 27,
        '>', 152,
        '?', 155,
        '@', 12,
        '[', 136,
        '\\', 31,
        ']', 140,
        '^', 173,
        '{', 143,
        '|', 177,
        '}', 144,
        '~', 158,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ' ||
          lookahead == 0xa0 ||
          lookahead == 0x3000 ||
          lookahead == 0xfeff) SKIP(130);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(264);
      if (set_contains(sym__identifier_token_character_set_2, 669, lookahead)) ADVANCE(333);
      END_STATE();
    case 131:
      if (eof) ADVANCE(132);
      ADVANCE_MAP(
        '!', 156,
        '"', 274,
        '#', 9,
        '&', 178,
        '\'', 258,
        '(', 141,
        ')', 142,
        '*', 167,
        '+', 161,
        ',', 139,
        '-', 165,
        '.', 193,
        '/', 20,
        '0', 263,
        ':', 138,
        ';', 133,
        '<', 148,
        '=', 135,
        '>', 150,
        '?', 153,
        '@', 12,
        '[', 136,
        '\\', 31,
        ']', 140,
        '^', 173,
        '{', 143,
        '}', 144,
        '~', 158,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ' ||
          lookahead == 0xa0 ||
          lookahead == 0x3000 ||
          lookahead == 0xfeff) SKIP(131);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(264);
      if (set_contains(sym__identifier_token_character_set_2, 669, lookahead)) ADVANCE(333);
      END_STATE();
    case 132:
      ACCEPT_TOKEN(ts_builtin_sym_end);
      END_STATE();
    case 133:
      ACCEPT_TOKEN(anon_sym_SEMI);
      END_STATE();
    case 134:
      ACCEPT_TOKEN(anon_sym_EQ);
      if (lookahead == '=') ADVANCE(187);
      if (lookahead == '>') ADVANCE(194);
      END_STATE();
    case 135:
      ACCEPT_TOKEN(anon_sym_EQ);
      if (lookahead == '>') ADVANCE(194);
      END_STATE();
    case 136:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      END_STATE();
    case 137:
      ACCEPT_TOKEN(anon_sym_COLON);
      END_STATE();
    case 138:
      ACCEPT_TOKEN(anon_sym_COLON);
      if (lookahead == ':') ADVANCE(195);
      END_STATE();
    case 139:
      ACCEPT_TOKEN(anon_sym_COMMA);
      END_STATE();
    case 140:
      ACCEPT_TOKEN(anon_sym_RBRACK);
      END_STATE();
    case 141:
      ACCEPT_TOKEN(anon_sym_LPAREN);
      END_STATE();
    case 142:
      ACCEPT_TOKEN(anon_sym_RPAREN);
      END_STATE();
    case 143:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      END_STATE();
    case 144:
      ACCEPT_TOKEN(anon_sym_RBRACE);
      END_STATE();
    case 145:
      ACCEPT_TOKEN(anon_sym_LT);
      END_STATE();
    case 146:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '<') ADVANCE(182);
      if (lookahead == '=') ADVANCE(190);
      END_STATE();
    case 147:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '<') ADVANCE(181);
      if (lookahead == '=') ADVANCE(190);
      END_STATE();
    case 148:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '=') ADVANCE(190);
      END_STATE();
    case 149:
      ACCEPT_TOKEN(anon_sym_GT);
      END_STATE();
    case 150:
      ACCEPT_TOKEN(anon_sym_GT);
      if (lookahead == '=') ADVANCE(189);
      END_STATE();
    case 151:
      ACCEPT_TOKEN(anon_sym_GT);
      if (lookahead == '=') ADVANCE(189);
      if (lookahead == '>') ADVANCE(183);
      END_STATE();
    case 152:
      ACCEPT_TOKEN(anon_sym_GT);
      if (lookahead == '=') ADVANCE(189);
      if (lookahead == '>') ADVANCE(184);
      END_STATE();
    case 153:
      ACCEPT_TOKEN(anon_sym_QMARK);
      END_STATE();
    case 154:
      ACCEPT_TOKEN(anon_sym_QMARK);
      if (lookahead == '?') ADVANCE(212);
      END_STATE();
    case 155:
      ACCEPT_TOKEN(anon_sym_QMARK);
      if (lookahead == '?') ADVANCE(211);
      END_STATE();
    case 156:
      ACCEPT_TOKEN(anon_sym_BANG);
      END_STATE();
    case 157:
      ACCEPT_TOKEN(anon_sym_BANG);
      if (lookahead == '=') ADVANCE(188);
      END_STATE();
    case 158:
      ACCEPT_TOKEN(anon_sym_TILDE);
      END_STATE();
    case 159:
      ACCEPT_TOKEN(anon_sym_PLUS_PLUS);
      END_STATE();
    case 160:
      ACCEPT_TOKEN(anon_sym_DASH_DASH);
      END_STATE();
    case 161:
      ACCEPT_TOKEN(anon_sym_PLUS);
      if (lookahead == '+') ADVANCE(159);
      END_STATE();
    case 162:
      ACCEPT_TOKEN(anon_sym_PLUS);
      if (lookahead == '+') ADVANCE(159);
      if (lookahead == '=') ADVANCE(197);
      END_STATE();
    case 163:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '-') ADVANCE(160);
      END_STATE();
    case 164:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '-') ADVANCE(160);
      if (lookahead == '=') ADVANCE(198);
      if (lookahead == '>') ADVANCE(257);
      END_STATE();
    case 165:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '-') ADVANCE(160);
      if (lookahead == '>') ADVANCE(257);
      END_STATE();
    case 166:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '>') ADVANCE(257);
      END_STATE();
    case 167:
      ACCEPT_TOKEN(anon_sym_STAR);
      END_STATE();
    case 168:
      ACCEPT_TOKEN(anon_sym_STAR);
      if (lookahead == '=') ADVANCE(199);
      END_STATE();
    case 169:
      ACCEPT_TOKEN(anon_sym_SLASH);
      if (lookahead == '*') ADVANCE(22);
      if (lookahead == '/') ADVANCE(412);
      END_STATE();
    case 170:
      ACCEPT_TOKEN(anon_sym_SLASH);
      if (lookahead == '*') ADVANCE(22);
      if (lookahead == '/') ADVANCE(412);
      if (lookahead == '=') ADVANCE(200);
      END_STATE();
    case 171:
      ACCEPT_TOKEN(anon_sym_PERCENT);
      END_STATE();
    case 172:
      ACCEPT_TOKEN(anon_sym_PERCENT);
      if (lookahead == '=') ADVANCE(201);
      END_STATE();
    case 173:
      ACCEPT_TOKEN(anon_sym_CARET);
      END_STATE();
    case 174:
      ACCEPT_TOKEN(anon_sym_CARET);
      if (lookahead == '=') ADVANCE(203);
      END_STATE();
    case 175:
      ACCEPT_TOKEN(anon_sym_PIPE);
      END_STATE();
    case 176:
      ACCEPT_TOKEN(anon_sym_PIPE);
      if (lookahead == '=') ADVANCE(204);
      if (lookahead == '|') ADVANCE(210);
      END_STATE();
    case 177:
      ACCEPT_TOKEN(anon_sym_PIPE);
      if (lookahead == '|') ADVANCE(210);
      END_STATE();
    case 178:
      ACCEPT_TOKEN(anon_sym_AMP);
      END_STATE();
    case 179:
      ACCEPT_TOKEN(anon_sym_AMP);
      if (lookahead == '&') ADVANCE(209);
      END_STATE();
    case 180:
      ACCEPT_TOKEN(anon_sym_AMP);
      if (lookahead == '&') ADVANCE(209);
      if (lookahead == '=') ADVANCE(202);
      END_STATE();
    case 181:
      ACCEPT_TOKEN(anon_sym_LT_LT);
      END_STATE();
    case 182:
      ACCEPT_TOKEN(anon_sym_LT_LT);
      if (lookahead == '=') ADVANCE(205);
      END_STATE();
    case 183:
      ACCEPT_TOKEN(anon_sym_GT_GT);
      if (lookahead == '=') ADVANCE(206);
      if (lookahead == '>') ADVANCE(186);
      END_STATE();
    case 184:
      ACCEPT_TOKEN(anon_sym_GT_GT);
      if (lookahead == '>') ADVANCE(185);
      END_STATE();
    case 185:
      ACCEPT_TOKEN(anon_sym_GT_GT_GT);
      END_STATE();
    case 186:
      ACCEPT_TOKEN(anon_sym_GT_GT_GT);
      if (lookahead == '=') ADVANCE(207);
      END_STATE();
    case 187:
      ACCEPT_TOKEN(anon_sym_EQ_EQ);
      END_STATE();
    case 188:
      ACCEPT_TOKEN(anon_sym_BANG_EQ);
      END_STATE();
    case 189:
      ACCEPT_TOKEN(anon_sym_GT_EQ);
      END_STATE();
    case 190:
      ACCEPT_TOKEN(anon_sym_LT_EQ);
      END_STATE();
    case 191:
      ACCEPT_TOKEN(anon_sym_DOT);
      END_STATE();
    case 192:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (lookahead == '.') ADVANCE(196);
      END_STATE();
    case 193:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (lookahead == '.') ADVANCE(196);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(272);
      END_STATE();
    case 194:
      ACCEPT_TOKEN(anon_sym_EQ_GT);
      END_STATE();
    case 195:
      ACCEPT_TOKEN(anon_sym_COLON_COLON);
      END_STATE();
    case 196:
      ACCEPT_TOKEN(anon_sym_DOT_DOT);
      END_STATE();
    case 197:
      ACCEPT_TOKEN(anon_sym_PLUS_EQ);
      END_STATE();
    case 198:
      ACCEPT_TOKEN(anon_sym_DASH_EQ);
      END_STATE();
    case 199:
      ACCEPT_TOKEN(anon_sym_STAR_EQ);
      END_STATE();
    case 200:
      ACCEPT_TOKEN(anon_sym_SLASH_EQ);
      END_STATE();
    case 201:
      ACCEPT_TOKEN(anon_sym_PERCENT_EQ);
      END_STATE();
    case 202:
      ACCEPT_TOKEN(anon_sym_AMP_EQ);
      END_STATE();
    case 203:
      ACCEPT_TOKEN(anon_sym_CARET_EQ);
      END_STATE();
    case 204:
      ACCEPT_TOKEN(anon_sym_PIPE_EQ);
      END_STATE();
    case 205:
      ACCEPT_TOKEN(anon_sym_LT_LT_EQ);
      END_STATE();
    case 206:
      ACCEPT_TOKEN(anon_sym_GT_GT_EQ);
      END_STATE();
    case 207:
      ACCEPT_TOKEN(anon_sym_GT_GT_GT_EQ);
      END_STATE();
    case 208:
      ACCEPT_TOKEN(anon_sym_QMARK_QMARK_EQ);
      END_STATE();
    case 209:
      ACCEPT_TOKEN(anon_sym_AMP_AMP);
      END_STATE();
    case 210:
      ACCEPT_TOKEN(anon_sym_PIPE_PIPE);
      END_STATE();
    case 211:
      ACCEPT_TOKEN(anon_sym_QMARK_QMARK);
      END_STATE();
    case 212:
      ACCEPT_TOKEN(anon_sym_QMARK_QMARK);
      if (lookahead == '=') ADVANCE(208);
      END_STATE();
    case 213:
      ACCEPT_TOKEN(aux_sym_interpolation_format_clause_token1);
      if (lookahead == '#') ADVANCE(222);
      if (lookahead == '/') ADVANCE(214);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ' ||
          lookahead == 0xa0 ||
          lookahead == 0x3000 ||
          lookahead == 0xfeff) ADVANCE(213);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '#' &&
          lookahead != '}') ADVANCE(256);
      END_STATE();
    case 214:
      ACCEPT_TOKEN(aux_sym_interpolation_format_clause_token1);
      if (lookahead == '*') ADVANCE(216);
      if (lookahead == '/') ADVANCE(255);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '}') ADVANCE(256);
      END_STATE();
    case 215:
      ACCEPT_TOKEN(aux_sym_interpolation_format_clause_token1);
      if (lookahead == '*') ADVANCE(215);
      if (lookahead == '/') ADVANCE(256);
      if (lookahead == '"' ||
          lookahead == '}') ADVANCE(22);
      if (lookahead != 0) ADVANCE(216);
      END_STATE();
    case 216:
      ACCEPT_TOKEN(aux_sym_interpolation_format_clause_token1);
      if (lookahead == '*') ADVANCE(215);
      if (lookahead == '"' ||
          lookahead == '}') ADVANCE(22);
      if (lookahead != 0) ADVANCE(216);
      END_STATE();
    case 217:
      ACCEPT_TOKEN(aux_sym_interpolation_format_clause_token1);
      if (lookahead == 'a') ADVANCE(256);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '}') ADVANCE(256);
      END_STATE();
    case 218:
      ACCEPT_TOKEN(aux_sym_interpolation_format_clause_token1);
      if (lookahead == 'a') ADVANCE(221);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '}') ADVANCE(256);
      END_STATE();
    case 219:
      ACCEPT_TOKEN(aux_sym_interpolation_format_clause_token1);
      if (lookahead == 'a') ADVANCE(232);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '}') ADVANCE(256);
      END_STATE();
    case 220:
      ACCEPT_TOKEN(aux_sym_interpolation_format_clause_token1);
      if (lookahead == 'a') ADVANCE(253);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '}') ADVANCE(256);
      END_STATE();
    case 221:
      ACCEPT_TOKEN(aux_sym_interpolation_format_clause_token1);
      if (lookahead == 'b') ADVANCE(238);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '}') ADVANCE(256);
      END_STATE();
    case 222:
      ACCEPT_TOKEN(aux_sym_interpolation_format_clause_token1);
      ADVANCE_MAP(
        'd', 226,
        'e', 242,
        'l', 234,
        'n', 254,
        'p', 252,
        'r', 227,
        'u', 243,
        'w', 220,
        '\t', 222,
        ' ', 222,
      );
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '}') ADVANCE(256);
      END_STATE();
    case 223:
      ACCEPT_TOKEN(aux_sym_interpolation_format_clause_token1);
      if (lookahead == 'd') ADVANCE(251);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '}') ADVANCE(256);
      END_STATE();
    case 224:
      ACCEPT_TOKEN(aux_sym_interpolation_format_clause_token1);
      if (lookahead == 'd') ADVANCE(228);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '}') ADVANCE(256);
      END_STATE();
    case 225:
      ACCEPT_TOKEN(aux_sym_interpolation_format_clause_token1);
      if (lookahead == 'e') ADVANCE(256);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '}') ADVANCE(256);
      END_STATE();
    case 226:
      ACCEPT_TOKEN(aux_sym_interpolation_format_clause_token1);
      if (lookahead == 'e') ADVANCE(230);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '}') ADVANCE(256);
      END_STATE();
    case 227:
      ACCEPT_TOKEN(aux_sym_interpolation_format_clause_token1);
      if (lookahead == 'e') ADVANCE(233);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '}') ADVANCE(256);
      END_STATE();
    case 228:
      ACCEPT_TOKEN(aux_sym_interpolation_format_clause_token1);
      if (lookahead == 'e') ADVANCE(229);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '}') ADVANCE(256);
      END_STATE();
    case 229:
      ACCEPT_TOKEN(aux_sym_interpolation_format_clause_token1);
      if (lookahead == 'f') ADVANCE(256);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '}') ADVANCE(256);
      END_STATE();
    case 230:
      ACCEPT_TOKEN(aux_sym_interpolation_format_clause_token1);
      if (lookahead == 'f') ADVANCE(234);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '}') ADVANCE(256);
      END_STATE();
    case 231:
      ACCEPT_TOKEN(aux_sym_interpolation_format_clause_token1);
      if (lookahead == 'g') ADVANCE(256);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '}') ADVANCE(256);
      END_STATE();
    case 232:
      ACCEPT_TOKEN(aux_sym_interpolation_format_clause_token1);
      if (lookahead == 'g') ADVANCE(240);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '}') ADVANCE(256);
      END_STATE();
    case 233:
      ACCEPT_TOKEN(aux_sym_interpolation_format_clause_token1);
      if (lookahead == 'g') ADVANCE(235);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '}') ADVANCE(256);
      END_STATE();
    case 234:
      ACCEPT_TOKEN(aux_sym_interpolation_format_clause_token1);
      if (lookahead == 'i') ADVANCE(244);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '}') ADVANCE(256);
      END_STATE();
    case 235:
      ACCEPT_TOKEN(aux_sym_interpolation_format_clause_token1);
      if (lookahead == 'i') ADVANCE(247);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '}') ADVANCE(256);
      END_STATE();
    case 236:
      ACCEPT_TOKEN(aux_sym_interpolation_format_clause_token1);
      if (lookahead == 'i') ADVANCE(245);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '}') ADVANCE(256);
      END_STATE();
    case 237:
      ACCEPT_TOKEN(aux_sym_interpolation_format_clause_token1);
      if (lookahead == 'l') ADVANCE(239);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '}') ADVANCE(256);
      END_STATE();
    case 238:
      ACCEPT_TOKEN(aux_sym_interpolation_format_clause_token1);
      if (lookahead == 'l') ADVANCE(225);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '}') ADVANCE(256);
      END_STATE();
    case 239:
      ACCEPT_TOKEN(aux_sym_interpolation_format_clause_token1);
      if (lookahead == 'l') ADVANCE(218);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '}') ADVANCE(256);
      END_STATE();
    case 240:
      ACCEPT_TOKEN(aux_sym_interpolation_format_clause_token1);
      if (lookahead == 'm') ADVANCE(217);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '}') ADVANCE(256);
      END_STATE();
    case 241:
      ACCEPT_TOKEN(aux_sym_interpolation_format_clause_token1);
      if (lookahead == 'n') ADVANCE(256);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '}') ADVANCE(256);
      END_STATE();
    case 242:
      ACCEPT_TOKEN(aux_sym_interpolation_format_clause_token1);
      if (lookahead == 'n') ADVANCE(223);
      if (lookahead == 'r') ADVANCE(250);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '}') ADVANCE(256);
      END_STATE();
    case 243:
      ACCEPT_TOKEN(aux_sym_interpolation_format_clause_token1);
      if (lookahead == 'n') ADVANCE(224);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '}') ADVANCE(256);
      END_STATE();
    case 244:
      ACCEPT_TOKEN(aux_sym_interpolation_format_clause_token1);
      if (lookahead == 'n') ADVANCE(225);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '}') ADVANCE(256);
      END_STATE();
    case 245:
      ACCEPT_TOKEN(aux_sym_interpolation_format_clause_token1);
      if (lookahead == 'n') ADVANCE(231);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '}') ADVANCE(256);
      END_STATE();
    case 246:
      ACCEPT_TOKEN(aux_sym_interpolation_format_clause_token1);
      if (lookahead == 'n') ADVANCE(236);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '}') ADVANCE(256);
      END_STATE();
    case 247:
      ACCEPT_TOKEN(aux_sym_interpolation_format_clause_token1);
      if (lookahead == 'o') ADVANCE(241);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '}') ADVANCE(256);
      END_STATE();
    case 248:
      ACCEPT_TOKEN(aux_sym_interpolation_format_clause_token1);
      if (lookahead == 'o') ADVANCE(249);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '}') ADVANCE(256);
      END_STATE();
    case 249:
      ACCEPT_TOKEN(aux_sym_interpolation_format_clause_token1);
      if (lookahead == 'r') ADVANCE(256);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '}') ADVANCE(256);
      END_STATE();
    case 250:
      ACCEPT_TOKEN(aux_sym_interpolation_format_clause_token1);
      if (lookahead == 'r') ADVANCE(248);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '}') ADVANCE(256);
      END_STATE();
    case 251:
      ACCEPT_TOKEN(aux_sym_interpolation_format_clause_token1);
      if (lookahead == 'r') ADVANCE(227);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '}') ADVANCE(256);
      END_STATE();
    case 252:
      ACCEPT_TOKEN(aux_sym_interpolation_format_clause_token1);
      if (lookahead == 'r') ADVANCE(219);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '}') ADVANCE(256);
      END_STATE();
    case 253:
      ACCEPT_TOKEN(aux_sym_interpolation_format_clause_token1);
      if (lookahead == 'r') ADVANCE(246);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '}') ADVANCE(256);
      END_STATE();
    case 254:
      ACCEPT_TOKEN(aux_sym_interpolation_format_clause_token1);
      if (lookahead == 'u') ADVANCE(237);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '}') ADVANCE(256);
      END_STATE();
    case 255:
      ACCEPT_TOKEN(aux_sym_interpolation_format_clause_token1);
      if (lookahead == '\n' ||
          lookahead == '\r') ADVANCE(256);
      if (lookahead == '"' ||
          lookahead == '}') ADVANCE(412);
      if (lookahead != 0) ADVANCE(255);
      END_STATE();
    case 256:
      ACCEPT_TOKEN(aux_sym_interpolation_format_clause_token1);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '}') ADVANCE(256);
      END_STATE();
    case 257:
      ACCEPT_TOKEN(anon_sym_DASH_GT);
      END_STATE();
    case 258:
      ACCEPT_TOKEN(anon_sym_SQUOTE);
      END_STATE();
    case 259:
      ACCEPT_TOKEN(sym_character_literal_content);
      END_STATE();
    case 260:
      ACCEPT_TOKEN(sym_character_literal_content);
      if (lookahead == '*') ADVANCE(22);
      if (lookahead == '/') ADVANCE(412);
      END_STATE();
    case 261:
      ACCEPT_TOKEN(sym_character_literal_content);
      ADVANCE_MAP(
        'd', 57,
        'e', 84,
        'l', 69,
        'n', 97,
        'p', 94,
        'r', 52,
        'u', 83,
        'w', 44,
        '\t', 48,
        ' ', 48,
      );
      END_STATE();
    case 262:
      ACCEPT_TOKEN(sym_integer_literal);
      END_STATE();
    case 263:
      ACCEPT_TOKEN(sym_integer_literal);
      ADVANCE_MAP(
        '.', 100,
        '_', 36,
        'B', 37,
        'b', 37,
        'E', 99,
        'e', 99,
        'L', 270,
        'l', 270,
        'U', 269,
        'u', 269,
        'X', 38,
        'x', 38,
        'D', 271,
        'F', 271,
        'M', 271,
        'd', 271,
        'f', 271,
        'm', 271,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(264);
      END_STATE();
    case 264:
      ACCEPT_TOKEN(sym_integer_literal);
      ADVANCE_MAP(
        '.', 100,
        '_', 36,
        'E', 99,
        'e', 99,
        'L', 270,
        'l', 270,
        'U', 269,
        'u', 269,
        'D', 271,
        'F', 271,
        'M', 271,
        'd', 271,
        'f', 271,
        'm', 271,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(264);
      END_STATE();
    case 265:
      ACCEPT_TOKEN(sym_integer_literal);
      if (lookahead == '_') ADVANCE(37);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(270);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(269);
      if (lookahead == '0' ||
          lookahead == '1') ADVANCE(265);
      END_STATE();
    case 266:
      ACCEPT_TOKEN(sym_integer_literal);
      if (lookahead == '_') ADVANCE(38);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(270);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(269);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(266);
      END_STATE();
    case 267:
      ACCEPT_TOKEN(sym_integer_literal);
      ADVANCE_MAP(
        '_', 40,
        'B', 37,
        'b', 37,
        'L', 270,
        'l', 270,
        'U', 269,
        'u', 269,
        'X', 38,
        'x', 38,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(268);
      END_STATE();
    case 268:
      ACCEPT_TOKEN(sym_integer_literal);
      if (lookahead == '_') ADVANCE(40);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(270);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(269);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(268);
      END_STATE();
    case 269:
      ACCEPT_TOKEN(sym_integer_literal);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(262);
      END_STATE();
    case 270:
      ACCEPT_TOKEN(sym_integer_literal);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(262);
      END_STATE();
    case 271:
      ACCEPT_TOKEN(sym_real_literal);
      END_STATE();
    case 272:
      ACCEPT_TOKEN(sym_real_literal);
      ADVANCE_MAP(
        '_', 39,
        'E', 99,
        'e', 99,
        'D', 271,
        'F', 271,
        'M', 271,
        'd', 271,
        'f', 271,
        'm', 271,
      );
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(272);
      END_STATE();
    case 273:
      ACCEPT_TOKEN(sym_real_literal);
      if (lookahead == 'D' ||
          lookahead == 'F' ||
          lookahead == 'M' ||
          lookahead == 'd' ||
          lookahead == 'f' ||
          lookahead == 'm') ADVANCE(271);
      if (('0' <= lookahead && lookahead <= '9') ||
          lookahead == '_') ADVANCE(273);
      END_STATE();
    case 274:
      ACCEPT_TOKEN(anon_sym_DQUOTE);
      END_STATE();
    case 275:
      ACCEPT_TOKEN(aux_sym_string_literal_content_token1);
      if (lookahead == '\r') ADVANCE(318);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(275);
      END_STATE();
    case 276:
      ACCEPT_TOKEN(aux_sym_string_literal_content_token1);
      if (lookahead == '#') ADVANCE(285);
      if (lookahead == '/') ADVANCE(277);
      if (lookahead == '\t' ||
          (0x0b <= lookahead && lookahead <= '\r') ||
          lookahead == ' ' ||
          lookahead == 0xa0 ||
          lookahead == 0x3000 ||
          lookahead == 0xfeff) ADVANCE(276);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead) &&
          lookahead != '"' &&
          lookahead != '#' &&
          lookahead != '\\') ADVANCE(318);
      END_STATE();
    case 277:
      ACCEPT_TOKEN(aux_sym_string_literal_content_token1);
      if (lookahead == '*') ADVANCE(279);
      if (lookahead == '/') ADVANCE(275);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(318);
      END_STATE();
    case 278:
      ACCEPT_TOKEN(aux_sym_string_literal_content_token1);
      if (lookahead == '*') ADVANCE(278);
      if (lookahead == '/') ADVANCE(318);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(279);
      END_STATE();
    case 279:
      ACCEPT_TOKEN(aux_sym_string_literal_content_token1);
      if (lookahead == '*') ADVANCE(278);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(279);
      END_STATE();
    case 280:
      ACCEPT_TOKEN(aux_sym_string_literal_content_token1);
      if (lookahead == 'a') ADVANCE(318);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(318);
      END_STATE();
    case 281:
      ACCEPT_TOKEN(aux_sym_string_literal_content_token1);
      if (lookahead == 'a') ADVANCE(284);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(318);
      END_STATE();
    case 282:
      ACCEPT_TOKEN(aux_sym_string_literal_content_token1);
      if (lookahead == 'a') ADVANCE(295);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(318);
      END_STATE();
    case 283:
      ACCEPT_TOKEN(aux_sym_string_literal_content_token1);
      if (lookahead == 'a') ADVANCE(316);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(318);
      END_STATE();
    case 284:
      ACCEPT_TOKEN(aux_sym_string_literal_content_token1);
      if (lookahead == 'b') ADVANCE(301);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(318);
      END_STATE();
    case 285:
      ACCEPT_TOKEN(aux_sym_string_literal_content_token1);
      ADVANCE_MAP(
        'd', 289,
        'e', 305,
        'l', 297,
        'n', 317,
        'p', 315,
        'r', 290,
        'u', 306,
        'w', 283,
        '\t', 285,
        ' ', 285,
      );
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(318);
      END_STATE();
    case 286:
      ACCEPT_TOKEN(aux_sym_string_literal_content_token1);
      if (lookahead == 'd') ADVANCE(314);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(318);
      END_STATE();
    case 287:
      ACCEPT_TOKEN(aux_sym_string_literal_content_token1);
      if (lookahead == 'd') ADVANCE(291);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(318);
      END_STATE();
    case 288:
      ACCEPT_TOKEN(aux_sym_string_literal_content_token1);
      if (lookahead == 'e') ADVANCE(318);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(318);
      END_STATE();
    case 289:
      ACCEPT_TOKEN(aux_sym_string_literal_content_token1);
      if (lookahead == 'e') ADVANCE(293);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(318);
      END_STATE();
    case 290:
      ACCEPT_TOKEN(aux_sym_string_literal_content_token1);
      if (lookahead == 'e') ADVANCE(296);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(318);
      END_STATE();
    case 291:
      ACCEPT_TOKEN(aux_sym_string_literal_content_token1);
      if (lookahead == 'e') ADVANCE(292);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(318);
      END_STATE();
    case 292:
      ACCEPT_TOKEN(aux_sym_string_literal_content_token1);
      if (lookahead == 'f') ADVANCE(318);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(318);
      END_STATE();
    case 293:
      ACCEPT_TOKEN(aux_sym_string_literal_content_token1);
      if (lookahead == 'f') ADVANCE(297);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(318);
      END_STATE();
    case 294:
      ACCEPT_TOKEN(aux_sym_string_literal_content_token1);
      if (lookahead == 'g') ADVANCE(318);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(318);
      END_STATE();
    case 295:
      ACCEPT_TOKEN(aux_sym_string_literal_content_token1);
      if (lookahead == 'g') ADVANCE(303);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(318);
      END_STATE();
    case 296:
      ACCEPT_TOKEN(aux_sym_string_literal_content_token1);
      if (lookahead == 'g') ADVANCE(298);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(318);
      END_STATE();
    case 297:
      ACCEPT_TOKEN(aux_sym_string_literal_content_token1);
      if (lookahead == 'i') ADVANCE(307);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(318);
      END_STATE();
    case 298:
      ACCEPT_TOKEN(aux_sym_string_literal_content_token1);
      if (lookahead == 'i') ADVANCE(310);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(318);
      END_STATE();
    case 299:
      ACCEPT_TOKEN(aux_sym_string_literal_content_token1);
      if (lookahead == 'i') ADVANCE(308);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(318);
      END_STATE();
    case 300:
      ACCEPT_TOKEN(aux_sym_string_literal_content_token1);
      if (lookahead == 'l') ADVANCE(302);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(318);
      END_STATE();
    case 301:
      ACCEPT_TOKEN(aux_sym_string_literal_content_token1);
      if (lookahead == 'l') ADVANCE(288);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(318);
      END_STATE();
    case 302:
      ACCEPT_TOKEN(aux_sym_string_literal_content_token1);
      if (lookahead == 'l') ADVANCE(281);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(318);
      END_STATE();
    case 303:
      ACCEPT_TOKEN(aux_sym_string_literal_content_token1);
      if (lookahead == 'm') ADVANCE(280);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(318);
      END_STATE();
    case 304:
      ACCEPT_TOKEN(aux_sym_string_literal_content_token1);
      if (lookahead == 'n') ADVANCE(318);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(318);
      END_STATE();
    case 305:
      ACCEPT_TOKEN(aux_sym_string_literal_content_token1);
      if (lookahead == 'n') ADVANCE(286);
      if (lookahead == 'r') ADVANCE(313);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(318);
      END_STATE();
    case 306:
      ACCEPT_TOKEN(aux_sym_string_literal_content_token1);
      if (lookahead == 'n') ADVANCE(287);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(318);
      END_STATE();
    case 307:
      ACCEPT_TOKEN(aux_sym_string_literal_content_token1);
      if (lookahead == 'n') ADVANCE(288);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(318);
      END_STATE();
    case 308:
      ACCEPT_TOKEN(aux_sym_string_literal_content_token1);
      if (lookahead == 'n') ADVANCE(294);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(318);
      END_STATE();
    case 309:
      ACCEPT_TOKEN(aux_sym_string_literal_content_token1);
      if (lookahead == 'n') ADVANCE(299);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(318);
      END_STATE();
    case 310:
      ACCEPT_TOKEN(aux_sym_string_literal_content_token1);
      if (lookahead == 'o') ADVANCE(304);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(318);
      END_STATE();
    case 311:
      ACCEPT_TOKEN(aux_sym_string_literal_content_token1);
      if (lookahead == 'o') ADVANCE(312);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(318);
      END_STATE();
    case 312:
      ACCEPT_TOKEN(aux_sym_string_literal_content_token1);
      if (lookahead == 'r') ADVANCE(318);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(318);
      END_STATE();
    case 313:
      ACCEPT_TOKEN(aux_sym_string_literal_content_token1);
      if (lookahead == 'r') ADVANCE(311);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(318);
      END_STATE();
    case 314:
      ACCEPT_TOKEN(aux_sym_string_literal_content_token1);
      if (lookahead == 'r') ADVANCE(290);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(318);
      END_STATE();
    case 315:
      ACCEPT_TOKEN(aux_sym_string_literal_content_token1);
      if (lookahead == 'r') ADVANCE(282);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(318);
      END_STATE();
    case 316:
      ACCEPT_TOKEN(aux_sym_string_literal_content_token1);
      if (lookahead == 'r') ADVANCE(309);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(318);
      END_STATE();
    case 317:
      ACCEPT_TOKEN(aux_sym_string_literal_content_token1);
      if (lookahead == 'u') ADVANCE(300);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(318);
      END_STATE();
    case 318:
      ACCEPT_TOKEN(aux_sym_string_literal_content_token1);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(318);
      END_STATE();
    case 319:
      ACCEPT_TOKEN(aux_sym_string_literal_content_token2);
      END_STATE();
    case 320:
      ACCEPT_TOKEN(aux_sym_string_literal_content_token2);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(104);
      END_STATE();
    case 321:
      ACCEPT_TOKEN(aux_sym_string_literal_content_token2);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(110);
      END_STATE();
    case 322:
      ACCEPT_TOKEN(aux_sym_string_literal_content_token2);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(112);
      END_STATE();
    case 323:
      ACCEPT_TOKEN(aux_sym_string_literal_content_token2);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(122);
      END_STATE();
    case 324:
      ACCEPT_TOKEN(aux_sym_string_literal_content_token2);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(124);
      END_STATE();
    case 325:
      ACCEPT_TOKEN(sym_escape_sequence);
      END_STATE();
    case 326:
      ACCEPT_TOKEN(sym_escape_sequence);
      if (lookahead == '\\') ADVANCE(31);
      if (set_contains(sym__identifier_token_character_set_3, 777, lookahead)) ADVANCE(333);
      END_STATE();
    case 327:
      ACCEPT_TOKEN(sym_escape_sequence);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(325);
      END_STATE();
    case 328:
      ACCEPT_TOKEN(sym_escape_sequence);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(327);
      END_STATE();
    case 329:
      ACCEPT_TOKEN(sym_verbatim_string_literal);
      END_STATE();
    case 330:
      ACCEPT_TOKEN(sym_verbatim_string_literal);
      if (lookahead == '"') ADVANCE(13);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(24);
      END_STATE();
    case 331:
      ACCEPT_TOKEN(aux_sym_raw_string_literal_token1);
      if (lookahead == '\\') ADVANCE(31);
      if (set_contains(sym__identifier_token_character_set_3, 777, lookahead)) ADVANCE(333);
      END_STATE();
    case 332:
      ACCEPT_TOKEN(sym__identifier_token);
      if (lookahead == '8') ADVANCE(331);
      if (lookahead == '\\') ADVANCE(31);
      if (set_contains(sym__identifier_token_character_set_3, 777, lookahead)) ADVANCE(333);
      END_STATE();
    case 333:
      ACCEPT_TOKEN(sym__identifier_token);
      if (lookahead == '\\') ADVANCE(31);
      if (set_contains(sym__identifier_token_character_set_3, 777, lookahead)) ADVANCE(333);
      END_STATE();
    case 334:
      ACCEPT_TOKEN(aux_sym_preproc_if_token1);
      END_STATE();
    case 335:
      ACCEPT_TOKEN(aux_sym_preproc_if_token2);
      if (lookahead == '\n') ADVANCE(335);
      END_STATE();
    case 336:
      ACCEPT_TOKEN(aux_sym_preproc_if_token2);
      if (lookahead == '\n') ADVANCE(336);
      if (lookahead == 0xa0 ||
          lookahead == 0x3000 ||
          lookahead == 0xfeff) ADVANCE(342);
      END_STATE();
    case 337:
      ACCEPT_TOKEN(aux_sym_preproc_if_token3);
      END_STATE();
    case 338:
      ACCEPT_TOKEN(aux_sym_preproc_else_token1);
      END_STATE();
    case 339:
      ACCEPT_TOKEN(aux_sym_preproc_elif_token1);
      END_STATE();
    case 340:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '\n') ADVANCE(22);
      if (lookahead == '*') ADVANCE(340);
      if (lookahead == '/') ADVANCE(408);
      if (lookahead == '\\') ADVANCE(345);
      if (lookahead != 0) ADVANCE(341);
      END_STATE();
    case 341:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '\n') ADVANCE(22);
      if (lookahead == '*') ADVANCE(340);
      if (lookahead == '/') ADVANCE(23);
      if (lookahead == '\\') ADVANCE(345);
      if (lookahead != 0) ADVANCE(341);
      END_STATE();
    case 342:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '\n') ADVANCE(336);
      if (lookahead == '#') ADVANCE(354);
      if (lookahead == '/') ADVANCE(347);
      if (lookahead == '\\') ADVANCE(344);
      if (lookahead == 0xa0 ||
          lookahead == 0x3000 ||
          lookahead == 0xfeff) ADVANCE(342);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(342);
      if (lookahead != 0) ADVANCE(396);
      END_STATE();
    case 343:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '\n') SKIP(14);
      if (lookahead == '#') ADVANCE(354);
      if (lookahead == '/') ADVANCE(347);
      if (lookahead == '\\') ADVANCE(344);
      if (lookahead == 0xa0 ||
          lookahead == 0x3000 ||
          lookahead == 0xfeff) ADVANCE(343);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(343);
      if (lookahead != 0) ADVANCE(396);
      END_STATE();
    case 344:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '\r') ADVANCE(397);
      if (lookahead == '/') ADVANCE(128);
      if (lookahead == '\\') ADVANCE(344);
      if (lookahead != 0) ADVANCE(396);
      END_STATE();
    case 345:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '\r') ADVANCE(348);
      if (lookahead == '*') ADVANCE(340);
      if (lookahead == '/') ADVANCE(23);
      if (lookahead == '\\') ADVANCE(345);
      if (lookahead != 0) ADVANCE(341);
      END_STATE();
    case 346:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '*') ADVANCE(341);
      if (lookahead == '/') ADVANCE(409);
      if (lookahead == '\\') ADVANCE(344);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(396);
      END_STATE();
    case 347:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '*') ADVANCE(341);
      if (lookahead == '/') ADVANCE(411);
      if (lookahead == '\\') ADVANCE(344);
      if (lookahead != 0) ADVANCE(396);
      END_STATE();
    case 348:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '*') ADVANCE(340);
      if (lookahead == '/') ADVANCE(23);
      if (lookahead == '\\') ADVANCE(345);
      if (lookahead != 0) ADVANCE(341);
      END_STATE();
    case 349:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '/') ADVANCE(128);
      if (lookahead == '\\') ADVANCE(344);
      if (lookahead == 'a') ADVANCE(401);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(396);
      END_STATE();
    case 350:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '/') ADVANCE(128);
      if (lookahead == '\\') ADVANCE(344);
      if (lookahead == 'a') ADVANCE(353);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(396);
      END_STATE();
    case 351:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '/') ADVANCE(128);
      if (lookahead == '\\') ADVANCE(344);
      if (lookahead == 'a') ADVANCE(367);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(396);
      END_STATE();
    case 352:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '/') ADVANCE(128);
      if (lookahead == '\\') ADVANCE(344);
      if (lookahead == 'a') ADVANCE(393);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(396);
      END_STATE();
    case 353:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '/') ADVANCE(128);
      if (lookahead == '\\') ADVANCE(344);
      if (lookahead == 'b') ADVANCE(377);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(396);
      END_STATE();
    case 354:
      ACCEPT_TOKEN(sym_preproc_arg);
      ADVANCE_MAP(
        '/', 128,
        '\\', 344,
        'd', 360,
        'e', 381,
        'l', 370,
        'n', 395,
        'p', 392,
        'r', 361,
        'u', 382,
        'w', 352,
        '\t', 354,
        ' ', 354,
      );
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n') ADVANCE(396);
      END_STATE();
    case 355:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '/') ADVANCE(128);
      if (lookahead == '\\') ADVANCE(344);
      if (lookahead == 'd') ADVANCE(394);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(396);
      END_STATE();
    case 356:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '/') ADVANCE(128);
      if (lookahead == '\\') ADVANCE(344);
      if (lookahead == 'd') ADVANCE(362);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(396);
      END_STATE();
    case 357:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '/') ADVANCE(128);
      if (lookahead == '\\') ADVANCE(344);
      if (lookahead == 'e') ADVANCE(400);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(396);
      END_STATE();
    case 358:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '/') ADVANCE(128);
      if (lookahead == '\\') ADVANCE(344);
      if (lookahead == 'e') ADVANCE(405);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(396);
      END_STATE();
    case 359:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '/') ADVANCE(128);
      if (lookahead == '\\') ADVANCE(344);
      if (lookahead == 'e') ADVANCE(402);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(396);
      END_STATE();
    case 360:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '/') ADVANCE(128);
      if (lookahead == '\\') ADVANCE(344);
      if (lookahead == 'e') ADVANCE(365);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(396);
      END_STATE();
    case 361:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '/') ADVANCE(128);
      if (lookahead == '\\') ADVANCE(344);
      if (lookahead == 'e') ADVANCE(368);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(396);
      END_STATE();
    case 362:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '/') ADVANCE(128);
      if (lookahead == '\\') ADVANCE(344);
      if (lookahead == 'e') ADVANCE(364);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(396);
      END_STATE();
    case 363:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '/') ADVANCE(128);
      if (lookahead == '\\') ADVANCE(344);
      if (lookahead == 'e') ADVANCE(369);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(396);
      END_STATE();
    case 364:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '/') ADVANCE(128);
      if (lookahead == '\\') ADVANCE(344);
      if (lookahead == 'f') ADVANCE(406);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(396);
      END_STATE();
    case 365:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '/') ADVANCE(128);
      if (lookahead == '\\') ADVANCE(344);
      if (lookahead == 'f') ADVANCE(373);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(396);
      END_STATE();
    case 366:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '/') ADVANCE(128);
      if (lookahead == '\\') ADVANCE(344);
      if (lookahead == 'g') ADVANCE(404);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(396);
      END_STATE();
    case 367:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '/') ADVANCE(128);
      if (lookahead == '\\') ADVANCE(344);
      if (lookahead == 'g') ADVANCE(378);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(396);
      END_STATE();
    case 368:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '/') ADVANCE(128);
      if (lookahead == '\\') ADVANCE(344);
      if (lookahead == 'g') ADVANCE(371);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(396);
      END_STATE();
    case 369:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '/') ADVANCE(128);
      if (lookahead == '\\') ADVANCE(344);
      if (lookahead == 'g') ADVANCE(374);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(396);
      END_STATE();
    case 370:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '/') ADVANCE(128);
      if (lookahead == '\\') ADVANCE(344);
      if (lookahead == 'i') ADVANCE(383);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(396);
      END_STATE();
    case 371:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '/') ADVANCE(128);
      if (lookahead == '\\') ADVANCE(344);
      if (lookahead == 'i') ADVANCE(387);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(396);
      END_STATE();
    case 372:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '/') ADVANCE(128);
      if (lookahead == '\\') ADVANCE(344);
      if (lookahead == 'i') ADVANCE(384);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(396);
      END_STATE();
    case 373:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '/') ADVANCE(128);
      if (lookahead == '\\') ADVANCE(344);
      if (lookahead == 'i') ADVANCE(385);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(396);
      END_STATE();
    case 374:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '/') ADVANCE(128);
      if (lookahead == '\\') ADVANCE(344);
      if (lookahead == 'i') ADVANCE(389);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(396);
      END_STATE();
    case 375:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '/') ADVANCE(128);
      if (lookahead == '\\') ADVANCE(344);
      if (lookahead == 'l') ADVANCE(376);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(396);
      END_STATE();
    case 376:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '/') ADVANCE(128);
      if (lookahead == '\\') ADVANCE(344);
      if (lookahead == 'l') ADVANCE(350);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(396);
      END_STATE();
    case 377:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '/') ADVANCE(128);
      if (lookahead == '\\') ADVANCE(344);
      if (lookahead == 'l') ADVANCE(359);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(396);
      END_STATE();
    case 378:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '/') ADVANCE(128);
      if (lookahead == '\\') ADVANCE(344);
      if (lookahead == 'm') ADVANCE(349);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(396);
      END_STATE();
    case 379:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '/') ADVANCE(128);
      if (lookahead == '\\') ADVANCE(344);
      if (lookahead == 'n') ADVANCE(398);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(396);
      END_STATE();
    case 380:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '/') ADVANCE(128);
      if (lookahead == '\\') ADVANCE(344);
      if (lookahead == 'n') ADVANCE(399);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(396);
      END_STATE();
    case 381:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '/') ADVANCE(128);
      if (lookahead == '\\') ADVANCE(344);
      if (lookahead == 'n') ADVANCE(355);
      if (lookahead == 'r') ADVANCE(391);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(396);
      END_STATE();
    case 382:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '/') ADVANCE(128);
      if (lookahead == '\\') ADVANCE(344);
      if (lookahead == 'n') ADVANCE(356);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(396);
      END_STATE();
    case 383:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '/') ADVANCE(128);
      if (lookahead == '\\') ADVANCE(344);
      if (lookahead == 'n') ADVANCE(357);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(396);
      END_STATE();
    case 384:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '/') ADVANCE(128);
      if (lookahead == '\\') ADVANCE(344);
      if (lookahead == 'n') ADVANCE(366);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(396);
      END_STATE();
    case 385:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '/') ADVANCE(128);
      if (lookahead == '\\') ADVANCE(344);
      if (lookahead == 'n') ADVANCE(358);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(396);
      END_STATE();
    case 386:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '/') ADVANCE(128);
      if (lookahead == '\\') ADVANCE(344);
      if (lookahead == 'n') ADVANCE(372);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(396);
      END_STATE();
    case 387:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '/') ADVANCE(128);
      if (lookahead == '\\') ADVANCE(344);
      if (lookahead == 'o') ADVANCE(379);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(396);
      END_STATE();
    case 388:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '/') ADVANCE(128);
      if (lookahead == '\\') ADVANCE(344);
      if (lookahead == 'o') ADVANCE(390);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(396);
      END_STATE();
    case 389:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '/') ADVANCE(128);
      if (lookahead == '\\') ADVANCE(344);
      if (lookahead == 'o') ADVANCE(380);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(396);
      END_STATE();
    case 390:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '/') ADVANCE(128);
      if (lookahead == '\\') ADVANCE(344);
      if (lookahead == 'r') ADVANCE(403);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(396);
      END_STATE();
    case 391:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '/') ADVANCE(128);
      if (lookahead == '\\') ADVANCE(344);
      if (lookahead == 'r') ADVANCE(388);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(396);
      END_STATE();
    case 392:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '/') ADVANCE(128);
      if (lookahead == '\\') ADVANCE(344);
      if (lookahead == 'r') ADVANCE(351);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(396);
      END_STATE();
    case 393:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '/') ADVANCE(128);
      if (lookahead == '\\') ADVANCE(344);
      if (lookahead == 'r') ADVANCE(386);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(396);
      END_STATE();
    case 394:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '/') ADVANCE(128);
      if (lookahead == '\\') ADVANCE(344);
      if (lookahead == 'r') ADVANCE(363);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(396);
      END_STATE();
    case 395:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '/') ADVANCE(128);
      if (lookahead == '\\') ADVANCE(344);
      if (lookahead == 'u') ADVANCE(375);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(396);
      END_STATE();
    case 396:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '/') ADVANCE(128);
      if (lookahead == '\\') ADVANCE(344);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(396);
      END_STATE();
    case 397:
      ACCEPT_TOKEN(sym_preproc_arg);
      if (lookahead == '/') ADVANCE(128);
      if (lookahead == '\\') ADVANCE(344);
      if (lookahead != 0) ADVANCE(396);
      END_STATE();
    case 398:
      ACCEPT_TOKEN(aux_sym_preproc_region_token1);
      END_STATE();
    case 399:
      ACCEPT_TOKEN(aux_sym_preproc_endregion_token1);
      END_STATE();
    case 400:
      ACCEPT_TOKEN(aux_sym_preproc_line_token1);
      END_STATE();
    case 401:
      ACCEPT_TOKEN(aux_sym_preproc_pragma_token1);
      END_STATE();
    case 402:
      ACCEPT_TOKEN(aux_sym_preproc_nullable_token1);
      END_STATE();
    case 403:
      ACCEPT_TOKEN(aux_sym_preproc_error_token1);
      END_STATE();
    case 404:
      ACCEPT_TOKEN(aux_sym_preproc_warning_token1);
      END_STATE();
    case 405:
      ACCEPT_TOKEN(aux_sym_preproc_define_token1);
      END_STATE();
    case 406:
      ACCEPT_TOKEN(aux_sym_preproc_undef_token1);
      END_STATE();
    case 407:
      ACCEPT_TOKEN(sym_shebang_directive);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(407);
      END_STATE();
    case 408:
      ACCEPT_TOKEN(sym_comment);
      END_STATE();
    case 409:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == '*') ADVANCE(412);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r') ADVANCE(410);
      END_STATE();
    case 410:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == '/') ADVANCE(409);
      if (lookahead == '\\') ADVANCE(410);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r') ADVANCE(410);
      END_STATE();
    case 411:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == '/') ADVANCE(411);
      if (lookahead == '\\') ADVANCE(410);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r') ADVANCE(410);
      END_STATE();
    case 412:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r') ADVANCE(412);
      END_STATE();
    default:
      return false;
  }
}

static bool ts_lex_keywords(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      ADVANCE_MAP(
        'C', 1,
        'F', 2,
        'S', 3,
        'T', 4,
        'U', 5,
        '_', 6,
        'a', 7,
        'b', 8,
        'c', 9,
        'd', 10,
        'e', 11,
        'f', 12,
        'g', 13,
        'h', 14,
        'i', 15,
        'j', 16,
        'l', 17,
        'm', 18,
        'n', 19,
        'o', 20,
        'p', 21,
        'r', 22,
        's', 23,
        't', 24,
        'u', 25,
        'v', 26,
        'w', 27,
        'y', 28,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ' ||
          lookahead == 0xa0 ||
          lookahead == 0x3000 ||
          lookahead == 0xfeff) SKIP(29);
      END_STATE();
    case 1:
      if (lookahead == 'd') ADVANCE(30);
      END_STATE();
    case 2:
      if (lookahead == 'a') ADVANCE(31);
      END_STATE();
    case 3:
      if (lookahead == 't') ADVANCE(32);
      END_STATE();
    case 4:
      if (lookahead == 'h') ADVANCE(33);
      END_STATE();
    case 5:
      if (lookahead == '8') ADVANCE(34);
      END_STATE();
    case 6:
      ACCEPT_TOKEN(sym_discard);
      if (lookahead == '_') ADVANCE(35);
      END_STATE();
    case 7:
      if (lookahead == 'b') ADVANCE(36);
      if (lookahead == 'd') ADVANCE(37);
      if (lookahead == 'l') ADVANCE(38);
      if (lookahead == 'n') ADVANCE(39);
      if (lookahead == 's') ADVANCE(40);
      if (lookahead == 'w') ADVANCE(41);
      END_STATE();
    case 8:
      if (lookahead == 'a') ADVANCE(42);
      if (lookahead == 'o') ADVANCE(43);
      if (lookahead == 'r') ADVANCE(44);
      if (lookahead == 'y') ADVANCE(45);
      END_STATE();
    case 9:
      if (lookahead == 'a') ADVANCE(46);
      if (lookahead == 'h') ADVANCE(47);
      if (lookahead == 'l') ADVANCE(48);
      if (lookahead == 'o') ADVANCE(49);
      END_STATE();
    case 10:
      if (lookahead == 'e') ADVANCE(50);
      if (lookahead == 'i') ADVANCE(51);
      if (lookahead == 'o') ADVANCE(52);
      END_STATE();
    case 11:
      if (lookahead == 'l') ADVANCE(53);
      if (lookahead == 'n') ADVANCE(54);
      if (lookahead == 'q') ADVANCE(55);
      if (lookahead == 'v') ADVANCE(56);
      if (lookahead == 'x') ADVANCE(57);
      END_STATE();
    case 12:
      if (lookahead == 'a') ADVANCE(58);
      if (lookahead == 'i') ADVANCE(59);
      if (lookahead == 'l') ADVANCE(60);
      if (lookahead == 'o') ADVANCE(61);
      if (lookahead == 'r') ADVANCE(62);
      END_STATE();
    case 13:
      if (lookahead == 'e') ADVANCE(63);
      if (lookahead == 'l') ADVANCE(64);
      if (lookahead == 'o') ADVANCE(65);
      if (lookahead == 'r') ADVANCE(66);
      END_STATE();
    case 14:
      if (lookahead == 'i') ADVANCE(67);
      END_STATE();
    case 15:
      if (lookahead == 'f') ADVANCE(68);
      if (lookahead == 'm') ADVANCE(69);
      if (lookahead == 'n') ADVANCE(70);
      if (lookahead == 's') ADVANCE(71);
      END_STATE();
    case 16:
      if (lookahead == 'o') ADVANCE(72);
      END_STATE();
    case 17:
      if (lookahead == 'e') ADVANCE(73);
      if (lookahead == 'o') ADVANCE(74);
      END_STATE();
    case 18:
      if (lookahead == 'a') ADVANCE(75);
      if (lookahead == 'e') ADVANCE(76);
      if (lookahead == 'o') ADVANCE(77);
      END_STATE();
    case 19:
      if (lookahead == 'a') ADVANCE(78);
      if (lookahead == 'e') ADVANCE(79);
      if (lookahead == 'i') ADVANCE(80);
      if (lookahead == 'o') ADVANCE(81);
      if (lookahead == 'u') ADVANCE(82);
      END_STATE();
    case 20:
      if (lookahead == 'b') ADVANCE(83);
      if (lookahead == 'n') ADVANCE(84);
      if (lookahead == 'p') ADVANCE(85);
      if (lookahead == 'r') ADVANCE(86);
      if (lookahead == 'u') ADVANCE(87);
      if (lookahead == 'v') ADVANCE(88);
      END_STATE();
    case 21:
      if (lookahead == 'a') ADVANCE(89);
      if (lookahead == 'r') ADVANCE(90);
      if (lookahead == 'u') ADVANCE(91);
      END_STATE();
    case 22:
      if (lookahead == 'e') ADVANCE(92);
      END_STATE();
    case 23:
      if (lookahead == 'b') ADVANCE(93);
      if (lookahead == 'c') ADVANCE(94);
      if (lookahead == 'e') ADVANCE(95);
      if (lookahead == 'h') ADVANCE(96);
      if (lookahead == 'i') ADVANCE(97);
      if (lookahead == 't') ADVANCE(98);
      if (lookahead == 'w') ADVANCE(99);
      END_STATE();
    case 24:
      if (lookahead == 'h') ADVANCE(100);
      if (lookahead == 'r') ADVANCE(101);
      if (lookahead == 'y') ADVANCE(102);
      END_STATE();
    case 25:
      if (lookahead == '8') ADVANCE(34);
      if (lookahead == 'i') ADVANCE(103);
      if (lookahead == 'l') ADVANCE(104);
      if (lookahead == 'n') ADVANCE(105);
      if (lookahead == 's') ADVANCE(106);
      END_STATE();
    case 26:
      if (lookahead == 'a') ADVANCE(107);
      if (lookahead == 'i') ADVANCE(108);
      if (lookahead == 'o') ADVANCE(109);
      END_STATE();
    case 27:
      if (lookahead == 'a') ADVANCE(110);
      if (lookahead == 'h') ADVANCE(111);
      if (lookahead == 'i') ADVANCE(112);
      END_STATE();
    case 28:
      if (lookahead == 'i') ADVANCE(113);
      END_STATE();
    case 29:
      ADVANCE_MAP(
        'C', 1,
        'F', 2,
        'S', 3,
        'T', 4,
        '_', 6,
        'a', 7,
        'b', 8,
        'c', 9,
        'd', 10,
        'e', 11,
        'f', 12,
        'g', 13,
        'h', 14,
        'i', 15,
        'j', 16,
        'l', 17,
        'm', 18,
        'n', 19,
        'o', 20,
        'p', 21,
        'r', 22,
        's', 23,
        't', 24,
        'u', 114,
        'v', 26,
        'w', 27,
        'y', 28,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ' ||
          lookahead == 0xa0 ||
          lookahead == 0x3000 ||
          lookahead == 0xfeff) SKIP(29);
      END_STATE();
    case 30:
      if (lookahead == 'e') ADVANCE(115);
      END_STATE();
    case 31:
      if (lookahead == 's') ADVANCE(116);
      END_STATE();
    case 32:
      if (lookahead == 'd') ADVANCE(117);
      END_STATE();
    case 33:
      if (lookahead == 'i') ADVANCE(118);
      END_STATE();
    case 34:
      ACCEPT_TOKEN(sym_string_literal_encoding);
      END_STATE();
    case 35:
      if (lookahead == 'm') ADVANCE(119);
      if (lookahead == 'r') ADVANCE(120);
      END_STATE();
    case 36:
      if (lookahead == 's') ADVANCE(121);
      END_STATE();
    case 37:
      if (lookahead == 'd') ADVANCE(122);
      END_STATE();
    case 38:
      if (lookahead == 'i') ADVANCE(123);
      END_STATE();
    case 39:
      if (lookahead == 'd') ADVANCE(124);
      if (lookahead == 'n') ADVANCE(125);
      END_STATE();
    case 40:
      ACCEPT_TOKEN(anon_sym_as);
      if (lookahead == 'c') ADVANCE(126);
      if (lookahead == 's') ADVANCE(127);
      if (lookahead == 'y') ADVANCE(128);
      END_STATE();
    case 41:
      if (lookahead == 'a') ADVANCE(129);
      END_STATE();
    case 42:
      if (lookahead == 's') ADVANCE(130);
      END_STATE();
    case 43:
      if (lookahead == 'o') ADVANCE(131);
      END_STATE();
    case 44:
      if (lookahead == 'e') ADVANCE(132);
      END_STATE();
    case 45:
      ACCEPT_TOKEN(anon_sym_by);
      if (lookahead == 't') ADVANCE(133);
      END_STATE();
    case 46:
      if (lookahead == 's') ADVANCE(134);
      if (lookahead == 't') ADVANCE(135);
      END_STATE();
    case 47:
      if (lookahead == 'a') ADVANCE(136);
      if (lookahead == 'e') ADVANCE(137);
      END_STATE();
    case 48:
      if (lookahead == 'a') ADVANCE(138);
      END_STATE();
    case 49:
      if (lookahead == 'n') ADVANCE(139);
      END_STATE();
    case 50:
      if (lookahead == 'c') ADVANCE(140);
      if (lookahead == 'f') ADVANCE(141);
      if (lookahead == 'l') ADVANCE(142);
      if (lookahead == 's') ADVANCE(143);
      END_STATE();
    case 51:
      if (lookahead == 's') ADVANCE(144);
      END_STATE();
    case 52:
      ACCEPT_TOKEN(anon_sym_do);
      if (lookahead == 'u') ADVANCE(145);
      END_STATE();
    case 53:
      if (lookahead == 's') ADVANCE(146);
      END_STATE();
    case 54:
      if (lookahead == 'a') ADVANCE(147);
      if (lookahead == 'u') ADVANCE(148);
      END_STATE();
    case 55:
      if (lookahead == 'u') ADVANCE(149);
      END_STATE();
    case 56:
      if (lookahead == 'e') ADVANCE(150);
      END_STATE();
    case 57:
      if (lookahead == 'p') ADVANCE(151);
      if (lookahead == 't') ADVANCE(152);
      END_STATE();
    case 58:
      if (lookahead == 'l') ADVANCE(153);
      END_STATE();
    case 59:
      if (lookahead == 'e') ADVANCE(154);
      if (lookahead == 'l') ADVANCE(155);
      if (lookahead == 'n') ADVANCE(156);
      if (lookahead == 'x') ADVANCE(157);
      END_STATE();
    case 60:
      if (lookahead == 'o') ADVANCE(158);
      END_STATE();
    case 61:
      if (lookahead == 'r') ADVANCE(159);
      END_STATE();
    case 62:
      if (lookahead == 'o') ADVANCE(160);
      END_STATE();
    case 63:
      if (lookahead == 't') ADVANCE(161);
      END_STATE();
    case 64:
      if (lookahead == 'o') ADVANCE(162);
      END_STATE();
    case 65:
      if (lookahead == 't') ADVANCE(163);
      END_STATE();
    case 66:
      if (lookahead == 'o') ADVANCE(164);
      END_STATE();
    case 67:
      if (lookahead == 'd') ADVANCE(165);
      END_STATE();
    case 68:
      ACCEPT_TOKEN(anon_sym_if);
      END_STATE();
    case 69:
      if (lookahead == 'p') ADVANCE(166);
      END_STATE();
    case 70:
      ACCEPT_TOKEN(anon_sym_in);
      if (lookahead == 'i') ADVANCE(167);
      if (lookahead == 't') ADVANCE(168);
      END_STATE();
    case 71:
      ACCEPT_TOKEN(anon_sym_is);
      END_STATE();
    case 72:
      if (lookahead == 'i') ADVANCE(169);
      END_STATE();
    case 73:
      if (lookahead == 't') ADVANCE(170);
      END_STATE();
    case 74:
      if (lookahead == 'c') ADVANCE(171);
      if (lookahead == 'n') ADVANCE(172);
      END_STATE();
    case 75:
      if (lookahead == 'n') ADVANCE(173);
      END_STATE();
    case 76:
      if (lookahead == 't') ADVANCE(174);
      END_STATE();
    case 77:
      if (lookahead == 'd') ADVANCE(175);
      END_STATE();
    case 78:
      if (lookahead == 'm') ADVANCE(176);
      END_STATE();
    case 79:
      if (lookahead == 'w') ADVANCE(177);
      END_STATE();
    case 80:
      if (lookahead == 'n') ADVANCE(178);
      END_STATE();
    case 81:
      if (lookahead == 't') ADVANCE(179);
      END_STATE();
    case 82:
      if (lookahead == 'i') ADVANCE(180);
      if (lookahead == 'l') ADVANCE(181);
      END_STATE();
    case 83:
      if (lookahead == 'j') ADVANCE(182);
      END_STATE();
    case 84:
      ACCEPT_TOKEN(anon_sym_on);
      END_STATE();
    case 85:
      if (lookahead == 'e') ADVANCE(183);
      END_STATE();
    case 86:
      ACCEPT_TOKEN(anon_sym_or);
      if (lookahead == 'd') ADVANCE(184);
      END_STATE();
    case 87:
      if (lookahead == 't') ADVANCE(185);
      END_STATE();
    case 88:
      if (lookahead == 'e') ADVANCE(186);
      END_STATE();
    case 89:
      if (lookahead == 'r') ADVANCE(187);
      END_STATE();
    case 90:
      if (lookahead == 'i') ADVANCE(188);
      if (lookahead == 'o') ADVANCE(189);
      END_STATE();
    case 91:
      if (lookahead == 'b') ADVANCE(190);
      END_STATE();
    case 92:
      if (lookahead == 'a') ADVANCE(191);
      if (lookahead == 'c') ADVANCE(192);
      if (lookahead == 'f') ADVANCE(193);
      if (lookahead == 'm') ADVANCE(194);
      if (lookahead == 'q') ADVANCE(195);
      if (lookahead == 's') ADVANCE(196);
      if (lookahead == 't') ADVANCE(197);
      END_STATE();
    case 93:
      if (lookahead == 'y') ADVANCE(198);
      END_STATE();
    case 94:
      if (lookahead == 'o') ADVANCE(199);
      END_STATE();
    case 95:
      if (lookahead == 'a') ADVANCE(200);
      if (lookahead == 'l') ADVANCE(201);
      if (lookahead == 't') ADVANCE(202);
      END_STATE();
    case 96:
      if (lookahead == 'o') ADVANCE(203);
      END_STATE();
    case 97:
      if (lookahead == 'z') ADVANCE(204);
      END_STATE();
    case 98:
      if (lookahead == 'a') ADVANCE(205);
      if (lookahead == 'r') ADVANCE(206);
      END_STATE();
    case 99:
      if (lookahead == 'i') ADVANCE(207);
      END_STATE();
    case 100:
      if (lookahead == 'i') ADVANCE(208);
      if (lookahead == 'r') ADVANCE(209);
      END_STATE();
    case 101:
      if (lookahead == 'u') ADVANCE(210);
      if (lookahead == 'y') ADVANCE(211);
      END_STATE();
    case 102:
      if (lookahead == 'p') ADVANCE(212);
      END_STATE();
    case 103:
      if (lookahead == 'n') ADVANCE(213);
      END_STATE();
    case 104:
      if (lookahead == 'o') ADVANCE(214);
      END_STATE();
    case 105:
      if (lookahead == 'c') ADVANCE(215);
      if (lookahead == 'm') ADVANCE(216);
      if (lookahead == 's') ADVANCE(217);
      END_STATE();
    case 106:
      if (lookahead == 'h') ADVANCE(218);
      if (lookahead == 'i') ADVANCE(219);
      END_STATE();
    case 107:
      if (lookahead == 'r') ADVANCE(220);
      END_STATE();
    case 108:
      if (lookahead == 'r') ADVANCE(221);
      END_STATE();
    case 109:
      if (lookahead == 'i') ADVANCE(222);
      if (lookahead == 'l') ADVANCE(223);
      END_STATE();
    case 110:
      if (lookahead == 'r') ADVANCE(224);
      END_STATE();
    case 111:
      if (lookahead == 'e') ADVANCE(225);
      if (lookahead == 'i') ADVANCE(226);
      END_STATE();
    case 112:
      if (lookahead == 't') ADVANCE(227);
      END_STATE();
    case 113:
      if (lookahead == 'e') ADVANCE(228);
      END_STATE();
    case 114:
      if (lookahead == 'i') ADVANCE(103);
      if (lookahead == 'l') ADVANCE(104);
      if (lookahead == 'n') ADVANCE(105);
      if (lookahead == 's') ADVANCE(106);
      END_STATE();
    case 115:
      if (lookahead == 'c') ADVANCE(229);
      END_STATE();
    case 116:
      if (lookahead == 't') ADVANCE(230);
      END_STATE();
    case 117:
      if (lookahead == 'c') ADVANCE(231);
      END_STATE();
    case 118:
      if (lookahead == 's') ADVANCE(232);
      END_STATE();
    case 119:
      if (lookahead == 'a') ADVANCE(233);
      END_STATE();
    case 120:
      if (lookahead == 'e') ADVANCE(234);
      END_STATE();
    case 121:
      if (lookahead == 't') ADVANCE(235);
      END_STATE();
    case 122:
      ACCEPT_TOKEN(anon_sym_add);
      END_STATE();
    case 123:
      if (lookahead == 'a') ADVANCE(236);
      END_STATE();
    case 124:
      ACCEPT_TOKEN(anon_sym_and);
      END_STATE();
    case 125:
      if (lookahead == 'o') ADVANCE(237);
      END_STATE();
    case 126:
      if (lookahead == 'e') ADVANCE(238);
      END_STATE();
    case 127:
      if (lookahead == 'e') ADVANCE(239);
      END_STATE();
    case 128:
      if (lookahead == 'n') ADVANCE(240);
      END_STATE();
    case 129:
      if (lookahead == 'i') ADVANCE(241);
      END_STATE();
    case 130:
      if (lookahead == 'e') ADVANCE(242);
      END_STATE();
    case 131:
      if (lookahead == 'l') ADVANCE(243);
      END_STATE();
    case 132:
      if (lookahead == 'a') ADVANCE(244);
      END_STATE();
    case 133:
      if (lookahead == 'e') ADVANCE(243);
      END_STATE();
    case 134:
      if (lookahead == 'e') ADVANCE(245);
      END_STATE();
    case 135:
      if (lookahead == 'c') ADVANCE(246);
      END_STATE();
    case 136:
      if (lookahead == 'r') ADVANCE(243);
      END_STATE();
    case 137:
      if (lookahead == 'c') ADVANCE(247);
      END_STATE();
    case 138:
      if (lookahead == 's') ADVANCE(248);
      END_STATE();
    case 139:
      if (lookahead == 's') ADVANCE(249);
      if (lookahead == 't') ADVANCE(250);
      END_STATE();
    case 140:
      if (lookahead == 'i') ADVANCE(251);
      END_STATE();
    case 141:
      if (lookahead == 'a') ADVANCE(252);
      END_STATE();
    case 142:
      if (lookahead == 'e') ADVANCE(253);
      END_STATE();
    case 143:
      if (lookahead == 'c') ADVANCE(254);
      END_STATE();
    case 144:
      if (lookahead == 'a') ADVANCE(255);
      END_STATE();
    case 145:
      if (lookahead == 'b') ADVANCE(256);
      END_STATE();
    case 146:
      if (lookahead == 'e') ADVANCE(257);
      END_STATE();
    case 147:
      if (lookahead == 'b') ADVANCE(258);
      END_STATE();
    case 148:
      if (lookahead == 'm') ADVANCE(259);
      END_STATE();
    case 149:
      if (lookahead == 'a') ADVANCE(260);
      END_STATE();
    case 150:
      if (lookahead == 'n') ADVANCE(261);
      END_STATE();
    case 151:
      if (lookahead == 'l') ADVANCE(262);
      END_STATE();
    case 152:
      if (lookahead == 'e') ADVANCE(263);
      END_STATE();
    case 153:
      if (lookahead == 's') ADVANCE(264);
      END_STATE();
    case 154:
      if (lookahead == 'l') ADVANCE(265);
      END_STATE();
    case 155:
      if (lookahead == 'e') ADVANCE(266);
      END_STATE();
    case 156:
      if (lookahead == 'a') ADVANCE(267);
      END_STATE();
    case 157:
      if (lookahead == 'e') ADVANCE(268);
      END_STATE();
    case 158:
      if (lookahead == 'a') ADVANCE(269);
      END_STATE();
    case 159:
      ACCEPT_TOKEN(anon_sym_for);
      if (lookahead == 'e') ADVANCE(270);
      END_STATE();
    case 160:
      if (lookahead == 'm') ADVANCE(271);
      END_STATE();
    case 161:
      ACCEPT_TOKEN(anon_sym_get);
      END_STATE();
    case 162:
      if (lookahead == 'b') ADVANCE(272);
      END_STATE();
    case 163:
      if (lookahead == 'o') ADVANCE(273);
      END_STATE();
    case 164:
      if (lookahead == 'u') ADVANCE(274);
      END_STATE();
    case 165:
      if (lookahead == 'd') ADVANCE(275);
      END_STATE();
    case 166:
      if (lookahead == 'l') ADVANCE(276);
      END_STATE();
    case 167:
      if (lookahead == 't') ADVANCE(277);
      END_STATE();
    case 168:
      ACCEPT_TOKEN(sym_predefined_type);
      if (lookahead == 'e') ADVANCE(278);
      if (lookahead == 'o') ADVANCE(279);
      END_STATE();
    case 169:
      if (lookahead == 'n') ADVANCE(280);
      END_STATE();
    case 170:
      ACCEPT_TOKEN(anon_sym_let);
      END_STATE();
    case 171:
      if (lookahead == 'k') ADVANCE(281);
      END_STATE();
    case 172:
      if (lookahead == 'g') ADVANCE(243);
      END_STATE();
    case 173:
      if (lookahead == 'a') ADVANCE(282);
      END_STATE();
    case 174:
      if (lookahead == 'h') ADVANCE(283);
      END_STATE();
    case 175:
      if (lookahead == 'u') ADVANCE(284);
      END_STATE();
    case 176:
      if (lookahead == 'e') ADVANCE(285);
      END_STATE();
    case 177:
      ACCEPT_TOKEN(anon_sym_new);
      END_STATE();
    case 178:
      if (lookahead == 't') ADVANCE(243);
      END_STATE();
    case 179:
      ACCEPT_TOKEN(anon_sym_not);
      if (lookahead == 'n') ADVANCE(286);
      END_STATE();
    case 180:
      if (lookahead == 'n') ADVANCE(287);
      END_STATE();
    case 181:
      if (lookahead == 'l') ADVANCE(288);
      END_STATE();
    case 182:
      if (lookahead == 'e') ADVANCE(289);
      END_STATE();
    case 183:
      if (lookahead == 'r') ADVANCE(290);
      END_STATE();
    case 184:
      if (lookahead == 'e') ADVANCE(291);
      END_STATE();
    case 185:
      ACCEPT_TOKEN(anon_sym_out);
      END_STATE();
    case 186:
      if (lookahead == 'r') ADVANCE(292);
      END_STATE();
    case 187:
      if (lookahead == 'a') ADVANCE(293);
      if (lookahead == 't') ADVANCE(294);
      END_STATE();
    case 188:
      if (lookahead == 'v') ADVANCE(295);
      END_STATE();
    case 189:
      if (lookahead == 'p') ADVANCE(296);
      if (lookahead == 't') ADVANCE(297);
      END_STATE();
    case 190:
      if (lookahead == 'l') ADVANCE(298);
      END_STATE();
    case 191:
      if (lookahead == 'd') ADVANCE(299);
      END_STATE();
    case 192:
      if (lookahead == 'o') ADVANCE(300);
      END_STATE();
    case 193:
      ACCEPT_TOKEN(anon_sym_ref);
      END_STATE();
    case 194:
      if (lookahead == 'o') ADVANCE(301);
      END_STATE();
    case 195:
      if (lookahead == 'u') ADVANCE(302);
      END_STATE();
    case 196:
      if (lookahead == 't') ADVANCE(303);
      END_STATE();
    case 197:
      if (lookahead == 'u') ADVANCE(304);
      END_STATE();
    case 198:
      if (lookahead == 't') ADVANCE(305);
      END_STATE();
    case 199:
      if (lookahead == 'p') ADVANCE(306);
      END_STATE();
    case 200:
      if (lookahead == 'l') ADVANCE(307);
      END_STATE();
    case 201:
      if (lookahead == 'e') ADVANCE(308);
      END_STATE();
    case 202:
      ACCEPT_TOKEN(anon_sym_set);
      END_STATE();
    case 203:
      if (lookahead == 'r') ADVANCE(309);
      END_STATE();
    case 204:
      if (lookahead == 'e') ADVANCE(310);
      END_STATE();
    case 205:
      if (lookahead == 'c') ADVANCE(311);
      if (lookahead == 't') ADVANCE(312);
      END_STATE();
    case 206:
      if (lookahead == 'i') ADVANCE(313);
      if (lookahead == 'u') ADVANCE(314);
      END_STATE();
    case 207:
      if (lookahead == 't') ADVANCE(315);
      END_STATE();
    case 208:
      if (lookahead == 's') ADVANCE(316);
      END_STATE();
    case 209:
      if (lookahead == 'o') ADVANCE(317);
      END_STATE();
    case 210:
      if (lookahead == 'e') ADVANCE(318);
      END_STATE();
    case 211:
      ACCEPT_TOKEN(anon_sym_try);
      END_STATE();
    case 212:
      if (lookahead == 'e') ADVANCE(319);
      END_STATE();
    case 213:
      if (lookahead == 't') ADVANCE(243);
      END_STATE();
    case 214:
      if (lookahead == 'n') ADVANCE(320);
      END_STATE();
    case 215:
      if (lookahead == 'h') ADVANCE(321);
      END_STATE();
    case 216:
      if (lookahead == 'a') ADVANCE(322);
      END_STATE();
    case 217:
      if (lookahead == 'a') ADVANCE(323);
      END_STATE();
    case 218:
      if (lookahead == 'o') ADVANCE(324);
      END_STATE();
    case 219:
      if (lookahead == 'n') ADVANCE(325);
      END_STATE();
    case 220:
      ACCEPT_TOKEN(anon_sym_var);
      END_STATE();
    case 221:
      if (lookahead == 't') ADVANCE(326);
      END_STATE();
    case 222:
      if (lookahead == 'd') ADVANCE(243);
      END_STATE();
    case 223:
      if (lookahead == 'a') ADVANCE(327);
      END_STATE();
    case 224:
      if (lookahead == 'n') ADVANCE(328);
      END_STATE();
    case 225:
      if (lookahead == 'n') ADVANCE(329);
      if (lookahead == 'r') ADVANCE(330);
      END_STATE();
    case 226:
      if (lookahead == 'l') ADVANCE(331);
      END_STATE();
    case 227:
      if (lookahead == 'h') ADVANCE(332);
      END_STATE();
    case 228:
      if (lookahead == 'l') ADVANCE(333);
      END_STATE();
    case 229:
      if (lookahead == 'l') ADVANCE(334);
      END_STATE();
    case 230:
      if (lookahead == 'c') ADVANCE(335);
      END_STATE();
    case 231:
      if (lookahead == 'a') ADVANCE(336);
      END_STATE();
    case 232:
      if (lookahead == 'c') ADVANCE(337);
      END_STATE();
    case 233:
      if (lookahead == 'k') ADVANCE(338);
      END_STATE();
    case 234:
      if (lookahead == 'f') ADVANCE(339);
      END_STATE();
    case 235:
      if (lookahead == 'r') ADVANCE(340);
      END_STATE();
    case 236:
      if (lookahead == 's') ADVANCE(341);
      END_STATE();
    case 237:
      if (lookahead == 't') ADVANCE(342);
      END_STATE();
    case 238:
      if (lookahead == 'n') ADVANCE(343);
      END_STATE();
    case 239:
      if (lookahead == 'm') ADVANCE(344);
      END_STATE();
    case 240:
      if (lookahead == 'c') ADVANCE(345);
      END_STATE();
    case 241:
      if (lookahead == 't') ADVANCE(346);
      END_STATE();
    case 242:
      ACCEPT_TOKEN(anon_sym_base);
      END_STATE();
    case 243:
      ACCEPT_TOKEN(sym_predefined_type);
      END_STATE();
    case 244:
      if (lookahead == 'k') ADVANCE(347);
      END_STATE();
    case 245:
      ACCEPT_TOKEN(anon_sym_case);
      END_STATE();
    case 246:
      if (lookahead == 'h') ADVANCE(348);
      END_STATE();
    case 247:
      if (lookahead == 'k') ADVANCE(349);
      END_STATE();
    case 248:
      if (lookahead == 's') ADVANCE(350);
      END_STATE();
    case 249:
      if (lookahead == 't') ADVANCE(351);
      END_STATE();
    case 250:
      if (lookahead == 'i') ADVANCE(352);
      END_STATE();
    case 251:
      if (lookahead == 'm') ADVANCE(353);
      END_STATE();
    case 252:
      if (lookahead == 'u') ADVANCE(354);
      END_STATE();
    case 253:
      if (lookahead == 'g') ADVANCE(355);
      END_STATE();
    case 254:
      if (lookahead == 'e') ADVANCE(356);
      END_STATE();
    case 255:
      if (lookahead == 'b') ADVANCE(357);
      END_STATE();
    case 256:
      if (lookahead == 'l') ADVANCE(358);
      END_STATE();
    case 257:
      ACCEPT_TOKEN(anon_sym_else);
      END_STATE();
    case 258:
      if (lookahead == 'l') ADVANCE(359);
      END_STATE();
    case 259:
      ACCEPT_TOKEN(anon_sym_enum);
      END_STATE();
    case 260:
      if (lookahead == 'l') ADVANCE(360);
      END_STATE();
    case 261:
      if (lookahead == 't') ADVANCE(361);
      END_STATE();
    case 262:
      if (lookahead == 'i') ADVANCE(362);
      END_STATE();
    case 263:
      if (lookahead == 'r') ADVANCE(363);
      END_STATE();
    case 264:
      if (lookahead == 'e') ADVANCE(364);
      END_STATE();
    case 265:
      if (lookahead == 'd') ADVANCE(365);
      END_STATE();
    case 266:
      ACCEPT_TOKEN(anon_sym_file);
      END_STATE();
    case 267:
      if (lookahead == 'l') ADVANCE(366);
      END_STATE();
    case 268:
      if (lookahead == 'd') ADVANCE(367);
      END_STATE();
    case 269:
      if (lookahead == 't') ADVANCE(243);
      END_STATE();
    case 270:
      if (lookahead == 'a') ADVANCE(368);
      END_STATE();
    case 271:
      ACCEPT_TOKEN(anon_sym_from);
      END_STATE();
    case 272:
      if (lookahead == 'a') ADVANCE(369);
      END_STATE();
    case 273:
      ACCEPT_TOKEN(anon_sym_goto);
      END_STATE();
    case 274:
      if (lookahead == 'p') ADVANCE(370);
      END_STATE();
    case 275:
      if (lookahead == 'e') ADVANCE(371);
      END_STATE();
    case 276:
      if (lookahead == 'i') ADVANCE(372);
      END_STATE();
    case 277:
      ACCEPT_TOKEN(anon_sym_init);
      END_STATE();
    case 278:
      if (lookahead == 'r') ADVANCE(373);
      END_STATE();
    case 279:
      ACCEPT_TOKEN(anon_sym_into);
      END_STATE();
    case 280:
      ACCEPT_TOKEN(anon_sym_join);
      END_STATE();
    case 281:
      ACCEPT_TOKEN(anon_sym_lock);
      END_STATE();
    case 282:
      if (lookahead == 'g') ADVANCE(374);
      END_STATE();
    case 283:
      if (lookahead == 'o') ADVANCE(375);
      END_STATE();
    case 284:
      if (lookahead == 'l') ADVANCE(376);
      END_STATE();
    case 285:
      if (lookahead == 's') ADVANCE(377);
      END_STATE();
    case 286:
      if (lookahead == 'u') ADVANCE(378);
      END_STATE();
    case 287:
      if (lookahead == 't') ADVANCE(243);
      END_STATE();
    case 288:
      ACCEPT_TOKEN(sym_null_literal);
      END_STATE();
    case 289:
      if (lookahead == 'c') ADVANCE(379);
      END_STATE();
    case 290:
      if (lookahead == 'a') ADVANCE(380);
      END_STATE();
    case 291:
      if (lookahead == 'r') ADVANCE(381);
      END_STATE();
    case 292:
      if (lookahead == 'r') ADVANCE(382);
      END_STATE();
    case 293:
      if (lookahead == 'm') ADVANCE(383);
      END_STATE();
    case 294:
      if (lookahead == 'i') ADVANCE(384);
      END_STATE();
    case 295:
      if (lookahead == 'a') ADVANCE(385);
      END_STATE();
    case 296:
      if (lookahead == 'e') ADVANCE(386);
      END_STATE();
    case 297:
      if (lookahead == 'e') ADVANCE(387);
      END_STATE();
    case 298:
      if (lookahead == 'i') ADVANCE(388);
      END_STATE();
    case 299:
      if (lookahead == 'o') ADVANCE(389);
      END_STATE();
    case 300:
      if (lookahead == 'r') ADVANCE(390);
      END_STATE();
    case 301:
      if (lookahead == 'v') ADVANCE(391);
      END_STATE();
    case 302:
      if (lookahead == 'i') ADVANCE(392);
      END_STATE();
    case 303:
      if (lookahead == 'o') ADVANCE(393);
      END_STATE();
    case 304:
      if (lookahead == 'r') ADVANCE(394);
      END_STATE();
    case 305:
      if (lookahead == 'e') ADVANCE(243);
      END_STATE();
    case 306:
      if (lookahead == 'e') ADVANCE(395);
      END_STATE();
    case 307:
      if (lookahead == 'e') ADVANCE(396);
      END_STATE();
    case 308:
      if (lookahead == 'c') ADVANCE(397);
      END_STATE();
    case 309:
      if (lookahead == 't') ADVANCE(243);
      END_STATE();
    case 310:
      if (lookahead == 'o') ADVANCE(398);
      END_STATE();
    case 311:
      if (lookahead == 'k') ADVANCE(399);
      END_STATE();
    case 312:
      if (lookahead == 'i') ADVANCE(400);
      END_STATE();
    case 313:
      if (lookahead == 'n') ADVANCE(401);
      END_STATE();
    case 314:
      if (lookahead == 'c') ADVANCE(402);
      END_STATE();
    case 315:
      if (lookahead == 'c') ADVANCE(403);
      END_STATE();
    case 316:
      ACCEPT_TOKEN(anon_sym_this);
      END_STATE();
    case 317:
      if (lookahead == 'w') ADVANCE(404);
      END_STATE();
    case 318:
      ACCEPT_TOKEN(anon_sym_true);
      END_STATE();
    case 319:
      ACCEPT_TOKEN(anon_sym_type);
      if (lookahead == 'o') ADVANCE(405);
      END_STATE();
    case 320:
      if (lookahead == 'g') ADVANCE(243);
      END_STATE();
    case 321:
      if (lookahead == 'e') ADVANCE(406);
      END_STATE();
    case 322:
      if (lookahead == 'n') ADVANCE(407);
      END_STATE();
    case 323:
      if (lookahead == 'f') ADVANCE(408);
      END_STATE();
    case 324:
      if (lookahead == 'r') ADVANCE(409);
      END_STATE();
    case 325:
      if (lookahead == 'g') ADVANCE(410);
      END_STATE();
    case 326:
      if (lookahead == 'u') ADVANCE(411);
      END_STATE();
    case 327:
      if (lookahead == 't') ADVANCE(412);
      END_STATE();
    case 328:
      if (lookahead == 'i') ADVANCE(413);
      END_STATE();
    case 329:
      ACCEPT_TOKEN(anon_sym_when);
      END_STATE();
    case 330:
      if (lookahead == 'e') ADVANCE(414);
      END_STATE();
    case 331:
      if (lookahead == 'e') ADVANCE(415);
      END_STATE();
    case 332:
      ACCEPT_TOKEN(anon_sym_with);
      END_STATE();
    case 333:
      if (lookahead == 'd') ADVANCE(416);
      END_STATE();
    case 334:
      ACCEPT_TOKEN(anon_sym_Cdecl);
      END_STATE();
    case 335:
      if (lookahead == 'a') ADVANCE(417);
      END_STATE();
    case 336:
      if (lookahead == 'l') ADVANCE(418);
      END_STATE();
    case 337:
      if (lookahead == 'a') ADVANCE(419);
      END_STATE();
    case 338:
      if (lookahead == 'e') ADVANCE(420);
      END_STATE();
    case 339:
      if (lookahead == 't') ADVANCE(421);
      if (lookahead == 'v') ADVANCE(422);
      END_STATE();
    case 340:
      if (lookahead == 'a') ADVANCE(423);
      END_STATE();
    case 341:
      ACCEPT_TOKEN(anon_sym_alias);
      END_STATE();
    case 342:
      if (lookahead == 'a') ADVANCE(424);
      END_STATE();
    case 343:
      if (lookahead == 'd') ADVANCE(425);
      END_STATE();
    case 344:
      if (lookahead == 'b') ADVANCE(426);
      END_STATE();
    case 345:
      ACCEPT_TOKEN(anon_sym_async);
      END_STATE();
    case 346:
      ACCEPT_TOKEN(anon_sym_await);
      END_STATE();
    case 347:
      ACCEPT_TOKEN(anon_sym_break);
      END_STATE();
    case 348:
      ACCEPT_TOKEN(anon_sym_catch);
      END_STATE();
    case 349:
      if (lookahead == 'e') ADVANCE(427);
      if (lookahead == 's') ADVANCE(428);
      END_STATE();
    case 350:
      ACCEPT_TOKEN(anon_sym_class);
      END_STATE();
    case 351:
      ACCEPT_TOKEN(anon_sym_const);
      END_STATE();
    case 352:
      if (lookahead == 'n') ADVANCE(429);
      END_STATE();
    case 353:
      if (lookahead == 'a') ADVANCE(430);
      END_STATE();
    case 354:
      if (lookahead == 'l') ADVANCE(431);
      END_STATE();
    case 355:
      if (lookahead == 'a') ADVANCE(432);
      END_STATE();
    case 356:
      if (lookahead == 'n') ADVANCE(433);
      END_STATE();
    case 357:
      if (lookahead == 'l') ADVANCE(434);
      END_STATE();
    case 358:
      if (lookahead == 'e') ADVANCE(243);
      END_STATE();
    case 359:
      if (lookahead == 'e') ADVANCE(435);
      END_STATE();
    case 360:
      if (lookahead == 's') ADVANCE(436);
      END_STATE();
    case 361:
      ACCEPT_TOKEN(anon_sym_event);
      END_STATE();
    case 362:
      if (lookahead == 'c') ADVANCE(437);
      END_STATE();
    case 363:
      if (lookahead == 'n') ADVANCE(438);
      END_STATE();
    case 364:
      ACCEPT_TOKEN(anon_sym_false);
      END_STATE();
    case 365:
      ACCEPT_TOKEN(anon_sym_field);
      END_STATE();
    case 366:
      if (lookahead == 'l') ADVANCE(439);
      END_STATE();
    case 367:
      ACCEPT_TOKEN(anon_sym_fixed);
      END_STATE();
    case 368:
      if (lookahead == 'c') ADVANCE(440);
      END_STATE();
    case 369:
      if (lookahead == 'l') ADVANCE(441);
      END_STATE();
    case 370:
      ACCEPT_TOKEN(anon_sym_group);
      END_STATE();
    case 371:
      if (lookahead == 'n') ADVANCE(442);
      END_STATE();
    case 372:
      if (lookahead == 'c') ADVANCE(443);
      END_STATE();
    case 373:
      if (lookahead == 'f') ADVANCE(444);
      if (lookahead == 'n') ADVANCE(445);
      END_STATE();
    case 374:
      if (lookahead == 'e') ADVANCE(446);
      END_STATE();
    case 375:
      if (lookahead == 'd') ADVANCE(447);
      END_STATE();
    case 376:
      if (lookahead == 'e') ADVANCE(448);
      END_STATE();
    case 377:
      if (lookahead == 'p') ADVANCE(449);
      END_STATE();
    case 378:
      if (lookahead == 'l') ADVANCE(450);
      END_STATE();
    case 379:
      if (lookahead == 't') ADVANCE(243);
      END_STATE();
    case 380:
      if (lookahead == 't') ADVANCE(451);
      END_STATE();
    case 381:
      if (lookahead == 'b') ADVANCE(452);
      END_STATE();
    case 382:
      if (lookahead == 'i') ADVANCE(453);
      END_STATE();
    case 383:
      ACCEPT_TOKEN(anon_sym_param);
      if (lookahead == 's') ADVANCE(454);
      END_STATE();
    case 384:
      if (lookahead == 'a') ADVANCE(455);
      END_STATE();
    case 385:
      if (lookahead == 't') ADVANCE(456);
      END_STATE();
    case 386:
      if (lookahead == 'r') ADVANCE(457);
      END_STATE();
    case 387:
      if (lookahead == 'c') ADVANCE(458);
      END_STATE();
    case 388:
      if (lookahead == 'c') ADVANCE(459);
      END_STATE();
    case 389:
      if (lookahead == 'n') ADVANCE(460);
      END_STATE();
    case 390:
      if (lookahead == 'd') ADVANCE(461);
      END_STATE();
    case 391:
      if (lookahead == 'e') ADVANCE(462);
      END_STATE();
    case 392:
      if (lookahead == 'r') ADVANCE(463);
      END_STATE();
    case 393:
      if (lookahead == 'r') ADVANCE(464);
      END_STATE();
    case 394:
      if (lookahead == 'n') ADVANCE(465);
      END_STATE();
    case 395:
      if (lookahead == 'd') ADVANCE(466);
      END_STATE();
    case 396:
      if (lookahead == 'd') ADVANCE(467);
      END_STATE();
    case 397:
      if (lookahead == 't') ADVANCE(468);
      END_STATE();
    case 398:
      if (lookahead == 'f') ADVANCE(469);
      END_STATE();
    case 399:
      if (lookahead == 'a') ADVANCE(470);
      END_STATE();
    case 400:
      if (lookahead == 'c') ADVANCE(471);
      END_STATE();
    case 401:
      if (lookahead == 'g') ADVANCE(243);
      END_STATE();
    case 402:
      if (lookahead == 't') ADVANCE(472);
      END_STATE();
    case 403:
      if (lookahead == 'h') ADVANCE(473);
      END_STATE();
    case 404:
      ACCEPT_TOKEN(anon_sym_throw);
      END_STATE();
    case 405:
      if (lookahead == 'f') ADVANCE(474);
      END_STATE();
    case 406:
      if (lookahead == 'c') ADVANCE(475);
      END_STATE();
    case 407:
      if (lookahead == 'a') ADVANCE(476);
      END_STATE();
    case 408:
      if (lookahead == 'e') ADVANCE(477);
      END_STATE();
    case 409:
      if (lookahead == 't') ADVANCE(243);
      END_STATE();
    case 410:
      ACCEPT_TOKEN(anon_sym_using);
      END_STATE();
    case 411:
      if (lookahead == 'a') ADVANCE(478);
      END_STATE();
    case 412:
      if (lookahead == 'i') ADVANCE(479);
      END_STATE();
    case 413:
      if (lookahead == 'n') ADVANCE(480);
      END_STATE();
    case 414:
      ACCEPT_TOKEN(anon_sym_where);
      END_STATE();
    case 415:
      ACCEPT_TOKEN(anon_sym_while);
      END_STATE();
    case 416:
      ACCEPT_TOKEN(anon_sym_yield);
      END_STATE();
    case 417:
      if (lookahead == 'l') ADVANCE(481);
      END_STATE();
    case 418:
      if (lookahead == 'l') ADVANCE(482);
      END_STATE();
    case 419:
      if (lookahead == 'l') ADVANCE(483);
      END_STATE();
    case 420:
      if (lookahead == 'r') ADVANCE(484);
      END_STATE();
    case 421:
      if (lookahead == 'y') ADVANCE(485);
      END_STATE();
    case 422:
      if (lookahead == 'a') ADVANCE(486);
      END_STATE();
    case 423:
      if (lookahead == 'c') ADVANCE(487);
      END_STATE();
    case 424:
      if (lookahead == 't') ADVANCE(488);
      END_STATE();
    case 425:
      if (lookahead == 'i') ADVANCE(489);
      END_STATE();
    case 426:
      if (lookahead == 'l') ADVANCE(490);
      END_STATE();
    case 427:
      if (lookahead == 'd') ADVANCE(491);
      END_STATE();
    case 428:
      if (lookahead == 'u') ADVANCE(492);
      END_STATE();
    case 429:
      if (lookahead == 'u') ADVANCE(493);
      END_STATE();
    case 430:
      if (lookahead == 'l') ADVANCE(243);
      END_STATE();
    case 431:
      if (lookahead == 't') ADVANCE(494);
      END_STATE();
    case 432:
      if (lookahead == 't') ADVANCE(495);
      END_STATE();
    case 433:
      if (lookahead == 'd') ADVANCE(496);
      END_STATE();
    case 434:
      if (lookahead == 'e') ADVANCE(497);
      END_STATE();
    case 435:
      ACCEPT_TOKEN(anon_sym_enable);
      END_STATE();
    case 436:
      ACCEPT_TOKEN(anon_sym_equals);
      END_STATE();
    case 437:
      if (lookahead == 'i') ADVANCE(498);
      END_STATE();
    case 438:
      ACCEPT_TOKEN(anon_sym_extern);
      END_STATE();
    case 439:
      if (lookahead == 'y') ADVANCE(499);
      END_STATE();
    case 440:
      if (lookahead == 'h') ADVANCE(500);
      END_STATE();
    case 441:
      ACCEPT_TOKEN(anon_sym_global);
      END_STATE();
    case 442:
      ACCEPT_TOKEN(anon_sym_hidden);
      END_STATE();
    case 443:
      if (lookahead == 'i') ADVANCE(501);
      END_STATE();
    case 444:
      if (lookahead == 'a') ADVANCE(502);
      END_STATE();
    case 445:
      if (lookahead == 'a') ADVANCE(503);
      END_STATE();
    case 446:
      if (lookahead == 'd') ADVANCE(504);
      END_STATE();
    case 447:
      ACCEPT_TOKEN(anon_sym_method);
      END_STATE();
    case 448:
      ACCEPT_TOKEN(anon_sym_module);
      END_STATE();
    case 449:
      if (lookahead == 'a') ADVANCE(505);
      END_STATE();
    case 450:
      if (lookahead == 'l') ADVANCE(506);
      END_STATE();
    case 451:
      if (lookahead == 'o') ADVANCE(507);
      END_STATE();
    case 452:
      if (lookahead == 'y') ADVANCE(508);
      END_STATE();
    case 453:
      if (lookahead == 'd') ADVANCE(509);
      END_STATE();
    case 454:
      ACCEPT_TOKEN(anon_sym_params);
      END_STATE();
    case 455:
      if (lookahead == 'l') ADVANCE(510);
      END_STATE();
    case 456:
      if (lookahead == 'e') ADVANCE(511);
      END_STATE();
    case 457:
      if (lookahead == 't') ADVANCE(512);
      END_STATE();
    case 458:
      if (lookahead == 't') ADVANCE(513);
      END_STATE();
    case 459:
      ACCEPT_TOKEN(anon_sym_public);
      END_STATE();
    case 460:
      if (lookahead == 'l') ADVANCE(514);
      END_STATE();
    case 461:
      ACCEPT_TOKEN(anon_sym_record);
      END_STATE();
    case 462:
      ACCEPT_TOKEN(anon_sym_remove);
      END_STATE();
    case 463:
      if (lookahead == 'e') ADVANCE(515);
      END_STATE();
    case 464:
      if (lookahead == 'e') ADVANCE(516);
      END_STATE();
    case 465:
      ACCEPT_TOKEN(anon_sym_return);
      END_STATE();
    case 466:
      ACCEPT_TOKEN(anon_sym_scoped);
      END_STATE();
    case 467:
      ACCEPT_TOKEN(anon_sym_sealed);
      END_STATE();
    case 468:
      ACCEPT_TOKEN(anon_sym_select);
      END_STATE();
    case 469:
      ACCEPT_TOKEN(anon_sym_sizeof);
      END_STATE();
    case 470:
      if (lookahead == 'l') ADVANCE(517);
      END_STATE();
    case 471:
      ACCEPT_TOKEN(anon_sym_static);
      END_STATE();
    case 472:
      ACCEPT_TOKEN(anon_sym_struct);
      END_STATE();
    case 473:
      ACCEPT_TOKEN(anon_sym_switch);
      END_STATE();
    case 474:
      ACCEPT_TOKEN(anon_sym_typeof);
      END_STATE();
    case 475:
      if (lookahead == 'k') ADVANCE(518);
      END_STATE();
    case 476:
      if (lookahead == 'g') ADVANCE(519);
      END_STATE();
    case 477:
      ACCEPT_TOKEN(anon_sym_unsafe);
      END_STATE();
    case 478:
      if (lookahead == 'l') ADVANCE(520);
      END_STATE();
    case 479:
      if (lookahead == 'l') ADVANCE(521);
      END_STATE();
    case 480:
      if (lookahead == 'g') ADVANCE(522);
      END_STATE();
    case 481:
      if (lookahead == 'l') ADVANCE(523);
      END_STATE();
    case 482:
      ACCEPT_TOKEN(anon_sym_Stdcall);
      END_STATE();
    case 483:
      if (lookahead == 'l') ADVANCE(524);
      END_STATE();
    case 484:
      if (lookahead == 'e') ADVANCE(525);
      END_STATE();
    case 485:
      if (lookahead == 'p') ADVANCE(526);
      END_STATE();
    case 486:
      if (lookahead == 'l') ADVANCE(527);
      END_STATE();
    case 487:
      if (lookahead == 't') ADVANCE(528);
      END_STATE();
    case 488:
      if (lookahead == 'i') ADVANCE(529);
      END_STATE();
    case 489:
      if (lookahead == 'n') ADVANCE(530);
      END_STATE();
    case 490:
      if (lookahead == 'y') ADVANCE(531);
      END_STATE();
    case 491:
      ACCEPT_TOKEN(anon_sym_checked);
      END_STATE();
    case 492:
      if (lookahead == 'm') ADVANCE(532);
      END_STATE();
    case 493:
      if (lookahead == 'e') ADVANCE(533);
      END_STATE();
    case 494:
      ACCEPT_TOKEN(anon_sym_default);
      END_STATE();
    case 495:
      if (lookahead == 'e') ADVANCE(534);
      END_STATE();
    case 496:
      if (lookahead == 'i') ADVANCE(535);
      END_STATE();
    case 497:
      ACCEPT_TOKEN(anon_sym_disable);
      END_STATE();
    case 498:
      if (lookahead == 't') ADVANCE(536);
      END_STATE();
    case 499:
      ACCEPT_TOKEN(anon_sym_finally);
      END_STATE();
    case 500:
      ACCEPT_TOKEN(anon_sym_foreach);
      END_STATE();
    case 501:
      if (lookahead == 't') ADVANCE(537);
      END_STATE();
    case 502:
      if (lookahead == 'c') ADVANCE(538);
      END_STATE();
    case 503:
      if (lookahead == 'l') ADVANCE(539);
      END_STATE();
    case 504:
      ACCEPT_TOKEN(anon_sym_managed);
      END_STATE();
    case 505:
      if (lookahead == 'c') ADVANCE(540);
      END_STATE();
    case 506:
      ACCEPT_TOKEN(anon_sym_notnull);
      END_STATE();
    case 507:
      if (lookahead == 'r') ADVANCE(541);
      END_STATE();
    case 508:
      ACCEPT_TOKEN(anon_sym_orderby);
      END_STATE();
    case 509:
      if (lookahead == 'e') ADVANCE(542);
      END_STATE();
    case 510:
      ACCEPT_TOKEN(anon_sym_partial);
      END_STATE();
    case 511:
      ACCEPT_TOKEN(anon_sym_private);
      END_STATE();
    case 512:
      if (lookahead == 'y') ADVANCE(543);
      END_STATE();
    case 513:
      if (lookahead == 'e') ADVANCE(544);
      END_STATE();
    case 514:
      if (lookahead == 'y') ADVANCE(545);
      END_STATE();
    case 515:
      if (lookahead == 'd') ADVANCE(546);
      END_STATE();
    case 516:
      ACCEPT_TOKEN(anon_sym_restore);
      END_STATE();
    case 517:
      if (lookahead == 'l') ADVANCE(547);
      END_STATE();
    case 518:
      if (lookahead == 'e') ADVANCE(548);
      END_STATE();
    case 519:
      if (lookahead == 'e') ADVANCE(549);
      END_STATE();
    case 520:
      ACCEPT_TOKEN(anon_sym_virtual);
      END_STATE();
    case 521:
      if (lookahead == 'e') ADVANCE(550);
      END_STATE();
    case 522:
      ACCEPT_TOKEN(anon_sym_warning);
      if (lookahead == 's') ADVANCE(551);
      END_STATE();
    case 523:
      ACCEPT_TOKEN(anon_sym_Fastcall);
      END_STATE();
    case 524:
      ACCEPT_TOKEN(anon_sym_Thiscall);
      END_STATE();
    case 525:
      if (lookahead == 'f') ADVANCE(552);
      END_STATE();
    case 526:
      if (lookahead == 'e') ADVANCE(553);
      END_STATE();
    case 527:
      if (lookahead == 'u') ADVANCE(554);
      END_STATE();
    case 528:
      ACCEPT_TOKEN(anon_sym_abstract);
      END_STATE();
    case 529:
      if (lookahead == 'o') ADVANCE(555);
      END_STATE();
    case 530:
      if (lookahead == 'g') ADVANCE(556);
      END_STATE();
    case 531:
      ACCEPT_TOKEN(anon_sym_assembly);
      END_STATE();
    case 532:
      ACCEPT_TOKEN(anon_sym_checksum);
      END_STATE();
    case 533:
      ACCEPT_TOKEN(anon_sym_continue);
      END_STATE();
    case 534:
      ACCEPT_TOKEN(anon_sym_delegate);
      END_STATE();
    case 535:
      if (lookahead == 'n') ADVANCE(557);
      END_STATE();
    case 536:
      ACCEPT_TOKEN(anon_sym_explicit);
      END_STATE();
    case 537:
      ACCEPT_TOKEN(anon_sym_implicit);
      END_STATE();
    case 538:
      if (lookahead == 'e') ADVANCE(558);
      END_STATE();
    case 539:
      ACCEPT_TOKEN(anon_sym_internal);
      END_STATE();
    case 540:
      if (lookahead == 'e') ADVANCE(559);
      END_STATE();
    case 541:
      ACCEPT_TOKEN(anon_sym_operator);
      END_STATE();
    case 542:
      ACCEPT_TOKEN(anon_sym_override);
      END_STATE();
    case 543:
      ACCEPT_TOKEN(anon_sym_property);
      END_STATE();
    case 544:
      if (lookahead == 'd') ADVANCE(560);
      END_STATE();
    case 545:
      ACCEPT_TOKEN(anon_sym_readonly);
      END_STATE();
    case 546:
      ACCEPT_TOKEN(anon_sym_required);
      END_STATE();
    case 547:
      if (lookahead == 'o') ADVANCE(561);
      END_STATE();
    case 548:
      if (lookahead == 'd') ADVANCE(562);
      END_STATE();
    case 549:
      if (lookahead == 'd') ADVANCE(563);
      END_STATE();
    case 550:
      ACCEPT_TOKEN(anon_sym_volatile);
      END_STATE();
    case 551:
      ACCEPT_TOKEN(anon_sym_warnings);
      END_STATE();
    case 552:
      ACCEPT_TOKEN(anon_sym___makeref);
      END_STATE();
    case 553:
      ACCEPT_TOKEN(anon_sym___reftype);
      END_STATE();
    case 554:
      if (lookahead == 'e') ADVANCE(564);
      END_STATE();
    case 555:
      if (lookahead == 'n') ADVANCE(565);
      END_STATE();
    case 556:
      ACCEPT_TOKEN(anon_sym_ascending);
      END_STATE();
    case 557:
      if (lookahead == 'g') ADVANCE(566);
      END_STATE();
    case 558:
      ACCEPT_TOKEN(anon_sym_interface);
      END_STATE();
    case 559:
      ACCEPT_TOKEN(anon_sym_namespace);
      END_STATE();
    case 560:
      ACCEPT_TOKEN(anon_sym_protected);
      END_STATE();
    case 561:
      if (lookahead == 'c') ADVANCE(567);
      END_STATE();
    case 562:
      ACCEPT_TOKEN(anon_sym_unchecked);
      END_STATE();
    case 563:
      ACCEPT_TOKEN(anon_sym_unmanaged);
      END_STATE();
    case 564:
      ACCEPT_TOKEN(anon_sym___refvalue);
      END_STATE();
    case 565:
      if (lookahead == 's') ADVANCE(568);
      END_STATE();
    case 566:
      ACCEPT_TOKEN(anon_sym_descending);
      END_STATE();
    case 567:
      ACCEPT_TOKEN(anon_sym_stackalloc);
      END_STATE();
    case 568:
      ACCEPT_TOKEN(anon_sym_annotations);
      END_STATE();
    default:
      return false;
  }
}

static const TSLexMode ts_lex_modes[STATE_COUNT] = {
  [0] = {.lex_state = 0, .external_lex_state = 1},
  [1] = {.lex_state = 131, .external_lex_state = 2},
  [2] = {.lex_state = 131, .external_lex_state = 2},
  [3] = {.lex_state = 131, .external_lex_state = 2},
  [4] = {.lex_state = 131, .external_lex_state = 2},
  [5] = {.lex_state = 131, .external_lex_state = 2},
  [6] = {.lex_state = 131, .external_lex_state = 2},
  [7] = {.lex_state = 131, .external_lex_state = 2},
  [8] = {.lex_state = 131, .external_lex_state = 2},
  [9] = {.lex_state = 131, .external_lex_state = 2},
  [10] = {.lex_state = 131, .external_lex_state = 2},
  [11] = {.lex_state = 131, .external_lex_state = 2},
  [12] = {.lex_state = 131, .external_lex_state = 2},
  [13] = {.lex_state = 131, .external_lex_state = 2},
  [14] = {.lex_state = 131, .external_lex_state = 2},
  [15] = {.lex_state = 131, .external_lex_state = 2},
  [16] = {.lex_state = 131, .external_lex_state = 2},
  [17] = {.lex_state = 131, .external_lex_state = 2},
  [18] = {.lex_state = 131, .external_lex_state = 2},
  [19] = {.lex_state = 131, .external_lex_state = 2},
  [20] = {.lex_state = 131, .external_lex_state = 2},
  [21] = {.lex_state = 131, .external_lex_state = 2},
  [22] = {.lex_state = 131, .external_lex_state = 2},
  [23] = {.lex_state = 131, .external_lex_state = 2},
  [24] = {.lex_state = 131, .external_lex_state = 2},
  [25] = {.lex_state = 131, .external_lex_state = 2},
  [26] = {.lex_state = 131, .external_lex_state = 2},
  [27] = {.lex_state = 131, .external_lex_state = 2},
  [28] = {.lex_state = 131, .external_lex_state = 2},
  [29] = {.lex_state = 131, .external_lex_state = 2},
  [30] = {.lex_state = 131, .external_lex_state = 2},
  [31] = {.lex_state = 131, .external_lex_state = 2},
  [32] = {.lex_state = 131, .external_lex_state = 2},
  [33] = {.lex_state = 131, .external_lex_state = 2},
  [34] = {.lex_state = 131, .external_lex_state = 2},
  [35] = {.lex_state = 131, .external_lex_state = 2},
  [36] = {.lex_state = 131, .external_lex_state = 2},
  [37] = {.lex_state = 131, .external_lex_state = 2},
  [38] = {.lex_state = 131, .external_lex_state = 2},
  [39] = {.lex_state = 131, .external_lex_state = 2},
  [40] = {.lex_state = 131, .external_lex_state = 2},
  [41] = {.lex_state = 131, .external_lex_state = 2},
  [42] = {.lex_state = 131, .external_lex_state = 2},
  [43] = {.lex_state = 131, .external_lex_state = 2},
  [44] = {.lex_state = 131, .external_lex_state = 2},
  [45] = {.lex_state = 131, .external_lex_state = 2},
  [46] = {.lex_state = 131, .external_lex_state = 2},
  [47] = {.lex_state = 131, .external_lex_state = 2},
  [48] = {.lex_state = 131, .external_lex_state = 2},
  [49] = {.lex_state = 131, .external_lex_state = 2},
  [50] = {.lex_state = 131, .external_lex_state = 2},
  [51] = {.lex_state = 131, .external_lex_state = 2},
  [52] = {.lex_state = 131, .external_lex_state = 2},
  [53] = {.lex_state = 131, .external_lex_state = 2},
  [54] = {.lex_state = 131, .external_lex_state = 2},
  [55] = {.lex_state = 131, .external_lex_state = 2},
  [56] = {.lex_state = 131, .external_lex_state = 2},
  [57] = {.lex_state = 131, .external_lex_state = 2},
  [58] = {.lex_state = 131, .external_lex_state = 2},
  [59] = {.lex_state = 131, .external_lex_state = 2},
  [60] = {.lex_state = 131, .external_lex_state = 2},
  [61] = {.lex_state = 131, .external_lex_state = 2},
  [62] = {.lex_state = 131, .external_lex_state = 2},
  [63] = {.lex_state = 131, .external_lex_state = 2},
  [64] = {.lex_state = 131, .external_lex_state = 2},
  [65] = {.lex_state = 131, .external_lex_state = 2},
  [66] = {.lex_state = 131, .external_lex_state = 2},
  [67] = {.lex_state = 131, .external_lex_state = 2},
  [68] = {.lex_state = 131, .external_lex_state = 2},
  [69] = {.lex_state = 131, .external_lex_state = 2},
  [70] = {.lex_state = 131, .external_lex_state = 2},
  [71] = {.lex_state = 131, .external_lex_state = 2},
  [72] = {.lex_state = 131, .external_lex_state = 2},
  [73] = {.lex_state = 131, .external_lex_state = 2},
  [74] = {.lex_state = 131, .external_lex_state = 2},
  [75] = {.lex_state = 131, .external_lex_state = 2},
  [76] = {.lex_state = 131, .external_lex_state = 2},
  [77] = {.lex_state = 131, .external_lex_state = 2},
  [78] = {.lex_state = 131, .external_lex_state = 2},
  [79] = {.lex_state = 131, .external_lex_state = 2},
  [80] = {.lex_state = 131, .external_lex_state = 2},
  [81] = {.lex_state = 131, .external_lex_state = 2},
  [82] = {.lex_state = 131, .external_lex_state = 2},
  [83] = {.lex_state = 131, .external_lex_state = 2},
  [84] = {.lex_state = 131, .external_lex_state = 2},
  [85] = {.lex_state = 131, .external_lex_state = 2},
  [86] = {.lex_state = 131, .external_lex_state = 2},
  [87] = {.lex_state = 131, .external_lex_state = 2},
  [88] = {.lex_state = 131, .external_lex_state = 2},
  [89] = {.lex_state = 131, .external_lex_state = 2},
  [90] = {.lex_state = 131, .external_lex_state = 2},
  [91] = {.lex_state = 131, .external_lex_state = 2},
  [92] = {.lex_state = 131, .external_lex_state = 2},
  [93] = {.lex_state = 131, .external_lex_state = 2},
  [94] = {.lex_state = 131, .external_lex_state = 2},
  [95] = {.lex_state = 131, .external_lex_state = 2},
  [96] = {.lex_state = 131, .external_lex_state = 2},
  [97] = {.lex_state = 131, .external_lex_state = 2},
  [98] = {.lex_state = 131, .external_lex_state = 2},
  [99] = {.lex_state = 131, .external_lex_state = 2},
  [100] = {.lex_state = 131, .external_lex_state = 2},
  [101] = {.lex_state = 131, .external_lex_state = 2},
  [102] = {.lex_state = 131, .external_lex_state = 2},
  [103] = {.lex_state = 131, .external_lex_state = 2},
  [104] = {.lex_state = 131, .external_lex_state = 2},
  [105] = {.lex_state = 131, .external_lex_state = 2},
  [106] = {.lex_state = 131, .external_lex_state = 2},
  [107] = {.lex_state = 131, .external_lex_state = 2},
  [108] = {.lex_state = 131, .external_lex_state = 2},
  [109] = {.lex_state = 131, .external_lex_state = 2},
  [110] = {.lex_state = 131, .external_lex_state = 2},
  [111] = {.lex_state = 131, .external_lex_state = 2},
  [112] = {.lex_state = 131, .external_lex_state = 2},
  [113] = {.lex_state = 131, .external_lex_state = 2},
  [114] = {.lex_state = 131, .external_lex_state = 2},
  [115] = {.lex_state = 131, .external_lex_state = 2},
  [116] = {.lex_state = 131, .external_lex_state = 2},
  [117] = {.lex_state = 131, .external_lex_state = 2},
  [118] = {.lex_state = 131, .external_lex_state = 2},
  [119] = {.lex_state = 131, .external_lex_state = 2},
  [120] = {.lex_state = 131, .external_lex_state = 2},
  [121] = {.lex_state = 131, .external_lex_state = 2},
  [122] = {.lex_state = 131, .external_lex_state = 2},
  [123] = {.lex_state = 131, .external_lex_state = 2},
  [124] = {.lex_state = 131, .external_lex_state = 2},
  [125] = {.lex_state = 131, .external_lex_state = 2},
  [126] = {.lex_state = 131, .external_lex_state = 2},
  [127] = {.lex_state = 131, .external_lex_state = 2},
  [128] = {.lex_state = 131, .external_lex_state = 2},
  [129] = {.lex_state = 131, .external_lex_state = 2},
  [130] = {.lex_state = 131, .external_lex_state = 2},
  [131] = {.lex_state = 131, .external_lex_state = 2},
  [132] = {.lex_state = 131, .external_lex_state = 2},
  [133] = {.lex_state = 131, .external_lex_state = 2},
  [134] = {.lex_state = 131, .external_lex_state = 2},
  [135] = {.lex_state = 131, .external_lex_state = 2},
  [136] = {.lex_state = 131, .external_lex_state = 2},
  [137] = {.lex_state = 131, .external_lex_state = 2},
  [138] = {.lex_state = 131, .external_lex_state = 2},
  [139] = {.lex_state = 131, .external_lex_state = 2},
  [140] = {.lex_state = 131, .external_lex_state = 2},
  [141] = {.lex_state = 131, .external_lex_state = 2},
  [142] = {.lex_state = 131, .external_lex_state = 2},
  [143] = {.lex_state = 131, .external_lex_state = 2},
  [144] = {.lex_state = 131, .external_lex_state = 2},
  [145] = {.lex_state = 131, .external_lex_state = 2},
  [146] = {.lex_state = 131, .external_lex_state = 2},
  [147] = {.lex_state = 131, .external_lex_state = 2},
  [148] = {.lex_state = 131, .external_lex_state = 2},
  [149] = {.lex_state = 131, .external_lex_state = 2},
  [150] = {.lex_state = 131, .external_lex_state = 2},
  [151] = {.lex_state = 131, .external_lex_state = 2},
  [152] = {.lex_state = 131, .external_lex_state = 2},
  [153] = {.lex_state = 131, .external_lex_state = 2},
  [154] = {.lex_state = 131, .external_lex_state = 2},
  [155] = {.lex_state = 131, .external_lex_state = 2},
  [156] = {.lex_state = 131, .external_lex_state = 2},
  [157] = {.lex_state = 131, .external_lex_state = 2},
  [158] = {.lex_state = 131, .external_lex_state = 2},
  [159] = {.lex_state = 131, .external_lex_state = 2},
  [160] = {.lex_state = 131, .external_lex_state = 2},
  [161] = {.lex_state = 131, .external_lex_state = 2},
  [162] = {.lex_state = 131, .external_lex_state = 2},
  [163] = {.lex_state = 131, .external_lex_state = 2},
  [164] = {.lex_state = 131, .external_lex_state = 2},
  [165] = {.lex_state = 131, .external_lex_state = 2},
  [166] = {.lex_state = 131, .external_lex_state = 2},
  [167] = {.lex_state = 131, .external_lex_state = 2},
  [168] = {.lex_state = 131, .external_lex_state = 2},
  [169] = {.lex_state = 131, .external_lex_state = 2},
  [170] = {.lex_state = 131, .external_lex_state = 2},
  [171] = {.lex_state = 131, .external_lex_state = 2},
  [172] = {.lex_state = 131, .external_lex_state = 2},
  [173] = {.lex_state = 131, .external_lex_state = 2},
  [174] = {.lex_state = 131, .external_lex_state = 2},
  [175] = {.lex_state = 131, .external_lex_state = 2},
  [176] = {.lex_state = 131, .external_lex_state = 2},
  [177] = {.lex_state = 131, .external_lex_state = 2},
  [178] = {.lex_state = 131, .external_lex_state = 2},
  [179] = {.lex_state = 131, .external_lex_state = 2},
  [180] = {.lex_state = 131, .external_lex_state = 2},
  [181] = {.lex_state = 131, .external_lex_state = 2},
  [182] = {.lex_state = 131, .external_lex_state = 2},
  [183] = {.lex_state = 131, .external_lex_state = 2},
  [184] = {.lex_state = 131, .external_lex_state = 2},
  [185] = {.lex_state = 131, .external_lex_state = 2},
  [186] = {.lex_state = 131, .external_lex_state = 2},
  [187] = {.lex_state = 131, .external_lex_state = 2},
  [188] = {.lex_state = 131, .external_lex_state = 2},
  [189] = {.lex_state = 131, .external_lex_state = 2},
  [190] = {.lex_state = 131, .external_lex_state = 2},
  [191] = {.lex_state = 130, .external_lex_state = 2},
  [192] = {.lex_state = 130, .external_lex_state = 2},
  [193] = {.lex_state = 131, .external_lex_state = 2},
  [194] = {.lex_state = 131, .external_lex_state = 2},
  [195] = {.lex_state = 131, .external_lex_state = 2},
  [196] = {.lex_state = 131, .external_lex_state = 2},
  [197] = {.lex_state = 131, .external_lex_state = 2},
  [198] = {.lex_state = 131, .external_lex_state = 2},
  [199] = {.lex_state = 131, .external_lex_state = 2},
  [200] = {.lex_state = 131, .external_lex_state = 2},
  [201] = {.lex_state = 131, .external_lex_state = 2},
  [202] = {.lex_state = 131, .external_lex_state = 2},
  [203] = {.lex_state = 131, .external_lex_state = 2},
  [204] = {.lex_state = 131, .external_lex_state = 2},
  [205] = {.lex_state = 131, .external_lex_state = 2},
  [206] = {.lex_state = 131, .external_lex_state = 2},
  [207] = {.lex_state = 131, .external_lex_state = 2},
  [208] = {.lex_state = 131, .external_lex_state = 2},
  [209] = {.lex_state = 131, .external_lex_state = 2},
  [210] = {.lex_state = 131, .external_lex_state = 2},
  [211] = {.lex_state = 131, .external_lex_state = 2},
  [212] = {.lex_state = 131, .external_lex_state = 2},
  [213] = {.lex_state = 131, .external_lex_state = 2},
  [214] = {.lex_state = 131, .external_lex_state = 2},
  [215] = {.lex_state = 131, .external_lex_state = 2},
  [216] = {.lex_state = 131, .external_lex_state = 2},
  [217] = {.lex_state = 131, .external_lex_state = 2},
  [218] = {.lex_state = 131, .external_lex_state = 2},
  [219] = {.lex_state = 131, .external_lex_state = 2},
  [220] = {.lex_state = 131, .external_lex_state = 2},
  [221] = {.lex_state = 131, .external_lex_state = 2},
  [222] = {.lex_state = 130, .external_lex_state = 2},
  [223] = {.lex_state = 130, .external_lex_state = 2},
  [224] = {.lex_state = 131, .external_lex_state = 2},
  [225] = {.lex_state = 131, .external_lex_state = 2},
  [226] = {.lex_state = 130, .external_lex_state = 2},
  [227] = {.lex_state = 130, .external_lex_state = 2},
  [228] = {.lex_state = 130, .external_lex_state = 2},
  [229] = {.lex_state = 130, .external_lex_state = 2},
  [230] = {.lex_state = 130, .external_lex_state = 2},
  [231] = {.lex_state = 130, .external_lex_state = 2},
  [232] = {.lex_state = 130, .external_lex_state = 2},
  [233] = {.lex_state = 130, .external_lex_state = 2},
  [234] = {.lex_state = 130, .external_lex_state = 3},
  [235] = {.lex_state = 130, .external_lex_state = 3},
  [236] = {.lex_state = 130, .external_lex_state = 3},
  [237] = {.lex_state = 130, .external_lex_state = 3},
  [238] = {.lex_state = 130, .external_lex_state = 2},
  [239] = {.lex_state = 130, .external_lex_state = 2},
  [240] = {.lex_state = 130, .external_lex_state = 2},
  [241] = {.lex_state = 130, .external_lex_state = 2},
  [242] = {.lex_state = 130, .external_lex_state = 2},
  [243] = {.lex_state = 130, .external_lex_state = 2},
  [244] = {.lex_state = 130, .external_lex_state = 2},
  [245] = {.lex_state = 130, .external_lex_state = 2},
  [246] = {.lex_state = 130, .external_lex_state = 2},
  [247] = {.lex_state = 130, .external_lex_state = 2},
  [248] = {.lex_state = 130, .external_lex_state = 2},
  [249] = {.lex_state = 130, .external_lex_state = 2},
  [250] = {.lex_state = 130, .external_lex_state = 2},
  [251] = {.lex_state = 130, .external_lex_state = 2},
  [252] = {.lex_state = 130, .external_lex_state = 2},
  [253] = {.lex_state = 130, .external_lex_state = 2},
  [254] = {.lex_state = 130, .external_lex_state = 3},
  [255] = {.lex_state = 130, .external_lex_state = 2},
  [256] = {.lex_state = 130, .external_lex_state = 2},
  [257] = {.lex_state = 130, .external_lex_state = 2},
  [258] = {.lex_state = 130, .external_lex_state = 2},
  [259] = {.lex_state = 130, .external_lex_state = 3},
  [260] = {.lex_state = 130, .external_lex_state = 2},
  [261] = {.lex_state = 130, .external_lex_state = 3},
  [262] = {.lex_state = 130, .external_lex_state = 3},
  [263] = {.lex_state = 130, .external_lex_state = 2},
  [264] = {.lex_state = 130, .external_lex_state = 2},
  [265] = {.lex_state = 130, .external_lex_state = 2},
  [266] = {.lex_state = 130, .external_lex_state = 2},
  [267] = {.lex_state = 130, .external_lex_state = 2},
  [268] = {.lex_state = 130, .external_lex_state = 2},
  [269] = {.lex_state = 130, .external_lex_state = 2},
  [270] = {.lex_state = 130, .external_lex_state = 2},
  [271] = {.lex_state = 130, .external_lex_state = 2},
  [272] = {.lex_state = 130, .external_lex_state = 2},
  [273] = {.lex_state = 130, .external_lex_state = 2},
  [274] = {.lex_state = 130, .external_lex_state = 2},
  [275] = {.lex_state = 130, .external_lex_state = 2},
  [276] = {.lex_state = 130, .external_lex_state = 2},
  [277] = {.lex_state = 130, .external_lex_state = 2},
  [278] = {.lex_state = 130, .external_lex_state = 2},
  [279] = {.lex_state = 130, .external_lex_state = 2},
  [280] = {.lex_state = 130, .external_lex_state = 2},
  [281] = {.lex_state = 130, .external_lex_state = 2},
  [282] = {.lex_state = 130, .external_lex_state = 2},
  [283] = {.lex_state = 130, .external_lex_state = 2},
  [284] = {.lex_state = 130, .external_lex_state = 2},
  [285] = {.lex_state = 130, .external_lex_state = 2},
  [286] = {.lex_state = 130, .external_lex_state = 2},
  [287] = {.lex_state = 130, .external_lex_state = 2},
  [288] = {.lex_state = 130, .external_lex_state = 2},
  [289] = {.lex_state = 130, .external_lex_state = 2},
  [290] = {.lex_state = 130, .external_lex_state = 2},
  [291] = {.lex_state = 130, .external_lex_state = 2},
  [292] = {.lex_state = 130, .external_lex_state = 2},
  [293] = {.lex_state = 130, .external_lex_state = 2},
  [294] = {.lex_state = 130, .external_lex_state = 2},
  [295] = {.lex_state = 130, .external_lex_state = 2},
  [296] = {.lex_state = 131, .external_lex_state = 2},
  [297] = {.lex_state = 130, .external_lex_state = 2},
  [298] = {.lex_state = 130, .external_lex_state = 2},
  [299] = {.lex_state = 130, .external_lex_state = 2},
  [300] = {.lex_state = 130, .external_lex_state = 2},
  [301] = {.lex_state = 131, .external_lex_state = 2},
  [302] = {.lex_state = 130, .external_lex_state = 2},
  [303] = {.lex_state = 131, .external_lex_state = 2},
  [304] = {.lex_state = 130, .external_lex_state = 2},
  [305] = {.lex_state = 130, .external_lex_state = 2},
  [306] = {.lex_state = 130, .external_lex_state = 2},
  [307] = {.lex_state = 130, .external_lex_state = 2},
  [308] = {.lex_state = 130, .external_lex_state = 2},
  [309] = {.lex_state = 131, .external_lex_state = 2},
  [310] = {.lex_state = 131, .external_lex_state = 2},
  [311] = {.lex_state = 131, .external_lex_state = 2},
  [312] = {.lex_state = 130, .external_lex_state = 2},
  [313] = {.lex_state = 130, .external_lex_state = 2},
  [314] = {.lex_state = 130, .external_lex_state = 2},
  [315] = {.lex_state = 131, .external_lex_state = 2},
  [316] = {.lex_state = 131, .external_lex_state = 2},
  [317] = {.lex_state = 130, .external_lex_state = 2},
  [318] = {.lex_state = 130, .external_lex_state = 2},
  [319] = {.lex_state = 131, .external_lex_state = 2},
  [320] = {.lex_state = 131, .external_lex_state = 2},
  [321] = {.lex_state = 130, .external_lex_state = 2},
  [322] = {.lex_state = 131, .external_lex_state = 2},
  [323] = {.lex_state = 130, .external_lex_state = 2},
  [324] = {.lex_state = 131, .external_lex_state = 2},
  [325] = {.lex_state = 130, .external_lex_state = 2},
  [326] = {.lex_state = 131, .external_lex_state = 2},
  [327] = {.lex_state = 130, .external_lex_state = 2},
  [328] = {.lex_state = 130, .external_lex_state = 2},
  [329] = {.lex_state = 131, .external_lex_state = 2},
  [330] = {.lex_state = 131, .external_lex_state = 2},
  [331] = {.lex_state = 131, .external_lex_state = 2},
  [332] = {.lex_state = 130, .external_lex_state = 2},
  [333] = {.lex_state = 130, .external_lex_state = 2},
  [334] = {.lex_state = 130, .external_lex_state = 2},
  [335] = {.lex_state = 131, .external_lex_state = 2},
  [336] = {.lex_state = 130, .external_lex_state = 2},
  [337] = {.lex_state = 131, .external_lex_state = 2},
  [338] = {.lex_state = 131, .external_lex_state = 2},
  [339] = {.lex_state = 131, .external_lex_state = 2},
  [340] = {.lex_state = 130, .external_lex_state = 2},
  [341] = {.lex_state = 130, .external_lex_state = 2},
  [342] = {.lex_state = 130, .external_lex_state = 2},
  [343] = {.lex_state = 131, .external_lex_state = 2},
  [344] = {.lex_state = 131, .external_lex_state = 2},
  [345] = {.lex_state = 130, .external_lex_state = 2},
  [346] = {.lex_state = 131, .external_lex_state = 2},
  [347] = {.lex_state = 131, .external_lex_state = 2},
  [348] = {.lex_state = 131, .external_lex_state = 2},
  [349] = {.lex_state = 130, .external_lex_state = 2},
  [350] = {.lex_state = 130, .external_lex_state = 2},
  [351] = {.lex_state = 130, .external_lex_state = 2},
  [352] = {.lex_state = 131, .external_lex_state = 2},
  [353] = {.lex_state = 130, .external_lex_state = 2},
  [354] = {.lex_state = 130, .external_lex_state = 2},
  [355] = {.lex_state = 131, .external_lex_state = 2},
  [356] = {.lex_state = 131, .external_lex_state = 2},
  [357] = {.lex_state = 131, .external_lex_state = 2},
  [358] = {.lex_state = 131, .external_lex_state = 2},
  [359] = {.lex_state = 131, .external_lex_state = 2},
  [360] = {.lex_state = 131, .external_lex_state = 2},
  [361] = {.lex_state = 131, .external_lex_state = 2},
  [362] = {.lex_state = 131, .external_lex_state = 2},
  [363] = {.lex_state = 131, .external_lex_state = 2},
  [364] = {.lex_state = 131, .external_lex_state = 2},
  [365] = {.lex_state = 131, .external_lex_state = 2},
  [366] = {.lex_state = 131, .external_lex_state = 2},
  [367] = {.lex_state = 131, .external_lex_state = 2},
  [368] = {.lex_state = 131, .external_lex_state = 2},
  [369] = {.lex_state = 131, .external_lex_state = 2},
  [370] = {.lex_state = 131, .external_lex_state = 2},
  [371] = {.lex_state = 131, .external_lex_state = 2},
  [372] = {.lex_state = 131, .external_lex_state = 2},
  [373] = {.lex_state = 131, .external_lex_state = 2},
  [374] = {.lex_state = 131, .external_lex_state = 2},
  [375] = {.lex_state = 131, .external_lex_state = 2},
  [376] = {.lex_state = 131, .external_lex_state = 2},
  [377] = {.lex_state = 131, .external_lex_state = 2},
  [378] = {.lex_state = 131, .external_lex_state = 2},
  [379] = {.lex_state = 131, .external_lex_state = 2},
  [380] = {.lex_state = 131, .external_lex_state = 2},
  [381] = {.lex_state = 131, .external_lex_state = 2},
  [382] = {.lex_state = 131, .external_lex_state = 2},
  [383] = {.lex_state = 131, .external_lex_state = 2},
  [384] = {.lex_state = 131, .external_lex_state = 2},
  [385] = {.lex_state = 131, .external_lex_state = 2},
  [386] = {.lex_state = 131, .external_lex_state = 2},
  [387] = {.lex_state = 131, .external_lex_state = 2},
  [388] = {.lex_state = 131, .external_lex_state = 2},
  [389] = {.lex_state = 131, .external_lex_state = 2},
  [390] = {.lex_state = 131, .external_lex_state = 2},
  [391] = {.lex_state = 131, .external_lex_state = 2},
  [392] = {.lex_state = 131, .external_lex_state = 2},
  [393] = {.lex_state = 131, .external_lex_state = 2},
  [394] = {.lex_state = 131, .external_lex_state = 2},
  [395] = {.lex_state = 131, .external_lex_state = 2},
  [396] = {.lex_state = 131, .external_lex_state = 2},
  [397] = {.lex_state = 131, .external_lex_state = 2},
  [398] = {.lex_state = 131, .external_lex_state = 2},
  [399] = {.lex_state = 131, .external_lex_state = 2},
  [400] = {.lex_state = 131, .external_lex_state = 2},
  [401] = {.lex_state = 131, .external_lex_state = 2},
  [402] = {.lex_state = 131, .external_lex_state = 2},
  [403] = {.lex_state = 131, .external_lex_state = 2},
  [404] = {.lex_state = 131, .external_lex_state = 2},
  [405] = {.lex_state = 131, .external_lex_state = 2},
  [406] = {.lex_state = 131, .external_lex_state = 2},
  [407] = {.lex_state = 131, .external_lex_state = 2},
  [408] = {.lex_state = 131, .external_lex_state = 2},
  [409] = {.lex_state = 131, .external_lex_state = 2},
  [410] = {.lex_state = 131, .external_lex_state = 2},
  [411] = {.lex_state = 131, .external_lex_state = 2},
  [412] = {.lex_state = 131, .external_lex_state = 2},
  [413] = {.lex_state = 131, .external_lex_state = 2},
  [414] = {.lex_state = 131, .external_lex_state = 2},
  [415] = {.lex_state = 131, .external_lex_state = 2},
  [416] = {.lex_state = 131, .external_lex_state = 2},
  [417] = {.lex_state = 131, .external_lex_state = 2},
  [418] = {.lex_state = 131, .external_lex_state = 2},
  [419] = {.lex_state = 131, .external_lex_state = 2},
  [420] = {.lex_state = 131, .external_lex_state = 2},
  [421] = {.lex_state = 131, .external_lex_state = 2},
  [422] = {.lex_state = 131, .external_lex_state = 2},
  [423] = {.lex_state = 131, .external_lex_state = 2},
  [424] = {.lex_state = 131, .external_lex_state = 2},
  [425] = {.lex_state = 131, .external_lex_state = 2},
  [426] = {.lex_state = 131, .external_lex_state = 2},
  [427] = {.lex_state = 131, .external_lex_state = 2},
  [428] = {.lex_state = 131, .external_lex_state = 2},
  [429] = {.lex_state = 131, .external_lex_state = 2},
  [430] = {.lex_state = 131, .external_lex_state = 2},
  [431] = {.lex_state = 131, .external_lex_state = 2},
  [432] = {.lex_state = 131, .external_lex_state = 2},
  [433] = {.lex_state = 131, .external_lex_state = 2},
  [434] = {.lex_state = 131, .external_lex_state = 2},
  [435] = {.lex_state = 131, .external_lex_state = 2},
  [436] = {.lex_state = 131, .external_lex_state = 2},
  [437] = {.lex_state = 131, .external_lex_state = 2},
  [438] = {.lex_state = 131, .external_lex_state = 2},
  [439] = {.lex_state = 131, .external_lex_state = 2},
  [440] = {.lex_state = 131, .external_lex_state = 2},
  [441] = {.lex_state = 131, .external_lex_state = 2},
  [442] = {.lex_state = 131, .external_lex_state = 2},
  [443] = {.lex_state = 131, .external_lex_state = 2},
  [444] = {.lex_state = 131, .external_lex_state = 2},
  [445] = {.lex_state = 131, .external_lex_state = 2},
  [446] = {.lex_state = 131, .external_lex_state = 2},
  [447] = {.lex_state = 131, .external_lex_state = 2},
  [448] = {.lex_state = 131, .external_lex_state = 2},
  [449] = {.lex_state = 131, .external_lex_state = 2},
  [450] = {.lex_state = 131, .external_lex_state = 2},
  [451] = {.lex_state = 131, .external_lex_state = 2},
  [452] = {.lex_state = 131, .external_lex_state = 2},
  [453] = {.lex_state = 131, .external_lex_state = 2},
  [454] = {.lex_state = 131, .external_lex_state = 2},
  [455] = {.lex_state = 131, .external_lex_state = 2},
  [456] = {.lex_state = 131, .external_lex_state = 2},
  [457] = {.lex_state = 131, .external_lex_state = 2},
  [458] = {.lex_state = 131, .external_lex_state = 2},
  [459] = {.lex_state = 131, .external_lex_state = 2},
  [460] = {.lex_state = 131, .external_lex_state = 2},
  [461] = {.lex_state = 131, .external_lex_state = 2},
  [462] = {.lex_state = 131, .external_lex_state = 2},
  [463] = {.lex_state = 131, .external_lex_state = 2},
  [464] = {.lex_state = 131, .external_lex_state = 2},
  [465] = {.lex_state = 131, .external_lex_state = 2},
  [466] = {.lex_state = 131, .external_lex_state = 2},
  [467] = {.lex_state = 131, .external_lex_state = 2},
  [468] = {.lex_state = 131, .external_lex_state = 2},
  [469] = {.lex_state = 131, .external_lex_state = 2},
  [470] = {.lex_state = 131, .external_lex_state = 2},
  [471] = {.lex_state = 131, .external_lex_state = 2},
  [472] = {.lex_state = 131, .external_lex_state = 2},
  [473] = {.lex_state = 131, .external_lex_state = 2},
  [474] = {.lex_state = 131, .external_lex_state = 2},
  [475] = {.lex_state = 131, .external_lex_state = 2},
  [476] = {.lex_state = 131, .external_lex_state = 2},
  [477] = {.lex_state = 131, .external_lex_state = 2},
  [478] = {.lex_state = 131, .external_lex_state = 2},
  [479] = {.lex_state = 131, .external_lex_state = 2},
  [480] = {.lex_state = 131, .external_lex_state = 2},
  [481] = {.lex_state = 131, .external_lex_state = 2},
  [482] = {.lex_state = 131, .external_lex_state = 2},
  [483] = {.lex_state = 131, .external_lex_state = 2},
  [484] = {.lex_state = 131, .external_lex_state = 2},
  [485] = {.lex_state = 131, .external_lex_state = 2},
  [486] = {.lex_state = 131, .external_lex_state = 2},
  [487] = {.lex_state = 131, .external_lex_state = 2},
  [488] = {.lex_state = 131, .external_lex_state = 2},
  [489] = {.lex_state = 131, .external_lex_state = 2},
  [490] = {.lex_state = 131, .external_lex_state = 2},
  [491] = {.lex_state = 131, .external_lex_state = 2},
  [492] = {.lex_state = 131, .external_lex_state = 2},
  [493] = {.lex_state = 131, .external_lex_state = 2},
  [494] = {.lex_state = 131, .external_lex_state = 2},
  [495] = {.lex_state = 131, .external_lex_state = 2},
  [496] = {.lex_state = 131, .external_lex_state = 2},
  [497] = {.lex_state = 131, .external_lex_state = 2},
  [498] = {.lex_state = 131, .external_lex_state = 2},
  [499] = {.lex_state = 131, .external_lex_state = 2},
  [500] = {.lex_state = 131, .external_lex_state = 2},
  [501] = {.lex_state = 131, .external_lex_state = 2},
  [502] = {.lex_state = 131, .external_lex_state = 2},
  [503] = {.lex_state = 131, .external_lex_state = 2},
  [504] = {.lex_state = 131, .external_lex_state = 2},
  [505] = {.lex_state = 131, .external_lex_state = 2},
  [506] = {.lex_state = 131, .external_lex_state = 2},
  [507] = {.lex_state = 131, .external_lex_state = 2},
  [508] = {.lex_state = 131, .external_lex_state = 2},
  [509] = {.lex_state = 131, .external_lex_state = 2},
  [510] = {.lex_state = 131, .external_lex_state = 2},
  [511] = {.lex_state = 131, .external_lex_state = 2},
  [512] = {.lex_state = 131, .external_lex_state = 2},
  [513] = {.lex_state = 131, .external_lex_state = 2},
  [514] = {.lex_state = 131, .external_lex_state = 2},
  [515] = {.lex_state = 131, .external_lex_state = 2},
  [516] = {.lex_state = 131, .external_lex_state = 2},
  [517] = {.lex_state = 131, .external_lex_state = 2},
  [518] = {.lex_state = 131, .external_lex_state = 2},
  [519] = {.lex_state = 131, .external_lex_state = 2},
  [520] = {.lex_state = 131, .external_lex_state = 2},
  [521] = {.lex_state = 131, .external_lex_state = 2},
  [522] = {.lex_state = 131, .external_lex_state = 2},
  [523] = {.lex_state = 131, .external_lex_state = 2},
  [524] = {.lex_state = 131, .external_lex_state = 2},
  [525] = {.lex_state = 131, .external_lex_state = 2},
  [526] = {.lex_state = 131, .external_lex_state = 2},
  [527] = {.lex_state = 131, .external_lex_state = 2},
  [528] = {.lex_state = 131, .external_lex_state = 2},
  [529] = {.lex_state = 131, .external_lex_state = 2},
  [530] = {.lex_state = 131, .external_lex_state = 2},
  [531] = {.lex_state = 131, .external_lex_state = 2},
  [532] = {.lex_state = 131, .external_lex_state = 2},
  [533] = {.lex_state = 131, .external_lex_state = 2},
  [534] = {.lex_state = 131, .external_lex_state = 2},
  [535] = {.lex_state = 131, .external_lex_state = 2},
  [536] = {.lex_state = 131, .external_lex_state = 2},
  [537] = {.lex_state = 131, .external_lex_state = 2},
  [538] = {.lex_state = 131, .external_lex_state = 2},
  [539] = {.lex_state = 131, .external_lex_state = 2},
  [540] = {.lex_state = 131, .external_lex_state = 2},
  [541] = {.lex_state = 131, .external_lex_state = 2},
  [542] = {.lex_state = 131, .external_lex_state = 2},
  [543] = {.lex_state = 131, .external_lex_state = 2},
  [544] = {.lex_state = 131, .external_lex_state = 2},
  [545] = {.lex_state = 131, .external_lex_state = 2},
  [546] = {.lex_state = 131, .external_lex_state = 2},
  [547] = {.lex_state = 131, .external_lex_state = 2},
  [548] = {.lex_state = 131, .external_lex_state = 2},
  [549] = {.lex_state = 131, .external_lex_state = 2},
  [550] = {.lex_state = 131, .external_lex_state = 2},
  [551] = {.lex_state = 131, .external_lex_state = 2},
  [552] = {.lex_state = 131, .external_lex_state = 2},
  [553] = {.lex_state = 131, .external_lex_state = 2},
  [554] = {.lex_state = 131, .external_lex_state = 2},
  [555] = {.lex_state = 131, .external_lex_state = 2},
  [556] = {.lex_state = 131, .external_lex_state = 2},
  [557] = {.lex_state = 131, .external_lex_state = 2},
  [558] = {.lex_state = 131, .external_lex_state = 2},
  [559] = {.lex_state = 131, .external_lex_state = 2},
  [560] = {.lex_state = 131, .external_lex_state = 2},
  [561] = {.lex_state = 131, .external_lex_state = 2},
  [562] = {.lex_state = 131, .external_lex_state = 2},
  [563] = {.lex_state = 131, .external_lex_state = 2},
  [564] = {.lex_state = 131, .external_lex_state = 2},
  [565] = {.lex_state = 131, .external_lex_state = 2},
  [566] = {.lex_state = 131, .external_lex_state = 2},
  [567] = {.lex_state = 131, .external_lex_state = 2},
  [568] = {.lex_state = 131, .external_lex_state = 2},
  [569] = {.lex_state = 131, .external_lex_state = 2},
  [570] = {.lex_state = 131, .external_lex_state = 2},
  [571] = {.lex_state = 131, .external_lex_state = 2},
  [572] = {.lex_state = 131, .external_lex_state = 2},
  [573] = {.lex_state = 131, .external_lex_state = 2},
  [574] = {.lex_state = 131, .external_lex_state = 2},
  [575] = {.lex_state = 131, .external_lex_state = 2},
  [576] = {.lex_state = 131, .external_lex_state = 2},
  [577] = {.lex_state = 131, .external_lex_state = 2},
  [578] = {.lex_state = 131, .external_lex_state = 2},
  [579] = {.lex_state = 131, .external_lex_state = 2},
  [580] = {.lex_state = 131, .external_lex_state = 2},
  [581] = {.lex_state = 131, .external_lex_state = 2},
  [582] = {.lex_state = 131, .external_lex_state = 2},
  [583] = {.lex_state = 131, .external_lex_state = 2},
  [584] = {.lex_state = 131, .external_lex_state = 2},
  [585] = {.lex_state = 131, .external_lex_state = 2},
  [586] = {.lex_state = 131, .external_lex_state = 2},
  [587] = {.lex_state = 131, .external_lex_state = 2},
  [588] = {.lex_state = 131, .external_lex_state = 2},
  [589] = {.lex_state = 131, .external_lex_state = 2},
  [590] = {.lex_state = 131, .external_lex_state = 2},
  [591] = {.lex_state = 131, .external_lex_state = 2},
  [592] = {.lex_state = 131, .external_lex_state = 2},
  [593] = {.lex_state = 131, .external_lex_state = 2},
  [594] = {.lex_state = 131, .external_lex_state = 2},
  [595] = {.lex_state = 131, .external_lex_state = 2},
  [596] = {.lex_state = 131, .external_lex_state = 2},
  [597] = {.lex_state = 131, .external_lex_state = 2},
  [598] = {.lex_state = 131, .external_lex_state = 2},
  [599] = {.lex_state = 131, .external_lex_state = 2},
  [600] = {.lex_state = 131, .external_lex_state = 2},
  [601] = {.lex_state = 131, .external_lex_state = 2},
  [602] = {.lex_state = 131, .external_lex_state = 2},
  [603] = {.lex_state = 131, .external_lex_state = 2},
  [604] = {.lex_state = 131, .external_lex_state = 2},
  [605] = {.lex_state = 131, .external_lex_state = 2},
  [606] = {.lex_state = 131, .external_lex_state = 2},
  [607] = {.lex_state = 131, .external_lex_state = 2},
  [608] = {.lex_state = 131, .external_lex_state = 2},
  [609] = {.lex_state = 131, .external_lex_state = 2},
  [610] = {.lex_state = 131, .external_lex_state = 2},
  [611] = {.lex_state = 131, .external_lex_state = 2},
  [612] = {.lex_state = 131, .external_lex_state = 2},
  [613] = {.lex_state = 131, .external_lex_state = 2},
  [614] = {.lex_state = 131, .external_lex_state = 2},
  [615] = {.lex_state = 131, .external_lex_state = 2},
  [616] = {.lex_state = 131, .external_lex_state = 2},
  [617] = {.lex_state = 131, .external_lex_state = 2},
  [618] = {.lex_state = 131, .external_lex_state = 2},
  [619] = {.lex_state = 131, .external_lex_state = 2},
  [620] = {.lex_state = 131, .external_lex_state = 2},
  [621] = {.lex_state = 131, .external_lex_state = 2},
  [622] = {.lex_state = 131, .external_lex_state = 2},
  [623] = {.lex_state = 131, .external_lex_state = 2},
  [624] = {.lex_state = 131, .external_lex_state = 2},
  [625] = {.lex_state = 131, .external_lex_state = 2},
  [626] = {.lex_state = 131, .external_lex_state = 2},
  [627] = {.lex_state = 131, .external_lex_state = 2},
  [628] = {.lex_state = 131, .external_lex_state = 2},
  [629] = {.lex_state = 131, .external_lex_state = 2},
  [630] = {.lex_state = 131, .external_lex_state = 2},
  [631] = {.lex_state = 131, .external_lex_state = 2},
  [632] = {.lex_state = 131, .external_lex_state = 2},
  [633] = {.lex_state = 131, .external_lex_state = 2},
  [634] = {.lex_state = 131, .external_lex_state = 2},
  [635] = {.lex_state = 131, .external_lex_state = 2},
  [636] = {.lex_state = 131, .external_lex_state = 2},
  [637] = {.lex_state = 131, .external_lex_state = 2},
  [638] = {.lex_state = 131, .external_lex_state = 2},
  [639] = {.lex_state = 131, .external_lex_state = 2},
  [640] = {.lex_state = 131, .external_lex_state = 2},
  [641] = {.lex_state = 131, .external_lex_state = 2},
  [642] = {.lex_state = 131, .external_lex_state = 2},
  [643] = {.lex_state = 131, .external_lex_state = 2},
  [644] = {.lex_state = 131, .external_lex_state = 2},
  [645] = {.lex_state = 131, .external_lex_state = 2},
  [646] = {.lex_state = 131, .external_lex_state = 2},
  [647] = {.lex_state = 131, .external_lex_state = 2},
  [648] = {.lex_state = 131, .external_lex_state = 2},
  [649] = {.lex_state = 131, .external_lex_state = 2},
  [650] = {.lex_state = 131, .external_lex_state = 2},
  [651] = {.lex_state = 131, .external_lex_state = 2},
  [652] = {.lex_state = 131, .external_lex_state = 2},
  [653] = {.lex_state = 131, .external_lex_state = 2},
  [654] = {.lex_state = 131, .external_lex_state = 2},
  [655] = {.lex_state = 131, .external_lex_state = 2},
  [656] = {.lex_state = 131, .external_lex_state = 2},
  [657] = {.lex_state = 131, .external_lex_state = 2},
  [658] = {.lex_state = 131, .external_lex_state = 2},
  [659] = {.lex_state = 131, .external_lex_state = 2},
  [660] = {.lex_state = 131, .external_lex_state = 2},
  [661] = {.lex_state = 131, .external_lex_state = 2},
  [662] = {.lex_state = 131, .external_lex_state = 2},
  [663] = {.lex_state = 131, .external_lex_state = 2},
  [664] = {.lex_state = 131, .external_lex_state = 2},
  [665] = {.lex_state = 131, .external_lex_state = 2},
  [666] = {.lex_state = 131, .external_lex_state = 2},
  [667] = {.lex_state = 131, .external_lex_state = 2},
  [668] = {.lex_state = 131, .external_lex_state = 2},
  [669] = {.lex_state = 131, .external_lex_state = 2},
  [670] = {.lex_state = 131, .external_lex_state = 2},
  [671] = {.lex_state = 131, .external_lex_state = 2},
  [672] = {.lex_state = 131, .external_lex_state = 2},
  [673] = {.lex_state = 131, .external_lex_state = 2},
  [674] = {.lex_state = 131, .external_lex_state = 2},
  [675] = {.lex_state = 131, .external_lex_state = 2},
  [676] = {.lex_state = 131, .external_lex_state = 2},
  [677] = {.lex_state = 131, .external_lex_state = 2},
  [678] = {.lex_state = 131, .external_lex_state = 2},
  [679] = {.lex_state = 131, .external_lex_state = 2},
  [680] = {.lex_state = 131, .external_lex_state = 2},
  [681] = {.lex_state = 131, .external_lex_state = 2},
  [682] = {.lex_state = 131, .external_lex_state = 2},
  [683] = {.lex_state = 131, .external_lex_state = 2},
  [684] = {.lex_state = 131, .external_lex_state = 2},
  [685] = {.lex_state = 131, .external_lex_state = 2},
  [686] = {.lex_state = 131, .external_lex_state = 2},
  [687] = {.lex_state = 131, .external_lex_state = 2},
  [688] = {.lex_state = 131, .external_lex_state = 2},
  [689] = {.lex_state = 131, .external_lex_state = 2},
  [690] = {.lex_state = 131, .external_lex_state = 2},
  [691] = {.lex_state = 131, .external_lex_state = 2},
  [692] = {.lex_state = 131, .external_lex_state = 2},
  [693] = {.lex_state = 131, .external_lex_state = 2},
  [694] = {.lex_state = 131, .external_lex_state = 2},
  [695] = {.lex_state = 131, .external_lex_state = 2},
  [696] = {.lex_state = 131, .external_lex_state = 2},
  [697] = {.lex_state = 131, .external_lex_state = 2},
  [698] = {.lex_state = 131, .external_lex_state = 2},
  [699] = {.lex_state = 131, .external_lex_state = 2},
  [700] = {.lex_state = 131, .external_lex_state = 2},
  [701] = {.lex_state = 131, .external_lex_state = 2},
  [702] = {.lex_state = 131, .external_lex_state = 2},
  [703] = {.lex_state = 131, .external_lex_state = 2},
  [704] = {.lex_state = 131, .external_lex_state = 2},
  [705] = {.lex_state = 131, .external_lex_state = 2},
  [706] = {.lex_state = 131, .external_lex_state = 2},
  [707] = {.lex_state = 131, .external_lex_state = 2},
  [708] = {.lex_state = 131, .external_lex_state = 2},
  [709] = {.lex_state = 131, .external_lex_state = 2},
  [710] = {.lex_state = 131, .external_lex_state = 2},
  [711] = {.lex_state = 131, .external_lex_state = 2},
  [712] = {.lex_state = 131, .external_lex_state = 2},
  [713] = {.lex_state = 131, .external_lex_state = 2},
  [714] = {.lex_state = 131, .external_lex_state = 2},
  [715] = {.lex_state = 131, .external_lex_state = 2},
  [716] = {.lex_state = 131, .external_lex_state = 2},
  [717] = {.lex_state = 131, .external_lex_state = 2},
  [718] = {.lex_state = 131, .external_lex_state = 2},
  [719] = {.lex_state = 131, .external_lex_state = 2},
  [720] = {.lex_state = 131, .external_lex_state = 2},
  [721] = {.lex_state = 131, .external_lex_state = 2},
  [722] = {.lex_state = 131, .external_lex_state = 2},
  [723] = {.lex_state = 131, .external_lex_state = 2},
  [724] = {.lex_state = 131, .external_lex_state = 2},
  [725] = {.lex_state = 131, .external_lex_state = 2},
  [726] = {.lex_state = 131, .external_lex_state = 2},
  [727] = {.lex_state = 131, .external_lex_state = 2},
  [728] = {.lex_state = 131, .external_lex_state = 2},
  [729] = {.lex_state = 131, .external_lex_state = 2},
  [730] = {.lex_state = 131, .external_lex_state = 2},
  [731] = {.lex_state = 131, .external_lex_state = 2},
  [732] = {.lex_state = 131, .external_lex_state = 2},
  [733] = {.lex_state = 131, .external_lex_state = 2},
  [734] = {.lex_state = 131, .external_lex_state = 2},
  [735] = {.lex_state = 131, .external_lex_state = 2},
  [736] = {.lex_state = 131, .external_lex_state = 2},
  [737] = {.lex_state = 131, .external_lex_state = 2},
  [738] = {.lex_state = 131, .external_lex_state = 2},
  [739] = {.lex_state = 131, .external_lex_state = 2},
  [740] = {.lex_state = 131, .external_lex_state = 2},
  [741] = {.lex_state = 131, .external_lex_state = 2},
  [742] = {.lex_state = 131, .external_lex_state = 2},
  [743] = {.lex_state = 131, .external_lex_state = 2},
  [744] = {.lex_state = 131, .external_lex_state = 2},
  [745] = {.lex_state = 131, .external_lex_state = 2},
  [746] = {.lex_state = 131, .external_lex_state = 2},
  [747] = {.lex_state = 131, .external_lex_state = 2},
  [748] = {.lex_state = 131, .external_lex_state = 2},
  [749] = {.lex_state = 131, .external_lex_state = 2},
  [750] = {.lex_state = 131, .external_lex_state = 2},
  [751] = {.lex_state = 131, .external_lex_state = 2},
  [752] = {.lex_state = 131, .external_lex_state = 2},
  [753] = {.lex_state = 131, .external_lex_state = 2},
  [754] = {.lex_state = 131, .external_lex_state = 2},
  [755] = {.lex_state = 131, .external_lex_state = 2},
  [756] = {.lex_state = 131, .external_lex_state = 2},
  [757] = {.lex_state = 131, .external_lex_state = 2},
  [758] = {.lex_state = 131, .external_lex_state = 2},
  [759] = {.lex_state = 131, .external_lex_state = 2},
  [760] = {.lex_state = 131, .external_lex_state = 2},
  [761] = {.lex_state = 131, .external_lex_state = 2},
  [762] = {.lex_state = 131, .external_lex_state = 2},
  [763] = {.lex_state = 131, .external_lex_state = 2},
  [764] = {.lex_state = 131, .external_lex_state = 2},
  [765] = {.lex_state = 131, .external_lex_state = 2},
  [766] = {.lex_state = 131, .external_lex_state = 2},
  [767] = {.lex_state = 131, .external_lex_state = 2},
  [768] = {.lex_state = 131, .external_lex_state = 2},
  [769] = {.lex_state = 131, .external_lex_state = 2},
  [770] = {.lex_state = 131, .external_lex_state = 2},
  [771] = {.lex_state = 131, .external_lex_state = 2},
  [772] = {.lex_state = 131, .external_lex_state = 2},
  [773] = {.lex_state = 131, .external_lex_state = 2},
  [774] = {.lex_state = 131, .external_lex_state = 2},
  [775] = {.lex_state = 131, .external_lex_state = 2},
  [776] = {.lex_state = 131, .external_lex_state = 2},
  [777] = {.lex_state = 131, .external_lex_state = 2},
  [778] = {.lex_state = 131, .external_lex_state = 2},
  [779] = {.lex_state = 131, .external_lex_state = 2},
  [780] = {.lex_state = 131, .external_lex_state = 2},
  [781] = {.lex_state = 131, .external_lex_state = 2},
  [782] = {.lex_state = 131, .external_lex_state = 2},
  [783] = {.lex_state = 131, .external_lex_state = 2},
  [784] = {.lex_state = 131, .external_lex_state = 2},
  [785] = {.lex_state = 131, .external_lex_state = 2},
  [786] = {.lex_state = 131, .external_lex_state = 2},
  [787] = {.lex_state = 131, .external_lex_state = 2},
  [788] = {.lex_state = 131, .external_lex_state = 2},
  [789] = {.lex_state = 131, .external_lex_state = 2},
  [790] = {.lex_state = 131, .external_lex_state = 2},
  [791] = {.lex_state = 131, .external_lex_state = 2},
  [792] = {.lex_state = 131, .external_lex_state = 2},
  [793] = {.lex_state = 131, .external_lex_state = 2},
  [794] = {.lex_state = 131, .external_lex_state = 2},
  [795] = {.lex_state = 131, .external_lex_state = 2},
  [796] = {.lex_state = 131, .external_lex_state = 2},
  [797] = {.lex_state = 131, .external_lex_state = 2},
  [798] = {.lex_state = 131, .external_lex_state = 2},
  [799] = {.lex_state = 131, .external_lex_state = 2},
  [800] = {.lex_state = 131, .external_lex_state = 2},
  [801] = {.lex_state = 131, .external_lex_state = 2},
  [802] = {.lex_state = 131, .external_lex_state = 2},
  [803] = {.lex_state = 131, .external_lex_state = 2},
  [804] = {.lex_state = 131, .external_lex_state = 2},
  [805] = {.lex_state = 131, .external_lex_state = 2},
  [806] = {.lex_state = 131, .external_lex_state = 2},
  [807] = {.lex_state = 131, .external_lex_state = 2},
  [808] = {.lex_state = 131, .external_lex_state = 2},
  [809] = {.lex_state = 131, .external_lex_state = 2},
  [810] = {.lex_state = 131, .external_lex_state = 2},
  [811] = {.lex_state = 131, .external_lex_state = 2},
  [812] = {.lex_state = 131, .external_lex_state = 2},
  [813] = {.lex_state = 131, .external_lex_state = 2},
  [814] = {.lex_state = 131, .external_lex_state = 2},
  [815] = {.lex_state = 131, .external_lex_state = 2},
  [816] = {.lex_state = 131, .external_lex_state = 2},
  [817] = {.lex_state = 131, .external_lex_state = 2},
  [818] = {.lex_state = 131, .external_lex_state = 2},
  [819] = {.lex_state = 131, .external_lex_state = 2},
  [820] = {.lex_state = 131, .external_lex_state = 2},
  [821] = {.lex_state = 131, .external_lex_state = 2},
  [822] = {.lex_state = 131, .external_lex_state = 2},
  [823] = {.lex_state = 131, .external_lex_state = 2},
  [824] = {.lex_state = 131, .external_lex_state = 2},
  [825] = {.lex_state = 131, .external_lex_state = 2},
  [826] = {.lex_state = 131, .external_lex_state = 2},
  [827] = {.lex_state = 131, .external_lex_state = 2},
  [828] = {.lex_state = 131, .external_lex_state = 2},
  [829] = {.lex_state = 131, .external_lex_state = 2},
  [830] = {.lex_state = 131, .external_lex_state = 2},
  [831] = {.lex_state = 131, .external_lex_state = 2},
  [832] = {.lex_state = 131, .external_lex_state = 2},
  [833] = {.lex_state = 131, .external_lex_state = 2},
  [834] = {.lex_state = 131, .external_lex_state = 2},
  [835] = {.lex_state = 131, .external_lex_state = 2},
  [836] = {.lex_state = 131, .external_lex_state = 2},
  [837] = {.lex_state = 131, .external_lex_state = 2},
  [838] = {.lex_state = 131, .external_lex_state = 2},
  [839] = {.lex_state = 131, .external_lex_state = 2},
  [840] = {.lex_state = 131, .external_lex_state = 2},
  [841] = {.lex_state = 131, .external_lex_state = 2},
  [842] = {.lex_state = 131, .external_lex_state = 2},
  [843] = {.lex_state = 131, .external_lex_state = 2},
  [844] = {.lex_state = 131, .external_lex_state = 2},
  [845] = {.lex_state = 131, .external_lex_state = 2},
  [846] = {.lex_state = 131, .external_lex_state = 2},
  [847] = {.lex_state = 131, .external_lex_state = 2},
  [848] = {.lex_state = 131, .external_lex_state = 2},
  [849] = {.lex_state = 131, .external_lex_state = 2},
  [850] = {.lex_state = 131, .external_lex_state = 2},
  [851] = {.lex_state = 131, .external_lex_state = 2},
  [852] = {.lex_state = 131, .external_lex_state = 2},
  [853] = {.lex_state = 131, .external_lex_state = 2},
  [854] = {.lex_state = 131, .external_lex_state = 2},
  [855] = {.lex_state = 131, .external_lex_state = 2},
  [856] = {.lex_state = 131, .external_lex_state = 2},
  [857] = {.lex_state = 131, .external_lex_state = 2},
  [858] = {.lex_state = 131, .external_lex_state = 2},
  [859] = {.lex_state = 131, .external_lex_state = 2},
  [860] = {.lex_state = 131, .external_lex_state = 2},
  [861] = {.lex_state = 131, .external_lex_state = 2},
  [862] = {.lex_state = 131, .external_lex_state = 2},
  [863] = {.lex_state = 131, .external_lex_state = 2},
  [864] = {.lex_state = 131, .external_lex_state = 2},
  [865] = {.lex_state = 131, .external_lex_state = 2},
  [866] = {.lex_state = 131, .external_lex_state = 2},
  [867] = {.lex_state = 131, .external_lex_state = 2},
  [868] = {.lex_state = 131, .external_lex_state = 2},
  [869] = {.lex_state = 131, .external_lex_state = 2},
  [870] = {.lex_state = 131, .external_lex_state = 2},
  [871] = {.lex_state = 131, .external_lex_state = 2},
  [872] = {.lex_state = 131, .external_lex_state = 2},
  [873] = {.lex_state = 131, .external_lex_state = 2},
  [874] = {.lex_state = 131, .external_lex_state = 2},
  [875] = {.lex_state = 131, .external_lex_state = 2},
  [876] = {.lex_state = 131, .external_lex_state = 2},
  [877] = {.lex_state = 131, .external_lex_state = 2},
  [878] = {.lex_state = 131, .external_lex_state = 2},
  [879] = {.lex_state = 131, .external_lex_state = 2},
  [880] = {.lex_state = 131, .external_lex_state = 2},
  [881] = {.lex_state = 131, .external_lex_state = 2},
  [882] = {.lex_state = 131, .external_lex_state = 2},
  [883] = {.lex_state = 131, .external_lex_state = 2},
  [884] = {.lex_state = 131, .external_lex_state = 2},
  [885] = {.lex_state = 131, .external_lex_state = 2},
  [886] = {.lex_state = 131, .external_lex_state = 2},
  [887] = {.lex_state = 131, .external_lex_state = 2},
  [888] = {.lex_state = 131, .external_lex_state = 2},
  [889] = {.lex_state = 131, .external_lex_state = 2},
  [890] = {.lex_state = 131, .external_lex_state = 2},
  [891] = {.lex_state = 131, .external_lex_state = 2},
  [892] = {.lex_state = 131, .external_lex_state = 2},
  [893] = {.lex_state = 131, .external_lex_state = 2},
  [894] = {.lex_state = 131, .external_lex_state = 2},
  [895] = {.lex_state = 131, .external_lex_state = 2},
  [896] = {.lex_state = 131, .external_lex_state = 2},
  [897] = {.lex_state = 131, .external_lex_state = 2},
  [898] = {.lex_state = 131, .external_lex_state = 2},
  [899] = {.lex_state = 131, .external_lex_state = 2},
  [900] = {.lex_state = 131, .external_lex_state = 2},
  [901] = {.lex_state = 131, .external_lex_state = 2},
  [902] = {.lex_state = 131, .external_lex_state = 2},
  [903] = {.lex_state = 131, .external_lex_state = 2},
  [904] = {.lex_state = 131, .external_lex_state = 2},
  [905] = {.lex_state = 131, .external_lex_state = 2},
  [906] = {.lex_state = 131, .external_lex_state = 2},
  [907] = {.lex_state = 131, .external_lex_state = 2},
  [908] = {.lex_state = 131, .external_lex_state = 2},
  [909] = {.lex_state = 131, .external_lex_state = 2},
  [910] = {.lex_state = 131, .external_lex_state = 2},
  [911] = {.lex_state = 131, .external_lex_state = 2},
  [912] = {.lex_state = 131, .external_lex_state = 2},
  [913] = {.lex_state = 131, .external_lex_state = 2},
  [914] = {.lex_state = 131, .external_lex_state = 2},
  [915] = {.lex_state = 131, .external_lex_state = 2},
  [916] = {.lex_state = 131, .external_lex_state = 2},
  [917] = {.lex_state = 131, .external_lex_state = 2},
  [918] = {.lex_state = 131, .external_lex_state = 2},
  [919] = {.lex_state = 131, .external_lex_state = 2},
  [920] = {.lex_state = 131, .external_lex_state = 2},
  [921] = {.lex_state = 131, .external_lex_state = 2},
  [922] = {.lex_state = 131, .external_lex_state = 2},
  [923] = {.lex_state = 131, .external_lex_state = 2},
  [924] = {.lex_state = 131, .external_lex_state = 2},
  [925] = {.lex_state = 131, .external_lex_state = 2},
  [926] = {.lex_state = 131, .external_lex_state = 2},
  [927] = {.lex_state = 131, .external_lex_state = 2},
  [928] = {.lex_state = 131, .external_lex_state = 2},
  [929] = {.lex_state = 131, .external_lex_state = 2},
  [930] = {.lex_state = 131, .external_lex_state = 2},
  [931] = {.lex_state = 131, .external_lex_state = 2},
  [932] = {.lex_state = 131, .external_lex_state = 2},
  [933] = {.lex_state = 131, .external_lex_state = 2},
  [934] = {.lex_state = 131, .external_lex_state = 2},
  [935] = {.lex_state = 131, .external_lex_state = 2},
  [936] = {.lex_state = 131, .external_lex_state = 2},
  [937] = {.lex_state = 131, .external_lex_state = 2},
  [938] = {.lex_state = 131, .external_lex_state = 2},
  [939] = {.lex_state = 131, .external_lex_state = 2},
  [940] = {.lex_state = 131, .external_lex_state = 2},
  [941] = {.lex_state = 131, .external_lex_state = 2},
  [942] = {.lex_state = 131, .external_lex_state = 2},
  [943] = {.lex_state = 131, .external_lex_state = 2},
  [944] = {.lex_state = 131, .external_lex_state = 2},
  [945] = {.lex_state = 131, .external_lex_state = 2},
  [946] = {.lex_state = 131, .external_lex_state = 2},
  [947] = {.lex_state = 131, .external_lex_state = 2},
  [948] = {.lex_state = 131, .external_lex_state = 2},
  [949] = {.lex_state = 131, .external_lex_state = 2},
  [950] = {.lex_state = 131, .external_lex_state = 2},
  [951] = {.lex_state = 131, .external_lex_state = 2},
  [952] = {.lex_state = 131, .external_lex_state = 2},
  [953] = {.lex_state = 131, .external_lex_state = 2},
  [954] = {.lex_state = 131, .external_lex_state = 2},
  [955] = {.lex_state = 131, .external_lex_state = 2},
  [956] = {.lex_state = 131, .external_lex_state = 2},
  [957] = {.lex_state = 131, .external_lex_state = 2},
  [958] = {.lex_state = 131, .external_lex_state = 2},
  [959] = {.lex_state = 131, .external_lex_state = 2},
  [960] = {.lex_state = 131, .external_lex_state = 2},
  [961] = {.lex_state = 131, .external_lex_state = 2},
  [962] = {.lex_state = 131, .external_lex_state = 2},
  [963] = {.lex_state = 131, .external_lex_state = 2},
  [964] = {.lex_state = 131, .external_lex_state = 2},
  [965] = {.lex_state = 131, .external_lex_state = 2},
  [966] = {.lex_state = 131, .external_lex_state = 2},
  [967] = {.lex_state = 131, .external_lex_state = 2},
  [968] = {.lex_state = 131, .external_lex_state = 2},
  [969] = {.lex_state = 131, .external_lex_state = 2},
  [970] = {.lex_state = 131, .external_lex_state = 2},
  [971] = {.lex_state = 131, .external_lex_state = 2},
  [972] = {.lex_state = 131, .external_lex_state = 2},
  [973] = {.lex_state = 131, .external_lex_state = 2},
  [974] = {.lex_state = 131, .external_lex_state = 2},
  [975] = {.lex_state = 131, .external_lex_state = 2},
  [976] = {.lex_state = 131, .external_lex_state = 2},
  [977] = {.lex_state = 131, .external_lex_state = 2},
  [978] = {.lex_state = 131, .external_lex_state = 2},
  [979] = {.lex_state = 131, .external_lex_state = 2},
  [980] = {.lex_state = 131, .external_lex_state = 2},
  [981] = {.lex_state = 131, .external_lex_state = 2},
  [982] = {.lex_state = 131, .external_lex_state = 2},
  [983] = {.lex_state = 131, .external_lex_state = 2},
  [984] = {.lex_state = 131, .external_lex_state = 2},
  [985] = {.lex_state = 131, .external_lex_state = 2},
  [986] = {.lex_state = 131, .external_lex_state = 2},
  [987] = {.lex_state = 131, .external_lex_state = 2},
  [988] = {.lex_state = 131, .external_lex_state = 2},
  [989] = {.lex_state = 131, .external_lex_state = 2},
  [990] = {.lex_state = 131, .external_lex_state = 2},
  [991] = {.lex_state = 131, .external_lex_state = 2},
  [992] = {.lex_state = 131, .external_lex_state = 2},
  [993] = {.lex_state = 131, .external_lex_state = 2},
  [994] = {.lex_state = 131, .external_lex_state = 2},
  [995] = {.lex_state = 131, .external_lex_state = 2},
  [996] = {.lex_state = 131, .external_lex_state = 2},
  [997] = {.lex_state = 131, .external_lex_state = 2},
  [998] = {.lex_state = 131, .external_lex_state = 2},
  [999] = {.lex_state = 131, .external_lex_state = 2},
  [1000] = {.lex_state = 131, .external_lex_state = 2},
  [1001] = {.lex_state = 131, .external_lex_state = 2},
  [1002] = {.lex_state = 131, .external_lex_state = 2},
  [1003] = {.lex_state = 131, .external_lex_state = 2},
  [1004] = {.lex_state = 131, .external_lex_state = 2},
  [1005] = {.lex_state = 131, .external_lex_state = 2},
  [1006] = {.lex_state = 131, .external_lex_state = 2},
  [1007] = {.lex_state = 131, .external_lex_state = 2},
  [1008] = {.lex_state = 131, .external_lex_state = 2},
  [1009] = {.lex_state = 131, .external_lex_state = 2},
  [1010] = {.lex_state = 131, .external_lex_state = 2},
  [1011] = {.lex_state = 131, .external_lex_state = 2},
  [1012] = {.lex_state = 131, .external_lex_state = 2},
  [1013] = {.lex_state = 131, .external_lex_state = 2},
  [1014] = {.lex_state = 131, .external_lex_state = 2},
  [1015] = {.lex_state = 131, .external_lex_state = 2},
  [1016] = {.lex_state = 131, .external_lex_state = 2},
  [1017] = {.lex_state = 131, .external_lex_state = 2},
  [1018] = {.lex_state = 131, .external_lex_state = 2},
  [1019] = {.lex_state = 131, .external_lex_state = 2},
  [1020] = {.lex_state = 131, .external_lex_state = 2},
  [1021] = {.lex_state = 131, .external_lex_state = 2},
  [1022] = {.lex_state = 131, .external_lex_state = 2},
  [1023] = {.lex_state = 131, .external_lex_state = 2},
  [1024] = {.lex_state = 131, .external_lex_state = 2},
  [1025] = {.lex_state = 131, .external_lex_state = 2},
  [1026] = {.lex_state = 131, .external_lex_state = 2},
  [1027] = {.lex_state = 131, .external_lex_state = 2},
  [1028] = {.lex_state = 131, .external_lex_state = 2},
  [1029] = {.lex_state = 131, .external_lex_state = 2},
  [1030] = {.lex_state = 131, .external_lex_state = 2},
  [1031] = {.lex_state = 131, .external_lex_state = 2},
  [1032] = {.lex_state = 131, .external_lex_state = 2},
  [1033] = {.lex_state = 131, .external_lex_state = 2},
  [1034] = {.lex_state = 131, .external_lex_state = 2},
  [1035] = {.lex_state = 131, .external_lex_state = 2},
  [1036] = {.lex_state = 131, .external_lex_state = 2},
  [1037] = {.lex_state = 131, .external_lex_state = 2},
  [1038] = {.lex_state = 131, .external_lex_state = 2},
  [1039] = {.lex_state = 131, .external_lex_state = 2},
  [1040] = {.lex_state = 131, .external_lex_state = 2},
  [1041] = {.lex_state = 131, .external_lex_state = 2},
  [1042] = {.lex_state = 131, .external_lex_state = 2},
  [1043] = {.lex_state = 131, .external_lex_state = 2},
  [1044] = {.lex_state = 131, .external_lex_state = 2},
  [1045] = {.lex_state = 131, .external_lex_state = 2},
  [1046] = {.lex_state = 131, .external_lex_state = 2},
  [1047] = {.lex_state = 131, .external_lex_state = 2},
  [1048] = {.lex_state = 131, .external_lex_state = 2},
  [1049] = {.lex_state = 131, .external_lex_state = 2},
  [1050] = {.lex_state = 131, .external_lex_state = 2},
  [1051] = {.lex_state = 131, .external_lex_state = 2},
  [1052] = {.lex_state = 131, .external_lex_state = 2},
  [1053] = {.lex_state = 131, .external_lex_state = 2},
  [1054] = {.lex_state = 131, .external_lex_state = 2},
  [1055] = {.lex_state = 131, .external_lex_state = 2},
  [1056] = {.lex_state = 131, .external_lex_state = 2},
  [1057] = {.lex_state = 131, .external_lex_state = 2},
  [1058] = {.lex_state = 131, .external_lex_state = 2},
  [1059] = {.lex_state = 131, .external_lex_state = 2},
  [1060] = {.lex_state = 131, .external_lex_state = 2},
  [1061] = {.lex_state = 131, .external_lex_state = 2},
  [1062] = {.lex_state = 131, .external_lex_state = 2},
  [1063] = {.lex_state = 131, .external_lex_state = 2},
  [1064] = {.lex_state = 131, .external_lex_state = 2},
  [1065] = {.lex_state = 131, .external_lex_state = 2},
  [1066] = {.lex_state = 131, .external_lex_state = 2},
  [1067] = {.lex_state = 131, .external_lex_state = 2},
  [1068] = {.lex_state = 131, .external_lex_state = 2},
  [1069] = {.lex_state = 131, .external_lex_state = 2},
  [1070] = {.lex_state = 131, .external_lex_state = 2},
  [1071] = {.lex_state = 131, .external_lex_state = 2},
  [1072] = {.lex_state = 131, .external_lex_state = 2},
  [1073] = {.lex_state = 131, .external_lex_state = 2},
  [1074] = {.lex_state = 131, .external_lex_state = 2},
  [1075] = {.lex_state = 131, .external_lex_state = 2},
  [1076] = {.lex_state = 131, .external_lex_state = 2},
  [1077] = {.lex_state = 131, .external_lex_state = 2},
  [1078] = {.lex_state = 131, .external_lex_state = 2},
  [1079] = {.lex_state = 131, .external_lex_state = 2},
  [1080] = {.lex_state = 131, .external_lex_state = 2},
  [1081] = {.lex_state = 131, .external_lex_state = 2},
  [1082] = {.lex_state = 131, .external_lex_state = 2},
  [1083] = {.lex_state = 131, .external_lex_state = 2},
  [1084] = {.lex_state = 131, .external_lex_state = 2},
  [1085] = {.lex_state = 131, .external_lex_state = 2},
  [1086] = {.lex_state = 131, .external_lex_state = 2},
  [1087] = {.lex_state = 131, .external_lex_state = 2},
  [1088] = {.lex_state = 131, .external_lex_state = 2},
  [1089] = {.lex_state = 131, .external_lex_state = 2},
  [1090] = {.lex_state = 131, .external_lex_state = 2},
  [1091] = {.lex_state = 131, .external_lex_state = 2},
  [1092] = {.lex_state = 131, .external_lex_state = 2},
  [1093] = {.lex_state = 131, .external_lex_state = 2},
  [1094] = {.lex_state = 131, .external_lex_state = 2},
  [1095] = {.lex_state = 131, .external_lex_state = 2},
  [1096] = {.lex_state = 131, .external_lex_state = 2},
  [1097] = {.lex_state = 131, .external_lex_state = 2},
  [1098] = {.lex_state = 131, .external_lex_state = 2},
  [1099] = {.lex_state = 131, .external_lex_state = 2},
  [1100] = {.lex_state = 131, .external_lex_state = 2},
  [1101] = {.lex_state = 131, .external_lex_state = 2},
  [1102] = {.lex_state = 131, .external_lex_state = 2},
  [1103] = {.lex_state = 131, .external_lex_state = 2},
  [1104] = {.lex_state = 131, .external_lex_state = 2},
  [1105] = {.lex_state = 131, .external_lex_state = 2},
  [1106] = {.lex_state = 131, .external_lex_state = 2},
  [1107] = {.lex_state = 131, .external_lex_state = 2},
  [1108] = {.lex_state = 131, .external_lex_state = 2},
  [1109] = {.lex_state = 131, .external_lex_state = 2},
  [1110] = {.lex_state = 131, .external_lex_state = 2},
  [1111] = {.lex_state = 131, .external_lex_state = 2},
  [1112] = {.lex_state = 131, .external_lex_state = 2},
  [1113] = {.lex_state = 131, .external_lex_state = 2},
  [1114] = {.lex_state = 131, .external_lex_state = 2},
  [1115] = {.lex_state = 131, .external_lex_state = 2},
  [1116] = {.lex_state = 131, .external_lex_state = 2},
  [1117] = {.lex_state = 131, .external_lex_state = 2},
  [1118] = {.lex_state = 131, .external_lex_state = 2},
  [1119] = {.lex_state = 131, .external_lex_state = 2},
  [1120] = {.lex_state = 131, .external_lex_state = 2},
  [1121] = {.lex_state = 131, .external_lex_state = 2},
  [1122] = {.lex_state = 131, .external_lex_state = 2},
  [1123] = {.lex_state = 131, .external_lex_state = 2},
  [1124] = {.lex_state = 131, .external_lex_state = 2},
  [1125] = {.lex_state = 131, .external_lex_state = 2},
  [1126] = {.lex_state = 131, .external_lex_state = 2},
  [1127] = {.lex_state = 131, .external_lex_state = 2},
  [1128] = {.lex_state = 131, .external_lex_state = 2},
  [1129] = {.lex_state = 131, .external_lex_state = 2},
  [1130] = {.lex_state = 131, .external_lex_state = 2},
  [1131] = {.lex_state = 131, .external_lex_state = 2},
  [1132] = {.lex_state = 131, .external_lex_state = 2},
  [1133] = {.lex_state = 131, .external_lex_state = 2},
  [1134] = {.lex_state = 131, .external_lex_state = 2},
  [1135] = {.lex_state = 131, .external_lex_state = 2},
  [1136] = {.lex_state = 131, .external_lex_state = 2},
  [1137] = {.lex_state = 131, .external_lex_state = 2},
  [1138] = {.lex_state = 131, .external_lex_state = 2},
  [1139] = {.lex_state = 131, .external_lex_state = 2},
  [1140] = {.lex_state = 131, .external_lex_state = 2},
  [1141] = {.lex_state = 131, .external_lex_state = 2},
  [1142] = {.lex_state = 131, .external_lex_state = 2},
  [1143] = {.lex_state = 131, .external_lex_state = 2},
  [1144] = {.lex_state = 131, .external_lex_state = 2},
  [1145] = {.lex_state = 131, .external_lex_state = 2},
  [1146] = {.lex_state = 131, .external_lex_state = 2},
  [1147] = {.lex_state = 131, .external_lex_state = 2},
  [1148] = {.lex_state = 131, .external_lex_state = 2},
  [1149] = {.lex_state = 131, .external_lex_state = 2},
  [1150] = {.lex_state = 131, .external_lex_state = 2},
  [1151] = {.lex_state = 131, .external_lex_state = 2},
  [1152] = {.lex_state = 131, .external_lex_state = 2},
  [1153] = {.lex_state = 131, .external_lex_state = 2},
  [1154] = {.lex_state = 131, .external_lex_state = 2},
  [1155] = {.lex_state = 131, .external_lex_state = 2},
  [1156] = {.lex_state = 131, .external_lex_state = 2},
  [1157] = {.lex_state = 131, .external_lex_state = 2},
  [1158] = {.lex_state = 131, .external_lex_state = 2},
  [1159] = {.lex_state = 131, .external_lex_state = 2},
  [1160] = {.lex_state = 131, .external_lex_state = 2},
  [1161] = {.lex_state = 131, .external_lex_state = 2},
  [1162] = {.lex_state = 131, .external_lex_state = 2},
  [1163] = {.lex_state = 131, .external_lex_state = 2},
  [1164] = {.lex_state = 131, .external_lex_state = 2},
  [1165] = {.lex_state = 131, .external_lex_state = 2},
  [1166] = {.lex_state = 131, .external_lex_state = 2},
  [1167] = {.lex_state = 131, .external_lex_state = 2},
  [1168] = {.lex_state = 131, .external_lex_state = 2},
  [1169] = {.lex_state = 131, .external_lex_state = 2},
  [1170] = {.lex_state = 131, .external_lex_state = 2},
  [1171] = {.lex_state = 131, .external_lex_state = 2},
  [1172] = {.lex_state = 131, .external_lex_state = 2},
  [1173] = {.lex_state = 131, .external_lex_state = 2},
  [1174] = {.lex_state = 131, .external_lex_state = 2},
  [1175] = {.lex_state = 131, .external_lex_state = 2},
  [1176] = {.lex_state = 131, .external_lex_state = 2},
  [1177] = {.lex_state = 131, .external_lex_state = 2},
  [1178] = {.lex_state = 131, .external_lex_state = 2},
  [1179] = {.lex_state = 131, .external_lex_state = 2},
  [1180] = {.lex_state = 131, .external_lex_state = 2},
  [1181] = {.lex_state = 131, .external_lex_state = 2},
  [1182] = {.lex_state = 131, .external_lex_state = 2},
  [1183] = {.lex_state = 131, .external_lex_state = 2},
  [1184] = {.lex_state = 131, .external_lex_state = 2},
  [1185] = {.lex_state = 131, .external_lex_state = 2},
  [1186] = {.lex_state = 131, .external_lex_state = 2},
  [1187] = {.lex_state = 131, .external_lex_state = 2},
  [1188] = {.lex_state = 131, .external_lex_state = 2},
  [1189] = {.lex_state = 131, .external_lex_state = 2},
  [1190] = {.lex_state = 131, .external_lex_state = 2},
  [1191] = {.lex_state = 131, .external_lex_state = 2},
  [1192] = {.lex_state = 131, .external_lex_state = 2},
  [1193] = {.lex_state = 131, .external_lex_state = 2},
  [1194] = {.lex_state = 131, .external_lex_state = 2},
  [1195] = {.lex_state = 131, .external_lex_state = 2},
  [1196] = {.lex_state = 131, .external_lex_state = 2},
  [1197] = {.lex_state = 131, .external_lex_state = 2},
  [1198] = {.lex_state = 131, .external_lex_state = 2},
  [1199] = {.lex_state = 131, .external_lex_state = 2},
  [1200] = {.lex_state = 131, .external_lex_state = 2},
  [1201] = {.lex_state = 131, .external_lex_state = 2},
  [1202] = {.lex_state = 131, .external_lex_state = 2},
  [1203] = {.lex_state = 131, .external_lex_state = 2},
  [1204] = {.lex_state = 131, .external_lex_state = 2},
  [1205] = {.lex_state = 131, .external_lex_state = 2},
  [1206] = {.lex_state = 131, .external_lex_state = 2},
  [1207] = {.lex_state = 131, .external_lex_state = 2},
  [1208] = {.lex_state = 131, .external_lex_state = 2},
  [1209] = {.lex_state = 131, .external_lex_state = 2},
  [1210] = {.lex_state = 131, .external_lex_state = 2},
  [1211] = {.lex_state = 131, .external_lex_state = 2},
  [1212] = {.lex_state = 131, .external_lex_state = 2},
  [1213] = {.lex_state = 131, .external_lex_state = 2},
  [1214] = {.lex_state = 131, .external_lex_state = 2},
  [1215] = {.lex_state = 131, .external_lex_state = 2},
  [1216] = {.lex_state = 131, .external_lex_state = 2},
  [1217] = {.lex_state = 131, .external_lex_state = 2},
  [1218] = {.lex_state = 131, .external_lex_state = 2},
  [1219] = {.lex_state = 131, .external_lex_state = 2},
  [1220] = {.lex_state = 131, .external_lex_state = 2},
  [1221] = {.lex_state = 131, .external_lex_state = 2},
  [1222] = {.lex_state = 131, .external_lex_state = 2},
  [1223] = {.lex_state = 131, .external_lex_state = 2},
  [1224] = {.lex_state = 131, .external_lex_state = 2},
  [1225] = {.lex_state = 131, .external_lex_state = 2},
  [1226] = {.lex_state = 131, .external_lex_state = 2},
  [1227] = {.lex_state = 131, .external_lex_state = 2},
  [1228] = {.lex_state = 131, .external_lex_state = 2},
  [1229] = {.lex_state = 131, .external_lex_state = 2},
  [1230] = {.lex_state = 131, .external_lex_state = 2},
  [1231] = {.lex_state = 131, .external_lex_state = 2},
  [1232] = {.lex_state = 131, .external_lex_state = 2},
  [1233] = {.lex_state = 131, .external_lex_state = 2},
  [1234] = {.lex_state = 131, .external_lex_state = 2},
  [1235] = {.lex_state = 131, .external_lex_state = 2},
  [1236] = {.lex_state = 131, .external_lex_state = 2},
  [1237] = {.lex_state = 131, .external_lex_state = 2},
  [1238] = {.lex_state = 131, .external_lex_state = 2},
  [1239] = {.lex_state = 131, .external_lex_state = 2},
  [1240] = {.lex_state = 131, .external_lex_state = 2},
  [1241] = {.lex_state = 131, .external_lex_state = 2},
  [1242] = {.lex_state = 131, .external_lex_state = 2},
  [1243] = {.lex_state = 131, .external_lex_state = 2},
  [1244] = {.lex_state = 131, .external_lex_state = 2},
  [1245] = {.lex_state = 131, .external_lex_state = 2},
  [1246] = {.lex_state = 131, .external_lex_state = 2},
  [1247] = {.lex_state = 131, .external_lex_state = 2},
  [1248] = {.lex_state = 131, .external_lex_state = 2},
  [1249] = {.lex_state = 131, .external_lex_state = 2},
  [1250] = {.lex_state = 131, .external_lex_state = 2},
  [1251] = {.lex_state = 131, .external_lex_state = 2},
  [1252] = {.lex_state = 131, .external_lex_state = 2},
  [1253] = {.lex_state = 131, .external_lex_state = 2},
  [1254] = {.lex_state = 131, .external_lex_state = 2},
  [1255] = {.lex_state = 131, .external_lex_state = 2},
  [1256] = {.lex_state = 131, .external_lex_state = 2},
  [1257] = {.lex_state = 131, .external_lex_state = 2},
  [1258] = {.lex_state = 131, .external_lex_state = 2},
  [1259] = {.lex_state = 131, .external_lex_state = 2},
  [1260] = {.lex_state = 131, .external_lex_state = 2},
  [1261] = {.lex_state = 131, .external_lex_state = 2},
  [1262] = {.lex_state = 131, .external_lex_state = 2},
  [1263] = {.lex_state = 131, .external_lex_state = 2},
  [1264] = {.lex_state = 131, .external_lex_state = 2},
  [1265] = {.lex_state = 131, .external_lex_state = 2},
  [1266] = {.lex_state = 131, .external_lex_state = 2},
  [1267] = {.lex_state = 131, .external_lex_state = 2},
  [1268] = {.lex_state = 131, .external_lex_state = 2},
  [1269] = {.lex_state = 131, .external_lex_state = 2},
  [1270] = {.lex_state = 131, .external_lex_state = 2},
  [1271] = {.lex_state = 131, .external_lex_state = 2},
  [1272] = {.lex_state = 131, .external_lex_state = 2},
  [1273] = {.lex_state = 131, .external_lex_state = 2},
  [1274] = {.lex_state = 131, .external_lex_state = 2},
  [1275] = {.lex_state = 131, .external_lex_state = 2},
  [1276] = {.lex_state = 131, .external_lex_state = 2},
  [1277] = {.lex_state = 131, .external_lex_state = 2},
  [1278] = {.lex_state = 131, .external_lex_state = 2},
  [1279] = {.lex_state = 131, .external_lex_state = 2},
  [1280] = {.lex_state = 131, .external_lex_state = 2},
  [1281] = {.lex_state = 131, .external_lex_state = 2},
  [1282] = {.lex_state = 131, .external_lex_state = 2},
  [1283] = {.lex_state = 131, .external_lex_state = 2},
  [1284] = {.lex_state = 131, .external_lex_state = 2},
  [1285] = {.lex_state = 131, .external_lex_state = 2},
  [1286] = {.lex_state = 131, .external_lex_state = 2},
  [1287] = {.lex_state = 131, .external_lex_state = 2},
  [1288] = {.lex_state = 131, .external_lex_state = 2},
  [1289] = {.lex_state = 131, .external_lex_state = 2},
  [1290] = {.lex_state = 131, .external_lex_state = 2},
  [1291] = {.lex_state = 131, .external_lex_state = 2},
  [1292] = {.lex_state = 131, .external_lex_state = 2},
  [1293] = {.lex_state = 131, .external_lex_state = 2},
  [1294] = {.lex_state = 131, .external_lex_state = 2},
  [1295] = {.lex_state = 131, .external_lex_state = 2},
  [1296] = {.lex_state = 131, .external_lex_state = 2},
  [1297] = {.lex_state = 131, .external_lex_state = 2},
  [1298] = {.lex_state = 131, .external_lex_state = 2},
  [1299] = {.lex_state = 131, .external_lex_state = 2},
  [1300] = {.lex_state = 131, .external_lex_state = 2},
  [1301] = {.lex_state = 131, .external_lex_state = 2},
  [1302] = {.lex_state = 131, .external_lex_state = 2},
  [1303] = {.lex_state = 131, .external_lex_state = 2},
  [1304] = {.lex_state = 131, .external_lex_state = 2},
  [1305] = {.lex_state = 131, .external_lex_state = 2},
  [1306] = {.lex_state = 131, .external_lex_state = 2},
  [1307] = {.lex_state = 131, .external_lex_state = 2},
  [1308] = {.lex_state = 131, .external_lex_state = 2},
  [1309] = {.lex_state = 131, .external_lex_state = 2},
  [1310] = {.lex_state = 131, .external_lex_state = 2},
  [1311] = {.lex_state = 131, .external_lex_state = 2},
  [1312] = {.lex_state = 131, .external_lex_state = 2},
  [1313] = {.lex_state = 131, .external_lex_state = 2},
  [1314] = {.lex_state = 131, .external_lex_state = 2},
  [1315] = {.lex_state = 131, .external_lex_state = 2},
  [1316] = {.lex_state = 131, .external_lex_state = 2},
  [1317] = {.lex_state = 131, .external_lex_state = 2},
  [1318] = {.lex_state = 131, .external_lex_state = 2},
  [1319] = {.lex_state = 131, .external_lex_state = 2},
  [1320] = {.lex_state = 131, .external_lex_state = 2},
  [1321] = {.lex_state = 131, .external_lex_state = 2},
  [1322] = {.lex_state = 131, .external_lex_state = 2},
  [1323] = {.lex_state = 131, .external_lex_state = 2},
  [1324] = {.lex_state = 131, .external_lex_state = 2},
  [1325] = {.lex_state = 131, .external_lex_state = 2},
  [1326] = {.lex_state = 131, .external_lex_state = 2},
  [1327] = {.lex_state = 131, .external_lex_state = 2},
  [1328] = {.lex_state = 131, .external_lex_state = 2},
  [1329] = {.lex_state = 131, .external_lex_state = 2},
  [1330] = {.lex_state = 131, .external_lex_state = 2},
  [1331] = {.lex_state = 131, .external_lex_state = 2},
  [1332] = {.lex_state = 131, .external_lex_state = 2},
  [1333] = {.lex_state = 131, .external_lex_state = 2},
  [1334] = {.lex_state = 131, .external_lex_state = 2},
  [1335] = {.lex_state = 131, .external_lex_state = 2},
  [1336] = {.lex_state = 131, .external_lex_state = 2},
  [1337] = {.lex_state = 131, .external_lex_state = 2},
  [1338] = {.lex_state = 131, .external_lex_state = 2},
  [1339] = {.lex_state = 131, .external_lex_state = 2},
  [1340] = {.lex_state = 131, .external_lex_state = 2},
  [1341] = {.lex_state = 131, .external_lex_state = 2},
  [1342] = {.lex_state = 131, .external_lex_state = 2},
  [1343] = {.lex_state = 131, .external_lex_state = 2},
  [1344] = {.lex_state = 131, .external_lex_state = 2},
  [1345] = {.lex_state = 131, .external_lex_state = 2},
  [1346] = {.lex_state = 131, .external_lex_state = 2},
  [1347] = {.lex_state = 131, .external_lex_state = 2},
  [1348] = {.lex_state = 131, .external_lex_state = 2},
  [1349] = {.lex_state = 131, .external_lex_state = 2},
  [1350] = {.lex_state = 131, .external_lex_state = 2},
  [1351] = {.lex_state = 131, .external_lex_state = 2},
  [1352] = {.lex_state = 131, .external_lex_state = 2},
  [1353] = {.lex_state = 131, .external_lex_state = 2},
  [1354] = {.lex_state = 131, .external_lex_state = 2},
  [1355] = {.lex_state = 131, .external_lex_state = 2},
  [1356] = {.lex_state = 131, .external_lex_state = 2},
  [1357] = {.lex_state = 131, .external_lex_state = 2},
  [1358] = {.lex_state = 131, .external_lex_state = 2},
  [1359] = {.lex_state = 131, .external_lex_state = 2},
  [1360] = {.lex_state = 131, .external_lex_state = 2},
  [1361] = {.lex_state = 131, .external_lex_state = 2},
  [1362] = {.lex_state = 131, .external_lex_state = 2},
  [1363] = {.lex_state = 131, .external_lex_state = 2},
  [1364] = {.lex_state = 131, .external_lex_state = 2},
  [1365] = {.lex_state = 131, .external_lex_state = 2},
  [1366] = {.lex_state = 131, .external_lex_state = 2},
  [1367] = {.lex_state = 131, .external_lex_state = 2},
  [1368] = {.lex_state = 131, .external_lex_state = 2},
  [1369] = {.lex_state = 131, .external_lex_state = 2},
  [1370] = {.lex_state = 131, .external_lex_state = 2},
  [1371] = {.lex_state = 131, .external_lex_state = 2},
  [1372] = {.lex_state = 131, .external_lex_state = 2},
  [1373] = {.lex_state = 131, .external_lex_state = 2},
  [1374] = {.lex_state = 131, .external_lex_state = 2},
  [1375] = {.lex_state = 131, .external_lex_state = 2},
  [1376] = {.lex_state = 131, .external_lex_state = 2},
  [1377] = {.lex_state = 131, .external_lex_state = 2},
  [1378] = {.lex_state = 131, .external_lex_state = 2},
  [1379] = {.lex_state = 131, .external_lex_state = 2},
  [1380] = {.lex_state = 131, .external_lex_state = 2},
  [1381] = {.lex_state = 131, .external_lex_state = 2},
  [1382] = {.lex_state = 131, .external_lex_state = 2},
  [1383] = {.lex_state = 131, .external_lex_state = 2},
  [1384] = {.lex_state = 131, .external_lex_state = 2},
  [1385] = {.lex_state = 131, .external_lex_state = 2},
  [1386] = {.lex_state = 131, .external_lex_state = 2},
  [1387] = {.lex_state = 131, .external_lex_state = 2},
  [1388] = {.lex_state = 131, .external_lex_state = 2},
  [1389] = {.lex_state = 131, .external_lex_state = 2},
  [1390] = {.lex_state = 131, .external_lex_state = 2},
  [1391] = {.lex_state = 131, .external_lex_state = 2},
  [1392] = {.lex_state = 131, .external_lex_state = 2},
  [1393] = {.lex_state = 131, .external_lex_state = 2},
  [1394] = {.lex_state = 131, .external_lex_state = 2},
  [1395] = {.lex_state = 131, .external_lex_state = 2},
  [1396] = {.lex_state = 131, .external_lex_state = 2},
  [1397] = {.lex_state = 131, .external_lex_state = 2},
  [1398] = {.lex_state = 131, .external_lex_state = 2},
  [1399] = {.lex_state = 131, .external_lex_state = 2},
  [1400] = {.lex_state = 131, .external_lex_state = 2},
  [1401] = {.lex_state = 131, .external_lex_state = 2},
  [1402] = {.lex_state = 131, .external_lex_state = 2},
  [1403] = {.lex_state = 131, .external_lex_state = 2},
  [1404] = {.lex_state = 131, .external_lex_state = 2},
  [1405] = {.lex_state = 131, .external_lex_state = 2},
  [1406] = {.lex_state = 131, .external_lex_state = 2},
  [1407] = {.lex_state = 131, .external_lex_state = 2},
  [1408] = {.lex_state = 131, .external_lex_state = 2},
  [1409] = {.lex_state = 131, .external_lex_state = 2},
  [1410] = {.lex_state = 131, .external_lex_state = 2},
  [1411] = {.lex_state = 131, .external_lex_state = 2},
  [1412] = {.lex_state = 131, .external_lex_state = 2},
  [1413] = {.lex_state = 131, .external_lex_state = 2},
  [1414] = {.lex_state = 131, .external_lex_state = 2},
  [1415] = {.lex_state = 131, .external_lex_state = 2},
  [1416] = {.lex_state = 131, .external_lex_state = 2},
  [1417] = {.lex_state = 131, .external_lex_state = 2},
  [1418] = {.lex_state = 131, .external_lex_state = 2},
  [1419] = {.lex_state = 131, .external_lex_state = 2},
  [1420] = {.lex_state = 131, .external_lex_state = 2},
  [1421] = {.lex_state = 131, .external_lex_state = 2},
  [1422] = {.lex_state = 131, .external_lex_state = 2},
  [1423] = {.lex_state = 131, .external_lex_state = 2},
  [1424] = {.lex_state = 131, .external_lex_state = 2},
  [1425] = {.lex_state = 131, .external_lex_state = 2},
  [1426] = {.lex_state = 131, .external_lex_state = 2},
  [1427] = {.lex_state = 131, .external_lex_state = 2},
  [1428] = {.lex_state = 131, .external_lex_state = 2},
  [1429] = {.lex_state = 131, .external_lex_state = 2},
  [1430] = {.lex_state = 131, .external_lex_state = 2},
  [1431] = {.lex_state = 131, .external_lex_state = 2},
  [1432] = {.lex_state = 131, .external_lex_state = 2},
  [1433] = {.lex_state = 131, .external_lex_state = 2},
  [1434] = {.lex_state = 131, .external_lex_state = 2},
  [1435] = {.lex_state = 131, .external_lex_state = 2},
  [1436] = {.lex_state = 131, .external_lex_state = 2},
  [1437] = {.lex_state = 131, .external_lex_state = 2},
  [1438] = {.lex_state = 131, .external_lex_state = 2},
  [1439] = {.lex_state = 131, .external_lex_state = 2},
  [1440] = {.lex_state = 131, .external_lex_state = 2},
  [1441] = {.lex_state = 131, .external_lex_state = 2},
  [1442] = {.lex_state = 131, .external_lex_state = 2},
  [1443] = {.lex_state = 131, .external_lex_state = 2},
  [1444] = {.lex_state = 131, .external_lex_state = 2},
  [1445] = {.lex_state = 131, .external_lex_state = 2},
  [1446] = {.lex_state = 131, .external_lex_state = 2},
  [1447] = {.lex_state = 131, .external_lex_state = 2},
  [1448] = {.lex_state = 131, .external_lex_state = 2},
  [1449] = {.lex_state = 131, .external_lex_state = 2},
  [1450] = {.lex_state = 131, .external_lex_state = 2},
  [1451] = {.lex_state = 131, .external_lex_state = 2},
  [1452] = {.lex_state = 131, .external_lex_state = 2},
  [1453] = {.lex_state = 131, .external_lex_state = 2},
  [1454] = {.lex_state = 131, .external_lex_state = 2},
  [1455] = {.lex_state = 131, .external_lex_state = 2},
  [1456] = {.lex_state = 131, .external_lex_state = 2},
  [1457] = {.lex_state = 131, .external_lex_state = 2},
  [1458] = {.lex_state = 131, .external_lex_state = 2},
  [1459] = {.lex_state = 131, .external_lex_state = 2},
  [1460] = {.lex_state = 131, .external_lex_state = 2},
  [1461] = {.lex_state = 131, .external_lex_state = 2},
  [1462] = {.lex_state = 131, .external_lex_state = 2},
  [1463] = {.lex_state = 131, .external_lex_state = 2},
  [1464] = {.lex_state = 131, .external_lex_state = 2},
  [1465] = {.lex_state = 131, .external_lex_state = 2},
  [1466] = {.lex_state = 131, .external_lex_state = 2},
  [1467] = {.lex_state = 131, .external_lex_state = 2},
  [1468] = {.lex_state = 131, .external_lex_state = 2},
  [1469] = {.lex_state = 131, .external_lex_state = 2},
  [1470] = {.lex_state = 131, .external_lex_state = 2},
  [1471] = {.lex_state = 131, .external_lex_state = 2},
  [1472] = {.lex_state = 131, .external_lex_state = 2},
  [1473] = {.lex_state = 131, .external_lex_state = 2},
  [1474] = {.lex_state = 131, .external_lex_state = 2},
  [1475] = {.lex_state = 131, .external_lex_state = 2},
  [1476] = {.lex_state = 131, .external_lex_state = 2},
  [1477] = {.lex_state = 131, .external_lex_state = 2},
  [1478] = {.lex_state = 131, .external_lex_state = 2},
  [1479] = {.lex_state = 131, .external_lex_state = 2},
  [1480] = {.lex_state = 131, .external_lex_state = 2},
  [1481] = {.lex_state = 131, .external_lex_state = 2},
  [1482] = {.lex_state = 131, .external_lex_state = 2},
  [1483] = {.lex_state = 131, .external_lex_state = 2},
  [1484] = {.lex_state = 131, .external_lex_state = 2},
  [1485] = {.lex_state = 131, .external_lex_state = 2},
  [1486] = {.lex_state = 131, .external_lex_state = 2},
  [1487] = {.lex_state = 131, .external_lex_state = 2},
  [1488] = {.lex_state = 131, .external_lex_state = 2},
  [1489] = {.lex_state = 131, .external_lex_state = 2},
  [1490] = {.lex_state = 131, .external_lex_state = 2},
  [1491] = {.lex_state = 131, .external_lex_state = 2},
  [1492] = {.lex_state = 131, .external_lex_state = 2},
  [1493] = {.lex_state = 131, .external_lex_state = 2},
  [1494] = {.lex_state = 131, .external_lex_state = 2},
  [1495] = {.lex_state = 131, .external_lex_state = 2},
  [1496] = {.lex_state = 131, .external_lex_state = 2},
  [1497] = {.lex_state = 131, .external_lex_state = 2},
  [1498] = {.lex_state = 131, .external_lex_state = 2},
  [1499] = {.lex_state = 131, .external_lex_state = 2},
  [1500] = {.lex_state = 131, .external_lex_state = 2},
  [1501] = {.lex_state = 131, .external_lex_state = 2},
  [1502] = {.lex_state = 131, .external_lex_state = 2},
  [1503] = {.lex_state = 131, .external_lex_state = 2},
  [1504] = {.lex_state = 131, .external_lex_state = 2},
  [1505] = {.lex_state = 131, .external_lex_state = 2},
  [1506] = {.lex_state = 131, .external_lex_state = 2},
  [1507] = {.lex_state = 131, .external_lex_state = 2},
  [1508] = {.lex_state = 131, .external_lex_state = 2},
  [1509] = {.lex_state = 131, .external_lex_state = 2},
  [1510] = {.lex_state = 131, .external_lex_state = 2},
  [1511] = {.lex_state = 131, .external_lex_state = 2},
  [1512] = {.lex_state = 131, .external_lex_state = 2},
  [1513] = {.lex_state = 131, .external_lex_state = 2},
  [1514] = {.lex_state = 131, .external_lex_state = 2},
  [1515] = {.lex_state = 131, .external_lex_state = 2},
  [1516] = {.lex_state = 131, .external_lex_state = 2},
  [1517] = {.lex_state = 131, .external_lex_state = 2},
  [1518] = {.lex_state = 131, .external_lex_state = 2},
  [1519] = {.lex_state = 131, .external_lex_state = 2},
  [1520] = {.lex_state = 131, .external_lex_state = 2},
  [1521] = {.lex_state = 131, .external_lex_state = 2},
  [1522] = {.lex_state = 131, .external_lex_state = 2},
  [1523] = {.lex_state = 131, .external_lex_state = 2},
  [1524] = {.lex_state = 131, .external_lex_state = 2},
  [1525] = {.lex_state = 131, .external_lex_state = 2},
  [1526] = {.lex_state = 131, .external_lex_state = 2},
  [1527] = {.lex_state = 131, .external_lex_state = 2},
  [1528] = {.lex_state = 131, .external_lex_state = 2},
  [1529] = {.lex_state = 131, .external_lex_state = 2},
  [1530] = {.lex_state = 131, .external_lex_state = 2},
  [1531] = {.lex_state = 131, .external_lex_state = 2},
  [1532] = {.lex_state = 131, .external_lex_state = 2},
  [1533] = {.lex_state = 131, .external_lex_state = 2},
  [1534] = {.lex_state = 131, .external_lex_state = 2},
  [1535] = {.lex_state = 131, .external_lex_state = 2},
  [1536] = {.lex_state = 131, .external_lex_state = 2},
  [1537] = {.lex_state = 131, .external_lex_state = 2},
  [1538] = {.lex_state = 131, .external_lex_state = 2},
  [1539] = {.lex_state = 131, .external_lex_state = 2},
  [1540] = {.lex_state = 131, .external_lex_state = 2},
  [1541] = {.lex_state = 131, .external_lex_state = 2},
  [1542] = {.lex_state = 131, .external_lex_state = 2},
  [1543] = {.lex_state = 131, .external_lex_state = 2},
  [1544] = {.lex_state = 131, .external_lex_state = 2},
  [1545] = {.lex_state = 131, .external_lex_state = 2},
  [1546] = {.lex_state = 131, .external_lex_state = 2},
  [1547] = {.lex_state = 131, .external_lex_state = 2},
  [1548] = {.lex_state = 131, .external_lex_state = 2},
  [1549] = {.lex_state = 131, .external_lex_state = 2},
  [1550] = {.lex_state = 131, .external_lex_state = 2},
  [1551] = {.lex_state = 131, .external_lex_state = 2},
  [1552] = {.lex_state = 131, .external_lex_state = 2},
  [1553] = {.lex_state = 131, .external_lex_state = 2},
  [1554] = {.lex_state = 131, .external_lex_state = 2},
  [1555] = {.lex_state = 131, .external_lex_state = 2},
  [1556] = {.lex_state = 131, .external_lex_state = 2},
  [1557] = {.lex_state = 131, .external_lex_state = 2},
  [1558] = {.lex_state = 131, .external_lex_state = 2},
  [1559] = {.lex_state = 131, .external_lex_state = 2},
  [1560] = {.lex_state = 131, .external_lex_state = 2},
  [1561] = {.lex_state = 131, .external_lex_state = 2},
  [1562] = {.lex_state = 131, .external_lex_state = 2},
  [1563] = {.lex_state = 131, .external_lex_state = 2},
  [1564] = {.lex_state = 131, .external_lex_state = 2},
  [1565] = {.lex_state = 131, .external_lex_state = 2},
  [1566] = {.lex_state = 131, .external_lex_state = 2},
  [1567] = {.lex_state = 131, .external_lex_state = 2},
  [1568] = {.lex_state = 131, .external_lex_state = 2},
  [1569] = {.lex_state = 131, .external_lex_state = 2},
  [1570] = {.lex_state = 131, .external_lex_state = 2},
  [1571] = {.lex_state = 131, .external_lex_state = 2},
  [1572] = {.lex_state = 131, .external_lex_state = 2},
  [1573] = {.lex_state = 131, .external_lex_state = 2},
  [1574] = {.lex_state = 131, .external_lex_state = 2},
  [1575] = {.lex_state = 131, .external_lex_state = 2},
  [1576] = {.lex_state = 131, .external_lex_state = 2},
  [1577] = {.lex_state = 131, .external_lex_state = 2},
  [1578] = {.lex_state = 131, .external_lex_state = 2},
  [1579] = {.lex_state = 131, .external_lex_state = 2},
  [1580] = {.lex_state = 131, .external_lex_state = 2},
  [1581] = {.lex_state = 131, .external_lex_state = 2},
  [1582] = {.lex_state = 131, .external_lex_state = 2},
  [1583] = {.lex_state = 131, .external_lex_state = 2},
  [1584] = {.lex_state = 131, .external_lex_state = 2},
  [1585] = {.lex_state = 131, .external_lex_state = 2},
  [1586] = {.lex_state = 131, .external_lex_state = 2},
  [1587] = {.lex_state = 131, .external_lex_state = 2},
  [1588] = {.lex_state = 131, .external_lex_state = 2},
  [1589] = {.lex_state = 131, .external_lex_state = 2},
  [1590] = {.lex_state = 131, .external_lex_state = 2},
  [1591] = {.lex_state = 131, .external_lex_state = 2},
  [1592] = {.lex_state = 131, .external_lex_state = 2},
  [1593] = {.lex_state = 131, .external_lex_state = 2},
  [1594] = {.lex_state = 131, .external_lex_state = 2},
  [1595] = {.lex_state = 131, .external_lex_state = 2},
  [1596] = {.lex_state = 131, .external_lex_state = 2},
  [1597] = {.lex_state = 131, .external_lex_state = 2},
  [1598] = {.lex_state = 131, .external_lex_state = 2},
  [1599] = {.lex_state = 131, .external_lex_state = 2},
  [1600] = {.lex_state = 131, .external_lex_state = 2},
  [1601] = {.lex_state = 131, .external_lex_state = 2},
  [1602] = {.lex_state = 131, .external_lex_state = 2},
  [1603] = {.lex_state = 131, .external_lex_state = 2},
  [1604] = {.lex_state = 131, .external_lex_state = 2},
  [1605] = {.lex_state = 131, .external_lex_state = 2},
  [1606] = {.lex_state = 131, .external_lex_state = 2},
  [1607] = {.lex_state = 131, .external_lex_state = 2},
  [1608] = {.lex_state = 131, .external_lex_state = 2},
  [1609] = {.lex_state = 131, .external_lex_state = 2},
  [1610] = {.lex_state = 131, .external_lex_state = 2},
  [1611] = {.lex_state = 131, .external_lex_state = 2},
  [1612] = {.lex_state = 131, .external_lex_state = 2},
  [1613] = {.lex_state = 131, .external_lex_state = 2},
  [1614] = {.lex_state = 131, .external_lex_state = 2},
  [1615] = {.lex_state = 131, .external_lex_state = 2},
  [1616] = {.lex_state = 131, .external_lex_state = 2},
  [1617] = {.lex_state = 131, .external_lex_state = 2},
  [1618] = {.lex_state = 131, .external_lex_state = 2},
  [1619] = {.lex_state = 131, .external_lex_state = 2},
  [1620] = {.lex_state = 131, .external_lex_state = 2},
  [1621] = {.lex_state = 131, .external_lex_state = 2},
  [1622] = {.lex_state = 131, .external_lex_state = 2},
  [1623] = {.lex_state = 131, .external_lex_state = 2},
  [1624] = {.lex_state = 131, .external_lex_state = 2},
  [1625] = {.lex_state = 131, .external_lex_state = 2},
  [1626] = {.lex_state = 131, .external_lex_state = 2},
  [1627] = {.lex_state = 131, .external_lex_state = 2},
  [1628] = {.lex_state = 131, .external_lex_state = 2},
  [1629] = {.lex_state = 131, .external_lex_state = 2},
  [1630] = {.lex_state = 131, .external_lex_state = 2},
  [1631] = {.lex_state = 131, .external_lex_state = 2},
  [1632] = {.lex_state = 131, .external_lex_state = 2},
  [1633] = {.lex_state = 131, .external_lex_state = 2},
  [1634] = {.lex_state = 131, .external_lex_state = 2},
  [1635] = {.lex_state = 131, .external_lex_state = 2},
  [1636] = {.lex_state = 131, .external_lex_state = 2},
  [1637] = {.lex_state = 131, .external_lex_state = 2},
  [1638] = {.lex_state = 131, .external_lex_state = 2},
  [1639] = {.lex_state = 131, .external_lex_state = 2},
  [1640] = {.lex_state = 131, .external_lex_state = 2},
  [1641] = {.lex_state = 131, .external_lex_state = 2},
  [1642] = {.lex_state = 131, .external_lex_state = 2},
  [1643] = {.lex_state = 131, .external_lex_state = 2},
  [1644] = {.lex_state = 131, .external_lex_state = 2},
  [1645] = {.lex_state = 131, .external_lex_state = 2},
  [1646] = {.lex_state = 131, .external_lex_state = 2},
  [1647] = {.lex_state = 131, .external_lex_state = 2},
  [1648] = {.lex_state = 131, .external_lex_state = 2},
  [1649] = {.lex_state = 131, .external_lex_state = 2},
  [1650] = {.lex_state = 131, .external_lex_state = 2},
  [1651] = {.lex_state = 131, .external_lex_state = 2},
  [1652] = {.lex_state = 131, .external_lex_state = 2},
  [1653] = {.lex_state = 131, .external_lex_state = 2},
  [1654] = {.lex_state = 131, .external_lex_state = 2},
  [1655] = {.lex_state = 131, .external_lex_state = 2},
  [1656] = {.lex_state = 131, .external_lex_state = 2},
  [1657] = {.lex_state = 131, .external_lex_state = 2},
  [1658] = {.lex_state = 131, .external_lex_state = 2},
  [1659] = {.lex_state = 131, .external_lex_state = 2},
  [1660] = {.lex_state = 131, .external_lex_state = 2},
  [1661] = {.lex_state = 131, .external_lex_state = 2},
  [1662] = {.lex_state = 131, .external_lex_state = 2},
  [1663] = {.lex_state = 131, .external_lex_state = 2},
  [1664] = {.lex_state = 131, .external_lex_state = 2},
  [1665] = {.lex_state = 131, .external_lex_state = 2},
  [1666] = {.lex_state = 131, .external_lex_state = 2},
  [1667] = {.lex_state = 131, .external_lex_state = 2},
  [1668] = {.lex_state = 131, .external_lex_state = 2},
  [1669] = {.lex_state = 131, .external_lex_state = 2},
  [1670] = {.lex_state = 131, .external_lex_state = 2},
  [1671] = {.lex_state = 131, .external_lex_state = 2},
  [1672] = {.lex_state = 131, .external_lex_state = 2},
  [1673] = {.lex_state = 131, .external_lex_state = 2},
  [1674] = {.lex_state = 131, .external_lex_state = 2},
  [1675] = {.lex_state = 131, .external_lex_state = 2},
  [1676] = {.lex_state = 131, .external_lex_state = 2},
  [1677] = {.lex_state = 131, .external_lex_state = 2},
  [1678] = {.lex_state = 131, .external_lex_state = 2},
  [1679] = {.lex_state = 131, .external_lex_state = 2},
  [1680] = {.lex_state = 131, .external_lex_state = 2},
  [1681] = {.lex_state = 131, .external_lex_state = 2},
  [1682] = {.lex_state = 131, .external_lex_state = 2},
  [1683] = {.lex_state = 131, .external_lex_state = 2},
  [1684] = {.lex_state = 131, .external_lex_state = 2},
  [1685] = {.lex_state = 131, .external_lex_state = 2},
  [1686] = {.lex_state = 131, .external_lex_state = 2},
  [1687] = {.lex_state = 131, .external_lex_state = 2},
  [1688] = {.lex_state = 131, .external_lex_state = 2},
  [1689] = {.lex_state = 131, .external_lex_state = 2},
  [1690] = {.lex_state = 131, .external_lex_state = 2},
  [1691] = {.lex_state = 131, .external_lex_state = 2},
  [1692] = {.lex_state = 131, .external_lex_state = 2},
  [1693] = {.lex_state = 131, .external_lex_state = 2},
  [1694] = {.lex_state = 131, .external_lex_state = 2},
  [1695] = {.lex_state = 131, .external_lex_state = 2},
  [1696] = {.lex_state = 131, .external_lex_state = 2},
  [1697] = {.lex_state = 131, .external_lex_state = 2},
  [1698] = {.lex_state = 131, .external_lex_state = 2},
  [1699] = {.lex_state = 131, .external_lex_state = 2},
  [1700] = {.lex_state = 131, .external_lex_state = 2},
  [1701] = {.lex_state = 131, .external_lex_state = 2},
  [1702] = {.lex_state = 131, .external_lex_state = 2},
  [1703] = {.lex_state = 131, .external_lex_state = 2},
  [1704] = {.lex_state = 131, .external_lex_state = 2},
  [1705] = {.lex_state = 131, .external_lex_state = 2},
  [1706] = {.lex_state = 131, .external_lex_state = 2},
  [1707] = {.lex_state = 131, .external_lex_state = 2},
  [1708] = {.lex_state = 131, .external_lex_state = 2},
  [1709] = {.lex_state = 131, .external_lex_state = 2},
  [1710] = {.lex_state = 131, .external_lex_state = 2},
  [1711] = {.lex_state = 131, .external_lex_state = 2},
  [1712] = {.lex_state = 131, .external_lex_state = 2},
  [1713] = {.lex_state = 131, .external_lex_state = 2},
  [1714] = {.lex_state = 131, .external_lex_state = 2},
  [1715] = {.lex_state = 131, .external_lex_state = 2},
  [1716] = {.lex_state = 131, .external_lex_state = 2},
  [1717] = {.lex_state = 131, .external_lex_state = 2},
  [1718] = {.lex_state = 131, .external_lex_state = 2},
  [1719] = {.lex_state = 131, .external_lex_state = 2},
  [1720] = {.lex_state = 131, .external_lex_state = 2},
  [1721] = {.lex_state = 131, .external_lex_state = 2},
  [1722] = {.lex_state = 131, .external_lex_state = 2},
  [1723] = {.lex_state = 131, .external_lex_state = 2},
  [1724] = {.lex_state = 131, .external_lex_state = 2},
  [1725] = {.lex_state = 131, .external_lex_state = 2},
  [1726] = {.lex_state = 131, .external_lex_state = 2},
  [1727] = {.lex_state = 131, .external_lex_state = 2},
  [1728] = {.lex_state = 131, .external_lex_state = 2},
  [1729] = {.lex_state = 131, .external_lex_state = 2},
  [1730] = {.lex_state = 131, .external_lex_state = 2},
  [1731] = {.lex_state = 131, .external_lex_state = 2},
  [1732] = {.lex_state = 131, .external_lex_state = 2},
  [1733] = {.lex_state = 131, .external_lex_state = 2},
  [1734] = {.lex_state = 131, .external_lex_state = 2},
  [1735] = {.lex_state = 131, .external_lex_state = 2},
  [1736] = {.lex_state = 131, .external_lex_state = 2},
  [1737] = {.lex_state = 131, .external_lex_state = 2},
  [1738] = {.lex_state = 131, .external_lex_state = 2},
  [1739] = {.lex_state = 131, .external_lex_state = 2},
  [1740] = {.lex_state = 131, .external_lex_state = 2},
  [1741] = {.lex_state = 131, .external_lex_state = 2},
  [1742] = {.lex_state = 131, .external_lex_state = 2},
  [1743] = {.lex_state = 131, .external_lex_state = 2},
  [1744] = {.lex_state = 131, .external_lex_state = 2},
  [1745] = {.lex_state = 131, .external_lex_state = 2},
  [1746] = {.lex_state = 131, .external_lex_state = 2},
  [1747] = {.lex_state = 131, .external_lex_state = 2},
  [1748] = {.lex_state = 131, .external_lex_state = 2},
  [1749] = {.lex_state = 131, .external_lex_state = 2},
  [1750] = {.lex_state = 131, .external_lex_state = 2},
  [1751] = {.lex_state = 131, .external_lex_state = 2},
  [1752] = {.lex_state = 131, .external_lex_state = 2},
  [1753] = {.lex_state = 131, .external_lex_state = 2},
  [1754] = {.lex_state = 131, .external_lex_state = 2},
  [1755] = {.lex_state = 131, .external_lex_state = 2},
  [1756] = {.lex_state = 131, .external_lex_state = 2},
  [1757] = {.lex_state = 131, .external_lex_state = 2},
  [1758] = {.lex_state = 131, .external_lex_state = 2},
  [1759] = {.lex_state = 131, .external_lex_state = 2},
  [1760] = {.lex_state = 131, .external_lex_state = 2},
  [1761] = {.lex_state = 131, .external_lex_state = 2},
  [1762] = {.lex_state = 131, .external_lex_state = 2},
  [1763] = {.lex_state = 131, .external_lex_state = 2},
  [1764] = {.lex_state = 131, .external_lex_state = 2},
  [1765] = {.lex_state = 131, .external_lex_state = 2},
  [1766] = {.lex_state = 131, .external_lex_state = 2},
  [1767] = {.lex_state = 131, .external_lex_state = 2},
  [1768] = {.lex_state = 131, .external_lex_state = 2},
  [1769] = {.lex_state = 131, .external_lex_state = 2},
  [1770] = {.lex_state = 131, .external_lex_state = 2},
  [1771] = {.lex_state = 131, .external_lex_state = 2},
  [1772] = {.lex_state = 131, .external_lex_state = 2},
  [1773] = {.lex_state = 131, .external_lex_state = 2},
  [1774] = {.lex_state = 131, .external_lex_state = 2},
  [1775] = {.lex_state = 131, .external_lex_state = 2},
  [1776] = {.lex_state = 131, .external_lex_state = 2},
  [1777] = {.lex_state = 131, .external_lex_state = 2},
  [1778] = {.lex_state = 131, .external_lex_state = 2},
  [1779] = {.lex_state = 131, .external_lex_state = 2},
  [1780] = {.lex_state = 131, .external_lex_state = 2},
  [1781] = {.lex_state = 131, .external_lex_state = 2},
  [1782] = {.lex_state = 131, .external_lex_state = 2},
  [1783] = {.lex_state = 131, .external_lex_state = 2},
  [1784] = {.lex_state = 131, .external_lex_state = 2},
  [1785] = {.lex_state = 131, .external_lex_state = 2},
  [1786] = {.lex_state = 131, .external_lex_state = 2},
  [1787] = {.lex_state = 131, .external_lex_state = 2},
  [1788] = {.lex_state = 131, .external_lex_state = 2},
  [1789] = {.lex_state = 131, .external_lex_state = 2},
  [1790] = {.lex_state = 131, .external_lex_state = 2},
  [1791] = {.lex_state = 131, .external_lex_state = 2},
  [1792] = {.lex_state = 131, .external_lex_state = 2},
  [1793] = {.lex_state = 131, .external_lex_state = 2},
  [1794] = {.lex_state = 131, .external_lex_state = 2},
  [1795] = {.lex_state = 131, .external_lex_state = 2},
  [1796] = {.lex_state = 131, .external_lex_state = 2},
  [1797] = {.lex_state = 131, .external_lex_state = 2},
  [1798] = {.lex_state = 131, .external_lex_state = 2},
  [1799] = {.lex_state = 131, .external_lex_state = 2},
  [1800] = {.lex_state = 131, .external_lex_state = 2},
  [1801] = {.lex_state = 131, .external_lex_state = 2},
  [1802] = {.lex_state = 131, .external_lex_state = 2},
  [1803] = {.lex_state = 131, .external_lex_state = 2},
  [1804] = {.lex_state = 131, .external_lex_state = 2},
  [1805] = {.lex_state = 131, .external_lex_state = 2},
  [1806] = {.lex_state = 131, .external_lex_state = 2},
  [1807] = {.lex_state = 131, .external_lex_state = 2},
  [1808] = {.lex_state = 131, .external_lex_state = 2},
  [1809] = {.lex_state = 131, .external_lex_state = 2},
  [1810] = {.lex_state = 131, .external_lex_state = 2},
  [1811] = {.lex_state = 131, .external_lex_state = 2},
  [1812] = {.lex_state = 131, .external_lex_state = 2},
  [1813] = {.lex_state = 131, .external_lex_state = 2},
  [1814] = {.lex_state = 131, .external_lex_state = 2},
  [1815] = {.lex_state = 131, .external_lex_state = 2},
  [1816] = {.lex_state = 131, .external_lex_state = 2},
  [1817] = {.lex_state = 131, .external_lex_state = 2},
  [1818] = {.lex_state = 131, .external_lex_state = 2},
  [1819] = {.lex_state = 131, .external_lex_state = 2},
  [1820] = {.lex_state = 131, .external_lex_state = 2},
  [1821] = {.lex_state = 131, .external_lex_state = 2},
  [1822] = {.lex_state = 131, .external_lex_state = 2},
  [1823] = {.lex_state = 131, .external_lex_state = 2},
  [1824] = {.lex_state = 131, .external_lex_state = 2},
  [1825] = {.lex_state = 131, .external_lex_state = 2},
  [1826] = {.lex_state = 131, .external_lex_state = 2},
  [1827] = {.lex_state = 131, .external_lex_state = 2},
  [1828] = {.lex_state = 131, .external_lex_state = 2},
  [1829] = {.lex_state = 131, .external_lex_state = 2},
  [1830] = {.lex_state = 131, .external_lex_state = 2},
  [1831] = {.lex_state = 131, .external_lex_state = 2},
  [1832] = {.lex_state = 131, .external_lex_state = 2},
  [1833] = {.lex_state = 131, .external_lex_state = 2},
  [1834] = {.lex_state = 131, .external_lex_state = 2},
  [1835] = {.lex_state = 131, .external_lex_state = 2},
  [1836] = {.lex_state = 131, .external_lex_state = 2},
  [1837] = {.lex_state = 131, .external_lex_state = 2},
  [1838] = {.lex_state = 131, .external_lex_state = 2},
  [1839] = {.lex_state = 131, .external_lex_state = 2},
  [1840] = {.lex_state = 131, .external_lex_state = 2},
  [1841] = {.lex_state = 131, .external_lex_state = 2},
  [1842] = {.lex_state = 131, .external_lex_state = 2},
  [1843] = {.lex_state = 131, .external_lex_state = 2},
  [1844] = {.lex_state = 131, .external_lex_state = 2},
  [1845] = {.lex_state = 131, .external_lex_state = 2},
  [1846] = {.lex_state = 131, .external_lex_state = 2},
  [1847] = {.lex_state = 131, .external_lex_state = 2},
  [1848] = {.lex_state = 131, .external_lex_state = 2},
  [1849] = {.lex_state = 131, .external_lex_state = 2},
  [1850] = {.lex_state = 131, .external_lex_state = 2},
  [1851] = {.lex_state = 131, .external_lex_state = 2},
  [1852] = {.lex_state = 131, .external_lex_state = 2},
  [1853] = {.lex_state = 131, .external_lex_state = 2},
  [1854] = {.lex_state = 131, .external_lex_state = 2},
  [1855] = {.lex_state = 131, .external_lex_state = 2},
  [1856] = {.lex_state = 131, .external_lex_state = 2},
  [1857] = {.lex_state = 131, .external_lex_state = 2},
  [1858] = {.lex_state = 131, .external_lex_state = 2},
  [1859] = {.lex_state = 131, .external_lex_state = 2},
  [1860] = {.lex_state = 131, .external_lex_state = 2},
  [1861] = {.lex_state = 131, .external_lex_state = 2},
  [1862] = {.lex_state = 131, .external_lex_state = 2},
  [1863] = {.lex_state = 131, .external_lex_state = 2},
  [1864] = {.lex_state = 131, .external_lex_state = 2},
  [1865] = {.lex_state = 131, .external_lex_state = 2},
  [1866] = {.lex_state = 131, .external_lex_state = 2},
  [1867] = {.lex_state = 131, .external_lex_state = 2},
  [1868] = {.lex_state = 131, .external_lex_state = 2},
  [1869] = {.lex_state = 131, .external_lex_state = 2},
  [1870] = {.lex_state = 131, .external_lex_state = 2},
  [1871] = {.lex_state = 131, .external_lex_state = 2},
  [1872] = {.lex_state = 131, .external_lex_state = 2},
  [1873] = {.lex_state = 131, .external_lex_state = 2},
  [1874] = {.lex_state = 131, .external_lex_state = 2},
  [1875] = {.lex_state = 131, .external_lex_state = 2},
  [1876] = {.lex_state = 131, .external_lex_state = 2},
  [1877] = {.lex_state = 131, .external_lex_state = 2},
  [1878] = {.lex_state = 131, .external_lex_state = 2},
  [1879] = {.lex_state = 131, .external_lex_state = 2},
  [1880] = {.lex_state = 131, .external_lex_state = 2},
  [1881] = {.lex_state = 131, .external_lex_state = 2},
  [1882] = {.lex_state = 131, .external_lex_state = 2},
  [1883] = {.lex_state = 131, .external_lex_state = 2},
  [1884] = {.lex_state = 131, .external_lex_state = 2},
  [1885] = {.lex_state = 131, .external_lex_state = 2},
  [1886] = {.lex_state = 131, .external_lex_state = 2},
  [1887] = {.lex_state = 131, .external_lex_state = 2},
  [1888] = {.lex_state = 131, .external_lex_state = 2},
  [1889] = {.lex_state = 131, .external_lex_state = 2},
  [1890] = {.lex_state = 131, .external_lex_state = 2},
  [1891] = {.lex_state = 131, .external_lex_state = 2},
  [1892] = {.lex_state = 131, .external_lex_state = 2},
  [1893] = {.lex_state = 131, .external_lex_state = 2},
  [1894] = {.lex_state = 131, .external_lex_state = 2},
  [1895] = {.lex_state = 131, .external_lex_state = 2},
  [1896] = {.lex_state = 131, .external_lex_state = 2},
  [1897] = {.lex_state = 131, .external_lex_state = 2},
  [1898] = {.lex_state = 131, .external_lex_state = 2},
  [1899] = {.lex_state = 131, .external_lex_state = 2},
  [1900] = {.lex_state = 131, .external_lex_state = 2},
  [1901] = {.lex_state = 131, .external_lex_state = 2},
  [1902] = {.lex_state = 131, .external_lex_state = 2},
  [1903] = {.lex_state = 131, .external_lex_state = 2},
  [1904] = {.lex_state = 131, .external_lex_state = 2},
  [1905] = {.lex_state = 131, .external_lex_state = 2},
  [1906] = {.lex_state = 131, .external_lex_state = 2},
  [1907] = {.lex_state = 131, .external_lex_state = 2},
  [1908] = {.lex_state = 131, .external_lex_state = 2},
  [1909] = {.lex_state = 131, .external_lex_state = 2},
  [1910] = {.lex_state = 131, .external_lex_state = 2},
  [1911] = {.lex_state = 131, .external_lex_state = 2},
  [1912] = {.lex_state = 131, .external_lex_state = 2},
  [1913] = {.lex_state = 131, .external_lex_state = 2},
  [1914] = {.lex_state = 131, .external_lex_state = 2},
  [1915] = {.lex_state = 131, .external_lex_state = 2},
  [1916] = {.lex_state = 131, .external_lex_state = 2},
  [1917] = {.lex_state = 131, .external_lex_state = 2},
  [1918] = {.lex_state = 131, .external_lex_state = 2},
  [1919] = {.lex_state = 131, .external_lex_state = 2},
  [1920] = {.lex_state = 131, .external_lex_state = 2},
  [1921] = {.lex_state = 131, .external_lex_state = 2},
  [1922] = {.lex_state = 131, .external_lex_state = 2},
  [1923] = {.lex_state = 131, .external_lex_state = 2},
  [1924] = {.lex_state = 131, .external_lex_state = 2},
  [1925] = {.lex_state = 131, .external_lex_state = 2},
  [1926] = {.lex_state = 131, .external_lex_state = 2},
  [1927] = {.lex_state = 131, .external_lex_state = 2},
  [1928] = {.lex_state = 131, .external_lex_state = 2},
  [1929] = {.lex_state = 131, .external_lex_state = 2},
  [1930] = {.lex_state = 131, .external_lex_state = 2},
  [1931] = {.lex_state = 131, .external_lex_state = 2},
  [1932] = {.lex_state = 131, .external_lex_state = 2},
  [1933] = {.lex_state = 131, .external_lex_state = 2},
  [1934] = {.lex_state = 131, .external_lex_state = 2},
  [1935] = {.lex_state = 131, .external_lex_state = 2},
  [1936] = {.lex_state = 131, .external_lex_state = 2},
  [1937] = {.lex_state = 131, .external_lex_state = 2},
  [1938] = {.lex_state = 131, .external_lex_state = 2},
  [1939] = {.lex_state = 131, .external_lex_state = 2},
  [1940] = {.lex_state = 131, .external_lex_state = 2},
  [1941] = {.lex_state = 131, .external_lex_state = 2},
  [1942] = {.lex_state = 131, .external_lex_state = 2},
  [1943] = {.lex_state = 131, .external_lex_state = 2},
  [1944] = {.lex_state = 131, .external_lex_state = 2},
  [1945] = {.lex_state = 131, .external_lex_state = 2},
  [1946] = {.lex_state = 131, .external_lex_state = 2},
  [1947] = {.lex_state = 131, .external_lex_state = 2},
  [1948] = {.lex_state = 131, .external_lex_state = 2},
  [1949] = {.lex_state = 131, .external_lex_state = 2},
  [1950] = {.lex_state = 131, .external_lex_state = 2},
  [1951] = {.lex_state = 131, .external_lex_state = 2},
  [1952] = {.lex_state = 131, .external_lex_state = 2},
  [1953] = {.lex_state = 131, .external_lex_state = 2},
  [1954] = {.lex_state = 131, .external_lex_state = 2},
  [1955] = {.lex_state = 131, .external_lex_state = 2},
  [1956] = {.lex_state = 131, .external_lex_state = 2},
  [1957] = {.lex_state = 131, .external_lex_state = 2},
  [1958] = {.lex_state = 131, .external_lex_state = 2},
  [1959] = {.lex_state = 131, .external_lex_state = 2},
  [1960] = {.lex_state = 131, .external_lex_state = 2},
  [1961] = {.lex_state = 131, .external_lex_state = 2},
  [1962] = {.lex_state = 131, .external_lex_state = 2},
  [1963] = {.lex_state = 131, .external_lex_state = 2},
  [1964] = {.lex_state = 131, .external_lex_state = 2},
  [1965] = {.lex_state = 131, .external_lex_state = 2},
  [1966] = {.lex_state = 131, .external_lex_state = 2},
  [1967] = {.lex_state = 131, .external_lex_state = 2},
  [1968] = {.lex_state = 131, .external_lex_state = 2},
  [1969] = {.lex_state = 131, .external_lex_state = 2},
  [1970] = {.lex_state = 131, .external_lex_state = 2},
  [1971] = {.lex_state = 131, .external_lex_state = 2},
  [1972] = {.lex_state = 131, .external_lex_state = 2},
  [1973] = {.lex_state = 131, .external_lex_state = 2},
  [1974] = {.lex_state = 131, .external_lex_state = 2},
  [1975] = {.lex_state = 131, .external_lex_state = 2},
  [1976] = {.lex_state = 131, .external_lex_state = 2},
  [1977] = {.lex_state = 131, .external_lex_state = 2},
  [1978] = {.lex_state = 131, .external_lex_state = 2},
  [1979] = {.lex_state = 131, .external_lex_state = 2},
  [1980] = {.lex_state = 131, .external_lex_state = 2},
  [1981] = {.lex_state = 131, .external_lex_state = 2},
  [1982] = {.lex_state = 131, .external_lex_state = 2},
  [1983] = {.lex_state = 131, .external_lex_state = 2},
  [1984] = {.lex_state = 131, .external_lex_state = 2},
  [1985] = {.lex_state = 131, .external_lex_state = 2},
  [1986] = {.lex_state = 131, .external_lex_state = 2},
  [1987] = {.lex_state = 131, .external_lex_state = 2},
  [1988] = {.lex_state = 131, .external_lex_state = 2},
  [1989] = {.lex_state = 131, .external_lex_state = 2},
  [1990] = {.lex_state = 131, .external_lex_state = 2},
  [1991] = {.lex_state = 131, .external_lex_state = 2},
  [1992] = {.lex_state = 131, .external_lex_state = 2},
  [1993] = {.lex_state = 131, .external_lex_state = 2},
  [1994] = {.lex_state = 131, .external_lex_state = 2},
  [1995] = {.lex_state = 131, .external_lex_state = 2},
  [1996] = {.lex_state = 131, .external_lex_state = 2},
  [1997] = {.lex_state = 131, .external_lex_state = 2},
  [1998] = {.lex_state = 131, .external_lex_state = 2},
  [1999] = {.lex_state = 131, .external_lex_state = 2},
  [2000] = {.lex_state = 131, .external_lex_state = 2},
  [2001] = {.lex_state = 131, .external_lex_state = 2},
  [2002] = {.lex_state = 131, .external_lex_state = 2},
  [2003] = {.lex_state = 131, .external_lex_state = 2},
  [2004] = {.lex_state = 131, .external_lex_state = 2},
  [2005] = {.lex_state = 131, .external_lex_state = 2},
  [2006] = {.lex_state = 131, .external_lex_state = 2},
  [2007] = {.lex_state = 131, .external_lex_state = 2},
  [2008] = {.lex_state = 131, .external_lex_state = 2},
  [2009] = {.lex_state = 131, .external_lex_state = 2},
  [2010] = {.lex_state = 131, .external_lex_state = 2},
  [2011] = {.lex_state = 131, .external_lex_state = 2},
  [2012] = {.lex_state = 131, .external_lex_state = 2},
  [2013] = {.lex_state = 131, .external_lex_state = 2},
  [2014] = {.lex_state = 131, .external_lex_state = 2},
  [2015] = {.lex_state = 131, .external_lex_state = 2},
  [2016] = {.lex_state = 131, .external_lex_state = 2},
  [2017] = {.lex_state = 131, .external_lex_state = 2},
  [2018] = {.lex_state = 131, .external_lex_state = 2},
  [2019] = {.lex_state = 131, .external_lex_state = 2},
  [2020] = {.lex_state = 131, .external_lex_state = 2},
  [2021] = {.lex_state = 131, .external_lex_state = 2},
  [2022] = {.lex_state = 131, .external_lex_state = 2},
  [2023] = {.lex_state = 131, .external_lex_state = 2},
  [2024] = {.lex_state = 131, .external_lex_state = 2},
  [2025] = {.lex_state = 131, .external_lex_state = 2},
  [2026] = {.lex_state = 131, .external_lex_state = 2},
  [2027] = {.lex_state = 131, .external_lex_state = 2},
  [2028] = {.lex_state = 131, .external_lex_state = 2},
  [2029] = {.lex_state = 131, .external_lex_state = 2},
  [2030] = {.lex_state = 131, .external_lex_state = 2},
  [2031] = {.lex_state = 131, .external_lex_state = 2},
  [2032] = {.lex_state = 131, .external_lex_state = 2},
  [2033] = {.lex_state = 131, .external_lex_state = 2},
  [2034] = {.lex_state = 131, .external_lex_state = 2},
  [2035] = {.lex_state = 131, .external_lex_state = 2},
  [2036] = {.lex_state = 131, .external_lex_state = 2},
  [2037] = {.lex_state = 131, .external_lex_state = 2},
  [2038] = {.lex_state = 131, .external_lex_state = 2},
  [2039] = {.lex_state = 131, .external_lex_state = 2},
  [2040] = {.lex_state = 131, .external_lex_state = 2},
  [2041] = {.lex_state = 131, .external_lex_state = 2},
  [2042] = {.lex_state = 131, .external_lex_state = 2},
  [2043] = {.lex_state = 131, .external_lex_state = 2},
  [2044] = {.lex_state = 131, .external_lex_state = 2},
  [2045] = {.lex_state = 131, .external_lex_state = 2},
  [2046] = {.lex_state = 131, .external_lex_state = 2},
  [2047] = {.lex_state = 131, .external_lex_state = 2},
  [2048] = {.lex_state = 131, .external_lex_state = 2},
  [2049] = {.lex_state = 131, .external_lex_state = 2},
  [2050] = {.lex_state = 131, .external_lex_state = 2},
  [2051] = {.lex_state = 131, .external_lex_state = 2},
  [2052] = {.lex_state = 131, .external_lex_state = 2},
  [2053] = {.lex_state = 131, .external_lex_state = 2},
  [2054] = {.lex_state = 131, .external_lex_state = 2},
  [2055] = {.lex_state = 131, .external_lex_state = 2},
  [2056] = {.lex_state = 131, .external_lex_state = 2},
  [2057] = {.lex_state = 131, .external_lex_state = 2},
  [2058] = {.lex_state = 131, .external_lex_state = 2},
  [2059] = {.lex_state = 131, .external_lex_state = 2},
  [2060] = {.lex_state = 131, .external_lex_state = 2},
  [2061] = {.lex_state = 131, .external_lex_state = 2},
  [2062] = {.lex_state = 131, .external_lex_state = 2},
  [2063] = {.lex_state = 131, .external_lex_state = 2},
  [2064] = {.lex_state = 131, .external_lex_state = 2},
  [2065] = {.lex_state = 131, .external_lex_state = 2},
  [2066] = {.lex_state = 131, .external_lex_state = 2},
  [2067] = {.lex_state = 131, .external_lex_state = 2},
  [2068] = {.lex_state = 131, .external_lex_state = 2},
  [2069] = {.lex_state = 131, .external_lex_state = 2},
  [2070] = {.lex_state = 131, .external_lex_state = 2},
  [2071] = {.lex_state = 131, .external_lex_state = 2},
  [2072] = {.lex_state = 131, .external_lex_state = 2},
  [2073] = {.lex_state = 131, .external_lex_state = 2},
  [2074] = {.lex_state = 131, .external_lex_state = 2},
  [2075] = {.lex_state = 131, .external_lex_state = 2},
  [2076] = {.lex_state = 131, .external_lex_state = 2},
  [2077] = {.lex_state = 131, .external_lex_state = 2},
  [2078] = {.lex_state = 131, .external_lex_state = 2},
  [2079] = {.lex_state = 131, .external_lex_state = 2},
  [2080] = {.lex_state = 131, .external_lex_state = 2},
  [2081] = {.lex_state = 131, .external_lex_state = 2},
  [2082] = {.lex_state = 131, .external_lex_state = 2},
  [2083] = {.lex_state = 131, .external_lex_state = 2},
  [2084] = {.lex_state = 131, .external_lex_state = 2},
  [2085] = {.lex_state = 131, .external_lex_state = 2},
  [2086] = {.lex_state = 131, .external_lex_state = 2},
  [2087] = {.lex_state = 131, .external_lex_state = 2},
  [2088] = {.lex_state = 131, .external_lex_state = 2},
  [2089] = {.lex_state = 131, .external_lex_state = 2},
  [2090] = {.lex_state = 131, .external_lex_state = 2},
  [2091] = {.lex_state = 131, .external_lex_state = 2},
  [2092] = {.lex_state = 131, .external_lex_state = 2},
  [2093] = {.lex_state = 131, .external_lex_state = 2},
  [2094] = {.lex_state = 131, .external_lex_state = 2},
  [2095] = {.lex_state = 131, .external_lex_state = 2},
  [2096] = {.lex_state = 131, .external_lex_state = 2},
  [2097] = {.lex_state = 131, .external_lex_state = 2},
  [2098] = {.lex_state = 131, .external_lex_state = 2},
  [2099] = {.lex_state = 131, .external_lex_state = 2},
  [2100] = {.lex_state = 131, .external_lex_state = 2},
  [2101] = {.lex_state = 131, .external_lex_state = 2},
  [2102] = {.lex_state = 131, .external_lex_state = 2},
  [2103] = {.lex_state = 131, .external_lex_state = 2},
  [2104] = {.lex_state = 131, .external_lex_state = 2},
  [2105] = {.lex_state = 131, .external_lex_state = 2},
  [2106] = {.lex_state = 131, .external_lex_state = 2},
  [2107] = {.lex_state = 131, .external_lex_state = 2},
  [2108] = {.lex_state = 131, .external_lex_state = 2},
  [2109] = {.lex_state = 131, .external_lex_state = 2},
  [2110] = {.lex_state = 131, .external_lex_state = 2},
  [2111] = {.lex_state = 131, .external_lex_state = 2},
  [2112] = {.lex_state = 131, .external_lex_state = 2},
  [2113] = {.lex_state = 131, .external_lex_state = 2},
  [2114] = {.lex_state = 131, .external_lex_state = 2},
  [2115] = {.lex_state = 131, .external_lex_state = 2},
  [2116] = {.lex_state = 131, .external_lex_state = 2},
  [2117] = {.lex_state = 131, .external_lex_state = 2},
  [2118] = {.lex_state = 131, .external_lex_state = 2},
  [2119] = {.lex_state = 131, .external_lex_state = 2},
  [2120] = {.lex_state = 131, .external_lex_state = 2},
  [2121] = {.lex_state = 131, .external_lex_state = 2},
  [2122] = {.lex_state = 131, .external_lex_state = 2},
  [2123] = {.lex_state = 131, .external_lex_state = 2},
  [2124] = {.lex_state = 131, .external_lex_state = 2},
  [2125] = {.lex_state = 131, .external_lex_state = 2},
  [2126] = {.lex_state = 131, .external_lex_state = 2},
  [2127] = {.lex_state = 131, .external_lex_state = 2},
  [2128] = {.lex_state = 131, .external_lex_state = 2},
  [2129] = {.lex_state = 131, .external_lex_state = 2},
  [2130] = {.lex_state = 131, .external_lex_state = 2},
  [2131] = {.lex_state = 131, .external_lex_state = 2},
  [2132] = {.lex_state = 131, .external_lex_state = 2},
  [2133] = {.lex_state = 131, .external_lex_state = 2},
  [2134] = {.lex_state = 131, .external_lex_state = 2},
  [2135] = {.lex_state = 131, .external_lex_state = 2},
  [2136] = {.lex_state = 131, .external_lex_state = 2},
  [2137] = {.lex_state = 131, .external_lex_state = 2},
  [2138] = {.lex_state = 131, .external_lex_state = 2},
  [2139] = {.lex_state = 131, .external_lex_state = 2},
  [2140] = {.lex_state = 131, .external_lex_state = 2},
  [2141] = {.lex_state = 131, .external_lex_state = 2},
  [2142] = {.lex_state = 131, .external_lex_state = 2},
  [2143] = {.lex_state = 131, .external_lex_state = 2},
  [2144] = {.lex_state = 131, .external_lex_state = 2},
  [2145] = {.lex_state = 131, .external_lex_state = 2},
  [2146] = {.lex_state = 131, .external_lex_state = 2},
  [2147] = {.lex_state = 131, .external_lex_state = 2},
  [2148] = {.lex_state = 131, .external_lex_state = 2},
  [2149] = {.lex_state = 131, .external_lex_state = 2},
  [2150] = {.lex_state = 131, .external_lex_state = 2},
  [2151] = {.lex_state = 131, .external_lex_state = 2},
  [2152] = {.lex_state = 131, .external_lex_state = 2},
  [2153] = {.lex_state = 131, .external_lex_state = 2},
  [2154] = {.lex_state = 131, .external_lex_state = 2},
  [2155] = {.lex_state = 131, .external_lex_state = 2},
  [2156] = {.lex_state = 131, .external_lex_state = 2},
  [2157] = {.lex_state = 131, .external_lex_state = 2},
  [2158] = {.lex_state = 131, .external_lex_state = 2},
  [2159] = {.lex_state = 131, .external_lex_state = 2},
  [2160] = {.lex_state = 131, .external_lex_state = 2},
  [2161] = {.lex_state = 131, .external_lex_state = 2},
  [2162] = {.lex_state = 131, .external_lex_state = 2},
  [2163] = {.lex_state = 131, .external_lex_state = 2},
  [2164] = {.lex_state = 131, .external_lex_state = 2},
  [2165] = {.lex_state = 131, .external_lex_state = 2},
  [2166] = {.lex_state = 131, .external_lex_state = 2},
  [2167] = {.lex_state = 131, .external_lex_state = 2},
  [2168] = {.lex_state = 131, .external_lex_state = 2},
  [2169] = {.lex_state = 131, .external_lex_state = 2},
  [2170] = {.lex_state = 131, .external_lex_state = 2},
  [2171] = {.lex_state = 131, .external_lex_state = 2},
  [2172] = {.lex_state = 131, .external_lex_state = 2},
  [2173] = {.lex_state = 131, .external_lex_state = 2},
  [2174] = {.lex_state = 131, .external_lex_state = 2},
  [2175] = {.lex_state = 131, .external_lex_state = 2},
  [2176] = {.lex_state = 131, .external_lex_state = 2},
  [2177] = {.lex_state = 131, .external_lex_state = 2},
  [2178] = {.lex_state = 131, .external_lex_state = 2},
  [2179] = {.lex_state = 131, .external_lex_state = 2},
  [2180] = {.lex_state = 131, .external_lex_state = 2},
  [2181] = {.lex_state = 131, .external_lex_state = 2},
  [2182] = {.lex_state = 131, .external_lex_state = 2},
  [2183] = {.lex_state = 131, .external_lex_state = 2},
  [2184] = {.lex_state = 131, .external_lex_state = 2},
  [2185] = {.lex_state = 131, .external_lex_state = 2},
  [2186] = {.lex_state = 131, .external_lex_state = 2},
  [2187] = {.lex_state = 131, .external_lex_state = 2},
  [2188] = {.lex_state = 131, .external_lex_state = 2},
  [2189] = {.lex_state = 131, .external_lex_state = 2},
  [2190] = {.lex_state = 131, .external_lex_state = 2},
  [2191] = {.lex_state = 131, .external_lex_state = 2},
  [2192] = {.lex_state = 131, .external_lex_state = 2},
  [2193] = {.lex_state = 131, .external_lex_state = 2},
  [2194] = {.lex_state = 131, .external_lex_state = 2},
  [2195] = {.lex_state = 131, .external_lex_state = 2},
  [2196] = {.lex_state = 131, .external_lex_state = 2},
  [2197] = {.lex_state = 131, .external_lex_state = 2},
  [2198] = {.lex_state = 131, .external_lex_state = 2},
  [2199] = {.lex_state = 131, .external_lex_state = 2},
  [2200] = {.lex_state = 131, .external_lex_state = 2},
  [2201] = {.lex_state = 131, .external_lex_state = 2},
  [2202] = {.lex_state = 131, .external_lex_state = 2},
  [2203] = {.lex_state = 130, .external_lex_state = 2},
  [2204] = {.lex_state = 130, .external_lex_state = 2},
  [2205] = {.lex_state = 130, .external_lex_state = 2},
  [2206] = {.lex_state = 130, .external_lex_state = 2},
  [2207] = {.lex_state = 130, .external_lex_state = 2},
  [2208] = {.lex_state = 130, .external_lex_state = 2},
  [2209] = {.lex_state = 131, .external_lex_state = 2},
  [2210] = {.lex_state = 131, .external_lex_state = 2},
  [2211] = {.lex_state = 131, .external_lex_state = 2},
  [2212] = {.lex_state = 131, .external_lex_state = 2},
  [2213] = {.lex_state = 131, .external_lex_state = 2},
  [2214] = {.lex_state = 131, .external_lex_state = 2},
  [2215] = {.lex_state = 131, .external_lex_state = 2},
  [2216] = {.lex_state = 131, .external_lex_state = 2},
  [2217] = {.lex_state = 131, .external_lex_state = 2},
  [2218] = {.lex_state = 131, .external_lex_state = 2},
  [2219] = {.lex_state = 131, .external_lex_state = 2},
  [2220] = {.lex_state = 131, .external_lex_state = 2},
  [2221] = {.lex_state = 131, .external_lex_state = 2},
  [2222] = {.lex_state = 131, .external_lex_state = 2},
  [2223] = {.lex_state = 131, .external_lex_state = 2},
  [2224] = {.lex_state = 131, .external_lex_state = 2},
  [2225] = {.lex_state = 131, .external_lex_state = 2},
  [2226] = {.lex_state = 131, .external_lex_state = 2},
  [2227] = {.lex_state = 131, .external_lex_state = 2},
  [2228] = {.lex_state = 131, .external_lex_state = 2},
  [2229] = {.lex_state = 131, .external_lex_state = 2},
  [2230] = {.lex_state = 131, .external_lex_state = 2},
  [2231] = {.lex_state = 131, .external_lex_state = 2},
  [2232] = {.lex_state = 131, .external_lex_state = 2},
  [2233] = {.lex_state = 131, .external_lex_state = 2},
  [2234] = {.lex_state = 131, .external_lex_state = 2},
  [2235] = {.lex_state = 131, .external_lex_state = 2},
  [2236] = {.lex_state = 131, .external_lex_state = 2},
  [2237] = {.lex_state = 131, .external_lex_state = 2},
  [2238] = {.lex_state = 131, .external_lex_state = 2},
  [2239] = {.lex_state = 131, .external_lex_state = 2},
  [2240] = {.lex_state = 131, .external_lex_state = 2},
  [2241] = {.lex_state = 131, .external_lex_state = 2},
  [2242] = {.lex_state = 131, .external_lex_state = 2},
  [2243] = {.lex_state = 131, .external_lex_state = 2},
  [2244] = {.lex_state = 131, .external_lex_state = 2},
  [2245] = {.lex_state = 131, .external_lex_state = 2},
  [2246] = {.lex_state = 131, .external_lex_state = 2},
  [2247] = {.lex_state = 131, .external_lex_state = 2},
  [2248] = {.lex_state = 131, .external_lex_state = 2},
  [2249] = {.lex_state = 131, .external_lex_state = 2},
  [2250] = {.lex_state = 131, .external_lex_state = 2},
  [2251] = {.lex_state = 131, .external_lex_state = 2},
  [2252] = {.lex_state = 131, .external_lex_state = 2},
  [2253] = {.lex_state = 131, .external_lex_state = 2},
  [2254] = {.lex_state = 131, .external_lex_state = 2},
  [2255] = {.lex_state = 131, .external_lex_state = 2},
  [2256] = {.lex_state = 131, .external_lex_state = 2},
  [2257] = {.lex_state = 131},
  [2258] = {.lex_state = 131, .external_lex_state = 2},
  [2259] = {.lex_state = 131, .external_lex_state = 2},
  [2260] = {.lex_state = 131, .external_lex_state = 2},
  [2261] = {.lex_state = 131, .external_lex_state = 2},
  [2262] = {.lex_state = 131},
  [2263] = {.lex_state = 131},
  [2264] = {.lex_state = 131, .external_lex_state = 2},
  [2265] = {.lex_state = 131, .external_lex_state = 2},
  [2266] = {.lex_state = 131, .external_lex_state = 2},
  [2267] = {.lex_state = 131, .external_lex_state = 2},
  [2268] = {.lex_state = 131, .external_lex_state = 2},
  [2269] = {.lex_state = 131, .external_lex_state = 2},
  [2270] = {.lex_state = 131, .external_lex_state = 2},
  [2271] = {.lex_state = 131, .external_lex_state = 2},
  [2272] = {.lex_state = 131, .external_lex_state = 2},
  [2273] = {.lex_state = 131, .external_lex_state = 2},
  [2274] = {.lex_state = 131, .external_lex_state = 2},
  [2275] = {.lex_state = 131, .external_lex_state = 2},
  [2276] = {.lex_state = 131, .external_lex_state = 2},
  [2277] = {.lex_state = 131, .external_lex_state = 2},
  [2278] = {.lex_state = 131, .external_lex_state = 2},
  [2279] = {.lex_state = 131, .external_lex_state = 2},
  [2280] = {.lex_state = 131, .external_lex_state = 2},
  [2281] = {.lex_state = 131, .external_lex_state = 2},
  [2282] = {.lex_state = 131, .external_lex_state = 2},
  [2283] = {.lex_state = 131, .external_lex_state = 2},
  [2284] = {.lex_state = 131, .external_lex_state = 2},
  [2285] = {.lex_state = 131, .external_lex_state = 2},
  [2286] = {.lex_state = 131, .external_lex_state = 2},
  [2287] = {.lex_state = 131, .external_lex_state = 2},
  [2288] = {.lex_state = 131, .external_lex_state = 2},
  [2289] = {.lex_state = 131, .external_lex_state = 2},
  [2290] = {.lex_state = 131, .external_lex_state = 2},
  [2291] = {.lex_state = 131, .external_lex_state = 2},
  [2292] = {.lex_state = 131, .external_lex_state = 2},
  [2293] = {.lex_state = 131, .external_lex_state = 2},
  [2294] = {.lex_state = 131},
  [2295] = {.lex_state = 131, .external_lex_state = 2},
  [2296] = {.lex_state = 131, .external_lex_state = 2},
  [2297] = {.lex_state = 131, .external_lex_state = 2},
  [2298] = {.lex_state = 131, .external_lex_state = 2},
  [2299] = {.lex_state = 131, .external_lex_state = 2},
  [2300] = {.lex_state = 131, .external_lex_state = 2},
  [2301] = {.lex_state = 131, .external_lex_state = 2},
  [2302] = {.lex_state = 131, .external_lex_state = 2},
  [2303] = {.lex_state = 131, .external_lex_state = 2},
  [2304] = {.lex_state = 131, .external_lex_state = 2},
  [2305] = {.lex_state = 131, .external_lex_state = 2},
  [2306] = {.lex_state = 131, .external_lex_state = 2},
  [2307] = {.lex_state = 131, .external_lex_state = 2},
  [2308] = {.lex_state = 131, .external_lex_state = 2},
  [2309] = {.lex_state = 131, .external_lex_state = 2},
  [2310] = {.lex_state = 131, .external_lex_state = 2},
  [2311] = {.lex_state = 131, .external_lex_state = 2},
  [2312] = {.lex_state = 131, .external_lex_state = 2},
  [2313] = {.lex_state = 131, .external_lex_state = 2},
  [2314] = {.lex_state = 131, .external_lex_state = 2},
  [2315] = {.lex_state = 131, .external_lex_state = 2},
  [2316] = {.lex_state = 131, .external_lex_state = 2},
  [2317] = {.lex_state = 131, .external_lex_state = 2},
  [2318] = {.lex_state = 131, .external_lex_state = 2},
  [2319] = {.lex_state = 131, .external_lex_state = 2},
  [2320] = {.lex_state = 131, .external_lex_state = 2},
  [2321] = {.lex_state = 131, .external_lex_state = 2},
  [2322] = {.lex_state = 131, .external_lex_state = 2},
  [2323] = {.lex_state = 131, .external_lex_state = 2},
  [2324] = {.lex_state = 131, .external_lex_state = 2},
  [2325] = {.lex_state = 131, .external_lex_state = 2},
  [2326] = {.lex_state = 131, .external_lex_state = 2},
  [2327] = {.lex_state = 131, .external_lex_state = 2},
  [2328] = {.lex_state = 131, .external_lex_state = 2},
  [2329] = {.lex_state = 131, .external_lex_state = 2},
  [2330] = {.lex_state = 131, .external_lex_state = 2},
  [2331] = {.lex_state = 131, .external_lex_state = 2},
  [2332] = {.lex_state = 131, .external_lex_state = 2},
  [2333] = {.lex_state = 131, .external_lex_state = 2},
  [2334] = {.lex_state = 131, .external_lex_state = 2},
  [2335] = {.lex_state = 131, .external_lex_state = 2},
  [2336] = {.lex_state = 131, .external_lex_state = 2},
  [2337] = {.lex_state = 131, .external_lex_state = 2},
  [2338] = {.lex_state = 131, .external_lex_state = 2},
  [2339] = {.lex_state = 131, .external_lex_state = 2},
  [2340] = {.lex_state = 131, .external_lex_state = 2},
  [2341] = {.lex_state = 131, .external_lex_state = 2},
  [2342] = {.lex_state = 131, .external_lex_state = 2},
  [2343] = {.lex_state = 131, .external_lex_state = 2},
  [2344] = {.lex_state = 131, .external_lex_state = 2},
  [2345] = {.lex_state = 131, .external_lex_state = 2},
  [2346] = {.lex_state = 131, .external_lex_state = 2},
  [2347] = {.lex_state = 131, .external_lex_state = 2},
  [2348] = {.lex_state = 131, .external_lex_state = 2},
  [2349] = {.lex_state = 131, .external_lex_state = 2},
  [2350] = {.lex_state = 131, .external_lex_state = 2},
  [2351] = {.lex_state = 131, .external_lex_state = 2},
  [2352] = {.lex_state = 131, .external_lex_state = 2},
  [2353] = {.lex_state = 131, .external_lex_state = 2},
  [2354] = {.lex_state = 131, .external_lex_state = 2},
  [2355] = {.lex_state = 131, .external_lex_state = 2},
  [2356] = {.lex_state = 131, .external_lex_state = 2},
  [2357] = {.lex_state = 131, .external_lex_state = 2},
  [2358] = {.lex_state = 131, .external_lex_state = 2},
  [2359] = {.lex_state = 131, .external_lex_state = 2},
  [2360] = {.lex_state = 131, .external_lex_state = 2},
  [2361] = {.lex_state = 131, .external_lex_state = 2},
  [2362] = {.lex_state = 131, .external_lex_state = 2},
  [2363] = {.lex_state = 131, .external_lex_state = 2},
  [2364] = {.lex_state = 131, .external_lex_state = 2},
  [2365] = {.lex_state = 131, .external_lex_state = 2},
  [2366] = {.lex_state = 131, .external_lex_state = 2},
  [2367] = {.lex_state = 131, .external_lex_state = 2},
  [2368] = {.lex_state = 131, .external_lex_state = 2},
  [2369] = {.lex_state = 131, .external_lex_state = 2},
  [2370] = {.lex_state = 131, .external_lex_state = 2},
  [2371] = {.lex_state = 131, .external_lex_state = 2},
  [2372] = {.lex_state = 131, .external_lex_state = 2},
  [2373] = {.lex_state = 131, .external_lex_state = 2},
  [2374] = {.lex_state = 131, .external_lex_state = 2},
  [2375] = {.lex_state = 131, .external_lex_state = 2},
  [2376] = {.lex_state = 131, .external_lex_state = 2},
  [2377] = {.lex_state = 131, .external_lex_state = 2},
  [2378] = {.lex_state = 131, .external_lex_state = 2},
  [2379] = {.lex_state = 131, .external_lex_state = 2},
  [2380] = {.lex_state = 131, .external_lex_state = 2},
  [2381] = {.lex_state = 131, .external_lex_state = 2},
  [2382] = {.lex_state = 131, .external_lex_state = 2},
  [2383] = {.lex_state = 131, .external_lex_state = 2},
  [2384] = {.lex_state = 131, .external_lex_state = 2},
  [2385] = {.lex_state = 131, .external_lex_state = 2},
  [2386] = {.lex_state = 131, .external_lex_state = 2},
  [2387] = {.lex_state = 131, .external_lex_state = 2},
  [2388] = {.lex_state = 131, .external_lex_state = 2},
  [2389] = {.lex_state = 131, .external_lex_state = 2},
  [2390] = {.lex_state = 131, .external_lex_state = 2},
  [2391] = {.lex_state = 131, .external_lex_state = 2},
  [2392] = {.lex_state = 131, .external_lex_state = 2},
  [2393] = {.lex_state = 131, .external_lex_state = 2},
  [2394] = {.lex_state = 131, .external_lex_state = 2},
  [2395] = {.lex_state = 131, .external_lex_state = 2},
  [2396] = {.lex_state = 131, .external_lex_state = 2},
  [2397] = {.lex_state = 131, .external_lex_state = 2},
  [2398] = {.lex_state = 131, .external_lex_state = 2},
  [2399] = {.lex_state = 131, .external_lex_state = 2},
  [2400] = {.lex_state = 131, .external_lex_state = 2},
  [2401] = {.lex_state = 131, .external_lex_state = 2},
  [2402] = {.lex_state = 131, .external_lex_state = 2},
  [2403] = {.lex_state = 131, .external_lex_state = 2},
  [2404] = {.lex_state = 131, .external_lex_state = 2},
  [2405] = {.lex_state = 131, .external_lex_state = 2},
  [2406] = {.lex_state = 131, .external_lex_state = 2},
  [2407] = {.lex_state = 131, .external_lex_state = 2},
  [2408] = {.lex_state = 131, .external_lex_state = 2},
  [2409] = {.lex_state = 131, .external_lex_state = 2},
  [2410] = {.lex_state = 131, .external_lex_state = 2},
  [2411] = {.lex_state = 131, .external_lex_state = 2},
  [2412] = {.lex_state = 131, .external_lex_state = 2},
  [2413] = {.lex_state = 131, .external_lex_state = 2},
  [2414] = {.lex_state = 131, .external_lex_state = 2},
  [2415] = {.lex_state = 131, .external_lex_state = 2},
  [2416] = {.lex_state = 131, .external_lex_state = 2},
  [2417] = {.lex_state = 131, .external_lex_state = 2},
  [2418] = {.lex_state = 131, .external_lex_state = 2},
  [2419] = {.lex_state = 131, .external_lex_state = 2},
  [2420] = {.lex_state = 131, .external_lex_state = 2},
  [2421] = {.lex_state = 131, .external_lex_state = 2},
  [2422] = {.lex_state = 131},
  [2423] = {.lex_state = 131, .external_lex_state = 2},
  [2424] = {.lex_state = 131, .external_lex_state = 2},
  [2425] = {.lex_state = 131, .external_lex_state = 2},
  [2426] = {.lex_state = 131, .external_lex_state = 2},
  [2427] = {.lex_state = 131, .external_lex_state = 2},
  [2428] = {.lex_state = 131, .external_lex_state = 2},
  [2429] = {.lex_state = 131, .external_lex_state = 2},
  [2430] = {.lex_state = 131, .external_lex_state = 2},
  [2431] = {.lex_state = 131, .external_lex_state = 2},
  [2432] = {.lex_state = 131, .external_lex_state = 2},
  [2433] = {.lex_state = 131, .external_lex_state = 2},
  [2434] = {.lex_state = 131, .external_lex_state = 2},
  [2435] = {.lex_state = 131, .external_lex_state = 2},
  [2436] = {.lex_state = 131, .external_lex_state = 2},
  [2437] = {.lex_state = 131, .external_lex_state = 2},
  [2438] = {.lex_state = 131, .external_lex_state = 2},
  [2439] = {.lex_state = 131, .external_lex_state = 2},
  [2440] = {.lex_state = 131, .external_lex_state = 2},
  [2441] = {.lex_state = 131, .external_lex_state = 2},
  [2442] = {.lex_state = 131, .external_lex_state = 2},
  [2443] = {.lex_state = 131, .external_lex_state = 2},
  [2444] = {.lex_state = 131, .external_lex_state = 2},
  [2445] = {.lex_state = 131, .external_lex_state = 2},
  [2446] = {.lex_state = 131, .external_lex_state = 2},
  [2447] = {.lex_state = 131, .external_lex_state = 2},
  [2448] = {.lex_state = 131, .external_lex_state = 2},
  [2449] = {.lex_state = 131, .external_lex_state = 2},
  [2450] = {.lex_state = 4},
  [2451] = {.lex_state = 131, .external_lex_state = 2},
  [2452] = {.lex_state = 131, .external_lex_state = 2},
  [2453] = {.lex_state = 131, .external_lex_state = 2},
  [2454] = {.lex_state = 131, .external_lex_state = 2},
  [2455] = {.lex_state = 131, .external_lex_state = 2},
  [2456] = {.lex_state = 131, .external_lex_state = 2},
  [2457] = {.lex_state = 131, .external_lex_state = 2},
  [2458] = {.lex_state = 131, .external_lex_state = 2},
  [2459] = {.lex_state = 131, .external_lex_state = 2},
  [2460] = {.lex_state = 131, .external_lex_state = 2},
  [2461] = {.lex_state = 131, .external_lex_state = 2},
  [2462] = {.lex_state = 131, .external_lex_state = 2},
  [2463] = {.lex_state = 131, .external_lex_state = 2},
  [2464] = {.lex_state = 131, .external_lex_state = 2},
  [2465] = {.lex_state = 131, .external_lex_state = 2},
  [2466] = {.lex_state = 131, .external_lex_state = 2},
  [2467] = {.lex_state = 131, .external_lex_state = 2},
  [2468] = {.lex_state = 131, .external_lex_state = 2},
  [2469] = {.lex_state = 131, .external_lex_state = 2},
  [2470] = {.lex_state = 131, .external_lex_state = 2},
  [2471] = {.lex_state = 131, .external_lex_state = 2},
  [2472] = {.lex_state = 131, .external_lex_state = 2},
  [2473] = {.lex_state = 131, .external_lex_state = 2},
  [2474] = {.lex_state = 131, .external_lex_state = 2},
  [2475] = {.lex_state = 131, .external_lex_state = 2},
  [2476] = {.lex_state = 131, .external_lex_state = 2},
  [2477] = {.lex_state = 131, .external_lex_state = 2},
  [2478] = {.lex_state = 131, .external_lex_state = 2},
  [2479] = {.lex_state = 131, .external_lex_state = 2},
  [2480] = {.lex_state = 131, .external_lex_state = 2},
  [2481] = {.lex_state = 131, .external_lex_state = 2},
  [2482] = {.lex_state = 131, .external_lex_state = 2},
  [2483] = {.lex_state = 131, .external_lex_state = 2},
  [2484] = {.lex_state = 131, .external_lex_state = 2},
  [2485] = {.lex_state = 131, .external_lex_state = 2},
  [2486] = {.lex_state = 131, .external_lex_state = 2},
  [2487] = {.lex_state = 131, .external_lex_state = 2},
  [2488] = {.lex_state = 131, .external_lex_state = 2},
  [2489] = {.lex_state = 131, .external_lex_state = 2},
  [2490] = {.lex_state = 131, .external_lex_state = 2},
  [2491] = {.lex_state = 131, .external_lex_state = 2},
  [2492] = {.lex_state = 131, .external_lex_state = 2},
  [2493] = {.lex_state = 131, .external_lex_state = 2},
  [2494] = {.lex_state = 131, .external_lex_state = 2},
  [2495] = {.lex_state = 131, .external_lex_state = 2},
  [2496] = {.lex_state = 131, .external_lex_state = 2},
  [2497] = {.lex_state = 131, .external_lex_state = 2},
  [2498] = {.lex_state = 131, .external_lex_state = 2},
  [2499] = {.lex_state = 131, .external_lex_state = 2},
  [2500] = {.lex_state = 131, .external_lex_state = 2},
  [2501] = {.lex_state = 131, .external_lex_state = 2},
  [2502] = {.lex_state = 131, .external_lex_state = 2},
  [2503] = {.lex_state = 131, .external_lex_state = 2},
  [2504] = {.lex_state = 131, .external_lex_state = 2},
  [2505] = {.lex_state = 131, .external_lex_state = 2},
  [2506] = {.lex_state = 131, .external_lex_state = 2},
  [2507] = {.lex_state = 131, .external_lex_state = 2},
  [2508] = {.lex_state = 131, .external_lex_state = 2},
  [2509] = {.lex_state = 131, .external_lex_state = 2},
  [2510] = {.lex_state = 131, .external_lex_state = 2},
  [2511] = {.lex_state = 131, .external_lex_state = 2},
  [2512] = {.lex_state = 131, .external_lex_state = 2},
  [2513] = {.lex_state = 131, .external_lex_state = 2},
  [2514] = {.lex_state = 131, .external_lex_state = 2},
  [2515] = {.lex_state = 131, .external_lex_state = 2},
  [2516] = {.lex_state = 131, .external_lex_state = 2},
  [2517] = {.lex_state = 131, .external_lex_state = 2},
  [2518] = {.lex_state = 131, .external_lex_state = 2},
  [2519] = {.lex_state = 131, .external_lex_state = 2},
  [2520] = {.lex_state = 131, .external_lex_state = 2},
  [2521] = {.lex_state = 131, .external_lex_state = 2},
  [2522] = {.lex_state = 131, .external_lex_state = 2},
  [2523] = {.lex_state = 131, .external_lex_state = 2},
  [2524] = {.lex_state = 131, .external_lex_state = 2},
  [2525] = {.lex_state = 131, .external_lex_state = 2},
  [2526] = {.lex_state = 131, .external_lex_state = 2},
  [2527] = {.lex_state = 131, .external_lex_state = 2},
  [2528] = {.lex_state = 131, .external_lex_state = 2},
  [2529] = {.lex_state = 131, .external_lex_state = 2},
  [2530] = {.lex_state = 131, .external_lex_state = 2},
  [2531] = {.lex_state = 131, .external_lex_state = 2},
  [2532] = {.lex_state = 131, .external_lex_state = 2},
  [2533] = {.lex_state = 131, .external_lex_state = 2},
  [2534] = {.lex_state = 131, .external_lex_state = 2},
  [2535] = {.lex_state = 131, .external_lex_state = 2},
  [2536] = {.lex_state = 131, .external_lex_state = 2},
  [2537] = {.lex_state = 131, .external_lex_state = 2},
  [2538] = {.lex_state = 131, .external_lex_state = 2},
  [2539] = {.lex_state = 131, .external_lex_state = 2},
  [2540] = {.lex_state = 131, .external_lex_state = 2},
  [2541] = {.lex_state = 131, .external_lex_state = 2},
  [2542] = {.lex_state = 131, .external_lex_state = 2},
  [2543] = {.lex_state = 131, .external_lex_state = 2},
  [2544] = {.lex_state = 131, .external_lex_state = 2},
  [2545] = {.lex_state = 131, .external_lex_state = 2},
  [2546] = {.lex_state = 131, .external_lex_state = 2},
  [2547] = {.lex_state = 131, .external_lex_state = 2},
  [2548] = {.lex_state = 131, .external_lex_state = 2},
  [2549] = {.lex_state = 131, .external_lex_state = 2},
  [2550] = {.lex_state = 131, .external_lex_state = 2},
  [2551] = {.lex_state = 131, .external_lex_state = 2},
  [2552] = {.lex_state = 131, .external_lex_state = 2},
  [2553] = {.lex_state = 131, .external_lex_state = 2},
  [2554] = {.lex_state = 131, .external_lex_state = 2},
  [2555] = {.lex_state = 131, .external_lex_state = 2},
  [2556] = {.lex_state = 131, .external_lex_state = 2},
  [2557] = {.lex_state = 131, .external_lex_state = 2},
  [2558] = {.lex_state = 131, .external_lex_state = 2},
  [2559] = {.lex_state = 131, .external_lex_state = 2},
  [2560] = {.lex_state = 131, .external_lex_state = 2},
  [2561] = {.lex_state = 131, .external_lex_state = 2},
  [2562] = {.lex_state = 131, .external_lex_state = 2},
  [2563] = {.lex_state = 131, .external_lex_state = 2},
  [2564] = {.lex_state = 131, .external_lex_state = 2},
  [2565] = {.lex_state = 131, .external_lex_state = 2},
  [2566] = {.lex_state = 131, .external_lex_state = 2},
  [2567] = {.lex_state = 131, .external_lex_state = 2},
  [2568] = {.lex_state = 131, .external_lex_state = 2},
  [2569] = {.lex_state = 131, .external_lex_state = 2},
  [2570] = {.lex_state = 131, .external_lex_state = 2},
  [2571] = {.lex_state = 131, .external_lex_state = 2},
  [2572] = {.lex_state = 131, .external_lex_state = 2},
  [2573] = {.lex_state = 131, .external_lex_state = 2},
  [2574] = {.lex_state = 131, .external_lex_state = 2},
  [2575] = {.lex_state = 131, .external_lex_state = 2},
  [2576] = {.lex_state = 131, .external_lex_state = 2},
  [2577] = {.lex_state = 131, .external_lex_state = 2},
  [2578] = {.lex_state = 131, .external_lex_state = 2},
  [2579] = {.lex_state = 131, .external_lex_state = 2},
  [2580] = {.lex_state = 131, .external_lex_state = 2},
  [2581] = {.lex_state = 131, .external_lex_state = 2},
  [2582] = {.lex_state = 131, .external_lex_state = 2},
  [2583] = {.lex_state = 131, .external_lex_state = 2},
  [2584] = {.lex_state = 131, .external_lex_state = 2},
  [2585] = {.lex_state = 131, .external_lex_state = 2},
  [2586] = {.lex_state = 131, .external_lex_state = 2},
  [2587] = {.lex_state = 131, .external_lex_state = 2},
  [2588] = {.lex_state = 131, .external_lex_state = 2},
  [2589] = {.lex_state = 131, .external_lex_state = 2},
  [2590] = {.lex_state = 131, .external_lex_state = 2},
  [2591] = {.lex_state = 131, .external_lex_state = 2},
  [2592] = {.lex_state = 131, .external_lex_state = 2},
  [2593] = {.lex_state = 131, .external_lex_state = 2},
  [2594] = {.lex_state = 131, .external_lex_state = 2},
  [2595] = {.lex_state = 131, .external_lex_state = 2},
  [2596] = {.lex_state = 131, .external_lex_state = 2},
  [2597] = {.lex_state = 131, .external_lex_state = 2},
  [2598] = {.lex_state = 131, .external_lex_state = 2},
  [2599] = {.lex_state = 131, .external_lex_state = 2},
  [2600] = {.lex_state = 131, .external_lex_state = 2},
  [2601] = {.lex_state = 131, .external_lex_state = 2},
  [2602] = {.lex_state = 131, .external_lex_state = 2},
  [2603] = {.lex_state = 131, .external_lex_state = 2},
  [2604] = {.lex_state = 131, .external_lex_state = 2},
  [2605] = {.lex_state = 131, .external_lex_state = 2},
  [2606] = {.lex_state = 131, .external_lex_state = 2},
  [2607] = {.lex_state = 131, .external_lex_state = 2},
  [2608] = {.lex_state = 131, .external_lex_state = 2},
  [2609] = {.lex_state = 131, .external_lex_state = 2},
  [2610] = {.lex_state = 131, .external_lex_state = 2},
  [2611] = {.lex_state = 131, .external_lex_state = 2},
  [2612] = {.lex_state = 131, .external_lex_state = 2},
  [2613] = {.lex_state = 131, .external_lex_state = 2},
  [2614] = {.lex_state = 131, .external_lex_state = 2},
  [2615] = {.lex_state = 131, .external_lex_state = 2},
  [2616] = {.lex_state = 131, .external_lex_state = 2},
  [2617] = {.lex_state = 131, .external_lex_state = 2},
  [2618] = {.lex_state = 131, .external_lex_state = 2},
  [2619] = {.lex_state = 131, .external_lex_state = 2},
  [2620] = {.lex_state = 131, .external_lex_state = 2},
  [2621] = {.lex_state = 131, .external_lex_state = 2},
  [2622] = {.lex_state = 131, .external_lex_state = 2},
  [2623] = {.lex_state = 131, .external_lex_state = 2},
  [2624] = {.lex_state = 131, .external_lex_state = 2},
  [2625] = {.lex_state = 131, .external_lex_state = 2},
  [2626] = {.lex_state = 131, .external_lex_state = 2},
  [2627] = {.lex_state = 131, .external_lex_state = 2},
  [2628] = {.lex_state = 131, .external_lex_state = 2},
  [2629] = {.lex_state = 131, .external_lex_state = 2},
  [2630] = {.lex_state = 131, .external_lex_state = 2},
  [2631] = {.lex_state = 131, .external_lex_state = 2},
  [2632] = {.lex_state = 131, .external_lex_state = 2},
  [2633] = {.lex_state = 131, .external_lex_state = 2},
  [2634] = {.lex_state = 131, .external_lex_state = 2},
  [2635] = {.lex_state = 131, .external_lex_state = 2},
  [2636] = {.lex_state = 131, .external_lex_state = 2},
  [2637] = {.lex_state = 131, .external_lex_state = 2},
  [2638] = {.lex_state = 131, .external_lex_state = 2},
  [2639] = {.lex_state = 131, .external_lex_state = 2},
  [2640] = {.lex_state = 131, .external_lex_state = 2},
  [2641] = {.lex_state = 131, .external_lex_state = 2},
  [2642] = {.lex_state = 131, .external_lex_state = 2},
  [2643] = {.lex_state = 131, .external_lex_state = 2},
  [2644] = {.lex_state = 131},
  [2645] = {.lex_state = 131},
  [2646] = {.lex_state = 131},
  [2647] = {.lex_state = 131},
  [2648] = {.lex_state = 131, .external_lex_state = 2},
  [2649] = {.lex_state = 131, .external_lex_state = 2},
  [2650] = {.lex_state = 131, .external_lex_state = 2},
  [2651] = {.lex_state = 131, .external_lex_state = 2},
  [2652] = {.lex_state = 131, .external_lex_state = 2},
  [2653] = {.lex_state = 131, .external_lex_state = 2},
  [2654] = {.lex_state = 4},
  [2655] = {.lex_state = 131, .external_lex_state = 2},
  [2656] = {.lex_state = 131, .external_lex_state = 2},
  [2657] = {.lex_state = 131, .external_lex_state = 2},
  [2658] = {.lex_state = 131, .external_lex_state = 2},
  [2659] = {.lex_state = 131, .external_lex_state = 2},
  [2660] = {.lex_state = 131, .external_lex_state = 2},
  [2661] = {.lex_state = 131, .external_lex_state = 2},
  [2662] = {.lex_state = 131, .external_lex_state = 2},
  [2663] = {.lex_state = 131, .external_lex_state = 2},
  [2664] = {.lex_state = 131, .external_lex_state = 2},
  [2665] = {.lex_state = 131, .external_lex_state = 2},
  [2666] = {.lex_state = 131, .external_lex_state = 2},
  [2667] = {.lex_state = 131, .external_lex_state = 2},
  [2668] = {.lex_state = 131, .external_lex_state = 2},
  [2669] = {.lex_state = 131, .external_lex_state = 2},
  [2670] = {.lex_state = 131, .external_lex_state = 2},
  [2671] = {.lex_state = 131, .external_lex_state = 2},
  [2672] = {.lex_state = 131, .external_lex_state = 2},
  [2673] = {.lex_state = 131, .external_lex_state = 2},
  [2674] = {.lex_state = 131, .external_lex_state = 2},
  [2675] = {.lex_state = 131, .external_lex_state = 2},
  [2676] = {.lex_state = 131, .external_lex_state = 2},
  [2677] = {.lex_state = 131, .external_lex_state = 2},
  [2678] = {.lex_state = 131, .external_lex_state = 2},
  [2679] = {.lex_state = 131, .external_lex_state = 2},
  [2680] = {.lex_state = 131, .external_lex_state = 2},
  [2681] = {.lex_state = 131, .external_lex_state = 2},
  [2682] = {.lex_state = 131, .external_lex_state = 2},
  [2683] = {.lex_state = 131, .external_lex_state = 2},
  [2684] = {.lex_state = 131, .external_lex_state = 2},
  [2685] = {.lex_state = 131, .external_lex_state = 2},
  [2686] = {.lex_state = 131, .external_lex_state = 2},
  [2687] = {.lex_state = 131, .external_lex_state = 2},
  [2688] = {.lex_state = 131, .external_lex_state = 2},
  [2689] = {.lex_state = 131, .external_lex_state = 2},
  [2690] = {.lex_state = 131, .external_lex_state = 2},
  [2691] = {.lex_state = 131, .external_lex_state = 2},
  [2692] = {.lex_state = 131, .external_lex_state = 2},
  [2693] = {.lex_state = 131, .external_lex_state = 2},
  [2694] = {.lex_state = 131, .external_lex_state = 2},
  [2695] = {.lex_state = 131, .external_lex_state = 2},
  [2696] = {.lex_state = 131, .external_lex_state = 2},
  [2697] = {.lex_state = 131, .external_lex_state = 2},
  [2698] = {.lex_state = 131, .external_lex_state = 2},
  [2699] = {.lex_state = 131, .external_lex_state = 2},
  [2700] = {.lex_state = 131, .external_lex_state = 2},
  [2701] = {.lex_state = 131, .external_lex_state = 2},
  [2702] = {.lex_state = 131, .external_lex_state = 2},
  [2703] = {.lex_state = 131, .external_lex_state = 2},
  [2704] = {.lex_state = 131, .external_lex_state = 2},
  [2705] = {.lex_state = 131, .external_lex_state = 2},
  [2706] = {.lex_state = 131, .external_lex_state = 2},
  [2707] = {.lex_state = 131, .external_lex_state = 2},
  [2708] = {.lex_state = 131, .external_lex_state = 2},
  [2709] = {.lex_state = 131, .external_lex_state = 2},
  [2710] = {.lex_state = 131, .external_lex_state = 2},
  [2711] = {.lex_state = 131, .external_lex_state = 2},
  [2712] = {.lex_state = 131, .external_lex_state = 2},
  [2713] = {.lex_state = 131, .external_lex_state = 2},
  [2714] = {.lex_state = 131, .external_lex_state = 2},
  [2715] = {.lex_state = 131, .external_lex_state = 2},
  [2716] = {.lex_state = 131, .external_lex_state = 2},
  [2717] = {.lex_state = 131, .external_lex_state = 2},
  [2718] = {.lex_state = 131, .external_lex_state = 2},
  [2719] = {.lex_state = 131, .external_lex_state = 2},
  [2720] = {.lex_state = 131, .external_lex_state = 2},
  [2721] = {.lex_state = 131, .external_lex_state = 2},
  [2722] = {.lex_state = 131, .external_lex_state = 2},
  [2723] = {.lex_state = 131, .external_lex_state = 2},
  [2724] = {.lex_state = 131, .external_lex_state = 2},
  [2725] = {.lex_state = 131, .external_lex_state = 2},
  [2726] = {.lex_state = 131, .external_lex_state = 2},
  [2727] = {.lex_state = 131, .external_lex_state = 2},
  [2728] = {.lex_state = 131, .external_lex_state = 2},
  [2729] = {.lex_state = 131, .external_lex_state = 2},
  [2730] = {.lex_state = 131, .external_lex_state = 2},
  [2731] = {.lex_state = 4},
  [2732] = {.lex_state = 131, .external_lex_state = 2},
  [2733] = {.lex_state = 4, .external_lex_state = 4},
  [2734] = {.lex_state = 4},
  [2735] = {.lex_state = 4},
  [2736] = {.lex_state = 4},
  [2737] = {.lex_state = 4},
  [2738] = {.lex_state = 4},
  [2739] = {.lex_state = 4},
  [2740] = {.lex_state = 4, .external_lex_state = 4},
  [2741] = {.lex_state = 4},
  [2742] = {.lex_state = 4},
  [2743] = {.lex_state = 4},
  [2744] = {.lex_state = 4},
  [2745] = {.lex_state = 5},
  [2746] = {.lex_state = 5},
  [2747] = {.lex_state = 5},
  [2748] = {.lex_state = 4},
  [2749] = {.lex_state = 5},
  [2750] = {.lex_state = 5},
  [2751] = {.lex_state = 4, .external_lex_state = 4},
  [2752] = {.lex_state = 4},
  [2753] = {.lex_state = 5},
  [2754] = {.lex_state = 4},
  [2755] = {.lex_state = 4},
  [2756] = {.lex_state = 5},
  [2757] = {.lex_state = 5},
  [2758] = {.lex_state = 5},
  [2759] = {.lex_state = 5},
  [2760] = {.lex_state = 5},
  [2761] = {.lex_state = 5},
  [2762] = {.lex_state = 5},
  [2763] = {.lex_state = 4},
  [2764] = {.lex_state = 4},
  [2765] = {.lex_state = 5},
  [2766] = {.lex_state = 5},
  [2767] = {.lex_state = 5},
  [2768] = {.lex_state = 4, .external_lex_state = 4},
  [2769] = {.lex_state = 4},
  [2770] = {.lex_state = 6},
  [2771] = {.lex_state = 6},
  [2772] = {.lex_state = 5},
  [2773] = {.lex_state = 4},
  [2774] = {.lex_state = 6},
  [2775] = {.lex_state = 4},
  [2776] = {.lex_state = 4},
  [2777] = {.lex_state = 4},
  [2778] = {.lex_state = 4},
  [2779] = {.lex_state = 4},
  [2780] = {.lex_state = 4},
  [2781] = {.lex_state = 131},
  [2782] = {.lex_state = 5},
  [2783] = {.lex_state = 4},
  [2784] = {.lex_state = 4},
  [2785] = {.lex_state = 4},
  [2786] = {.lex_state = 4},
  [2787] = {.lex_state = 4},
  [2788] = {.lex_state = 4},
  [2789] = {.lex_state = 5},
  [2790] = {.lex_state = 4},
  [2791] = {.lex_state = 5},
  [2792] = {.lex_state = 4, .external_lex_state = 4},
  [2793] = {.lex_state = 6},
  [2794] = {.lex_state = 4},
  [2795] = {.lex_state = 130},
  [2796] = {.lex_state = 6},
  [2797] = {.lex_state = 5},
  [2798] = {.lex_state = 5},
  [2799] = {.lex_state = 4, .external_lex_state = 4},
  [2800] = {.lex_state = 130},
  [2801] = {.lex_state = 5},
  [2802] = {.lex_state = 5},
  [2803] = {.lex_state = 4, .external_lex_state = 4},
  [2804] = {.lex_state = 4, .external_lex_state = 4},
  [2805] = {.lex_state = 130},
  [2806] = {.lex_state = 5},
  [2807] = {.lex_state = 4, .external_lex_state = 4},
  [2808] = {.lex_state = 5, .external_lex_state = 4},
  [2809] = {.lex_state = 130},
  [2810] = {.lex_state = 4},
  [2811] = {.lex_state = 4},
  [2812] = {.lex_state = 5},
  [2813] = {.lex_state = 130},
  [2814] = {.lex_state = 130},
  [2815] = {.lex_state = 131},
  [2816] = {.lex_state = 5},
  [2817] = {.lex_state = 131},
  [2818] = {.lex_state = 5, .external_lex_state = 4},
  [2819] = {.lex_state = 5},
  [2820] = {.lex_state = 5, .external_lex_state = 4},
  [2821] = {.lex_state = 5, .external_lex_state = 4},
  [2822] = {.lex_state = 5, .external_lex_state = 4},
  [2823] = {.lex_state = 4},
  [2824] = {.lex_state = 4, .external_lex_state = 4},
  [2825] = {.lex_state = 5, .external_lex_state = 4},
  [2826] = {.lex_state = 5, .external_lex_state = 4},
  [2827] = {.lex_state = 4},
  [2828] = {.lex_state = 4},
  [2829] = {.lex_state = 5},
  [2830] = {.lex_state = 5, .external_lex_state = 4},
  [2831] = {.lex_state = 5, .external_lex_state = 4},
  [2832] = {.lex_state = 5, .external_lex_state = 4},
  [2833] = {.lex_state = 5, .external_lex_state = 4},
  [2834] = {.lex_state = 5},
  [2835] = {.lex_state = 4},
  [2836] = {.lex_state = 5, .external_lex_state = 4},
  [2837] = {.lex_state = 5, .external_lex_state = 4},
  [2838] = {.lex_state = 5},
  [2839] = {.lex_state = 5, .external_lex_state = 4},
  [2840] = {.lex_state = 130},
  [2841] = {.lex_state = 4},
  [2842] = {.lex_state = 130},
  [2843] = {.lex_state = 4},
  [2844] = {.lex_state = 5},
  [2845] = {.lex_state = 4},
  [2846] = {.lex_state = 5},
  [2847] = {.lex_state = 4},
  [2848] = {.lex_state = 131},
  [2849] = {.lex_state = 4},
  [2850] = {.lex_state = 5},
  [2851] = {.lex_state = 5},
  [2852] = {.lex_state = 5},
  [2853] = {.lex_state = 5},
  [2854] = {.lex_state = 130},
  [2855] = {.lex_state = 130},
  [2856] = {.lex_state = 6},
  [2857] = {.lex_state = 131},
  [2858] = {.lex_state = 130},
  [2859] = {.lex_state = 4},
  [2860] = {.lex_state = 5},
  [2861] = {.lex_state = 5, .external_lex_state = 4},
  [2862] = {.lex_state = 5},
  [2863] = {.lex_state = 5, .external_lex_state = 4},
  [2864] = {.lex_state = 5},
  [2865] = {.lex_state = 5},
  [2866] = {.lex_state = 5, .external_lex_state = 4},
  [2867] = {.lex_state = 4},
  [2868] = {.lex_state = 5},
  [2869] = {.lex_state = 130},
  [2870] = {.lex_state = 6, .external_lex_state = 4},
  [2871] = {.lex_state = 130},
  [2872] = {.lex_state = 4},
  [2873] = {.lex_state = 5, .external_lex_state = 4},
  [2874] = {.lex_state = 130},
  [2875] = {.lex_state = 4},
  [2876] = {.lex_state = 4},
  [2877] = {.lex_state = 4},
  [2878] = {.lex_state = 4},
  [2879] = {.lex_state = 130},
  [2880] = {.lex_state = 4},
  [2881] = {.lex_state = 130},
  [2882] = {.lex_state = 4},
  [2883] = {.lex_state = 130},
  [2884] = {.lex_state = 6, .external_lex_state = 4},
  [2885] = {.lex_state = 130},
  [2886] = {.lex_state = 130},
  [2887] = {.lex_state = 130},
  [2888] = {.lex_state = 130},
  [2889] = {.lex_state = 5},
  [2890] = {.lex_state = 4},
  [2891] = {.lex_state = 4},
  [2892] = {.lex_state = 4},
  [2893] = {.lex_state = 4},
  [2894] = {.lex_state = 4},
  [2895] = {.lex_state = 4},
  [2896] = {.lex_state = 6, .external_lex_state = 4},
  [2897] = {.lex_state = 4},
  [2898] = {.lex_state = 130},
  [2899] = {.lex_state = 4},
  [2900] = {.lex_state = 4},
  [2901] = {.lex_state = 4},
  [2902] = {.lex_state = 130},
  [2903] = {.lex_state = 130},
  [2904] = {.lex_state = 4},
  [2905] = {.lex_state = 5},
  [2906] = {.lex_state = 130},
  [2907] = {.lex_state = 4},
  [2908] = {.lex_state = 4},
  [2909] = {.lex_state = 130},
  [2910] = {.lex_state = 5},
  [2911] = {.lex_state = 4},
  [2912] = {.lex_state = 5},
  [2913] = {.lex_state = 130},
  [2914] = {.lex_state = 130},
  [2915] = {.lex_state = 4},
  [2916] = {.lex_state = 4},
  [2917] = {.lex_state = 4},
  [2918] = {.lex_state = 4},
  [2919] = {.lex_state = 131},
  [2920] = {.lex_state = 6},
  [2921] = {.lex_state = 131},
  [2922] = {.lex_state = 6},
  [2923] = {.lex_state = 131},
  [2924] = {.lex_state = 6},
  [2925] = {.lex_state = 6},
  [2926] = {.lex_state = 6},
  [2927] = {.lex_state = 6},
  [2928] = {.lex_state = 6},
  [2929] = {.lex_state = 131},
  [2930] = {.lex_state = 4},
  [2931] = {.lex_state = 131},
  [2932] = {.lex_state = 4},
  [2933] = {.lex_state = 4},
  [2934] = {.lex_state = 4},
  [2935] = {.lex_state = 131},
  [2936] = {.lex_state = 131},
  [2937] = {.lex_state = 131},
  [2938] = {.lex_state = 130},
  [2939] = {.lex_state = 4},
  [2940] = {.lex_state = 4},
  [2941] = {.lex_state = 130},
  [2942] = {.lex_state = 4},
  [2943] = {.lex_state = 6},
  [2944] = {.lex_state = 130},
  [2945] = {.lex_state = 130},
  [2946] = {.lex_state = 6},
  [2947] = {.lex_state = 130},
  [2948] = {.lex_state = 130},
  [2949] = {.lex_state = 4},
  [2950] = {.lex_state = 4},
  [2951] = {.lex_state = 4},
  [2952] = {.lex_state = 130},
  [2953] = {.lex_state = 5},
  [2954] = {.lex_state = 4},
  [2955] = {.lex_state = 4},
  [2956] = {.lex_state = 130},
  [2957] = {.lex_state = 130},
  [2958] = {.lex_state = 131},
  [2959] = {.lex_state = 130, .external_lex_state = 4},
  [2960] = {.lex_state = 4},
  [2961] = {.lex_state = 130},
  [2962] = {.lex_state = 130},
  [2963] = {.lex_state = 130},
  [2964] = {.lex_state = 130, .external_lex_state = 4},
  [2965] = {.lex_state = 131},
  [2966] = {.lex_state = 130},
  [2967] = {.lex_state = 4},
  [2968] = {.lex_state = 130},
  [2969] = {.lex_state = 130},
  [2970] = {.lex_state = 130},
  [2971] = {.lex_state = 130},
  [2972] = {.lex_state = 130},
  [2973] = {.lex_state = 130},
  [2974] = {.lex_state = 130, .external_lex_state = 4},
  [2975] = {.lex_state = 4},
  [2976] = {.lex_state = 130, .external_lex_state = 4},
  [2977] = {.lex_state = 4},
  [2978] = {.lex_state = 130},
  [2979] = {.lex_state = 6},
  [2980] = {.lex_state = 130, .external_lex_state = 4},
  [2981] = {.lex_state = 130},
  [2982] = {.lex_state = 4},
  [2983] = {.lex_state = 4},
  [2984] = {.lex_state = 4},
  [2985] = {.lex_state = 130, .external_lex_state = 4},
  [2986] = {.lex_state = 4},
  [2987] = {.lex_state = 130},
  [2988] = {.lex_state = 130},
  [2989] = {.lex_state = 6},
  [2990] = {.lex_state = 5},
  [2991] = {.lex_state = 6},
  [2992] = {.lex_state = 130},
  [2993] = {.lex_state = 6},
  [2994] = {.lex_state = 130},
  [2995] = {.lex_state = 130},
  [2996] = {.lex_state = 130},
  [2997] = {.lex_state = 6},
  [2998] = {.lex_state = 6},
  [2999] = {.lex_state = 130},
  [3000] = {.lex_state = 130},
  [3001] = {.lex_state = 5},
  [3002] = {.lex_state = 5},
  [3003] = {.lex_state = 5},
  [3004] = {.lex_state = 130},
  [3005] = {.lex_state = 5},
  [3006] = {.lex_state = 6},
  [3007] = {.lex_state = 5},
  [3008] = {.lex_state = 5},
  [3009] = {.lex_state = 5},
  [3010] = {.lex_state = 5},
  [3011] = {.lex_state = 6},
  [3012] = {.lex_state = 5},
  [3013] = {.lex_state = 6},
  [3014] = {.lex_state = 130},
  [3015] = {.lex_state = 130},
  [3016] = {.lex_state = 5},
  [3017] = {.lex_state = 5},
  [3018] = {.lex_state = 5},
  [3019] = {.lex_state = 5},
  [3020] = {.lex_state = 5},
  [3021] = {.lex_state = 5},
  [3022] = {.lex_state = 5},
  [3023] = {.lex_state = 5},
  [3024] = {.lex_state = 130},
  [3025] = {.lex_state = 130},
  [3026] = {.lex_state = 5},
  [3027] = {.lex_state = 5},
  [3028] = {.lex_state = 130},
  [3029] = {.lex_state = 130},
  [3030] = {.lex_state = 5},
  [3031] = {.lex_state = 130},
  [3032] = {.lex_state = 130},
  [3033] = {.lex_state = 5},
  [3034] = {.lex_state = 130},
  [3035] = {.lex_state = 130},
  [3036] = {.lex_state = 130},
  [3037] = {.lex_state = 130},
  [3038] = {.lex_state = 130},
  [3039] = {.lex_state = 130},
  [3040] = {.lex_state = 130},
  [3041] = {.lex_state = 130},
  [3042] = {.lex_state = 130},
  [3043] = {.lex_state = 130},
  [3044] = {.lex_state = 130},
  [3045] = {.lex_state = 130},
  [3046] = {.lex_state = 5},
  [3047] = {.lex_state = 130},
  [3048] = {.lex_state = 130},
  [3049] = {.lex_state = 5},
  [3050] = {.lex_state = 5},
  [3051] = {.lex_state = 130},
  [3052] = {.lex_state = 130},
  [3053] = {.lex_state = 130},
  [3054] = {.lex_state = 5},
  [3055] = {.lex_state = 130},
  [3056] = {.lex_state = 5},
  [3057] = {.lex_state = 130},
  [3058] = {.lex_state = 130},
  [3059] = {.lex_state = 130},
  [3060] = {.lex_state = 130},
  [3061] = {.lex_state = 130},
  [3062] = {.lex_state = 130},
  [3063] = {.lex_state = 130},
  [3064] = {.lex_state = 130},
  [3065] = {.lex_state = 130},
  [3066] = {.lex_state = 6},
  [3067] = {.lex_state = 130},
  [3068] = {.lex_state = 130},
  [3069] = {.lex_state = 130},
  [3070] = {.lex_state = 130},
  [3071] = {.lex_state = 6},
  [3072] = {.lex_state = 130},
  [3073] = {.lex_state = 130},
  [3074] = {.lex_state = 130},
  [3075] = {.lex_state = 6},
  [3076] = {.lex_state = 130, .external_lex_state = 4},
  [3077] = {.lex_state = 130},
  [3078] = {.lex_state = 130},
  [3079] = {.lex_state = 130},
  [3080] = {.lex_state = 6},
  [3081] = {.lex_state = 130, .external_lex_state = 4},
  [3082] = {.lex_state = 130},
  [3083] = {.lex_state = 130},
  [3084] = {.lex_state = 130, .external_lex_state = 4},
  [3085] = {.lex_state = 130, .external_lex_state = 4},
  [3086] = {.lex_state = 6},
  [3087] = {.lex_state = 130},
  [3088] = {.lex_state = 130},
  [3089] = {.lex_state = 130},
  [3090] = {.lex_state = 130},
  [3091] = {.lex_state = 6},
  [3092] = {.lex_state = 131},
  [3093] = {.lex_state = 131},
  [3094] = {.lex_state = 131},
  [3095] = {.lex_state = 131},
  [3096] = {.lex_state = 130, .external_lex_state = 4},
  [3097] = {.lex_state = 131},
  [3098] = {.lex_state = 131},
  [3099] = {.lex_state = 131},
  [3100] = {.lex_state = 131},
  [3101] = {.lex_state = 131},
  [3102] = {.lex_state = 131},
  [3103] = {.lex_state = 130},
  [3104] = {.lex_state = 131},
  [3105] = {.lex_state = 131},
  [3106] = {.lex_state = 130},
  [3107] = {.lex_state = 131},
  [3108] = {.lex_state = 131},
  [3109] = {.lex_state = 131},
  [3110] = {.lex_state = 131},
  [3111] = {.lex_state = 130},
  [3112] = {.lex_state = 131},
  [3113] = {.lex_state = 131},
  [3114] = {.lex_state = 131},
  [3115] = {.lex_state = 131},
  [3116] = {.lex_state = 131},
  [3117] = {.lex_state = 131},
  [3118] = {.lex_state = 131},
  [3119] = {.lex_state = 131},
  [3120] = {.lex_state = 130},
  [3121] = {.lex_state = 130, .external_lex_state = 4},
  [3122] = {.lex_state = 130, .external_lex_state = 4},
  [3123] = {.lex_state = 6},
  [3124] = {.lex_state = 130},
  [3125] = {.lex_state = 131},
  [3126] = {.lex_state = 131},
  [3127] = {.lex_state = 130},
  [3128] = {.lex_state = 130},
  [3129] = {.lex_state = 130, .external_lex_state = 4},
  [3130] = {.lex_state = 130},
  [3131] = {.lex_state = 130},
  [3132] = {.lex_state = 130, .external_lex_state = 4},
  [3133] = {.lex_state = 131},
  [3134] = {.lex_state = 131},
  [3135] = {.lex_state = 130, .external_lex_state = 4},
  [3136] = {.lex_state = 130, .external_lex_state = 4},
  [3137] = {.lex_state = 130, .external_lex_state = 4},
  [3138] = {.lex_state = 130},
  [3139] = {.lex_state = 130, .external_lex_state = 4},
  [3140] = {.lex_state = 130},
  [3141] = {.lex_state = 130},
  [3142] = {.lex_state = 130},
  [3143] = {.lex_state = 130},
  [3144] = {.lex_state = 130},
  [3145] = {.lex_state = 5},
  [3146] = {.lex_state = 130},
  [3147] = {.lex_state = 130},
  [3148] = {.lex_state = 130},
  [3149] = {.lex_state = 130},
  [3150] = {.lex_state = 5},
  [3151] = {.lex_state = 130},
  [3152] = {.lex_state = 131},
  [3153] = {.lex_state = 130},
  [3154] = {.lex_state = 130},
  [3155] = {.lex_state = 130},
  [3156] = {.lex_state = 130},
  [3157] = {.lex_state = 130},
  [3158] = {.lex_state = 6, .external_lex_state = 4},
  [3159] = {.lex_state = 130},
  [3160] = {.lex_state = 131},
  [3161] = {.lex_state = 130},
  [3162] = {.lex_state = 130},
  [3163] = {.lex_state = 130},
  [3164] = {.lex_state = 130},
  [3165] = {.lex_state = 5},
  [3166] = {.lex_state = 131},
  [3167] = {.lex_state = 130},
  [3168] = {.lex_state = 130},
  [3169] = {.lex_state = 130},
  [3170] = {.lex_state = 130},
  [3171] = {.lex_state = 130},
  [3172] = {.lex_state = 130},
  [3173] = {.lex_state = 130},
  [3174] = {.lex_state = 131},
  [3175] = {.lex_state = 5},
  [3176] = {.lex_state = 131},
  [3177] = {.lex_state = 5},
  [3178] = {.lex_state = 6, .external_lex_state = 4},
  [3179] = {.lex_state = 6, .external_lex_state = 4},
  [3180] = {.lex_state = 5},
  [3181] = {.lex_state = 5},
  [3182] = {.lex_state = 131},
  [3183] = {.lex_state = 130},
  [3184] = {.lex_state = 130},
  [3185] = {.lex_state = 130},
  [3186] = {.lex_state = 6, .external_lex_state = 4},
  [3187] = {.lex_state = 5},
  [3188] = {.lex_state = 5},
  [3189] = {.lex_state = 5},
  [3190] = {.lex_state = 5},
  [3191] = {.lex_state = 5},
  [3192] = {.lex_state = 130},
  [3193] = {.lex_state = 5},
  [3194] = {.lex_state = 5},
  [3195] = {.lex_state = 5},
  [3196] = {.lex_state = 130, .external_lex_state = 4},
  [3197] = {.lex_state = 130},
  [3198] = {.lex_state = 131},
  [3199] = {.lex_state = 130},
  [3200] = {.lex_state = 130, .external_lex_state = 4},
  [3201] = {.lex_state = 131},
  [3202] = {.lex_state = 131},
  [3203] = {.lex_state = 130, .external_lex_state = 4},
  [3204] = {.lex_state = 130},
  [3205] = {.lex_state = 5},
  [3206] = {.lex_state = 5},
  [3207] = {.lex_state = 130},
  [3208] = {.lex_state = 5},
  [3209] = {.lex_state = 130},
  [3210] = {.lex_state = 5},
  [3211] = {.lex_state = 130},
  [3212] = {.lex_state = 130},
  [3213] = {.lex_state = 5},
  [3214] = {.lex_state = 5},
  [3215] = {.lex_state = 131},
  [3216] = {.lex_state = 5},
  [3217] = {.lex_state = 130},
  [3218] = {.lex_state = 131},
  [3219] = {.lex_state = 130},
  [3220] = {.lex_state = 5},
  [3221] = {.lex_state = 5},
  [3222] = {.lex_state = 130},
  [3223] = {.lex_state = 130},
  [3224] = {.lex_state = 130},
  [3225] = {.lex_state = 130},
  [3226] = {.lex_state = 130},
  [3227] = {.lex_state = 131},
  [3228] = {.lex_state = 131},
  [3229] = {.lex_state = 130, .external_lex_state = 4},
  [3230] = {.lex_state = 131},
  [3231] = {.lex_state = 131},
  [3232] = {.lex_state = 131},
  [3233] = {.lex_state = 131},
  [3234] = {.lex_state = 130, .external_lex_state = 4},
  [3235] = {.lex_state = 131},
  [3236] = {.lex_state = 130, .external_lex_state = 4},
  [3237] = {.lex_state = 5},
  [3238] = {.lex_state = 131},
  [3239] = {.lex_state = 130, .external_lex_state = 4},
  [3240] = {.lex_state = 130, .external_lex_state = 4},
  [3241] = {.lex_state = 131},
  [3242] = {.lex_state = 131},
  [3243] = {.lex_state = 131},
  [3244] = {.lex_state = 5},
  [3245] = {.lex_state = 130, .external_lex_state = 4},
  [3246] = {.lex_state = 131},
  [3247] = {.lex_state = 131},
  [3248] = {.lex_state = 131},
  [3249] = {.lex_state = 131},
  [3250] = {.lex_state = 131},
  [3251] = {.lex_state = 131},
  [3252] = {.lex_state = 131},
  [3253] = {.lex_state = 131},
  [3254] = {.lex_state = 131},
  [3255] = {.lex_state = 131},
  [3256] = {.lex_state = 131},
  [3257] = {.lex_state = 131},
  [3258] = {.lex_state = 131},
  [3259] = {.lex_state = 131},
  [3260] = {.lex_state = 131},
  [3261] = {.lex_state = 131},
  [3262] = {.lex_state = 131},
  [3263] = {.lex_state = 131},
  [3264] = {.lex_state = 131},
  [3265] = {.lex_state = 131},
  [3266] = {.lex_state = 131},
  [3267] = {.lex_state = 5},
  [3268] = {.lex_state = 131},
  [3269] = {.lex_state = 131},
  [3270] = {.lex_state = 131},
  [3271] = {.lex_state = 131},
  [3272] = {.lex_state = 130, .external_lex_state = 4},
  [3273] = {.lex_state = 130},
  [3274] = {.lex_state = 131},
  [3275] = {.lex_state = 131},
  [3276] = {.lex_state = 131},
  [3277] = {.lex_state = 131},
  [3278] = {.lex_state = 130},
  [3279] = {.lex_state = 130},
  [3280] = {.lex_state = 131},
  [3281] = {.lex_state = 131},
  [3282] = {.lex_state = 131},
  [3283] = {.lex_state = 131},
  [3284] = {.lex_state = 131},
  [3285] = {.lex_state = 131},
  [3286] = {.lex_state = 131},
  [3287] = {.lex_state = 130},
  [3288] = {.lex_state = 131},
  [3289] = {.lex_state = 131},
  [3290] = {.lex_state = 131},
  [3291] = {.lex_state = 131},
  [3292] = {.lex_state = 131},
  [3293] = {.lex_state = 131},
  [3294] = {.lex_state = 131},
  [3295] = {.lex_state = 131},
  [3296] = {.lex_state = 131},
  [3297] = {.lex_state = 131},
  [3298] = {.lex_state = 5},
  [3299] = {.lex_state = 131},
  [3300] = {.lex_state = 131},
  [3301] = {.lex_state = 131},
  [3302] = {.lex_state = 131},
  [3303] = {.lex_state = 131},
  [3304] = {.lex_state = 131},
  [3305] = {.lex_state = 131},
  [3306] = {.lex_state = 131},
  [3307] = {.lex_state = 131},
  [3308] = {.lex_state = 131},
  [3309] = {.lex_state = 131},
  [3310] = {.lex_state = 131},
  [3311] = {.lex_state = 131},
  [3312] = {.lex_state = 131},
  [3313] = {.lex_state = 131},
  [3314] = {.lex_state = 131},
  [3315] = {.lex_state = 131},
  [3316] = {.lex_state = 131},
  [3317] = {.lex_state = 131},
  [3318] = {.lex_state = 131},
  [3319] = {.lex_state = 131},
  [3320] = {.lex_state = 131},
  [3321] = {.lex_state = 131},
  [3322] = {.lex_state = 131},
  [3323] = {.lex_state = 130, .external_lex_state = 4},
  [3324] = {.lex_state = 131},
  [3325] = {.lex_state = 131},
  [3326] = {.lex_state = 130, .external_lex_state = 4},
  [3327] = {.lex_state = 131},
  [3328] = {.lex_state = 130, .external_lex_state = 4},
  [3329] = {.lex_state = 5},
  [3330] = {.lex_state = 130, .external_lex_state = 4},
  [3331] = {.lex_state = 130, .external_lex_state = 4},
  [3332] = {.lex_state = 131},
  [3333] = {.lex_state = 131},
  [3334] = {.lex_state = 131},
  [3335] = {.lex_state = 131},
  [3336] = {.lex_state = 131},
  [3337] = {.lex_state = 131},
  [3338] = {.lex_state = 131},
  [3339] = {.lex_state = 131},
  [3340] = {.lex_state = 131},
  [3341] = {.lex_state = 131},
  [3342] = {.lex_state = 131},
  [3343] = {.lex_state = 130, .external_lex_state = 4},
  [3344] = {.lex_state = 130, .external_lex_state = 4},
  [3345] = {.lex_state = 131},
  [3346] = {.lex_state = 131},
  [3347] = {.lex_state = 131},
  [3348] = {.lex_state = 131},
  [3349] = {.lex_state = 131},
  [3350] = {.lex_state = 131},
  [3351] = {.lex_state = 131},
  [3352] = {.lex_state = 131},
  [3353] = {.lex_state = 131},
  [3354] = {.lex_state = 131},
  [3355] = {.lex_state = 131},
  [3356] = {.lex_state = 131},
  [3357] = {.lex_state = 131},
  [3358] = {.lex_state = 131},
  [3359] = {.lex_state = 131},
  [3360] = {.lex_state = 130},
  [3361] = {.lex_state = 130},
  [3362] = {.lex_state = 130},
  [3363] = {.lex_state = 130},
  [3364] = {.lex_state = 131},
  [3365] = {.lex_state = 130, .external_lex_state = 4},
  [3366] = {.lex_state = 131},
  [3367] = {.lex_state = 131},
  [3368] = {.lex_state = 130, .external_lex_state = 4},
  [3369] = {.lex_state = 130, .external_lex_state = 4},
  [3370] = {.lex_state = 130, .external_lex_state = 4},
  [3371] = {.lex_state = 131},
  [3372] = {.lex_state = 131},
  [3373] = {.lex_state = 130},
  [3374] = {.lex_state = 130},
  [3375] = {.lex_state = 130},
  [3376] = {.lex_state = 130},
  [3377] = {.lex_state = 130, .external_lex_state = 4},
  [3378] = {.lex_state = 131},
  [3379] = {.lex_state = 131},
  [3380] = {.lex_state = 130},
  [3381] = {.lex_state = 130},
  [3382] = {.lex_state = 130},
  [3383] = {.lex_state = 131},
  [3384] = {.lex_state = 130},
  [3385] = {.lex_state = 130, .external_lex_state = 4},
  [3386] = {.lex_state = 130, .external_lex_state = 4},
  [3387] = {.lex_state = 131},
  [3388] = {.lex_state = 131},
  [3389] = {.lex_state = 131},
  [3390] = {.lex_state = 131},
  [3391] = {.lex_state = 131},
  [3392] = {.lex_state = 131},
  [3393] = {.lex_state = 5},
  [3394] = {.lex_state = 131},
  [3395] = {.lex_state = 130, .external_lex_state = 4},
  [3396] = {.lex_state = 131},
  [3397] = {.lex_state = 131},
  [3398] = {.lex_state = 131},
  [3399] = {.lex_state = 131},
  [3400] = {.lex_state = 131},
  [3401] = {.lex_state = 131},
  [3402] = {.lex_state = 131},
  [3403] = {.lex_state = 131},
  [3404] = {.lex_state = 131},
  [3405] = {.lex_state = 131},
  [3406] = {.lex_state = 131},
  [3407] = {.lex_state = 130},
  [3408] = {.lex_state = 130, .external_lex_state = 4},
  [3409] = {.lex_state = 130},
  [3410] = {.lex_state = 130},
  [3411] = {.lex_state = 130},
  [3412] = {.lex_state = 131},
  [3413] = {.lex_state = 131},
  [3414] = {.lex_state = 131},
  [3415] = {.lex_state = 131},
  [3416] = {.lex_state = 131},
  [3417] = {.lex_state = 131},
  [3418] = {.lex_state = 131},
  [3419] = {.lex_state = 131},
  [3420] = {.lex_state = 131},
  [3421] = {.lex_state = 131},
  [3422] = {.lex_state = 130},
  [3423] = {.lex_state = 131},
  [3424] = {.lex_state = 130},
  [3425] = {.lex_state = 130},
  [3426] = {.lex_state = 130},
  [3427] = {.lex_state = 131},
  [3428] = {.lex_state = 130},
  [3429] = {.lex_state = 130},
  [3430] = {.lex_state = 130},
  [3431] = {.lex_state = 131},
  [3432] = {.lex_state = 130},
  [3433] = {.lex_state = 131},
  [3434] = {.lex_state = 131},
  [3435] = {.lex_state = 130},
  [3436] = {.lex_state = 131},
  [3437] = {.lex_state = 131},
  [3438] = {.lex_state = 5},
  [3439] = {.lex_state = 131},
  [3440] = {.lex_state = 131},
  [3441] = {.lex_state = 131},
  [3442] = {.lex_state = 130},
  [3443] = {.lex_state = 130},
  [3444] = {.lex_state = 5},
  [3445] = {.lex_state = 130, .external_lex_state = 4},
  [3446] = {.lex_state = 131},
  [3447] = {.lex_state = 131},
  [3448] = {.lex_state = 131},
  [3449] = {.lex_state = 131},
  [3450] = {.lex_state = 131},
  [3451] = {.lex_state = 131},
  [3452] = {.lex_state = 131},
  [3453] = {.lex_state = 131},
  [3454] = {.lex_state = 131},
  [3455] = {.lex_state = 130},
  [3456] = {.lex_state = 5},
  [3457] = {.lex_state = 130, .external_lex_state = 4},
  [3458] = {.lex_state = 131},
  [3459] = {.lex_state = 130, .external_lex_state = 4},
  [3460] = {.lex_state = 131},
  [3461] = {.lex_state = 131},
  [3462] = {.lex_state = 131},
  [3463] = {.lex_state = 131},
  [3464] = {.lex_state = 131},
  [3465] = {.lex_state = 130, .external_lex_state = 4},
  [3466] = {.lex_state = 131},
  [3467] = {.lex_state = 131},
  [3468] = {.lex_state = 131},
  [3469] = {.lex_state = 131},
  [3470] = {.lex_state = 131},
  [3471] = {.lex_state = 131},
  [3472] = {.lex_state = 131},
  [3473] = {.lex_state = 131},
  [3474] = {.lex_state = 131},
  [3475] = {.lex_state = 131},
  [3476] = {.lex_state = 130, .external_lex_state = 4},
  [3477] = {.lex_state = 131},
  [3478] = {.lex_state = 131},
  [3479] = {.lex_state = 131},
  [3480] = {.lex_state = 5},
  [3481] = {.lex_state = 131},
  [3482] = {.lex_state = 5},
  [3483] = {.lex_state = 130, .external_lex_state = 4},
  [3484] = {.lex_state = 5},
  [3485] = {.lex_state = 130, .external_lex_state = 4},
  [3486] = {.lex_state = 130, .external_lex_state = 4},
  [3487] = {.lex_state = 131},
  [3488] = {.lex_state = 130, .external_lex_state = 4},
  [3489] = {.lex_state = 130, .external_lex_state = 4},
  [3490] = {.lex_state = 130, .external_lex_state = 4},
  [3491] = {.lex_state = 131},
  [3492] = {.lex_state = 131},
  [3493] = {.lex_state = 131},
  [3494] = {.lex_state = 131},
  [3495] = {.lex_state = 131},
  [3496] = {.lex_state = 131},
  [3497] = {.lex_state = 131},
  [3498] = {.lex_state = 131},
  [3499] = {.lex_state = 130, .external_lex_state = 4},
  [3500] = {.lex_state = 5},
  [3501] = {.lex_state = 130, .external_lex_state = 4},
  [3502] = {.lex_state = 131},
  [3503] = {.lex_state = 131},
  [3504] = {.lex_state = 131},
  [3505] = {.lex_state = 131},
  [3506] = {.lex_state = 131},
  [3507] = {.lex_state = 5},
  [3508] = {.lex_state = 131},
  [3509] = {.lex_state = 131},
  [3510] = {.lex_state = 131},
  [3511] = {.lex_state = 131},
  [3512] = {.lex_state = 131},
  [3513] = {.lex_state = 131},
  [3514] = {.lex_state = 131},
  [3515] = {.lex_state = 131},
  [3516] = {.lex_state = 131},
  [3517] = {.lex_state = 131},
  [3518] = {.lex_state = 131},
  [3519] = {.lex_state = 131},
  [3520] = {.lex_state = 131},
  [3521] = {.lex_state = 131},
  [3522] = {.lex_state = 5},
  [3523] = {.lex_state = 131},
  [3524] = {.lex_state = 5},
  [3525] = {.lex_state = 131},
  [3526] = {.lex_state = 131},
  [3527] = {.lex_state = 131},
  [3528] = {.lex_state = 130, .external_lex_state = 4},
  [3529] = {.lex_state = 130, .external_lex_state = 4},
  [3530] = {.lex_state = 130, .external_lex_state = 4},
  [3531] = {.lex_state = 130, .external_lex_state = 4},
  [3532] = {.lex_state = 130, .external_lex_state = 4},
  [3533] = {.lex_state = 130, .external_lex_state = 4},
  [3534] = {.lex_state = 130},
  [3535] = {.lex_state = 130},
  [3536] = {.lex_state = 130},
  [3537] = {.lex_state = 130},
  [3538] = {.lex_state = 130},
  [3539] = {.lex_state = 130},
  [3540] = {.lex_state = 130},
  [3541] = {.lex_state = 130},
  [3542] = {.lex_state = 130},
  [3543] = {.lex_state = 130},
  [3544] = {.lex_state = 130},
  [3545] = {.lex_state = 130},
  [3546] = {.lex_state = 130},
  [3547] = {.lex_state = 130},
  [3548] = {.lex_state = 130},
  [3549] = {.lex_state = 130},
  [3550] = {.lex_state = 5},
  [3551] = {.lex_state = 130},
  [3552] = {.lex_state = 130},
  [3553] = {.lex_state = 5},
  [3554] = {.lex_state = 130},
  [3555] = {.lex_state = 130},
  [3556] = {.lex_state = 5},
  [3557] = {.lex_state = 130},
  [3558] = {.lex_state = 5},
  [3559] = {.lex_state = 130},
  [3560] = {.lex_state = 130},
  [3561] = {.lex_state = 130},
  [3562] = {.lex_state = 130},
  [3563] = {.lex_state = 4},
  [3564] = {.lex_state = 4},
  [3565] = {.lex_state = 4},
  [3566] = {.lex_state = 4},
  [3567] = {.lex_state = 130},
  [3568] = {.lex_state = 130},
  [3569] = {.lex_state = 4},
  [3570] = {.lex_state = 4},
  [3571] = {.lex_state = 130},
  [3572] = {.lex_state = 6},
  [3573] = {.lex_state = 6},
  [3574] = {.lex_state = 131},
  [3575] = {.lex_state = 131},
  [3576] = {.lex_state = 130},
  [3577] = {.lex_state = 4},
  [3578] = {.lex_state = 6},
  [3579] = {.lex_state = 4},
  [3580] = {.lex_state = 131},
  [3581] = {.lex_state = 131},
  [3582] = {.lex_state = 130},
  [3583] = {.lex_state = 4},
  [3584] = {.lex_state = 130},
  [3585] = {.lex_state = 4},
  [3586] = {.lex_state = 130},
  [3587] = {.lex_state = 130},
  [3588] = {.lex_state = 130},
  [3589] = {.lex_state = 130},
  [3590] = {.lex_state = 6},
  [3591] = {.lex_state = 130},
  [3592] = {.lex_state = 130},
  [3593] = {.lex_state = 130},
  [3594] = {.lex_state = 130},
  [3595] = {.lex_state = 130},
  [3596] = {.lex_state = 130},
  [3597] = {.lex_state = 130},
  [3598] = {.lex_state = 130},
  [3599] = {.lex_state = 130},
  [3600] = {.lex_state = 130},
  [3601] = {.lex_state = 130},
  [3602] = {.lex_state = 130},
  [3603] = {.lex_state = 130},
  [3604] = {.lex_state = 131},
  [3605] = {.lex_state = 4},
  [3606] = {.lex_state = 130},
  [3607] = {.lex_state = 130},
  [3608] = {.lex_state = 130},
  [3609] = {.lex_state = 130},
  [3610] = {.lex_state = 6},
  [3611] = {.lex_state = 130},
  [3612] = {.lex_state = 130},
  [3613] = {.lex_state = 6},
  [3614] = {.lex_state = 130},
  [3615] = {.lex_state = 130},
  [3616] = {.lex_state = 130},
  [3617] = {.lex_state = 130},
  [3618] = {.lex_state = 130},
  [3619] = {.lex_state = 130},
  [3620] = {.lex_state = 130},
  [3621] = {.lex_state = 130},
  [3622] = {.lex_state = 130},
  [3623] = {.lex_state = 130},
  [3624] = {.lex_state = 130},
  [3625] = {.lex_state = 6},
  [3626] = {.lex_state = 130},
  [3627] = {.lex_state = 7},
  [3628] = {.lex_state = 131},
  [3629] = {.lex_state = 131},
  [3630] = {.lex_state = 130},
  [3631] = {.lex_state = 130},
  [3632] = {.lex_state = 130},
  [3633] = {.lex_state = 130},
  [3634] = {.lex_state = 130},
  [3635] = {.lex_state = 130},
  [3636] = {.lex_state = 130},
  [3637] = {.lex_state = 130},
  [3638] = {.lex_state = 130},
  [3639] = {.lex_state = 130},
  [3640] = {.lex_state = 130},
  [3641] = {.lex_state = 130},
  [3642] = {.lex_state = 130},
  [3643] = {.lex_state = 130},
  [3644] = {.lex_state = 131},
  [3645] = {.lex_state = 130},
  [3646] = {.lex_state = 131},
  [3647] = {.lex_state = 130},
  [3648] = {.lex_state = 130},
  [3649] = {.lex_state = 130},
  [3650] = {.lex_state = 130},
  [3651] = {.lex_state = 130},
  [3652] = {.lex_state = 131},
  [3653] = {.lex_state = 130},
  [3654] = {.lex_state = 130},
  [3655] = {.lex_state = 130},
  [3656] = {.lex_state = 130},
  [3657] = {.lex_state = 130},
  [3658] = {.lex_state = 131},
  [3659] = {.lex_state = 130},
  [3660] = {.lex_state = 130},
  [3661] = {.lex_state = 130},
  [3662] = {.lex_state = 130},
  [3663] = {.lex_state = 130},
  [3664] = {.lex_state = 130},
  [3665] = {.lex_state = 130},
  [3666] = {.lex_state = 130},
  [3667] = {.lex_state = 130},
  [3668] = {.lex_state = 130},
  [3669] = {.lex_state = 130},
  [3670] = {.lex_state = 130},
  [3671] = {.lex_state = 130},
  [3672] = {.lex_state = 130},
  [3673] = {.lex_state = 130},
  [3674] = {.lex_state = 130},
  [3675] = {.lex_state = 130},
  [3676] = {.lex_state = 130},
  [3677] = {.lex_state = 130},
  [3678] = {.lex_state = 131},
  [3679] = {.lex_state = 130},
  [3680] = {.lex_state = 130},
  [3681] = {.lex_state = 130},
  [3682] = {.lex_state = 130},
  [3683] = {.lex_state = 130},
  [3684] = {.lex_state = 130},
  [3685] = {.lex_state = 130},
  [3686] = {.lex_state = 130},
  [3687] = {.lex_state = 130},
  [3688] = {.lex_state = 130},
  [3689] = {.lex_state = 130},
  [3690] = {.lex_state = 130},
  [3691] = {.lex_state = 130},
  [3692] = {.lex_state = 130},
  [3693] = {.lex_state = 130},
  [3694] = {.lex_state = 130},
  [3695] = {.lex_state = 130},
  [3696] = {.lex_state = 130},
  [3697] = {.lex_state = 130},
  [3698] = {.lex_state = 130},
  [3699] = {.lex_state = 130},
  [3700] = {.lex_state = 130},
  [3701] = {.lex_state = 130},
  [3702] = {.lex_state = 4},
  [3703] = {.lex_state = 130},
  [3704] = {.lex_state = 130},
  [3705] = {.lex_state = 130},
  [3706] = {.lex_state = 130},
  [3707] = {.lex_state = 130},
  [3708] = {.lex_state = 130},
  [3709] = {.lex_state = 130},
  [3710] = {.lex_state = 130},
  [3711] = {.lex_state = 130},
  [3712] = {.lex_state = 130},
  [3713] = {.lex_state = 130},
  [3714] = {.lex_state = 130},
  [3715] = {.lex_state = 130},
  [3716] = {.lex_state = 130},
  [3717] = {.lex_state = 130},
  [3718] = {.lex_state = 130},
  [3719] = {.lex_state = 130},
  [3720] = {.lex_state = 130},
  [3721] = {.lex_state = 130},
  [3722] = {.lex_state = 130},
  [3723] = {.lex_state = 130},
  [3724] = {.lex_state = 130},
  [3725] = {.lex_state = 130},
  [3726] = {.lex_state = 130},
  [3727] = {.lex_state = 130},
  [3728] = {.lex_state = 130},
  [3729] = {.lex_state = 130},
  [3730] = {.lex_state = 130},
  [3731] = {.lex_state = 130},
  [3732] = {.lex_state = 130},
  [3733] = {.lex_state = 131},
  [3734] = {.lex_state = 130},
  [3735] = {.lex_state = 130},
  [3736] = {.lex_state = 130},
  [3737] = {.lex_state = 131},
  [3738] = {.lex_state = 130},
  [3739] = {.lex_state = 4},
  [3740] = {.lex_state = 131},
  [3741] = {.lex_state = 130},
  [3742] = {.lex_state = 4},
  [3743] = {.lex_state = 130},
  [3744] = {.lex_state = 130},
  [3745] = {.lex_state = 130},
  [3746] = {.lex_state = 131},
  [3747] = {.lex_state = 130},
  [3748] = {.lex_state = 130},
  [3749] = {.lex_state = 130},
  [3750] = {.lex_state = 130},
  [3751] = {.lex_state = 130},
  [3752] = {.lex_state = 4},
  [3753] = {.lex_state = 131},
  [3754] = {.lex_state = 130},
  [3755] = {.lex_state = 130},
  [3756] = {.lex_state = 130},
  [3757] = {.lex_state = 130},
  [3758] = {.lex_state = 130},
  [3759] = {.lex_state = 130},
  [3760] = {.lex_state = 130},
  [3761] = {.lex_state = 130},
  [3762] = {.lex_state = 130},
  [3763] = {.lex_state = 130},
  [3764] = {.lex_state = 130},
  [3765] = {.lex_state = 130},
  [3766] = {.lex_state = 130},
  [3767] = {.lex_state = 130},
  [3768] = {.lex_state = 130},
  [3769] = {.lex_state = 130},
  [3770] = {.lex_state = 130},
  [3771] = {.lex_state = 130},
  [3772] = {.lex_state = 130},
  [3773] = {.lex_state = 130},
  [3774] = {.lex_state = 130},
  [3775] = {.lex_state = 130},
  [3776] = {.lex_state = 130},
  [3777] = {.lex_state = 130},
  [3778] = {.lex_state = 130},
  [3779] = {.lex_state = 131},
  [3780] = {.lex_state = 130},
  [3781] = {.lex_state = 130},
  [3782] = {.lex_state = 130},
  [3783] = {.lex_state = 130},
  [3784] = {.lex_state = 130},
  [3785] = {.lex_state = 130},
  [3786] = {.lex_state = 131},
  [3787] = {.lex_state = 130},
  [3788] = {.lex_state = 130},
  [3789] = {.lex_state = 4},
  [3790] = {.lex_state = 130},
  [3791] = {.lex_state = 130},
  [3792] = {.lex_state = 130},
  [3793] = {.lex_state = 130},
  [3794] = {.lex_state = 130},
  [3795] = {.lex_state = 4},
  [3796] = {.lex_state = 131},
  [3797] = {.lex_state = 5},
  [3798] = {.lex_state = 131},
  [3799] = {.lex_state = 131},
  [3800] = {.lex_state = 4},
  [3801] = {.lex_state = 5},
  [3802] = {.lex_state = 131},
  [3803] = {.lex_state = 131},
  [3804] = {.lex_state = 10},
  [3805] = {.lex_state = 131},
  [3806] = {.lex_state = 130},
  [3807] = {.lex_state = 131},
  [3808] = {.lex_state = 6},
  [3809] = {.lex_state = 131},
  [3810] = {.lex_state = 131},
  [3811] = {.lex_state = 131},
  [3812] = {.lex_state = 131},
  [3813] = {.lex_state = 4},
  [3814] = {.lex_state = 131},
  [3815] = {.lex_state = 131},
  [3816] = {.lex_state = 131},
  [3817] = {.lex_state = 131},
  [3818] = {.lex_state = 131},
  [3819] = {.lex_state = 131},
  [3820] = {.lex_state = 131},
  [3821] = {.lex_state = 131},
  [3822] = {.lex_state = 131},
  [3823] = {.lex_state = 131},
  [3824] = {.lex_state = 131},
  [3825] = {.lex_state = 131},
  [3826] = {.lex_state = 131},
  [3827] = {.lex_state = 131},
  [3828] = {.lex_state = 131},
  [3829] = {.lex_state = 131},
  [3830] = {.lex_state = 131},
  [3831] = {.lex_state = 131},
  [3832] = {.lex_state = 131},
  [3833] = {.lex_state = 131},
  [3834] = {.lex_state = 130},
  [3835] = {.lex_state = 131},
  [3836] = {.lex_state = 130},
  [3837] = {.lex_state = 131},
  [3838] = {.lex_state = 130},
  [3839] = {.lex_state = 131},
  [3840] = {.lex_state = 131},
  [3841] = {.lex_state = 131},
  [3842] = {.lex_state = 131},
  [3843] = {.lex_state = 131},
  [3844] = {.lex_state = 131},
  [3845] = {.lex_state = 131},
  [3846] = {.lex_state = 131},
  [3847] = {.lex_state = 131},
  [3848] = {.lex_state = 131},
  [3849] = {.lex_state = 131},
  [3850] = {.lex_state = 130},
  [3851] = {.lex_state = 130},
  [3852] = {.lex_state = 130},
  [3853] = {.lex_state = 131},
  [3854] = {.lex_state = 131},
  [3855] = {.lex_state = 131},
  [3856] = {.lex_state = 131},
  [3857] = {.lex_state = 4},
  [3858] = {.lex_state = 131},
  [3859] = {.lex_state = 131},
  [3860] = {.lex_state = 5, .external_lex_state = 4},
  [3861] = {.lex_state = 131},
  [3862] = {.lex_state = 5},
  [3863] = {.lex_state = 130},
  [3864] = {.lex_state = 131},
  [3865] = {.lex_state = 131},
  [3866] = {.lex_state = 130},
  [3867] = {.lex_state = 130},
  [3868] = {.lex_state = 5},
  [3869] = {.lex_state = 6},
  [3870] = {.lex_state = 131},
  [3871] = {.lex_state = 6},
  [3872] = {.lex_state = 131},
  [3873] = {.lex_state = 6},
  [3874] = {.lex_state = 131},
  [3875] = {.lex_state = 131},
  [3876] = {.lex_state = 131},
  [3877] = {.lex_state = 131},
  [3878] = {.lex_state = 131},
  [3879] = {.lex_state = 131},
  [3880] = {.lex_state = 130},
  [3881] = {.lex_state = 130},
  [3882] = {.lex_state = 5, .external_lex_state = 4},
  [3883] = {.lex_state = 130},
  [3884] = {.lex_state = 5, .external_lex_state = 4},
  [3885] = {.lex_state = 130},
  [3886] = {.lex_state = 5, .external_lex_state = 4},
  [3887] = {.lex_state = 130},
  [3888] = {.lex_state = 5, .external_lex_state = 4},
  [3889] = {.lex_state = 6},
  [3890] = {.lex_state = 130},
  [3891] = {.lex_state = 5, .external_lex_state = 4},
  [3892] = {.lex_state = 130},
  [3893] = {.lex_state = 130},
  [3894] = {.lex_state = 130},
  [3895] = {.lex_state = 5, .external_lex_state = 4},
  [3896] = {.lex_state = 5, .external_lex_state = 4},
  [3897] = {.lex_state = 5, .external_lex_state = 4},
  [3898] = {.lex_state = 5, .external_lex_state = 4},
  [3899] = {.lex_state = 5, .external_lex_state = 4},
  [3900] = {.lex_state = 130},
  [3901] = {.lex_state = 130},
  [3902] = {.lex_state = 5, .external_lex_state = 4},
  [3903] = {.lex_state = 5},
  [3904] = {.lex_state = 130},
  [3905] = {.lex_state = 130},
  [3906] = {.lex_state = 5, .external_lex_state = 4},
  [3907] = {.lex_state = 6},
  [3908] = {.lex_state = 130},
  [3909] = {.lex_state = 130},
  [3910] = {.lex_state = 130},
  [3911] = {.lex_state = 6},
  [3912] = {.lex_state = 130},
  [3913] = {.lex_state = 130},
  [3914] = {.lex_state = 130},
  [3915] = {.lex_state = 131},
  [3916] = {.lex_state = 130},
  [3917] = {.lex_state = 130},
  [3918] = {.lex_state = 130},
  [3919] = {.lex_state = 130},
  [3920] = {.lex_state = 130},
  [3921] = {.lex_state = 130},
  [3922] = {.lex_state = 5, .external_lex_state = 4},
  [3923] = {.lex_state = 130},
  [3924] = {.lex_state = 130},
  [3925] = {.lex_state = 5, .external_lex_state = 4},
  [3926] = {.lex_state = 130},
  [3927] = {.lex_state = 130},
  [3928] = {.lex_state = 130},
  [3929] = {.lex_state = 130},
  [3930] = {.lex_state = 130},
  [3931] = {.lex_state = 4},
  [3932] = {.lex_state = 130},
  [3933] = {.lex_state = 130},
  [3934] = {.lex_state = 5, .external_lex_state = 4},
  [3935] = {.lex_state = 130},
  [3936] = {.lex_state = 130},
  [3937] = {.lex_state = 7},
  [3938] = {.lex_state = 5, .external_lex_state = 4},
  [3939] = {.lex_state = 130},
  [3940] = {.lex_state = 5, .external_lex_state = 4},
  [3941] = {.lex_state = 130},
  [3942] = {.lex_state = 130},
  [3943] = {.lex_state = 130},
  [3944] = {.lex_state = 5, .external_lex_state = 4},
  [3945] = {.lex_state = 130},
  [3946] = {.lex_state = 6},
  [3947] = {.lex_state = 5, .external_lex_state = 4},
  [3948] = {.lex_state = 5, .external_lex_state = 4},
  [3949] = {.lex_state = 130},
  [3950] = {.lex_state = 130},
  [3951] = {.lex_state = 130},
  [3952] = {.lex_state = 130},
  [3953] = {.lex_state = 130},
  [3954] = {.lex_state = 130},
  [3955] = {.lex_state = 130},
  [3956] = {.lex_state = 130},
  [3957] = {.lex_state = 130},
  [3958] = {.lex_state = 130},
  [3959] = {.lex_state = 130},
  [3960] = {.lex_state = 5},
  [3961] = {.lex_state = 130},
  [3962] = {.lex_state = 130},
  [3963] = {.lex_state = 4},
  [3964] = {.lex_state = 130},
  [3965] = {.lex_state = 130},
  [3966] = {.lex_state = 130},
  [3967] = {.lex_state = 130},
  [3968] = {.lex_state = 130},
  [3969] = {.lex_state = 130},
  [3970] = {.lex_state = 130},
  [3971] = {.lex_state = 130},
  [3972] = {.lex_state = 130},
  [3973] = {.lex_state = 130},
  [3974] = {.lex_state = 130},
  [3975] = {.lex_state = 131},
  [3976] = {.lex_state = 130},
  [3977] = {.lex_state = 130},
  [3978] = {.lex_state = 130},
  [3979] = {.lex_state = 130},
  [3980] = {.lex_state = 130},
  [3981] = {.lex_state = 130},
  [3982] = {.lex_state = 130},
  [3983] = {.lex_state = 130},
  [3984] = {.lex_state = 130},
  [3985] = {.lex_state = 130},
  [3986] = {.lex_state = 130},
  [3987] = {.lex_state = 130},
  [3988] = {.lex_state = 131},
  [3989] = {.lex_state = 130},
  [3990] = {.lex_state = 130},
  [3991] = {.lex_state = 130},
  [3992] = {.lex_state = 130},
  [3993] = {.lex_state = 130},
  [3994] = {.lex_state = 130},
  [3995] = {.lex_state = 131},
  [3996] = {.lex_state = 130},
  [3997] = {.lex_state = 131},
  [3998] = {.lex_state = 130},
  [3999] = {.lex_state = 130},
  [4000] = {.lex_state = 130},
  [4001] = {.lex_state = 130},
  [4002] = {.lex_state = 130},
  [4003] = {.lex_state = 130},
  [4004] = {.lex_state = 6},
  [4005] = {.lex_state = 130},
  [4006] = {.lex_state = 130},
  [4007] = {.lex_state = 130},
  [4008] = {.lex_state = 130},
  [4009] = {.lex_state = 130},
  [4010] = {.lex_state = 130},
  [4011] = {.lex_state = 130},
  [4012] = {.lex_state = 130},
  [4013] = {.lex_state = 130},
  [4014] = {.lex_state = 130},
  [4015] = {.lex_state = 130},
  [4016] = {.lex_state = 130},
  [4017] = {.lex_state = 130},
  [4018] = {.lex_state = 130},
  [4019] = {.lex_state = 130},
  [4020] = {.lex_state = 130},
  [4021] = {.lex_state = 130},
  [4022] = {.lex_state = 130},
  [4023] = {.lex_state = 130},
  [4024] = {.lex_state = 130},
  [4025] = {.lex_state = 131},
  [4026] = {.lex_state = 130},
  [4027] = {.lex_state = 131},
  [4028] = {.lex_state = 130},
  [4029] = {.lex_state = 130},
  [4030] = {.lex_state = 130},
  [4031] = {.lex_state = 130},
  [4032] = {.lex_state = 130},
  [4033] = {.lex_state = 130},
  [4034] = {.lex_state = 130},
  [4035] = {.lex_state = 130},
  [4036] = {.lex_state = 130},
  [4037] = {.lex_state = 130},
  [4038] = {.lex_state = 5, .external_lex_state = 4},
  [4039] = {.lex_state = 130},
  [4040] = {.lex_state = 130},
  [4041] = {.lex_state = 130},
  [4042] = {.lex_state = 130},
  [4043] = {.lex_state = 130},
  [4044] = {.lex_state = 130},
  [4045] = {.lex_state = 130},
  [4046] = {.lex_state = 130},
  [4047] = {.lex_state = 130},
  [4048] = {.lex_state = 130},
  [4049] = {.lex_state = 130},
  [4050] = {.lex_state = 130},
  [4051] = {.lex_state = 130},
  [4052] = {.lex_state = 130},
  [4053] = {.lex_state = 130},
  [4054] = {.lex_state = 130},
  [4055] = {.lex_state = 130},
  [4056] = {.lex_state = 130},
  [4057] = {.lex_state = 130},
  [4058] = {.lex_state = 130},
  [4059] = {.lex_state = 130},
  [4060] = {.lex_state = 130},
  [4061] = {.lex_state = 130},
  [4062] = {.lex_state = 130},
  [4063] = {.lex_state = 130},
  [4064] = {.lex_state = 130},
  [4065] = {.lex_state = 130},
  [4066] = {.lex_state = 130},
  [4067] = {.lex_state = 130},
  [4068] = {.lex_state = 130},
  [4069] = {.lex_state = 5},
  [4070] = {.lex_state = 130},
  [4071] = {.lex_state = 130},
  [4072] = {.lex_state = 130},
  [4073] = {.lex_state = 130},
  [4074] = {.lex_state = 130},
  [4075] = {.lex_state = 130},
  [4076] = {.lex_state = 130},
  [4077] = {.lex_state = 130},
  [4078] = {.lex_state = 130},
  [4079] = {.lex_state = 7},
  [4080] = {.lex_state = 130},
  [4081] = {.lex_state = 130},
  [4082] = {.lex_state = 130},
  [4083] = {.lex_state = 130},
  [4084] = {.lex_state = 130},
  [4085] = {.lex_state = 130},
  [4086] = {.lex_state = 130},
  [4087] = {.lex_state = 131},
  [4088] = {.lex_state = 130},
  [4089] = {.lex_state = 130},
  [4090] = {.lex_state = 130},
  [4091] = {.lex_state = 130},
  [4092] = {.lex_state = 131},
  [4093] = {.lex_state = 131},
  [4094] = {.lex_state = 131},
  [4095] = {.lex_state = 131},
  [4096] = {.lex_state = 130},
  [4097] = {.lex_state = 130},
  [4098] = {.lex_state = 130},
  [4099] = {.lex_state = 130},
  [4100] = {.lex_state = 131},
  [4101] = {.lex_state = 130},
  [4102] = {.lex_state = 130},
  [4103] = {.lex_state = 130},
  [4104] = {.lex_state = 130},
  [4105] = {.lex_state = 130},
  [4106] = {.lex_state = 130},
  [4107] = {.lex_state = 130},
  [4108] = {.lex_state = 130},
  [4109] = {.lex_state = 130},
  [4110] = {.lex_state = 130},
  [4111] = {.lex_state = 130},
  [4112] = {.lex_state = 130},
  [4113] = {.lex_state = 130},
  [4114] = {.lex_state = 130},
  [4115] = {.lex_state = 130},
  [4116] = {.lex_state = 131},
  [4117] = {.lex_state = 130},
  [4118] = {.lex_state = 130},
  [4119] = {.lex_state = 130},
  [4120] = {.lex_state = 130},
  [4121] = {.lex_state = 130},
  [4122] = {.lex_state = 130},
  [4123] = {.lex_state = 131},
  [4124] = {.lex_state = 130},
  [4125] = {.lex_state = 130},
  [4126] = {.lex_state = 131},
  [4127] = {.lex_state = 130},
  [4128] = {.lex_state = 131},
  [4129] = {.lex_state = 131},
  [4130] = {.lex_state = 130},
  [4131] = {.lex_state = 130},
  [4132] = {.lex_state = 130},
  [4133] = {.lex_state = 130},
  [4134] = {.lex_state = 130},
  [4135] = {.lex_state = 4},
  [4136] = {.lex_state = 131},
  [4137] = {.lex_state = 130},
  [4138] = {.lex_state = 130},
  [4139] = {.lex_state = 130},
  [4140] = {.lex_state = 130},
  [4141] = {.lex_state = 131},
  [4142] = {.lex_state = 131},
  [4143] = {.lex_state = 131},
  [4144] = {.lex_state = 131},
  [4145] = {.lex_state = 131},
  [4146] = {.lex_state = 4},
  [4147] = {.lex_state = 130},
  [4148] = {.lex_state = 130},
  [4149] = {.lex_state = 5, .external_lex_state = 4},
  [4150] = {.lex_state = 130},
  [4151] = {.lex_state = 130},
  [4152] = {.lex_state = 130},
  [4153] = {.lex_state = 130},
  [4154] = {.lex_state = 130},
  [4155] = {.lex_state = 130},
  [4156] = {.lex_state = 130},
  [4157] = {.lex_state = 130},
  [4158] = {.lex_state = 130},
  [4159] = {.lex_state = 130},
  [4160] = {.lex_state = 130},
  [4161] = {.lex_state = 130},
  [4162] = {.lex_state = 130},
  [4163] = {.lex_state = 130},
  [4164] = {.lex_state = 130},
  [4165] = {.lex_state = 130},
  [4166] = {.lex_state = 130},
  [4167] = {.lex_state = 130},
  [4168] = {.lex_state = 130},
  [4169] = {.lex_state = 131},
  [4170] = {.lex_state = 130},
  [4171] = {.lex_state = 131},
  [4172] = {.lex_state = 131},
  [4173] = {.lex_state = 131},
  [4174] = {.lex_state = 131},
  [4175] = {.lex_state = 131},
  [4176] = {.lex_state = 130},
  [4177] = {.lex_state = 130},
  [4178] = {.lex_state = 4},
  [4179] = {.lex_state = 5},
  [4180] = {.lex_state = 130},
  [4181] = {.lex_state = 131},
  [4182] = {.lex_state = 130},
  [4183] = {.lex_state = 130},
  [4184] = {.lex_state = 130},
  [4185] = {.lex_state = 131},
  [4186] = {.lex_state = 131},
  [4187] = {.lex_state = 131},
  [4188] = {.lex_state = 131},
  [4189] = {.lex_state = 131},
  [4190] = {.lex_state = 130},
  [4191] = {.lex_state = 130},
  [4192] = {.lex_state = 131},
  [4193] = {.lex_state = 131},
  [4194] = {.lex_state = 131},
  [4195] = {.lex_state = 131},
  [4196] = {.lex_state = 131},
  [4197] = {.lex_state = 131},
  [4198] = {.lex_state = 130},
  [4199] = {.lex_state = 5},
  [4200] = {.lex_state = 4},
  [4201] = {.lex_state = 131},
  [4202] = {.lex_state = 131},
  [4203] = {.lex_state = 131},
  [4204] = {.lex_state = 131},
  [4205] = {.lex_state = 131},
  [4206] = {.lex_state = 131},
  [4207] = {.lex_state = 130},
  [4208] = {.lex_state = 4},
  [4209] = {.lex_state = 131},
  [4210] = {.lex_state = 131},
  [4211] = {.lex_state = 131},
  [4212] = {.lex_state = 131},
  [4213] = {.lex_state = 131},
  [4214] = {.lex_state = 131},
  [4215] = {.lex_state = 4},
  [4216] = {.lex_state = 5},
  [4217] = {.lex_state = 131},
  [4218] = {.lex_state = 130},
  [4219] = {.lex_state = 131},
  [4220] = {.lex_state = 131},
  [4221] = {.lex_state = 131},
  [4222] = {.lex_state = 131},
  [4223] = {.lex_state = 131},
  [4224] = {.lex_state = 4},
  [4225] = {.lex_state = 131},
  [4226] = {.lex_state = 131},
  [4227] = {.lex_state = 131},
  [4228] = {.lex_state = 131},
  [4229] = {.lex_state = 131},
  [4230] = {.lex_state = 130},
  [4231] = {.lex_state = 131},
  [4232] = {.lex_state = 131},
  [4233] = {.lex_state = 131},
  [4234] = {.lex_state = 131},
  [4235] = {.lex_state = 131},
  [4236] = {.lex_state = 131},
  [4237] = {.lex_state = 131},
  [4238] = {.lex_state = 131},
  [4239] = {.lex_state = 131},
  [4240] = {.lex_state = 131},
  [4241] = {.lex_state = 131},
  [4242] = {.lex_state = 131},
  [4243] = {.lex_state = 131},
  [4244] = {.lex_state = 131},
  [4245] = {.lex_state = 131},
  [4246] = {.lex_state = 131},
  [4247] = {.lex_state = 131},
  [4248] = {.lex_state = 131},
  [4249] = {.lex_state = 5},
  [4250] = {.lex_state = 131},
  [4251] = {.lex_state = 130},
  [4252] = {.lex_state = 131},
  [4253] = {.lex_state = 130},
  [4254] = {.lex_state = 131},
  [4255] = {.lex_state = 131},
  [4256] = {.lex_state = 131},
  [4257] = {.lex_state = 131},
  [4258] = {.lex_state = 131},
  [4259] = {.lex_state = 131},
  [4260] = {.lex_state = 131},
  [4261] = {.lex_state = 131},
  [4262] = {.lex_state = 131},
  [4263] = {.lex_state = 131},
  [4264] = {.lex_state = 131},
  [4265] = {.lex_state = 131},
  [4266] = {.lex_state = 131},
  [4267] = {.lex_state = 131},
  [4268] = {.lex_state = 131},
  [4269] = {.lex_state = 131},
  [4270] = {.lex_state = 131},
  [4271] = {.lex_state = 131},
  [4272] = {.lex_state = 131},
  [4273] = {.lex_state = 131},
  [4274] = {.lex_state = 131},
  [4275] = {.lex_state = 131},
  [4276] = {.lex_state = 131},
  [4277] = {.lex_state = 131},
  [4278] = {.lex_state = 131},
  [4279] = {.lex_state = 131},
  [4280] = {.lex_state = 131},
  [4281] = {.lex_state = 131},
  [4282] = {.lex_state = 131},
  [4283] = {.lex_state = 131},
  [4284] = {.lex_state = 131},
  [4285] = {.lex_state = 131},
  [4286] = {.lex_state = 131},
  [4287] = {.lex_state = 130},
  [4288] = {.lex_state = 131},
  [4289] = {.lex_state = 131},
  [4290] = {.lex_state = 130},
  [4291] = {.lex_state = 130},
  [4292] = {.lex_state = 130},
  [4293] = {.lex_state = 130},
  [4294] = {.lex_state = 131},
  [4295] = {.lex_state = 130},
  [4296] = {.lex_state = 131},
  [4297] = {.lex_state = 131},
  [4298] = {.lex_state = 131},
  [4299] = {.lex_state = 131},
  [4300] = {.lex_state = 130},
  [4301] = {.lex_state = 131},
  [4302] = {.lex_state = 131},
  [4303] = {.lex_state = 130},
  [4304] = {.lex_state = 130},
  [4305] = {.lex_state = 131},
  [4306] = {.lex_state = 131},
  [4307] = {.lex_state = 131},
  [4308] = {.lex_state = 131},
  [4309] = {.lex_state = 130},
  [4310] = {.lex_state = 131},
  [4311] = {.lex_state = 131},
  [4312] = {.lex_state = 131},
  [4313] = {.lex_state = 130},
  [4314] = {.lex_state = 131},
  [4315] = {.lex_state = 131},
  [4316] = {.lex_state = 131},
  [4317] = {.lex_state = 131},
  [4318] = {.lex_state = 130},
  [4319] = {.lex_state = 131},
  [4320] = {.lex_state = 131},
  [4321] = {.lex_state = 131},
  [4322] = {.lex_state = 131},
  [4323] = {.lex_state = 130},
  [4324] = {.lex_state = 130},
  [4325] = {.lex_state = 130},
  [4326] = {.lex_state = 130},
  [4327] = {.lex_state = 130},
  [4328] = {.lex_state = 130},
  [4329] = {.lex_state = 130},
  [4330] = {.lex_state = 131},
  [4331] = {.lex_state = 131},
  [4332] = {.lex_state = 130},
  [4333] = {.lex_state = 130},
  [4334] = {.lex_state = 4},
  [4335] = {.lex_state = 5},
  [4336] = {.lex_state = 130},
  [4337] = {.lex_state = 4},
  [4338] = {.lex_state = 130},
  [4339] = {.lex_state = 131},
  [4340] = {.lex_state = 5},
  [4341] = {.lex_state = 131},
  [4342] = {.lex_state = 4},
  [4343] = {.lex_state = 130},
  [4344] = {.lex_state = 4},
  [4345] = {.lex_state = 4},
  [4346] = {.lex_state = 5, .external_lex_state = 4},
  [4347] = {.lex_state = 131},
  [4348] = {.lex_state = 130},
  [4349] = {.lex_state = 131},
  [4350] = {.lex_state = 131},
  [4351] = {.lex_state = 131},
  [4352] = {.lex_state = 131},
  [4353] = {.lex_state = 131},
  [4354] = {.lex_state = 130},
  [4355] = {.lex_state = 131},
  [4356] = {.lex_state = 131},
  [4357] = {.lex_state = 131},
  [4358] = {.lex_state = 131},
  [4359] = {.lex_state = 131},
  [4360] = {.lex_state = 4},
  [4361] = {.lex_state = 130},
  [4362] = {.lex_state = 131},
  [4363] = {.lex_state = 131},
  [4364] = {.lex_state = 4},
  [4365] = {.lex_state = 4},
  [4366] = {.lex_state = 4},
  [4367] = {.lex_state = 10},
  [4368] = {.lex_state = 131},
  [4369] = {.lex_state = 4},
  [4370] = {.lex_state = 131},
  [4371] = {.lex_state = 131},
  [4372] = {.lex_state = 131},
  [4373] = {.lex_state = 130},
  [4374] = {.lex_state = 131},
  [4375] = {.lex_state = 131},
  [4376] = {.lex_state = 130},
  [4377] = {.lex_state = 130},
  [4378] = {.lex_state = 4},
  [4379] = {.lex_state = 131},
  [4380] = {.lex_state = 10},
  [4381] = {.lex_state = 10},
  [4382] = {.lex_state = 131},
  [4383] = {.lex_state = 131},
  [4384] = {.lex_state = 4},
  [4385] = {.lex_state = 131},
  [4386] = {.lex_state = 4},
  [4387] = {.lex_state = 131},
  [4388] = {.lex_state = 131},
  [4389] = {.lex_state = 130},
  [4390] = {.lex_state = 131},
  [4391] = {.lex_state = 130},
  [4392] = {.lex_state = 130},
  [4393] = {.lex_state = 131},
  [4394] = {.lex_state = 131},
  [4395] = {.lex_state = 10},
  [4396] = {.lex_state = 131},
  [4397] = {.lex_state = 131},
  [4398] = {.lex_state = 10},
  [4399] = {.lex_state = 4},
  [4400] = {.lex_state = 131},
  [4401] = {.lex_state = 131},
  [4402] = {.lex_state = 10},
  [4403] = {.lex_state = 131},
  [4404] = {.lex_state = 131},
  [4405] = {.lex_state = 130},
  [4406] = {.lex_state = 10},
  [4407] = {.lex_state = 10},
  [4408] = {.lex_state = 130},
  [4409] = {.lex_state = 130},
  [4410] = {.lex_state = 130},
  [4411] = {.lex_state = 130},
  [4412] = {.lex_state = 130},
  [4413] = {.lex_state = 130},
  [4414] = {.lex_state = 130},
  [4415] = {.lex_state = 131},
  [4416] = {.lex_state = 130},
  [4417] = {.lex_state = 130},
  [4418] = {.lex_state = 130},
  [4419] = {.lex_state = 130},
  [4420] = {.lex_state = 130},
  [4421] = {.lex_state = 131},
  [4422] = {.lex_state = 130},
  [4423] = {.lex_state = 130},
  [4424] = {.lex_state = 130},
  [4425] = {.lex_state = 10},
  [4426] = {.lex_state = 130},
  [4427] = {.lex_state = 131},
  [4428] = {.lex_state = 131},
  [4429] = {.lex_state = 131},
  [4430] = {.lex_state = 130},
  [4431] = {.lex_state = 130},
  [4432] = {.lex_state = 130},
  [4433] = {.lex_state = 130},
  [4434] = {.lex_state = 130},
  [4435] = {.lex_state = 10},
  [4436] = {.lex_state = 4},
  [4437] = {.lex_state = 130},
  [4438] = {.lex_state = 130},
  [4439] = {.lex_state = 131},
  [4440] = {.lex_state = 131},
  [4441] = {.lex_state = 131},
  [4442] = {.lex_state = 131},
  [4443] = {.lex_state = 10},
  [4444] = {.lex_state = 131},
  [4445] = {.lex_state = 10},
  [4446] = {.lex_state = 130},
  [4447] = {.lex_state = 10},
  [4448] = {.lex_state = 131},
  [4449] = {.lex_state = 131},
  [4450] = {.lex_state = 130},
  [4451] = {.lex_state = 131},
  [4452] = {.lex_state = 10},
  [4453] = {.lex_state = 131},
  [4454] = {.lex_state = 131},
  [4455] = {.lex_state = 131},
  [4456] = {.lex_state = 130},
  [4457] = {.lex_state = 4},
  [4458] = {.lex_state = 4},
  [4459] = {.lex_state = 131},
  [4460] = {.lex_state = 130},
  [4461] = {.lex_state = 130},
  [4462] = {.lex_state = 130},
  [4463] = {.lex_state = 130},
  [4464] = {.lex_state = 130},
  [4465] = {.lex_state = 130},
  [4466] = {.lex_state = 130},
  [4467] = {.lex_state = 131},
  [4468] = {.lex_state = 5},
  [4469] = {.lex_state = 130},
  [4470] = {.lex_state = 130},
  [4471] = {.lex_state = 130},
  [4472] = {.lex_state = 131},
  [4473] = {.lex_state = 4},
  [4474] = {.lex_state = 130},
  [4475] = {.lex_state = 130},
  [4476] = {.lex_state = 130},
  [4477] = {.lex_state = 130},
  [4478] = {.lex_state = 130},
  [4479] = {.lex_state = 130},
  [4480] = {.lex_state = 130},
  [4481] = {.lex_state = 130},
  [4482] = {.lex_state = 130},
  [4483] = {.lex_state = 130},
  [4484] = {.lex_state = 130},
  [4485] = {.lex_state = 130},
  [4486] = {.lex_state = 130},
  [4487] = {.lex_state = 4},
  [4488] = {.lex_state = 130},
  [4489] = {.lex_state = 4},
  [4490] = {.lex_state = 7},
  [4491] = {.lex_state = 130},
  [4492] = {.lex_state = 130},
  [4493] = {.lex_state = 131},
  [4494] = {.lex_state = 130},
  [4495] = {.lex_state = 130},
  [4496] = {.lex_state = 131},
  [4497] = {.lex_state = 131},
  [4498] = {.lex_state = 130},
  [4499] = {.lex_state = 130},
  [4500] = {.lex_state = 130},
  [4501] = {.lex_state = 130},
  [4502] = {.lex_state = 130},
  [4503] = {.lex_state = 131},
  [4504] = {.lex_state = 130},
  [4505] = {.lex_state = 130},
  [4506] = {.lex_state = 130},
  [4507] = {.lex_state = 130},
  [4508] = {.lex_state = 130},
  [4509] = {.lex_state = 131},
  [4510] = {.lex_state = 130},
  [4511] = {.lex_state = 130},
  [4512] = {.lex_state = 130},
  [4513] = {.lex_state = 10},
  [4514] = {.lex_state = 130},
  [4515] = {.lex_state = 130},
  [4516] = {.lex_state = 130},
  [4517] = {.lex_state = 130},
  [4518] = {.lex_state = 4},
  [4519] = {.lex_state = 130},
  [4520] = {.lex_state = 131},
  [4521] = {.lex_state = 130},
  [4522] = {.lex_state = 130},
  [4523] = {.lex_state = 130},
  [4524] = {.lex_state = 130},
  [4525] = {.lex_state = 130},
  [4526] = {.lex_state = 130},
  [4527] = {.lex_state = 130},
  [4528] = {.lex_state = 131},
  [4529] = {.lex_state = 10},
  [4530] = {.lex_state = 131},
  [4531] = {.lex_state = 130},
  [4532] = {.lex_state = 131},
  [4533] = {.lex_state = 131},
  [4534] = {.lex_state = 130},
  [4535] = {.lex_state = 131},
  [4536] = {.lex_state = 130},
  [4537] = {.lex_state = 131},
  [4538] = {.lex_state = 130},
  [4539] = {.lex_state = 130},
  [4540] = {.lex_state = 131},
  [4541] = {.lex_state = 4},
  [4542] = {.lex_state = 131},
  [4543] = {.lex_state = 130},
  [4544] = {.lex_state = 130},
  [4545] = {.lex_state = 130},
  [4546] = {.lex_state = 130},
  [4547] = {.lex_state = 130},
  [4548] = {.lex_state = 130},
  [4549] = {.lex_state = 130},
  [4550] = {.lex_state = 131},
  [4551] = {.lex_state = 130},
  [4552] = {.lex_state = 130},
  [4553] = {.lex_state = 130},
  [4554] = {.lex_state = 131},
  [4555] = {.lex_state = 130},
  [4556] = {.lex_state = 130},
  [4557] = {.lex_state = 130},
  [4558] = {.lex_state = 131},
  [4559] = {.lex_state = 130},
  [4560] = {.lex_state = 130},
  [4561] = {.lex_state = 130},
  [4562] = {.lex_state = 130},
  [4563] = {.lex_state = 130},
  [4564] = {.lex_state = 130},
  [4565] = {.lex_state = 130},
  [4566] = {.lex_state = 131},
  [4567] = {.lex_state = 131},
  [4568] = {.lex_state = 130},
  [4569] = {.lex_state = 130},
  [4570] = {.lex_state = 131},
  [4571] = {.lex_state = 130},
  [4572] = {.lex_state = 131},
  [4573] = {.lex_state = 131},
  [4574] = {.lex_state = 6},
  [4575] = {.lex_state = 130},
  [4576] = {.lex_state = 130},
  [4577] = {.lex_state = 130},
  [4578] = {.lex_state = 130},
  [4579] = {.lex_state = 131},
  [4580] = {.lex_state = 130},
  [4581] = {.lex_state = 130},
  [4582] = {.lex_state = 130},
  [4583] = {.lex_state = 131},
  [4584] = {.lex_state = 130},
  [4585] = {.lex_state = 130},
  [4586] = {.lex_state = 130},
  [4587] = {.lex_state = 130},
  [4588] = {.lex_state = 130},
  [4589] = {.lex_state = 130},
  [4590] = {.lex_state = 130},
  [4591] = {.lex_state = 131},
  [4592] = {.lex_state = 130},
  [4593] = {.lex_state = 130},
  [4594] = {.lex_state = 131},
  [4595] = {.lex_state = 130},
  [4596] = {.lex_state = 131},
  [4597] = {.lex_state = 131},
  [4598] = {.lex_state = 130},
  [4599] = {.lex_state = 130},
  [4600] = {.lex_state = 130},
  [4601] = {.lex_state = 130},
  [4602] = {.lex_state = 130},
  [4603] = {.lex_state = 131},
  [4604] = {.lex_state = 131},
  [4605] = {.lex_state = 131},
  [4606] = {.lex_state = 130},
  [4607] = {.lex_state = 130},
  [4608] = {.lex_state = 130},
  [4609] = {.lex_state = 130},
  [4610] = {.lex_state = 130},
  [4611] = {.lex_state = 130},
  [4612] = {.lex_state = 130},
  [4613] = {.lex_state = 130},
  [4614] = {.lex_state = 130},
  [4615] = {.lex_state = 131},
  [4616] = {.lex_state = 130},
  [4617] = {.lex_state = 130},
  [4618] = {.lex_state = 130},
  [4619] = {.lex_state = 130},
  [4620] = {.lex_state = 130},
  [4621] = {.lex_state = 130},
  [4622] = {.lex_state = 131},
  [4623] = {.lex_state = 130},
  [4624] = {.lex_state = 130},
  [4625] = {.lex_state = 131},
  [4626] = {.lex_state = 130},
  [4627] = {.lex_state = 131},
  [4628] = {.lex_state = 131},
  [4629] = {.lex_state = 130},
  [4630] = {.lex_state = 130},
  [4631] = {.lex_state = 130},
  [4632] = {.lex_state = 131},
  [4633] = {.lex_state = 130},
  [4634] = {.lex_state = 131},
  [4635] = {.lex_state = 130},
  [4636] = {.lex_state = 130},
  [4637] = {.lex_state = 130},
  [4638] = {.lex_state = 131},
  [4639] = {.lex_state = 131},
  [4640] = {.lex_state = 131},
  [4641] = {.lex_state = 131},
  [4642] = {.lex_state = 131},
  [4643] = {.lex_state = 130},
  [4644] = {.lex_state = 131},
  [4645] = {.lex_state = 131},
  [4646] = {.lex_state = 130},
  [4647] = {.lex_state = 131},
  [4648] = {.lex_state = 130},
  [4649] = {.lex_state = 130},
  [4650] = {.lex_state = 130},
  [4651] = {.lex_state = 131},
  [4652] = {.lex_state = 131},
  [4653] = {.lex_state = 130},
  [4654] = {.lex_state = 130},
  [4655] = {.lex_state = 130},
  [4656] = {.lex_state = 130},
  [4657] = {.lex_state = 130},
  [4658] = {.lex_state = 131},
  [4659] = {.lex_state = 131},
  [4660] = {.lex_state = 131},
  [4661] = {.lex_state = 131},
  [4662] = {.lex_state = 130},
  [4663] = {.lex_state = 130},
  [4664] = {.lex_state = 130},
  [4665] = {.lex_state = 131},
  [4666] = {.lex_state = 131},
  [4667] = {.lex_state = 131},
  [4668] = {.lex_state = 131},
  [4669] = {.lex_state = 130},
  [4670] = {.lex_state = 130},
  [4671] = {.lex_state = 130},
  [4672] = {.lex_state = 130},
  [4673] = {.lex_state = 130},
  [4674] = {.lex_state = 130},
  [4675] = {.lex_state = 131},
  [4676] = {.lex_state = 130},
  [4677] = {.lex_state = 130},
  [4678] = {.lex_state = 131},
  [4679] = {.lex_state = 130},
  [4680] = {.lex_state = 130},
  [4681] = {.lex_state = 130},
  [4682] = {.lex_state = 131},
  [4683] = {.lex_state = 130},
  [4684] = {.lex_state = 130},
  [4685] = {.lex_state = 130},
  [4686] = {.lex_state = 130},
  [4687] = {.lex_state = 131},
  [4688] = {.lex_state = 130},
  [4689] = {.lex_state = 130},
  [4690] = {.lex_state = 130},
  [4691] = {.lex_state = 131},
  [4692] = {.lex_state = 131},
  [4693] = {.lex_state = 131},
  [4694] = {.lex_state = 131},
  [4695] = {.lex_state = 130},
  [4696] = {.lex_state = 131},
  [4697] = {.lex_state = 131},
  [4698] = {.lex_state = 131},
  [4699] = {.lex_state = 130},
  [4700] = {.lex_state = 131},
  [4701] = {.lex_state = 130},
  [4702] = {.lex_state = 130},
  [4703] = {.lex_state = 130},
  [4704] = {.lex_state = 131},
  [4705] = {.lex_state = 130},
  [4706] = {.lex_state = 131},
  [4707] = {.lex_state = 130},
  [4708] = {.lex_state = 130},
  [4709] = {.lex_state = 130},
  [4710] = {.lex_state = 131},
  [4711] = {.lex_state = 131},
  [4712] = {.lex_state = 130},
  [4713] = {.lex_state = 130},
  [4714] = {.lex_state = 130},
  [4715] = {.lex_state = 131},
  [4716] = {.lex_state = 131},
  [4717] = {.lex_state = 130},
  [4718] = {.lex_state = 131},
  [4719] = {.lex_state = 130},
  [4720] = {.lex_state = 130},
  [4721] = {.lex_state = 130},
  [4722] = {.lex_state = 130},
  [4723] = {.lex_state = 131},
  [4724] = {.lex_state = 130},
  [4725] = {.lex_state = 131},
  [4726] = {.lex_state = 130},
  [4727] = {.lex_state = 131},
  [4728] = {.lex_state = 131},
  [4729] = {.lex_state = 131},
  [4730] = {.lex_state = 130},
  [4731] = {.lex_state = 131},
  [4732] = {.lex_state = 130},
  [4733] = {.lex_state = 130},
  [4734] = {.lex_state = 131},
  [4735] = {.lex_state = 131},
  [4736] = {.lex_state = 130},
  [4737] = {.lex_state = 131},
  [4738] = {.lex_state = 130},
  [4739] = {.lex_state = 130},
  [4740] = {.lex_state = 130},
  [4741] = {.lex_state = 131},
  [4742] = {.lex_state = 131},
  [4743] = {.lex_state = 131},
  [4744] = {.lex_state = 130},
  [4745] = {.lex_state = 131},
  [4746] = {.lex_state = 131},
  [4747] = {.lex_state = 131},
  [4748] = {.lex_state = 130},
  [4749] = {.lex_state = 130},
  [4750] = {.lex_state = 131},
  [4751] = {.lex_state = 130},
  [4752] = {.lex_state = 130},
  [4753] = {.lex_state = 131},
  [4754] = {.lex_state = 130},
  [4755] = {.lex_state = 131},
  [4756] = {.lex_state = 130},
  [4757] = {.lex_state = 131},
  [4758] = {.lex_state = 131},
  [4759] = {.lex_state = 131},
  [4760] = {.lex_state = 131},
  [4761] = {.lex_state = 131},
  [4762] = {.lex_state = 131},
  [4763] = {.lex_state = 131},
  [4764] = {.lex_state = 131},
  [4765] = {.lex_state = 10},
  [4766] = {.lex_state = 131},
  [4767] = {.lex_state = 130},
  [4768] = {.lex_state = 130},
  [4769] = {.lex_state = 130},
  [4770] = {.lex_state = 130},
  [4771] = {.lex_state = 130},
  [4772] = {.lex_state = 130},
  [4773] = {.lex_state = 130},
  [4774] = {.lex_state = 130},
  [4775] = {.lex_state = 130},
  [4776] = {.lex_state = 130},
  [4777] = {.lex_state = 130},
  [4778] = {.lex_state = 130},
  [4779] = {.lex_state = 130},
  [4780] = {.lex_state = 130},
  [4781] = {.lex_state = 130},
  [4782] = {.lex_state = 130},
  [4783] = {.lex_state = 131},
  [4784] = {.lex_state = 131},
  [4785] = {.lex_state = 131},
  [4786] = {.lex_state = 17},
  [4787] = {.lex_state = 130},
  [4788] = {.lex_state = 131},
  [4789] = {.lex_state = 131},
  [4790] = {.lex_state = 131},
  [4791] = {.lex_state = 131},
  [4792] = {.lex_state = 131},
  [4793] = {.lex_state = 131},
  [4794] = {.lex_state = 131},
  [4795] = {.lex_state = 131},
  [4796] = {.lex_state = 131},
  [4797] = {.lex_state = 131},
  [4798] = {.lex_state = 131},
  [4799] = {.lex_state = 130},
  [4800] = {.lex_state = 131},
  [4801] = {.lex_state = 131},
  [4802] = {.lex_state = 131},
  [4803] = {.lex_state = 130},
  [4804] = {.lex_state = 130},
  [4805] = {.lex_state = 131},
  [4806] = {.lex_state = 131},
  [4807] = {.lex_state = 131},
  [4808] = {.lex_state = 130},
  [4809] = {.lex_state = 131},
  [4810] = {.lex_state = 131},
  [4811] = {.lex_state = 130},
  [4812] = {.lex_state = 131},
  [4813] = {.lex_state = 130},
  [4814] = {.lex_state = 131},
  [4815] = {.lex_state = 130},
  [4816] = {.lex_state = 130},
  [4817] = {.lex_state = 131},
  [4818] = {.lex_state = 131},
  [4819] = {.lex_state = 131},
  [4820] = {.lex_state = 131},
  [4821] = {.lex_state = 131},
  [4822] = {.lex_state = 131},
  [4823] = {.lex_state = 131},
  [4824] = {.lex_state = 131},
  [4825] = {.lex_state = 130},
  [4826] = {.lex_state = 131},
  [4827] = {.lex_state = 131},
  [4828] = {.lex_state = 131},
  [4829] = {.lex_state = 131},
  [4830] = {.lex_state = 131},
  [4831] = {.lex_state = 130},
  [4832] = {.lex_state = 130},
  [4833] = {.lex_state = 130},
  [4834] = {.lex_state = 130},
  [4835] = {.lex_state = 130},
  [4836] = {.lex_state = 131},
  [4837] = {.lex_state = 130},
  [4838] = {.lex_state = 131},
  [4839] = {.lex_state = 130},
  [4840] = {.lex_state = 131},
  [4841] = {.lex_state = 130},
  [4842] = {.lex_state = 131},
  [4843] = {.lex_state = 131},
  [4844] = {.lex_state = 131},
  [4845] = {.lex_state = 131},
  [4846] = {.lex_state = 131},
  [4847] = {.lex_state = 130},
  [4848] = {.lex_state = 131},
  [4849] = {.lex_state = 131},
  [4850] = {.lex_state = 130},
  [4851] = {.lex_state = 131},
  [4852] = {.lex_state = 130},
  [4853] = {.lex_state = 130},
  [4854] = {.lex_state = 131},
  [4855] = {.lex_state = 130},
  [4856] = {.lex_state = 130},
  [4857] = {.lex_state = 131},
  [4858] = {.lex_state = 131},
  [4859] = {.lex_state = 131},
  [4860] = {.lex_state = 131},
  [4861] = {.lex_state = 131},
  [4862] = {.lex_state = 131},
  [4863] = {.lex_state = 131},
  [4864] = {.lex_state = 131},
  [4865] = {.lex_state = 130},
  [4866] = {.lex_state = 131},
  [4867] = {.lex_state = 130},
  [4868] = {.lex_state = 130},
  [4869] = {.lex_state = 131},
  [4870] = {.lex_state = 131},
  [4871] = {.lex_state = 131},
  [4872] = {.lex_state = 131},
  [4873] = {.lex_state = 131},
  [4874] = {.lex_state = 131},
  [4875] = {.lex_state = 131},
  [4876] = {.lex_state = 131},
  [4877] = {.lex_state = 131},
  [4878] = {.lex_state = 130},
  [4879] = {.lex_state = 131},
  [4880] = {.lex_state = 130},
  [4881] = {.lex_state = 131},
  [4882] = {.lex_state = 131},
  [4883] = {.lex_state = 131},
  [4884] = {.lex_state = 130},
  [4885] = {.lex_state = 131},
  [4886] = {.lex_state = 130},
  [4887] = {.lex_state = 131},
  [4888] = {.lex_state = 131},
  [4889] = {.lex_state = 130},
  [4890] = {.lex_state = 130},
  [4891] = {.lex_state = 131},
  [4892] = {.lex_state = 131},
  [4893] = {.lex_state = 130},
  [4894] = {.lex_state = 130},
  [4895] = {.lex_state = 131},
  [4896] = {.lex_state = 131},
  [4897] = {.lex_state = 130},
  [4898] = {.lex_state = 130},
  [4899] = {.lex_state = 130},
  [4900] = {.lex_state = 130},
  [4901] = {.lex_state = 131},
  [4902] = {.lex_state = 130},
  [4903] = {.lex_state = 131},
  [4904] = {.lex_state = 131},
  [4905] = {.lex_state = 130},
  [4906] = {.lex_state = 130},
  [4907] = {.lex_state = 130},
  [4908] = {.lex_state = 130},
  [4909] = {.lex_state = 130},
  [4910] = {.lex_state = 130},
  [4911] = {.lex_state = 131},
  [4912] = {.lex_state = 131},
  [4913] = {.lex_state = 130},
  [4914] = {.lex_state = 130},
  [4915] = {.lex_state = 131},
  [4916] = {.lex_state = 130},
  [4917] = {.lex_state = 130},
  [4918] = {.lex_state = 130},
  [4919] = {.lex_state = 130},
  [4920] = {.lex_state = 131},
  [4921] = {.lex_state = 130},
  [4922] = {.lex_state = 130},
  [4923] = {.lex_state = 130},
  [4924] = {.lex_state = 130},
  [4925] = {.lex_state = 130},
  [4926] = {.lex_state = 130},
  [4927] = {.lex_state = 130},
  [4928] = {.lex_state = 130},
  [4929] = {.lex_state = 131},
  [4930] = {.lex_state = 130},
  [4931] = {.lex_state = 131},
  [4932] = {.lex_state = 131},
  [4933] = {.lex_state = 131},
  [4934] = {.lex_state = 130},
  [4935] = {.lex_state = 131},
  [4936] = {.lex_state = 131},
  [4937] = {.lex_state = 131},
  [4938] = {.lex_state = 130},
  [4939] = {.lex_state = 130},
  [4940] = {.lex_state = 131},
  [4941] = {.lex_state = 131},
  [4942] = {.lex_state = 131},
  [4943] = {.lex_state = 130},
  [4944] = {.lex_state = 130},
  [4945] = {.lex_state = 130},
  [4946] = {.lex_state = 130},
  [4947] = {.lex_state = 10},
  [4948] = {.lex_state = 130},
  [4949] = {.lex_state = 130},
  [4950] = {.lex_state = 130},
  [4951] = {.lex_state = 130},
  [4952] = {.lex_state = 130},
  [4953] = {.lex_state = 130},
  [4954] = {.lex_state = 130},
  [4955] = {.lex_state = 130},
  [4956] = {.lex_state = 130},
  [4957] = {.lex_state = 130},
  [4958] = {.lex_state = 130},
  [4959] = {.lex_state = 130},
  [4960] = {.lex_state = 130},
  [4961] = {.lex_state = 130},
  [4962] = {.lex_state = 130},
  [4963] = {.lex_state = 130},
  [4964] = {.lex_state = 130},
  [4965] = {.lex_state = 130},
  [4966] = {.lex_state = 130},
  [4967] = {.lex_state = 130},
  [4968] = {.lex_state = 130},
  [4969] = {.lex_state = 130},
  [4970] = {.lex_state = 130},
  [4971] = {.lex_state = 130},
  [4972] = {.lex_state = 130},
  [4973] = {.lex_state = 130},
  [4974] = {.lex_state = 130},
  [4975] = {.lex_state = 130},
  [4976] = {.lex_state = 130},
  [4977] = {.lex_state = 130},
  [4978] = {.lex_state = 130},
  [4979] = {.lex_state = 131},
  [4980] = {.lex_state = 130},
  [4981] = {.lex_state = 130},
  [4982] = {.lex_state = 130},
  [4983] = {.lex_state = 130},
  [4984] = {.lex_state = 130},
  [4985] = {.lex_state = 130},
  [4986] = {.lex_state = 130},
  [4987] = {.lex_state = 130},
  [4988] = {.lex_state = 130},
  [4989] = {.lex_state = 130},
  [4990] = {.lex_state = 130},
  [4991] = {.lex_state = 130},
  [4992] = {.lex_state = 130},
  [4993] = {.lex_state = 130},
  [4994] = {.lex_state = 130},
  [4995] = {.lex_state = 130},
  [4996] = {.lex_state = 130},
  [4997] = {.lex_state = 130},
  [4998] = {.lex_state = 17},
  [4999] = {.lex_state = 130},
  [5000] = {.lex_state = 130},
  [5001] = {.lex_state = 17},
  [5002] = {.lex_state = 130},
  [5003] = {.lex_state = 130},
  [5004] = {.lex_state = 130},
  [5005] = {.lex_state = 130},
  [5006] = {.lex_state = 130},
  [5007] = {.lex_state = 17},
  [5008] = {.lex_state = 130},
  [5009] = {.lex_state = 130},
  [5010] = {.lex_state = 130},
  [5011] = {.lex_state = 130},
  [5012] = {.lex_state = 130},
  [5013] = {.lex_state = 130},
  [5014] = {.lex_state = 17},
  [5015] = {.lex_state = 130},
  [5016] = {.lex_state = 131},
  [5017] = {.lex_state = 130},
  [5018] = {.lex_state = 130},
  [5019] = {.lex_state = 17},
  [5020] = {.lex_state = 130},
  [5021] = {.lex_state = 130},
  [5022] = {.lex_state = 130},
  [5023] = {.lex_state = 130},
  [5024] = {.lex_state = 130},
  [5025] = {.lex_state = 17},
  [5026] = {.lex_state = 130},
  [5027] = {.lex_state = 130},
  [5028] = {.lex_state = 130},
  [5029] = {.lex_state = 130},
  [5030] = {.lex_state = 130},
  [5031] = {.lex_state = 130},
  [5032] = {.lex_state = 130},
  [5033] = {.lex_state = 130},
  [5034] = {.lex_state = 130},
  [5035] = {.lex_state = 130},
  [5036] = {.lex_state = 130},
  [5037] = {.lex_state = 130},
  [5038] = {.lex_state = 130},
  [5039] = {.lex_state = 130},
  [5040] = {.lex_state = 130},
  [5041] = {.lex_state = 130},
  [5042] = {.lex_state = 130},
  [5043] = {.lex_state = 130},
  [5044] = {.lex_state = 17},
  [5045] = {.lex_state = 130},
  [5046] = {.lex_state = 130},
  [5047] = {.lex_state = 130},
  [5048] = {.lex_state = 130},
  [5049] = {.lex_state = 130},
  [5050] = {.lex_state = 130},
  [5051] = {.lex_state = 130},
  [5052] = {.lex_state = 130},
  [5053] = {.lex_state = 130},
  [5054] = {.lex_state = 130},
  [5055] = {.lex_state = 130},
  [5056] = {.lex_state = 130},
  [5057] = {.lex_state = 130},
  [5058] = {.lex_state = 130},
  [5059] = {.lex_state = 130},
  [5060] = {.lex_state = 130},
  [5061] = {.lex_state = 130},
  [5062] = {.lex_state = 130},
  [5063] = {.lex_state = 130},
  [5064] = {.lex_state = 130},
  [5065] = {.lex_state = 130, .external_lex_state = 4},
  [5066] = {.lex_state = 130},
  [5067] = {.lex_state = 130},
  [5068] = {.lex_state = 130},
  [5069] = {.lex_state = 130},
  [5070] = {.lex_state = 130},
  [5071] = {.lex_state = 130},
  [5072] = {.lex_state = 130},
  [5073] = {.lex_state = 130},
  [5074] = {.lex_state = 130},
  [5075] = {.lex_state = 130},
  [5076] = {.lex_state = 6, .external_lex_state = 4},
  [5077] = {.lex_state = 130},
  [5078] = {.lex_state = 130},
  [5079] = {.lex_state = 130},
  [5080] = {.lex_state = 130},
  [5081] = {.lex_state = 130},
  [5082] = {.lex_state = 130},
  [5083] = {.lex_state = 130},
  [5084] = {.lex_state = 130},
  [5085] = {.lex_state = 130},
  [5086] = {.lex_state = 130},
  [5087] = {.lex_state = 130},
  [5088] = {.lex_state = 130},
  [5089] = {.lex_state = 130},
  [5090] = {.lex_state = 130},
  [5091] = {.lex_state = 130},
  [5092] = {.lex_state = 10},
  [5093] = {.lex_state = 130},
  [5094] = {.lex_state = 130},
  [5095] = {.lex_state = 130},
  [5096] = {.lex_state = 130},
  [5097] = {.lex_state = 130},
  [5098] = {.lex_state = 130},
  [5099] = {.lex_state = 130},
  [5100] = {.lex_state = 130},
  [5101] = {.lex_state = 130},
  [5102] = {.lex_state = 130},
  [5103] = {.lex_state = 130},
  [5104] = {.lex_state = 130},
  [5105] = {.lex_state = 130},
  [5106] = {.lex_state = 130},
  [5107] = {.lex_state = 130},
  [5108] = {.lex_state = 130},
  [5109] = {.lex_state = 130},
  [5110] = {.lex_state = 130},
  [5111] = {.lex_state = 130},
  [5112] = {.lex_state = 130},
  [5113] = {.lex_state = 130},
  [5114] = {.lex_state = 130},
  [5115] = {.lex_state = 130},
  [5116] = {.lex_state = 130},
  [5117] = {.lex_state = 130},
  [5118] = {.lex_state = 130},
  [5119] = {.lex_state = 130},
  [5120] = {.lex_state = 131},
  [5121] = {.lex_state = 130},
  [5122] = {.lex_state = 130},
  [5123] = {.lex_state = 130},
  [5124] = {.lex_state = 130},
  [5125] = {.lex_state = 130},
  [5126] = {.lex_state = 130},
  [5127] = {.lex_state = 130},
  [5128] = {.lex_state = 17},
  [5129] = {.lex_state = 130},
  [5130] = {.lex_state = 130},
  [5131] = {.lex_state = 130},
  [5132] = {.lex_state = 130},
  [5133] = {.lex_state = 130},
  [5134] = {.lex_state = 130},
  [5135] = {.lex_state = 130},
  [5136] = {.lex_state = 130},
  [5137] = {.lex_state = 130},
  [5138] = {.lex_state = 130},
  [5139] = {.lex_state = 130},
  [5140] = {.lex_state = 130},
  [5141] = {.lex_state = 130},
  [5142] = {.lex_state = 130},
  [5143] = {.lex_state = 130},
  [5144] = {.lex_state = 130},
  [5145] = {.lex_state = 130},
  [5146] = {.lex_state = 130},
  [5147] = {.lex_state = 6, .external_lex_state = 4},
  [5148] = {.lex_state = 130},
  [5149] = {.lex_state = 130},
  [5150] = {.lex_state = 130},
  [5151] = {.lex_state = 130, .external_lex_state = 4},
  [5152] = {.lex_state = 130},
  [5153] = {.lex_state = 10},
  [5154] = {.lex_state = 130},
  [5155] = {.lex_state = 130, .external_lex_state = 4},
  [5156] = {.lex_state = 130, .external_lex_state = 4},
  [5157] = {.lex_state = 130},
  [5158] = {.lex_state = 130},
  [5159] = {.lex_state = 130},
  [5160] = {.lex_state = 130},
  [5161] = {.lex_state = 130},
  [5162] = {.lex_state = 130, .external_lex_state = 4},
  [5163] = {.lex_state = 130},
  [5164] = {.lex_state = 130},
  [5165] = {.lex_state = 130, .external_lex_state = 4},
  [5166] = {.lex_state = 131},
  [5167] = {.lex_state = 6, .external_lex_state = 4},
  [5168] = {.lex_state = 130, .external_lex_state = 4},
  [5169] = {.lex_state = 130},
  [5170] = {.lex_state = 130},
  [5171] = {.lex_state = 131},
  [5172] = {.lex_state = 130},
  [5173] = {.lex_state = 6, .external_lex_state = 4},
  [5174] = {.lex_state = 130, .external_lex_state = 4},
  [5175] = {.lex_state = 131},
  [5176] = {.lex_state = 130, .external_lex_state = 4},
  [5177] = {.lex_state = 130, .external_lex_state = 4},
  [5178] = {.lex_state = 130, .external_lex_state = 4},
  [5179] = {.lex_state = 10},
  [5180] = {.lex_state = 130},
  [5181] = {.lex_state = 130, .external_lex_state = 4},
  [5182] = {.lex_state = 130, .external_lex_state = 4},
  [5183] = {.lex_state = 130, .external_lex_state = 4},
  [5184] = {.lex_state = 130, .external_lex_state = 4},
  [5185] = {.lex_state = 130},
  [5186] = {.lex_state = 130},
  [5187] = {.lex_state = 131},
  [5188] = {.lex_state = 130},
  [5189] = {.lex_state = 130, .external_lex_state = 4},
  [5190] = {.lex_state = 130},
  [5191] = {.lex_state = 130},
  [5192] = {.lex_state = 130},
  [5193] = {.lex_state = 130},
  [5194] = {.lex_state = 130},
  [5195] = {.lex_state = 130},
  [5196] = {.lex_state = 130},
  [5197] = {.lex_state = 130},
  [5198] = {.lex_state = 130},
  [5199] = {.lex_state = 130},
  [5200] = {.lex_state = 130, .external_lex_state = 4},
  [5201] = {.lex_state = 130, .external_lex_state = 4},
  [5202] = {.lex_state = 130, .external_lex_state = 4},
  [5203] = {.lex_state = 130, .external_lex_state = 4},
  [5204] = {.lex_state = 130},
  [5205] = {.lex_state = 130},
  [5206] = {.lex_state = 130},
  [5207] = {.lex_state = 130, .external_lex_state = 4},
  [5208] = {.lex_state = 130},
  [5209] = {.lex_state = 130},
  [5210] = {.lex_state = 130, .external_lex_state = 4},
  [5211] = {.lex_state = 130},
  [5212] = {.lex_state = 130, .external_lex_state = 4},
  [5213] = {.lex_state = 130},
  [5214] = {.lex_state = 130, .external_lex_state = 4},
  [5215] = {.lex_state = 130},
  [5216] = {.lex_state = 130, .external_lex_state = 4},
  [5217] = {.lex_state = 130, .external_lex_state = 4},
  [5218] = {.lex_state = 130},
  [5219] = {.lex_state = 130, .external_lex_state = 4},
  [5220] = {.lex_state = 130},
  [5221] = {.lex_state = 130, .external_lex_state = 4},
  [5222] = {.lex_state = 130, .external_lex_state = 4},
  [5223] = {.lex_state = 131},
  [5224] = {.lex_state = 130, .external_lex_state = 4},
  [5225] = {.lex_state = 130},
  [5226] = {.lex_state = 130, .external_lex_state = 4},
  [5227] = {.lex_state = 130},
  [5228] = {.lex_state = 130},
  [5229] = {.lex_state = 130, .external_lex_state = 4},
  [5230] = {.lex_state = 130, .external_lex_state = 4},
  [5231] = {.lex_state = 130},
  [5232] = {.lex_state = 130},
  [5233] = {.lex_state = 130, .external_lex_state = 4},
  [5234] = {.lex_state = 130, .external_lex_state = 4},
  [5235] = {.lex_state = 130, .external_lex_state = 4},
  [5236] = {.lex_state = 130},
  [5237] = {.lex_state = 130},
  [5238] = {.lex_state = 131},
  [5239] = {.lex_state = 130},
  [5240] = {.lex_state = 17},
  [5241] = {.lex_state = 130},
  [5242] = {.lex_state = 130, .external_lex_state = 4},
  [5243] = {.lex_state = 130, .external_lex_state = 4},
  [5244] = {.lex_state = 130},
  [5245] = {.lex_state = 130},
  [5246] = {.lex_state = 130},
  [5247] = {.lex_state = 130},
  [5248] = {.lex_state = 130},
  [5249] = {.lex_state = 130},
  [5250] = {.lex_state = 17},
  [5251] = {.lex_state = 130, .external_lex_state = 4},
  [5252] = {.lex_state = 130},
  [5253] = {.lex_state = 130, .external_lex_state = 4},
  [5254] = {.lex_state = 130, .external_lex_state = 4},
  [5255] = {.lex_state = 6},
  [5256] = {.lex_state = 130},
  [5257] = {.lex_state = 130},
  [5258] = {.lex_state = 130},
  [5259] = {.lex_state = 17},
  [5260] = {.lex_state = 130},
  [5261] = {.lex_state = 130},
  [5262] = {.lex_state = 130, .external_lex_state = 4},
  [5263] = {.lex_state = 130},
  [5264] = {.lex_state = 130},
  [5265] = {.lex_state = 130},
  [5266] = {.lex_state = 131},
  [5267] = {.lex_state = 130},
  [5268] = {.lex_state = 130, .external_lex_state = 4},
  [5269] = {.lex_state = 131},
  [5270] = {.lex_state = 130, .external_lex_state = 4},
  [5271] = {.lex_state = 130},
  [5272] = {.lex_state = 130, .external_lex_state = 4},
  [5273] = {.lex_state = 130, .external_lex_state = 4},
  [5274] = {.lex_state = 130},
  [5275] = {.lex_state = 130},
  [5276] = {.lex_state = 130},
  [5277] = {.lex_state = 130},
  [5278] = {.lex_state = 130, .external_lex_state = 4},
  [5279] = {.lex_state = 130, .external_lex_state = 4},
  [5280] = {.lex_state = 130},
  [5281] = {.lex_state = 130},
  [5282] = {.lex_state = 130},
  [5283] = {.lex_state = 130, .external_lex_state = 4},
  [5284] = {.lex_state = 130},
  [5285] = {.lex_state = 130},
  [5286] = {.lex_state = 130, .external_lex_state = 4},
  [5287] = {.lex_state = 130},
  [5288] = {.lex_state = 130},
  [5289] = {.lex_state = 130},
  [5290] = {.lex_state = 130, .external_lex_state = 4},
  [5291] = {.lex_state = 130},
  [5292] = {.lex_state = 130, .external_lex_state = 4},
  [5293] = {.lex_state = 130},
  [5294] = {.lex_state = 130, .external_lex_state = 4},
  [5295] = {.lex_state = 17},
  [5296] = {.lex_state = 130},
  [5297] = {.lex_state = 130},
  [5298] = {.lex_state = 130},
  [5299] = {.lex_state = 130, .external_lex_state = 4},
  [5300] = {.lex_state = 130},
  [5301] = {.lex_state = 130},
  [5302] = {.lex_state = 130},
  [5303] = {.lex_state = 130, .external_lex_state = 4},
  [5304] = {.lex_state = 130, .external_lex_state = 4},
  [5305] = {.lex_state = 130, .external_lex_state = 4},
  [5306] = {.lex_state = 130},
  [5307] = {.lex_state = 130},
  [5308] = {.lex_state = 130},
  [5309] = {.lex_state = 130},
  [5310] = {.lex_state = 130, .external_lex_state = 4},
  [5311] = {.lex_state = 130},
  [5312] = {.lex_state = 130},
  [5313] = {.lex_state = 130, .external_lex_state = 4},
  [5314] = {.lex_state = 130, .external_lex_state = 4},
  [5315] = {.lex_state = 130},
  [5316] = {.lex_state = 130, .external_lex_state = 4},
  [5317] = {.lex_state = 130},
  [5318] = {.lex_state = 130, .external_lex_state = 4},
  [5319] = {.lex_state = 130},
  [5320] = {.lex_state = 130, .external_lex_state = 4},
  [5321] = {.lex_state = 130, .external_lex_state = 4},
  [5322] = {.lex_state = 130},
  [5323] = {.lex_state = 130},
  [5324] = {.lex_state = 130},
  [5325] = {.lex_state = 130, .external_lex_state = 4},
  [5326] = {.lex_state = 130, .external_lex_state = 4},
  [5327] = {.lex_state = 130, .external_lex_state = 4},
  [5328] = {.lex_state = 130},
  [5329] = {.lex_state = 130},
  [5330] = {.lex_state = 130, .external_lex_state = 4},
  [5331] = {.lex_state = 130},
  [5332] = {.lex_state = 130, .external_lex_state = 4},
  [5333] = {.lex_state = 130},
  [5334] = {.lex_state = 17},
  [5335] = {.lex_state = 130, .external_lex_state = 4},
  [5336] = {.lex_state = 130, .external_lex_state = 4},
  [5337] = {.lex_state = 130},
  [5338] = {.lex_state = 130, .external_lex_state = 4},
  [5339] = {.lex_state = 130, .external_lex_state = 4},
  [5340] = {.lex_state = 130},
  [5341] = {.lex_state = 130, .external_lex_state = 4},
  [5342] = {.lex_state = 130, .external_lex_state = 4},
  [5343] = {.lex_state = 130},
  [5344] = {.lex_state = 130},
  [5345] = {.lex_state = 130, .external_lex_state = 4},
  [5346] = {.lex_state = 131},
  [5347] = {.lex_state = 130},
  [5348] = {.lex_state = 130, .external_lex_state = 4},
  [5349] = {.lex_state = 130, .external_lex_state = 4},
  [5350] = {.lex_state = 130},
  [5351] = {.lex_state = 131},
  [5352] = {.lex_state = 7, .external_lex_state = 4},
  [5353] = {.lex_state = 17},
  [5354] = {.lex_state = 130, .external_lex_state = 4},
  [5355] = {.lex_state = 130, .external_lex_state = 4},
  [5356] = {.lex_state = 130},
  [5357] = {.lex_state = 130, .external_lex_state = 4},
  [5358] = {.lex_state = 130},
  [5359] = {.lex_state = 130, .external_lex_state = 4},
  [5360] = {.lex_state = 130, .external_lex_state = 4},
  [5361] = {.lex_state = 130, .external_lex_state = 4},
  [5362] = {.lex_state = 130},
  [5363] = {.lex_state = 130},
  [5364] = {.lex_state = 130},
  [5365] = {.lex_state = 131},
  [5366] = {.lex_state = 130, .external_lex_state = 4},
  [5367] = {.lex_state = 130, .external_lex_state = 4},
  [5368] = {.lex_state = 130},
  [5369] = {.lex_state = 130},
  [5370] = {.lex_state = 130},
  [5371] = {.lex_state = 130},
  [5372] = {.lex_state = 130},
  [5373] = {.lex_state = 131},
  [5374] = {.lex_state = 130},
  [5375] = {.lex_state = 130, .external_lex_state = 4},
  [5376] = {.lex_state = 130},
  [5377] = {.lex_state = 130, .external_lex_state = 4},
  [5378] = {.lex_state = 130},
  [5379] = {.lex_state = 130, .external_lex_state = 4},
  [5380] = {.lex_state = 130},
  [5381] = {.lex_state = 130, .external_lex_state = 4},
  [5382] = {.lex_state = 130},
  [5383] = {.lex_state = 130, .external_lex_state = 4},
  [5384] = {.lex_state = 130, .external_lex_state = 4},
  [5385] = {.lex_state = 17},
  [5386] = {.lex_state = 130},
  [5387] = {.lex_state = 130},
  [5388] = {.lex_state = 130, .external_lex_state = 4},
  [5389] = {.lex_state = 130, .external_lex_state = 4},
  [5390] = {.lex_state = 130, .external_lex_state = 4},
  [5391] = {.lex_state = 130, .external_lex_state = 4},
  [5392] = {.lex_state = 130, .external_lex_state = 4},
  [5393] = {.lex_state = 130},
  [5394] = {.lex_state = 130},
  [5395] = {.lex_state = 130, .external_lex_state = 4},
  [5396] = {.lex_state = 130, .external_lex_state = 4},
  [5397] = {.lex_state = 130},
  [5398] = {.lex_state = 130},
  [5399] = {.lex_state = 130},
  [5400] = {.lex_state = 130},
  [5401] = {.lex_state = 130},
  [5402] = {.lex_state = 130},
  [5403] = {.lex_state = 130},
  [5404] = {.lex_state = 130},
  [5405] = {.lex_state = 130},
  [5406] = {.lex_state = 131},
  [5407] = {.lex_state = 130},
  [5408] = {.lex_state = 130, .external_lex_state = 4},
  [5409] = {.lex_state = 130},
  [5410] = {.lex_state = 130},
  [5411] = {.lex_state = 130},
  [5412] = {.lex_state = 130},
  [5413] = {.lex_state = 130, .external_lex_state = 4},
  [5414] = {.lex_state = 130},
  [5415] = {.lex_state = 130},
  [5416] = {.lex_state = 130},
  [5417] = {.lex_state = 130},
  [5418] = {.lex_state = 130},
  [5419] = {.lex_state = 130},
  [5420] = {.lex_state = 130},
  [5421] = {.lex_state = 130},
  [5422] = {.lex_state = 130},
  [5423] = {.lex_state = 130},
  [5424] = {.lex_state = 130},
  [5425] = {.lex_state = 130},
  [5426] = {.lex_state = 130},
  [5427] = {.lex_state = 130, .external_lex_state = 4},
  [5428] = {.lex_state = 130, .external_lex_state = 4},
  [5429] = {.lex_state = 130, .external_lex_state = 4},
  [5430] = {.lex_state = 130, .external_lex_state = 4},
  [5431] = {.lex_state = 130, .external_lex_state = 4},
  [5432] = {.lex_state = 130, .external_lex_state = 4},
  [5433] = {.lex_state = 130, .external_lex_state = 4},
  [5434] = {.lex_state = 131},
  [5435] = {.lex_state = 130, .external_lex_state = 4},
  [5436] = {.lex_state = 130, .external_lex_state = 4},
  [5437] = {.lex_state = 130, .external_lex_state = 4},
  [5438] = {.lex_state = 130, .external_lex_state = 4},
  [5439] = {.lex_state = 130, .external_lex_state = 4},
  [5440] = {.lex_state = 130},
  [5441] = {.lex_state = 130, .external_lex_state = 4},
  [5442] = {.lex_state = 130, .external_lex_state = 4},
  [5443] = {.lex_state = 130, .external_lex_state = 4},
  [5444] = {.lex_state = 130, .external_lex_state = 4},
  [5445] = {.lex_state = 130},
  [5446] = {.lex_state = 130, .external_lex_state = 4},
  [5447] = {.lex_state = 130, .external_lex_state = 4},
  [5448] = {.lex_state = 130, .external_lex_state = 4},
  [5449] = {.lex_state = 130},
  [5450] = {.lex_state = 130},
  [5451] = {.lex_state = 130},
  [5452] = {.lex_state = 130},
  [5453] = {.lex_state = 17},
  [5454] = {.lex_state = 130},
  [5455] = {.lex_state = 130},
  [5456] = {.lex_state = 130},
  [5457] = {.lex_state = 130},
  [5458] = {.lex_state = 130},
  [5459] = {.lex_state = 130},
  [5460] = {.lex_state = 130},
  [5461] = {.lex_state = 130},
  [5462] = {.lex_state = 130},
  [5463] = {.lex_state = 130},
  [5464] = {.lex_state = 130},
  [5465] = {.lex_state = 130},
  [5466] = {.lex_state = 130},
  [5467] = {.lex_state = 130, .external_lex_state = 4},
  [5468] = {.lex_state = 131},
  [5469] = {.lex_state = 130, .external_lex_state = 4},
  [5470] = {.lex_state = 130, .external_lex_state = 4},
  [5471] = {.lex_state = 130},
  [5472] = {.lex_state = 130},
  [5473] = {.lex_state = 17},
  [5474] = {.lex_state = 130},
  [5475] = {.lex_state = 130},
  [5476] = {.lex_state = 130},
  [5477] = {.lex_state = 130},
  [5478] = {.lex_state = 131},
  [5479] = {.lex_state = 130, .external_lex_state = 4},
  [5480] = {.lex_state = 130},
  [5481] = {.lex_state = 130},
  [5482] = {.lex_state = 130},
  [5483] = {.lex_state = 130},
  [5484] = {.lex_state = 130},
  [5485] = {.lex_state = 130},
  [5486] = {.lex_state = 130},
  [5487] = {.lex_state = 130},
  [5488] = {.lex_state = 130},
  [5489] = {.lex_state = 130},
  [5490] = {.lex_state = 130},
  [5491] = {.lex_state = 130},
  [5492] = {.lex_state = 130},
  [5493] = {.lex_state = 130},
  [5494] = {.lex_state = 130},
  [5495] = {.lex_state = 130},
  [5496] = {.lex_state = 130},
  [5497] = {.lex_state = 130},
  [5498] = {.lex_state = 130},
  [5499] = {.lex_state = 130},
  [5500] = {.lex_state = 130},
  [5501] = {.lex_state = 130},
  [5502] = {.lex_state = 6},
  [5503] = {.lex_state = 130, .external_lex_state = 4},
  [5504] = {.lex_state = 130},
  [5505] = {.lex_state = 130},
  [5506] = {.lex_state = 130},
  [5507] = {.lex_state = 130},
  [5508] = {.lex_state = 130},
  [5509] = {.lex_state = 130, .external_lex_state = 4},
  [5510] = {.lex_state = 130},
  [5511] = {.lex_state = 130},
  [5512] = {.lex_state = 130},
  [5513] = {.lex_state = 130},
  [5514] = {.lex_state = 130},
  [5515] = {.lex_state = 130},
  [5516] = {.lex_state = 130},
  [5517] = {.lex_state = 130},
  [5518] = {.lex_state = 130},
  [5519] = {.lex_state = 130},
  [5520] = {.lex_state = 130},
  [5521] = {.lex_state = 130},
  [5522] = {.lex_state = 130},
  [5523] = {.lex_state = 130},
  [5524] = {.lex_state = 130},
  [5525] = {.lex_state = 130},
  [5526] = {.lex_state = 130},
  [5527] = {.lex_state = 130},
  [5528] = {.lex_state = 130},
  [5529] = {.lex_state = 130, .external_lex_state = 4},
  [5530] = {.lex_state = 130, .external_lex_state = 4},
  [5531] = {.lex_state = 130, .external_lex_state = 4},
  [5532] = {.lex_state = 130},
  [5533] = {.lex_state = 130},
  [5534] = {.lex_state = 130},
  [5535] = {.lex_state = 130},
  [5536] = {.lex_state = 130, .external_lex_state = 4},
  [5537] = {.lex_state = 130, .external_lex_state = 4},
  [5538] = {.lex_state = 130, .external_lex_state = 4},
  [5539] = {.lex_state = 130, .external_lex_state = 4},
  [5540] = {.lex_state = 130, .external_lex_state = 4},
  [5541] = {.lex_state = 130, .external_lex_state = 4},
  [5542] = {.lex_state = 130, .external_lex_state = 4},
  [5543] = {.lex_state = 130, .external_lex_state = 4},
  [5544] = {.lex_state = 130, .external_lex_state = 4},
  [5545] = {.lex_state = 130, .external_lex_state = 4},
  [5546] = {.lex_state = 130, .external_lex_state = 4},
  [5547] = {.lex_state = 130, .external_lex_state = 4},
  [5548] = {.lex_state = 130, .external_lex_state = 4},
  [5549] = {.lex_state = 130, .external_lex_state = 4},
  [5550] = {.lex_state = 130, .external_lex_state = 4},
  [5551] = {.lex_state = 130, .external_lex_state = 4},
  [5552] = {.lex_state = 130, .external_lex_state = 4},
  [5553] = {.lex_state = 130},
  [5554] = {.lex_state = 130},
  [5555] = {.lex_state = 130},
  [5556] = {.lex_state = 130},
  [5557] = {.lex_state = 130, .external_lex_state = 4},
  [5558] = {.lex_state = 130, .external_lex_state = 4},
  [5559] = {.lex_state = 130, .external_lex_state = 4},
  [5560] = {.lex_state = 130, .external_lex_state = 4},
  [5561] = {.lex_state = 130, .external_lex_state = 4},
  [5562] = {.lex_state = 130, .external_lex_state = 4},
  [5563] = {.lex_state = 130, .external_lex_state = 4},
  [5564] = {.lex_state = 130, .external_lex_state = 4},
  [5565] = {.lex_state = 130, .external_lex_state = 4},
  [5566] = {.lex_state = 130, .external_lex_state = 4},
  [5567] = {.lex_state = 130, .external_lex_state = 4},
  [5568] = {.lex_state = 130, .external_lex_state = 4},
  [5569] = {.lex_state = 130, .external_lex_state = 4},
  [5570] = {.lex_state = 130, .external_lex_state = 4},
  [5571] = {.lex_state = 130, .external_lex_state = 4},
  [5572] = {.lex_state = 130, .external_lex_state = 4},
  [5573] = {.lex_state = 130, .external_lex_state = 4},
  [5574] = {.lex_state = 130, .external_lex_state = 4},
  [5575] = {.lex_state = 130, .external_lex_state = 4},
  [5576] = {.lex_state = 130, .external_lex_state = 4},
  [5577] = {.lex_state = 130, .external_lex_state = 4},
  [5578] = {.lex_state = 130, .external_lex_state = 4},
  [5579] = {.lex_state = 130, .external_lex_state = 4},
  [5580] = {.lex_state = 130, .external_lex_state = 4},
  [5581] = {.lex_state = 130},
  [5582] = {.lex_state = 130, .external_lex_state = 4},
  [5583] = {.lex_state = 130, .external_lex_state = 4},
  [5584] = {.lex_state = 130, .external_lex_state = 4},
  [5585] = {.lex_state = 130, .external_lex_state = 4},
  [5586] = {.lex_state = 130, .external_lex_state = 4},
  [5587] = {.lex_state = 130, .external_lex_state = 4},
  [5588] = {.lex_state = 130, .external_lex_state = 4},
  [5589] = {.lex_state = 130, .external_lex_state = 4},
  [5590] = {.lex_state = 131},
  [5591] = {.lex_state = 130, .external_lex_state = 4},
  [5592] = {.lex_state = 130},
  [5593] = {.lex_state = 130},
  [5594] = {.lex_state = 130},
  [5595] = {.lex_state = 130},
  [5596] = {.lex_state = 130},
  [5597] = {.lex_state = 130},
  [5598] = {.lex_state = 130},
  [5599] = {.lex_state = 130},
  [5600] = {.lex_state = 130},
  [5601] = {.lex_state = 130},
  [5602] = {.lex_state = 130},
  [5603] = {.lex_state = 130},
  [5604] = {.lex_state = 130},
  [5605] = {.lex_state = 130, .external_lex_state = 4},
  [5606] = {.lex_state = 130, .external_lex_state = 4},
  [5607] = {.lex_state = 130, .external_lex_state = 4},
  [5608] = {.lex_state = 130},
  [5609] = {.lex_state = 130},
  [5610] = {.lex_state = 130},
  [5611] = {.lex_state = 130},
  [5612] = {.lex_state = 130},
  [5613] = {.lex_state = 130},
  [5614] = {.lex_state = 130},
  [5615] = {.lex_state = 130, .external_lex_state = 4},
  [5616] = {.lex_state = 130},
  [5617] = {.lex_state = 130},
  [5618] = {.lex_state = 130, .external_lex_state = 4},
  [5619] = {.lex_state = 130},
  [5620] = {.lex_state = 130, .external_lex_state = 4},
  [5621] = {.lex_state = 130, .external_lex_state = 4},
  [5622] = {.lex_state = 130},
  [5623] = {.lex_state = 130, .external_lex_state = 4},
  [5624] = {.lex_state = 130},
  [5625] = {.lex_state = 130, .external_lex_state = 4},
  [5626] = {.lex_state = 130, .external_lex_state = 4},
  [5627] = {.lex_state = 130},
  [5628] = {.lex_state = 130},
  [5629] = {.lex_state = 130, .external_lex_state = 4},
  [5630] = {.lex_state = 130},
  [5631] = {.lex_state = 130, .external_lex_state = 4},
  [5632] = {.lex_state = 130, .external_lex_state = 4},
  [5633] = {.lex_state = 130},
  [5634] = {.lex_state = 130, .external_lex_state = 4},
  [5635] = {.lex_state = 130, .external_lex_state = 4},
  [5636] = {.lex_state = 130},
  [5637] = {.lex_state = 130},
  [5638] = {.lex_state = 130},
  [5639] = {.lex_state = 130, .external_lex_state = 4},
  [5640] = {.lex_state = 130},
  [5641] = {.lex_state = 130},
  [5642] = {.lex_state = 130},
  [5643] = {.lex_state = 130},
  [5644] = {.lex_state = 130},
  [5645] = {.lex_state = 130},
  [5646] = {.lex_state = 130},
  [5647] = {.lex_state = 130},
  [5648] = {.lex_state = 130},
  [5649] = {.lex_state = 130},
  [5650] = {.lex_state = 130},
  [5651] = {.lex_state = 130, .external_lex_state = 4},
  [5652] = {.lex_state = 130},
  [5653] = {.lex_state = 130},
  [5654] = {.lex_state = 130},
  [5655] = {.lex_state = 130},
  [5656] = {.lex_state = 130},
  [5657] = {.lex_state = 130},
  [5658] = {.lex_state = 130},
  [5659] = {.lex_state = 130},
  [5660] = {.lex_state = 130},
  [5661] = {.lex_state = 130},
  [5662] = {.lex_state = 130},
  [5663] = {.lex_state = 130},
  [5664] = {.lex_state = 130},
  [5665] = {.lex_state = 130},
  [5666] = {.lex_state = 130},
  [5667] = {.lex_state = 130},
  [5668] = {.lex_state = 130},
  [5669] = {.lex_state = 130},
  [5670] = {.lex_state = 130},
  [5671] = {.lex_state = 130},
  [5672] = {.lex_state = 130},
  [5673] = {.lex_state = 130},
  [5674] = {.lex_state = 130, .external_lex_state = 4},
  [5675] = {.lex_state = 130, .external_lex_state = 4},
  [5676] = {.lex_state = 130},
  [5677] = {.lex_state = 130, .external_lex_state = 4},
  [5678] = {.lex_state = 130},
  [5679] = {.lex_state = 130},
  [5680] = {.lex_state = 130},
  [5681] = {.lex_state = 130, .external_lex_state = 4},
  [5682] = {.lex_state = 130},
  [5683] = {.lex_state = 130, .external_lex_state = 4},
  [5684] = {.lex_state = 130},
  [5685] = {.lex_state = 130, .external_lex_state = 4},
  [5686] = {.lex_state = 130},
  [5687] = {.lex_state = 130},
  [5688] = {.lex_state = 130},
  [5689] = {.lex_state = 130},
  [5690] = {.lex_state = 130},
  [5691] = {.lex_state = 130},
  [5692] = {.lex_state = 130},
  [5693] = {.lex_state = 130},
  [5694] = {.lex_state = 130},
  [5695] = {.lex_state = 130},
  [5696] = {.lex_state = 130},
  [5697] = {.lex_state = 130},
  [5698] = {.lex_state = 130},
  [5699] = {.lex_state = 130},
  [5700] = {.lex_state = 130},
  [5701] = {.lex_state = 130},
  [5702] = {.lex_state = 130},
  [5703] = {.lex_state = 130, .external_lex_state = 4},
  [5704] = {.lex_state = 130, .external_lex_state = 4},
  [5705] = {.lex_state = 130},
  [5706] = {.lex_state = 130, .external_lex_state = 4},
  [5707] = {.lex_state = 130, .external_lex_state = 4},
  [5708] = {.lex_state = 130, .external_lex_state = 4},
  [5709] = {.lex_state = 130},
  [5710] = {.lex_state = 130},
  [5711] = {.lex_state = 130},
  [5712] = {.lex_state = 130},
  [5713] = {.lex_state = 130},
  [5714] = {.lex_state = 130},
  [5715] = {.lex_state = 130},
  [5716] = {.lex_state = 130, .external_lex_state = 4},
  [5717] = {.lex_state = 130, .external_lex_state = 4},
  [5718] = {.lex_state = 130, .external_lex_state = 4},
  [5719] = {.lex_state = 130, .external_lex_state = 4},
  [5720] = {.lex_state = 130},
  [5721] = {.lex_state = 130},
  [5722] = {.lex_state = 130},
  [5723] = {.lex_state = 130},
  [5724] = {.lex_state = 130},
  [5725] = {.lex_state = 130},
  [5726] = {.lex_state = 130},
  [5727] = {.lex_state = 130},
  [5728] = {.lex_state = 130},
  [5729] = {.lex_state = 130},
  [5730] = {.lex_state = 130, .external_lex_state = 4},
  [5731] = {.lex_state = 130, .external_lex_state = 4},
  [5732] = {.lex_state = 130},
  [5733] = {.lex_state = 130},
  [5734] = {.lex_state = 130},
  [5735] = {.lex_state = 130},
  [5736] = {.lex_state = 130},
  [5737] = {.lex_state = 130},
  [5738] = {.lex_state = 130},
  [5739] = {.lex_state = 130},
  [5740] = {.lex_state = 130},
  [5741] = {.lex_state = 130},
  [5742] = {.lex_state = 130},
  [5743] = {.lex_state = 130},
  [5744] = {.lex_state = 130, .external_lex_state = 4},
  [5745] = {.lex_state = 130},
  [5746] = {.lex_state = 130},
  [5747] = {.lex_state = 130, .external_lex_state = 4},
  [5748] = {.lex_state = 130},
  [5749] = {.lex_state = 130},
  [5750] = {.lex_state = 130},
  [5751] = {.lex_state = 130, .external_lex_state = 4},
  [5752] = {.lex_state = 131},
  [5753] = {.lex_state = 130},
  [5754] = {.lex_state = 131},
  [5755] = {.lex_state = 130},
  [5756] = {.lex_state = 130},
  [5757] = {.lex_state = 130},
  [5758] = {.lex_state = 130},
  [5759] = {.lex_state = 130},
  [5760] = {.lex_state = 130},
  [5761] = {.lex_state = 130},
  [5762] = {.lex_state = 130},
  [5763] = {.lex_state = 130},
  [5764] = {.lex_state = 130},
  [5765] = {.lex_state = 130},
  [5766] = {.lex_state = 130},
  [5767] = {.lex_state = 130},
  [5768] = {.lex_state = 130},
  [5769] = {.lex_state = 130},
  [5770] = {.lex_state = 130},
  [5771] = {.lex_state = 130},
  [5772] = {.lex_state = 130, .external_lex_state = 4},
  [5773] = {.lex_state = 130, .external_lex_state = 4},
  [5774] = {.lex_state = 130, .external_lex_state = 4},
  [5775] = {.lex_state = 130, .external_lex_state = 4},
  [5776] = {.lex_state = 130},
  [5777] = {.lex_state = 130, .external_lex_state = 4},
  [5778] = {.lex_state = 130},
  [5779] = {.lex_state = 130},
  [5780] = {.lex_state = 130},
  [5781] = {.lex_state = 130},
  [5782] = {.lex_state = 130},
  [5783] = {.lex_state = 130},
  [5784] = {.lex_state = 130, .external_lex_state = 4},
  [5785] = {.lex_state = 130, .external_lex_state = 4},
  [5786] = {.lex_state = 130},
  [5787] = {.lex_state = 130},
  [5788] = {.lex_state = 130},
  [5789] = {.lex_state = 130},
  [5790] = {.lex_state = 130},
  [5791] = {.lex_state = 130},
  [5792] = {.lex_state = 130, .external_lex_state = 4},
  [5793] = {.lex_state = 130},
  [5794] = {.lex_state = 130},
  [5795] = {.lex_state = 130, .external_lex_state = 4},
  [5796] = {.lex_state = 131},
  [5797] = {.lex_state = 130},
  [5798] = {.lex_state = 130},
  [5799] = {.lex_state = 130},
  [5800] = {.lex_state = 130},
  [5801] = {.lex_state = 130},
  [5802] = {.lex_state = 130},
  [5803] = {.lex_state = 130},
  [5804] = {.lex_state = 130},
  [5805] = {.lex_state = 130},
  [5806] = {.lex_state = 130},
  [5807] = {.lex_state = 130, .external_lex_state = 4},
  [5808] = {.lex_state = 130},
  [5809] = {.lex_state = 130, .external_lex_state = 4},
  [5810] = {.lex_state = 130},
  [5811] = {.lex_state = 130},
  [5812] = {.lex_state = 130},
  [5813] = {.lex_state = 130},
  [5814] = {.lex_state = 130},
  [5815] = {.lex_state = 130},
  [5816] = {.lex_state = 130},
  [5817] = {.lex_state = 130},
  [5818] = {.lex_state = 130},
  [5819] = {.lex_state = 130},
  [5820] = {.lex_state = 130},
  [5821] = {.lex_state = 130},
  [5822] = {.lex_state = 130},
  [5823] = {.lex_state = 130, .external_lex_state = 4},
  [5824] = {.lex_state = 130},
  [5825] = {.lex_state = 130, .external_lex_state = 4},
  [5826] = {.lex_state = 130},
  [5827] = {.lex_state = 130},
  [5828] = {.lex_state = 130, .external_lex_state = 4},
  [5829] = {.lex_state = 130},
  [5830] = {.lex_state = 130},
  [5831] = {.lex_state = 130},
  [5832] = {.lex_state = 130},
  [5833] = {.lex_state = 131},
  [5834] = {.lex_state = 130},
  [5835] = {.lex_state = 130, .external_lex_state = 4},
  [5836] = {.lex_state = 130, .external_lex_state = 4},
  [5837] = {.lex_state = 130},
  [5838] = {.lex_state = 130, .external_lex_state = 4},
  [5839] = {.lex_state = 130},
  [5840] = {.lex_state = 130},
  [5841] = {.lex_state = 130},
  [5842] = {.lex_state = 130},
  [5843] = {.lex_state = 130},
  [5844] = {.lex_state = 130},
  [5845] = {.lex_state = 130},
  [5846] = {.lex_state = 130},
  [5847] = {.lex_state = 130},
  [5848] = {.lex_state = 130},
  [5849] = {.lex_state = 130},
  [5850] = {.lex_state = 130},
  [5851] = {.lex_state = 130},
  [5852] = {.lex_state = 130},
  [5853] = {.lex_state = 130},
  [5854] = {.lex_state = 130},
  [5855] = {.lex_state = 130},
  [5856] = {.lex_state = 130},
  [5857] = {.lex_state = 130},
  [5858] = {.lex_state = 130},
  [5859] = {.lex_state = 130},
  [5860] = {.lex_state = 130},
  [5861] = {.lex_state = 130},
  [5862] = {.lex_state = 130},
  [5863] = {.lex_state = 130},
  [5864] = {.lex_state = 130},
  [5865] = {.lex_state = 130},
  [5866] = {.lex_state = 130},
  [5867] = {.lex_state = 130},
  [5868] = {.lex_state = 130},
  [5869] = {.lex_state = 130},
  [5870] = {.lex_state = 130},
  [5871] = {.lex_state = 130},
  [5872] = {.lex_state = 130},
  [5873] = {.lex_state = 130, .external_lex_state = 4},
  [5874] = {.lex_state = 131},
  [5875] = {.lex_state = 131},
  [5876] = {.lex_state = 130},
  [5877] = {.lex_state = 130},
  [5878] = {.lex_state = 130},
  [5879] = {.lex_state = 130},
  [5880] = {.lex_state = 130},
  [5881] = {.lex_state = 130},
  [5882] = {.lex_state = 130},
  [5883] = {.lex_state = 130},
  [5884] = {.lex_state = 130},
  [5885] = {.lex_state = 130},
  [5886] = {.lex_state = 130, .external_lex_state = 4},
  [5887] = {.lex_state = 130},
  [5888] = {.lex_state = 130},
  [5889] = {.lex_state = 130},
  [5890] = {.lex_state = 130},
  [5891] = {.lex_state = 130},
  [5892] = {.lex_state = 130},
  [5893] = {.lex_state = 130},
  [5894] = {.lex_state = 130},
  [5895] = {.lex_state = 130},
  [5896] = {.lex_state = 130},
  [5897] = {.lex_state = 130},
  [5898] = {.lex_state = 130, .external_lex_state = 4},
  [5899] = {.lex_state = 130, .external_lex_state = 4},
  [5900] = {.lex_state = 131},
  [5901] = {.lex_state = 130, .external_lex_state = 4},
  [5902] = {.lex_state = 130, .external_lex_state = 4},
  [5903] = {.lex_state = 131},
  [5904] = {.lex_state = 130, .external_lex_state = 4},
  [5905] = {.lex_state = 130},
  [5906] = {.lex_state = 131},
  [5907] = {.lex_state = 130, .external_lex_state = 4},
  [5908] = {.lex_state = 130},
  [5909] = {.lex_state = 131},
  [5910] = {.lex_state = 130, .external_lex_state = 4},
  [5911] = {.lex_state = 131},
  [5912] = {.lex_state = 130, .external_lex_state = 4},
  [5913] = {.lex_state = 130, .external_lex_state = 4},
  [5914] = {.lex_state = 130, .external_lex_state = 4},
  [5915] = {.lex_state = 130, .external_lex_state = 4},
  [5916] = {.lex_state = 130},
  [5917] = {.lex_state = 130},
  [5918] = {.lex_state = 130, .external_lex_state = 4},
  [5919] = {.lex_state = 130},
  [5920] = {.lex_state = 130},
  [5921] = {.lex_state = 130},
  [5922] = {.lex_state = 130},
  [5923] = {.lex_state = 130},
  [5924] = {.lex_state = 130},
  [5925] = {.lex_state = 130},
  [5926] = {.lex_state = 130},
  [5927] = {.lex_state = 130},
  [5928] = {.lex_state = 130},
  [5929] = {.lex_state = 130},
  [5930] = {.lex_state = 131},
  [5931] = {.lex_state = 130},
  [5932] = {.lex_state = 130},
  [5933] = {.lex_state = 130},
  [5934] = {.lex_state = 131},
  [5935] = {.lex_state = 130},
  [5936] = {.lex_state = 130},
  [5937] = {.lex_state = 130},
  [5938] = {.lex_state = 130},
  [5939] = {.lex_state = 130},
  [5940] = {.lex_state = 130},
  [5941] = {.lex_state = 130},
  [5942] = {.lex_state = 130},
  [5943] = {.lex_state = 130},
  [5944] = {.lex_state = 130},
  [5945] = {.lex_state = 130},
  [5946] = {.lex_state = 130},
  [5947] = {.lex_state = 130},
  [5948] = {.lex_state = 131},
  [5949] = {.lex_state = 130},
  [5950] = {.lex_state = 130},
  [5951] = {.lex_state = 130},
  [5952] = {.lex_state = 130},
  [5953] = {.lex_state = 130},
  [5954] = {.lex_state = 130},
  [5955] = {.lex_state = 130},
  [5956] = {.lex_state = 130},
  [5957] = {.lex_state = 130},
  [5958] = {.lex_state = 130},
  [5959] = {.lex_state = 130},
  [5960] = {.lex_state = 130},
  [5961] = {.lex_state = 130},
  [5962] = {.lex_state = 130},
  [5963] = {.lex_state = 130},
  [5964] = {.lex_state = 130},
  [5965] = {.lex_state = 130},
  [5966] = {.lex_state = 130},
  [5967] = {.lex_state = 130},
  [5968] = {.lex_state = 130},
  [5969] = {.lex_state = 130},
  [5970] = {.lex_state = 130},
  [5971] = {.lex_state = 130},
  [5972] = {.lex_state = 130},
  [5973] = {.lex_state = 130},
  [5974] = {.lex_state = 130},
  [5975] = {.lex_state = 131},
  [5976] = {.lex_state = 130},
  [5977] = {.lex_state = 130},
  [5978] = {.lex_state = 130},
  [5979] = {.lex_state = 130},
  [5980] = {.lex_state = 130},
  [5981] = {.lex_state = 130},
  [5982] = {.lex_state = 130},
  [5983] = {.lex_state = 131},
  [5984] = {.lex_state = 130},
  [5985] = {.lex_state = 130},
  [5986] = {.lex_state = 130},
  [5987] = {.lex_state = 131},
  [5988] = {.lex_state = 130},
  [5989] = {.lex_state = 130},
  [5990] = {.lex_state = 130},
  [5991] = {.lex_state = 130},
  [5992] = {.lex_state = 130},
  [5993] = {.lex_state = 130},
  [5994] = {.lex_state = 130},
  [5995] = {.lex_state = 130},
  [5996] = {.lex_state = 130},
  [5997] = {.lex_state = 130},
  [5998] = {.lex_state = 130},
  [5999] = {.lex_state = 130},
  [6000] = {.lex_state = 130},
  [6001] = {.lex_state = 130},
  [6002] = {.lex_state = 130},
  [6003] = {.lex_state = 131},
  [6004] = {.lex_state = 130},
  [6005] = {.lex_state = 130},
  [6006] = {.lex_state = 130},
  [6007] = {.lex_state = 130},
  [6008] = {.lex_state = 130},
  [6009] = {.lex_state = 130},
  [6010] = {.lex_state = 130},
  [6011] = {.lex_state = 130},
  [6012] = {.lex_state = 130},
  [6013] = {.lex_state = 130},
  [6014] = {.lex_state = 130},
  [6015] = {.lex_state = 130},
  [6016] = {.lex_state = 130},
  [6017] = {.lex_state = 130},
  [6018] = {.lex_state = 130},
  [6019] = {.lex_state = 130},
  [6020] = {.lex_state = 17},
  [6021] = {.lex_state = 130},
  [6022] = {.lex_state = 130},
  [6023] = {.lex_state = 130, .external_lex_state = 4},
  [6024] = {.lex_state = 131},
  [6025] = {.lex_state = 130},
  [6026] = {.lex_state = 130},
  [6027] = {.lex_state = 130, .external_lex_state = 4},
  [6028] = {.lex_state = 130},
  [6029] = {.lex_state = 130},
  [6030] = {.lex_state = 130},
  [6031] = {.lex_state = 130},
  [6032] = {.lex_state = 130},
  [6033] = {.lex_state = 131},
  [6034] = {.lex_state = 131},
  [6035] = {.lex_state = 130},
  [6036] = {.lex_state = 130},
  [6037] = {.lex_state = 131},
  [6038] = {.lex_state = 130},
  [6039] = {.lex_state = 130},
  [6040] = {.lex_state = 130},
  [6041] = {.lex_state = 130, .external_lex_state = 4},
  [6042] = {.lex_state = 130},
  [6043] = {.lex_state = 130},
  [6044] = {.lex_state = 130, .external_lex_state = 4},
  [6045] = {.lex_state = 130},
  [6046] = {.lex_state = 131},
  [6047] = {.lex_state = 130},
  [6048] = {.lex_state = 130},
  [6049] = {.lex_state = 130},
  [6050] = {.lex_state = 131},
  [6051] = {.lex_state = 130},
  [6052] = {.lex_state = 131},
  [6053] = {.lex_state = 130},
  [6054] = {.lex_state = 130},
  [6055] = {.lex_state = 131},
  [6056] = {.lex_state = 130},
  [6057] = {.lex_state = 130},
  [6058] = {.lex_state = 130},
  [6059] = {.lex_state = 131},
  [6060] = {.lex_state = 130},
  [6061] = {.lex_state = 130},
  [6062] = {.lex_state = 130},
  [6063] = {.lex_state = 130},
  [6064] = {.lex_state = 130},
  [6065] = {.lex_state = 130},
  [6066] = {.lex_state = 130},
  [6067] = {.lex_state = 130},
  [6068] = {.lex_state = 130},
  [6069] = {.lex_state = 130},
  [6070] = {.lex_state = 130},
  [6071] = {.lex_state = 130},
  [6072] = {.lex_state = 130},
  [6073] = {.lex_state = 130},
  [6074] = {.lex_state = 130},
  [6075] = {.lex_state = 130, .external_lex_state = 4},
  [6076] = {.lex_state = 130},
  [6077] = {.lex_state = 130},
  [6078] = {.lex_state = 130},
  [6079] = {.lex_state = 130},
  [6080] = {.lex_state = 130},
  [6081] = {.lex_state = 130},
  [6082] = {.lex_state = 131},
  [6083] = {.lex_state = 130},
  [6084] = {.lex_state = 130},
  [6085] = {.lex_state = 130},
  [6086] = {.lex_state = 130},
  [6087] = {.lex_state = 130},
  [6088] = {.lex_state = 130},
  [6089] = {.lex_state = 130},
  [6090] = {.lex_state = 130},
  [6091] = {.lex_state = 130},
  [6092] = {.lex_state = 130},
  [6093] = {.lex_state = 130, .external_lex_state = 4},
  [6094] = {.lex_state = 130},
  [6095] = {.lex_state = 130},
  [6096] = {.lex_state = 130},
  [6097] = {.lex_state = 130},
  [6098] = {.lex_state = 130},
  [6099] = {.lex_state = 130},
  [6100] = {.lex_state = 130, .external_lex_state = 4},
  [6101] = {.lex_state = 130},
  [6102] = {.lex_state = 130},
  [6103] = {.lex_state = 130},
  [6104] = {.lex_state = 130},
  [6105] = {.lex_state = 130},
  [6106] = {.lex_state = 131},
  [6107] = {.lex_state = 130},
  [6108] = {.lex_state = 130},
  [6109] = {.lex_state = 130},
  [6110] = {.lex_state = 130},
  [6111] = {.lex_state = 130},
  [6112] = {.lex_state = 130},
  [6113] = {.lex_state = 130},
  [6114] = {.lex_state = 130},
  [6115] = {.lex_state = 130},
  [6116] = {.lex_state = 130},
  [6117] = {.lex_state = 130},
  [6118] = {.lex_state = 130},
  [6119] = {.lex_state = 130},
  [6120] = {.lex_state = 130},
  [6121] = {.lex_state = 130},
  [6122] = {.lex_state = 130},
  [6123] = {.lex_state = 130},
  [6124] = {.lex_state = 130},
  [6125] = {.lex_state = 10},
  [6126] = {.lex_state = 130},
  [6127] = {.lex_state = 10},
  [6128] = {.lex_state = 130},
  [6129] = {.lex_state = 130},
  [6130] = {.lex_state = 10},
  [6131] = {.lex_state = 10},
  [6132] = {.lex_state = 130},
  [6133] = {.lex_state = 130},
  [6134] = {.lex_state = 130},
  [6135] = {.lex_state = 130},
  [6136] = {.lex_state = 130},
  [6137] = {.lex_state = 10},
  [6138] = {.lex_state = 130},
  [6139] = {.lex_state = 131},
  [6140] = {.lex_state = 130},
  [6141] = {.lex_state = 130},
  [6142] = {.lex_state = 130},
  [6143] = {.lex_state = 130},
  [6144] = {.lex_state = 130},
  [6145] = {.lex_state = 130},
  [6146] = {.lex_state = 130},
  [6147] = {.lex_state = 130},
  [6148] = {.lex_state = 130},
  [6149] = {.lex_state = 131},
  [6150] = {.lex_state = 130},
  [6151] = {.lex_state = 130},
  [6152] = {.lex_state = 130},
  [6153] = {.lex_state = 130},
  [6154] = {.lex_state = 130},
  [6155] = {.lex_state = 130, .external_lex_state = 4},
  [6156] = {.lex_state = 130},
  [6157] = {.lex_state = 130},
  [6158] = {.lex_state = 131},
  [6159] = {.lex_state = 130},
  [6160] = {.lex_state = 130},
  [6161] = {.lex_state = 130},
  [6162] = {.lex_state = 130},
  [6163] = {.lex_state = 131},
  [6164] = {.lex_state = 130},
  [6165] = {.lex_state = 130},
  [6166] = {.lex_state = 10},
  [6167] = {.lex_state = 130},
  [6168] = {.lex_state = 130},
  [6169] = {.lex_state = 130},
  [6170] = {.lex_state = 10},
  [6171] = {.lex_state = 10},
  [6172] = {.lex_state = 130},
  [6173] = {.lex_state = 10},
  [6174] = {.lex_state = 130},
  [6175] = {.lex_state = 10},
  [6176] = {.lex_state = 130},
  [6177] = {.lex_state = 130},
  [6178] = {.lex_state = 130},
  [6179] = {.lex_state = 130},
  [6180] = {.lex_state = 130},
  [6181] = {.lex_state = 130},
  [6182] = {.lex_state = 130},
  [6183] = {.lex_state = 130},
  [6184] = {.lex_state = 130},
  [6185] = {.lex_state = 130},
  [6186] = {.lex_state = 10},
  [6187] = {.lex_state = 130},
  [6188] = {.lex_state = 130},
  [6189] = {.lex_state = 130},
  [6190] = {.lex_state = 130},
  [6191] = {.lex_state = 130},
  [6192] = {.lex_state = 130},
  [6193] = {.lex_state = 130},
  [6194] = {.lex_state = 10},
  [6195] = {.lex_state = 10},
  [6196] = {.lex_state = 130},
  [6197] = {.lex_state = 130},
  [6198] = {.lex_state = 130},
  [6199] = {.lex_state = 130},
  [6200] = {.lex_state = 130},
  [6201] = {.lex_state = 130},
  [6202] = {.lex_state = 131},
  [6203] = {.lex_state = 130},
  [6204] = {.lex_state = 130},
  [6205] = {.lex_state = 10},
  [6206] = {.lex_state = 130},
  [6207] = {.lex_state = 10},
  [6208] = {.lex_state = 130},
  [6209] = {.lex_state = 130},
  [6210] = {.lex_state = 130},
  [6211] = {.lex_state = 130},
  [6212] = {.lex_state = 130},
  [6213] = {.lex_state = 130},
  [6214] = {.lex_state = 130},
  [6215] = {.lex_state = 130},
  [6216] = {.lex_state = 130},
  [6217] = {.lex_state = 130},
  [6218] = {.lex_state = 130},
  [6219] = {.lex_state = 130},
  [6220] = {.lex_state = 130},
  [6221] = {.lex_state = 131},
  [6222] = {.lex_state = 130},
  [6223] = {.lex_state = 130},
  [6224] = {.lex_state = 130},
  [6225] = {.lex_state = 130},
  [6226] = {.lex_state = 130},
  [6227] = {.lex_state = 130},
  [6228] = {.lex_state = 10},
  [6229] = {.lex_state = 130},
  [6230] = {.lex_state = 130},
  [6231] = {.lex_state = 130},
  [6232] = {.lex_state = 130},
  [6233] = {.lex_state = 10},
  [6234] = {.lex_state = 10},
  [6235] = {.lex_state = 130},
  [6236] = {.lex_state = 130},
  [6237] = {.lex_state = 130},
  [6238] = {.lex_state = 130},
  [6239] = {.lex_state = 130},
  [6240] = {.lex_state = 130},
  [6241] = {.lex_state = 130},
  [6242] = {.lex_state = 130},
  [6243] = {.lex_state = 130},
  [6244] = {.lex_state = 130},
  [6245] = {.lex_state = 130},
  [6246] = {.lex_state = 130},
  [6247] = {.lex_state = 130},
  [6248] = {.lex_state = 130},
  [6249] = {.lex_state = 130},
  [6250] = {.lex_state = 130},
  [6251] = {.lex_state = 130},
  [6252] = {.lex_state = 130},
  [6253] = {.lex_state = 130},
  [6254] = {.lex_state = 130},
  [6255] = {.lex_state = 130},
  [6256] = {.lex_state = 130},
  [6257] = {.lex_state = 130},
  [6258] = {.lex_state = 130},
  [6259] = {.lex_state = 130},
  [6260] = {.lex_state = 130},
  [6261] = {.lex_state = 131},
  [6262] = {.lex_state = 130},
  [6263] = {.lex_state = 131},
  [6264] = {.lex_state = 130},
  [6265] = {.lex_state = 130},
  [6266] = {.lex_state = 130},
  [6267] = {.lex_state = 10},
  [6268] = {.lex_state = 10},
  [6269] = {.lex_state = 10},
  [6270] = {.lex_state = 130},
  [6271] = {.lex_state = 130},
  [6272] = {.lex_state = 10},
  [6273] = {.lex_state = 10},
  [6274] = {.lex_state = 130},
  [6275] = {.lex_state = 130},
  [6276] = {.lex_state = 130},
  [6277] = {.lex_state = 130},
  [6278] = {.lex_state = 130},
  [6279] = {.lex_state = 130},
  [6280] = {.lex_state = 10},
  [6281] = {.lex_state = 130},
  [6282] = {.lex_state = 130},
  [6283] = {.lex_state = 130},
  [6284] = {.lex_state = 130},
  [6285] = {.lex_state = 130},
  [6286] = {.lex_state = 10},
  [6287] = {.lex_state = 130},
  [6288] = {.lex_state = 10},
  [6289] = {.lex_state = 130},
  [6290] = {.lex_state = 130},
  [6291] = {.lex_state = 10},
  [6292] = {.lex_state = 130},
  [6293] = {.lex_state = 130},
  [6294] = {.lex_state = 130},
  [6295] = {.lex_state = 130},
  [6296] = {.lex_state = 130},
  [6297] = {.lex_state = 130},
  [6298] = {.lex_state = 130},
  [6299] = {.lex_state = 130},
  [6300] = {.lex_state = 130},
  [6301] = {.lex_state = 130},
  [6302] = {.lex_state = 130},
  [6303] = {.lex_state = 130},
  [6304] = {.lex_state = 130},
  [6305] = {.lex_state = 130},
  [6306] = {.lex_state = 130},
  [6307] = {.lex_state = 130},
  [6308] = {.lex_state = 130},
  [6309] = {.lex_state = 130},
  [6310] = {.lex_state = 130},
  [6311] = {.lex_state = 130},
  [6312] = {.lex_state = 130},
  [6313] = {.lex_state = 130},
  [6314] = {.lex_state = 130},
  [6315] = {.lex_state = 130},
  [6316] = {.lex_state = 130},
  [6317] = {.lex_state = 130},
  [6318] = {.lex_state = 130},
  [6319] = {.lex_state = 130},
  [6320] = {.lex_state = 130},
  [6321] = {.lex_state = 130},
  [6322] = {.lex_state = 130},
  [6323] = {.lex_state = 130},
  [6324] = {.lex_state = 130},
  [6325] = {.lex_state = 130},
  [6326] = {.lex_state = 130},
  [6327] = {.lex_state = 130},
  [6328] = {.lex_state = 130},
  [6329] = {.lex_state = 130},
  [6330] = {.lex_state = 130},
  [6331] = {.lex_state = 130},
  [6332] = {.lex_state = 130},
  [6333] = {.lex_state = 130},
  [6334] = {.lex_state = 130},
  [6335] = {.lex_state = 130},
  [6336] = {.lex_state = 130},
  [6337] = {.lex_state = 130},
  [6338] = {.lex_state = 130},
  [6339] = {.lex_state = 130},
  [6340] = {.lex_state = 130},
  [6341] = {.lex_state = 130},
  [6342] = {.lex_state = 130},
  [6343] = {.lex_state = 130},
  [6344] = {.lex_state = 131},
  [6345] = {.lex_state = 130},
  [6346] = {.lex_state = 130},
  [6347] = {.lex_state = 130},
  [6348] = {.lex_state = 130},
  [6349] = {.lex_state = 130},
  [6350] = {.lex_state = 130},
  [6351] = {.lex_state = 130},
  [6352] = {.lex_state = 130},
  [6353] = {.lex_state = 130},
  [6354] = {.lex_state = 130},
  [6355] = {.lex_state = 130},
  [6356] = {.lex_state = 130},
  [6357] = {.lex_state = 130},
  [6358] = {.lex_state = 130},
  [6359] = {.lex_state = 130},
  [6360] = {.lex_state = 130},
  [6361] = {.lex_state = 130},
  [6362] = {.lex_state = 130},
  [6363] = {.lex_state = 130},
  [6364] = {.lex_state = 130},
  [6365] = {.lex_state = 130},
  [6366] = {.lex_state = 130},
  [6367] = {.lex_state = 130},
  [6368] = {.lex_state = 130},
  [6369] = {.lex_state = 130},
  [6370] = {.lex_state = 130},
  [6371] = {.lex_state = 130},
  [6372] = {.lex_state = 130},
  [6373] = {.lex_state = 130},
  [6374] = {.lex_state = 130},
  [6375] = {.lex_state = 130},
  [6376] = {.lex_state = 130},
  [6377] = {.lex_state = 130},
  [6378] = {.lex_state = 130},
  [6379] = {.lex_state = 130},
  [6380] = {.lex_state = 130},
  [6381] = {.lex_state = 130},
  [6382] = {.lex_state = 130},
  [6383] = {.lex_state = 130},
  [6384] = {.lex_state = 130},
  [6385] = {.lex_state = 130},
  [6386] = {.lex_state = 130},
  [6387] = {.lex_state = 130},
  [6388] = {.lex_state = 130},
  [6389] = {.lex_state = 130},
  [6390] = {.lex_state = 130},
  [6391] = {.lex_state = 130},
  [6392] = {.lex_state = 130},
  [6393] = {.lex_state = 130},
  [6394] = {.lex_state = 130},
  [6395] = {.lex_state = 130},
  [6396] = {.lex_state = 130},
  [6397] = {.lex_state = 130},
  [6398] = {.lex_state = 130},
  [6399] = {.lex_state = 130},
  [6400] = {.lex_state = 130},
  [6401] = {.lex_state = 130},
  [6402] = {.lex_state = 130},
  [6403] = {.lex_state = 130},
  [6404] = {.lex_state = 130},
  [6405] = {.lex_state = 130},
  [6406] = {.lex_state = 130},
  [6407] = {.lex_state = 130},
  [6408] = {.lex_state = 130},
  [6409] = {.lex_state = 130},
  [6410] = {.lex_state = 130},
  [6411] = {.lex_state = 130},
  [6412] = {.lex_state = 130},
  [6413] = {.lex_state = 130},
  [6414] = {.lex_state = 130},
  [6415] = {.lex_state = 130},
  [6416] = {.lex_state = 130},
  [6417] = {.lex_state = 131},
  [6418] = {.lex_state = 130},
  [6419] = {.lex_state = 130},
  [6420] = {.lex_state = 130},
  [6421] = {.lex_state = 130},
  [6422] = {.lex_state = 130},
  [6423] = {.lex_state = 130},
  [6424] = {.lex_state = 130},
  [6425] = {.lex_state = 130},
  [6426] = {.lex_state = 130},
  [6427] = {.lex_state = 130},
  [6428] = {.lex_state = 130},
  [6429] = {.lex_state = 130},
  [6430] = {.lex_state = 130},
  [6431] = {.lex_state = 130},
  [6432] = {.lex_state = 130},
  [6433] = {.lex_state = 130},
  [6434] = {.lex_state = 130},
  [6435] = {.lex_state = 130},
  [6436] = {.lex_state = 130},
  [6437] = {.lex_state = 130},
  [6438] = {.lex_state = 130},
  [6439] = {.lex_state = 130},
  [6440] = {.lex_state = 130},
  [6441] = {.lex_state = 130},
  [6442] = {.lex_state = 130},
  [6443] = {.lex_state = 130},
  [6444] = {.lex_state = 130},
  [6445] = {.lex_state = 130},
  [6446] = {.lex_state = 130},
  [6447] = {.lex_state = 130},
  [6448] = {.lex_state = 130},
  [6449] = {.lex_state = 130},
  [6450] = {.lex_state = 130},
  [6451] = {.lex_state = 130},
  [6452] = {.lex_state = 130},
  [6453] = {.lex_state = 130},
  [6454] = {.lex_state = 130},
  [6455] = {.lex_state = 130},
  [6456] = {.lex_state = 130},
  [6457] = {.lex_state = 130},
  [6458] = {.lex_state = 130},
  [6459] = {.lex_state = 130},
  [6460] = {.lex_state = 130},
  [6461] = {.lex_state = 130},
  [6462] = {.lex_state = 130},
  [6463] = {.lex_state = 130},
  [6464] = {.lex_state = 130},
  [6465] = {.lex_state = 130},
  [6466] = {.lex_state = 131},
  [6467] = {.lex_state = 130},
  [6468] = {.lex_state = 130},
  [6469] = {.lex_state = 130},
  [6470] = {.lex_state = 130},
  [6471] = {.lex_state = 130},
  [6472] = {.lex_state = 130},
  [6473] = {.lex_state = 130},
  [6474] = {.lex_state = 130},
  [6475] = {.lex_state = 130},
  [6476] = {.lex_state = 130},
  [6477] = {.lex_state = 130},
  [6478] = {.lex_state = 130},
  [6479] = {.lex_state = 130},
  [6480] = {.lex_state = 130},
  [6481] = {.lex_state = 130},
  [6482] = {.lex_state = 130},
  [6483] = {.lex_state = 130},
  [6484] = {.lex_state = 131},
  [6485] = {.lex_state = 130},
  [6486] = {.lex_state = 130},
  [6487] = {.lex_state = 130},
  [6488] = {.lex_state = 130},
  [6489] = {.lex_state = 130},
  [6490] = {.lex_state = 130},
  [6491] = {.lex_state = 130},
  [6492] = {.lex_state = 130},
  [6493] = {.lex_state = 130},
  [6494] = {.lex_state = 130},
  [6495] = {.lex_state = 130},
  [6496] = {.lex_state = 130},
  [6497] = {.lex_state = 130},
  [6498] = {.lex_state = 130},
  [6499] = {.lex_state = 130},
  [6500] = {.lex_state = 130},
  [6501] = {.lex_state = 130},
  [6502] = {.lex_state = 130},
  [6503] = {.lex_state = 130},
  [6504] = {.lex_state = 130},
  [6505] = {.lex_state = 130},
  [6506] = {.lex_state = 130},
  [6507] = {.lex_state = 130},
  [6508] = {.lex_state = 130},
  [6509] = {.lex_state = 130},
  [6510] = {.lex_state = 130},
  [6511] = {.lex_state = 130},
  [6512] = {.lex_state = 130},
  [6513] = {.lex_state = 130},
  [6514] = {.lex_state = 130},
  [6515] = {.lex_state = 130},
  [6516] = {.lex_state = 130},
  [6517] = {.lex_state = 131},
  [6518] = {.lex_state = 130},
  [6519] = {.lex_state = 130},
  [6520] = {.lex_state = 130},
  [6521] = {.lex_state = 130},
  [6522] = {.lex_state = 130},
  [6523] = {.lex_state = 130},
  [6524] = {.lex_state = 130},
  [6525] = {.lex_state = 130},
  [6526] = {.lex_state = 130},
  [6527] = {.lex_state = 130},
  [6528] = {.lex_state = 130},
  [6529] = {.lex_state = 130},
  [6530] = {.lex_state = 130},
  [6531] = {.lex_state = 130},
  [6532] = {.lex_state = 130},
  [6533] = {.lex_state = 130},
  [6534] = {.lex_state = 130},
  [6535] = {.lex_state = 130},
  [6536] = {.lex_state = 130},
  [6537] = {.lex_state = 130},
  [6538] = {.lex_state = 130},
  [6539] = {.lex_state = 130},
  [6540] = {.lex_state = 130},
  [6541] = {.lex_state = 130},
  [6542] = {.lex_state = 130},
  [6543] = {.lex_state = 130},
  [6544] = {.lex_state = 130},
  [6545] = {.lex_state = 130},
  [6546] = {.lex_state = 130},
  [6547] = {.lex_state = 130},
  [6548] = {.lex_state = 130},
  [6549] = {.lex_state = 130},
  [6550] = {.lex_state = 130},
  [6551] = {.lex_state = 130},
  [6552] = {.lex_state = 130},
  [6553] = {.lex_state = 130},
  [6554] = {.lex_state = 130},
  [6555] = {.lex_state = 130},
  [6556] = {.lex_state = 130},
  [6557] = {.lex_state = 130},
  [6558] = {.lex_state = 130},
  [6559] = {.lex_state = 130},
  [6560] = {.lex_state = 130},
  [6561] = {.lex_state = 130},
  [6562] = {.lex_state = 130},
  [6563] = {.lex_state = 130},
  [6564] = {.lex_state = 130},
  [6565] = {.lex_state = 130},
  [6566] = {.lex_state = 130},
  [6567] = {.lex_state = 130},
  [6568] = {.lex_state = 130},
  [6569] = {.lex_state = 130},
  [6570] = {.lex_state = 130},
  [6571] = {.lex_state = 130},
  [6572] = {.lex_state = 130},
  [6573] = {.lex_state = 130},
  [6574] = {.lex_state = 130},
  [6575] = {.lex_state = 130},
  [6576] = {.lex_state = 130},
  [6577] = {.lex_state = 130},
  [6578] = {.lex_state = 130},
  [6579] = {.lex_state = 130},
  [6580] = {.lex_state = 131},
  [6581] = {.lex_state = 130},
  [6582] = {.lex_state = 131},
  [6583] = {.lex_state = 130},
  [6584] = {.lex_state = 130},
  [6585] = {.lex_state = 130},
  [6586] = {.lex_state = 130},
  [6587] = {.lex_state = 130},
  [6588] = {.lex_state = 130},
  [6589] = {.lex_state = 130},
  [6590] = {.lex_state = 130},
  [6591] = {.lex_state = 130},
  [6592] = {.lex_state = 130},
  [6593] = {.lex_state = 130},
  [6594] = {.lex_state = 130},
  [6595] = {.lex_state = 130},
  [6596] = {.lex_state = 130},
  [6597] = {.lex_state = 130},
  [6598] = {.lex_state = 130},
  [6599] = {.lex_state = 130},
  [6600] = {.lex_state = 130},
  [6601] = {.lex_state = 130},
  [6602] = {.lex_state = 130},
  [6603] = {.lex_state = 130},
  [6604] = {.lex_state = 130},
  [6605] = {.lex_state = 130},
  [6606] = {.lex_state = 130},
  [6607] = {.lex_state = 130},
  [6608] = {.lex_state = 130},
  [6609] = {.lex_state = 130},
  [6610] = {.lex_state = 130},
  [6611] = {.lex_state = 130},
  [6612] = {.lex_state = 130},
  [6613] = {.lex_state = 130},
  [6614] = {.lex_state = 130},
  [6615] = {.lex_state = 130},
  [6616] = {.lex_state = 130},
  [6617] = {.lex_state = 130},
  [6618] = {.lex_state = 130},
  [6619] = {.lex_state = 130},
  [6620] = {.lex_state = 130},
  [6621] = {.lex_state = 130},
  [6622] = {.lex_state = 130},
  [6623] = {.lex_state = 130},
  [6624] = {.lex_state = 130},
  [6625] = {.lex_state = 130},
  [6626] = {.lex_state = 130},
  [6627] = {.lex_state = 130},
  [6628] = {.lex_state = 130},
  [6629] = {.lex_state = 130},
  [6630] = {.lex_state = 130},
  [6631] = {.lex_state = 130},
  [6632] = {.lex_state = 130},
  [6633] = {.lex_state = 130},
  [6634] = {.lex_state = 130},
  [6635] = {.lex_state = 130},
  [6636] = {.lex_state = 130},
  [6637] = {.lex_state = 130},
  [6638] = {.lex_state = 130},
  [6639] = {.lex_state = 130},
  [6640] = {.lex_state = 130},
  [6641] = {.lex_state = 130},
  [6642] = {.lex_state = 130},
  [6643] = {.lex_state = 130},
  [6644] = {.lex_state = 130},
  [6645] = {.lex_state = 130},
  [6646] = {.lex_state = 130},
  [6647] = {.lex_state = 130},
  [6648] = {.lex_state = 130},
  [6649] = {.lex_state = 130},
  [6650] = {.lex_state = 130},
  [6651] = {.lex_state = 130},
  [6652] = {.lex_state = 130},
  [6653] = {.lex_state = 130},
  [6654] = {.lex_state = 130},
  [6655] = {.lex_state = 130},
  [6656] = {.lex_state = 130},
  [6657] = {.lex_state = 130},
  [6658] = {.lex_state = 130},
  [6659] = {.lex_state = 130},
  [6660] = {.lex_state = 130},
  [6661] = {.lex_state = 130},
  [6662] = {.lex_state = 130},
  [6663] = {.lex_state = 130},
  [6664] = {.lex_state = 130},
  [6665] = {.lex_state = 130},
  [6666] = {.lex_state = 130},
  [6667] = {.lex_state = 130},
  [6668] = {.lex_state = 130},
  [6669] = {.lex_state = 130},
  [6670] = {.lex_state = 130},
  [6671] = {.lex_state = 130},
  [6672] = {.lex_state = 130},
  [6673] = {.lex_state = 130},
  [6674] = {.lex_state = 130},
  [6675] = {.lex_state = 130},
  [6676] = {.lex_state = 130},
  [6677] = {.lex_state = 130},
  [6678] = {.lex_state = 130},
  [6679] = {.lex_state = 130},
  [6680] = {.lex_state = 130},
  [6681] = {.lex_state = 130},
  [6682] = {.lex_state = 130},
  [6683] = {.lex_state = 130},
  [6684] = {.lex_state = 130},
  [6685] = {.lex_state = 130},
  [6686] = {.lex_state = 130},
  [6687] = {.lex_state = 130},
  [6688] = {.lex_state = 130},
  [6689] = {.lex_state = 130},
  [6690] = {.lex_state = 130},
  [6691] = {.lex_state = 131},
  [6692] = {.lex_state = 130},
  [6693] = {.lex_state = 130},
  [6694] = {.lex_state = 130},
  [6695] = {.lex_state = 130},
  [6696] = {.lex_state = 131},
  [6697] = {.lex_state = 130},
  [6698] = {.lex_state = 131},
  [6699] = {.lex_state = 131},
  [6700] = {.lex_state = 130},
  [6701] = {.lex_state = 130},
  [6702] = {.lex_state = 131},
  [6703] = {.lex_state = 130},
  [6704] = {.lex_state = 130},
  [6705] = {.lex_state = 130},
  [6706] = {.lex_state = 130},
  [6707] = {.lex_state = 130},
  [6708] = {.lex_state = 130},
  [6709] = {.lex_state = 130},
  [6710] = {.lex_state = 17},
  [6711] = {.lex_state = 17},
  [6712] = {.lex_state = 131},
  [6713] = {.lex_state = 130},
  [6714] = {.lex_state = 131},
  [6715] = {.lex_state = 130},
  [6716] = {.lex_state = 131},
  [6717] = {.lex_state = 130},
  [6718] = {.lex_state = 130},
  [6719] = {.lex_state = 130},
  [6720] = {.lex_state = 130},
  [6721] = {.lex_state = 130},
  [6722] = {.lex_state = 130},
  [6723] = {.lex_state = 130},
  [6724] = {.lex_state = 131},
  [6725] = {.lex_state = 131},
  [6726] = {.lex_state = 130},
  [6727] = {.lex_state = 130},
  [6728] = {.lex_state = 131},
  [6729] = {.lex_state = 130},
  [6730] = {.lex_state = 131},
  [6731] = {.lex_state = 131},
  [6732] = {.lex_state = 130},
  [6733] = {.lex_state = 131},
  [6734] = {.lex_state = 130},
  [6735] = {.lex_state = 130},
  [6736] = {.lex_state = 130},
  [6737] = {.lex_state = 130},
  [6738] = {.lex_state = 131},
  [6739] = {.lex_state = 131},
  [6740] = {.lex_state = 130},
  [6741] = {.lex_state = 130},
  [6742] = {.lex_state = 130},
  [6743] = {.lex_state = 131},
  [6744] = {.lex_state = 130},
  [6745] = {.lex_state = 131},
  [6746] = {.lex_state = 131},
  [6747] = {.lex_state = 130},
  [6748] = {.lex_state = 130},
  [6749] = {.lex_state = 131},
  [6750] = {.lex_state = 131},
  [6751] = {.lex_state = 131},
  [6752] = {.lex_state = 131},
  [6753] = {.lex_state = 131},
  [6754] = {.lex_state = 131},
  [6755] = {.lex_state = 130},
  [6756] = {.lex_state = 131},
  [6757] = {.lex_state = 131},
  [6758] = {.lex_state = 131},
  [6759] = {.lex_state = 131},
  [6760] = {.lex_state = 131},
  [6761] = {.lex_state = 131},
  [6762] = {.lex_state = 131},
  [6763] = {.lex_state = 17},
  [6764] = {.lex_state = 17},
  [6765] = {.lex_state = 17},
  [6766] = {.lex_state = 131},
  [6767] = {.lex_state = 131},
  [6768] = {.lex_state = 131},
  [6769] = {.lex_state = 131},
  [6770] = {.lex_state = 130},
  [6771] = {.lex_state = 17},
  [6772] = {.lex_state = 130},
  [6773] = {.lex_state = 131},
  [6774] = {.lex_state = 130},
  [6775] = {.lex_state = 131},
  [6776] = {.lex_state = 130},
  [6777] = {.lex_state = 131},
  [6778] = {.lex_state = 131},
  [6779] = {.lex_state = 131},
  [6780] = {.lex_state = 131},
  [6781] = {.lex_state = 131},
  [6782] = {.lex_state = 131},
  [6783] = {.lex_state = 131},
  [6784] = {.lex_state = 131},
  [6785] = {.lex_state = 131},
  [6786] = {.lex_state = 131},
  [6787] = {.lex_state = 131},
  [6788] = {.lex_state = 131},
  [6789] = {.lex_state = 131},
  [6790] = {.lex_state = 131},
  [6791] = {.lex_state = 131},
  [6792] = {.lex_state = 131},
  [6793] = {.lex_state = 131},
  [6794] = {.lex_state = 131},
  [6795] = {.lex_state = 131},
  [6796] = {.lex_state = 131},
  [6797] = {.lex_state = 131},
  [6798] = {.lex_state = 131},
  [6799] = {.lex_state = 131},
  [6800] = {.lex_state = 131},
  [6801] = {.lex_state = 131},
  [6802] = {.lex_state = 131},
  [6803] = {.lex_state = 131},
  [6804] = {.lex_state = 131},
  [6805] = {.lex_state = 131},
  [6806] = {.lex_state = 131},
  [6807] = {.lex_state = 131},
  [6808] = {.lex_state = 131},
  [6809] = {.lex_state = 131},
  [6810] = {.lex_state = 131},
  [6811] = {.lex_state = 131},
  [6812] = {.lex_state = 131},
  [6813] = {.lex_state = 131},
  [6814] = {.lex_state = 131},
  [6815] = {.lex_state = 131},
  [6816] = {.lex_state = 131},
  [6817] = {.lex_state = 131},
  [6818] = {.lex_state = 131},
  [6819] = {.lex_state = 131},
  [6820] = {.lex_state = 131},
  [6821] = {.lex_state = 131},
  [6822] = {.lex_state = 131},
  [6823] = {.lex_state = 131},
  [6824] = {.lex_state = 131},
  [6825] = {.lex_state = 131},
  [6826] = {.lex_state = 131},
  [6827] = {.lex_state = 131},
  [6828] = {.lex_state = 131},
  [6829] = {.lex_state = 131},
  [6830] = {.lex_state = 131},
  [6831] = {.lex_state = 131},
  [6832] = {.lex_state = 131},
  [6833] = {.lex_state = 131},
  [6834] = {.lex_state = 131},
  [6835] = {.lex_state = 131},
  [6836] = {.lex_state = 131},
  [6837] = {.lex_state = 131},
  [6838] = {.lex_state = 131},
  [6839] = {.lex_state = 131},
  [6840] = {.lex_state = 131},
  [6841] = {.lex_state = 131},
  [6842] = {.lex_state = 131},
  [6843] = {.lex_state = 131},
  [6844] = {.lex_state = 131},
  [6845] = {.lex_state = 131},
  [6846] = {.lex_state = 131},
  [6847] = {.lex_state = 131},
  [6848] = {.lex_state = 131},
  [6849] = {.lex_state = 131},
  [6850] = {.lex_state = 131},
  [6851] = {.lex_state = 131},
  [6852] = {.lex_state = 131},
  [6853] = {.lex_state = 131},
  [6854] = {.lex_state = 131},
  [6855] = {.lex_state = 131},
  [6856] = {.lex_state = 131},
  [6857] = {.lex_state = 131},
  [6858] = {.lex_state = 131},
  [6859] = {.lex_state = 131},
  [6860] = {.lex_state = 131},
  [6861] = {.lex_state = 131},
  [6862] = {.lex_state = 131},
  [6863] = {.lex_state = 131},
  [6864] = {.lex_state = 131},
  [6865] = {.lex_state = 131},
  [6866] = {.lex_state = 131},
  [6867] = {.lex_state = 131},
  [6868] = {.lex_state = 131},
  [6869] = {.lex_state = 131},
  [6870] = {.lex_state = 131},
  [6871] = {.lex_state = 131},
  [6872] = {.lex_state = 131},
  [6873] = {.lex_state = 131},
  [6874] = {.lex_state = 131},
  [6875] = {.lex_state = 131},
  [6876] = {.lex_state = 131},
  [6877] = {.lex_state = 131},
  [6878] = {.lex_state = 131},
  [6879] = {.lex_state = 131},
  [6880] = {.lex_state = 131},
  [6881] = {.lex_state = 131},
  [6882] = {.lex_state = 131},
  [6883] = {.lex_state = 131},
  [6884] = {.lex_state = 131},
  [6885] = {.lex_state = 131},
  [6886] = {.lex_state = 131},
  [6887] = {.lex_state = 131},
  [6888] = {.lex_state = 131},
  [6889] = {.lex_state = 130},
  [6890] = {.lex_state = 131},
  [6891] = {.lex_state = 131},
  [6892] = {.lex_state = 131},
  [6893] = {.lex_state = 131},
  [6894] = {.lex_state = 131},
  [6895] = {.lex_state = 131},
  [6896] = {.lex_state = 131},
  [6897] = {.lex_state = 131},
  [6898] = {.lex_state = 131},
  [6899] = {.lex_state = 131},
  [6900] = {.lex_state = 131},
  [6901] = {.lex_state = 131},
  [6902] = {.lex_state = 131},
  [6903] = {.lex_state = 131},
  [6904] = {.lex_state = 131},
  [6905] = {.lex_state = 131},
  [6906] = {.lex_state = 131},
  [6907] = {.lex_state = 131},
  [6908] = {.lex_state = 131},
  [6909] = {.lex_state = 131},
  [6910] = {.lex_state = 131},
  [6911] = {.lex_state = 131},
  [6912] = {.lex_state = 131},
  [6913] = {.lex_state = 131},
  [6914] = {.lex_state = 131},
  [6915] = {.lex_state = 131},
  [6916] = {.lex_state = 131},
  [6917] = {.lex_state = 131},
  [6918] = {.lex_state = 131},
  [6919] = {.lex_state = 131},
  [6920] = {.lex_state = 131},
  [6921] = {.lex_state = 131},
  [6922] = {.lex_state = 131},
  [6923] = {.lex_state = 131},
  [6924] = {.lex_state = 131},
  [6925] = {.lex_state = 131},
  [6926] = {.lex_state = 131},
  [6927] = {.lex_state = 131},
  [6928] = {.lex_state = 131},
  [6929] = {.lex_state = 131},
  [6930] = {.lex_state = 131},
  [6931] = {.lex_state = 131},
  [6932] = {.lex_state = 131},
  [6933] = {.lex_state = 131},
  [6934] = {.lex_state = 131},
  [6935] = {.lex_state = 131},
  [6936] = {.lex_state = 131},
  [6937] = {.lex_state = 131},
  [6938] = {.lex_state = 131},
  [6939] = {.lex_state = 131},
  [6940] = {.lex_state = 131},
  [6941] = {.lex_state = 131},
  [6942] = {.lex_state = 131},
  [6943] = {.lex_state = 131},
  [6944] = {.lex_state = 131},
  [6945] = {.lex_state = 131},
  [6946] = {.lex_state = 131},
  [6947] = {.lex_state = 131},
  [6948] = {.lex_state = 131},
  [6949] = {.lex_state = 131},
  [6950] = {.lex_state = 131},
  [6951] = {.lex_state = 131},
  [6952] = {.lex_state = 131},
  [6953] = {.lex_state = 131},
  [6954] = {.lex_state = 131},
  [6955] = {.lex_state = 131},
  [6956] = {.lex_state = 131},
  [6957] = {.lex_state = 131},
  [6958] = {.lex_state = 131},
  [6959] = {.lex_state = 131},
  [6960] = {.lex_state = 131},
  [6961] = {.lex_state = 131},
  [6962] = {.lex_state = 131},
  [6963] = {.lex_state = 131},
  [6964] = {.lex_state = 131},
  [6965] = {.lex_state = 131},
  [6966] = {.lex_state = 131},
  [6967] = {.lex_state = 131},
  [6968] = {.lex_state = 131},
  [6969] = {.lex_state = 131},
  [6970] = {.lex_state = 131},
  [6971] = {.lex_state = 131},
  [6972] = {.lex_state = 131},
  [6973] = {.lex_state = 131},
  [6974] = {.lex_state = 131},
  [6975] = {.lex_state = 131},
  [6976] = {.lex_state = 131},
  [6977] = {.lex_state = 131},
  [6978] = {.lex_state = 131},
  [6979] = {.lex_state = 131},
  [6980] = {.lex_state = 131},
  [6981] = {.lex_state = 131},
  [6982] = {.lex_state = 131},
  [6983] = {.lex_state = 131},
  [6984] = {.lex_state = 131},
  [6985] = {.lex_state = 131},
  [6986] = {.lex_state = 131},
  [6987] = {.lex_state = 131},
  [6988] = {.lex_state = 131},
  [6989] = {.lex_state = 131},
  [6990] = {.lex_state = 131},
  [6991] = {.lex_state = 131},
  [6992] = {.lex_state = 131},
  [6993] = {.lex_state = 131},
  [6994] = {.lex_state = 131},
  [6995] = {.lex_state = 131},
  [6996] = {.lex_state = 131},
  [6997] = {.lex_state = 131},
  [6998] = {.lex_state = 131},
  [6999] = {.lex_state = 131},
  [7000] = {.lex_state = 131},
  [7001] = {.lex_state = 131},
  [7002] = {.lex_state = 131},
  [7003] = {.lex_state = 131},
  [7004] = {.lex_state = 131},
  [7005] = {.lex_state = 131},
  [7006] = {.lex_state = 131},
  [7007] = {.lex_state = 131},
  [7008] = {.lex_state = 131},
  [7009] = {.lex_state = 131},
  [7010] = {.lex_state = 131},
  [7011] = {.lex_state = 131},
  [7012] = {.lex_state = 131},
  [7013] = {.lex_state = 131},
  [7014] = {.lex_state = 131},
  [7015] = {.lex_state = 131},
  [7016] = {.lex_state = 131},
  [7017] = {.lex_state = 131},
  [7018] = {.lex_state = 131},
  [7019] = {.lex_state = 131},
  [7020] = {.lex_state = 131},
  [7021] = {.lex_state = 131},
  [7022] = {.lex_state = 131},
  [7023] = {.lex_state = 131},
  [7024] = {.lex_state = 131},
  [7025] = {.lex_state = 131},
  [7026] = {.lex_state = 131},
  [7027] = {.lex_state = 131},
  [7028] = {.lex_state = 131},
  [7029] = {.lex_state = 131},
  [7030] = {.lex_state = 131},
  [7031] = {.lex_state = 131},
  [7032] = {.lex_state = 131},
  [7033] = {.lex_state = 131},
  [7034] = {.lex_state = 131},
  [7035] = {.lex_state = 131},
  [7036] = {.lex_state = 131},
  [7037] = {.lex_state = 131},
  [7038] = {.lex_state = 131},
  [7039] = {.lex_state = 131},
  [7040] = {.lex_state = 131},
  [7041] = {.lex_state = 131},
  [7042] = {.lex_state = 131},
  [7043] = {.lex_state = 131},
  [7044] = {.lex_state = 131},
  [7045] = {.lex_state = 131},
  [7046] = {.lex_state = 131},
  [7047] = {.lex_state = 131},
  [7048] = {.lex_state = 131},
  [7049] = {.lex_state = 131},
  [7050] = {.lex_state = 131},
  [7051] = {.lex_state = 131},
  [7052] = {.lex_state = 131},
  [7053] = {.lex_state = 131},
  [7054] = {.lex_state = 131},
  [7055] = {.lex_state = 131},
  [7056] = {.lex_state = 131},
  [7057] = {.lex_state = 131},
  [7058] = {.lex_state = 131},
  [7059] = {.lex_state = 131},
  [7060] = {.lex_state = 131},
  [7061] = {.lex_state = 131},
  [7062] = {.lex_state = 131},
  [7063] = {.lex_state = 131},
  [7064] = {.lex_state = 131},
  [7065] = {.lex_state = 131},
  [7066] = {.lex_state = 131},
  [7067] = {.lex_state = 131},
  [7068] = {.lex_state = 131},
  [7069] = {.lex_state = 131},
  [7070] = {.lex_state = 131},
  [7071] = {.lex_state = 131},
  [7072] = {.lex_state = 131},
  [7073] = {.lex_state = 131},
  [7074] = {.lex_state = 131},
  [7075] = {.lex_state = 131},
  [7076] = {.lex_state = 131},
  [7077] = {.lex_state = 131},
  [7078] = {.lex_state = 131},
  [7079] = {.lex_state = 131},
  [7080] = {.lex_state = 131},
  [7081] = {.lex_state = 131},
  [7082] = {.lex_state = 131},
  [7083] = {.lex_state = 131},
  [7084] = {.lex_state = 131},
  [7085] = {.lex_state = 131},
  [7086] = {.lex_state = 131},
  [7087] = {.lex_state = 131},
  [7088] = {.lex_state = 131},
  [7089] = {.lex_state = 131},
  [7090] = {.lex_state = 131},
  [7091] = {.lex_state = 131},
  [7092] = {.lex_state = 131},
  [7093] = {.lex_state = 131},
  [7094] = {.lex_state = 131},
  [7095] = {.lex_state = 131},
  [7096] = {.lex_state = 131},
  [7097] = {.lex_state = 131},
  [7098] = {.lex_state = 131},
  [7099] = {.lex_state = 131},
  [7100] = {.lex_state = 131},
  [7101] = {.lex_state = 131},
  [7102] = {.lex_state = 131},
  [7103] = {.lex_state = 131},
  [7104] = {.lex_state = 131},
  [7105] = {.lex_state = 131},
  [7106] = {.lex_state = 131},
  [7107] = {.lex_state = 131},
  [7108] = {.lex_state = 131},
  [7109] = {.lex_state = 131},
  [7110] = {.lex_state = 131},
  [7111] = {.lex_state = 131},
  [7112] = {.lex_state = 131},
  [7113] = {.lex_state = 131},
  [7114] = {.lex_state = 131},
  [7115] = {.lex_state = 131},
  [7116] = {.lex_state = 131},
  [7117] = {.lex_state = 131},
  [7118] = {.lex_state = 131},
  [7119] = {.lex_state = 131},
  [7120] = {.lex_state = 131},
  [7121] = {.lex_state = 131},
  [7122] = {.lex_state = 131},
  [7123] = {.lex_state = 131},
  [7124] = {.lex_state = 131},
  [7125] = {.lex_state = 131},
  [7126] = {.lex_state = 131},
  [7127] = {.lex_state = 131},
  [7128] = {.lex_state = 131},
  [7129] = {.lex_state = 131},
  [7130] = {.lex_state = 131},
  [7131] = {.lex_state = 131},
  [7132] = {.lex_state = 131},
  [7133] = {.lex_state = 131},
  [7134] = {.lex_state = 131},
  [7135] = {.lex_state = 131},
  [7136] = {.lex_state = 131},
  [7137] = {.lex_state = 131},
  [7138] = {.lex_state = 131},
  [7139] = {.lex_state = 131},
  [7140] = {.lex_state = 131},
  [7141] = {.lex_state = 131},
  [7142] = {.lex_state = 131},
  [7143] = {.lex_state = 131},
  [7144] = {.lex_state = 131},
  [7145] = {.lex_state = 131},
  [7146] = {.lex_state = 131},
  [7147] = {.lex_state = 131},
  [7148] = {.lex_state = 131},
  [7149] = {.lex_state = 131},
  [7150] = {.lex_state = 131},
  [7151] = {.lex_state = 131},
  [7152] = {.lex_state = 131},
  [7153] = {.lex_state = 131},
  [7154] = {.lex_state = 131},
  [7155] = {.lex_state = 131},
  [7156] = {.lex_state = 131},
  [7157] = {.lex_state = 131},
  [7158] = {.lex_state = 131},
  [7159] = {.lex_state = 131},
  [7160] = {.lex_state = 131},
  [7161] = {.lex_state = 131},
  [7162] = {.lex_state = 131},
  [7163] = {.lex_state = 131},
  [7164] = {.lex_state = 131},
  [7165] = {.lex_state = 131},
  [7166] = {.lex_state = 131},
  [7167] = {.lex_state = 131},
  [7168] = {.lex_state = 131},
  [7169] = {.lex_state = 131},
  [7170] = {.lex_state = 131},
  [7171] = {.lex_state = 131},
  [7172] = {.lex_state = 131},
  [7173] = {.lex_state = 131},
  [7174] = {.lex_state = 131},
  [7175] = {.lex_state = 131},
  [7176] = {.lex_state = 131},
  [7177] = {.lex_state = 131},
  [7178] = {.lex_state = 131},
  [7179] = {.lex_state = 131},
  [7180] = {.lex_state = 131},
  [7181] = {.lex_state = 131},
  [7182] = {.lex_state = 131},
  [7183] = {.lex_state = 131},
  [7184] = {.lex_state = 131},
  [7185] = {.lex_state = 131},
  [7186] = {.lex_state = 131},
  [7187] = {.lex_state = 131},
  [7188] = {.lex_state = 131},
  [7189] = {.lex_state = 131},
  [7190] = {.lex_state = 131},
  [7191] = {.lex_state = 131},
  [7192] = {.lex_state = 131},
  [7193] = {.lex_state = 131},
  [7194] = {.lex_state = 131},
  [7195] = {.lex_state = 131},
  [7196] = {.lex_state = 131},
  [7197] = {.lex_state = 131},
  [7198] = {.lex_state = 131},
  [7199] = {.lex_state = 131},
  [7200] = {.lex_state = 131},
  [7201] = {.lex_state = 131},
  [7202] = {.lex_state = 131},
  [7203] = {.lex_state = 131},
  [7204] = {.lex_state = 131},
  [7205] = {.lex_state = 131},
  [7206] = {.lex_state = 131},
  [7207] = {.lex_state = 131},
  [7208] = {.lex_state = 131},
  [7209] = {.lex_state = 131},
  [7210] = {.lex_state = 131},
  [7211] = {.lex_state = 131},
  [7212] = {.lex_state = 131},
  [7213] = {.lex_state = 131},
  [7214] = {.lex_state = 131},
  [7215] = {.lex_state = 131},
  [7216] = {.lex_state = 131},
  [7217] = {.lex_state = 131},
  [7218] = {.lex_state = 131},
  [7219] = {.lex_state = 131},
  [7220] = {.lex_state = 131},
  [7221] = {.lex_state = 131},
  [7222] = {.lex_state = 131},
  [7223] = {.lex_state = 131},
  [7224] = {.lex_state = 131},
  [7225] = {.lex_state = 131},
  [7226] = {.lex_state = 131},
  [7227] = {.lex_state = 131},
  [7228] = {.lex_state = 131},
  [7229] = {.lex_state = 131},
  [7230] = {.lex_state = 131},
  [7231] = {.lex_state = 131},
  [7232] = {.lex_state = 131},
  [7233] = {.lex_state = 131},
  [7234] = {.lex_state = 131},
  [7235] = {.lex_state = 131},
  [7236] = {.lex_state = 131},
  [7237] = {.lex_state = 131},
  [7238] = {.lex_state = 131},
  [7239] = {.lex_state = 131},
  [7240] = {.lex_state = 131},
  [7241] = {.lex_state = 131},
  [7242] = {.lex_state = 131},
  [7243] = {.lex_state = 131},
  [7244] = {.lex_state = 131},
  [7245] = {.lex_state = 131},
  [7246] = {.lex_state = 131},
  [7247] = {.lex_state = 131},
  [7248] = {.lex_state = 131},
  [7249] = {.lex_state = 131},
  [7250] = {.lex_state = 131},
  [7251] = {.lex_state = 131},
  [7252] = {.lex_state = 131},
  [7253] = {.lex_state = 131},
  [7254] = {.lex_state = 131},
  [7255] = {.lex_state = 131},
  [7256] = {.lex_state = 131},
  [7257] = {.lex_state = 131},
  [7258] = {.lex_state = 131},
  [7259] = {.lex_state = 131},
  [7260] = {.lex_state = 131},
  [7261] = {.lex_state = 131},
  [7262] = {.lex_state = 131},
  [7263] = {.lex_state = 131},
  [7264] = {.lex_state = 131},
  [7265] = {.lex_state = 131},
  [7266] = {.lex_state = 131},
  [7267] = {.lex_state = 131},
  [7268] = {.lex_state = 131},
  [7269] = {.lex_state = 131},
  [7270] = {.lex_state = 131},
  [7271] = {.lex_state = 131},
  [7272] = {.lex_state = 131},
  [7273] = {.lex_state = 131},
  [7274] = {.lex_state = 131},
  [7275] = {.lex_state = 131},
  [7276] = {.lex_state = 131},
  [7277] = {.lex_state = 131},
  [7278] = {.lex_state = 1},
  [7279] = {.lex_state = 131},
  [7280] = {.lex_state = 131},
  [7281] = {.lex_state = 131},
  [7282] = {.lex_state = 131},
  [7283] = {.lex_state = 131},
  [7284] = {.lex_state = 131},
  [7285] = {.lex_state = 131},
  [7286] = {.lex_state = 131},
  [7287] = {.lex_state = 131},
  [7288] = {.lex_state = 131},
  [7289] = {.lex_state = 131},
  [7290] = {.lex_state = 131},
  [7291] = {.lex_state = 131},
  [7292] = {.lex_state = 131},
  [7293] = {.lex_state = 131},
  [7294] = {.lex_state = 131},
  [7295] = {.lex_state = 131},
  [7296] = {.lex_state = 131},
  [7297] = {.lex_state = 131},
  [7298] = {.lex_state = 4},
  [7299] = {.lex_state = 131},
  [7300] = {.lex_state = 131},
  [7301] = {.lex_state = 131},
  [7302] = {.lex_state = 131},
  [7303] = {.lex_state = 131},
  [7304] = {.lex_state = 131},
  [7305] = {.lex_state = 131},
  [7306] = {.lex_state = 131},
  [7307] = {.lex_state = 131},
  [7308] = {.lex_state = 131},
  [7309] = {.lex_state = 131},
  [7310] = {.lex_state = 131},
  [7311] = {.lex_state = 131},
  [7312] = {.lex_state = 131},
  [7313] = {.lex_state = 131},
  [7314] = {.lex_state = 131},
  [7315] = {.lex_state = 131},
  [7316] = {.lex_state = 131},
  [7317] = {.lex_state = 131},
  [7318] = {.lex_state = 131},
  [7319] = {.lex_state = 131},
  [7320] = {.lex_state = 131},
  [7321] = {.lex_state = 131},
  [7322] = {.lex_state = 131},
  [7323] = {.lex_state = 131},
  [7324] = {.lex_state = 131},
  [7325] = {.lex_state = 131},
  [7326] = {.lex_state = 131},
  [7327] = {.lex_state = 131},
  [7328] = {.lex_state = 131},
  [7329] = {.lex_state = 131},
  [7330] = {.lex_state = 131},
  [7331] = {.lex_state = 131},
  [7332] = {.lex_state = 131},
  [7333] = {.lex_state = 131},
  [7334] = {.lex_state = 131},
  [7335] = {.lex_state = 131},
  [7336] = {.lex_state = 131},
  [7337] = {.lex_state = 131},
  [7338] = {.lex_state = 131},
  [7339] = {.lex_state = 131},
  [7340] = {.lex_state = 131},
  [7341] = {.lex_state = 131},
  [7342] = {.lex_state = 131},
  [7343] = {.lex_state = 131},
  [7344] = {.lex_state = 131},
  [7345] = {.lex_state = 131},
  [7346] = {.lex_state = 131},
  [7347] = {.lex_state = 131},
  [7348] = {.lex_state = 131},
  [7349] = {.lex_state = 131},
  [7350] = {.lex_state = 131},
  [7351] = {.lex_state = 131},
  [7352] = {.lex_state = 131},
  [7353] = {.lex_state = 131},
  [7354] = {.lex_state = 131},
  [7355] = {.lex_state = 131},
  [7356] = {.lex_state = 131},
  [7357] = {.lex_state = 131},
  [7358] = {.lex_state = 131},
  [7359] = {.lex_state = 131},
  [7360] = {.lex_state = 131},
  [7361] = {.lex_state = 131},
  [7362] = {.lex_state = 131},
  [7363] = {.lex_state = 131},
  [7364] = {.lex_state = 131},
  [7365] = {.lex_state = 131},
  [7366] = {.lex_state = 131},
  [7367] = {.lex_state = 131},
  [7368] = {.lex_state = 131},
  [7369] = {.lex_state = 131},
  [7370] = {.lex_state = 131},
  [7371] = {.lex_state = 131},
  [7372] = {.lex_state = 131},
  [7373] = {.lex_state = 131},
  [7374] = {.lex_state = 131},
  [7375] = {.lex_state = 131},
  [7376] = {.lex_state = 131},
  [7377] = {.lex_state = 131},
  [7378] = {.lex_state = 131},
  [7379] = {.lex_state = 131},
  [7380] = {.lex_state = 131},
  [7381] = {.lex_state = 131},
  [7382] = {.lex_state = 131},
  [7383] = {.lex_state = 131},
  [7384] = {.lex_state = 131},
  [7385] = {.lex_state = 131},
  [7386] = {.lex_state = 131},
  [7387] = {.lex_state = 131},
  [7388] = {.lex_state = 131},
  [7389] = {.lex_state = 131},
  [7390] = {.lex_state = 131},
  [7391] = {.lex_state = 131},
  [7392] = {.lex_state = 131},
  [7393] = {.lex_state = 131},
  [7394] = {.lex_state = 131},
  [7395] = {.lex_state = 131},
  [7396] = {.lex_state = 131},
  [7397] = {.lex_state = 131},
  [7398] = {.lex_state = 131},
  [7399] = {.lex_state = 131},
  [7400] = {.lex_state = 8},
  [7401] = {.lex_state = 8},
  [7402] = {.lex_state = 8},
  [7403] = {.lex_state = 8},
  [7404] = {.lex_state = 8},
  [7405] = {.lex_state = 8},
  [7406] = {.lex_state = 8},
  [7407] = {.lex_state = 8},
  [7408] = {.lex_state = 8},
  [7409] = {.lex_state = 8},
  [7410] = {.lex_state = 8},
  [7411] = {.lex_state = 131},
  [7412] = {.lex_state = 8},
  [7413] = {.lex_state = 131},
  [7414] = {.lex_state = 131},
  [7415] = {.lex_state = 131},
  [7416] = {.lex_state = 131},
  [7417] = {.lex_state = 131},
  [7418] = {.lex_state = 131},
  [7419] = {.lex_state = 131},
  [7420] = {.lex_state = 131},
  [7421] = {.lex_state = 131},
  [7422] = {.lex_state = 131},
  [7423] = {.lex_state = 131},
  [7424] = {.lex_state = 131},
  [7425] = {.lex_state = 131},
  [7426] = {.lex_state = 131},
  [7427] = {.lex_state = 131},
  [7428] = {.lex_state = 131},
  [7429] = {.lex_state = 131},
  [7430] = {.lex_state = 131},
  [7431] = {.lex_state = 131},
  [7432] = {.lex_state = 131},
  [7433] = {.lex_state = 131},
  [7434] = {.lex_state = 131},
  [7435] = {.lex_state = 131},
  [7436] = {.lex_state = 131},
  [7437] = {.lex_state = 131},
  [7438] = {.lex_state = 131},
  [7439] = {.lex_state = 131},
  [7440] = {.lex_state = 131},
  [7441] = {.lex_state = 131},
  [7442] = {.lex_state = 131},
  [7443] = {.lex_state = 131},
  [7444] = {.lex_state = 131},
  [7445] = {.lex_state = 131},
  [7446] = {.lex_state = 131},
  [7447] = {.lex_state = 131},
  [7448] = {.lex_state = 131},
  [7449] = {.lex_state = 131},
  [7450] = {.lex_state = 131},
  [7451] = {.lex_state = 131},
  [7452] = {.lex_state = 131},
  [7453] = {.lex_state = 131},
  [7454] = {.lex_state = 131},
  [7455] = {.lex_state = 131},
  [7456] = {.lex_state = 131},
  [7457] = {.lex_state = 131},
  [7458] = {.lex_state = 131},
  [7459] = {.lex_state = 131},
  [7460] = {.lex_state = 131},
  [7461] = {.lex_state = 131},
  [7462] = {.lex_state = 131},
  [7463] = {.lex_state = 131},
  [7464] = {.lex_state = 131},
  [7465] = {.lex_state = 131},
  [7466] = {.lex_state = 131},
  [7467] = {.lex_state = 131},
  [7468] = {.lex_state = 131},
  [7469] = {.lex_state = 131},
  [7470] = {.lex_state = 131},
  [7471] = {.lex_state = 131},
  [7472] = {.lex_state = 131},
  [7473] = {.lex_state = 131},
  [7474] = {.lex_state = 131},
  [7475] = {.lex_state = 131},
  [7476] = {.lex_state = 131},
  [7477] = {.lex_state = 131},
  [7478] = {.lex_state = 131},
  [7479] = {.lex_state = 131},
  [7480] = {.lex_state = 131},
  [7481] = {.lex_state = 131},
  [7482] = {.lex_state = 131},
  [7483] = {.lex_state = 131},
  [7484] = {.lex_state = 131},
  [7485] = {.lex_state = 131},
  [7486] = {.lex_state = 131},
  [7487] = {.lex_state = 131},
  [7488] = {.lex_state = 131},
  [7489] = {.lex_state = 131},
  [7490] = {.lex_state = 131},
  [7491] = {.lex_state = 131},
  [7492] = {.lex_state = 131},
  [7493] = {.lex_state = 131},
  [7494] = {.lex_state = 131},
  [7495] = {.lex_state = 131},
  [7496] = {.lex_state = 131},
  [7497] = {.lex_state = 131},
  [7498] = {.lex_state = 131},
  [7499] = {.lex_state = 131},
  [7500] = {.lex_state = 131},
  [7501] = {.lex_state = 131},
  [7502] = {.lex_state = 131},
  [7503] = {.lex_state = 131},
  [7504] = {.lex_state = 131},
  [7505] = {.lex_state = 131},
  [7506] = {.lex_state = 131},
  [7507] = {.lex_state = 131},
  [7508] = {.lex_state = 131},
  [7509] = {.lex_state = 0},
  [7510] = {.lex_state = 0},
  [7511] = {.lex_state = 0},
  [7512] = {.lex_state = 131},
  [7513] = {.lex_state = 130},
  [7514] = {.lex_state = 130},
  [7515] = {.lex_state = 130},
  [7516] = {.lex_state = 130},
  [7517] = {.lex_state = 130},
  [7518] = {.lex_state = 130},
  [7519] = {.lex_state = 130},
  [7520] = {.lex_state = 130},
  [7521] = {.lex_state = 130},
  [7522] = {.lex_state = 130},
  [7523] = {.lex_state = 130},
  [7524] = {.lex_state = 130},
  [7525] = {.lex_state = 130},
  [7526] = {.lex_state = 0},
  [7527] = {.lex_state = 0},
  [7528] = {.lex_state = 130},
  [7529] = {.lex_state = 130},
  [7530] = {.lex_state = 131},
  [7531] = {.lex_state = 130},
  [7532] = {.lex_state = 130},
  [7533] = {.lex_state = 130},
  [7534] = {.lex_state = 130},
  [7535] = {.lex_state = 130},
  [7536] = {.lex_state = 130},
  [7537] = {.lex_state = 0},
  [7538] = {.lex_state = 130},
  [7539] = {.lex_state = 130},
  [7540] = {.lex_state = 130},
  [7541] = {.lex_state = 130},
  [7542] = {.lex_state = 130},
  [7543] = {.lex_state = 130},
  [7544] = {.lex_state = 130},
  [7545] = {.lex_state = 130},
  [7546] = {.lex_state = 130},
  [7547] = {.lex_state = 130},
  [7548] = {.lex_state = 130},
  [7549] = {.lex_state = 130},
  [7550] = {.lex_state = 130},
  [7551] = {.lex_state = 130},
  [7552] = {.lex_state = 130},
  [7553] = {.lex_state = 130},
  [7554] = {.lex_state = 130},
  [7555] = {.lex_state = 0},
  [7556] = {.lex_state = 130},
  [7557] = {.lex_state = 130},
  [7558] = {.lex_state = 0},
  [7559] = {.lex_state = 0},
  [7560] = {.lex_state = 0},
  [7561] = {.lex_state = 130},
  [7562] = {.lex_state = 130},
  [7563] = {.lex_state = 130},
  [7564] = {.lex_state = 130},
  [7565] = {.lex_state = 130},
  [7566] = {.lex_state = 131},
  [7567] = {.lex_state = 131},
  [7568] = {.lex_state = 131},
  [7569] = {.lex_state = 131},
  [7570] = {.lex_state = 131},
  [7571] = {.lex_state = 131},
  [7572] = {.lex_state = 131},
  [7573] = {.lex_state = 131},
  [7574] = {.lex_state = 131},
  [7575] = {.lex_state = 131},
  [7576] = {.lex_state = 131},
  [7577] = {.lex_state = 131},
  [7578] = {.lex_state = 131},
  [7579] = {.lex_state = 131},
  [7580] = {.lex_state = 130},
  [7581] = {.lex_state = 130},
  [7582] = {.lex_state = 130},
  [7583] = {.lex_state = 131},
  [7584] = {.lex_state = 0},
  [7585] = {.lex_state = 131},
  [7586] = {.lex_state = 130},
  [7587] = {.lex_state = 131},
  [7588] = {.lex_state = 130},
  [7589] = {.lex_state = 131},
  [7590] = {.lex_state = 130},
  [7591] = {.lex_state = 130},
  [7592] = {.lex_state = 131},
  [7593] = {.lex_state = 131},
  [7594] = {.lex_state = 130},
  [7595] = {.lex_state = 130},
  [7596] = {.lex_state = 130},
  [7597] = {.lex_state = 131},
  [7598] = {.lex_state = 131},
  [7599] = {.lex_state = 131},
  [7600] = {.lex_state = 130},
  [7601] = {.lex_state = 131},
  [7602] = {.lex_state = 131},
  [7603] = {.lex_state = 131},
  [7604] = {.lex_state = 130},
  [7605] = {.lex_state = 131},
  [7606] = {.lex_state = 131},
  [7607] = {.lex_state = 131},
  [7608] = {.lex_state = 131},
  [7609] = {.lex_state = 10},
  [7610] = {.lex_state = 131},
  [7611] = {.lex_state = 131},
  [7612] = {.lex_state = 131},
  [7613] = {.lex_state = 131},
  [7614] = {.lex_state = 131},
  [7615] = {.lex_state = 131},
  [7616] = {.lex_state = 131},
  [7617] = {.lex_state = 131},
  [7618] = {.lex_state = 130},
  [7619] = {.lex_state = 130},
  [7620] = {.lex_state = 130},
  [7621] = {.lex_state = 131},
  [7622] = {.lex_state = 131},
  [7623] = {.lex_state = 131},
  [7624] = {.lex_state = 130},
  [7625] = {.lex_state = 130},
  [7626] = {.lex_state = 131},
  [7627] = {.lex_state = 130},
  [7628] = {.lex_state = 130},
  [7629] = {.lex_state = 130},
  [7630] = {.lex_state = 131},
  [7631] = {.lex_state = 130},
  [7632] = {.lex_state = 130},
  [7633] = {.lex_state = 131},
  [7634] = {.lex_state = 130},
  [7635] = {.lex_state = 130},
  [7636] = {.lex_state = 0},
  [7637] = {.lex_state = 130},
  [7638] = {.lex_state = 131},
  [7639] = {.lex_state = 130},
  [7640] = {.lex_state = 131},
  [7641] = {.lex_state = 131},
  [7642] = {.lex_state = 131},
  [7643] = {.lex_state = 131},
  [7644] = {.lex_state = 131},
  [7645] = {.lex_state = 131},
  [7646] = {.lex_state = 131},
  [7647] = {.lex_state = 131},
  [7648] = {.lex_state = 131},
  [7649] = {.lex_state = 131},
  [7650] = {.lex_state = 131},
  [7651] = {.lex_state = 131},
  [7652] = {.lex_state = 131},
  [7653] = {.lex_state = 131},
  [7654] = {.lex_state = 131},
  [7655] = {.lex_state = 131},
  [7656] = {.lex_state = 130},
  [7657] = {.lex_state = 130},
  [7658] = {.lex_state = 131},
  [7659] = {.lex_state = 131},
  [7660] = {.lex_state = 131},
  [7661] = {.lex_state = 130},
  [7662] = {.lex_state = 131},
  [7663] = {.lex_state = 131},
  [7664] = {.lex_state = 131},
  [7665] = {.lex_state = 131},
  [7666] = {.lex_state = 131},
  [7667] = {.lex_state = 131},
  [7668] = {.lex_state = 131},
  [7669] = {.lex_state = 131},
  [7670] = {.lex_state = 131},
  [7671] = {.lex_state = 0},
  [7672] = {.lex_state = 130},
  [7673] = {.lex_state = 131},
  [7674] = {.lex_state = 131},
  [7675] = {.lex_state = 0},
  [7676] = {.lex_state = 131},
  [7677] = {.lex_state = 130},
  [7678] = {.lex_state = 130},
  [7679] = {.lex_state = 130},
  [7680] = {.lex_state = 130},
  [7681] = {.lex_state = 130},
  [7682] = {.lex_state = 130},
  [7683] = {.lex_state = 0},
  [7684] = {.lex_state = 130},
  [7685] = {.lex_state = 130},
  [7686] = {.lex_state = 130},
  [7687] = {.lex_state = 130},
  [7688] = {.lex_state = 130},
  [7689] = {.lex_state = 130},
  [7690] = {.lex_state = 130},
  [7691] = {.lex_state = 130},
  [7692] = {.lex_state = 131},
  [7693] = {.lex_state = 130},
  [7694] = {.lex_state = 130},
  [7695] = {.lex_state = 131},
  [7696] = {.lex_state = 130},
  [7697] = {.lex_state = 130},
  [7698] = {.lex_state = 131},
  [7699] = {.lex_state = 0},
  [7700] = {.lex_state = 130},
  [7701] = {.lex_state = 0},
  [7702] = {.lex_state = 130},
  [7703] = {.lex_state = 130},
  [7704] = {.lex_state = 130},
  [7705] = {.lex_state = 130},
  [7706] = {.lex_state = 130},
  [7707] = {.lex_state = 130},
  [7708] = {.lex_state = 130},
  [7709] = {.lex_state = 130},
  [7710] = {.lex_state = 130},
  [7711] = {.lex_state = 131},
  [7712] = {.lex_state = 130},
  [7713] = {.lex_state = 18, .external_lex_state = 5},
  [7714] = {.lex_state = 130},
  [7715] = {.lex_state = 130},
  [7716] = {.lex_state = 130},
  [7717] = {.lex_state = 131},
  [7718] = {.lex_state = 130},
  [7719] = {.lex_state = 130},
  [7720] = {.lex_state = 130},
  [7721] = {.lex_state = 18, .external_lex_state = 5},
  [7722] = {.lex_state = 130},
  [7723] = {.lex_state = 130},
  [7724] = {.lex_state = 130},
  [7725] = {.lex_state = 18, .external_lex_state = 5},
  [7726] = {.lex_state = 130},
  [7727] = {.lex_state = 131},
  [7728] = {.lex_state = 130},
  [7729] = {.lex_state = 18, .external_lex_state = 5},
  [7730] = {.lex_state = 130},
  [7731] = {.lex_state = 130},
  [7732] = {.lex_state = 130},
  [7733] = {.lex_state = 18, .external_lex_state = 5},
  [7734] = {.lex_state = 130},
  [7735] = {.lex_state = 130},
  [7736] = {.lex_state = 131},
  [7737] = {.lex_state = 131},
  [7738] = {.lex_state = 131},
  [7739] = {.lex_state = 18, .external_lex_state = 5},
  [7740] = {.lex_state = 130},
  [7741] = {.lex_state = 18, .external_lex_state = 5},
  [7742] = {.lex_state = 130},
  [7743] = {.lex_state = 130},
  [7744] = {.lex_state = 130},
  [7745] = {.lex_state = 130},
  [7746] = {.lex_state = 130},
  [7747] = {.lex_state = 130},
  [7748] = {.lex_state = 130},
  [7749] = {.lex_state = 18, .external_lex_state = 5},
  [7750] = {.lex_state = 130},
  [7751] = {.lex_state = 130},
  [7752] = {.lex_state = 130},
  [7753] = {.lex_state = 130},
  [7754] = {.lex_state = 130},
  [7755] = {.lex_state = 130},
  [7756] = {.lex_state = 18, .external_lex_state = 5},
  [7757] = {.lex_state = 130},
  [7758] = {.lex_state = 130},
  [7759] = {.lex_state = 130},
  [7760] = {.lex_state = 130},
  [7761] = {.lex_state = 130},
  [7762] = {.lex_state = 130},
  [7763] = {.lex_state = 130},
  [7764] = {.lex_state = 130},
  [7765] = {.lex_state = 130},
  [7766] = {.lex_state = 18, .external_lex_state = 5},
  [7767] = {.lex_state = 130},
  [7768] = {.lex_state = 130},
  [7769] = {.lex_state = 130},
  [7770] = {.lex_state = 130},
  [7771] = {.lex_state = 130},
  [7772] = {.lex_state = 130},
  [7773] = {.lex_state = 130},
  [7774] = {.lex_state = 130},
  [7775] = {.lex_state = 130},
  [7776] = {.lex_state = 130},
  [7777] = {.lex_state = 18, .external_lex_state = 5},
  [7778] = {.lex_state = 131},
  [7779] = {.lex_state = 0},
  [7780] = {.lex_state = 0},
  [7781] = {.lex_state = 131},
  [7782] = {.lex_state = 131},
  [7783] = {.lex_state = 131},
  [7784] = {.lex_state = 131},
  [7785] = {.lex_state = 0},
  [7786] = {.lex_state = 131},
  [7787] = {.lex_state = 0},
  [7788] = {.lex_state = 131},
  [7789] = {.lex_state = 131},
  [7790] = {.lex_state = 131},
  [7791] = {.lex_state = 0, .external_lex_state = 5},
  [7792] = {.lex_state = 0},
  [7793] = {.lex_state = 131},
  [7794] = {.lex_state = 0},
  [7795] = {.lex_state = 131},
  [7796] = {.lex_state = 0},
  [7797] = {.lex_state = 131},
  [7798] = {.lex_state = 1},
  [7799] = {.lex_state = 131},
  [7800] = {.lex_state = 131},
  [7801] = {.lex_state = 0},
  [7802] = {.lex_state = 131},
  [7803] = {.lex_state = 131},
  [7804] = {.lex_state = 131},
  [7805] = {.lex_state = 131},
  [7806] = {.lex_state = 131},
  [7807] = {.lex_state = 131},
  [7808] = {.lex_state = 1},
  [7809] = {.lex_state = 131},
  [7810] = {.lex_state = 131},
  [7811] = {.lex_state = 131},
  [7812] = {.lex_state = 131},
  [7813] = {.lex_state = 131},
  [7814] = {.lex_state = 131},
  [7815] = {.lex_state = 131},
  [7816] = {.lex_state = 131},
  [7817] = {.lex_state = 131},
  [7818] = {.lex_state = 131},
  [7819] = {.lex_state = 131},
  [7820] = {.lex_state = 131},
  [7821] = {.lex_state = 131},
  [7822] = {.lex_state = 131},
  [7823] = {.lex_state = 131},
  [7824] = {.lex_state = 131},
  [7825] = {.lex_state = 131},
  [7826] = {.lex_state = 131},
  [7827] = {.lex_state = 131},
  [7828] = {.lex_state = 131},
  [7829] = {.lex_state = 131},
  [7830] = {.lex_state = 131},
  [7831] = {.lex_state = 131},
  [7832] = {.lex_state = 131},
  [7833] = {.lex_state = 131},
  [7834] = {.lex_state = 131},
  [7835] = {.lex_state = 131},
  [7836] = {.lex_state = 131},
  [7837] = {.lex_state = 131},
  [7838] = {.lex_state = 131},
  [7839] = {.lex_state = 0, .external_lex_state = 5},
  [7840] = {.lex_state = 0},
  [7841] = {.lex_state = 0},
  [7842] = {.lex_state = 0, .external_lex_state = 5},
  [7843] = {.lex_state = 0, .external_lex_state = 5},
  [7844] = {.lex_state = 2},
  [7845] = {.lex_state = 0},
  [7846] = {.lex_state = 131},
  [7847] = {.lex_state = 131},
  [7848] = {.lex_state = 131},
  [7849] = {.lex_state = 131},
  [7850] = {.lex_state = 131},
  [7851] = {.lex_state = 131},
  [7852] = {.lex_state = 0, .external_lex_state = 5},
  [7853] = {.lex_state = 131},
  [7854] = {.lex_state = 0},
  [7855] = {.lex_state = 0},
  [7856] = {.lex_state = 0},
  [7857] = {.lex_state = 2},
  [7858] = {.lex_state = 0, .external_lex_state = 5},
  [7859] = {.lex_state = 0, .external_lex_state = 5},
  [7860] = {.lex_state = 2},
  [7861] = {.lex_state = 131},
  [7862] = {.lex_state = 131},
  [7863] = {.lex_state = 0},
  [7864] = {.lex_state = 2},
  [7865] = {.lex_state = 131},
  [7866] = {.lex_state = 131},
  [7867] = {.lex_state = 131},
  [7868] = {.lex_state = 2},
  [7869] = {.lex_state = 0},
  [7870] = {.lex_state = 131},
  [7871] = {.lex_state = 131},
  [7872] = {.lex_state = 0},
  [7873] = {.lex_state = 131},
  [7874] = {.lex_state = 0, .external_lex_state = 5},
  [7875] = {.lex_state = 0, .external_lex_state = 5},
  [7876] = {.lex_state = 0},
  [7877] = {.lex_state = 131},
  [7878] = {.lex_state = 0, .external_lex_state = 5},
  [7879] = {.lex_state = 0},
  [7880] = {.lex_state = 0, .external_lex_state = 5},
  [7881] = {.lex_state = 131},
  [7882] = {.lex_state = 10},
  [7883] = {.lex_state = 131},
  [7884] = {.lex_state = 131},
  [7885] = {.lex_state = 131},
  [7886] = {.lex_state = 2},
  [7887] = {.lex_state = 0},
  [7888] = {.lex_state = 131},
  [7889] = {.lex_state = 131},
  [7890] = {.lex_state = 0, .external_lex_state = 5},
  [7891] = {.lex_state = 131},
  [7892] = {.lex_state = 0, .external_lex_state = 5},
  [7893] = {.lex_state = 131},
  [7894] = {.lex_state = 131},
  [7895] = {.lex_state = 2},
  [7896] = {.lex_state = 0},
  [7897] = {.lex_state = 131},
  [7898] = {.lex_state = 0, .external_lex_state = 5},
  [7899] = {.lex_state = 0, .external_lex_state = 5},
  [7900] = {.lex_state = 131},
  [7901] = {.lex_state = 0, .external_lex_state = 5},
  [7902] = {.lex_state = 131},
  [7903] = {.lex_state = 0, .external_lex_state = 5},
  [7904] = {.lex_state = 0},
  [7905] = {.lex_state = 2},
  [7906] = {.lex_state = 131},
  [7907] = {.lex_state = 131},
  [7908] = {.lex_state = 131},
  [7909] = {.lex_state = 131},
  [7910] = {.lex_state = 131},
  [7911] = {.lex_state = 0},
  [7912] = {.lex_state = 0, .external_lex_state = 5},
  [7913] = {.lex_state = 0, .external_lex_state = 5},
  [7914] = {.lex_state = 131},
  [7915] = {.lex_state = 2},
  [7916] = {.lex_state = 131},
  [7917] = {.lex_state = 0},
  [7918] = {.lex_state = 131},
  [7919] = {.lex_state = 0, .external_lex_state = 5},
  [7920] = {.lex_state = 0, .external_lex_state = 5},
  [7921] = {.lex_state = 131},
  [7922] = {.lex_state = 131},
  [7923] = {.lex_state = 131},
  [7924] = {.lex_state = 131},
  [7925] = {.lex_state = 131},
  [7926] = {.lex_state = 131},
  [7927] = {.lex_state = 0},
  [7928] = {.lex_state = 2},
  [7929] = {.lex_state = 131},
  [7930] = {.lex_state = 0},
  [7931] = {.lex_state = 131},
  [7932] = {.lex_state = 0},
  [7933] = {.lex_state = 131},
  [7934] = {.lex_state = 131},
  [7935] = {.lex_state = 131},
  [7936] = {.lex_state = 131},
  [7937] = {.lex_state = 0},
  [7938] = {.lex_state = 131},
  [7939] = {.lex_state = 131},
  [7940] = {.lex_state = 0},
  [7941] = {.lex_state = 0, .external_lex_state = 5},
  [7942] = {.lex_state = 0},
  [7943] = {.lex_state = 10},
  [7944] = {.lex_state = 2},
  [7945] = {.lex_state = 131},
  [7946] = {.lex_state = 2},
  [7947] = {.lex_state = 0},
  [7948] = {.lex_state = 2},
  [7949] = {.lex_state = 131},
  [7950] = {.lex_state = 131},
  [7951] = {.lex_state = 131},
  [7952] = {.lex_state = 131},
  [7953] = {.lex_state = 131},
  [7954] = {.lex_state = 1},
  [7955] = {.lex_state = 131},
  [7956] = {.lex_state = 131},
  [7957] = {.lex_state = 131},
  [7958] = {.lex_state = 131},
  [7959] = {.lex_state = 131},
  [7960] = {.lex_state = 0},
  [7961] = {.lex_state = 131},
  [7962] = {.lex_state = 131},
  [7963] = {.lex_state = 131},
  [7964] = {.lex_state = 131},
  [7965] = {.lex_state = 131},
  [7966] = {.lex_state = 131},
  [7967] = {.lex_state = 131},
  [7968] = {.lex_state = 131},
  [7969] = {.lex_state = 1},
  [7970] = {.lex_state = 131},
  [7971] = {.lex_state = 131},
  [7972] = {.lex_state = 1},
  [7973] = {.lex_state = 131},
  [7974] = {.lex_state = 131},
  [7975] = {.lex_state = 131},
  [7976] = {.lex_state = 131},
  [7977] = {.lex_state = 131},
  [7978] = {.lex_state = 131},
  [7979] = {.lex_state = 131},
  [7980] = {.lex_state = 0},
  [7981] = {.lex_state = 131},
  [7982] = {.lex_state = 131},
  [7983] = {.lex_state = 131},
  [7984] = {.lex_state = 130},
  [7985] = {.lex_state = 131},
  [7986] = {.lex_state = 131},
  [7987] = {.lex_state = 131},
  [7988] = {.lex_state = 131},
  [7989] = {.lex_state = 131},
  [7990] = {.lex_state = 1},
  [7991] = {.lex_state = 131},
  [7992] = {.lex_state = 131},
  [7993] = {.lex_state = 131},
  [7994] = {.lex_state = 0},
  [7995] = {.lex_state = 131},
  [7996] = {.lex_state = 131},
  [7997] = {.lex_state = 1},
  [7998] = {.lex_state = 130},
  [7999] = {.lex_state = 1},
  [8000] = {.lex_state = 131},
  [8001] = {.lex_state = 131},
  [8002] = {.lex_state = 131},
  [8003] = {.lex_state = 131},
  [8004] = {.lex_state = 130},
  [8005] = {.lex_state = 131},
  [8006] = {.lex_state = 131},
  [8007] = {.lex_state = 131},
  [8008] = {.lex_state = 131},
  [8009] = {.lex_state = 131},
  [8010] = {.lex_state = 0},
  [8011] = {.lex_state = 131},
  [8012] = {.lex_state = 131},
  [8013] = {.lex_state = 131},
  [8014] = {.lex_state = 0},
  [8015] = {.lex_state = 131},
  [8016] = {.lex_state = 131},
  [8017] = {.lex_state = 131},
  [8018] = {.lex_state = 131},
  [8019] = {.lex_state = 131},
  [8020] = {.lex_state = 131},
  [8021] = {.lex_state = 1},
  [8022] = {.lex_state = 131},
  [8023] = {.lex_state = 131},
  [8024] = {.lex_state = 1},
  [8025] = {.lex_state = 1},
  [8026] = {.lex_state = 131},
  [8027] = {.lex_state = 131},
  [8028] = {.lex_state = 131},
  [8029] = {.lex_state = 131},
  [8030] = {.lex_state = 131},
  [8031] = {.lex_state = 131},
  [8032] = {.lex_state = 131},
  [8033] = {.lex_state = 131},
  [8034] = {.lex_state = 131},
  [8035] = {.lex_state = 131},
  [8036] = {.lex_state = 0},
  [8037] = {.lex_state = 1},
  [8038] = {.lex_state = 131},
  [8039] = {.lex_state = 131},
  [8040] = {.lex_state = 131},
  [8041] = {.lex_state = 1},
  [8042] = {.lex_state = 131},
  [8043] = {.lex_state = 131},
  [8044] = {.lex_state = 1},
  [8045] = {.lex_state = 131},
  [8046] = {.lex_state = 131},
  [8047] = {.lex_state = 131},
  [8048] = {.lex_state = 131},
  [8049] = {.lex_state = 131},
  [8050] = {.lex_state = 131},
  [8051] = {.lex_state = 130},
  [8052] = {.lex_state = 131},
  [8053] = {.lex_state = 131},
  [8054] = {.lex_state = 1},
  [8055] = {.lex_state = 131},
  [8056] = {.lex_state = 10},
  [8057] = {.lex_state = 130},
  [8058] = {.lex_state = 131},
  [8059] = {.lex_state = 131},
  [8060] = {.lex_state = 131},
  [8061] = {.lex_state = 131},
  [8062] = {.lex_state = 130},
  [8063] = {.lex_state = 131},
  [8064] = {.lex_state = 131},
  [8065] = {.lex_state = 131},
  [8066] = {.lex_state = 131},
  [8067] = {.lex_state = 131},
  [8068] = {.lex_state = 0},
  [8069] = {.lex_state = 131},
  [8070] = {.lex_state = 131},
  [8071] = {.lex_state = 131},
  [8072] = {.lex_state = 131},
  [8073] = {.lex_state = 0},
  [8074] = {.lex_state = 131},
  [8075] = {.lex_state = 131},
  [8076] = {.lex_state = 131},
  [8077] = {.lex_state = 131},
  [8078] = {.lex_state = 131},
  [8079] = {.lex_state = 131},
  [8080] = {.lex_state = 131},
  [8081] = {.lex_state = 131},
  [8082] = {.lex_state = 1},
  [8083] = {.lex_state = 0},
  [8084] = {.lex_state = 131},
  [8085] = {.lex_state = 130},
  [8086] = {.lex_state = 131},
  [8087] = {.lex_state = 1},
  [8088] = {.lex_state = 131},
  [8089] = {.lex_state = 131},
  [8090] = {.lex_state = 131},
  [8091] = {.lex_state = 131},
  [8092] = {.lex_state = 131},
  [8093] = {.lex_state = 131},
  [8094] = {.lex_state = 131},
  [8095] = {.lex_state = 131},
  [8096] = {.lex_state = 131},
  [8097] = {.lex_state = 131},
  [8098] = {.lex_state = 131},
  [8099] = {.lex_state = 131},
  [8100] = {.lex_state = 1},
  [8101] = {.lex_state = 1},
  [8102] = {.lex_state = 1},
  [8103] = {.lex_state = 1},
  [8104] = {.lex_state = 1},
  [8105] = {.lex_state = 131},
  [8106] = {.lex_state = 1},
  [8107] = {.lex_state = 131},
  [8108] = {.lex_state = 131},
  [8109] = {.lex_state = 0},
  [8110] = {.lex_state = 131},
  [8111] = {.lex_state = 131},
  [8112] = {.lex_state = 131},
  [8113] = {.lex_state = 131},
  [8114] = {.lex_state = 131},
  [8115] = {.lex_state = 131},
  [8116] = {.lex_state = 131},
  [8117] = {.lex_state = 0},
  [8118] = {.lex_state = 0},
  [8119] = {.lex_state = 0},
  [8120] = {.lex_state = 131},
  [8121] = {.lex_state = 131},
  [8122] = {.lex_state = 131},
  [8123] = {.lex_state = 131},
  [8124] = {.lex_state = 131},
  [8125] = {.lex_state = 131},
  [8126] = {.lex_state = 131},
  [8127] = {.lex_state = 131},
  [8128] = {.lex_state = 1},
  [8129] = {.lex_state = 131},
  [8130] = {.lex_state = 131},
  [8131] = {.lex_state = 131},
  [8132] = {.lex_state = 131},
  [8133] = {.lex_state = 131},
  [8134] = {.lex_state = 131},
  [8135] = {.lex_state = 131},
  [8136] = {.lex_state = 131},
  [8137] = {.lex_state = 131},
  [8138] = {.lex_state = 131},
  [8139] = {.lex_state = 131},
  [8140] = {.lex_state = 131},
  [8141] = {.lex_state = 131},
  [8142] = {.lex_state = 131},
  [8143] = {.lex_state = 131},
  [8144] = {.lex_state = 131},
  [8145] = {.lex_state = 131},
  [8146] = {.lex_state = 131},
  [8147] = {.lex_state = 131},
  [8148] = {.lex_state = 131},
  [8149] = {.lex_state = 131},
  [8150] = {.lex_state = 131},
  [8151] = {.lex_state = 131},
  [8152] = {.lex_state = 131},
  [8153] = {.lex_state = 131},
  [8154] = {.lex_state = 131},
  [8155] = {.lex_state = 131},
  [8156] = {.lex_state = 131},
  [8157] = {.lex_state = 131},
  [8158] = {.lex_state = 131},
  [8159] = {.lex_state = 131},
  [8160] = {.lex_state = 131},
  [8161] = {.lex_state = 131},
  [8162] = {.lex_state = 131},
  [8163] = {.lex_state = 131},
  [8164] = {.lex_state = 131},
  [8165] = {.lex_state = 131},
  [8166] = {.lex_state = 131},
  [8167] = {.lex_state = 0},
  [8168] = {.lex_state = 131},
  [8169] = {.lex_state = 1},
  [8170] = {.lex_state = 131},
  [8171] = {.lex_state = 131},
  [8172] = {.lex_state = 131},
  [8173] = {.lex_state = 10},
  [8174] = {.lex_state = 131},
  [8175] = {.lex_state = 131},
  [8176] = {.lex_state = 131},
  [8177] = {.lex_state = 131},
  [8178] = {.lex_state = 131},
  [8179] = {.lex_state = 131},
  [8180] = {.lex_state = 131},
  [8181] = {.lex_state = 131},
  [8182] = {.lex_state = 131},
  [8183] = {.lex_state = 131},
  [8184] = {.lex_state = 131},
  [8185] = {.lex_state = 131},
  [8186] = {.lex_state = 131},
  [8187] = {.lex_state = 131},
  [8188] = {.lex_state = 131},
  [8189] = {.lex_state = 131},
  [8190] = {.lex_state = 131},
  [8191] = {.lex_state = 131},
  [8192] = {.lex_state = 1},
  [8193] = {.lex_state = 131},
  [8194] = {.lex_state = 131},
  [8195] = {.lex_state = 131},
  [8196] = {.lex_state = 131},
  [8197] = {.lex_state = 131},
  [8198] = {.lex_state = 131},
  [8199] = {.lex_state = 131},
  [8200] = {.lex_state = 131},
  [8201] = {.lex_state = 131},
  [8202] = {.lex_state = 0},
  [8203] = {.lex_state = 131},
  [8204] = {.lex_state = 131},
  [8205] = {.lex_state = 0},
  [8206] = {.lex_state = 131},
  [8207] = {.lex_state = 131},
  [8208] = {.lex_state = 131},
  [8209] = {.lex_state = 131},
  [8210] = {.lex_state = 131},
  [8211] = {.lex_state = 131},
  [8212] = {.lex_state = 131},
  [8213] = {.lex_state = 131},
  [8214] = {.lex_state = 131},
  [8215] = {.lex_state = 131},
  [8216] = {.lex_state = 0},
  [8217] = {.lex_state = 131},
  [8218] = {.lex_state = 131},
  [8219] = {.lex_state = 131},
  [8220] = {.lex_state = 131},
  [8221] = {.lex_state = 131},
  [8222] = {.lex_state = 131},
  [8223] = {.lex_state = 131},
  [8224] = {.lex_state = 130},
  [8225] = {.lex_state = 131},
  [8226] = {.lex_state = 131},
  [8227] = {.lex_state = 131},
  [8228] = {.lex_state = 131},
  [8229] = {.lex_state = 131},
  [8230] = {.lex_state = 131},
  [8231] = {.lex_state = 0},
  [8232] = {.lex_state = 131},
  [8233] = {.lex_state = 131},
  [8234] = {.lex_state = 131},
  [8235] = {.lex_state = 131},
  [8236] = {.lex_state = 131},
  [8237] = {.lex_state = 131},
  [8238] = {.lex_state = 131},
  [8239] = {.lex_state = 131},
  [8240] = {.lex_state = 1},
  [8241] = {.lex_state = 131},
  [8242] = {.lex_state = 131},
  [8243] = {.lex_state = 131},
  [8244] = {.lex_state = 131},
  [8245] = {.lex_state = 131},
  [8246] = {.lex_state = 0},
  [8247] = {.lex_state = 0},
  [8248] = {.lex_state = 0},
  [8249] = {.lex_state = 130},
  [8250] = {.lex_state = 131},
  [8251] = {.lex_state = 131},
  [8252] = {.lex_state = 131},
  [8253] = {.lex_state = 0},
  [8254] = {.lex_state = 131},
  [8255] = {.lex_state = 131},
  [8256] = {.lex_state = 131},
  [8257] = {.lex_state = 131},
  [8258] = {.lex_state = 18, .external_lex_state = 5},
  [8259] = {.lex_state = 131},
  [8260] = {.lex_state = 131},
  [8261] = {.lex_state = 0},
  [8262] = {.lex_state = 130},
  [8263] = {.lex_state = 130},
  [8264] = {.lex_state = 131},
  [8265] = {.lex_state = 0},
  [8266] = {.lex_state = 130},
  [8267] = {.lex_state = 18, .external_lex_state = 5},
  [8268] = {.lex_state = 0},
  [8269] = {.lex_state = 131},
  [8270] = {.lex_state = 130},
  [8271] = {.lex_state = 10},
  [8272] = {.lex_state = 131},
  [8273] = {.lex_state = 0},
  [8274] = {.lex_state = 0},
  [8275] = {.lex_state = 0},
  [8276] = {.lex_state = 130},
  [8277] = {.lex_state = 10},
  [8278] = {.lex_state = 0},
  [8279] = {.lex_state = 130},
  [8280] = {.lex_state = 0},
  [8281] = {.lex_state = 0},
  [8282] = {.lex_state = 131},
  [8283] = {.lex_state = 0},
  [8284] = {.lex_state = 130},
  [8285] = {.lex_state = 130},
  [8286] = {.lex_state = 0},
  [8287] = {.lex_state = 0},
  [8288] = {.lex_state = 130},
  [8289] = {.lex_state = 131},
  [8290] = {.lex_state = 10},
  [8291] = {.lex_state = 131},
  [8292] = {.lex_state = 18, .external_lex_state = 5},
  [8293] = {.lex_state = 4},
  [8294] = {.lex_state = 10},
  [8295] = {.lex_state = 0},
  [8296] = {.lex_state = 131},
  [8297] = {.lex_state = 131},
  [8298] = {.lex_state = 131},
  [8299] = {.lex_state = 131},
  [8300] = {.lex_state = 131},
  [8301] = {.lex_state = 0},
  [8302] = {.lex_state = 131},
  [8303] = {.lex_state = 131},
  [8304] = {.lex_state = 0},
  [8305] = {.lex_state = 131},
  [8306] = {.lex_state = 131},
  [8307] = {.lex_state = 0},
  [8308] = {.lex_state = 131},
  [8309] = {.lex_state = 10},
  [8310] = {.lex_state = 0},
  [8311] = {.lex_state = 0},
  [8312] = {.lex_state = 0},
  [8313] = {.lex_state = 131},
  [8314] = {.lex_state = 0},
  [8315] = {.lex_state = 131},
  [8316] = {.lex_state = 131},
  [8317] = {.lex_state = 10},
  [8318] = {.lex_state = 131},
  [8319] = {.lex_state = 0},
  [8320] = {.lex_state = 131},
  [8321] = {.lex_state = 18, .external_lex_state = 5},
  [8322] = {.lex_state = 0},
  [8323] = {.lex_state = 131},
  [8324] = {.lex_state = 131},
  [8325] = {.lex_state = 131},
  [8326] = {.lex_state = 131},
  [8327] = {.lex_state = 131},
  [8328] = {.lex_state = 131},
  [8329] = {.lex_state = 131},
  [8330] = {.lex_state = 131},
  [8331] = {.lex_state = 10},
  [8332] = {.lex_state = 131},
  [8333] = {.lex_state = 131},
  [8334] = {.lex_state = 131},
  [8335] = {.lex_state = 131},
  [8336] = {.lex_state = 131},
  [8337] = {.lex_state = 131},
  [8338] = {.lex_state = 2},
  [8339] = {.lex_state = 131},
  [8340] = {.lex_state = 2},
  [8341] = {.lex_state = 131},
  [8342] = {.lex_state = 131},
  [8343] = {.lex_state = 131},
  [8344] = {.lex_state = 0},
  [8345] = {.lex_state = 10},
  [8346] = {.lex_state = 2},
  [8347] = {.lex_state = 10},
  [8348] = {.lex_state = 130},
  [8349] = {.lex_state = 131},
  [8350] = {.lex_state = 131},
  [8351] = {.lex_state = 131},
  [8352] = {.lex_state = 0},
  [8353] = {.lex_state = 131},
  [8354] = {.lex_state = 131},
  [8355] = {.lex_state = 131},
  [8356] = {.lex_state = 131},
  [8357] = {.lex_state = 131},
  [8358] = {.lex_state = 131},
  [8359] = {.lex_state = 131},
  [8360] = {.lex_state = 0},
  [8361] = {.lex_state = 0},
  [8362] = {.lex_state = 131},
  [8363] = {.lex_state = 0},
  [8364] = {.lex_state = 0},
  [8365] = {.lex_state = 131},
  [8366] = {.lex_state = 131},
  [8367] = {.lex_state = 131},
  [8368] = {.lex_state = 131},
  [8369] = {.lex_state = 131},
  [8370] = {.lex_state = 131},
  [8371] = {.lex_state = 131},
  [8372] = {.lex_state = 131},
  [8373] = {.lex_state = 131},
  [8374] = {.lex_state = 131},
  [8375] = {.lex_state = 131},
  [8376] = {.lex_state = 0},
  [8377] = {.lex_state = 131},
  [8378] = {.lex_state = 131},
  [8379] = {.lex_state = 131},
  [8380] = {.lex_state = 131},
  [8381] = {.lex_state = 131},
  [8382] = {.lex_state = 0},
  [8383] = {.lex_state = 131},
  [8384] = {.lex_state = 18, .external_lex_state = 5},
  [8385] = {.lex_state = 0},
  [8386] = {.lex_state = 0},
  [8387] = {.lex_state = 1},
  [8388] = {.lex_state = 0},
  [8389] = {.lex_state = 0},
  [8390] = {.lex_state = 0},
  [8391] = {.lex_state = 0},
  [8392] = {.lex_state = 0},
  [8393] = {.lex_state = 0},
  [8394] = {.lex_state = 0},
  [8395] = {.lex_state = 0},
  [8396] = {.lex_state = 0},
  [8397] = {.lex_state = 0},
  [8398] = {.lex_state = 0},
  [8399] = {.lex_state = 0},
  [8400] = {.lex_state = 0},
  [8401] = {.lex_state = 0},
  [8402] = {.lex_state = 0},
  [8403] = {.lex_state = 0},
  [8404] = {.lex_state = 0},
  [8405] = {.lex_state = 0},
  [8406] = {.lex_state = 0},
  [8407] = {.lex_state = 0},
  [8408] = {.lex_state = 0},
  [8409] = {.lex_state = 0},
  [8410] = {.lex_state = 0},
  [8411] = {.lex_state = 0},
  [8412] = {.lex_state = 0},
  [8413] = {.lex_state = 0},
  [8414] = {.lex_state = 0},
  [8415] = {.lex_state = 0},
  [8416] = {.lex_state = 0},
  [8417] = {.lex_state = 0},
  [8418] = {.lex_state = 0},
  [8419] = {.lex_state = 0},
  [8420] = {.lex_state = 0},
  [8421] = {.lex_state = 10},
  [8422] = {.lex_state = 0},
  [8423] = {.lex_state = 0},
  [8424] = {.lex_state = 0},
  [8425] = {.lex_state = 1},
  [8426] = {.lex_state = 10},
  [8427] = {.lex_state = 0},
  [8428] = {.lex_state = 0},
  [8429] = {.lex_state = 1},
  [8430] = {.lex_state = 0},
  [8431] = {.lex_state = 0},
  [8432] = {.lex_state = 0},
  [8433] = {.lex_state = 0},
  [8434] = {.lex_state = 0},
  [8435] = {.lex_state = 0},
  [8436] = {.lex_state = 0},
  [8437] = {.lex_state = 1},
  [8438] = {.lex_state = 130, .external_lex_state = 4},
  [8439] = {.lex_state = 0},
  [8440] = {.lex_state = 0},
  [8441] = {.lex_state = 0},
  [8442] = {.lex_state = 0},
  [8443] = {.lex_state = 0},
  [8444] = {.lex_state = 0},
  [8445] = {.lex_state = 0},
  [8446] = {.lex_state = 10},
  [8447] = {.lex_state = 0},
  [8448] = {.lex_state = 0},
  [8449] = {.lex_state = 0},
  [8450] = {.lex_state = 0},
  [8451] = {.lex_state = 0},
  [8452] = {.lex_state = 0},
  [8453] = {.lex_state = 0},
  [8454] = {.lex_state = 0},
  [8455] = {.lex_state = 0},
  [8456] = {.lex_state = 0},
  [8457] = {.lex_state = 0},
  [8458] = {.lex_state = 0},
  [8459] = {.lex_state = 0},
  [8460] = {.lex_state = 0},
  [8461] = {.lex_state = 0},
  [8462] = {.lex_state = 0},
  [8463] = {.lex_state = 0},
  [8464] = {.lex_state = 0},
  [8465] = {.lex_state = 0},
  [8466] = {.lex_state = 0},
  [8467] = {.lex_state = 0},
  [8468] = {.lex_state = 10},
  [8469] = {.lex_state = 10},
  [8470] = {.lex_state = 10},
  [8471] = {.lex_state = 0},
  [8472] = {.lex_state = 0},
  [8473] = {.lex_state = 0},
  [8474] = {.lex_state = 0},
  [8475] = {.lex_state = 10},
  [8476] = {.lex_state = 0},
  [8477] = {.lex_state = 0},
  [8478] = {.lex_state = 0},
  [8479] = {.lex_state = 10},
  [8480] = {.lex_state = 10},
  [8481] = {.lex_state = 0},
  [8482] = {.lex_state = 0},
  [8483] = {.lex_state = 0},
  [8484] = {.lex_state = 0},
  [8485] = {.lex_state = 0},
  [8486] = {.lex_state = 0},
  [8487] = {.lex_state = 10},
  [8488] = {.lex_state = 0},
  [8489] = {.lex_state = 0},
  [8490] = {.lex_state = 0},
  [8491] = {.lex_state = 0},
  [8492] = {.lex_state = 0},
  [8493] = {.lex_state = 0},
  [8494] = {.lex_state = 0},
  [8495] = {.lex_state = 0},
  [8496] = {.lex_state = 0},
  [8497] = {.lex_state = 0},
  [8498] = {.lex_state = 10},
  [8499] = {.lex_state = 0},
  [8500] = {.lex_state = 0},
  [8501] = {.lex_state = 10},
  [8502] = {.lex_state = 0},
  [8503] = {.lex_state = 0},
  [8504] = {.lex_state = 0},
  [8505] = {.lex_state = 0},
  [8506] = {.lex_state = 0},
  [8507] = {.lex_state = 0},
  [8508] = {.lex_state = 0},
  [8509] = {.lex_state = 0},
  [8510] = {.lex_state = 0},
  [8511] = {.lex_state = 10},
  [8512] = {.lex_state = 0},
  [8513] = {.lex_state = 0},
  [8514] = {.lex_state = 0},
  [8515] = {.lex_state = 0},
  [8516] = {.lex_state = 0},
  [8517] = {.lex_state = 0},
  [8518] = {.lex_state = 0},
  [8519] = {.lex_state = 0},
  [8520] = {.lex_state = 0},
  [8521] = {.lex_state = 0},
  [8522] = {.lex_state = 0},
  [8523] = {.lex_state = 0},
  [8524] = {.lex_state = 131},
  [8525] = {.lex_state = 0},
  [8526] = {.lex_state = 0},
  [8527] = {.lex_state = 131},
  [8528] = {.lex_state = 0},
  [8529] = {.lex_state = 0},
  [8530] = {.lex_state = 0},
  [8531] = {.lex_state = 4},
  [8532] = {.lex_state = 10},
  [8533] = {.lex_state = 0},
  [8534] = {.lex_state = 10},
  [8535] = {.lex_state = 0},
  [8536] = {.lex_state = 10},
  [8537] = {.lex_state = 10},
  [8538] = {.lex_state = 0},
  [8539] = {.lex_state = 10},
  [8540] = {.lex_state = 10},
  [8541] = {.lex_state = 0, .external_lex_state = 5},
  [8542] = {.lex_state = 0},
  [8543] = {.lex_state = 10},
  [8544] = {.lex_state = 0},
  [8545] = {.lex_state = 0},
  [8546] = {.lex_state = 0},
  [8547] = {.lex_state = 0},
  [8548] = {.lex_state = 0},
  [8549] = {.lex_state = 0},
  [8550] = {.lex_state = 0},
  [8551] = {.lex_state = 0},
  [8552] = {.lex_state = 0},
  [8553] = {.lex_state = 0},
  [8554] = {.lex_state = 0},
  [8555] = {.lex_state = 10},
  [8556] = {.lex_state = 0, .external_lex_state = 5},
  [8557] = {.lex_state = 0},
  [8558] = {.lex_state = 10},
  [8559] = {.lex_state = 0},
  [8560] = {.lex_state = 0},
  [8561] = {.lex_state = 0},
  [8562] = {.lex_state = 0},
  [8563] = {.lex_state = 0},
  [8564] = {.lex_state = 0},
  [8565] = {.lex_state = 0, .external_lex_state = 5},
  [8566] = {.lex_state = 131},
  [8567] = {.lex_state = 0, .external_lex_state = 5},
  [8568] = {.lex_state = 0},
  [8569] = {.lex_state = 0},
  [8570] = {.lex_state = 0},
  [8571] = {.lex_state = 0},
  [8572] = {.lex_state = 0},
  [8573] = {.lex_state = 0},
  [8574] = {.lex_state = 0},
  [8575] = {.lex_state = 0},
  [8576] = {.lex_state = 10},
  [8577] = {.lex_state = 0},
  [8578] = {.lex_state = 0},
  [8579] = {.lex_state = 0},
  [8580] = {.lex_state = 0},
  [8581] = {.lex_state = 0},
  [8582] = {.lex_state = 0},
  [8583] = {.lex_state = 0},
  [8584] = {.lex_state = 0},
  [8585] = {.lex_state = 0},
  [8586] = {.lex_state = 0},
  [8587] = {.lex_state = 0},
  [8588] = {.lex_state = 0},
  [8589] = {.lex_state = 0},
  [8590] = {.lex_state = 10},
  [8591] = {.lex_state = 10},
  [8592] = {.lex_state = 0},
  [8593] = {.lex_state = 10},
  [8594] = {.lex_state = 10},
  [8595] = {.lex_state = 0},
  [8596] = {.lex_state = 0},
  [8597] = {.lex_state = 10},
  [8598] = {.lex_state = 0},
  [8599] = {.lex_state = 0},
  [8600] = {.lex_state = 0},
  [8601] = {.lex_state = 0},
  [8602] = {.lex_state = 0},
  [8603] = {.lex_state = 0},
  [8604] = {.lex_state = 10},
  [8605] = {.lex_state = 0},
  [8606] = {.lex_state = 0},
  [8607] = {.lex_state = 0},
  [8608] = {.lex_state = 0},
  [8609] = {.lex_state = 0},
  [8610] = {.lex_state = 131},
  [8611] = {.lex_state = 131},
  [8612] = {.lex_state = 0},
  [8613] = {.lex_state = 0},
  [8614] = {.lex_state = 0},
  [8615] = {.lex_state = 0},
  [8616] = {.lex_state = 0},
  [8617] = {.lex_state = 0},
  [8618] = {.lex_state = 0},
  [8619] = {.lex_state = 0},
  [8620] = {.lex_state = 0},
  [8621] = {.lex_state = 0},
  [8622] = {.lex_state = 0},
  [8623] = {.lex_state = 0},
  [8624] = {.lex_state = 0},
  [8625] = {.lex_state = 0},
  [8626] = {.lex_state = 0},
  [8627] = {.lex_state = 0},
  [8628] = {.lex_state = 0},
  [8629] = {.lex_state = 0},
  [8630] = {.lex_state = 10},
  [8631] = {.lex_state = 0},
  [8632] = {.lex_state = 10},
  [8633] = {.lex_state = 10},
  [8634] = {.lex_state = 0},
  [8635] = {.lex_state = 0},
  [8636] = {.lex_state = 0},
  [8637] = {.lex_state = 0},
  [8638] = {.lex_state = 0},
  [8639] = {.lex_state = 0},
  [8640] = {.lex_state = 0},
  [8641] = {.lex_state = 0},
  [8642] = {.lex_state = 0},
  [8643] = {.lex_state = 10},
  [8644] = {.lex_state = 10},
  [8645] = {.lex_state = 0},
  [8646] = {.lex_state = 0},
  [8647] = {.lex_state = 0},
  [8648] = {.lex_state = 10},
  [8649] = {.lex_state = 10},
  [8650] = {.lex_state = 10},
  [8651] = {.lex_state = 1},
  [8652] = {.lex_state = 0},
  [8653] = {.lex_state = 0},
  [8654] = {.lex_state = 0},
  [8655] = {.lex_state = 0},
  [8656] = {.lex_state = 0},
  [8657] = {.lex_state = 0},
  [8658] = {.lex_state = 0},
  [8659] = {.lex_state = 0},
  [8660] = {.lex_state = 0},
  [8661] = {.lex_state = 131},
  [8662] = {.lex_state = 10},
  [8663] = {.lex_state = 0},
  [8664] = {.lex_state = 10},
  [8665] = {.lex_state = 0},
  [8666] = {.lex_state = 0},
  [8667] = {.lex_state = 0},
  [8668] = {.lex_state = 10},
  [8669] = {.lex_state = 0},
  [8670] = {.lex_state = 0},
  [8671] = {.lex_state = 0},
  [8672] = {.lex_state = 0},
  [8673] = {.lex_state = 0},
  [8674] = {.lex_state = 10},
  [8675] = {.lex_state = 10},
  [8676] = {.lex_state = 0},
  [8677] = {.lex_state = 0},
  [8678] = {.lex_state = 10},
  [8679] = {.lex_state = 10},
  [8680] = {.lex_state = 0},
  [8681] = {.lex_state = 10},
  [8682] = {.lex_state = 0},
  [8683] = {.lex_state = 10},
  [8684] = {.lex_state = 0},
  [8685] = {.lex_state = 0},
  [8686] = {.lex_state = 0},
  [8687] = {.lex_state = 0},
  [8688] = {.lex_state = 0},
  [8689] = {.lex_state = 10},
  [8690] = {.lex_state = 0},
  [8691] = {.lex_state = 0},
  [8692] = {.lex_state = 0},
  [8693] = {.lex_state = 0},
  [8694] = {.lex_state = 0},
  [8695] = {.lex_state = 0},
  [8696] = {.lex_state = 0},
  [8697] = {.lex_state = 0},
  [8698] = {.lex_state = 0},
  [8699] = {.lex_state = 0},
  [8700] = {.lex_state = 0},
  [8701] = {.lex_state = 0},
  [8702] = {.lex_state = 0},
  [8703] = {.lex_state = 10},
  [8704] = {.lex_state = 0},
  [8705] = {.lex_state = 131},
  [8706] = {.lex_state = 0},
  [8707] = {.lex_state = 131},
  [8708] = {.lex_state = 0},
  [8709] = {.lex_state = 0},
  [8710] = {.lex_state = 0},
  [8711] = {.lex_state = 131},
  [8712] = {.lex_state = 0},
  [8713] = {.lex_state = 0},
  [8714] = {.lex_state = 131},
  [8715] = {.lex_state = 131},
  [8716] = {.lex_state = 131},
  [8717] = {.lex_state = 131},
  [8718] = {.lex_state = 0},
  [8719] = {.lex_state = 0},
  [8720] = {.lex_state = 0},
  [8721] = {.lex_state = 0},
  [8722] = {.lex_state = 131},
  [8723] = {.lex_state = 131},
  [8724] = {.lex_state = 0},
  [8725] = {.lex_state = 0},
  [8726] = {.lex_state = 131},
  [8727] = {.lex_state = 0},
  [8728] = {.lex_state = 131},
  [8729] = {.lex_state = 0},
  [8730] = {.lex_state = 0},
  [8731] = {.lex_state = 10},
  [8732] = {.lex_state = 0},
  [8733] = {.lex_state = 0},
  [8734] = {.lex_state = 0},
  [8735] = {.lex_state = 0},
  [8736] = {.lex_state = 0},
  [8737] = {.lex_state = 0},
  [8738] = {.lex_state = 0},
  [8739] = {.lex_state = 131},
  [8740] = {.lex_state = 3},
  [8741] = {.lex_state = 0},
  [8742] = {.lex_state = 131},
  [8743] = {.lex_state = 131},
  [8744] = {.lex_state = 131},
  [8745] = {.lex_state = 0},
  [8746] = {.lex_state = 0},
  [8747] = {.lex_state = 10},
  [8748] = {.lex_state = 0},
  [8749] = {.lex_state = 0},
  [8750] = {.lex_state = 3},
  [8751] = {.lex_state = 131},
  [8752] = {.lex_state = 131},
  [8753] = {.lex_state = 0},
  [8754] = {.lex_state = 0},
  [8755] = {.lex_state = 131},
  [8756] = {.lex_state = 0},
  [8757] = {.lex_state = 131},
  [8758] = {.lex_state = 131},
  [8759] = {.lex_state = 0},
  [8760] = {.lex_state = 0},
  [8761] = {.lex_state = 15},
  [8762] = {.lex_state = 0},
  [8763] = {.lex_state = 0},
  [8764] = {.lex_state = 0},
  [8765] = {.lex_state = 15},
  [8766] = {.lex_state = 0},
  [8767] = {.lex_state = 10},
  [8768] = {.lex_state = 0},
  [8769] = {.lex_state = 131},
  [8770] = {.lex_state = 0},
  [8771] = {.lex_state = 131},
  [8772] = {.lex_state = 131},
  [8773] = {.lex_state = 0},
  [8774] = {.lex_state = 15},
  [8775] = {.lex_state = 0},
  [8776] = {.lex_state = 0},
  [8777] = {.lex_state = 1},
  [8778] = {.lex_state = 0},
  [8779] = {.lex_state = 0},
  [8780] = {.lex_state = 131},
  [8781] = {.lex_state = 0},
  [8782] = {.lex_state = 0},
  [8783] = {.lex_state = 0},
  [8784] = {.lex_state = 0},
  [8785] = {.lex_state = 0},
  [8786] = {.lex_state = 0},
  [8787] = {.lex_state = 10},
  [8788] = {.lex_state = 0},
  [8789] = {.lex_state = 0},
  [8790] = {.lex_state = 0},
  [8791] = {.lex_state = 0},
  [8792] = {.lex_state = 0},
  [8793] = {.lex_state = 0},
  [8794] = {.lex_state = 0},
  [8795] = {.lex_state = 131},
  [8796] = {.lex_state = 0},
  [8797] = {.lex_state = 0},
  [8798] = {.lex_state = 0},
  [8799] = {.lex_state = 0},
  [8800] = {.lex_state = 0},
  [8801] = {.lex_state = 131},
  [8802] = {.lex_state = 131},
  [8803] = {.lex_state = 0},
  [8804] = {.lex_state = 0},
  [8805] = {.lex_state = 0},
  [8806] = {.lex_state = 0},
  [8807] = {.lex_state = 0},
  [8808] = {.lex_state = 0},
  [8809] = {.lex_state = 0},
  [8810] = {.lex_state = 0},
  [8811] = {.lex_state = 0},
  [8812] = {.lex_state = 0},
  [8813] = {.lex_state = 0},
  [8814] = {.lex_state = 0},
  [8815] = {.lex_state = 131},
  [8816] = {.lex_state = 0},
  [8817] = {.lex_state = 0},
  [8818] = {.lex_state = 0},
  [8819] = {.lex_state = 0},
  [8820] = {.lex_state = 0},
  [8821] = {.lex_state = 0},
  [8822] = {.lex_state = 131},
  [8823] = {.lex_state = 0},
  [8824] = {.lex_state = 0},
  [8825] = {.lex_state = 0},
  [8826] = {.lex_state = 131},
  [8827] = {.lex_state = 0},
  [8828] = {.lex_state = 10},
  [8829] = {.lex_state = 0},
  [8830] = {.lex_state = 131},
  [8831] = {.lex_state = 131},
  [8832] = {.lex_state = 0},
  [8833] = {.lex_state = 0},
  [8834] = {.lex_state = 131},
  [8835] = {.lex_state = 0},
  [8836] = {.lex_state = 0},
  [8837] = {.lex_state = 0},
  [8838] = {.lex_state = 0},
  [8839] = {.lex_state = 0},
  [8840] = {.lex_state = 0},
  [8841] = {.lex_state = 0},
  [8842] = {.lex_state = 0},
  [8843] = {.lex_state = 131},
  [8844] = {.lex_state = 131},
  [8845] = {.lex_state = 131},
  [8846] = {.lex_state = 0},
  [8847] = {.lex_state = 0},
  [8848] = {.lex_state = 0},
  [8849] = {.lex_state = 10},
  [8850] = {.lex_state = 0},
  [8851] = {.lex_state = 0},
  [8852] = {.lex_state = 0},
  [8853] = {.lex_state = 0},
  [8854] = {.lex_state = 0},
  [8855] = {.lex_state = 0},
  [8856] = {.lex_state = 0},
  [8857] = {.lex_state = 0},
  [8858] = {.lex_state = 131},
  [8859] = {.lex_state = 0},
  [8860] = {.lex_state = 0},
  [8861] = {.lex_state = 131},
  [8862] = {.lex_state = 0},
  [8863] = {.lex_state = 131},
  [8864] = {.lex_state = 0},
  [8865] = {.lex_state = 131},
  [8866] = {.lex_state = 131},
  [8867] = {.lex_state = 0},
  [8868] = {.lex_state = 10},
  [8869] = {.lex_state = 0},
  [8870] = {.lex_state = 10},
  [8871] = {.lex_state = 0},
  [8872] = {.lex_state = 131},
  [8873] = {.lex_state = 0},
  [8874] = {.lex_state = 10},
  [8875] = {.lex_state = 0},
  [8876] = {.lex_state = 131},
  [8877] = {.lex_state = 0},
  [8878] = {.lex_state = 131},
  [8879] = {.lex_state = 131},
  [8880] = {.lex_state = 131},
  [8881] = {.lex_state = 131},
  [8882] = {.lex_state = 0},
  [8883] = {.lex_state = 0},
  [8884] = {.lex_state = 0},
  [8885] = {.lex_state = 131},
  [8886] = {.lex_state = 15},
  [8887] = {.lex_state = 131},
  [8888] = {.lex_state = 131},
  [8889] = {.lex_state = 131},
  [8890] = {.lex_state = 131},
  [8891] = {.lex_state = 131},
  [8892] = {.lex_state = 131},
  [8893] = {.lex_state = 0},
  [8894] = {.lex_state = 0},
  [8895] = {.lex_state = 0},
  [8896] = {.lex_state = 131},
  [8897] = {.lex_state = 0},
  [8898] = {.lex_state = 131},
  [8899] = {.lex_state = 0},
  [8900] = {.lex_state = 0},
  [8901] = {.lex_state = 0},
  [8902] = {.lex_state = 0},
  [8903] = {.lex_state = 0},
  [8904] = {.lex_state = 131},
  [8905] = {.lex_state = 131},
  [8906] = {.lex_state = 131},
  [8907] = {.lex_state = 0},
  [8908] = {.lex_state = 131},
  [8909] = {.lex_state = 131},
  [8910] = {.lex_state = 0},
  [8911] = {.lex_state = 0},
  [8912] = {.lex_state = 0},
  [8913] = {.lex_state = 131},
  [8914] = {.lex_state = 0},
  [8915] = {.lex_state = 131},
  [8916] = {.lex_state = 131},
  [8917] = {.lex_state = 0},
  [8918] = {.lex_state = 0},
  [8919] = {.lex_state = 0},
  [8920] = {.lex_state = 131},
  [8921] = {.lex_state = 131},
  [8922] = {.lex_state = 0},
  [8923] = {.lex_state = 0},
  [8924] = {.lex_state = 0},
  [8925] = {.lex_state = 131},
  [8926] = {.lex_state = 0},
  [8927] = {.lex_state = 0},
  [8928] = {.lex_state = 131},
  [8929] = {.lex_state = 131},
  [8930] = {.lex_state = 1},
  [8931] = {.lex_state = 0},
  [8932] = {.lex_state = 0},
  [8933] = {.lex_state = 0},
  [8934] = {.lex_state = 0},
  [8935] = {.lex_state = 0},
  [8936] = {.lex_state = 131},
  [8937] = {.lex_state = 0},
  [8938] = {.lex_state = 0},
  [8939] = {.lex_state = 0},
  [8940] = {.lex_state = 0},
  [8941] = {.lex_state = 0},
  [8942] = {.lex_state = 0},
  [8943] = {.lex_state = 0},
  [8944] = {.lex_state = 1},
  [8945] = {.lex_state = 15},
  [8946] = {.lex_state = 0},
  [8947] = {.lex_state = 10},
  [8948] = {.lex_state = 131},
  [8949] = {.lex_state = 131},
  [8950] = {.lex_state = 0},
  [8951] = {.lex_state = 0},
  [8952] = {.lex_state = 0},
  [8953] = {.lex_state = 0},
  [8954] = {.lex_state = 131},
  [8955] = {.lex_state = 0},
  [8956] = {.lex_state = 0},
  [8957] = {.lex_state = 131},
  [8958] = {.lex_state = 0},
  [8959] = {.lex_state = 0},
  [8960] = {.lex_state = 131},
  [8961] = {.lex_state = 131},
  [8962] = {.lex_state = 131},
  [8963] = {.lex_state = 0},
  [8964] = {.lex_state = 131},
  [8965] = {.lex_state = 131},
  [8966] = {.lex_state = 0},
  [8967] = {.lex_state = 15},
  [8968] = {.lex_state = 0},
  [8969] = {.lex_state = 0},
  [8970] = {.lex_state = 131},
  [8971] = {.lex_state = 0},
  [8972] = {.lex_state = 131},
  [8973] = {.lex_state = 0},
  [8974] = {.lex_state = 0},
  [8975] = {.lex_state = 131},
  [8976] = {.lex_state = 131},
  [8977] = {.lex_state = 0},
  [8978] = {.lex_state = 0},
  [8979] = {.lex_state = 131},
  [8980] = {.lex_state = 0},
  [8981] = {.lex_state = 131},
  [8982] = {.lex_state = 0},
  [8983] = {.lex_state = 131},
  [8984] = {.lex_state = 131},
  [8985] = {.lex_state = 0},
  [8986] = {.lex_state = 0},
  [8987] = {.lex_state = 0},
  [8988] = {.lex_state = 0},
  [8989] = {.lex_state = 0},
  [8990] = {.lex_state = 131},
  [8991] = {.lex_state = 0},
  [8992] = {.lex_state = 0},
  [8993] = {.lex_state = 0},
  [8994] = {.lex_state = 0},
  [8995] = {.lex_state = 0},
  [8996] = {.lex_state = 0},
  [8997] = {.lex_state = 0},
  [8998] = {.lex_state = 0},
  [8999] = {.lex_state = 0},
  [9000] = {.lex_state = 0},
  [9001] = {.lex_state = 0},
  [9002] = {.lex_state = 0},
  [9003] = {.lex_state = 0, .external_lex_state = 6},
  [9004] = {.lex_state = 0},
  [9005] = {.lex_state = 0},
  [9006] = {.lex_state = 0},
  [9007] = {.lex_state = 0},
  [9008] = {.lex_state = 0},
  [9009] = {.lex_state = 0},
  [9010] = {.lex_state = 0},
  [9011] = {.lex_state = 0, .external_lex_state = 6},
  [9012] = {.lex_state = 0},
  [9013] = {.lex_state = 0},
  [9014] = {.lex_state = 10},
  [9015] = {.lex_state = 0},
  [9016] = {.lex_state = 4},
  [9017] = {.lex_state = 0},
  [9018] = {.lex_state = 0},
  [9019] = {.lex_state = 0},
  [9020] = {.lex_state = 0},
  [9021] = {.lex_state = 0},
  [9022] = {.lex_state = 0},
  [9023] = {.lex_state = 0},
  [9024] = {.lex_state = 0},
  [9025] = {.lex_state = 0, .external_lex_state = 6},
  [9026] = {.lex_state = 0, .external_lex_state = 6},
  [9027] = {.lex_state = 10},
  [9028] = {.lex_state = 10},
  [9029] = {.lex_state = 0},
  [9030] = {.lex_state = 0},
  [9031] = {.lex_state = 0},
  [9032] = {.lex_state = 0},
  [9033] = {.lex_state = 0},
  [9034] = {.lex_state = 0},
  [9035] = {.lex_state = 0},
  [9036] = {.lex_state = 0},
  [9037] = {.lex_state = 0},
  [9038] = {.lex_state = 0},
  [9039] = {.lex_state = 0, .external_lex_state = 6},
  [9040] = {.lex_state = 0},
  [9041] = {.lex_state = 0},
  [9042] = {.lex_state = 0, .external_lex_state = 6},
  [9043] = {.lex_state = 10},
  [9044] = {.lex_state = 0, .external_lex_state = 6},
  [9045] = {.lex_state = 0},
  [9046] = {.lex_state = 0},
  [9047] = {.lex_state = 0},
  [9048] = {.lex_state = 0, .external_lex_state = 6},
  [9049] = {.lex_state = 0},
  [9050] = {.lex_state = 0},
  [9051] = {.lex_state = 0, .external_lex_state = 6},
  [9052] = {.lex_state = 0},
  [9053] = {.lex_state = 0},
  [9054] = {.lex_state = 0},
  [9055] = {.lex_state = 0, .external_lex_state = 6},
  [9056] = {.lex_state = 0},
  [9057] = {.lex_state = 0, .external_lex_state = 6},
  [9058] = {.lex_state = 0},
  [9059] = {.lex_state = 0},
  [9060] = {.lex_state = 0},
  [9061] = {.lex_state = 0},
  [9062] = {.lex_state = 0},
  [9063] = {.lex_state = 0},
  [9064] = {.lex_state = 0},
  [9065] = {.lex_state = 0},
  [9066] = {.lex_state = 0},
  [9067] = {.lex_state = 0},
  [9068] = {.lex_state = 0, .external_lex_state = 6},
  [9069] = {.lex_state = 0},
  [9070] = {.lex_state = 0, .external_lex_state = 6},
  [9071] = {.lex_state = 131},
  [9072] = {.lex_state = 0},
  [9073] = {.lex_state = 0},
  [9074] = {.lex_state = 130},
  [9075] = {.lex_state = 0},
  [9076] = {.lex_state = 0},
  [9077] = {.lex_state = 0},
  [9078] = {.lex_state = 0},
  [9079] = {.lex_state = 131},
  [9080] = {.lex_state = 0, .external_lex_state = 6},
  [9081] = {.lex_state = 0},
  [9082] = {.lex_state = 0},
  [9083] = {.lex_state = 0},
  [9084] = {.lex_state = 14},
  [9085] = {.lex_state = 0, .external_lex_state = 6},
  [9086] = {.lex_state = 0},
  [9087] = {.lex_state = 0, .external_lex_state = 6},
  [9088] = {.lex_state = 0},
  [9089] = {.lex_state = 0},
  [9090] = {.lex_state = 0},
  [9091] = {.lex_state = 0, .external_lex_state = 6},
  [9092] = {.lex_state = 0},
  [9093] = {.lex_state = 0},
  [9094] = {.lex_state = 0},
  [9095] = {.lex_state = 0},
  [9096] = {.lex_state = 0},
  [9097] = {.lex_state = 0},
  [9098] = {.lex_state = 0},
  [9099] = {.lex_state = 0, .external_lex_state = 6},
  [9100] = {.lex_state = 0},
  [9101] = {.lex_state = 131},
  [9102] = {.lex_state = 0, .external_lex_state = 6},
  [9103] = {.lex_state = 10},
  [9104] = {.lex_state = 0, .external_lex_state = 6},
  [9105] = {.lex_state = 0, .external_lex_state = 6},
  [9106] = {.lex_state = 0},
  [9107] = {.lex_state = 0},
  [9108] = {.lex_state = 0},
  [9109] = {.lex_state = 0},
  [9110] = {.lex_state = 0},
  [9111] = {.lex_state = 0},
  [9112] = {.lex_state = 0, .external_lex_state = 7},
  [9113] = {.lex_state = 0},
  [9114] = {.lex_state = 0, .external_lex_state = 6},
  [9115] = {.lex_state = 0},
  [9116] = {.lex_state = 131},
  [9117] = {.lex_state = 0},
  [9118] = {.lex_state = 0},
  [9119] = {.lex_state = 0},
  [9120] = {.lex_state = 0},
  [9121] = {.lex_state = 0},
  [9122] = {.lex_state = 0},
  [9123] = {.lex_state = 0, .external_lex_state = 6},
  [9124] = {.lex_state = 0},
  [9125] = {.lex_state = 0},
  [9126] = {.lex_state = 0},
  [9127] = {.lex_state = 0},
  [9128] = {.lex_state = 0},
  [9129] = {.lex_state = 0},
  [9130] = {.lex_state = 0},
  [9131] = {.lex_state = 0},
  [9132] = {.lex_state = 0},
  [9133] = {.lex_state = 0, .external_lex_state = 6},
  [9134] = {.lex_state = 0},
  [9135] = {.lex_state = 0},
  [9136] = {.lex_state = 0, .external_lex_state = 6},
  [9137] = {.lex_state = 0},
  [9138] = {.lex_state = 0, .external_lex_state = 6},
  [9139] = {.lex_state = 0},
  [9140] = {.lex_state = 0},
  [9141] = {.lex_state = 0},
  [9142] = {.lex_state = 0, .external_lex_state = 6},
  [9143] = {.lex_state = 0},
  [9144] = {.lex_state = 0, .external_lex_state = 6},
  [9145] = {.lex_state = 0},
  [9146] = {.lex_state = 0, .external_lex_state = 6},
  [9147] = {.lex_state = 0},
  [9148] = {.lex_state = 0},
  [9149] = {.lex_state = 0},
  [9150] = {.lex_state = 0, .external_lex_state = 6},
  [9151] = {.lex_state = 0},
  [9152] = {.lex_state = 0, .external_lex_state = 6},
  [9153] = {.lex_state = 0, .external_lex_state = 6},
  [9154] = {.lex_state = 0},
  [9155] = {.lex_state = 1},
  [9156] = {.lex_state = 0},
  [9157] = {.lex_state = 0},
  [9158] = {.lex_state = 0},
  [9159] = {.lex_state = 0, .external_lex_state = 6},
  [9160] = {.lex_state = 0, .external_lex_state = 6},
  [9161] = {.lex_state = 1},
  [9162] = {.lex_state = 0},
  [9163] = {.lex_state = 0},
  [9164] = {.lex_state = 0, .external_lex_state = 6},
  [9165] = {.lex_state = 0},
  [9166] = {.lex_state = 0, .external_lex_state = 6},
  [9167] = {.lex_state = 0, .external_lex_state = 6},
  [9168] = {.lex_state = 0},
  [9169] = {.lex_state = 0},
  [9170] = {.lex_state = 0},
  [9171] = {.lex_state = 0},
  [9172] = {.lex_state = 0, .external_lex_state = 6},
  [9173] = {.lex_state = 0},
  [9174] = {.lex_state = 0},
  [9175] = {.lex_state = 0},
  [9176] = {.lex_state = 0},
  [9177] = {.lex_state = 0, .external_lex_state = 6},
  [9178] = {.lex_state = 0},
  [9179] = {.lex_state = 0, .external_lex_state = 6},
  [9180] = {.lex_state = 0},
  [9181] = {.lex_state = 0},
  [9182] = {.lex_state = 0, .external_lex_state = 6},
  [9183] = {.lex_state = 0},
  [9184] = {.lex_state = 0},
  [9185] = {.lex_state = 0},
  [9186] = {.lex_state = 0},
  [9187] = {.lex_state = 130},
  [9188] = {.lex_state = 0},
  [9189] = {.lex_state = 0},
  [9190] = {.lex_state = 0},
  [9191] = {.lex_state = 0},
  [9192] = {.lex_state = 0},
  [9193] = {.lex_state = 0},
  [9194] = {.lex_state = 0},
  [9195] = {.lex_state = 0},
  [9196] = {.lex_state = 0},
  [9197] = {.lex_state = 0},
  [9198] = {.lex_state = 0},
  [9199] = {.lex_state = 0},
  [9200] = {.lex_state = 0},
  [9201] = {.lex_state = 0, .external_lex_state = 6},
  [9202] = {.lex_state = 0},
  [9203] = {.lex_state = 14},
  [9204] = {.lex_state = 0},
  [9205] = {.lex_state = 0},
  [9206] = {.lex_state = 0, .external_lex_state = 6},
  [9207] = {.lex_state = 0, .external_lex_state = 6},
  [9208] = {.lex_state = 0},
  [9209] = {.lex_state = 0},
  [9210] = {.lex_state = 0},
  [9211] = {.lex_state = 1},
  [9212] = {.lex_state = 0, .external_lex_state = 6},
  [9213] = {.lex_state = 0},
  [9214] = {.lex_state = 0, .external_lex_state = 6},
  [9215] = {.lex_state = 1},
  [9216] = {.lex_state = 0},
  [9217] = {.lex_state = 0, .external_lex_state = 8},
  [9218] = {.lex_state = 0},
  [9219] = {.lex_state = 0, .external_lex_state = 6},
  [9220] = {.lex_state = 0},
  [9221] = {.lex_state = 131},
  [9222] = {.lex_state = 0},
  [9223] = {.lex_state = 0},
  [9224] = {.lex_state = 0, .external_lex_state = 6},
  [9225] = {.lex_state = 10},
  [9226] = {.lex_state = 0},
  [9227] = {.lex_state = 0, .external_lex_state = 6},
  [9228] = {.lex_state = 0},
  [9229] = {.lex_state = 0, .external_lex_state = 6},
  [9230] = {.lex_state = 0},
  [9231] = {.lex_state = 0, .external_lex_state = 6},
  [9232] = {.lex_state = 0, .external_lex_state = 6},
  [9233] = {.lex_state = 0},
  [9234] = {.lex_state = 0},
  [9235] = {.lex_state = 0},
  [9236] = {.lex_state = 0},
  [9237] = {.lex_state = 0, .external_lex_state = 6},
  [9238] = {.lex_state = 0},
  [9239] = {.lex_state = 0, .external_lex_state = 6},
  [9240] = {.lex_state = 0},
  [9241] = {.lex_state = 0},
  [9242] = {.lex_state = 0},
  [9243] = {.lex_state = 0, .external_lex_state = 6},
  [9244] = {.lex_state = 0},
  [9245] = {.lex_state = 0},
  [9246] = {.lex_state = 0},
  [9247] = {.lex_state = 0},
  [9248] = {.lex_state = 0},
  [9249] = {.lex_state = 0},
  [9250] = {.lex_state = 0},
  [9251] = {.lex_state = 0},
  [9252] = {.lex_state = 0},
  [9253] = {.lex_state = 4},
  [9254] = {.lex_state = 0},
  [9255] = {.lex_state = 0},
  [9256] = {.lex_state = 0},
  [9257] = {.lex_state = 0},
  [9258] = {.lex_state = 0},
  [9259] = {.lex_state = 0, .external_lex_state = 6},
  [9260] = {.lex_state = 0},
  [9261] = {.lex_state = 0, .external_lex_state = 6},
  [9262] = {.lex_state = 0, .external_lex_state = 6},
  [9263] = {.lex_state = 10},
  [9264] = {.lex_state = 0},
  [9265] = {.lex_state = 0},
  [9266] = {.lex_state = 0},
  [9267] = {.lex_state = 0},
  [9268] = {.lex_state = 0},
  [9269] = {.lex_state = 0, .external_lex_state = 6},
  [9270] = {.lex_state = 0, .external_lex_state = 6},
  [9271] = {.lex_state = 0, .external_lex_state = 6},
  [9272] = {.lex_state = 0},
  [9273] = {.lex_state = 0},
  [9274] = {.lex_state = 0},
  [9275] = {.lex_state = 10},
  [9276] = {.lex_state = 0, .external_lex_state = 6},
  [9277] = {.lex_state = 0},
  [9278] = {.lex_state = 0},
  [9279] = {.lex_state = 0, .external_lex_state = 6},
  [9280] = {.lex_state = 0},
  [9281] = {.lex_state = 0},
  [9282] = {.lex_state = 0, .external_lex_state = 6},
  [9283] = {.lex_state = 0},
  [9284] = {.lex_state = 0},
  [9285] = {.lex_state = 0, .external_lex_state = 6},
  [9286] = {.lex_state = 1},
  [9287] = {.lex_state = 0, .external_lex_state = 6},
  [9288] = {.lex_state = 1},
  [9289] = {.lex_state = 0},
  [9290] = {.lex_state = 0, .external_lex_state = 6},
  [9291] = {.lex_state = 0, .external_lex_state = 6},
  [9292] = {.lex_state = 0},
  [9293] = {.lex_state = 0},
  [9294] = {.lex_state = 0, .external_lex_state = 6},
  [9295] = {.lex_state = 0, .external_lex_state = 6},
  [9296] = {.lex_state = 0},
  [9297] = {.lex_state = 0},
  [9298] = {.lex_state = 0},
  [9299] = {.lex_state = 0, .external_lex_state = 6},
  [9300] = {.lex_state = 0},
  [9301] = {.lex_state = 10},
  [9302] = {.lex_state = 0, .external_lex_state = 6},
  [9303] = {.lex_state = 0, .external_lex_state = 6},
  [9304] = {.lex_state = 0},
  [9305] = {.lex_state = 0},
  [9306] = {.lex_state = 0, .external_lex_state = 6},
  [9307] = {.lex_state = 0},
  [9308] = {.lex_state = 0},
  [9309] = {.lex_state = 0},
  [9310] = {.lex_state = 0},
  [9311] = {.lex_state = 1},
  [9312] = {.lex_state = 14},
  [9313] = {.lex_state = 0},
  [9314] = {.lex_state = 0, .external_lex_state = 6},
  [9315] = {.lex_state = 0},
  [9316] = {.lex_state = 0},
  [9317] = {.lex_state = 0},
  [9318] = {.lex_state = 0, .external_lex_state = 6},
  [9319] = {.lex_state = 0, .external_lex_state = 6},
  [9320] = {.lex_state = 0},
  [9321] = {.lex_state = 0},
  [9322] = {.lex_state = 0, .external_lex_state = 6},
  [9323] = {.lex_state = 0, .external_lex_state = 6},
  [9324] = {.lex_state = 0},
  [9325] = {.lex_state = 0, .external_lex_state = 6},
  [9326] = {.lex_state = 0, .external_lex_state = 6},
  [9327] = {.lex_state = 0, .external_lex_state = 6},
  [9328] = {.lex_state = 14},
  [9329] = {.lex_state = 0},
  [9330] = {.lex_state = 0, .external_lex_state = 6},
  [9331] = {.lex_state = 0},
  [9332] = {.lex_state = 10},
  [9333] = {.lex_state = 0, .external_lex_state = 6},
  [9334] = {.lex_state = 0},
  [9335] = {.lex_state = 0},
  [9336] = {.lex_state = 0},
  [9337] = {.lex_state = 0},
  [9338] = {.lex_state = 0, .external_lex_state = 6},
  [9339] = {.lex_state = 0, .external_lex_state = 6},
  [9340] = {.lex_state = 0},
  [9341] = {.lex_state = 0},
  [9342] = {.lex_state = 0},
  [9343] = {.lex_state = 0, .external_lex_state = 6},
  [9344] = {.lex_state = 0},
  [9345] = {.lex_state = 0},
  [9346] = {.lex_state = 0},
  [9347] = {.lex_state = 10},
  [9348] = {.lex_state = 0},
  [9349] = {.lex_state = 130},
  [9350] = {.lex_state = 0},
  [9351] = {.lex_state = 0},
  [9352] = {.lex_state = 0, .external_lex_state = 6},
  [9353] = {.lex_state = 0},
  [9354] = {.lex_state = 0},
  [9355] = {.lex_state = 4},
  [9356] = {.lex_state = 131},
  [9357] = {.lex_state = 0},
  [9358] = {.lex_state = 0, .external_lex_state = 6},
  [9359] = {.lex_state = 0, .external_lex_state = 6},
  [9360] = {.lex_state = 0},
  [9361] = {.lex_state = 0},
  [9362] = {.lex_state = 0},
  [9363] = {.lex_state = 0},
  [9364] = {.lex_state = 0},
  [9365] = {.lex_state = 0, .external_lex_state = 6},
  [9366] = {.lex_state = 0},
  [9367] = {.lex_state = 131},
  [9368] = {.lex_state = 0},
  [9369] = {.lex_state = 0},
  [9370] = {.lex_state = 0},
  [9371] = {.lex_state = 0},
  [9372] = {.lex_state = 0, .external_lex_state = 6},
  [9373] = {.lex_state = 0, .external_lex_state = 6},
  [9374] = {.lex_state = 0},
  [9375] = {.lex_state = 0},
  [9376] = {.lex_state = 0, .external_lex_state = 9},
  [9377] = {.lex_state = 0, .external_lex_state = 9},
  [9378] = {.lex_state = 0},
  [9379] = {.lex_state = 0},
  [9380] = {.lex_state = 0, .external_lex_state = 9},
  [9381] = {.lex_state = 0, .external_lex_state = 8},
  [9382] = {.lex_state = 0, .external_lex_state = 6},
  [9383] = {.lex_state = 0, .external_lex_state = 7},
  [9384] = {.lex_state = 0, .external_lex_state = 9},
  [9385] = {.lex_state = 0, .external_lex_state = 6},
  [9386] = {.lex_state = 0, .external_lex_state = 6},
  [9387] = {.lex_state = 0},
  [9388] = {.lex_state = 0},
  [9389] = {.lex_state = 0, .external_lex_state = 9},
  [9390] = {.lex_state = 0},
  [9391] = {.lex_state = 0},
  [9392] = {.lex_state = 0, .external_lex_state = 9},
  [9393] = {.lex_state = 0},
  [9394] = {.lex_state = 0},
  [9395] = {.lex_state = 0},
  [9396] = {.lex_state = 10},
  [9397] = {.lex_state = 0, .external_lex_state = 6},
  [9398] = {.lex_state = 0},
  [9399] = {.lex_state = 130},
  [9400] = {.lex_state = 0, .external_lex_state = 8},
  [9401] = {.lex_state = 0},
  [9402] = {.lex_state = 0, .external_lex_state = 6},
  [9403] = {.lex_state = 0},
  [9404] = {.lex_state = 0, .external_lex_state = 6},
  [9405] = {.lex_state = 0},
  [9406] = {.lex_state = 0},
  [9407] = {.lex_state = 0},
  [9408] = {.lex_state = 0, .external_lex_state = 6},
  [9409] = {.lex_state = 131},
  [9410] = {.lex_state = 0, .external_lex_state = 6},
  [9411] = {.lex_state = 0},
  [9412] = {.lex_state = 0},
  [9413] = {.lex_state = 0},
  [9414] = {.lex_state = 0, .external_lex_state = 6},
  [9415] = {.lex_state = 0},
  [9416] = {.lex_state = 0},
  [9417] = {.lex_state = 0},
  [9418] = {.lex_state = 0, .external_lex_state = 6},
  [9419] = {.lex_state = 0, .external_lex_state = 9},
  [9420] = {.lex_state = 0},
  [9421] = {.lex_state = 0, .external_lex_state = 9},
  [9422] = {.lex_state = 0},
  [9423] = {.lex_state = 0, .external_lex_state = 9},
  [9424] = {.lex_state = 0},
  [9425] = {.lex_state = 0, .external_lex_state = 8},
  [9426] = {.lex_state = 0, .external_lex_state = 6},
  [9427] = {.lex_state = 0},
  [9428] = {.lex_state = 0},
  [9429] = {.lex_state = 0},
  [9430] = {.lex_state = 0},
  [9431] = {.lex_state = 0, .external_lex_state = 6},
  [9432] = {.lex_state = 0},
  [9433] = {.lex_state = 0},
  [9434] = {.lex_state = 0},
  [9435] = {.lex_state = 0},
  [9436] = {.lex_state = 131},
  [9437] = {.lex_state = 0, .external_lex_state = 6},
  [9438] = {.lex_state = 1},
  [9439] = {.lex_state = 0, .external_lex_state = 6},
  [9440] = {.lex_state = 0},
  [9441] = {.lex_state = 0},
  [9442] = {.lex_state = 0, .external_lex_state = 6},
  [9443] = {.lex_state = 131},
  [9444] = {.lex_state = 0},
  [9445] = {.lex_state = 0, .external_lex_state = 6},
  [9446] = {.lex_state = 0},
  [9447] = {.lex_state = 0, .external_lex_state = 6},
  [9448] = {.lex_state = 0},
  [9449] = {.lex_state = 0},
  [9450] = {.lex_state = 0},
  [9451] = {.lex_state = 0},
  [9452] = {.lex_state = 0},
  [9453] = {.lex_state = 0},
  [9454] = {.lex_state = 0},
  [9455] = {.lex_state = 0},
  [9456] = {.lex_state = 0},
  [9457] = {.lex_state = 0},
  [9458] = {.lex_state = 0, .external_lex_state = 6},
  [9459] = {.lex_state = 0, .external_lex_state = 6},
  [9460] = {.lex_state = 0, .external_lex_state = 6},
  [9461] = {.lex_state = 0, .external_lex_state = 6},
  [9462] = {.lex_state = 0},
  [9463] = {.lex_state = 0, .external_lex_state = 6},
  [9464] = {.lex_state = 130},
  [9465] = {.lex_state = 10},
  [9466] = {.lex_state = 0},
  [9467] = {.lex_state = 0},
  [9468] = {.lex_state = 0},
  [9469] = {.lex_state = 0, .external_lex_state = 6},
  [9470] = {.lex_state = 0},
  [9471] = {.lex_state = 0},
  [9472] = {.lex_state = 0, .external_lex_state = 6},
  [9473] = {.lex_state = 0},
  [9474] = {.lex_state = 0},
  [9475] = {.lex_state = 0},
  [9476] = {.lex_state = 1},
  [9477] = {.lex_state = 0, .external_lex_state = 6},
  [9478] = {.lex_state = 0, .external_lex_state = 6},
  [9479] = {.lex_state = 0, .external_lex_state = 6},
  [9480] = {.lex_state = 1},
  [9481] = {.lex_state = 0, .external_lex_state = 6},
  [9482] = {.lex_state = 0},
  [9483] = {.lex_state = 0, .external_lex_state = 6},
  [9484] = {.lex_state = 0, .external_lex_state = 6},
  [9485] = {.lex_state = 0, .external_lex_state = 6},
  [9486] = {.lex_state = 0, .external_lex_state = 6},
  [9487] = {.lex_state = 0, .external_lex_state = 6},
  [9488] = {.lex_state = 0, .external_lex_state = 6},
  [9489] = {.lex_state = 0, .external_lex_state = 6},
  [9490] = {.lex_state = 0, .external_lex_state = 6},
  [9491] = {.lex_state = 0, .external_lex_state = 6},
  [9492] = {.lex_state = 0, .external_lex_state = 6},
  [9493] = {.lex_state = 0},
  [9494] = {.lex_state = 0, .external_lex_state = 6},
  [9495] = {.lex_state = 0},
  [9496] = {.lex_state = 0, .external_lex_state = 6},
  [9497] = {.lex_state = 0},
  [9498] = {.lex_state = 0},
  [9499] = {.lex_state = 0},
  [9500] = {.lex_state = 0},
  [9501] = {.lex_state = 0, .external_lex_state = 6},
  [9502] = {.lex_state = 0, .external_lex_state = 6},
  [9503] = {.lex_state = 0},
  [9504] = {.lex_state = 0, .external_lex_state = 6},
  [9505] = {.lex_state = 0, .external_lex_state = 6},
  [9506] = {.lex_state = 0},
  [9507] = {.lex_state = 0, .external_lex_state = 6},
  [9508] = {.lex_state = 0, .external_lex_state = 6},
  [9509] = {.lex_state = 0, .external_lex_state = 6},
  [9510] = {.lex_state = 0, .external_lex_state = 6},
  [9511] = {.lex_state = 0},
  [9512] = {.lex_state = 0},
  [9513] = {.lex_state = 0},
  [9514] = {.lex_state = 0, .external_lex_state = 6},
  [9515] = {.lex_state = 0},
  [9516] = {.lex_state = 0, .external_lex_state = 6},
  [9517] = {.lex_state = 0},
  [9518] = {.lex_state = 0, .external_lex_state = 6},
  [9519] = {.lex_state = 0},
  [9520] = {.lex_state = 0},
  [9521] = {.lex_state = 0},
  [9522] = {.lex_state = 10},
  [9523] = {.lex_state = 10},
  [9524] = {.lex_state = 0},
  [9525] = {.lex_state = 0},
  [9526] = {.lex_state = 0, .external_lex_state = 6},
  [9527] = {.lex_state = 0, .external_lex_state = 6},
  [9528] = {.lex_state = 0, .external_lex_state = 6},
  [9529] = {.lex_state = 0, .external_lex_state = 6},
  [9530] = {.lex_state = 0, .external_lex_state = 6},
  [9531] = {.lex_state = 0, .external_lex_state = 6},
  [9532] = {.lex_state = 0, .external_lex_state = 6},
  [9533] = {.lex_state = 0, .external_lex_state = 6},
  [9534] = {.lex_state = 0},
  [9535] = {.lex_state = 131},
  [9536] = {.lex_state = 16},
  [9537] = {.lex_state = 0},
  [9538] = {.lex_state = 131},
  [9539] = {.lex_state = 0},
  [9540] = {.lex_state = 0},
  [9541] = {.lex_state = 0, .external_lex_state = 6},
  [9542] = {.lex_state = 0},
  [9543] = {.lex_state = 0},
  [9544] = {.lex_state = 0},
  [9545] = {.lex_state = 131},
  [9546] = {.lex_state = 0},
  [9547] = {.lex_state = 0, .external_lex_state = 6},
  [9548] = {.lex_state = 0},
  [9549] = {.lex_state = 10},
  [9550] = {.lex_state = 0},
  [9551] = {.lex_state = 0, .external_lex_state = 6},
  [9552] = {.lex_state = 0, .external_lex_state = 6},
  [9553] = {.lex_state = 0, .external_lex_state = 6},
  [9554] = {.lex_state = 0, .external_lex_state = 6},
  [9555] = {.lex_state = 0, .external_lex_state = 6},
  [9556] = {.lex_state = 0},
  [9557] = {.lex_state = 0, .external_lex_state = 6},
  [9558] = {.lex_state = 0, .external_lex_state = 6},
  [9559] = {.lex_state = 0, .external_lex_state = 6},
  [9560] = {.lex_state = 0, .external_lex_state = 4},
  [9561] = {.lex_state = 0},
  [9562] = {.lex_state = 0, .external_lex_state = 6},
  [9563] = {.lex_state = 0, .external_lex_state = 6},
  [9564] = {.lex_state = 0, .external_lex_state = 6},
  [9565] = {.lex_state = 0, .external_lex_state = 6},
  [9566] = {.lex_state = 0, .external_lex_state = 6},
  [9567] = {.lex_state = 0, .external_lex_state = 6},
  [9568] = {.lex_state = 0},
  [9569] = {.lex_state = 0},
  [9570] = {.lex_state = 10},
  [9571] = {.lex_state = 0, .external_lex_state = 6},
  [9572] = {.lex_state = 0, .external_lex_state = 6},
  [9573] = {.lex_state = 0},
  [9574] = {.lex_state = 0},
  [9575] = {.lex_state = 0},
  [9576] = {.lex_state = 0},
  [9577] = {.lex_state = 0, .external_lex_state = 6},
  [9578] = {.lex_state = 1},
  [9579] = {.lex_state = 0},
  [9580] = {.lex_state = 0},
  [9581] = {.lex_state = 0, .external_lex_state = 6},
  [9582] = {.lex_state = 0},
  [9583] = {.lex_state = 0, .external_lex_state = 6},
  [9584] = {.lex_state = 0, .external_lex_state = 6},
  [9585] = {.lex_state = 0, .external_lex_state = 7},
  [9586] = {.lex_state = 0, .external_lex_state = 6},
  [9587] = {.lex_state = 0},
  [9588] = {.lex_state = 0, .external_lex_state = 6},
  [9589] = {.lex_state = 0},
  [9590] = {.lex_state = 1},
  [9591] = {.lex_state = 0, .external_lex_state = 6},
  [9592] = {.lex_state = 0},
  [9593] = {.lex_state = 0},
  [9594] = {.lex_state = 0},
  [9595] = {.lex_state = 4},
  [9596] = {.lex_state = 0},
  [9597] = {.lex_state = 0},
  [9598] = {.lex_state = 0, .external_lex_state = 6},
  [9599] = {.lex_state = 0},
  [9600] = {.lex_state = 0},
  [9601] = {.lex_state = 0, .external_lex_state = 6},
  [9602] = {.lex_state = 0, .external_lex_state = 6},
  [9603] = {.lex_state = 0, .external_lex_state = 6},
  [9604] = {.lex_state = 0},
  [9605] = {.lex_state = 0, .external_lex_state = 6},
  [9606] = {.lex_state = 0},
  [9607] = {.lex_state = 0},
  [9608] = {.lex_state = 0},
  [9609] = {.lex_state = 0, .external_lex_state = 6},
  [9610] = {.lex_state = 0},
  [9611] = {.lex_state = 0, .external_lex_state = 6},
  [9612] = {.lex_state = 0},
  [9613] = {.lex_state = 0, .external_lex_state = 6},
  [9614] = {.lex_state = 0},
  [9615] = {.lex_state = 0, .external_lex_state = 6},
  [9616] = {.lex_state = 0},
  [9617] = {.lex_state = 0},
  [9618] = {.lex_state = 0, .external_lex_state = 6},
  [9619] = {.lex_state = 0, .external_lex_state = 6},
  [9620] = {.lex_state = 0, .external_lex_state = 6},
  [9621] = {.lex_state = 0, .external_lex_state = 6},
  [9622] = {.lex_state = 0},
  [9623] = {.lex_state = 0},
  [9624] = {.lex_state = 0, .external_lex_state = 6},
  [9625] = {.lex_state = 0},
  [9626] = {.lex_state = 0, .external_lex_state = 6},
  [9627] = {.lex_state = 0},
  [9628] = {.lex_state = 0},
  [9629] = {.lex_state = 0},
  [9630] = {.lex_state = 0},
  [9631] = {.lex_state = 0},
  [9632] = {.lex_state = 0},
  [9633] = {.lex_state = 0},
  [9634] = {.lex_state = 0},
  [9635] = {.lex_state = 0},
  [9636] = {.lex_state = 0},
  [9637] = {.lex_state = 0},
  [9638] = {.lex_state = 0},
  [9639] = {.lex_state = 0, .external_lex_state = 6},
  [9640] = {.lex_state = 0, .external_lex_state = 6},
  [9641] = {.lex_state = 0},
  [9642] = {.lex_state = 0, .external_lex_state = 6},
  [9643] = {.lex_state = 0},
  [9644] = {.lex_state = 0, .external_lex_state = 6},
  [9645] = {.lex_state = 0},
  [9646] = {.lex_state = 0},
  [9647] = {.lex_state = 0},
  [9648] = {.lex_state = 0},
  [9649] = {.lex_state = 0},
  [9650] = {.lex_state = 0, .external_lex_state = 6},
  [9651] = {.lex_state = 0, .external_lex_state = 6},
  [9652] = {.lex_state = 0},
  [9653] = {.lex_state = 0, .external_lex_state = 6},
  [9654] = {.lex_state = 0, .external_lex_state = 6},
  [9655] = {.lex_state = 0},
  [9656] = {.lex_state = 0},
  [9657] = {.lex_state = 0},
  [9658] = {.lex_state = 0, .external_lex_state = 6},
  [9659] = {.lex_state = 131},
  [9660] = {.lex_state = 0},
  [9661] = {.lex_state = 0},
  [9662] = {.lex_state = 0, .external_lex_state = 6},
  [9663] = {.lex_state = 0, .external_lex_state = 6},
  [9664] = {.lex_state = 0, .external_lex_state = 6},
  [9665] = {.lex_state = 0},
  [9666] = {.lex_state = 0},
  [9667] = {.lex_state = 0},
  [9668] = {.lex_state = 0},
  [9669] = {.lex_state = 0},
  [9670] = {.lex_state = 0},
  [9671] = {.lex_state = 0},
  [9672] = {.lex_state = 0},
  [9673] = {.lex_state = 0, .external_lex_state = 6},
  [9674] = {.lex_state = 0},
  [9675] = {.lex_state = 0},
  [9676] = {.lex_state = 0},
  [9677] = {.lex_state = 0},
  [9678] = {.lex_state = 1},
  [9679] = {.lex_state = 0},
  [9680] = {.lex_state = 0, .external_lex_state = 6},
  [9681] = {.lex_state = 0},
  [9682] = {.lex_state = 0, .external_lex_state = 6},
  [9683] = {.lex_state = 0, .external_lex_state = 6},
  [9684] = {.lex_state = 0, .external_lex_state = 6},
  [9685] = {.lex_state = 0},
  [9686] = {.lex_state = 0},
  [9687] = {.lex_state = 0, .external_lex_state = 6},
  [9688] = {.lex_state = 0, .external_lex_state = 6},
  [9689] = {.lex_state = 0, .external_lex_state = 6},
  [9690] = {.lex_state = 0, .external_lex_state = 6},
  [9691] = {.lex_state = 0},
  [9692] = {.lex_state = 0},
  [9693] = {.lex_state = 0},
  [9694] = {.lex_state = 0, .external_lex_state = 6},
  [9695] = {.lex_state = 0},
  [9696] = {.lex_state = 0, .external_lex_state = 6},
  [9697] = {.lex_state = 0, .external_lex_state = 6},
  [9698] = {.lex_state = 0},
  [9699] = {.lex_state = 0, .external_lex_state = 6},
  [9700] = {.lex_state = 0},
  [9701] = {.lex_state = 0},
  [9702] = {.lex_state = 0, .external_lex_state = 6},
  [9703] = {.lex_state = 0},
  [9704] = {.lex_state = 0},
  [9705] = {.lex_state = 0, .external_lex_state = 6},
  [9706] = {.lex_state = 0},
  [9707] = {.lex_state = 0},
  [9708] = {.lex_state = 0, .external_lex_state = 6},
  [9709] = {.lex_state = 0},
  [9710] = {.lex_state = 0, .external_lex_state = 6},
  [9711] = {.lex_state = 0, .external_lex_state = 6},
  [9712] = {.lex_state = 0, .external_lex_state = 6},
  [9713] = {.lex_state = 0},
  [9714] = {.lex_state = 0, .external_lex_state = 6},
  [9715] = {.lex_state = 10},
  [9716] = {.lex_state = 0},
  [9717] = {.lex_state = 0, .external_lex_state = 7},
  [9718] = {.lex_state = 131},
  [9719] = {.lex_state = 0},
  [9720] = {.lex_state = 0},
  [9721] = {.lex_state = 0, .external_lex_state = 6},
  [9722] = {.lex_state = 131},
  [9723] = {.lex_state = 0, .external_lex_state = 6},
  [9724] = {.lex_state = 0, .external_lex_state = 6},
  [9725] = {.lex_state = 0, .external_lex_state = 6},
  [9726] = {.lex_state = 0, .external_lex_state = 6},
  [9727] = {.lex_state = 0, .external_lex_state = 6},
  [9728] = {.lex_state = 0, .external_lex_state = 6},
  [9729] = {.lex_state = 0, .external_lex_state = 6},
  [9730] = {.lex_state = 0, .external_lex_state = 6},
  [9731] = {.lex_state = 0, .external_lex_state = 6},
  [9732] = {.lex_state = 0},
  [9733] = {.lex_state = 0},
  [9734] = {.lex_state = 0},
  [9735] = {.lex_state = 0},
  [9736] = {.lex_state = 0},
  [9737] = {.lex_state = 0},
  [9738] = {.lex_state = 0},
  [9739] = {.lex_state = 0},
  [9740] = {.lex_state = 0},
  [9741] = {.lex_state = 0},
  [9742] = {.lex_state = 0, .external_lex_state = 9},
  [9743] = {.lex_state = 0, .external_lex_state = 6},
  [9744] = {.lex_state = 0, .external_lex_state = 6},
  [9745] = {.lex_state = 0},
  [9746] = {.lex_state = 0, .external_lex_state = 6},
  [9747] = {.lex_state = 0, .external_lex_state = 6},
  [9748] = {.lex_state = 0, .external_lex_state = 9},
  [9749] = {.lex_state = 0, .external_lex_state = 6},
  [9750] = {.lex_state = 0, .external_lex_state = 9},
  [9751] = {.lex_state = 0, .external_lex_state = 9},
  [9752] = {.lex_state = 0, .external_lex_state = 6},
  [9753] = {.lex_state = 0, .external_lex_state = 8},
  [9754] = {.lex_state = 0},
  [9755] = {.lex_state = 0},
  [9756] = {.lex_state = 0, .external_lex_state = 6},
  [9757] = {.lex_state = 0},
  [9758] = {.lex_state = 0},
  [9759] = {.lex_state = 0},
  [9760] = {.lex_state = 0},
  [9761] = {.lex_state = 0},
  [9762] = {.lex_state = 0},
  [9763] = {.lex_state = 0},
  [9764] = {.lex_state = 0, .external_lex_state = 6},
  [9765] = {.lex_state = 0},
  [9766] = {.lex_state = 0, .external_lex_state = 6},
  [9767] = {.lex_state = 0},
  [9768] = {.lex_state = 0},
  [9769] = {.lex_state = 0, .external_lex_state = 6},
  [9770] = {.lex_state = 131},
  [9771] = {.lex_state = 0, .external_lex_state = 9},
  [9772] = {.lex_state = 131},
  [9773] = {.lex_state = 0},
  [9774] = {.lex_state = 0},
  [9775] = {.lex_state = 0},
  [9776] = {.lex_state = 0},
  [9777] = {.lex_state = 0},
  [9778] = {.lex_state = 0},
  [9779] = {.lex_state = 0},
  [9780] = {.lex_state = 0, .external_lex_state = 6},
  [9781] = {.lex_state = 0},
  [9782] = {.lex_state = 0, .external_lex_state = 9},
  [9783] = {.lex_state = 0},
  [9784] = {.lex_state = 0},
  [9785] = {.lex_state = 0},
  [9786] = {.lex_state = 0},
  [9787] = {.lex_state = 0},
  [9788] = {.lex_state = 0},
  [9789] = {.lex_state = 0},
  [9790] = {.lex_state = 0},
  [9791] = {.lex_state = 0},
  [9792] = {.lex_state = 0, .external_lex_state = 4},
  [9793] = {.lex_state = 0},
  [9794] = {.lex_state = 0},
  [9795] = {.lex_state = 0, .external_lex_state = 6},
  [9796] = {.lex_state = 0},
  [9797] = {.lex_state = 0},
  [9798] = {.lex_state = 0, .external_lex_state = 6},
  [9799] = {.lex_state = 0},
  [9800] = {.lex_state = 0, .external_lex_state = 6},
  [9801] = {.lex_state = 131},
  [9802] = {.lex_state = 0},
  [9803] = {.lex_state = 0},
  [9804] = {.lex_state = 0},
  [9805] = {.lex_state = 0},
  [9806] = {.lex_state = 131},
  [9807] = {.lex_state = 0, .external_lex_state = 6},
  [9808] = {.lex_state = 0, .external_lex_state = 6},
  [9809] = {.lex_state = 0, .external_lex_state = 6},
  [9810] = {.lex_state = 0, .external_lex_state = 6},
  [9811] = {.lex_state = 0},
  [9812] = {.lex_state = 0},
  [9813] = {.lex_state = 0},
  [9814] = {.lex_state = 10},
  [9815] = {.lex_state = 0},
  [9816] = {.lex_state = 0},
  [9817] = {.lex_state = 0},
  [9818] = {.lex_state = 0},
  [9819] = {.lex_state = 0},
  [9820] = {.lex_state = 131},
  [9821] = {.lex_state = 0},
  [9822] = {.lex_state = 0},
  [9823] = {.lex_state = 0},
  [9824] = {.lex_state = 0},
  [9825] = {.lex_state = 0},
  [9826] = {.lex_state = 0},
  [9827] = {.lex_state = 0, .external_lex_state = 6},
  [9828] = {.lex_state = 10},
  [9829] = {.lex_state = 0},
  [9830] = {.lex_state = 0},
  [9831] = {.lex_state = 0, .external_lex_state = 6},
  [9832] = {.lex_state = 0},
  [9833] = {.lex_state = 0, .external_lex_state = 6},
  [9834] = {.lex_state = 0},
  [9835] = {.lex_state = 131},
  [9836] = {.lex_state = 0},
  [9837] = {.lex_state = 0},
  [9838] = {.lex_state = 0},
  [9839] = {.lex_state = 0},
  [9840] = {.lex_state = 130},
  [9841] = {.lex_state = 0},
  [9842] = {.lex_state = 0, .external_lex_state = 6},
  [9843] = {.lex_state = 0, .external_lex_state = 6},
  [9844] = {.lex_state = 10},
  [9845] = {.lex_state = 0},
  [9846] = {.lex_state = 0},
  [9847] = {.lex_state = 0, .external_lex_state = 6},
  [9848] = {.lex_state = 0},
  [9849] = {.lex_state = 0, .external_lex_state = 6},
  [9850] = {.lex_state = 0},
  [9851] = {.lex_state = 0},
  [9852] = {.lex_state = 1},
  [9853] = {.lex_state = 0},
  [9854] = {.lex_state = 0, .external_lex_state = 6},
  [9855] = {.lex_state = 0, .external_lex_state = 6},
  [9856] = {.lex_state = 0},
  [9857] = {.lex_state = 0, .external_lex_state = 6},
  [9858] = {.lex_state = 131},
  [9859] = {.lex_state = 0},
  [9860] = {.lex_state = 0},
  [9861] = {.lex_state = 0},
  [9862] = {.lex_state = 0},
  [9863] = {.lex_state = 0, .external_lex_state = 6},
  [9864] = {.lex_state = 0},
  [9865] = {.lex_state = 0, .external_lex_state = 6},
  [9866] = {.lex_state = 0},
  [9867] = {.lex_state = 0},
  [9868] = {.lex_state = 0, .external_lex_state = 6},
  [9869] = {.lex_state = 0, .external_lex_state = 6},
  [9870] = {.lex_state = 0},
  [9871] = {.lex_state = 0, .external_lex_state = 6},
  [9872] = {.lex_state = 0, .external_lex_state = 4},
  [9873] = {.lex_state = 0},
  [9874] = {.lex_state = 0, .external_lex_state = 6},
  [9875] = {.lex_state = 0},
  [9876] = {.lex_state = 0},
  [9877] = {.lex_state = 0, .external_lex_state = 6},
  [9878] = {.lex_state = 0, .external_lex_state = 6},
  [9879] = {.lex_state = 0},
  [9880] = {.lex_state = 0},
  [9881] = {.lex_state = 0, .external_lex_state = 6},
  [9882] = {.lex_state = 0, .external_lex_state = 6},
  [9883] = {.lex_state = 0, .external_lex_state = 6},
  [9884] = {.lex_state = 0},
  [9885] = {.lex_state = 0},
  [9886] = {.lex_state = 10},
  [9887] = {.lex_state = 0},
  [9888] = {.lex_state = 0},
  [9889] = {.lex_state = 0},
  [9890] = {.lex_state = 0},
  [9891] = {.lex_state = 0, .external_lex_state = 6},
  [9892] = {.lex_state = 0, .external_lex_state = 6},
  [9893] = {.lex_state = 0, .external_lex_state = 6},
  [9894] = {.lex_state = 0, .external_lex_state = 6},
  [9895] = {.lex_state = 0, .external_lex_state = 6},
  [9896] = {.lex_state = 0},
  [9897] = {.lex_state = 0, .external_lex_state = 7},
  [9898] = {.lex_state = 0},
  [9899] = {.lex_state = 0},
  [9900] = {.lex_state = 0},
  [9901] = {.lex_state = 0},
  [9902] = {.lex_state = 0},
  [9903] = {.lex_state = 0},
  [9904] = {.lex_state = 0},
  [9905] = {.lex_state = 0},
  [9906] = {.lex_state = 131},
  [9907] = {.lex_state = 0, .external_lex_state = 6},
  [9908] = {.lex_state = 0},
  [9909] = {.lex_state = 0},
  [9910] = {.lex_state = 0, .external_lex_state = 6},
  [9911] = {.lex_state = 0, .external_lex_state = 6},
  [9912] = {.lex_state = 0},
  [9913] = {.lex_state = 0},
  [9914] = {.lex_state = 0},
  [9915] = {.lex_state = 0},
  [9916] = {.lex_state = 0, .external_lex_state = 6},
  [9917] = {.lex_state = 0},
  [9918] = {.lex_state = 0},
  [9919] = {.lex_state = 0},
  [9920] = {.lex_state = 0},
  [9921] = {.lex_state = 10},
  [9922] = {.lex_state = 0},
  [9923] = {.lex_state = 0},
  [9924] = {.lex_state = 0, .external_lex_state = 6},
  [9925] = {.lex_state = 0},
  [9926] = {.lex_state = 0},
  [9927] = {.lex_state = 0, .external_lex_state = 6},
  [9928] = {.lex_state = 0, .external_lex_state = 6},
  [9929] = {.lex_state = 0, .external_lex_state = 6},
  [9930] = {.lex_state = 0, .external_lex_state = 6},
  [9931] = {.lex_state = 0, .external_lex_state = 6},
  [9932] = {.lex_state = 0, .external_lex_state = 6},
  [9933] = {.lex_state = 10},
  [9934] = {.lex_state = 0},
  [9935] = {.lex_state = 131},
  [9936] = {.lex_state = 0, .external_lex_state = 6},
  [9937] = {.lex_state = 0, .external_lex_state = 6},
  [9938] = {.lex_state = 0},
  [9939] = {.lex_state = 0, .external_lex_state = 6},
  [9940] = {.lex_state = 0},
  [9941] = {.lex_state = 0, .external_lex_state = 6},
  [9942] = {.lex_state = 0, .external_lex_state = 6},
  [9943] = {.lex_state = 0, .external_lex_state = 6},
  [9944] = {.lex_state = 0},
  [9945] = {.lex_state = 0},
  [9946] = {.lex_state = 0},
  [9947] = {.lex_state = 131},
  [9948] = {.lex_state = 0, .external_lex_state = 6},
  [9949] = {.lex_state = 0, .external_lex_state = 6},
  [9950] = {.lex_state = 0},
  [9951] = {.lex_state = 0},
  [9952] = {.lex_state = 0},
  [9953] = {.lex_state = 0, .external_lex_state = 6},
  [9954] = {.lex_state = 131},
  [9955] = {.lex_state = 0, .external_lex_state = 6},
  [9956] = {.lex_state = 131},
  [9957] = {.lex_state = 0, .external_lex_state = 6},
  [9958] = {.lex_state = 131},
  [9959] = {.lex_state = 131},
  [9960] = {.lex_state = 0, .external_lex_state = 6},
  [9961] = {.lex_state = 0},
  [9962] = {.lex_state = 0},
  [9963] = {.lex_state = 0, .external_lex_state = 6},
  [9964] = {.lex_state = 0},
  [9965] = {.lex_state = 131},
  [9966] = {.lex_state = 0},
  [9967] = {.lex_state = 10},
  [9968] = {.lex_state = 0},
  [9969] = {.lex_state = 0},
  [9970] = {.lex_state = 0},
  [9971] = {.lex_state = 0},
  [9972] = {.lex_state = 0},
  [9973] = {.lex_state = 131},
  [9974] = {.lex_state = 0},
  [9975] = {.lex_state = 0},
  [9976] = {.lex_state = 0},
  [9977] = {.lex_state = 131},
  [9978] = {.lex_state = 0},
  [9979] = {.lex_state = 0},
  [9980] = {.lex_state = 0},
  [9981] = {.lex_state = 0, .external_lex_state = 6},
  [9982] = {.lex_state = 0, .external_lex_state = 6},
  [9983] = {.lex_state = 0, .external_lex_state = 6},
  [9984] = {.lex_state = 0, .external_lex_state = 6},
  [9985] = {(TSStateId)(-1)},
  [9986] = {(TSStateId)(-1)},
  [9987] = {(TSStateId)(-1)},
  [9988] = {(TSStateId)(-1)},
  [9989] = {(TSStateId)(-1)},
  [9990] = {(TSStateId)(-1)},
  [9991] = {(TSStateId)(-1)},
  [9992] = {(TSStateId)(-1)},
  [9993] = {(TSStateId)(-1)},
  [9994] = {(TSStateId)(-1)},
  [9995] = {(TSStateId)(-1)},
  [9996] = {(TSStateId)(-1)},
  [9997] = {(TSStateId)(-1)},
  [9998] = {(TSStateId)(-1)},
  [9999] = {(TSStateId)(-1)},
  [10000] = {(TSStateId)(-1)},
  [10001] = {(TSStateId)(-1)},
};

static const uint16_t ts_parse_table[LARGE_STATE_COUNT][SYMBOL_COUNT] = {
  [0] = {
    [sym_preproc_region] = STATE(0),
    [sym_preproc_endregion] = STATE(0),
    [sym_preproc_line] = STATE(0),
    [sym_preproc_pragma] = STATE(0),
    [sym_preproc_nullable] = STATE(0),
    [sym_preproc_error] = STATE(0),
    [sym_preproc_warning] = STATE(0),
    [sym_preproc_define] = STATE(0),
    [sym_preproc_undef] = STATE(0),
    [ts_builtin_sym_end] = ACTIONS(1),
    [sym__identifier_token] = ACTIONS(1),
    [anon_sym_extern] = ACTIONS(1),
    [anon_sym_alias] = ACTIONS(1),
    [anon_sym_SEMI] = ACTIONS(1),
    [anon_sym_global] = ACTIONS(1),
    [anon_sym_using] = ACTIONS(1),
    [anon_sym_unsafe] = ACTIONS(1),
    [anon_sym_EQ] = ACTIONS(1),
    [anon_sym_static] = ACTIONS(1),
    [anon_sym_LBRACK] = ACTIONS(1),
    [anon_sym_assembly] = ACTIONS(1),
    [anon_sym_module] = ACTIONS(1),
    [anon_sym_COLON] = ACTIONS(1),
    [anon_sym_COMMA] = ACTIONS(1),
    [anon_sym_RBRACK] = ACTIONS(1),
    [anon_sym_LPAREN] = ACTIONS(1),
    [anon_sym_RPAREN] = ACTIONS(1),
    [anon_sym_field] = ACTIONS(1),
    [anon_sym_event] = ACTIONS(1),
    [anon_sym_method] = ACTIONS(1),
    [anon_sym_param] = ACTIONS(1),
    [anon_sym_property] = ACTIONS(1),
    [anon_sym_return] = ACTIONS(1),
    [anon_sym_type] = ACTIONS(1),
    [anon_sym_namespace] = ACTIONS(1),
    [anon_sym_class] = ACTIONS(1),
    [anon_sym_ref] = ACTIONS(1),
    [anon_sym_struct] = ACTIONS(1),
    [anon_sym_enum] = ACTIONS(1),
    [anon_sym_LBRACE] = ACTIONS(1),
    [anon_sym_RBRACE] = ACTIONS(1),
    [anon_sym_interface] = ACTIONS(1),
    [anon_sym_delegate] = ACTIONS(1),
    [anon_sym_record] = ACTIONS(1),
    [anon_sym_abstract] = ACTIONS(1),
    [anon_sym_async] = ACTIONS(1),
    [anon_sym_const] = ACTIONS(1),
    [anon_sym_file] = ACTIONS(1),
    [anon_sym_fixed] = ACTIONS(1),
    [anon_sym_internal] = ACTIONS(1),
    [anon_sym_new] = ACTIONS(1),
    [anon_sym_override] = ACTIONS(1),
    [anon_sym_partial] = ACTIONS(1),
    [anon_sym_private] = ACTIONS(1),
    [anon_sym_protected] = ACTIONS(1),
    [anon_sym_public] = ACTIONS(1),
    [anon_sym_readonly] = ACTIONS(1),
    [anon_sym_required] = ACTIONS(1),
    [anon_sym_sealed] = ACTIONS(1),
    [anon_sym_virtual] = ACTIONS(1),
    [anon_sym_volatile] = ACTIONS(1),
    [anon_sym_LT] = ACTIONS(1),
    [anon_sym_GT] = ACTIONS(1),
    [anon_sym_in] = ACTIONS(1),
    [anon_sym_out] = ACTIONS(1),
    [anon_sym_where] = ACTIONS(1),
    [anon_sym_QMARK] = ACTIONS(1),
    [anon_sym_notnull] = ACTIONS(1),
    [anon_sym_unmanaged] = ACTIONS(1),
    [anon_sym_operator] = ACTIONS(1),
    [anon_sym_checked] = ACTIONS(1),
    [anon_sym_BANG] = ACTIONS(1),
    [anon_sym_TILDE] = ACTIONS(1),
    [anon_sym_PLUS_PLUS] = ACTIONS(1),
    [anon_sym_DASH_DASH] = ACTIONS(1),
    [anon_sym_true] = ACTIONS(1),
    [anon_sym_false] = ACTIONS(1),
    [anon_sym_PLUS] = ACTIONS(1),
    [anon_sym_DASH] = ACTIONS(1),
    [anon_sym_STAR] = ACTIONS(1),
    [anon_sym_SLASH] = ACTIONS(1),
    [anon_sym_PERCENT] = ACTIONS(1),
    [anon_sym_CARET] = ACTIONS(1),
    [anon_sym_PIPE] = ACTIONS(1),
    [anon_sym_AMP] = ACTIONS(1),
    [anon_sym_LT_LT] = ACTIONS(1),
    [anon_sym_GT_GT] = ACTIONS(1),
    [anon_sym_GT_GT_GT] = ACTIONS(1),
    [anon_sym_EQ_EQ] = ACTIONS(1),
    [anon_sym_BANG_EQ] = ACTIONS(1),
    [anon_sym_GT_EQ] = ACTIONS(1),
    [anon_sym_LT_EQ] = ACTIONS(1),
    [anon_sym_implicit] = ACTIONS(1),
    [anon_sym_explicit] = ACTIONS(1),
    [anon_sym_get] = ACTIONS(1),
    [anon_sym_set] = ACTIONS(1),
    [anon_sym_add] = ACTIONS(1),
    [anon_sym_remove] = ACTIONS(1),
    [anon_sym_init] = ACTIONS(1),
    [anon_sym_this] = ACTIONS(1),
    [anon_sym_DOT] = ACTIONS(1),
    [anon_sym_scoped] = ACTIONS(1),
    [anon_sym_params] = ACTIONS(1),
    [anon_sym_base] = ACTIONS(1),
    [anon_sym_EQ_GT] = ACTIONS(1),
    [anon_sym_COLON_COLON] = ACTIONS(1),
    [anon_sym_var] = ACTIONS(1),
    [anon_sym_managed] = ACTIONS(1),
    [anon_sym_Cdecl] = ACTIONS(1),
    [anon_sym_Stdcall] = ACTIONS(1),
    [anon_sym_Thiscall] = ACTIONS(1),
    [anon_sym_Fastcall] = ACTIONS(1),
    [sym_predefined_type] = ACTIONS(1),
    [anon_sym_break] = ACTIONS(1),
    [anon_sym_unchecked] = ACTIONS(1),
    [anon_sym_continue] = ACTIONS(1),
    [anon_sym_do] = ACTIONS(1),
    [anon_sym_while] = ACTIONS(1),
    [anon_sym_for] = ACTIONS(1),
    [anon_sym_lock] = ACTIONS(1),
    [anon_sym_yield] = ACTIONS(1),
    [anon_sym_switch] = ACTIONS(1),
    [anon_sym_case] = ACTIONS(1),
    [anon_sym_default] = ACTIONS(1),
    [anon_sym_throw] = ACTIONS(1),
    [anon_sym_try] = ACTIONS(1),
    [anon_sym_catch] = ACTIONS(1),
    [anon_sym_when] = ACTIONS(1),
    [anon_sym_finally] = ACTIONS(1),
    [anon_sym_await] = ACTIONS(1),
    [anon_sym_foreach] = ACTIONS(1),
    [anon_sym_goto] = ACTIONS(1),
    [anon_sym_if] = ACTIONS(1),
    [anon_sym_else] = ACTIONS(1),
    [sym_discard] = ACTIONS(1),
    [anon_sym_DOT_DOT] = ACTIONS(1),
    [anon_sym_not] = ACTIONS(1),
    [anon_sym_and] = ACTIONS(1),
    [anon_sym_or] = ACTIONS(1),
    [anon_sym_PLUS_EQ] = ACTIONS(1),
    [anon_sym_DASH_EQ] = ACTIONS(1),
    [anon_sym_STAR_EQ] = ACTIONS(1),
    [anon_sym_SLASH_EQ] = ACTIONS(1),
    [anon_sym_PERCENT_EQ] = ACTIONS(1),
    [anon_sym_AMP_EQ] = ACTIONS(1),
    [anon_sym_CARET_EQ] = ACTIONS(1),
    [anon_sym_PIPE_EQ] = ACTIONS(1),
    [anon_sym_LT_LT_EQ] = ACTIONS(1),
    [anon_sym_GT_GT_EQ] = ACTIONS(1),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(1),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(1),
    [anon_sym_AMP_AMP] = ACTIONS(1),
    [anon_sym_PIPE_PIPE] = ACTIONS(1),
    [anon_sym_QMARK_QMARK] = ACTIONS(1),
    [anon_sym_from] = ACTIONS(1),
    [anon_sym_into] = ACTIONS(1),
    [anon_sym_join] = ACTIONS(1),
    [anon_sym_on] = ACTIONS(1),
    [anon_sym_equals] = ACTIONS(1),
    [anon_sym_let] = ACTIONS(1),
    [anon_sym_orderby] = ACTIONS(1),
    [anon_sym_ascending] = ACTIONS(1),
    [anon_sym_descending] = ACTIONS(1),
    [anon_sym_group] = ACTIONS(1),
    [anon_sym_by] = ACTIONS(1),
    [anon_sym_select] = ACTIONS(1),
    [anon_sym_as] = ACTIONS(1),
    [anon_sym_is] = ACTIONS(1),
    [anon_sym_DASH_GT] = ACTIONS(1),
    [anon_sym_stackalloc] = ACTIONS(1),
    [anon_sym_with] = ACTIONS(1),
    [anon_sym_sizeof] = ACTIONS(1),
    [anon_sym_typeof] = ACTIONS(1),
    [anon_sym___makeref] = ACTIONS(1),
    [anon_sym___reftype] = ACTIONS(1),
    [anon_sym___refvalue] = ACTIONS(1),
    [sym_null_literal] = ACTIONS(1),
    [anon_sym_SQUOTE] = ACTIONS(1),
    [sym_integer_literal] = ACTIONS(1),
    [sym_real_literal] = ACTIONS(1),
    [anon_sym_DQUOTE] = ACTIONS(1),
    [aux_sym_string_literal_content_token2] = ACTIONS(1),
    [sym_escape_sequence] = ACTIONS(1),
    [sym_string_literal_encoding] = ACTIONS(1),
    [sym_verbatim_string_literal] = ACTIONS(1),
    [aux_sym_raw_string_literal_token1] = ACTIONS(1),
    [aux_sym_preproc_if_token1] = ACTIONS(1),
    [aux_sym_preproc_if_token3] = ACTIONS(1),
    [aux_sym_preproc_else_token1] = ACTIONS(1),
    [aux_sym_preproc_elif_token1] = ACTIONS(1),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [anon_sym_hidden] = ACTIONS(1),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [anon_sym_warning] = ACTIONS(1),
    [anon_sym_disable] = ACTIONS(1),
    [anon_sym_restore] = ACTIONS(1),
    [anon_sym_checksum] = ACTIONS(1),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [anon_sym_enable] = ACTIONS(1),
    [anon_sym_annotations] = ACTIONS(1),
    [anon_sym_warnings] = ACTIONS(1),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_shebang_directive] = ACTIONS(1),
    [sym_comment] = ACTIONS(21),
    [sym__optional_semi] = ACTIONS(1),
    [sym_interpolation_regular_start] = ACTIONS(1),
    [sym_interpolation_verbatim_start] = ACTIONS(1),
    [sym_interpolation_raw_start] = ACTIONS(1),
    [sym_interpolation_start_quote] = ACTIONS(1),
    [sym_interpolation_end_quote] = ACTIONS(1),
    [sym_interpolation_open_brace] = ACTIONS(1),
    [sym_interpolation_close_brace] = ACTIONS(1),
    [sym_interpolation_string_content] = ACTIONS(1),
    [sym_raw_string_start] = ACTIONS(1),
    [sym_raw_string_end] = ACTIONS(1),
    [sym_raw_string_content] = ACTIONS(1),
  },
  [1] = {
    [sym_compilation_unit] = STATE(9098),
    [sym__top_level_item] = STATE(2585),
    [sym_global_statement] = STATE(2621),
    [sym_extern_alias_directive] = STATE(2621),
    [sym_using_directive] = STATE(2621),
    [sym_global_attribute] = STATE(2621),
    [sym_attribute_list] = STATE(3740),
    [sym_namespace_declaration] = STATE(2621),
    [sym_file_scoped_namespace_declaration] = STATE(2621),
    [sym_type_declaration] = STATE(2621),
    [sym_class_declaration] = STATE(2622),
    [sym_struct_declaration] = STATE(2622),
    [sym_enum_declaration] = STATE(2622),
    [sym_interface_declaration] = STATE(2622),
    [sym_delegate_declaration] = STATE(2622),
    [sym_record_declaration] = STATE(2622),
    [sym_modifier] = STATE(3807),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2493),
    [sym_variable_declaration] = STATE(9635),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6854),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2636),
    [sym_break_statement] = STATE(2493),
    [sym_checked_statement] = STATE(2493),
    [sym_continue_statement] = STATE(2493),
    [sym_do_statement] = STATE(2493),
    [sym_empty_statement] = STATE(2493),
    [sym_expression_statement] = STATE(2493),
    [sym_fixed_statement] = STATE(2493),
    [sym_for_statement] = STATE(2493),
    [sym_return_statement] = STATE(2493),
    [sym_lock_statement] = STATE(2493),
    [sym_yield_statement] = STATE(2493),
    [sym_switch_statement] = STATE(2493),
    [sym_throw_statement] = STATE(2493),
    [sym_try_statement] = STATE(2493),
    [sym_unsafe_statement] = STATE(2493),
    [sym_using_statement] = STATE(2493),
    [sym_foreach_statement] = STATE(2493),
    [sym_goto_statement] = STATE(2493),
    [sym_labeled_statement] = STATE(2493),
    [sym_if_statement] = STATE(2493),
    [sym_while_statement] = STATE(2493),
    [sym_local_declaration_statement] = STATE(2493),
    [sym_local_function_statement] = STATE(2493),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6748),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2907),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2581),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1),
    [sym_preproc_endregion] = STATE(1),
    [sym_preproc_line] = STATE(1),
    [sym_preproc_pragma] = STATE(1),
    [sym_preproc_nullable] = STATE(1),
    [sym_preproc_error] = STATE(1),
    [sym_preproc_warning] = STATE(1),
    [sym_preproc_define] = STATE(1),
    [sym_preproc_undef] = STATE(1),
    [aux_sym_compilation_unit_repeat1] = STATE(17),
    [aux_sym_class_declaration_repeat1] = STATE(2817),
    [aux_sym_class_declaration_repeat2] = STATE(2923),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [ts_builtin_sym_end] = ACTIONS(23),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(27),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(31),
    [anon_sym_global] = ACTIONS(33),
    [anon_sym_using] = ACTIONS(35),
    [anon_sym_unsafe] = ACTIONS(37),
    [anon_sym_static] = ACTIONS(39),
    [anon_sym_LBRACK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(45),
    [anon_sym_namespace] = ACTIONS(47),
    [anon_sym_class] = ACTIONS(49),
    [anon_sym_ref] = ACTIONS(51),
    [anon_sym_struct] = ACTIONS(53),
    [anon_sym_enum] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_interface] = ACTIONS(59),
    [anon_sym_delegate] = ACTIONS(61),
    [anon_sym_record] = ACTIONS(63),
    [anon_sym_abstract] = ACTIONS(65),
    [anon_sym_async] = ACTIONS(39),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_file] = ACTIONS(67),
    [anon_sym_fixed] = ACTIONS(69),
    [anon_sym_internal] = ACTIONS(65),
    [anon_sym_new] = ACTIONS(71),
    [anon_sym_override] = ACTIONS(65),
    [anon_sym_partial] = ACTIONS(65),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_public] = ACTIONS(65),
    [anon_sym_readonly] = ACTIONS(65),
    [anon_sym_required] = ACTIONS(65),
    [anon_sym_sealed] = ACTIONS(65),
    [anon_sym_virtual] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(73),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_unchecked] = ACTIONS(73),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_do] = ACTIONS(97),
    [anon_sym_while] = ACTIONS(99),
    [anon_sym_for] = ACTIONS(101),
    [anon_sym_lock] = ACTIONS(103),
    [anon_sym_yield] = ACTIONS(105),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(111),
    [anon_sym_try] = ACTIONS(113),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(115),
    [anon_sym_foreach] = ACTIONS(117),
    [anon_sym_goto] = ACTIONS(119),
    [anon_sym_if] = ACTIONS(121),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(147),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_shebang_directive] = ACTIONS(149),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2] = {
    [sym_extern_alias_directive] = STATE(2327),
    [sym_using_directive] = STATE(2327),
    [sym_global_attribute] = STATE(2327),
    [sym_attribute_list] = STATE(3740),
    [sym_namespace_declaration] = STATE(2327),
    [sym_file_scoped_namespace_declaration] = STATE(2327),
    [sym_type_declaration] = STATE(2327),
    [sym_class_declaration] = STATE(2308),
    [sym_struct_declaration] = STATE(2308),
    [sym_enum_declaration] = STATE(2308),
    [sym_interface_declaration] = STATE(2308),
    [sym_delegate_declaration] = STATE(2308),
    [sym_record_declaration] = STATE(2308),
    [sym_modifier] = STATE(3807),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2270),
    [sym_variable_declaration] = STATE(9038),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6880),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2327),
    [sym_break_statement] = STATE(2270),
    [sym_checked_statement] = STATE(2270),
    [sym_continue_statement] = STATE(2270),
    [sym_do_statement] = STATE(2270),
    [sym_empty_statement] = STATE(2270),
    [sym_expression_statement] = STATE(2270),
    [sym_fixed_statement] = STATE(2270),
    [sym_for_statement] = STATE(2270),
    [sym_return_statement] = STATE(2270),
    [sym_lock_statement] = STATE(2270),
    [sym_yield_statement] = STATE(2270),
    [sym_switch_statement] = STATE(2270),
    [sym_throw_statement] = STATE(2270),
    [sym_try_statement] = STATE(2270),
    [sym_unsafe_statement] = STATE(2270),
    [sym_using_statement] = STATE(2270),
    [sym_foreach_statement] = STATE(2270),
    [sym_goto_statement] = STATE(2270),
    [sym_labeled_statement] = STATE(2270),
    [sym_if_statement] = STATE(2270),
    [sym_while_statement] = STATE(2270),
    [sym_local_declaration_statement] = STATE(2270),
    [sym_local_function_statement] = STATE(2270),
    [sym_expression] = STATE(5308),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6279),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2841),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2329),
    [sym_preproc_else_in_top_level] = STATE(9097),
    [sym_preproc_elif_in_top_level] = STATE(9097),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_else_in_expression] = STATE(9435),
    [sym_preproc_elif_in_expression] = STATE(9435),
    [sym_preproc_region] = STATE(2),
    [sym_preproc_endregion] = STATE(2),
    [sym_preproc_line] = STATE(2),
    [sym_preproc_pragma] = STATE(2),
    [sym_preproc_nullable] = STATE(2),
    [sym_preproc_error] = STATE(2),
    [sym_preproc_warning] = STATE(2),
    [sym_preproc_define] = STATE(2),
    [sym_preproc_undef] = STATE(2),
    [aux_sym_class_declaration_repeat1] = STATE(2815),
    [aux_sym_class_declaration_repeat2] = STATE(2921),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [aux_sym_preproc_if_in_top_level_repeat1] = STATE(8),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(159),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(161),
    [anon_sym_global] = ACTIONS(163),
    [anon_sym_using] = ACTIONS(165),
    [anon_sym_unsafe] = ACTIONS(167),
    [anon_sym_static] = ACTIONS(39),
    [anon_sym_LBRACK] = ACTIONS(169),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(171),
    [anon_sym_namespace] = ACTIONS(173),
    [anon_sym_class] = ACTIONS(175),
    [anon_sym_ref] = ACTIONS(177),
    [anon_sym_struct] = ACTIONS(179),
    [anon_sym_enum] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_interface] = ACTIONS(185),
    [anon_sym_delegate] = ACTIONS(187),
    [anon_sym_record] = ACTIONS(189),
    [anon_sym_abstract] = ACTIONS(65),
    [anon_sym_async] = ACTIONS(39),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_file] = ACTIONS(67),
    [anon_sym_fixed] = ACTIONS(191),
    [anon_sym_internal] = ACTIONS(65),
    [anon_sym_new] = ACTIONS(71),
    [anon_sym_override] = ACTIONS(65),
    [anon_sym_partial] = ACTIONS(65),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_public] = ACTIONS(65),
    [anon_sym_readonly] = ACTIONS(65),
    [anon_sym_required] = ACTIONS(65),
    [anon_sym_sealed] = ACTIONS(65),
    [anon_sym_virtual] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(193),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(195),
    [anon_sym_unchecked] = ACTIONS(193),
    [anon_sym_continue] = ACTIONS(197),
    [anon_sym_do] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_lock] = ACTIONS(205),
    [anon_sym_yield] = ACTIONS(207),
    [anon_sym_switch] = ACTIONS(209),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(211),
    [anon_sym_try] = ACTIONS(213),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(215),
    [anon_sym_foreach] = ACTIONS(217),
    [anon_sym_goto] = ACTIONS(219),
    [anon_sym_if] = ACTIONS(221),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(223),
    [aux_sym_preproc_if_token3] = ACTIONS(225),
    [aux_sym_preproc_else_token1] = ACTIONS(227),
    [aux_sym_preproc_elif_token1] = ACTIONS(229),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [3] = {
    [sym_extern_alias_directive] = STATE(2327),
    [sym_using_directive] = STATE(2327),
    [sym_global_attribute] = STATE(2327),
    [sym_attribute_list] = STATE(3740),
    [sym_namespace_declaration] = STATE(2327),
    [sym_file_scoped_namespace_declaration] = STATE(2327),
    [sym_type_declaration] = STATE(2327),
    [sym_class_declaration] = STATE(2308),
    [sym_struct_declaration] = STATE(2308),
    [sym_enum_declaration] = STATE(2308),
    [sym_interface_declaration] = STATE(2308),
    [sym_delegate_declaration] = STATE(2308),
    [sym_record_declaration] = STATE(2308),
    [sym_modifier] = STATE(3807),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2270),
    [sym_variable_declaration] = STATE(9038),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6880),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2327),
    [sym_break_statement] = STATE(2270),
    [sym_checked_statement] = STATE(2270),
    [sym_continue_statement] = STATE(2270),
    [sym_do_statement] = STATE(2270),
    [sym_empty_statement] = STATE(2270),
    [sym_expression_statement] = STATE(2270),
    [sym_fixed_statement] = STATE(2270),
    [sym_for_statement] = STATE(2270),
    [sym_return_statement] = STATE(2270),
    [sym_lock_statement] = STATE(2270),
    [sym_yield_statement] = STATE(2270),
    [sym_switch_statement] = STATE(2270),
    [sym_throw_statement] = STATE(2270),
    [sym_try_statement] = STATE(2270),
    [sym_unsafe_statement] = STATE(2270),
    [sym_using_statement] = STATE(2270),
    [sym_foreach_statement] = STATE(2270),
    [sym_goto_statement] = STATE(2270),
    [sym_labeled_statement] = STATE(2270),
    [sym_if_statement] = STATE(2270),
    [sym_while_statement] = STATE(2270),
    [sym_local_declaration_statement] = STATE(2270),
    [sym_local_function_statement] = STATE(2270),
    [sym_expression] = STATE(5308),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6279),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2841),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2329),
    [sym_preproc_else_in_top_level] = STATE(9413),
    [sym_preproc_elif_in_top_level] = STATE(9413),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_else_in_expression] = STATE(9435),
    [sym_preproc_elif_in_expression] = STATE(9435),
    [sym_preproc_region] = STATE(3),
    [sym_preproc_endregion] = STATE(3),
    [sym_preproc_line] = STATE(3),
    [sym_preproc_pragma] = STATE(3),
    [sym_preproc_nullable] = STATE(3),
    [sym_preproc_error] = STATE(3),
    [sym_preproc_warning] = STATE(3),
    [sym_preproc_define] = STATE(3),
    [sym_preproc_undef] = STATE(3),
    [aux_sym_class_declaration_repeat1] = STATE(2815),
    [aux_sym_class_declaration_repeat2] = STATE(2921),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [aux_sym_preproc_if_in_top_level_repeat1] = STATE(9),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(159),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(161),
    [anon_sym_global] = ACTIONS(163),
    [anon_sym_using] = ACTIONS(165),
    [anon_sym_unsafe] = ACTIONS(167),
    [anon_sym_static] = ACTIONS(39),
    [anon_sym_LBRACK] = ACTIONS(169),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(171),
    [anon_sym_namespace] = ACTIONS(173),
    [anon_sym_class] = ACTIONS(175),
    [anon_sym_ref] = ACTIONS(177),
    [anon_sym_struct] = ACTIONS(179),
    [anon_sym_enum] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_interface] = ACTIONS(185),
    [anon_sym_delegate] = ACTIONS(187),
    [anon_sym_record] = ACTIONS(189),
    [anon_sym_abstract] = ACTIONS(65),
    [anon_sym_async] = ACTIONS(39),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_file] = ACTIONS(67),
    [anon_sym_fixed] = ACTIONS(191),
    [anon_sym_internal] = ACTIONS(65),
    [anon_sym_new] = ACTIONS(71),
    [anon_sym_override] = ACTIONS(65),
    [anon_sym_partial] = ACTIONS(65),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_public] = ACTIONS(65),
    [anon_sym_readonly] = ACTIONS(65),
    [anon_sym_required] = ACTIONS(65),
    [anon_sym_sealed] = ACTIONS(65),
    [anon_sym_virtual] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(193),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(195),
    [anon_sym_unchecked] = ACTIONS(193),
    [anon_sym_continue] = ACTIONS(197),
    [anon_sym_do] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_lock] = ACTIONS(205),
    [anon_sym_yield] = ACTIONS(207),
    [anon_sym_switch] = ACTIONS(209),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(211),
    [anon_sym_try] = ACTIONS(213),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(215),
    [anon_sym_foreach] = ACTIONS(217),
    [anon_sym_goto] = ACTIONS(219),
    [anon_sym_if] = ACTIONS(221),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(223),
    [aux_sym_preproc_if_token3] = ACTIONS(231),
    [aux_sym_preproc_else_token1] = ACTIONS(227),
    [aux_sym_preproc_elif_token1] = ACTIONS(229),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [4] = {
    [sym_extern_alias_directive] = STATE(2327),
    [sym_using_directive] = STATE(2327),
    [sym_global_attribute] = STATE(2327),
    [sym_attribute_list] = STATE(3740),
    [sym_namespace_declaration] = STATE(2327),
    [sym_file_scoped_namespace_declaration] = STATE(2327),
    [sym_type_declaration] = STATE(2327),
    [sym_class_declaration] = STATE(2308),
    [sym_struct_declaration] = STATE(2308),
    [sym_enum_declaration] = STATE(2308),
    [sym_interface_declaration] = STATE(2308),
    [sym_delegate_declaration] = STATE(2308),
    [sym_record_declaration] = STATE(2308),
    [sym_modifier] = STATE(3807),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2270),
    [sym_variable_declaration] = STATE(9038),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6880),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2327),
    [sym_break_statement] = STATE(2270),
    [sym_checked_statement] = STATE(2270),
    [sym_continue_statement] = STATE(2270),
    [sym_do_statement] = STATE(2270),
    [sym_empty_statement] = STATE(2270),
    [sym_expression_statement] = STATE(2270),
    [sym_fixed_statement] = STATE(2270),
    [sym_for_statement] = STATE(2270),
    [sym_return_statement] = STATE(2270),
    [sym_lock_statement] = STATE(2270),
    [sym_yield_statement] = STATE(2270),
    [sym_switch_statement] = STATE(2270),
    [sym_throw_statement] = STATE(2270),
    [sym_try_statement] = STATE(2270),
    [sym_unsafe_statement] = STATE(2270),
    [sym_using_statement] = STATE(2270),
    [sym_foreach_statement] = STATE(2270),
    [sym_goto_statement] = STATE(2270),
    [sym_labeled_statement] = STATE(2270),
    [sym_if_statement] = STATE(2270),
    [sym_while_statement] = STATE(2270),
    [sym_local_declaration_statement] = STATE(2270),
    [sym_local_function_statement] = STATE(2270),
    [sym_expression] = STATE(5400),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6279),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2841),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2329),
    [sym_preproc_else_in_top_level] = STATE(9473),
    [sym_preproc_elif_in_top_level] = STATE(9473),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_else_in_expression] = STATE(9475),
    [sym_preproc_elif_in_expression] = STATE(9475),
    [sym_preproc_region] = STATE(4),
    [sym_preproc_endregion] = STATE(4),
    [sym_preproc_line] = STATE(4),
    [sym_preproc_pragma] = STATE(4),
    [sym_preproc_nullable] = STATE(4),
    [sym_preproc_error] = STATE(4),
    [sym_preproc_warning] = STATE(4),
    [sym_preproc_define] = STATE(4),
    [sym_preproc_undef] = STATE(4),
    [aux_sym_class_declaration_repeat1] = STATE(2815),
    [aux_sym_class_declaration_repeat2] = STATE(2921),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [aux_sym_preproc_if_in_top_level_repeat1] = STATE(10),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(159),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(161),
    [anon_sym_global] = ACTIONS(163),
    [anon_sym_using] = ACTIONS(165),
    [anon_sym_unsafe] = ACTIONS(167),
    [anon_sym_static] = ACTIONS(39),
    [anon_sym_LBRACK] = ACTIONS(169),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(171),
    [anon_sym_namespace] = ACTIONS(173),
    [anon_sym_class] = ACTIONS(175),
    [anon_sym_ref] = ACTIONS(177),
    [anon_sym_struct] = ACTIONS(179),
    [anon_sym_enum] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_interface] = ACTIONS(185),
    [anon_sym_delegate] = ACTIONS(187),
    [anon_sym_record] = ACTIONS(189),
    [anon_sym_abstract] = ACTIONS(65),
    [anon_sym_async] = ACTIONS(39),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_file] = ACTIONS(67),
    [anon_sym_fixed] = ACTIONS(191),
    [anon_sym_internal] = ACTIONS(65),
    [anon_sym_new] = ACTIONS(71),
    [anon_sym_override] = ACTIONS(65),
    [anon_sym_partial] = ACTIONS(65),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_public] = ACTIONS(65),
    [anon_sym_readonly] = ACTIONS(65),
    [anon_sym_required] = ACTIONS(65),
    [anon_sym_sealed] = ACTIONS(65),
    [anon_sym_virtual] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(193),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(195),
    [anon_sym_unchecked] = ACTIONS(193),
    [anon_sym_continue] = ACTIONS(197),
    [anon_sym_do] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_lock] = ACTIONS(205),
    [anon_sym_yield] = ACTIONS(207),
    [anon_sym_switch] = ACTIONS(209),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(211),
    [anon_sym_try] = ACTIONS(213),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(215),
    [anon_sym_foreach] = ACTIONS(217),
    [anon_sym_goto] = ACTIONS(219),
    [anon_sym_if] = ACTIONS(221),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(223),
    [aux_sym_preproc_if_token3] = ACTIONS(233),
    [aux_sym_preproc_else_token1] = ACTIONS(227),
    [aux_sym_preproc_elif_token1] = ACTIONS(229),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [5] = {
    [sym_extern_alias_directive] = STATE(2327),
    [sym_using_directive] = STATE(2327),
    [sym_global_attribute] = STATE(2327),
    [sym_attribute_list] = STATE(3740),
    [sym_namespace_declaration] = STATE(2327),
    [sym_file_scoped_namespace_declaration] = STATE(2327),
    [sym_type_declaration] = STATE(2327),
    [sym_class_declaration] = STATE(2308),
    [sym_struct_declaration] = STATE(2308),
    [sym_enum_declaration] = STATE(2308),
    [sym_interface_declaration] = STATE(2308),
    [sym_delegate_declaration] = STATE(2308),
    [sym_record_declaration] = STATE(2308),
    [sym_modifier] = STATE(3807),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2270),
    [sym_variable_declaration] = STATE(9038),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6880),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2327),
    [sym_break_statement] = STATE(2270),
    [sym_checked_statement] = STATE(2270),
    [sym_continue_statement] = STATE(2270),
    [sym_do_statement] = STATE(2270),
    [sym_empty_statement] = STATE(2270),
    [sym_expression_statement] = STATE(2270),
    [sym_fixed_statement] = STATE(2270),
    [sym_for_statement] = STATE(2270),
    [sym_return_statement] = STATE(2270),
    [sym_lock_statement] = STATE(2270),
    [sym_yield_statement] = STATE(2270),
    [sym_switch_statement] = STATE(2270),
    [sym_throw_statement] = STATE(2270),
    [sym_try_statement] = STATE(2270),
    [sym_unsafe_statement] = STATE(2270),
    [sym_using_statement] = STATE(2270),
    [sym_foreach_statement] = STATE(2270),
    [sym_goto_statement] = STATE(2270),
    [sym_labeled_statement] = STATE(2270),
    [sym_if_statement] = STATE(2270),
    [sym_while_statement] = STATE(2270),
    [sym_local_declaration_statement] = STATE(2270),
    [sym_local_function_statement] = STATE(2270),
    [sym_expression] = STATE(5308),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6279),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2841),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2329),
    [sym_preproc_else_in_top_level] = STATE(9351),
    [sym_preproc_elif_in_top_level] = STATE(9351),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_else_in_expression] = STATE(9435),
    [sym_preproc_elif_in_expression] = STATE(9435),
    [sym_preproc_region] = STATE(5),
    [sym_preproc_endregion] = STATE(5),
    [sym_preproc_line] = STATE(5),
    [sym_preproc_pragma] = STATE(5),
    [sym_preproc_nullable] = STATE(5),
    [sym_preproc_error] = STATE(5),
    [sym_preproc_warning] = STATE(5),
    [sym_preproc_define] = STATE(5),
    [sym_preproc_undef] = STATE(5),
    [aux_sym_class_declaration_repeat1] = STATE(2815),
    [aux_sym_class_declaration_repeat2] = STATE(2921),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [aux_sym_preproc_if_in_top_level_repeat1] = STATE(7),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(159),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(161),
    [anon_sym_global] = ACTIONS(163),
    [anon_sym_using] = ACTIONS(165),
    [anon_sym_unsafe] = ACTIONS(167),
    [anon_sym_static] = ACTIONS(39),
    [anon_sym_LBRACK] = ACTIONS(169),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(171),
    [anon_sym_namespace] = ACTIONS(173),
    [anon_sym_class] = ACTIONS(175),
    [anon_sym_ref] = ACTIONS(177),
    [anon_sym_struct] = ACTIONS(179),
    [anon_sym_enum] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_interface] = ACTIONS(185),
    [anon_sym_delegate] = ACTIONS(187),
    [anon_sym_record] = ACTIONS(189),
    [anon_sym_abstract] = ACTIONS(65),
    [anon_sym_async] = ACTIONS(39),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_file] = ACTIONS(67),
    [anon_sym_fixed] = ACTIONS(191),
    [anon_sym_internal] = ACTIONS(65),
    [anon_sym_new] = ACTIONS(71),
    [anon_sym_override] = ACTIONS(65),
    [anon_sym_partial] = ACTIONS(65),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_public] = ACTIONS(65),
    [anon_sym_readonly] = ACTIONS(65),
    [anon_sym_required] = ACTIONS(65),
    [anon_sym_sealed] = ACTIONS(65),
    [anon_sym_virtual] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(193),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(195),
    [anon_sym_unchecked] = ACTIONS(193),
    [anon_sym_continue] = ACTIONS(197),
    [anon_sym_do] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_lock] = ACTIONS(205),
    [anon_sym_yield] = ACTIONS(207),
    [anon_sym_switch] = ACTIONS(209),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(211),
    [anon_sym_try] = ACTIONS(213),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(215),
    [anon_sym_foreach] = ACTIONS(217),
    [anon_sym_goto] = ACTIONS(219),
    [anon_sym_if] = ACTIONS(221),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(223),
    [aux_sym_preproc_if_token3] = ACTIONS(235),
    [aux_sym_preproc_else_token1] = ACTIONS(227),
    [aux_sym_preproc_elif_token1] = ACTIONS(229),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [6] = {
    [sym_extern_alias_directive] = STATE(2327),
    [sym_using_directive] = STATE(2327),
    [sym_global_attribute] = STATE(2327),
    [sym_attribute_list] = STATE(3740),
    [sym_namespace_declaration] = STATE(2327),
    [sym_file_scoped_namespace_declaration] = STATE(2327),
    [sym_type_declaration] = STATE(2327),
    [sym_class_declaration] = STATE(2308),
    [sym_struct_declaration] = STATE(2308),
    [sym_enum_declaration] = STATE(2308),
    [sym_interface_declaration] = STATE(2308),
    [sym_delegate_declaration] = STATE(2308),
    [sym_record_declaration] = STATE(2308),
    [sym_modifier] = STATE(3807),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2270),
    [sym_variable_declaration] = STATE(9038),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6880),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2327),
    [sym_break_statement] = STATE(2270),
    [sym_checked_statement] = STATE(2270),
    [sym_continue_statement] = STATE(2270),
    [sym_do_statement] = STATE(2270),
    [sym_empty_statement] = STATE(2270),
    [sym_expression_statement] = STATE(2270),
    [sym_fixed_statement] = STATE(2270),
    [sym_for_statement] = STATE(2270),
    [sym_return_statement] = STATE(2270),
    [sym_lock_statement] = STATE(2270),
    [sym_yield_statement] = STATE(2270),
    [sym_switch_statement] = STATE(2270),
    [sym_throw_statement] = STATE(2270),
    [sym_try_statement] = STATE(2270),
    [sym_unsafe_statement] = STATE(2270),
    [sym_using_statement] = STATE(2270),
    [sym_foreach_statement] = STATE(2270),
    [sym_goto_statement] = STATE(2270),
    [sym_labeled_statement] = STATE(2270),
    [sym_if_statement] = STATE(2270),
    [sym_while_statement] = STATE(2270),
    [sym_local_declaration_statement] = STATE(2270),
    [sym_local_function_statement] = STATE(2270),
    [sym_expression] = STATE(5308),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6279),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2841),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2329),
    [sym_preproc_else_in_top_level] = STATE(9767),
    [sym_preproc_elif_in_top_level] = STATE(9767),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_else_in_expression] = STATE(9435),
    [sym_preproc_elif_in_expression] = STATE(9435),
    [sym_preproc_region] = STATE(6),
    [sym_preproc_endregion] = STATE(6),
    [sym_preproc_line] = STATE(6),
    [sym_preproc_pragma] = STATE(6),
    [sym_preproc_nullable] = STATE(6),
    [sym_preproc_error] = STATE(6),
    [sym_preproc_warning] = STATE(6),
    [sym_preproc_define] = STATE(6),
    [sym_preproc_undef] = STATE(6),
    [aux_sym_class_declaration_repeat1] = STATE(2815),
    [aux_sym_class_declaration_repeat2] = STATE(2921),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [aux_sym_preproc_if_in_top_level_repeat1] = STATE(12),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(159),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(161),
    [anon_sym_global] = ACTIONS(163),
    [anon_sym_using] = ACTIONS(165),
    [anon_sym_unsafe] = ACTIONS(167),
    [anon_sym_static] = ACTIONS(39),
    [anon_sym_LBRACK] = ACTIONS(169),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(171),
    [anon_sym_namespace] = ACTIONS(173),
    [anon_sym_class] = ACTIONS(175),
    [anon_sym_ref] = ACTIONS(177),
    [anon_sym_struct] = ACTIONS(179),
    [anon_sym_enum] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_interface] = ACTIONS(185),
    [anon_sym_delegate] = ACTIONS(187),
    [anon_sym_record] = ACTIONS(189),
    [anon_sym_abstract] = ACTIONS(65),
    [anon_sym_async] = ACTIONS(39),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_file] = ACTIONS(67),
    [anon_sym_fixed] = ACTIONS(191),
    [anon_sym_internal] = ACTIONS(65),
    [anon_sym_new] = ACTIONS(71),
    [anon_sym_override] = ACTIONS(65),
    [anon_sym_partial] = ACTIONS(65),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_public] = ACTIONS(65),
    [anon_sym_readonly] = ACTIONS(65),
    [anon_sym_required] = ACTIONS(65),
    [anon_sym_sealed] = ACTIONS(65),
    [anon_sym_virtual] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(193),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(195),
    [anon_sym_unchecked] = ACTIONS(193),
    [anon_sym_continue] = ACTIONS(197),
    [anon_sym_do] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_lock] = ACTIONS(205),
    [anon_sym_yield] = ACTIONS(207),
    [anon_sym_switch] = ACTIONS(209),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(211),
    [anon_sym_try] = ACTIONS(213),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(215),
    [anon_sym_foreach] = ACTIONS(217),
    [anon_sym_goto] = ACTIONS(219),
    [anon_sym_if] = ACTIONS(221),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(223),
    [aux_sym_preproc_if_token3] = ACTIONS(237),
    [aux_sym_preproc_else_token1] = ACTIONS(227),
    [aux_sym_preproc_elif_token1] = ACTIONS(229),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [7] = {
    [sym_extern_alias_directive] = STATE(2327),
    [sym_using_directive] = STATE(2327),
    [sym_global_attribute] = STATE(2327),
    [sym_attribute_list] = STATE(3740),
    [sym_namespace_declaration] = STATE(2327),
    [sym_file_scoped_namespace_declaration] = STATE(2327),
    [sym_type_declaration] = STATE(2327),
    [sym_class_declaration] = STATE(2308),
    [sym_struct_declaration] = STATE(2308),
    [sym_enum_declaration] = STATE(2308),
    [sym_interface_declaration] = STATE(2308),
    [sym_delegate_declaration] = STATE(2308),
    [sym_record_declaration] = STATE(2308),
    [sym_modifier] = STATE(3807),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2270),
    [sym_variable_declaration] = STATE(9038),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6880),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2327),
    [sym_break_statement] = STATE(2270),
    [sym_checked_statement] = STATE(2270),
    [sym_continue_statement] = STATE(2270),
    [sym_do_statement] = STATE(2270),
    [sym_empty_statement] = STATE(2270),
    [sym_expression_statement] = STATE(2270),
    [sym_fixed_statement] = STATE(2270),
    [sym_for_statement] = STATE(2270),
    [sym_return_statement] = STATE(2270),
    [sym_lock_statement] = STATE(2270),
    [sym_yield_statement] = STATE(2270),
    [sym_switch_statement] = STATE(2270),
    [sym_throw_statement] = STATE(2270),
    [sym_try_statement] = STATE(2270),
    [sym_unsafe_statement] = STATE(2270),
    [sym_using_statement] = STATE(2270),
    [sym_foreach_statement] = STATE(2270),
    [sym_goto_statement] = STATE(2270),
    [sym_labeled_statement] = STATE(2270),
    [sym_if_statement] = STATE(2270),
    [sym_while_statement] = STATE(2270),
    [sym_local_declaration_statement] = STATE(2270),
    [sym_local_function_statement] = STATE(2270),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6279),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2841),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2329),
    [sym_preproc_else_in_top_level] = STATE(9617),
    [sym_preproc_elif_in_top_level] = STATE(9617),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(7),
    [sym_preproc_endregion] = STATE(7),
    [sym_preproc_line] = STATE(7),
    [sym_preproc_pragma] = STATE(7),
    [sym_preproc_nullable] = STATE(7),
    [sym_preproc_error] = STATE(7),
    [sym_preproc_warning] = STATE(7),
    [sym_preproc_define] = STATE(7),
    [sym_preproc_undef] = STATE(7),
    [aux_sym_class_declaration_repeat1] = STATE(2815),
    [aux_sym_class_declaration_repeat2] = STATE(2921),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [aux_sym_preproc_if_in_top_level_repeat1] = STATE(14),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(159),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(161),
    [anon_sym_global] = ACTIONS(163),
    [anon_sym_using] = ACTIONS(165),
    [anon_sym_unsafe] = ACTIONS(167),
    [anon_sym_static] = ACTIONS(39),
    [anon_sym_LBRACK] = ACTIONS(169),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(171),
    [anon_sym_namespace] = ACTIONS(173),
    [anon_sym_class] = ACTIONS(175),
    [anon_sym_ref] = ACTIONS(177),
    [anon_sym_struct] = ACTIONS(179),
    [anon_sym_enum] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_interface] = ACTIONS(185),
    [anon_sym_delegate] = ACTIONS(187),
    [anon_sym_record] = ACTIONS(189),
    [anon_sym_abstract] = ACTIONS(65),
    [anon_sym_async] = ACTIONS(39),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_file] = ACTIONS(67),
    [anon_sym_fixed] = ACTIONS(191),
    [anon_sym_internal] = ACTIONS(65),
    [anon_sym_new] = ACTIONS(71),
    [anon_sym_override] = ACTIONS(65),
    [anon_sym_partial] = ACTIONS(65),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_public] = ACTIONS(65),
    [anon_sym_readonly] = ACTIONS(65),
    [anon_sym_required] = ACTIONS(65),
    [anon_sym_sealed] = ACTIONS(65),
    [anon_sym_virtual] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(193),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(195),
    [anon_sym_unchecked] = ACTIONS(193),
    [anon_sym_continue] = ACTIONS(197),
    [anon_sym_do] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_lock] = ACTIONS(205),
    [anon_sym_yield] = ACTIONS(207),
    [anon_sym_switch] = ACTIONS(209),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(211),
    [anon_sym_try] = ACTIONS(213),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(215),
    [anon_sym_foreach] = ACTIONS(217),
    [anon_sym_goto] = ACTIONS(219),
    [anon_sym_if] = ACTIONS(221),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(223),
    [aux_sym_preproc_if_token3] = ACTIONS(239),
    [aux_sym_preproc_else_token1] = ACTIONS(241),
    [aux_sym_preproc_elif_token1] = ACTIONS(243),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [8] = {
    [sym_extern_alias_directive] = STATE(2327),
    [sym_using_directive] = STATE(2327),
    [sym_global_attribute] = STATE(2327),
    [sym_attribute_list] = STATE(3740),
    [sym_namespace_declaration] = STATE(2327),
    [sym_file_scoped_namespace_declaration] = STATE(2327),
    [sym_type_declaration] = STATE(2327),
    [sym_class_declaration] = STATE(2308),
    [sym_struct_declaration] = STATE(2308),
    [sym_enum_declaration] = STATE(2308),
    [sym_interface_declaration] = STATE(2308),
    [sym_delegate_declaration] = STATE(2308),
    [sym_record_declaration] = STATE(2308),
    [sym_modifier] = STATE(3807),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2270),
    [sym_variable_declaration] = STATE(9038),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6880),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2327),
    [sym_break_statement] = STATE(2270),
    [sym_checked_statement] = STATE(2270),
    [sym_continue_statement] = STATE(2270),
    [sym_do_statement] = STATE(2270),
    [sym_empty_statement] = STATE(2270),
    [sym_expression_statement] = STATE(2270),
    [sym_fixed_statement] = STATE(2270),
    [sym_for_statement] = STATE(2270),
    [sym_return_statement] = STATE(2270),
    [sym_lock_statement] = STATE(2270),
    [sym_yield_statement] = STATE(2270),
    [sym_switch_statement] = STATE(2270),
    [sym_throw_statement] = STATE(2270),
    [sym_try_statement] = STATE(2270),
    [sym_unsafe_statement] = STATE(2270),
    [sym_using_statement] = STATE(2270),
    [sym_foreach_statement] = STATE(2270),
    [sym_goto_statement] = STATE(2270),
    [sym_labeled_statement] = STATE(2270),
    [sym_if_statement] = STATE(2270),
    [sym_while_statement] = STATE(2270),
    [sym_local_declaration_statement] = STATE(2270),
    [sym_local_function_statement] = STATE(2270),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6279),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2841),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2329),
    [sym_preproc_else_in_top_level] = STATE(9062),
    [sym_preproc_elif_in_top_level] = STATE(9062),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(8),
    [sym_preproc_endregion] = STATE(8),
    [sym_preproc_line] = STATE(8),
    [sym_preproc_pragma] = STATE(8),
    [sym_preproc_nullable] = STATE(8),
    [sym_preproc_error] = STATE(8),
    [sym_preproc_warning] = STATE(8),
    [sym_preproc_define] = STATE(8),
    [sym_preproc_undef] = STATE(8),
    [aux_sym_class_declaration_repeat1] = STATE(2815),
    [aux_sym_class_declaration_repeat2] = STATE(2921),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [aux_sym_preproc_if_in_top_level_repeat1] = STATE(14),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(159),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(161),
    [anon_sym_global] = ACTIONS(163),
    [anon_sym_using] = ACTIONS(165),
    [anon_sym_unsafe] = ACTIONS(167),
    [anon_sym_static] = ACTIONS(39),
    [anon_sym_LBRACK] = ACTIONS(169),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(171),
    [anon_sym_namespace] = ACTIONS(173),
    [anon_sym_class] = ACTIONS(175),
    [anon_sym_ref] = ACTIONS(177),
    [anon_sym_struct] = ACTIONS(179),
    [anon_sym_enum] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_interface] = ACTIONS(185),
    [anon_sym_delegate] = ACTIONS(187),
    [anon_sym_record] = ACTIONS(189),
    [anon_sym_abstract] = ACTIONS(65),
    [anon_sym_async] = ACTIONS(39),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_file] = ACTIONS(67),
    [anon_sym_fixed] = ACTIONS(191),
    [anon_sym_internal] = ACTIONS(65),
    [anon_sym_new] = ACTIONS(71),
    [anon_sym_override] = ACTIONS(65),
    [anon_sym_partial] = ACTIONS(65),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_public] = ACTIONS(65),
    [anon_sym_readonly] = ACTIONS(65),
    [anon_sym_required] = ACTIONS(65),
    [anon_sym_sealed] = ACTIONS(65),
    [anon_sym_virtual] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(193),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(195),
    [anon_sym_unchecked] = ACTIONS(193),
    [anon_sym_continue] = ACTIONS(197),
    [anon_sym_do] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_lock] = ACTIONS(205),
    [anon_sym_yield] = ACTIONS(207),
    [anon_sym_switch] = ACTIONS(209),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(211),
    [anon_sym_try] = ACTIONS(213),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(215),
    [anon_sym_foreach] = ACTIONS(217),
    [anon_sym_goto] = ACTIONS(219),
    [anon_sym_if] = ACTIONS(221),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(223),
    [aux_sym_preproc_if_token3] = ACTIONS(245),
    [aux_sym_preproc_else_token1] = ACTIONS(241),
    [aux_sym_preproc_elif_token1] = ACTIONS(243),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [9] = {
    [sym_extern_alias_directive] = STATE(2327),
    [sym_using_directive] = STATE(2327),
    [sym_global_attribute] = STATE(2327),
    [sym_attribute_list] = STATE(3740),
    [sym_namespace_declaration] = STATE(2327),
    [sym_file_scoped_namespace_declaration] = STATE(2327),
    [sym_type_declaration] = STATE(2327),
    [sym_class_declaration] = STATE(2308),
    [sym_struct_declaration] = STATE(2308),
    [sym_enum_declaration] = STATE(2308),
    [sym_interface_declaration] = STATE(2308),
    [sym_delegate_declaration] = STATE(2308),
    [sym_record_declaration] = STATE(2308),
    [sym_modifier] = STATE(3807),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2270),
    [sym_variable_declaration] = STATE(9038),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6880),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2327),
    [sym_break_statement] = STATE(2270),
    [sym_checked_statement] = STATE(2270),
    [sym_continue_statement] = STATE(2270),
    [sym_do_statement] = STATE(2270),
    [sym_empty_statement] = STATE(2270),
    [sym_expression_statement] = STATE(2270),
    [sym_fixed_statement] = STATE(2270),
    [sym_for_statement] = STATE(2270),
    [sym_return_statement] = STATE(2270),
    [sym_lock_statement] = STATE(2270),
    [sym_yield_statement] = STATE(2270),
    [sym_switch_statement] = STATE(2270),
    [sym_throw_statement] = STATE(2270),
    [sym_try_statement] = STATE(2270),
    [sym_unsafe_statement] = STATE(2270),
    [sym_using_statement] = STATE(2270),
    [sym_foreach_statement] = STATE(2270),
    [sym_goto_statement] = STATE(2270),
    [sym_labeled_statement] = STATE(2270),
    [sym_if_statement] = STATE(2270),
    [sym_while_statement] = STATE(2270),
    [sym_local_declaration_statement] = STATE(2270),
    [sym_local_function_statement] = STATE(2270),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6279),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2841),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2329),
    [sym_preproc_else_in_top_level] = STATE(9022),
    [sym_preproc_elif_in_top_level] = STATE(9022),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(9),
    [sym_preproc_endregion] = STATE(9),
    [sym_preproc_line] = STATE(9),
    [sym_preproc_pragma] = STATE(9),
    [sym_preproc_nullable] = STATE(9),
    [sym_preproc_error] = STATE(9),
    [sym_preproc_warning] = STATE(9),
    [sym_preproc_define] = STATE(9),
    [sym_preproc_undef] = STATE(9),
    [aux_sym_class_declaration_repeat1] = STATE(2815),
    [aux_sym_class_declaration_repeat2] = STATE(2921),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [aux_sym_preproc_if_in_top_level_repeat1] = STATE(14),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(159),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(161),
    [anon_sym_global] = ACTIONS(163),
    [anon_sym_using] = ACTIONS(165),
    [anon_sym_unsafe] = ACTIONS(167),
    [anon_sym_static] = ACTIONS(39),
    [anon_sym_LBRACK] = ACTIONS(169),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(171),
    [anon_sym_namespace] = ACTIONS(173),
    [anon_sym_class] = ACTIONS(175),
    [anon_sym_ref] = ACTIONS(177),
    [anon_sym_struct] = ACTIONS(179),
    [anon_sym_enum] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_interface] = ACTIONS(185),
    [anon_sym_delegate] = ACTIONS(187),
    [anon_sym_record] = ACTIONS(189),
    [anon_sym_abstract] = ACTIONS(65),
    [anon_sym_async] = ACTIONS(39),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_file] = ACTIONS(67),
    [anon_sym_fixed] = ACTIONS(191),
    [anon_sym_internal] = ACTIONS(65),
    [anon_sym_new] = ACTIONS(71),
    [anon_sym_override] = ACTIONS(65),
    [anon_sym_partial] = ACTIONS(65),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_public] = ACTIONS(65),
    [anon_sym_readonly] = ACTIONS(65),
    [anon_sym_required] = ACTIONS(65),
    [anon_sym_sealed] = ACTIONS(65),
    [anon_sym_virtual] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(193),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(195),
    [anon_sym_unchecked] = ACTIONS(193),
    [anon_sym_continue] = ACTIONS(197),
    [anon_sym_do] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_lock] = ACTIONS(205),
    [anon_sym_yield] = ACTIONS(207),
    [anon_sym_switch] = ACTIONS(209),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(211),
    [anon_sym_try] = ACTIONS(213),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(215),
    [anon_sym_foreach] = ACTIONS(217),
    [anon_sym_goto] = ACTIONS(219),
    [anon_sym_if] = ACTIONS(221),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(223),
    [aux_sym_preproc_if_token3] = ACTIONS(247),
    [aux_sym_preproc_else_token1] = ACTIONS(241),
    [aux_sym_preproc_elif_token1] = ACTIONS(243),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [10] = {
    [sym_extern_alias_directive] = STATE(2327),
    [sym_using_directive] = STATE(2327),
    [sym_global_attribute] = STATE(2327),
    [sym_attribute_list] = STATE(3740),
    [sym_namespace_declaration] = STATE(2327),
    [sym_file_scoped_namespace_declaration] = STATE(2327),
    [sym_type_declaration] = STATE(2327),
    [sym_class_declaration] = STATE(2308),
    [sym_struct_declaration] = STATE(2308),
    [sym_enum_declaration] = STATE(2308),
    [sym_interface_declaration] = STATE(2308),
    [sym_delegate_declaration] = STATE(2308),
    [sym_record_declaration] = STATE(2308),
    [sym_modifier] = STATE(3807),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2270),
    [sym_variable_declaration] = STATE(9038),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6880),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2327),
    [sym_break_statement] = STATE(2270),
    [sym_checked_statement] = STATE(2270),
    [sym_continue_statement] = STATE(2270),
    [sym_do_statement] = STATE(2270),
    [sym_empty_statement] = STATE(2270),
    [sym_expression_statement] = STATE(2270),
    [sym_fixed_statement] = STATE(2270),
    [sym_for_statement] = STATE(2270),
    [sym_return_statement] = STATE(2270),
    [sym_lock_statement] = STATE(2270),
    [sym_yield_statement] = STATE(2270),
    [sym_switch_statement] = STATE(2270),
    [sym_throw_statement] = STATE(2270),
    [sym_try_statement] = STATE(2270),
    [sym_unsafe_statement] = STATE(2270),
    [sym_using_statement] = STATE(2270),
    [sym_foreach_statement] = STATE(2270),
    [sym_goto_statement] = STATE(2270),
    [sym_labeled_statement] = STATE(2270),
    [sym_if_statement] = STATE(2270),
    [sym_while_statement] = STATE(2270),
    [sym_local_declaration_statement] = STATE(2270),
    [sym_local_function_statement] = STATE(2270),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6279),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2841),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2329),
    [sym_preproc_else_in_top_level] = STATE(9429),
    [sym_preproc_elif_in_top_level] = STATE(9429),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(10),
    [sym_preproc_endregion] = STATE(10),
    [sym_preproc_line] = STATE(10),
    [sym_preproc_pragma] = STATE(10),
    [sym_preproc_nullable] = STATE(10),
    [sym_preproc_error] = STATE(10),
    [sym_preproc_warning] = STATE(10),
    [sym_preproc_define] = STATE(10),
    [sym_preproc_undef] = STATE(10),
    [aux_sym_class_declaration_repeat1] = STATE(2815),
    [aux_sym_class_declaration_repeat2] = STATE(2921),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [aux_sym_preproc_if_in_top_level_repeat1] = STATE(14),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(159),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(161),
    [anon_sym_global] = ACTIONS(163),
    [anon_sym_using] = ACTIONS(165),
    [anon_sym_unsafe] = ACTIONS(167),
    [anon_sym_static] = ACTIONS(39),
    [anon_sym_LBRACK] = ACTIONS(169),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(171),
    [anon_sym_namespace] = ACTIONS(173),
    [anon_sym_class] = ACTIONS(175),
    [anon_sym_ref] = ACTIONS(177),
    [anon_sym_struct] = ACTIONS(179),
    [anon_sym_enum] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_interface] = ACTIONS(185),
    [anon_sym_delegate] = ACTIONS(187),
    [anon_sym_record] = ACTIONS(189),
    [anon_sym_abstract] = ACTIONS(65),
    [anon_sym_async] = ACTIONS(39),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_file] = ACTIONS(67),
    [anon_sym_fixed] = ACTIONS(191),
    [anon_sym_internal] = ACTIONS(65),
    [anon_sym_new] = ACTIONS(71),
    [anon_sym_override] = ACTIONS(65),
    [anon_sym_partial] = ACTIONS(65),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_public] = ACTIONS(65),
    [anon_sym_readonly] = ACTIONS(65),
    [anon_sym_required] = ACTIONS(65),
    [anon_sym_sealed] = ACTIONS(65),
    [anon_sym_virtual] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(193),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(195),
    [anon_sym_unchecked] = ACTIONS(193),
    [anon_sym_continue] = ACTIONS(197),
    [anon_sym_do] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_lock] = ACTIONS(205),
    [anon_sym_yield] = ACTIONS(207),
    [anon_sym_switch] = ACTIONS(209),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(211),
    [anon_sym_try] = ACTIONS(213),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(215),
    [anon_sym_foreach] = ACTIONS(217),
    [anon_sym_goto] = ACTIONS(219),
    [anon_sym_if] = ACTIONS(221),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(223),
    [aux_sym_preproc_if_token3] = ACTIONS(249),
    [aux_sym_preproc_else_token1] = ACTIONS(241),
    [aux_sym_preproc_elif_token1] = ACTIONS(243),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [11] = {
    [sym_extern_alias_directive] = STATE(2327),
    [sym_using_directive] = STATE(2327),
    [sym_global_attribute] = STATE(2327),
    [sym_attribute_list] = STATE(3740),
    [sym_namespace_declaration] = STATE(2327),
    [sym_file_scoped_namespace_declaration] = STATE(2327),
    [sym_type_declaration] = STATE(2327),
    [sym_class_declaration] = STATE(2308),
    [sym_struct_declaration] = STATE(2308),
    [sym_enum_declaration] = STATE(2308),
    [sym_interface_declaration] = STATE(2308),
    [sym_delegate_declaration] = STATE(2308),
    [sym_record_declaration] = STATE(2308),
    [sym_modifier] = STATE(3807),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2270),
    [sym_variable_declaration] = STATE(9038),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6880),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2327),
    [sym_break_statement] = STATE(2270),
    [sym_checked_statement] = STATE(2270),
    [sym_continue_statement] = STATE(2270),
    [sym_do_statement] = STATE(2270),
    [sym_empty_statement] = STATE(2270),
    [sym_expression_statement] = STATE(2270),
    [sym_fixed_statement] = STATE(2270),
    [sym_for_statement] = STATE(2270),
    [sym_return_statement] = STATE(2270),
    [sym_lock_statement] = STATE(2270),
    [sym_yield_statement] = STATE(2270),
    [sym_switch_statement] = STATE(2270),
    [sym_throw_statement] = STATE(2270),
    [sym_try_statement] = STATE(2270),
    [sym_unsafe_statement] = STATE(2270),
    [sym_using_statement] = STATE(2270),
    [sym_foreach_statement] = STATE(2270),
    [sym_goto_statement] = STATE(2270),
    [sym_labeled_statement] = STATE(2270),
    [sym_if_statement] = STATE(2270),
    [sym_while_statement] = STATE(2270),
    [sym_local_declaration_statement] = STATE(2270),
    [sym_local_function_statement] = STATE(2270),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6279),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2841),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2329),
    [sym_preproc_else_in_top_level] = STATE(9473),
    [sym_preproc_elif_in_top_level] = STATE(9473),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(11),
    [sym_preproc_endregion] = STATE(11),
    [sym_preproc_line] = STATE(11),
    [sym_preproc_pragma] = STATE(11),
    [sym_preproc_nullable] = STATE(11),
    [sym_preproc_error] = STATE(11),
    [sym_preproc_warning] = STATE(11),
    [sym_preproc_define] = STATE(11),
    [sym_preproc_undef] = STATE(11),
    [aux_sym_class_declaration_repeat1] = STATE(2815),
    [aux_sym_class_declaration_repeat2] = STATE(2921),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [aux_sym_preproc_if_in_top_level_repeat1] = STATE(10),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(159),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(161),
    [anon_sym_global] = ACTIONS(163),
    [anon_sym_using] = ACTIONS(165),
    [anon_sym_unsafe] = ACTIONS(167),
    [anon_sym_static] = ACTIONS(39),
    [anon_sym_LBRACK] = ACTIONS(169),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(171),
    [anon_sym_namespace] = ACTIONS(173),
    [anon_sym_class] = ACTIONS(175),
    [anon_sym_ref] = ACTIONS(177),
    [anon_sym_struct] = ACTIONS(179),
    [anon_sym_enum] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_interface] = ACTIONS(185),
    [anon_sym_delegate] = ACTIONS(187),
    [anon_sym_record] = ACTIONS(189),
    [anon_sym_abstract] = ACTIONS(65),
    [anon_sym_async] = ACTIONS(39),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_file] = ACTIONS(67),
    [anon_sym_fixed] = ACTIONS(191),
    [anon_sym_internal] = ACTIONS(65),
    [anon_sym_new] = ACTIONS(71),
    [anon_sym_override] = ACTIONS(65),
    [anon_sym_partial] = ACTIONS(65),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_public] = ACTIONS(65),
    [anon_sym_readonly] = ACTIONS(65),
    [anon_sym_required] = ACTIONS(65),
    [anon_sym_sealed] = ACTIONS(65),
    [anon_sym_virtual] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(193),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(195),
    [anon_sym_unchecked] = ACTIONS(193),
    [anon_sym_continue] = ACTIONS(197),
    [anon_sym_do] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_lock] = ACTIONS(205),
    [anon_sym_yield] = ACTIONS(207),
    [anon_sym_switch] = ACTIONS(209),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(211),
    [anon_sym_try] = ACTIONS(213),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(215),
    [anon_sym_foreach] = ACTIONS(217),
    [anon_sym_goto] = ACTIONS(219),
    [anon_sym_if] = ACTIONS(221),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(223),
    [aux_sym_preproc_if_token3] = ACTIONS(233),
    [aux_sym_preproc_else_token1] = ACTIONS(241),
    [aux_sym_preproc_elif_token1] = ACTIONS(243),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [12] = {
    [sym_extern_alias_directive] = STATE(2327),
    [sym_using_directive] = STATE(2327),
    [sym_global_attribute] = STATE(2327),
    [sym_attribute_list] = STATE(3740),
    [sym_namespace_declaration] = STATE(2327),
    [sym_file_scoped_namespace_declaration] = STATE(2327),
    [sym_type_declaration] = STATE(2327),
    [sym_class_declaration] = STATE(2308),
    [sym_struct_declaration] = STATE(2308),
    [sym_enum_declaration] = STATE(2308),
    [sym_interface_declaration] = STATE(2308),
    [sym_delegate_declaration] = STATE(2308),
    [sym_record_declaration] = STATE(2308),
    [sym_modifier] = STATE(3807),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2270),
    [sym_variable_declaration] = STATE(9038),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6880),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2327),
    [sym_break_statement] = STATE(2270),
    [sym_checked_statement] = STATE(2270),
    [sym_continue_statement] = STATE(2270),
    [sym_do_statement] = STATE(2270),
    [sym_empty_statement] = STATE(2270),
    [sym_expression_statement] = STATE(2270),
    [sym_fixed_statement] = STATE(2270),
    [sym_for_statement] = STATE(2270),
    [sym_return_statement] = STATE(2270),
    [sym_lock_statement] = STATE(2270),
    [sym_yield_statement] = STATE(2270),
    [sym_switch_statement] = STATE(2270),
    [sym_throw_statement] = STATE(2270),
    [sym_try_statement] = STATE(2270),
    [sym_unsafe_statement] = STATE(2270),
    [sym_using_statement] = STATE(2270),
    [sym_foreach_statement] = STATE(2270),
    [sym_goto_statement] = STATE(2270),
    [sym_labeled_statement] = STATE(2270),
    [sym_if_statement] = STATE(2270),
    [sym_while_statement] = STATE(2270),
    [sym_local_declaration_statement] = STATE(2270),
    [sym_local_function_statement] = STATE(2270),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6279),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2841),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2329),
    [sym_preproc_else_in_top_level] = STATE(9903),
    [sym_preproc_elif_in_top_level] = STATE(9903),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(12),
    [sym_preproc_endregion] = STATE(12),
    [sym_preproc_line] = STATE(12),
    [sym_preproc_pragma] = STATE(12),
    [sym_preproc_nullable] = STATE(12),
    [sym_preproc_error] = STATE(12),
    [sym_preproc_warning] = STATE(12),
    [sym_preproc_define] = STATE(12),
    [sym_preproc_undef] = STATE(12),
    [aux_sym_class_declaration_repeat1] = STATE(2815),
    [aux_sym_class_declaration_repeat2] = STATE(2921),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [aux_sym_preproc_if_in_top_level_repeat1] = STATE(14),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(159),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(161),
    [anon_sym_global] = ACTIONS(163),
    [anon_sym_using] = ACTIONS(165),
    [anon_sym_unsafe] = ACTIONS(167),
    [anon_sym_static] = ACTIONS(39),
    [anon_sym_LBRACK] = ACTIONS(169),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(171),
    [anon_sym_namespace] = ACTIONS(173),
    [anon_sym_class] = ACTIONS(175),
    [anon_sym_ref] = ACTIONS(177),
    [anon_sym_struct] = ACTIONS(179),
    [anon_sym_enum] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_interface] = ACTIONS(185),
    [anon_sym_delegate] = ACTIONS(187),
    [anon_sym_record] = ACTIONS(189),
    [anon_sym_abstract] = ACTIONS(65),
    [anon_sym_async] = ACTIONS(39),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_file] = ACTIONS(67),
    [anon_sym_fixed] = ACTIONS(191),
    [anon_sym_internal] = ACTIONS(65),
    [anon_sym_new] = ACTIONS(71),
    [anon_sym_override] = ACTIONS(65),
    [anon_sym_partial] = ACTIONS(65),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_public] = ACTIONS(65),
    [anon_sym_readonly] = ACTIONS(65),
    [anon_sym_required] = ACTIONS(65),
    [anon_sym_sealed] = ACTIONS(65),
    [anon_sym_virtual] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(193),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(195),
    [anon_sym_unchecked] = ACTIONS(193),
    [anon_sym_continue] = ACTIONS(197),
    [anon_sym_do] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_lock] = ACTIONS(205),
    [anon_sym_yield] = ACTIONS(207),
    [anon_sym_switch] = ACTIONS(209),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(211),
    [anon_sym_try] = ACTIONS(213),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(215),
    [anon_sym_foreach] = ACTIONS(217),
    [anon_sym_goto] = ACTIONS(219),
    [anon_sym_if] = ACTIONS(221),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(223),
    [aux_sym_preproc_if_token3] = ACTIONS(251),
    [aux_sym_preproc_else_token1] = ACTIONS(241),
    [aux_sym_preproc_elif_token1] = ACTIONS(243),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [13] = {
    [sym__top_level_item] = STATE(2585),
    [sym_global_statement] = STATE(2621),
    [sym_extern_alias_directive] = STATE(2621),
    [sym_using_directive] = STATE(2621),
    [sym_global_attribute] = STATE(2621),
    [sym_attribute_list] = STATE(3740),
    [sym_namespace_declaration] = STATE(2621),
    [sym_file_scoped_namespace_declaration] = STATE(2621),
    [sym_type_declaration] = STATE(2621),
    [sym_class_declaration] = STATE(2622),
    [sym_struct_declaration] = STATE(2622),
    [sym_enum_declaration] = STATE(2622),
    [sym_interface_declaration] = STATE(2622),
    [sym_delegate_declaration] = STATE(2622),
    [sym_record_declaration] = STATE(2622),
    [sym_modifier] = STATE(3807),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2493),
    [sym_variable_declaration] = STATE(9635),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6854),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2636),
    [sym_break_statement] = STATE(2493),
    [sym_checked_statement] = STATE(2493),
    [sym_continue_statement] = STATE(2493),
    [sym_do_statement] = STATE(2493),
    [sym_empty_statement] = STATE(2493),
    [sym_expression_statement] = STATE(2493),
    [sym_fixed_statement] = STATE(2493),
    [sym_for_statement] = STATE(2493),
    [sym_return_statement] = STATE(2493),
    [sym_lock_statement] = STATE(2493),
    [sym_yield_statement] = STATE(2493),
    [sym_switch_statement] = STATE(2493),
    [sym_throw_statement] = STATE(2493),
    [sym_try_statement] = STATE(2493),
    [sym_unsafe_statement] = STATE(2493),
    [sym_using_statement] = STATE(2493),
    [sym_foreach_statement] = STATE(2493),
    [sym_goto_statement] = STATE(2493),
    [sym_labeled_statement] = STATE(2493),
    [sym_if_statement] = STATE(2493),
    [sym_while_statement] = STATE(2493),
    [sym_local_declaration_statement] = STATE(2493),
    [sym_local_function_statement] = STATE(2493),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6748),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2907),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2581),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(13),
    [sym_preproc_endregion] = STATE(13),
    [sym_preproc_line] = STATE(13),
    [sym_preproc_pragma] = STATE(13),
    [sym_preproc_nullable] = STATE(13),
    [sym_preproc_error] = STATE(13),
    [sym_preproc_warning] = STATE(13),
    [sym_preproc_define] = STATE(13),
    [sym_preproc_undef] = STATE(13),
    [aux_sym_compilation_unit_repeat1] = STATE(15),
    [aux_sym_class_declaration_repeat1] = STATE(2817),
    [aux_sym_class_declaration_repeat2] = STATE(2923),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [ts_builtin_sym_end] = ACTIONS(253),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(27),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(31),
    [anon_sym_global] = ACTIONS(33),
    [anon_sym_using] = ACTIONS(35),
    [anon_sym_unsafe] = ACTIONS(37),
    [anon_sym_static] = ACTIONS(39),
    [anon_sym_LBRACK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(45),
    [anon_sym_namespace] = ACTIONS(47),
    [anon_sym_class] = ACTIONS(49),
    [anon_sym_ref] = ACTIONS(51),
    [anon_sym_struct] = ACTIONS(53),
    [anon_sym_enum] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_interface] = ACTIONS(59),
    [anon_sym_delegate] = ACTIONS(61),
    [anon_sym_record] = ACTIONS(63),
    [anon_sym_abstract] = ACTIONS(65),
    [anon_sym_async] = ACTIONS(39),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_file] = ACTIONS(67),
    [anon_sym_fixed] = ACTIONS(69),
    [anon_sym_internal] = ACTIONS(65),
    [anon_sym_new] = ACTIONS(71),
    [anon_sym_override] = ACTIONS(65),
    [anon_sym_partial] = ACTIONS(65),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_public] = ACTIONS(65),
    [anon_sym_readonly] = ACTIONS(65),
    [anon_sym_required] = ACTIONS(65),
    [anon_sym_sealed] = ACTIONS(65),
    [anon_sym_virtual] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(73),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_unchecked] = ACTIONS(73),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_do] = ACTIONS(97),
    [anon_sym_while] = ACTIONS(99),
    [anon_sym_for] = ACTIONS(101),
    [anon_sym_lock] = ACTIONS(103),
    [anon_sym_yield] = ACTIONS(105),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(111),
    [anon_sym_try] = ACTIONS(113),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(115),
    [anon_sym_foreach] = ACTIONS(117),
    [anon_sym_goto] = ACTIONS(119),
    [anon_sym_if] = ACTIONS(121),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(147),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [14] = {
    [sym_extern_alias_directive] = STATE(2327),
    [sym_using_directive] = STATE(2327),
    [sym_global_attribute] = STATE(2327),
    [sym_attribute_list] = STATE(3740),
    [sym_namespace_declaration] = STATE(2327),
    [sym_file_scoped_namespace_declaration] = STATE(2327),
    [sym_type_declaration] = STATE(2327),
    [sym_class_declaration] = STATE(2308),
    [sym_struct_declaration] = STATE(2308),
    [sym_enum_declaration] = STATE(2308),
    [sym_interface_declaration] = STATE(2308),
    [sym_delegate_declaration] = STATE(2308),
    [sym_record_declaration] = STATE(2308),
    [sym_modifier] = STATE(3807),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2270),
    [sym_variable_declaration] = STATE(9038),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6880),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2327),
    [sym_break_statement] = STATE(2270),
    [sym_checked_statement] = STATE(2270),
    [sym_continue_statement] = STATE(2270),
    [sym_do_statement] = STATE(2270),
    [sym_empty_statement] = STATE(2270),
    [sym_expression_statement] = STATE(2270),
    [sym_fixed_statement] = STATE(2270),
    [sym_for_statement] = STATE(2270),
    [sym_return_statement] = STATE(2270),
    [sym_lock_statement] = STATE(2270),
    [sym_yield_statement] = STATE(2270),
    [sym_switch_statement] = STATE(2270),
    [sym_throw_statement] = STATE(2270),
    [sym_try_statement] = STATE(2270),
    [sym_unsafe_statement] = STATE(2270),
    [sym_using_statement] = STATE(2270),
    [sym_foreach_statement] = STATE(2270),
    [sym_goto_statement] = STATE(2270),
    [sym_labeled_statement] = STATE(2270),
    [sym_if_statement] = STATE(2270),
    [sym_while_statement] = STATE(2270),
    [sym_local_declaration_statement] = STATE(2270),
    [sym_local_function_statement] = STATE(2270),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6279),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2841),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2329),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(14),
    [sym_preproc_endregion] = STATE(14),
    [sym_preproc_line] = STATE(14),
    [sym_preproc_pragma] = STATE(14),
    [sym_preproc_nullable] = STATE(14),
    [sym_preproc_error] = STATE(14),
    [sym_preproc_warning] = STATE(14),
    [sym_preproc_define] = STATE(14),
    [sym_preproc_undef] = STATE(14),
    [aux_sym_class_declaration_repeat1] = STATE(2815),
    [aux_sym_class_declaration_repeat2] = STATE(2921),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [aux_sym_preproc_if_in_top_level_repeat1] = STATE(14),
    [sym__identifier_token] = ACTIONS(255),
    [anon_sym_extern] = ACTIONS(258),
    [anon_sym_alias] = ACTIONS(261),
    [anon_sym_SEMI] = ACTIONS(264),
    [anon_sym_global] = ACTIONS(267),
    [anon_sym_using] = ACTIONS(270),
    [anon_sym_unsafe] = ACTIONS(273),
    [anon_sym_static] = ACTIONS(276),
    [anon_sym_LBRACK] = ACTIONS(279),
    [anon_sym_LPAREN] = ACTIONS(282),
    [anon_sym_return] = ACTIONS(285),
    [anon_sym_namespace] = ACTIONS(288),
    [anon_sym_class] = ACTIONS(291),
    [anon_sym_ref] = ACTIONS(294),
    [anon_sym_struct] = ACTIONS(297),
    [anon_sym_enum] = ACTIONS(300),
    [anon_sym_LBRACE] = ACTIONS(303),
    [anon_sym_interface] = ACTIONS(306),
    [anon_sym_delegate] = ACTIONS(309),
    [anon_sym_record] = ACTIONS(312),
    [anon_sym_abstract] = ACTIONS(315),
    [anon_sym_async] = ACTIONS(276),
    [anon_sym_const] = ACTIONS(315),
    [anon_sym_file] = ACTIONS(318),
    [anon_sym_fixed] = ACTIONS(321),
    [anon_sym_internal] = ACTIONS(315),
    [anon_sym_new] = ACTIONS(324),
    [anon_sym_override] = ACTIONS(315),
    [anon_sym_partial] = ACTIONS(315),
    [anon_sym_private] = ACTIONS(315),
    [anon_sym_protected] = ACTIONS(315),
    [anon_sym_public] = ACTIONS(315),
    [anon_sym_readonly] = ACTIONS(315),
    [anon_sym_required] = ACTIONS(315),
    [anon_sym_sealed] = ACTIONS(315),
    [anon_sym_virtual] = ACTIONS(315),
    [anon_sym_volatile] = ACTIONS(315),
    [anon_sym_where] = ACTIONS(261),
    [anon_sym_notnull] = ACTIONS(261),
    [anon_sym_unmanaged] = ACTIONS(261),
    [anon_sym_checked] = ACTIONS(327),
    [anon_sym_BANG] = ACTIONS(330),
    [anon_sym_TILDE] = ACTIONS(330),
    [anon_sym_PLUS_PLUS] = ACTIONS(330),
    [anon_sym_DASH_DASH] = ACTIONS(330),
    [anon_sym_true] = ACTIONS(333),
    [anon_sym_false] = ACTIONS(333),
    [anon_sym_PLUS] = ACTIONS(336),
    [anon_sym_DASH] = ACTIONS(336),
    [anon_sym_STAR] = ACTIONS(339),
    [anon_sym_CARET] = ACTIONS(330),
    [anon_sym_AMP] = ACTIONS(330),
    [anon_sym_this] = ACTIONS(342),
    [anon_sym_scoped] = ACTIONS(345),
    [anon_sym_base] = ACTIONS(348),
    [anon_sym_var] = ACTIONS(351),
    [sym_predefined_type] = ACTIONS(354),
    [anon_sym_break] = ACTIONS(357),
    [anon_sym_unchecked] = ACTIONS(327),
    [anon_sym_continue] = ACTIONS(360),
    [anon_sym_do] = ACTIONS(363),
    [anon_sym_while] = ACTIONS(366),
    [anon_sym_for] = ACTIONS(369),
    [anon_sym_lock] = ACTIONS(372),
    [anon_sym_yield] = ACTIONS(375),
    [anon_sym_switch] = ACTIONS(378),
    [anon_sym_default] = ACTIONS(381),
    [anon_sym_throw] = ACTIONS(384),
    [anon_sym_try] = ACTIONS(387),
    [anon_sym_when] = ACTIONS(261),
    [anon_sym_await] = ACTIONS(390),
    [anon_sym_foreach] = ACTIONS(393),
    [anon_sym_goto] = ACTIONS(396),
    [anon_sym_if] = ACTIONS(399),
    [anon_sym_DOT_DOT] = ACTIONS(402),
    [anon_sym_from] = ACTIONS(405),
    [anon_sym_into] = ACTIONS(261),
    [anon_sym_join] = ACTIONS(261),
    [anon_sym_on] = ACTIONS(261),
    [anon_sym_equals] = ACTIONS(261),
    [anon_sym_let] = ACTIONS(261),
    [anon_sym_orderby] = ACTIONS(261),
    [anon_sym_ascending] = ACTIONS(261),
    [anon_sym_descending] = ACTIONS(261),
    [anon_sym_group] = ACTIONS(261),
    [anon_sym_by] = ACTIONS(261),
    [anon_sym_select] = ACTIONS(261),
    [anon_sym_stackalloc] = ACTIONS(408),
    [anon_sym_sizeof] = ACTIONS(411),
    [anon_sym_typeof] = ACTIONS(414),
    [anon_sym___makeref] = ACTIONS(417),
    [anon_sym___reftype] = ACTIONS(420),
    [anon_sym___refvalue] = ACTIONS(423),
    [sym_null_literal] = ACTIONS(426),
    [anon_sym_SQUOTE] = ACTIONS(429),
    [sym_integer_literal] = ACTIONS(426),
    [sym_real_literal] = ACTIONS(432),
    [anon_sym_DQUOTE] = ACTIONS(435),
    [sym_verbatim_string_literal] = ACTIONS(432),
    [aux_sym_preproc_if_token1] = ACTIONS(438),
    [aux_sym_preproc_if_token3] = ACTIONS(441),
    [aux_sym_preproc_else_token1] = ACTIONS(441),
    [aux_sym_preproc_elif_token1] = ACTIONS(441),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(443),
    [sym_interpolation_verbatim_start] = ACTIONS(446),
    [sym_interpolation_raw_start] = ACTIONS(449),
    [sym_raw_string_start] = ACTIONS(452),
  },
  [15] = {
    [sym__top_level_item] = STATE(2585),
    [sym_global_statement] = STATE(2621),
    [sym_extern_alias_directive] = STATE(2621),
    [sym_using_directive] = STATE(2621),
    [sym_global_attribute] = STATE(2621),
    [sym_attribute_list] = STATE(3740),
    [sym_namespace_declaration] = STATE(2621),
    [sym_file_scoped_namespace_declaration] = STATE(2621),
    [sym_type_declaration] = STATE(2621),
    [sym_class_declaration] = STATE(2622),
    [sym_struct_declaration] = STATE(2622),
    [sym_enum_declaration] = STATE(2622),
    [sym_interface_declaration] = STATE(2622),
    [sym_delegate_declaration] = STATE(2622),
    [sym_record_declaration] = STATE(2622),
    [sym_modifier] = STATE(3807),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2493),
    [sym_variable_declaration] = STATE(9635),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6854),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2636),
    [sym_break_statement] = STATE(2493),
    [sym_checked_statement] = STATE(2493),
    [sym_continue_statement] = STATE(2493),
    [sym_do_statement] = STATE(2493),
    [sym_empty_statement] = STATE(2493),
    [sym_expression_statement] = STATE(2493),
    [sym_fixed_statement] = STATE(2493),
    [sym_for_statement] = STATE(2493),
    [sym_return_statement] = STATE(2493),
    [sym_lock_statement] = STATE(2493),
    [sym_yield_statement] = STATE(2493),
    [sym_switch_statement] = STATE(2493),
    [sym_throw_statement] = STATE(2493),
    [sym_try_statement] = STATE(2493),
    [sym_unsafe_statement] = STATE(2493),
    [sym_using_statement] = STATE(2493),
    [sym_foreach_statement] = STATE(2493),
    [sym_goto_statement] = STATE(2493),
    [sym_labeled_statement] = STATE(2493),
    [sym_if_statement] = STATE(2493),
    [sym_while_statement] = STATE(2493),
    [sym_local_declaration_statement] = STATE(2493),
    [sym_local_function_statement] = STATE(2493),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6748),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2907),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2581),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(15),
    [sym_preproc_endregion] = STATE(15),
    [sym_preproc_line] = STATE(15),
    [sym_preproc_pragma] = STATE(15),
    [sym_preproc_nullable] = STATE(15),
    [sym_preproc_error] = STATE(15),
    [sym_preproc_warning] = STATE(15),
    [sym_preproc_define] = STATE(15),
    [sym_preproc_undef] = STATE(15),
    [aux_sym_compilation_unit_repeat1] = STATE(16),
    [aux_sym_class_declaration_repeat1] = STATE(2817),
    [aux_sym_class_declaration_repeat2] = STATE(2923),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [ts_builtin_sym_end] = ACTIONS(455),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(27),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(31),
    [anon_sym_global] = ACTIONS(33),
    [anon_sym_using] = ACTIONS(35),
    [anon_sym_unsafe] = ACTIONS(37),
    [anon_sym_static] = ACTIONS(39),
    [anon_sym_LBRACK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(45),
    [anon_sym_namespace] = ACTIONS(47),
    [anon_sym_class] = ACTIONS(49),
    [anon_sym_ref] = ACTIONS(51),
    [anon_sym_struct] = ACTIONS(53),
    [anon_sym_enum] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_interface] = ACTIONS(59),
    [anon_sym_delegate] = ACTIONS(61),
    [anon_sym_record] = ACTIONS(63),
    [anon_sym_abstract] = ACTIONS(65),
    [anon_sym_async] = ACTIONS(39),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_file] = ACTIONS(67),
    [anon_sym_fixed] = ACTIONS(69),
    [anon_sym_internal] = ACTIONS(65),
    [anon_sym_new] = ACTIONS(71),
    [anon_sym_override] = ACTIONS(65),
    [anon_sym_partial] = ACTIONS(65),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_public] = ACTIONS(65),
    [anon_sym_readonly] = ACTIONS(65),
    [anon_sym_required] = ACTIONS(65),
    [anon_sym_sealed] = ACTIONS(65),
    [anon_sym_virtual] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(73),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_unchecked] = ACTIONS(73),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_do] = ACTIONS(97),
    [anon_sym_while] = ACTIONS(99),
    [anon_sym_for] = ACTIONS(101),
    [anon_sym_lock] = ACTIONS(103),
    [anon_sym_yield] = ACTIONS(105),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(111),
    [anon_sym_try] = ACTIONS(113),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(115),
    [anon_sym_foreach] = ACTIONS(117),
    [anon_sym_goto] = ACTIONS(119),
    [anon_sym_if] = ACTIONS(121),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(147),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [16] = {
    [sym__top_level_item] = STATE(2585),
    [sym_global_statement] = STATE(2621),
    [sym_extern_alias_directive] = STATE(2621),
    [sym_using_directive] = STATE(2621),
    [sym_global_attribute] = STATE(2621),
    [sym_attribute_list] = STATE(3740),
    [sym_namespace_declaration] = STATE(2621),
    [sym_file_scoped_namespace_declaration] = STATE(2621),
    [sym_type_declaration] = STATE(2621),
    [sym_class_declaration] = STATE(2622),
    [sym_struct_declaration] = STATE(2622),
    [sym_enum_declaration] = STATE(2622),
    [sym_interface_declaration] = STATE(2622),
    [sym_delegate_declaration] = STATE(2622),
    [sym_record_declaration] = STATE(2622),
    [sym_modifier] = STATE(3807),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2493),
    [sym_variable_declaration] = STATE(9635),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6854),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2636),
    [sym_break_statement] = STATE(2493),
    [sym_checked_statement] = STATE(2493),
    [sym_continue_statement] = STATE(2493),
    [sym_do_statement] = STATE(2493),
    [sym_empty_statement] = STATE(2493),
    [sym_expression_statement] = STATE(2493),
    [sym_fixed_statement] = STATE(2493),
    [sym_for_statement] = STATE(2493),
    [sym_return_statement] = STATE(2493),
    [sym_lock_statement] = STATE(2493),
    [sym_yield_statement] = STATE(2493),
    [sym_switch_statement] = STATE(2493),
    [sym_throw_statement] = STATE(2493),
    [sym_try_statement] = STATE(2493),
    [sym_unsafe_statement] = STATE(2493),
    [sym_using_statement] = STATE(2493),
    [sym_foreach_statement] = STATE(2493),
    [sym_goto_statement] = STATE(2493),
    [sym_labeled_statement] = STATE(2493),
    [sym_if_statement] = STATE(2493),
    [sym_while_statement] = STATE(2493),
    [sym_local_declaration_statement] = STATE(2493),
    [sym_local_function_statement] = STATE(2493),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6748),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2907),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2581),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(16),
    [sym_preproc_endregion] = STATE(16),
    [sym_preproc_line] = STATE(16),
    [sym_preproc_pragma] = STATE(16),
    [sym_preproc_nullable] = STATE(16),
    [sym_preproc_error] = STATE(16),
    [sym_preproc_warning] = STATE(16),
    [sym_preproc_define] = STATE(16),
    [sym_preproc_undef] = STATE(16),
    [aux_sym_compilation_unit_repeat1] = STATE(16),
    [aux_sym_class_declaration_repeat1] = STATE(2817),
    [aux_sym_class_declaration_repeat2] = STATE(2923),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [ts_builtin_sym_end] = ACTIONS(457),
    [sym__identifier_token] = ACTIONS(459),
    [anon_sym_extern] = ACTIONS(462),
    [anon_sym_alias] = ACTIONS(465),
    [anon_sym_SEMI] = ACTIONS(468),
    [anon_sym_global] = ACTIONS(471),
    [anon_sym_using] = ACTIONS(474),
    [anon_sym_unsafe] = ACTIONS(477),
    [anon_sym_static] = ACTIONS(480),
    [anon_sym_LBRACK] = ACTIONS(483),
    [anon_sym_LPAREN] = ACTIONS(486),
    [anon_sym_return] = ACTIONS(489),
    [anon_sym_namespace] = ACTIONS(492),
    [anon_sym_class] = ACTIONS(495),
    [anon_sym_ref] = ACTIONS(498),
    [anon_sym_struct] = ACTIONS(501),
    [anon_sym_enum] = ACTIONS(504),
    [anon_sym_LBRACE] = ACTIONS(507),
    [anon_sym_interface] = ACTIONS(510),
    [anon_sym_delegate] = ACTIONS(513),
    [anon_sym_record] = ACTIONS(516),
    [anon_sym_abstract] = ACTIONS(519),
    [anon_sym_async] = ACTIONS(480),
    [anon_sym_const] = ACTIONS(519),
    [anon_sym_file] = ACTIONS(522),
    [anon_sym_fixed] = ACTIONS(525),
    [anon_sym_internal] = ACTIONS(519),
    [anon_sym_new] = ACTIONS(528),
    [anon_sym_override] = ACTIONS(519),
    [anon_sym_partial] = ACTIONS(519),
    [anon_sym_private] = ACTIONS(519),
    [anon_sym_protected] = ACTIONS(519),
    [anon_sym_public] = ACTIONS(519),
    [anon_sym_readonly] = ACTIONS(519),
    [anon_sym_required] = ACTIONS(519),
    [anon_sym_sealed] = ACTIONS(519),
    [anon_sym_virtual] = ACTIONS(519),
    [anon_sym_volatile] = ACTIONS(519),
    [anon_sym_where] = ACTIONS(465),
    [anon_sym_notnull] = ACTIONS(465),
    [anon_sym_unmanaged] = ACTIONS(465),
    [anon_sym_checked] = ACTIONS(531),
    [anon_sym_BANG] = ACTIONS(534),
    [anon_sym_TILDE] = ACTIONS(534),
    [anon_sym_PLUS_PLUS] = ACTIONS(534),
    [anon_sym_DASH_DASH] = ACTIONS(534),
    [anon_sym_true] = ACTIONS(537),
    [anon_sym_false] = ACTIONS(537),
    [anon_sym_PLUS] = ACTIONS(540),
    [anon_sym_DASH] = ACTIONS(540),
    [anon_sym_STAR] = ACTIONS(543),
    [anon_sym_CARET] = ACTIONS(534),
    [anon_sym_AMP] = ACTIONS(534),
    [anon_sym_this] = ACTIONS(546),
    [anon_sym_scoped] = ACTIONS(549),
    [anon_sym_base] = ACTIONS(552),
    [anon_sym_var] = ACTIONS(555),
    [sym_predefined_type] = ACTIONS(558),
    [anon_sym_break] = ACTIONS(561),
    [anon_sym_unchecked] = ACTIONS(531),
    [anon_sym_continue] = ACTIONS(564),
    [anon_sym_do] = ACTIONS(567),
    [anon_sym_while] = ACTIONS(570),
    [anon_sym_for] = ACTIONS(573),
    [anon_sym_lock] = ACTIONS(576),
    [anon_sym_yield] = ACTIONS(579),
    [anon_sym_switch] = ACTIONS(582),
    [anon_sym_default] = ACTIONS(585),
    [anon_sym_throw] = ACTIONS(588),
    [anon_sym_try] = ACTIONS(591),
    [anon_sym_when] = ACTIONS(465),
    [anon_sym_await] = ACTIONS(594),
    [anon_sym_foreach] = ACTIONS(597),
    [anon_sym_goto] = ACTIONS(600),
    [anon_sym_if] = ACTIONS(603),
    [anon_sym_DOT_DOT] = ACTIONS(606),
    [anon_sym_from] = ACTIONS(609),
    [anon_sym_into] = ACTIONS(465),
    [anon_sym_join] = ACTIONS(465),
    [anon_sym_on] = ACTIONS(465),
    [anon_sym_equals] = ACTIONS(465),
    [anon_sym_let] = ACTIONS(465),
    [anon_sym_orderby] = ACTIONS(465),
    [anon_sym_ascending] = ACTIONS(465),
    [anon_sym_descending] = ACTIONS(465),
    [anon_sym_group] = ACTIONS(465),
    [anon_sym_by] = ACTIONS(465),
    [anon_sym_select] = ACTIONS(465),
    [anon_sym_stackalloc] = ACTIONS(612),
    [anon_sym_sizeof] = ACTIONS(615),
    [anon_sym_typeof] = ACTIONS(618),
    [anon_sym___makeref] = ACTIONS(621),
    [anon_sym___reftype] = ACTIONS(624),
    [anon_sym___refvalue] = ACTIONS(627),
    [sym_null_literal] = ACTIONS(630),
    [anon_sym_SQUOTE] = ACTIONS(633),
    [sym_integer_literal] = ACTIONS(630),
    [sym_real_literal] = ACTIONS(636),
    [anon_sym_DQUOTE] = ACTIONS(639),
    [sym_verbatim_string_literal] = ACTIONS(636),
    [aux_sym_preproc_if_token1] = ACTIONS(642),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(645),
    [sym_interpolation_verbatim_start] = ACTIONS(648),
    [sym_interpolation_raw_start] = ACTIONS(651),
    [sym_raw_string_start] = ACTIONS(654),
  },
  [17] = {
    [sym__top_level_item] = STATE(2585),
    [sym_global_statement] = STATE(2621),
    [sym_extern_alias_directive] = STATE(2621),
    [sym_using_directive] = STATE(2621),
    [sym_global_attribute] = STATE(2621),
    [sym_attribute_list] = STATE(3740),
    [sym_namespace_declaration] = STATE(2621),
    [sym_file_scoped_namespace_declaration] = STATE(2621),
    [sym_type_declaration] = STATE(2621),
    [sym_class_declaration] = STATE(2622),
    [sym_struct_declaration] = STATE(2622),
    [sym_enum_declaration] = STATE(2622),
    [sym_interface_declaration] = STATE(2622),
    [sym_delegate_declaration] = STATE(2622),
    [sym_record_declaration] = STATE(2622),
    [sym_modifier] = STATE(3807),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2493),
    [sym_variable_declaration] = STATE(9635),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6854),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2636),
    [sym_break_statement] = STATE(2493),
    [sym_checked_statement] = STATE(2493),
    [sym_continue_statement] = STATE(2493),
    [sym_do_statement] = STATE(2493),
    [sym_empty_statement] = STATE(2493),
    [sym_expression_statement] = STATE(2493),
    [sym_fixed_statement] = STATE(2493),
    [sym_for_statement] = STATE(2493),
    [sym_return_statement] = STATE(2493),
    [sym_lock_statement] = STATE(2493),
    [sym_yield_statement] = STATE(2493),
    [sym_switch_statement] = STATE(2493),
    [sym_throw_statement] = STATE(2493),
    [sym_try_statement] = STATE(2493),
    [sym_unsafe_statement] = STATE(2493),
    [sym_using_statement] = STATE(2493),
    [sym_foreach_statement] = STATE(2493),
    [sym_goto_statement] = STATE(2493),
    [sym_labeled_statement] = STATE(2493),
    [sym_if_statement] = STATE(2493),
    [sym_while_statement] = STATE(2493),
    [sym_local_declaration_statement] = STATE(2493),
    [sym_local_function_statement] = STATE(2493),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6748),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2907),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2581),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(17),
    [sym_preproc_endregion] = STATE(17),
    [sym_preproc_line] = STATE(17),
    [sym_preproc_pragma] = STATE(17),
    [sym_preproc_nullable] = STATE(17),
    [sym_preproc_error] = STATE(17),
    [sym_preproc_warning] = STATE(17),
    [sym_preproc_define] = STATE(17),
    [sym_preproc_undef] = STATE(17),
    [aux_sym_compilation_unit_repeat1] = STATE(16),
    [aux_sym_class_declaration_repeat1] = STATE(2817),
    [aux_sym_class_declaration_repeat2] = STATE(2923),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [ts_builtin_sym_end] = ACTIONS(253),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(27),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(31),
    [anon_sym_global] = ACTIONS(33),
    [anon_sym_using] = ACTIONS(35),
    [anon_sym_unsafe] = ACTIONS(37),
    [anon_sym_static] = ACTIONS(39),
    [anon_sym_LBRACK] = ACTIONS(41),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(45),
    [anon_sym_namespace] = ACTIONS(47),
    [anon_sym_class] = ACTIONS(49),
    [anon_sym_ref] = ACTIONS(51),
    [anon_sym_struct] = ACTIONS(53),
    [anon_sym_enum] = ACTIONS(55),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_interface] = ACTIONS(59),
    [anon_sym_delegate] = ACTIONS(61),
    [anon_sym_record] = ACTIONS(63),
    [anon_sym_abstract] = ACTIONS(65),
    [anon_sym_async] = ACTIONS(39),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_file] = ACTIONS(67),
    [anon_sym_fixed] = ACTIONS(69),
    [anon_sym_internal] = ACTIONS(65),
    [anon_sym_new] = ACTIONS(71),
    [anon_sym_override] = ACTIONS(65),
    [anon_sym_partial] = ACTIONS(65),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_public] = ACTIONS(65),
    [anon_sym_readonly] = ACTIONS(65),
    [anon_sym_required] = ACTIONS(65),
    [anon_sym_sealed] = ACTIONS(65),
    [anon_sym_virtual] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(73),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_unchecked] = ACTIONS(73),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_do] = ACTIONS(97),
    [anon_sym_while] = ACTIONS(99),
    [anon_sym_for] = ACTIONS(101),
    [anon_sym_lock] = ACTIONS(103),
    [anon_sym_yield] = ACTIONS(105),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(111),
    [anon_sym_try] = ACTIONS(113),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(115),
    [anon_sym_foreach] = ACTIONS(117),
    [anon_sym_goto] = ACTIONS(119),
    [anon_sym_if] = ACTIONS(121),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(147),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [18] = {
    [sym_extern_alias_directive] = STATE(2327),
    [sym_using_directive] = STATE(2327),
    [sym_global_attribute] = STATE(2327),
    [sym_attribute_list] = STATE(3740),
    [sym_namespace_declaration] = STATE(2327),
    [sym_file_scoped_namespace_declaration] = STATE(2327),
    [sym_type_declaration] = STATE(2327),
    [sym_class_declaration] = STATE(2308),
    [sym_struct_declaration] = STATE(2308),
    [sym_enum_declaration] = STATE(2308),
    [sym_interface_declaration] = STATE(2308),
    [sym_delegate_declaration] = STATE(2308),
    [sym_record_declaration] = STATE(2308),
    [sym_modifier] = STATE(3807),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2270),
    [sym_variable_declaration] = STATE(9038),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6880),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2327),
    [sym_break_statement] = STATE(2270),
    [sym_checked_statement] = STATE(2270),
    [sym_continue_statement] = STATE(2270),
    [sym_do_statement] = STATE(2270),
    [sym_empty_statement] = STATE(2270),
    [sym_expression_statement] = STATE(2270),
    [sym_fixed_statement] = STATE(2270),
    [sym_for_statement] = STATE(2270),
    [sym_return_statement] = STATE(2270),
    [sym_lock_statement] = STATE(2270),
    [sym_yield_statement] = STATE(2270),
    [sym_switch_statement] = STATE(2270),
    [sym_throw_statement] = STATE(2270),
    [sym_try_statement] = STATE(2270),
    [sym_unsafe_statement] = STATE(2270),
    [sym_using_statement] = STATE(2270),
    [sym_foreach_statement] = STATE(2270),
    [sym_goto_statement] = STATE(2270),
    [sym_labeled_statement] = STATE(2270),
    [sym_if_statement] = STATE(2270),
    [sym_while_statement] = STATE(2270),
    [sym_local_declaration_statement] = STATE(2270),
    [sym_local_function_statement] = STATE(2270),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6279),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2841),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2329),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(18),
    [sym_preproc_endregion] = STATE(18),
    [sym_preproc_line] = STATE(18),
    [sym_preproc_pragma] = STATE(18),
    [sym_preproc_nullable] = STATE(18),
    [sym_preproc_error] = STATE(18),
    [sym_preproc_warning] = STATE(18),
    [sym_preproc_define] = STATE(18),
    [sym_preproc_undef] = STATE(18),
    [aux_sym_class_declaration_repeat1] = STATE(2815),
    [aux_sym_class_declaration_repeat2] = STATE(2921),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [aux_sym_preproc_if_in_top_level_repeat1] = STATE(14),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(159),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(161),
    [anon_sym_global] = ACTIONS(163),
    [anon_sym_using] = ACTIONS(165),
    [anon_sym_unsafe] = ACTIONS(167),
    [anon_sym_static] = ACTIONS(39),
    [anon_sym_LBRACK] = ACTIONS(169),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(171),
    [anon_sym_namespace] = ACTIONS(173),
    [anon_sym_class] = ACTIONS(175),
    [anon_sym_ref] = ACTIONS(177),
    [anon_sym_struct] = ACTIONS(179),
    [anon_sym_enum] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_interface] = ACTIONS(185),
    [anon_sym_delegate] = ACTIONS(187),
    [anon_sym_record] = ACTIONS(189),
    [anon_sym_abstract] = ACTIONS(65),
    [anon_sym_async] = ACTIONS(39),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_file] = ACTIONS(67),
    [anon_sym_fixed] = ACTIONS(191),
    [anon_sym_internal] = ACTIONS(65),
    [anon_sym_new] = ACTIONS(71),
    [anon_sym_override] = ACTIONS(65),
    [anon_sym_partial] = ACTIONS(65),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_public] = ACTIONS(65),
    [anon_sym_readonly] = ACTIONS(65),
    [anon_sym_required] = ACTIONS(65),
    [anon_sym_sealed] = ACTIONS(65),
    [anon_sym_virtual] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(193),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(195),
    [anon_sym_unchecked] = ACTIONS(193),
    [anon_sym_continue] = ACTIONS(197),
    [anon_sym_do] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_lock] = ACTIONS(205),
    [anon_sym_yield] = ACTIONS(207),
    [anon_sym_switch] = ACTIONS(209),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(211),
    [anon_sym_try] = ACTIONS(213),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(215),
    [anon_sym_foreach] = ACTIONS(217),
    [anon_sym_goto] = ACTIONS(219),
    [anon_sym_if] = ACTIONS(221),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(223),
    [aux_sym_preproc_if_token3] = ACTIONS(657),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [19] = {
    [sym_extern_alias_directive] = STATE(2327),
    [sym_using_directive] = STATE(2327),
    [sym_global_attribute] = STATE(2327),
    [sym_attribute_list] = STATE(3740),
    [sym_namespace_declaration] = STATE(2327),
    [sym_file_scoped_namespace_declaration] = STATE(2327),
    [sym_type_declaration] = STATE(2327),
    [sym_class_declaration] = STATE(2308),
    [sym_struct_declaration] = STATE(2308),
    [sym_enum_declaration] = STATE(2308),
    [sym_interface_declaration] = STATE(2308),
    [sym_delegate_declaration] = STATE(2308),
    [sym_record_declaration] = STATE(2308),
    [sym_modifier] = STATE(3807),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2270),
    [sym_variable_declaration] = STATE(9038),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6880),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2327),
    [sym_break_statement] = STATE(2270),
    [sym_checked_statement] = STATE(2270),
    [sym_continue_statement] = STATE(2270),
    [sym_do_statement] = STATE(2270),
    [sym_empty_statement] = STATE(2270),
    [sym_expression_statement] = STATE(2270),
    [sym_fixed_statement] = STATE(2270),
    [sym_for_statement] = STATE(2270),
    [sym_return_statement] = STATE(2270),
    [sym_lock_statement] = STATE(2270),
    [sym_yield_statement] = STATE(2270),
    [sym_switch_statement] = STATE(2270),
    [sym_throw_statement] = STATE(2270),
    [sym_try_statement] = STATE(2270),
    [sym_unsafe_statement] = STATE(2270),
    [sym_using_statement] = STATE(2270),
    [sym_foreach_statement] = STATE(2270),
    [sym_goto_statement] = STATE(2270),
    [sym_labeled_statement] = STATE(2270),
    [sym_if_statement] = STATE(2270),
    [sym_while_statement] = STATE(2270),
    [sym_local_declaration_statement] = STATE(2270),
    [sym_local_function_statement] = STATE(2270),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6279),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2841),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2329),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(19),
    [sym_preproc_endregion] = STATE(19),
    [sym_preproc_line] = STATE(19),
    [sym_preproc_pragma] = STATE(19),
    [sym_preproc_nullable] = STATE(19),
    [sym_preproc_error] = STATE(19),
    [sym_preproc_warning] = STATE(19),
    [sym_preproc_define] = STATE(19),
    [sym_preproc_undef] = STATE(19),
    [aux_sym_class_declaration_repeat1] = STATE(2815),
    [aux_sym_class_declaration_repeat2] = STATE(2921),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [aux_sym_preproc_if_in_top_level_repeat1] = STATE(18),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(159),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(161),
    [anon_sym_global] = ACTIONS(163),
    [anon_sym_using] = ACTIONS(165),
    [anon_sym_unsafe] = ACTIONS(167),
    [anon_sym_static] = ACTIONS(39),
    [anon_sym_LBRACK] = ACTIONS(169),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(171),
    [anon_sym_namespace] = ACTIONS(173),
    [anon_sym_class] = ACTIONS(175),
    [anon_sym_ref] = ACTIONS(177),
    [anon_sym_struct] = ACTIONS(179),
    [anon_sym_enum] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_interface] = ACTIONS(185),
    [anon_sym_delegate] = ACTIONS(187),
    [anon_sym_record] = ACTIONS(189),
    [anon_sym_abstract] = ACTIONS(65),
    [anon_sym_async] = ACTIONS(39),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_file] = ACTIONS(67),
    [anon_sym_fixed] = ACTIONS(191),
    [anon_sym_internal] = ACTIONS(65),
    [anon_sym_new] = ACTIONS(71),
    [anon_sym_override] = ACTIONS(65),
    [anon_sym_partial] = ACTIONS(65),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_public] = ACTIONS(65),
    [anon_sym_readonly] = ACTIONS(65),
    [anon_sym_required] = ACTIONS(65),
    [anon_sym_sealed] = ACTIONS(65),
    [anon_sym_virtual] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(193),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(195),
    [anon_sym_unchecked] = ACTIONS(193),
    [anon_sym_continue] = ACTIONS(197),
    [anon_sym_do] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_lock] = ACTIONS(205),
    [anon_sym_yield] = ACTIONS(207),
    [anon_sym_switch] = ACTIONS(209),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(211),
    [anon_sym_try] = ACTIONS(213),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(215),
    [anon_sym_foreach] = ACTIONS(217),
    [anon_sym_goto] = ACTIONS(219),
    [anon_sym_if] = ACTIONS(221),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(223),
    [aux_sym_preproc_if_token3] = ACTIONS(659),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [20] = {
    [sym_extern_alias_directive] = STATE(2327),
    [sym_using_directive] = STATE(2327),
    [sym_global_attribute] = STATE(2327),
    [sym_attribute_list] = STATE(3740),
    [sym_namespace_declaration] = STATE(2327),
    [sym_file_scoped_namespace_declaration] = STATE(2327),
    [sym_type_declaration] = STATE(2327),
    [sym_class_declaration] = STATE(2308),
    [sym_struct_declaration] = STATE(2308),
    [sym_enum_declaration] = STATE(2308),
    [sym_interface_declaration] = STATE(2308),
    [sym_delegate_declaration] = STATE(2308),
    [sym_record_declaration] = STATE(2308),
    [sym_modifier] = STATE(3807),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2270),
    [sym_variable_declaration] = STATE(9038),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6880),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2327),
    [sym_break_statement] = STATE(2270),
    [sym_checked_statement] = STATE(2270),
    [sym_continue_statement] = STATE(2270),
    [sym_do_statement] = STATE(2270),
    [sym_empty_statement] = STATE(2270),
    [sym_expression_statement] = STATE(2270),
    [sym_fixed_statement] = STATE(2270),
    [sym_for_statement] = STATE(2270),
    [sym_return_statement] = STATE(2270),
    [sym_lock_statement] = STATE(2270),
    [sym_yield_statement] = STATE(2270),
    [sym_switch_statement] = STATE(2270),
    [sym_throw_statement] = STATE(2270),
    [sym_try_statement] = STATE(2270),
    [sym_unsafe_statement] = STATE(2270),
    [sym_using_statement] = STATE(2270),
    [sym_foreach_statement] = STATE(2270),
    [sym_goto_statement] = STATE(2270),
    [sym_labeled_statement] = STATE(2270),
    [sym_if_statement] = STATE(2270),
    [sym_while_statement] = STATE(2270),
    [sym_local_declaration_statement] = STATE(2270),
    [sym_local_function_statement] = STATE(2270),
    [sym_expression] = STATE(6640),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6279),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2841),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2329),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(20),
    [sym_preproc_endregion] = STATE(20),
    [sym_preproc_line] = STATE(20),
    [sym_preproc_pragma] = STATE(20),
    [sym_preproc_nullable] = STATE(20),
    [sym_preproc_error] = STATE(20),
    [sym_preproc_warning] = STATE(20),
    [sym_preproc_define] = STATE(20),
    [sym_preproc_undef] = STATE(20),
    [aux_sym_class_declaration_repeat1] = STATE(2815),
    [aux_sym_class_declaration_repeat2] = STATE(2921),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [aux_sym_preproc_if_in_top_level_repeat1] = STATE(18),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(159),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(161),
    [anon_sym_global] = ACTIONS(163),
    [anon_sym_using] = ACTIONS(165),
    [anon_sym_unsafe] = ACTIONS(167),
    [anon_sym_static] = ACTIONS(39),
    [anon_sym_LBRACK] = ACTIONS(169),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(171),
    [anon_sym_namespace] = ACTIONS(173),
    [anon_sym_class] = ACTIONS(175),
    [anon_sym_ref] = ACTIONS(177),
    [anon_sym_struct] = ACTIONS(179),
    [anon_sym_enum] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_interface] = ACTIONS(185),
    [anon_sym_delegate] = ACTIONS(187),
    [anon_sym_record] = ACTIONS(189),
    [anon_sym_abstract] = ACTIONS(65),
    [anon_sym_async] = ACTIONS(39),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_file] = ACTIONS(67),
    [anon_sym_fixed] = ACTIONS(191),
    [anon_sym_internal] = ACTIONS(65),
    [anon_sym_new] = ACTIONS(71),
    [anon_sym_override] = ACTIONS(65),
    [anon_sym_partial] = ACTIONS(65),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_public] = ACTIONS(65),
    [anon_sym_readonly] = ACTIONS(65),
    [anon_sym_required] = ACTIONS(65),
    [anon_sym_sealed] = ACTIONS(65),
    [anon_sym_virtual] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(193),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(195),
    [anon_sym_unchecked] = ACTIONS(193),
    [anon_sym_continue] = ACTIONS(197),
    [anon_sym_do] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_lock] = ACTIONS(205),
    [anon_sym_yield] = ACTIONS(207),
    [anon_sym_switch] = ACTIONS(209),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(211),
    [anon_sym_try] = ACTIONS(213),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(215),
    [anon_sym_foreach] = ACTIONS(217),
    [anon_sym_goto] = ACTIONS(219),
    [anon_sym_if] = ACTIONS(221),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(223),
    [aux_sym_preproc_if_token3] = ACTIONS(659),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [21] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2659),
    [sym_variable_declaration] = STATE(9524),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6894),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2732),
    [sym_break_statement] = STATE(2659),
    [sym_checked_statement] = STATE(2659),
    [sym_continue_statement] = STATE(2659),
    [sym_do_statement] = STATE(2659),
    [sym_empty_statement] = STATE(2659),
    [sym_expression_statement] = STATE(2659),
    [sym_fixed_statement] = STATE(2659),
    [sym_for_statement] = STATE(2659),
    [sym_return_statement] = STATE(2659),
    [sym_lock_statement] = STATE(2659),
    [sym_yield_statement] = STATE(2659),
    [sym_switch_statement] = STATE(2659),
    [sym_throw_statement] = STATE(2659),
    [sym_try_statement] = STATE(2659),
    [sym_unsafe_statement] = STATE(2659),
    [sym_using_statement] = STATE(2659),
    [sym_foreach_statement] = STATE(2659),
    [sym_goto_statement] = STATE(2659),
    [sym_labeled_statement] = STATE(2659),
    [sym_if_statement] = STATE(2659),
    [sym_while_statement] = STATE(2659),
    [sym_local_declaration_statement] = STATE(2659),
    [sym_local_function_statement] = STATE(2659),
    [sym_expression] = STATE(5839),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4364),
    [sym__expression_statement_expression] = STATE(6347),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2847),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2659),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(21),
    [sym_preproc_endregion] = STATE(21),
    [sym_preproc_line] = STATE(21),
    [sym_preproc_pragma] = STATE(21),
    [sym_preproc_nullable] = STATE(21),
    [sym_preproc_error] = STATE(21),
    [sym_preproc_warning] = STATE(21),
    [sym_preproc_define] = STATE(21),
    [sym_preproc_undef] = STATE(21),
    [aux_sym_class_declaration_repeat1] = STATE(2929),
    [aux_sym_class_declaration_repeat2] = STATE(3094),
    [aux_sym_block_repeat1] = STATE(48),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(663),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(665),
    [anon_sym_unsafe] = ACTIONS(667),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_COMMA] = ACTIONS(673),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_return] = ACTIONS(677),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_RBRACE] = ACTIONS(683),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(689),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(693),
    [anon_sym_BANG] = ACTIONS(695),
    [anon_sym_TILDE] = ACTIONS(695),
    [anon_sym_PLUS_PLUS] = ACTIONS(695),
    [anon_sym_DASH_DASH] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(697),
    [anon_sym_DASH] = ACTIONS(697),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(695),
    [anon_sym_AMP] = ACTIONS(695),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(701),
    [anon_sym_unchecked] = ACTIONS(693),
    [anon_sym_continue] = ACTIONS(703),
    [anon_sym_do] = ACTIONS(705),
    [anon_sym_while] = ACTIONS(707),
    [anon_sym_for] = ACTIONS(709),
    [anon_sym_lock] = ACTIONS(711),
    [anon_sym_yield] = ACTIONS(713),
    [anon_sym_switch] = ACTIONS(715),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(717),
    [anon_sym_try] = ACTIONS(719),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(721),
    [anon_sym_foreach] = ACTIONS(723),
    [anon_sym_goto] = ACTIONS(725),
    [anon_sym_if] = ACTIONS(727),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(731),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [22] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2659),
    [sym_variable_declaration] = STATE(9524),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6870),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2732),
    [sym_break_statement] = STATE(2659),
    [sym_checked_statement] = STATE(2659),
    [sym_continue_statement] = STATE(2659),
    [sym_do_statement] = STATE(2659),
    [sym_empty_statement] = STATE(2659),
    [sym_expression_statement] = STATE(2659),
    [sym_fixed_statement] = STATE(2659),
    [sym_for_statement] = STATE(2659),
    [sym_return_statement] = STATE(2659),
    [sym_lock_statement] = STATE(2659),
    [sym_yield_statement] = STATE(2659),
    [sym_switch_statement] = STATE(2659),
    [sym_throw_statement] = STATE(2659),
    [sym_try_statement] = STATE(2659),
    [sym_unsafe_statement] = STATE(2659),
    [sym_using_statement] = STATE(2659),
    [sym_foreach_statement] = STATE(2659),
    [sym_goto_statement] = STATE(2659),
    [sym_labeled_statement] = STATE(2659),
    [sym_if_statement] = STATE(2659),
    [sym_while_statement] = STATE(2659),
    [sym_local_declaration_statement] = STATE(2659),
    [sym_local_function_statement] = STATE(2659),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6347),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2847),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2659),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(22),
    [sym_preproc_endregion] = STATE(22),
    [sym_preproc_line] = STATE(22),
    [sym_preproc_pragma] = STATE(22),
    [sym_preproc_nullable] = STATE(22),
    [sym_preproc_error] = STATE(22),
    [sym_preproc_warning] = STATE(22),
    [sym_preproc_define] = STATE(22),
    [sym_preproc_undef] = STATE(22),
    [aux_sym_class_declaration_repeat1] = STATE(2935),
    [aux_sym_class_declaration_repeat2] = STATE(3094),
    [aux_sym_block_repeat1] = STATE(27),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(663),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(665),
    [anon_sym_unsafe] = ACTIONS(667),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(677),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_RBRACE] = ACTIONS(735),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(689),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(693),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(701),
    [anon_sym_unchecked] = ACTIONS(693),
    [anon_sym_continue] = ACTIONS(703),
    [anon_sym_do] = ACTIONS(705),
    [anon_sym_while] = ACTIONS(707),
    [anon_sym_for] = ACTIONS(709),
    [anon_sym_lock] = ACTIONS(711),
    [anon_sym_yield] = ACTIONS(713),
    [anon_sym_switch] = ACTIONS(715),
    [anon_sym_case] = ACTIONS(737),
    [anon_sym_default] = ACTIONS(737),
    [anon_sym_throw] = ACTIONS(739),
    [anon_sym_try] = ACTIONS(719),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(741),
    [anon_sym_foreach] = ACTIONS(723),
    [anon_sym_goto] = ACTIONS(725),
    [anon_sym_if] = ACTIONS(727),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(731),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [23] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2659),
    [sym_variable_declaration] = STATE(9524),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6894),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2732),
    [sym_break_statement] = STATE(2659),
    [sym_checked_statement] = STATE(2659),
    [sym_continue_statement] = STATE(2659),
    [sym_do_statement] = STATE(2659),
    [sym_empty_statement] = STATE(2659),
    [sym_expression_statement] = STATE(2659),
    [sym_fixed_statement] = STATE(2659),
    [sym_for_statement] = STATE(2659),
    [sym_return_statement] = STATE(2659),
    [sym_lock_statement] = STATE(2659),
    [sym_yield_statement] = STATE(2659),
    [sym_switch_statement] = STATE(2659),
    [sym_throw_statement] = STATE(2659),
    [sym_try_statement] = STATE(2659),
    [sym_unsafe_statement] = STATE(2659),
    [sym_using_statement] = STATE(2659),
    [sym_foreach_statement] = STATE(2659),
    [sym_goto_statement] = STATE(2659),
    [sym_labeled_statement] = STATE(2659),
    [sym_if_statement] = STATE(2659),
    [sym_while_statement] = STATE(2659),
    [sym_local_declaration_statement] = STATE(2659),
    [sym_local_function_statement] = STATE(2659),
    [sym_expression] = STATE(6117),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4364),
    [sym__expression_statement_expression] = STATE(6347),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2847),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2659),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(23),
    [sym_preproc_endregion] = STATE(23),
    [sym_preproc_line] = STATE(23),
    [sym_preproc_pragma] = STATE(23),
    [sym_preproc_nullable] = STATE(23),
    [sym_preproc_error] = STATE(23),
    [sym_preproc_warning] = STATE(23),
    [sym_preproc_define] = STATE(23),
    [sym_preproc_undef] = STATE(23),
    [aux_sym_class_declaration_repeat1] = STATE(2929),
    [aux_sym_class_declaration_repeat2] = STATE(3094),
    [aux_sym_block_repeat1] = STATE(49),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(663),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(665),
    [anon_sym_unsafe] = ACTIONS(667),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_COMMA] = ACTIONS(743),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_return] = ACTIONS(677),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_RBRACE] = ACTIONS(745),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(689),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(693),
    [anon_sym_BANG] = ACTIONS(695),
    [anon_sym_TILDE] = ACTIONS(695),
    [anon_sym_PLUS_PLUS] = ACTIONS(695),
    [anon_sym_DASH_DASH] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(697),
    [anon_sym_DASH] = ACTIONS(697),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(695),
    [anon_sym_AMP] = ACTIONS(695),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(701),
    [anon_sym_unchecked] = ACTIONS(693),
    [anon_sym_continue] = ACTIONS(703),
    [anon_sym_do] = ACTIONS(705),
    [anon_sym_while] = ACTIONS(707),
    [anon_sym_for] = ACTIONS(709),
    [anon_sym_lock] = ACTIONS(711),
    [anon_sym_yield] = ACTIONS(713),
    [anon_sym_switch] = ACTIONS(715),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(717),
    [anon_sym_try] = ACTIONS(719),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(721),
    [anon_sym_foreach] = ACTIONS(723),
    [anon_sym_goto] = ACTIONS(725),
    [anon_sym_if] = ACTIONS(727),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(731),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [24] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2659),
    [sym_variable_declaration] = STATE(9524),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6870),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2732),
    [sym_break_statement] = STATE(2659),
    [sym_checked_statement] = STATE(2659),
    [sym_continue_statement] = STATE(2659),
    [sym_do_statement] = STATE(2659),
    [sym_empty_statement] = STATE(2659),
    [sym_expression_statement] = STATE(2659),
    [sym_fixed_statement] = STATE(2659),
    [sym_for_statement] = STATE(2659),
    [sym_return_statement] = STATE(2659),
    [sym_lock_statement] = STATE(2659),
    [sym_yield_statement] = STATE(2659),
    [sym_switch_statement] = STATE(2659),
    [sym_throw_statement] = STATE(2659),
    [sym_try_statement] = STATE(2659),
    [sym_unsafe_statement] = STATE(2659),
    [sym_using_statement] = STATE(2659),
    [sym_foreach_statement] = STATE(2659),
    [sym_goto_statement] = STATE(2659),
    [sym_labeled_statement] = STATE(2659),
    [sym_if_statement] = STATE(2659),
    [sym_while_statement] = STATE(2659),
    [sym_local_declaration_statement] = STATE(2659),
    [sym_local_function_statement] = STATE(2659),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6347),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2847),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2659),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(24),
    [sym_preproc_endregion] = STATE(24),
    [sym_preproc_line] = STATE(24),
    [sym_preproc_pragma] = STATE(24),
    [sym_preproc_nullable] = STATE(24),
    [sym_preproc_error] = STATE(24),
    [sym_preproc_warning] = STATE(24),
    [sym_preproc_define] = STATE(24),
    [sym_preproc_undef] = STATE(24),
    [aux_sym_class_declaration_repeat1] = STATE(2935),
    [aux_sym_class_declaration_repeat2] = STATE(3094),
    [aux_sym_block_repeat1] = STATE(29),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(663),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(665),
    [anon_sym_unsafe] = ACTIONS(667),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(677),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_RBRACE] = ACTIONS(747),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(689),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(693),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(701),
    [anon_sym_unchecked] = ACTIONS(693),
    [anon_sym_continue] = ACTIONS(703),
    [anon_sym_do] = ACTIONS(705),
    [anon_sym_while] = ACTIONS(707),
    [anon_sym_for] = ACTIONS(709),
    [anon_sym_lock] = ACTIONS(711),
    [anon_sym_yield] = ACTIONS(713),
    [anon_sym_switch] = ACTIONS(715),
    [anon_sym_case] = ACTIONS(749),
    [anon_sym_default] = ACTIONS(749),
    [anon_sym_throw] = ACTIONS(739),
    [anon_sym_try] = ACTIONS(719),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(741),
    [anon_sym_foreach] = ACTIONS(723),
    [anon_sym_goto] = ACTIONS(725),
    [anon_sym_if] = ACTIONS(727),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(731),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [25] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2659),
    [sym_variable_declaration] = STATE(9524),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6894),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2732),
    [sym_break_statement] = STATE(2659),
    [sym_checked_statement] = STATE(2659),
    [sym_continue_statement] = STATE(2659),
    [sym_do_statement] = STATE(2659),
    [sym_empty_statement] = STATE(2659),
    [sym_expression_statement] = STATE(2659),
    [sym_fixed_statement] = STATE(2659),
    [sym_for_statement] = STATE(2659),
    [sym_return_statement] = STATE(2659),
    [sym_lock_statement] = STATE(2659),
    [sym_yield_statement] = STATE(2659),
    [sym_switch_statement] = STATE(2659),
    [sym_throw_statement] = STATE(2659),
    [sym_try_statement] = STATE(2659),
    [sym_unsafe_statement] = STATE(2659),
    [sym_using_statement] = STATE(2659),
    [sym_foreach_statement] = STATE(2659),
    [sym_goto_statement] = STATE(2659),
    [sym_labeled_statement] = STATE(2659),
    [sym_if_statement] = STATE(2659),
    [sym_while_statement] = STATE(2659),
    [sym_local_declaration_statement] = STATE(2659),
    [sym_local_function_statement] = STATE(2659),
    [sym_expression] = STATE(6117),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4364),
    [sym__expression_statement_expression] = STATE(6347),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2847),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2659),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(25),
    [sym_preproc_endregion] = STATE(25),
    [sym_preproc_line] = STATE(25),
    [sym_preproc_pragma] = STATE(25),
    [sym_preproc_nullable] = STATE(25),
    [sym_preproc_error] = STATE(25),
    [sym_preproc_warning] = STATE(25),
    [sym_preproc_define] = STATE(25),
    [sym_preproc_undef] = STATE(25),
    [aux_sym_class_declaration_repeat1] = STATE(2929),
    [aux_sym_class_declaration_repeat2] = STATE(3094),
    [aux_sym_block_repeat1] = STATE(39),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(663),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(665),
    [anon_sym_unsafe] = ACTIONS(667),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_COMMA] = ACTIONS(743),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_return] = ACTIONS(677),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_RBRACE] = ACTIONS(751),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(689),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(693),
    [anon_sym_BANG] = ACTIONS(695),
    [anon_sym_TILDE] = ACTIONS(695),
    [anon_sym_PLUS_PLUS] = ACTIONS(695),
    [anon_sym_DASH_DASH] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(697),
    [anon_sym_DASH] = ACTIONS(697),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(695),
    [anon_sym_AMP] = ACTIONS(695),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(701),
    [anon_sym_unchecked] = ACTIONS(693),
    [anon_sym_continue] = ACTIONS(703),
    [anon_sym_do] = ACTIONS(705),
    [anon_sym_while] = ACTIONS(707),
    [anon_sym_for] = ACTIONS(709),
    [anon_sym_lock] = ACTIONS(711),
    [anon_sym_yield] = ACTIONS(713),
    [anon_sym_switch] = ACTIONS(715),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(717),
    [anon_sym_try] = ACTIONS(719),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(721),
    [anon_sym_foreach] = ACTIONS(723),
    [anon_sym_goto] = ACTIONS(725),
    [anon_sym_if] = ACTIONS(727),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(731),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [26] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2659),
    [sym_variable_declaration] = STATE(9524),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6870),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2732),
    [sym_break_statement] = STATE(2659),
    [sym_checked_statement] = STATE(2659),
    [sym_continue_statement] = STATE(2659),
    [sym_do_statement] = STATE(2659),
    [sym_empty_statement] = STATE(2659),
    [sym_expression_statement] = STATE(2659),
    [sym_fixed_statement] = STATE(2659),
    [sym_for_statement] = STATE(2659),
    [sym_return_statement] = STATE(2659),
    [sym_lock_statement] = STATE(2659),
    [sym_yield_statement] = STATE(2659),
    [sym_switch_statement] = STATE(2659),
    [sym_throw_statement] = STATE(2659),
    [sym_try_statement] = STATE(2659),
    [sym_unsafe_statement] = STATE(2659),
    [sym_using_statement] = STATE(2659),
    [sym_foreach_statement] = STATE(2659),
    [sym_goto_statement] = STATE(2659),
    [sym_labeled_statement] = STATE(2659),
    [sym_if_statement] = STATE(2659),
    [sym_while_statement] = STATE(2659),
    [sym_local_declaration_statement] = STATE(2659),
    [sym_local_function_statement] = STATE(2659),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6347),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2847),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2659),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(26),
    [sym_preproc_endregion] = STATE(26),
    [sym_preproc_line] = STATE(26),
    [sym_preproc_pragma] = STATE(26),
    [sym_preproc_nullable] = STATE(26),
    [sym_preproc_error] = STATE(26),
    [sym_preproc_warning] = STATE(26),
    [sym_preproc_define] = STATE(26),
    [sym_preproc_undef] = STATE(26),
    [aux_sym_class_declaration_repeat1] = STATE(2935),
    [aux_sym_class_declaration_repeat2] = STATE(3094),
    [aux_sym_block_repeat1] = STATE(27),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(663),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(665),
    [anon_sym_unsafe] = ACTIONS(667),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(677),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_RBRACE] = ACTIONS(747),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(689),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(693),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(701),
    [anon_sym_unchecked] = ACTIONS(693),
    [anon_sym_continue] = ACTIONS(703),
    [anon_sym_do] = ACTIONS(705),
    [anon_sym_while] = ACTIONS(707),
    [anon_sym_for] = ACTIONS(709),
    [anon_sym_lock] = ACTIONS(711),
    [anon_sym_yield] = ACTIONS(713),
    [anon_sym_switch] = ACTIONS(715),
    [anon_sym_case] = ACTIONS(749),
    [anon_sym_default] = ACTIONS(749),
    [anon_sym_throw] = ACTIONS(739),
    [anon_sym_try] = ACTIONS(719),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(741),
    [anon_sym_foreach] = ACTIONS(723),
    [anon_sym_goto] = ACTIONS(725),
    [anon_sym_if] = ACTIONS(727),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(731),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [27] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2659),
    [sym_variable_declaration] = STATE(9524),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6870),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2732),
    [sym_break_statement] = STATE(2659),
    [sym_checked_statement] = STATE(2659),
    [sym_continue_statement] = STATE(2659),
    [sym_do_statement] = STATE(2659),
    [sym_empty_statement] = STATE(2659),
    [sym_expression_statement] = STATE(2659),
    [sym_fixed_statement] = STATE(2659),
    [sym_for_statement] = STATE(2659),
    [sym_return_statement] = STATE(2659),
    [sym_lock_statement] = STATE(2659),
    [sym_yield_statement] = STATE(2659),
    [sym_switch_statement] = STATE(2659),
    [sym_throw_statement] = STATE(2659),
    [sym_try_statement] = STATE(2659),
    [sym_unsafe_statement] = STATE(2659),
    [sym_using_statement] = STATE(2659),
    [sym_foreach_statement] = STATE(2659),
    [sym_goto_statement] = STATE(2659),
    [sym_labeled_statement] = STATE(2659),
    [sym_if_statement] = STATE(2659),
    [sym_while_statement] = STATE(2659),
    [sym_local_declaration_statement] = STATE(2659),
    [sym_local_function_statement] = STATE(2659),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6347),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2847),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2659),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(27),
    [sym_preproc_endregion] = STATE(27),
    [sym_preproc_line] = STATE(27),
    [sym_preproc_pragma] = STATE(27),
    [sym_preproc_nullable] = STATE(27),
    [sym_preproc_error] = STATE(27),
    [sym_preproc_warning] = STATE(27),
    [sym_preproc_define] = STATE(27),
    [sym_preproc_undef] = STATE(27),
    [aux_sym_class_declaration_repeat1] = STATE(2935),
    [aux_sym_class_declaration_repeat2] = STATE(3094),
    [aux_sym_block_repeat1] = STATE(27),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(753),
    [anon_sym_extern] = ACTIONS(756),
    [anon_sym_alias] = ACTIONS(759),
    [anon_sym_SEMI] = ACTIONS(762),
    [anon_sym_global] = ACTIONS(759),
    [anon_sym_using] = ACTIONS(765),
    [anon_sym_unsafe] = ACTIONS(768),
    [anon_sym_static] = ACTIONS(771),
    [anon_sym_LBRACK] = ACTIONS(774),
    [anon_sym_LPAREN] = ACTIONS(777),
    [anon_sym_return] = ACTIONS(780),
    [anon_sym_ref] = ACTIONS(783),
    [anon_sym_LBRACE] = ACTIONS(786),
    [anon_sym_RBRACE] = ACTIONS(789),
    [anon_sym_delegate] = ACTIONS(791),
    [anon_sym_abstract] = ACTIONS(756),
    [anon_sym_async] = ACTIONS(771),
    [anon_sym_const] = ACTIONS(756),
    [anon_sym_file] = ACTIONS(794),
    [anon_sym_fixed] = ACTIONS(797),
    [anon_sym_internal] = ACTIONS(756),
    [anon_sym_new] = ACTIONS(800),
    [anon_sym_override] = ACTIONS(756),
    [anon_sym_partial] = ACTIONS(756),
    [anon_sym_private] = ACTIONS(756),
    [anon_sym_protected] = ACTIONS(756),
    [anon_sym_public] = ACTIONS(756),
    [anon_sym_readonly] = ACTIONS(756),
    [anon_sym_required] = ACTIONS(756),
    [anon_sym_sealed] = ACTIONS(756),
    [anon_sym_virtual] = ACTIONS(756),
    [anon_sym_volatile] = ACTIONS(756),
    [anon_sym_where] = ACTIONS(759),
    [anon_sym_notnull] = ACTIONS(759),
    [anon_sym_unmanaged] = ACTIONS(759),
    [anon_sym_checked] = ACTIONS(803),
    [anon_sym_BANG] = ACTIONS(806),
    [anon_sym_TILDE] = ACTIONS(806),
    [anon_sym_PLUS_PLUS] = ACTIONS(806),
    [anon_sym_DASH_DASH] = ACTIONS(806),
    [anon_sym_true] = ACTIONS(809),
    [anon_sym_false] = ACTIONS(809),
    [anon_sym_PLUS] = ACTIONS(812),
    [anon_sym_DASH] = ACTIONS(812),
    [anon_sym_STAR] = ACTIONS(815),
    [anon_sym_CARET] = ACTIONS(806),
    [anon_sym_AMP] = ACTIONS(806),
    [anon_sym_this] = ACTIONS(818),
    [anon_sym_scoped] = ACTIONS(821),
    [anon_sym_base] = ACTIONS(824),
    [anon_sym_var] = ACTIONS(827),
    [sym_predefined_type] = ACTIONS(830),
    [anon_sym_break] = ACTIONS(833),
    [anon_sym_unchecked] = ACTIONS(803),
    [anon_sym_continue] = ACTIONS(836),
    [anon_sym_do] = ACTIONS(839),
    [anon_sym_while] = ACTIONS(842),
    [anon_sym_for] = ACTIONS(845),
    [anon_sym_lock] = ACTIONS(848),
    [anon_sym_yield] = ACTIONS(851),
    [anon_sym_switch] = ACTIONS(854),
    [anon_sym_case] = ACTIONS(857),
    [anon_sym_default] = ACTIONS(859),
    [anon_sym_throw] = ACTIONS(862),
    [anon_sym_try] = ACTIONS(865),
    [anon_sym_when] = ACTIONS(759),
    [anon_sym_await] = ACTIONS(868),
    [anon_sym_foreach] = ACTIONS(871),
    [anon_sym_goto] = ACTIONS(874),
    [anon_sym_if] = ACTIONS(877),
    [anon_sym_DOT_DOT] = ACTIONS(880),
    [anon_sym_from] = ACTIONS(883),
    [anon_sym_into] = ACTIONS(759),
    [anon_sym_join] = ACTIONS(759),
    [anon_sym_on] = ACTIONS(759),
    [anon_sym_equals] = ACTIONS(759),
    [anon_sym_let] = ACTIONS(759),
    [anon_sym_orderby] = ACTIONS(759),
    [anon_sym_ascending] = ACTIONS(759),
    [anon_sym_descending] = ACTIONS(759),
    [anon_sym_group] = ACTIONS(759),
    [anon_sym_by] = ACTIONS(759),
    [anon_sym_select] = ACTIONS(759),
    [anon_sym_stackalloc] = ACTIONS(886),
    [anon_sym_sizeof] = ACTIONS(889),
    [anon_sym_typeof] = ACTIONS(892),
    [anon_sym___makeref] = ACTIONS(895),
    [anon_sym___reftype] = ACTIONS(898),
    [anon_sym___refvalue] = ACTIONS(901),
    [sym_null_literal] = ACTIONS(904),
    [anon_sym_SQUOTE] = ACTIONS(907),
    [sym_integer_literal] = ACTIONS(904),
    [sym_real_literal] = ACTIONS(910),
    [anon_sym_DQUOTE] = ACTIONS(913),
    [sym_verbatim_string_literal] = ACTIONS(910),
    [aux_sym_preproc_if_token1] = ACTIONS(916),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(919),
    [sym_interpolation_verbatim_start] = ACTIONS(922),
    [sym_interpolation_raw_start] = ACTIONS(925),
    [sym_raw_string_start] = ACTIONS(928),
  },
  [28] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2659),
    [sym_variable_declaration] = STATE(9524),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6894),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2732),
    [sym_break_statement] = STATE(2659),
    [sym_checked_statement] = STATE(2659),
    [sym_continue_statement] = STATE(2659),
    [sym_do_statement] = STATE(2659),
    [sym_empty_statement] = STATE(2659),
    [sym_expression_statement] = STATE(2659),
    [sym_fixed_statement] = STATE(2659),
    [sym_for_statement] = STATE(2659),
    [sym_return_statement] = STATE(2659),
    [sym_lock_statement] = STATE(2659),
    [sym_yield_statement] = STATE(2659),
    [sym_switch_statement] = STATE(2659),
    [sym_throw_statement] = STATE(2659),
    [sym_try_statement] = STATE(2659),
    [sym_unsafe_statement] = STATE(2659),
    [sym_using_statement] = STATE(2659),
    [sym_foreach_statement] = STATE(2659),
    [sym_goto_statement] = STATE(2659),
    [sym_labeled_statement] = STATE(2659),
    [sym_if_statement] = STATE(2659),
    [sym_while_statement] = STATE(2659),
    [sym_local_declaration_statement] = STATE(2659),
    [sym_local_function_statement] = STATE(2659),
    [sym_expression] = STATE(6117),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4364),
    [sym__expression_statement_expression] = STATE(6347),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2847),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2659),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(28),
    [sym_preproc_endregion] = STATE(28),
    [sym_preproc_line] = STATE(28),
    [sym_preproc_pragma] = STATE(28),
    [sym_preproc_nullable] = STATE(28),
    [sym_preproc_error] = STATE(28),
    [sym_preproc_warning] = STATE(28),
    [sym_preproc_define] = STATE(28),
    [sym_preproc_undef] = STATE(28),
    [aux_sym_class_declaration_repeat1] = STATE(2929),
    [aux_sym_class_declaration_repeat2] = STATE(3094),
    [aux_sym_block_repeat1] = STATE(39),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(663),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(665),
    [anon_sym_unsafe] = ACTIONS(667),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_COMMA] = ACTIONS(743),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_return] = ACTIONS(677),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_RBRACE] = ACTIONS(931),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(689),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(693),
    [anon_sym_BANG] = ACTIONS(695),
    [anon_sym_TILDE] = ACTIONS(695),
    [anon_sym_PLUS_PLUS] = ACTIONS(695),
    [anon_sym_DASH_DASH] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(697),
    [anon_sym_DASH] = ACTIONS(697),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(695),
    [anon_sym_AMP] = ACTIONS(695),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(701),
    [anon_sym_unchecked] = ACTIONS(693),
    [anon_sym_continue] = ACTIONS(703),
    [anon_sym_do] = ACTIONS(705),
    [anon_sym_while] = ACTIONS(707),
    [anon_sym_for] = ACTIONS(709),
    [anon_sym_lock] = ACTIONS(711),
    [anon_sym_yield] = ACTIONS(713),
    [anon_sym_switch] = ACTIONS(715),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(717),
    [anon_sym_try] = ACTIONS(719),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(721),
    [anon_sym_foreach] = ACTIONS(723),
    [anon_sym_goto] = ACTIONS(725),
    [anon_sym_if] = ACTIONS(727),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(731),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [29] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2659),
    [sym_variable_declaration] = STATE(9524),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6870),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2732),
    [sym_break_statement] = STATE(2659),
    [sym_checked_statement] = STATE(2659),
    [sym_continue_statement] = STATE(2659),
    [sym_do_statement] = STATE(2659),
    [sym_empty_statement] = STATE(2659),
    [sym_expression_statement] = STATE(2659),
    [sym_fixed_statement] = STATE(2659),
    [sym_for_statement] = STATE(2659),
    [sym_return_statement] = STATE(2659),
    [sym_lock_statement] = STATE(2659),
    [sym_yield_statement] = STATE(2659),
    [sym_switch_statement] = STATE(2659),
    [sym_throw_statement] = STATE(2659),
    [sym_try_statement] = STATE(2659),
    [sym_unsafe_statement] = STATE(2659),
    [sym_using_statement] = STATE(2659),
    [sym_foreach_statement] = STATE(2659),
    [sym_goto_statement] = STATE(2659),
    [sym_labeled_statement] = STATE(2659),
    [sym_if_statement] = STATE(2659),
    [sym_while_statement] = STATE(2659),
    [sym_local_declaration_statement] = STATE(2659),
    [sym_local_function_statement] = STATE(2659),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6347),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2847),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2659),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(29),
    [sym_preproc_endregion] = STATE(29),
    [sym_preproc_line] = STATE(29),
    [sym_preproc_pragma] = STATE(29),
    [sym_preproc_nullable] = STATE(29),
    [sym_preproc_error] = STATE(29),
    [sym_preproc_warning] = STATE(29),
    [sym_preproc_define] = STATE(29),
    [sym_preproc_undef] = STATE(29),
    [aux_sym_class_declaration_repeat1] = STATE(2935),
    [aux_sym_class_declaration_repeat2] = STATE(3094),
    [aux_sym_block_repeat1] = STATE(27),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(663),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(665),
    [anon_sym_unsafe] = ACTIONS(667),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(677),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_RBRACE] = ACTIONS(933),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(689),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(693),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(701),
    [anon_sym_unchecked] = ACTIONS(693),
    [anon_sym_continue] = ACTIONS(703),
    [anon_sym_do] = ACTIONS(705),
    [anon_sym_while] = ACTIONS(707),
    [anon_sym_for] = ACTIONS(709),
    [anon_sym_lock] = ACTIONS(711),
    [anon_sym_yield] = ACTIONS(713),
    [anon_sym_switch] = ACTIONS(715),
    [anon_sym_case] = ACTIONS(935),
    [anon_sym_default] = ACTIONS(935),
    [anon_sym_throw] = ACTIONS(739),
    [anon_sym_try] = ACTIONS(719),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(741),
    [anon_sym_foreach] = ACTIONS(723),
    [anon_sym_goto] = ACTIONS(725),
    [anon_sym_if] = ACTIONS(727),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(731),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [30] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2659),
    [sym_variable_declaration] = STATE(9524),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6870),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2732),
    [sym_break_statement] = STATE(2659),
    [sym_checked_statement] = STATE(2659),
    [sym_continue_statement] = STATE(2659),
    [sym_do_statement] = STATE(2659),
    [sym_empty_statement] = STATE(2659),
    [sym_expression_statement] = STATE(2659),
    [sym_fixed_statement] = STATE(2659),
    [sym_for_statement] = STATE(2659),
    [sym_return_statement] = STATE(2659),
    [sym_lock_statement] = STATE(2659),
    [sym_yield_statement] = STATE(2659),
    [sym_switch_statement] = STATE(2659),
    [sym_throw_statement] = STATE(2659),
    [sym_try_statement] = STATE(2659),
    [sym_unsafe_statement] = STATE(2659),
    [sym_using_statement] = STATE(2659),
    [sym_foreach_statement] = STATE(2659),
    [sym_goto_statement] = STATE(2659),
    [sym_labeled_statement] = STATE(2659),
    [sym_if_statement] = STATE(2659),
    [sym_while_statement] = STATE(2659),
    [sym_local_declaration_statement] = STATE(2659),
    [sym_local_function_statement] = STATE(2659),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6347),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2847),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2659),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(30),
    [sym_preproc_endregion] = STATE(30),
    [sym_preproc_line] = STATE(30),
    [sym_preproc_pragma] = STATE(30),
    [sym_preproc_nullable] = STATE(30),
    [sym_preproc_error] = STATE(30),
    [sym_preproc_warning] = STATE(30),
    [sym_preproc_define] = STATE(30),
    [sym_preproc_undef] = STATE(30),
    [aux_sym_class_declaration_repeat1] = STATE(2935),
    [aux_sym_class_declaration_repeat2] = STATE(3094),
    [aux_sym_block_repeat1] = STATE(22),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(663),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(665),
    [anon_sym_unsafe] = ACTIONS(667),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(677),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_RBRACE] = ACTIONS(933),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(689),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(693),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(701),
    [anon_sym_unchecked] = ACTIONS(693),
    [anon_sym_continue] = ACTIONS(703),
    [anon_sym_do] = ACTIONS(705),
    [anon_sym_while] = ACTIONS(707),
    [anon_sym_for] = ACTIONS(709),
    [anon_sym_lock] = ACTIONS(711),
    [anon_sym_yield] = ACTIONS(713),
    [anon_sym_switch] = ACTIONS(715),
    [anon_sym_case] = ACTIONS(935),
    [anon_sym_default] = ACTIONS(935),
    [anon_sym_throw] = ACTIONS(739),
    [anon_sym_try] = ACTIONS(719),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(741),
    [anon_sym_foreach] = ACTIONS(723),
    [anon_sym_goto] = ACTIONS(725),
    [anon_sym_if] = ACTIONS(727),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(731),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [31] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2659),
    [sym_variable_declaration] = STATE(9524),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6894),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2732),
    [sym_break_statement] = STATE(2659),
    [sym_checked_statement] = STATE(2659),
    [sym_continue_statement] = STATE(2659),
    [sym_do_statement] = STATE(2659),
    [sym_empty_statement] = STATE(2659),
    [sym_expression_statement] = STATE(2659),
    [sym_fixed_statement] = STATE(2659),
    [sym_for_statement] = STATE(2659),
    [sym_return_statement] = STATE(2659),
    [sym_lock_statement] = STATE(2659),
    [sym_yield_statement] = STATE(2659),
    [sym_switch_statement] = STATE(2659),
    [sym_throw_statement] = STATE(2659),
    [sym_try_statement] = STATE(2659),
    [sym_unsafe_statement] = STATE(2659),
    [sym_using_statement] = STATE(2659),
    [sym_foreach_statement] = STATE(2659),
    [sym_goto_statement] = STATE(2659),
    [sym_labeled_statement] = STATE(2659),
    [sym_if_statement] = STATE(2659),
    [sym_while_statement] = STATE(2659),
    [sym_local_declaration_statement] = STATE(2659),
    [sym_local_function_statement] = STATE(2659),
    [sym_expression] = STATE(6117),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4364),
    [sym__expression_statement_expression] = STATE(6347),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2847),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2659),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(31),
    [sym_preproc_endregion] = STATE(31),
    [sym_preproc_line] = STATE(31),
    [sym_preproc_pragma] = STATE(31),
    [sym_preproc_nullable] = STATE(31),
    [sym_preproc_error] = STATE(31),
    [sym_preproc_warning] = STATE(31),
    [sym_preproc_define] = STATE(31),
    [sym_preproc_undef] = STATE(31),
    [aux_sym_class_declaration_repeat1] = STATE(2929),
    [aux_sym_class_declaration_repeat2] = STATE(3094),
    [aux_sym_block_repeat1] = STATE(55),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(663),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(665),
    [anon_sym_unsafe] = ACTIONS(667),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_COMMA] = ACTIONS(743),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_return] = ACTIONS(677),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_RBRACE] = ACTIONS(937),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(689),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(693),
    [anon_sym_BANG] = ACTIONS(695),
    [anon_sym_TILDE] = ACTIONS(695),
    [anon_sym_PLUS_PLUS] = ACTIONS(695),
    [anon_sym_DASH_DASH] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(697),
    [anon_sym_DASH] = ACTIONS(697),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(695),
    [anon_sym_AMP] = ACTIONS(695),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(701),
    [anon_sym_unchecked] = ACTIONS(693),
    [anon_sym_continue] = ACTIONS(703),
    [anon_sym_do] = ACTIONS(705),
    [anon_sym_while] = ACTIONS(707),
    [anon_sym_for] = ACTIONS(709),
    [anon_sym_lock] = ACTIONS(711),
    [anon_sym_yield] = ACTIONS(713),
    [anon_sym_switch] = ACTIONS(715),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(717),
    [anon_sym_try] = ACTIONS(719),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(721),
    [anon_sym_foreach] = ACTIONS(723),
    [anon_sym_goto] = ACTIONS(725),
    [anon_sym_if] = ACTIONS(727),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(731),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [32] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2659),
    [sym_variable_declaration] = STATE(9524),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6894),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2732),
    [sym_break_statement] = STATE(2659),
    [sym_checked_statement] = STATE(2659),
    [sym_continue_statement] = STATE(2659),
    [sym_do_statement] = STATE(2659),
    [sym_empty_statement] = STATE(2659),
    [sym_expression_statement] = STATE(2659),
    [sym_fixed_statement] = STATE(2659),
    [sym_for_statement] = STATE(2659),
    [sym_return_statement] = STATE(2659),
    [sym_lock_statement] = STATE(2659),
    [sym_yield_statement] = STATE(2659),
    [sym_switch_statement] = STATE(2659),
    [sym_throw_statement] = STATE(2659),
    [sym_try_statement] = STATE(2659),
    [sym_unsafe_statement] = STATE(2659),
    [sym_using_statement] = STATE(2659),
    [sym_foreach_statement] = STATE(2659),
    [sym_goto_statement] = STATE(2659),
    [sym_labeled_statement] = STATE(2659),
    [sym_if_statement] = STATE(2659),
    [sym_while_statement] = STATE(2659),
    [sym_local_declaration_statement] = STATE(2659),
    [sym_local_function_statement] = STATE(2659),
    [sym_expression] = STATE(5905),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4364),
    [sym__expression_statement_expression] = STATE(6347),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2847),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2659),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(32),
    [sym_preproc_endregion] = STATE(32),
    [sym_preproc_line] = STATE(32),
    [sym_preproc_pragma] = STATE(32),
    [sym_preproc_nullable] = STATE(32),
    [sym_preproc_error] = STATE(32),
    [sym_preproc_warning] = STATE(32),
    [sym_preproc_define] = STATE(32),
    [sym_preproc_undef] = STATE(32),
    [aux_sym_class_declaration_repeat1] = STATE(2929),
    [aux_sym_class_declaration_repeat2] = STATE(3094),
    [aux_sym_block_repeat1] = STATE(42),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(663),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(665),
    [anon_sym_unsafe] = ACTIONS(667),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_COMMA] = ACTIONS(939),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_return] = ACTIONS(677),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_RBRACE] = ACTIONS(941),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(689),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(693),
    [anon_sym_BANG] = ACTIONS(695),
    [anon_sym_TILDE] = ACTIONS(695),
    [anon_sym_PLUS_PLUS] = ACTIONS(695),
    [anon_sym_DASH_DASH] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(697),
    [anon_sym_DASH] = ACTIONS(697),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(695),
    [anon_sym_AMP] = ACTIONS(695),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(701),
    [anon_sym_unchecked] = ACTIONS(693),
    [anon_sym_continue] = ACTIONS(703),
    [anon_sym_do] = ACTIONS(705),
    [anon_sym_while] = ACTIONS(707),
    [anon_sym_for] = ACTIONS(709),
    [anon_sym_lock] = ACTIONS(711),
    [anon_sym_yield] = ACTIONS(713),
    [anon_sym_switch] = ACTIONS(715),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(717),
    [anon_sym_try] = ACTIONS(719),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(721),
    [anon_sym_foreach] = ACTIONS(723),
    [anon_sym_goto] = ACTIONS(725),
    [anon_sym_if] = ACTIONS(727),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(731),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [33] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2659),
    [sym_variable_declaration] = STATE(9524),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6894),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2732),
    [sym_break_statement] = STATE(2659),
    [sym_checked_statement] = STATE(2659),
    [sym_continue_statement] = STATE(2659),
    [sym_do_statement] = STATE(2659),
    [sym_empty_statement] = STATE(2659),
    [sym_expression_statement] = STATE(2659),
    [sym_fixed_statement] = STATE(2659),
    [sym_for_statement] = STATE(2659),
    [sym_return_statement] = STATE(2659),
    [sym_lock_statement] = STATE(2659),
    [sym_yield_statement] = STATE(2659),
    [sym_switch_statement] = STATE(2659),
    [sym_throw_statement] = STATE(2659),
    [sym_try_statement] = STATE(2659),
    [sym_unsafe_statement] = STATE(2659),
    [sym_using_statement] = STATE(2659),
    [sym_foreach_statement] = STATE(2659),
    [sym_goto_statement] = STATE(2659),
    [sym_labeled_statement] = STATE(2659),
    [sym_if_statement] = STATE(2659),
    [sym_while_statement] = STATE(2659),
    [sym_local_declaration_statement] = STATE(2659),
    [sym_local_function_statement] = STATE(2659),
    [sym_expression] = STATE(6077),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4364),
    [sym__expression_statement_expression] = STATE(6347),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2847),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2659),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(33),
    [sym_preproc_endregion] = STATE(33),
    [sym_preproc_line] = STATE(33),
    [sym_preproc_pragma] = STATE(33),
    [sym_preproc_nullable] = STATE(33),
    [sym_preproc_error] = STATE(33),
    [sym_preproc_warning] = STATE(33),
    [sym_preproc_define] = STATE(33),
    [sym_preproc_undef] = STATE(33),
    [aux_sym_class_declaration_repeat1] = STATE(2929),
    [aux_sym_class_declaration_repeat2] = STATE(3094),
    [aux_sym_block_repeat1] = STATE(45),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(663),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(665),
    [anon_sym_unsafe] = ACTIONS(667),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_COMMA] = ACTIONS(943),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_return] = ACTIONS(677),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_RBRACE] = ACTIONS(945),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(689),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(693),
    [anon_sym_BANG] = ACTIONS(695),
    [anon_sym_TILDE] = ACTIONS(695),
    [anon_sym_PLUS_PLUS] = ACTIONS(695),
    [anon_sym_DASH_DASH] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(697),
    [anon_sym_DASH] = ACTIONS(697),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(695),
    [anon_sym_AMP] = ACTIONS(695),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(701),
    [anon_sym_unchecked] = ACTIONS(693),
    [anon_sym_continue] = ACTIONS(703),
    [anon_sym_do] = ACTIONS(705),
    [anon_sym_while] = ACTIONS(707),
    [anon_sym_for] = ACTIONS(709),
    [anon_sym_lock] = ACTIONS(711),
    [anon_sym_yield] = ACTIONS(713),
    [anon_sym_switch] = ACTIONS(715),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(717),
    [anon_sym_try] = ACTIONS(719),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(721),
    [anon_sym_foreach] = ACTIONS(723),
    [anon_sym_goto] = ACTIONS(725),
    [anon_sym_if] = ACTIONS(727),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(731),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [34] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2659),
    [sym_variable_declaration] = STATE(9524),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6894),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2732),
    [sym_break_statement] = STATE(2659),
    [sym_checked_statement] = STATE(2659),
    [sym_continue_statement] = STATE(2659),
    [sym_do_statement] = STATE(2659),
    [sym_empty_statement] = STATE(2659),
    [sym_expression_statement] = STATE(2659),
    [sym_fixed_statement] = STATE(2659),
    [sym_for_statement] = STATE(2659),
    [sym_return_statement] = STATE(2659),
    [sym_lock_statement] = STATE(2659),
    [sym_yield_statement] = STATE(2659),
    [sym_switch_statement] = STATE(2659),
    [sym_throw_statement] = STATE(2659),
    [sym_try_statement] = STATE(2659),
    [sym_unsafe_statement] = STATE(2659),
    [sym_using_statement] = STATE(2659),
    [sym_foreach_statement] = STATE(2659),
    [sym_goto_statement] = STATE(2659),
    [sym_labeled_statement] = STATE(2659),
    [sym_if_statement] = STATE(2659),
    [sym_while_statement] = STATE(2659),
    [sym_local_declaration_statement] = STATE(2659),
    [sym_local_function_statement] = STATE(2659),
    [sym_expression] = STATE(6117),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4364),
    [sym__expression_statement_expression] = STATE(6347),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2847),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2659),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(34),
    [sym_preproc_endregion] = STATE(34),
    [sym_preproc_line] = STATE(34),
    [sym_preproc_pragma] = STATE(34),
    [sym_preproc_nullable] = STATE(34),
    [sym_preproc_error] = STATE(34),
    [sym_preproc_warning] = STATE(34),
    [sym_preproc_define] = STATE(34),
    [sym_preproc_undef] = STATE(34),
    [aux_sym_class_declaration_repeat1] = STATE(2929),
    [aux_sym_class_declaration_repeat2] = STATE(3094),
    [aux_sym_block_repeat1] = STATE(40),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(663),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(665),
    [anon_sym_unsafe] = ACTIONS(667),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_COMMA] = ACTIONS(743),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_return] = ACTIONS(677),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_RBRACE] = ACTIONS(947),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(689),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(693),
    [anon_sym_BANG] = ACTIONS(695),
    [anon_sym_TILDE] = ACTIONS(695),
    [anon_sym_PLUS_PLUS] = ACTIONS(695),
    [anon_sym_DASH_DASH] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(697),
    [anon_sym_DASH] = ACTIONS(697),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(695),
    [anon_sym_AMP] = ACTIONS(695),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(701),
    [anon_sym_unchecked] = ACTIONS(693),
    [anon_sym_continue] = ACTIONS(703),
    [anon_sym_do] = ACTIONS(705),
    [anon_sym_while] = ACTIONS(707),
    [anon_sym_for] = ACTIONS(709),
    [anon_sym_lock] = ACTIONS(711),
    [anon_sym_yield] = ACTIONS(713),
    [anon_sym_switch] = ACTIONS(715),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(717),
    [anon_sym_try] = ACTIONS(719),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(721),
    [anon_sym_foreach] = ACTIONS(723),
    [anon_sym_goto] = ACTIONS(725),
    [anon_sym_if] = ACTIONS(727),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(731),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [35] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2659),
    [sym_variable_declaration] = STATE(9524),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6894),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2732),
    [sym_break_statement] = STATE(2659),
    [sym_checked_statement] = STATE(2659),
    [sym_continue_statement] = STATE(2659),
    [sym_do_statement] = STATE(2659),
    [sym_empty_statement] = STATE(2659),
    [sym_expression_statement] = STATE(2659),
    [sym_fixed_statement] = STATE(2659),
    [sym_for_statement] = STATE(2659),
    [sym_return_statement] = STATE(2659),
    [sym_lock_statement] = STATE(2659),
    [sym_yield_statement] = STATE(2659),
    [sym_switch_statement] = STATE(2659),
    [sym_throw_statement] = STATE(2659),
    [sym_try_statement] = STATE(2659),
    [sym_unsafe_statement] = STATE(2659),
    [sym_using_statement] = STATE(2659),
    [sym_foreach_statement] = STATE(2659),
    [sym_goto_statement] = STATE(2659),
    [sym_labeled_statement] = STATE(2659),
    [sym_if_statement] = STATE(2659),
    [sym_while_statement] = STATE(2659),
    [sym_local_declaration_statement] = STATE(2659),
    [sym_local_function_statement] = STATE(2659),
    [sym_expression] = STATE(5870),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4364),
    [sym__expression_statement_expression] = STATE(6347),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2847),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2659),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(35),
    [sym_preproc_endregion] = STATE(35),
    [sym_preproc_line] = STATE(35),
    [sym_preproc_pragma] = STATE(35),
    [sym_preproc_nullable] = STATE(35),
    [sym_preproc_error] = STATE(35),
    [sym_preproc_warning] = STATE(35),
    [sym_preproc_define] = STATE(35),
    [sym_preproc_undef] = STATE(35),
    [aux_sym_class_declaration_repeat1] = STATE(2929),
    [aux_sym_class_declaration_repeat2] = STATE(3094),
    [aux_sym_block_repeat1] = STATE(51),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(663),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(665),
    [anon_sym_unsafe] = ACTIONS(667),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_COMMA] = ACTIONS(949),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_return] = ACTIONS(677),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_RBRACE] = ACTIONS(951),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(689),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(693),
    [anon_sym_BANG] = ACTIONS(695),
    [anon_sym_TILDE] = ACTIONS(695),
    [anon_sym_PLUS_PLUS] = ACTIONS(695),
    [anon_sym_DASH_DASH] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(697),
    [anon_sym_DASH] = ACTIONS(697),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(695),
    [anon_sym_AMP] = ACTIONS(695),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(701),
    [anon_sym_unchecked] = ACTIONS(693),
    [anon_sym_continue] = ACTIONS(703),
    [anon_sym_do] = ACTIONS(705),
    [anon_sym_while] = ACTIONS(707),
    [anon_sym_for] = ACTIONS(709),
    [anon_sym_lock] = ACTIONS(711),
    [anon_sym_yield] = ACTIONS(713),
    [anon_sym_switch] = ACTIONS(715),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(717),
    [anon_sym_try] = ACTIONS(719),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(721),
    [anon_sym_foreach] = ACTIONS(723),
    [anon_sym_goto] = ACTIONS(725),
    [anon_sym_if] = ACTIONS(727),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(731),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [36] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2659),
    [sym_variable_declaration] = STATE(9524),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6894),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2732),
    [sym_break_statement] = STATE(2659),
    [sym_checked_statement] = STATE(2659),
    [sym_continue_statement] = STATE(2659),
    [sym_do_statement] = STATE(2659),
    [sym_empty_statement] = STATE(2659),
    [sym_expression_statement] = STATE(2659),
    [sym_fixed_statement] = STATE(2659),
    [sym_for_statement] = STATE(2659),
    [sym_return_statement] = STATE(2659),
    [sym_lock_statement] = STATE(2659),
    [sym_yield_statement] = STATE(2659),
    [sym_switch_statement] = STATE(2659),
    [sym_throw_statement] = STATE(2659),
    [sym_try_statement] = STATE(2659),
    [sym_unsafe_statement] = STATE(2659),
    [sym_using_statement] = STATE(2659),
    [sym_foreach_statement] = STATE(2659),
    [sym_goto_statement] = STATE(2659),
    [sym_labeled_statement] = STATE(2659),
    [sym_if_statement] = STATE(2659),
    [sym_while_statement] = STATE(2659),
    [sym_local_declaration_statement] = STATE(2659),
    [sym_local_function_statement] = STATE(2659),
    [sym_expression] = STATE(5980),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4364),
    [sym__expression_statement_expression] = STATE(6347),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2847),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2659),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(36),
    [sym_preproc_endregion] = STATE(36),
    [sym_preproc_line] = STATE(36),
    [sym_preproc_pragma] = STATE(36),
    [sym_preproc_nullable] = STATE(36),
    [sym_preproc_error] = STATE(36),
    [sym_preproc_warning] = STATE(36),
    [sym_preproc_define] = STATE(36),
    [sym_preproc_undef] = STATE(36),
    [aux_sym_class_declaration_repeat1] = STATE(2929),
    [aux_sym_class_declaration_repeat2] = STATE(3094),
    [aux_sym_block_repeat1] = STATE(57),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(663),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(665),
    [anon_sym_unsafe] = ACTIONS(667),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_COMMA] = ACTIONS(953),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_return] = ACTIONS(677),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_RBRACE] = ACTIONS(955),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(689),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(693),
    [anon_sym_BANG] = ACTIONS(695),
    [anon_sym_TILDE] = ACTIONS(695),
    [anon_sym_PLUS_PLUS] = ACTIONS(695),
    [anon_sym_DASH_DASH] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(697),
    [anon_sym_DASH] = ACTIONS(697),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(695),
    [anon_sym_AMP] = ACTIONS(695),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(701),
    [anon_sym_unchecked] = ACTIONS(693),
    [anon_sym_continue] = ACTIONS(703),
    [anon_sym_do] = ACTIONS(705),
    [anon_sym_while] = ACTIONS(707),
    [anon_sym_for] = ACTIONS(709),
    [anon_sym_lock] = ACTIONS(711),
    [anon_sym_yield] = ACTIONS(713),
    [anon_sym_switch] = ACTIONS(715),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(717),
    [anon_sym_try] = ACTIONS(719),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(721),
    [anon_sym_foreach] = ACTIONS(723),
    [anon_sym_goto] = ACTIONS(725),
    [anon_sym_if] = ACTIONS(727),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(731),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [37] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2659),
    [sym_variable_declaration] = STATE(9524),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6870),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2732),
    [sym_break_statement] = STATE(2659),
    [sym_checked_statement] = STATE(2659),
    [sym_continue_statement] = STATE(2659),
    [sym_do_statement] = STATE(2659),
    [sym_empty_statement] = STATE(2659),
    [sym_expression_statement] = STATE(2659),
    [sym_fixed_statement] = STATE(2659),
    [sym_for_statement] = STATE(2659),
    [sym_return_statement] = STATE(2659),
    [sym_lock_statement] = STATE(2659),
    [sym_yield_statement] = STATE(2659),
    [sym_switch_statement] = STATE(2659),
    [sym_throw_statement] = STATE(2659),
    [sym_try_statement] = STATE(2659),
    [sym_unsafe_statement] = STATE(2659),
    [sym_using_statement] = STATE(2659),
    [sym_foreach_statement] = STATE(2659),
    [sym_goto_statement] = STATE(2659),
    [sym_labeled_statement] = STATE(2659),
    [sym_if_statement] = STATE(2659),
    [sym_while_statement] = STATE(2659),
    [sym_local_declaration_statement] = STATE(2659),
    [sym_local_function_statement] = STATE(2659),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6347),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2847),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2659),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(37),
    [sym_preproc_endregion] = STATE(37),
    [sym_preproc_line] = STATE(37),
    [sym_preproc_pragma] = STATE(37),
    [sym_preproc_nullable] = STATE(37),
    [sym_preproc_error] = STATE(37),
    [sym_preproc_warning] = STATE(37),
    [sym_preproc_define] = STATE(37),
    [sym_preproc_undef] = STATE(37),
    [aux_sym_class_declaration_repeat1] = STATE(2935),
    [aux_sym_class_declaration_repeat2] = STATE(3094),
    [aux_sym_block_repeat1] = STATE(26),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(663),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(665),
    [anon_sym_unsafe] = ACTIONS(667),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(677),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_RBRACE] = ACTIONS(957),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(689),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(693),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(701),
    [anon_sym_unchecked] = ACTIONS(693),
    [anon_sym_continue] = ACTIONS(703),
    [anon_sym_do] = ACTIONS(705),
    [anon_sym_while] = ACTIONS(707),
    [anon_sym_for] = ACTIONS(709),
    [anon_sym_lock] = ACTIONS(711),
    [anon_sym_yield] = ACTIONS(713),
    [anon_sym_switch] = ACTIONS(715),
    [anon_sym_case] = ACTIONS(959),
    [anon_sym_default] = ACTIONS(959),
    [anon_sym_throw] = ACTIONS(739),
    [anon_sym_try] = ACTIONS(719),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(741),
    [anon_sym_foreach] = ACTIONS(723),
    [anon_sym_goto] = ACTIONS(725),
    [anon_sym_if] = ACTIONS(727),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(731),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [38] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2659),
    [sym_variable_declaration] = STATE(9524),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6870),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2732),
    [sym_break_statement] = STATE(2659),
    [sym_checked_statement] = STATE(2659),
    [sym_continue_statement] = STATE(2659),
    [sym_do_statement] = STATE(2659),
    [sym_empty_statement] = STATE(2659),
    [sym_expression_statement] = STATE(2659),
    [sym_fixed_statement] = STATE(2659),
    [sym_for_statement] = STATE(2659),
    [sym_return_statement] = STATE(2659),
    [sym_lock_statement] = STATE(2659),
    [sym_yield_statement] = STATE(2659),
    [sym_switch_statement] = STATE(2659),
    [sym_throw_statement] = STATE(2659),
    [sym_try_statement] = STATE(2659),
    [sym_unsafe_statement] = STATE(2659),
    [sym_using_statement] = STATE(2659),
    [sym_foreach_statement] = STATE(2659),
    [sym_goto_statement] = STATE(2659),
    [sym_labeled_statement] = STATE(2659),
    [sym_if_statement] = STATE(2659),
    [sym_while_statement] = STATE(2659),
    [sym_local_declaration_statement] = STATE(2659),
    [sym_local_function_statement] = STATE(2659),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6347),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2847),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2659),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(38),
    [sym_preproc_endregion] = STATE(38),
    [sym_preproc_line] = STATE(38),
    [sym_preproc_pragma] = STATE(38),
    [sym_preproc_nullable] = STATE(38),
    [sym_preproc_error] = STATE(38),
    [sym_preproc_warning] = STATE(38),
    [sym_preproc_define] = STATE(38),
    [sym_preproc_undef] = STATE(38),
    [aux_sym_class_declaration_repeat1] = STATE(2935),
    [aux_sym_class_declaration_repeat2] = STATE(3094),
    [aux_sym_block_repeat1] = STATE(49),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(663),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(665),
    [anon_sym_unsafe] = ACTIONS(667),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(677),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_RBRACE] = ACTIONS(961),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(689),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(693),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(701),
    [anon_sym_unchecked] = ACTIONS(693),
    [anon_sym_continue] = ACTIONS(703),
    [anon_sym_do] = ACTIONS(705),
    [anon_sym_while] = ACTIONS(707),
    [anon_sym_for] = ACTIONS(709),
    [anon_sym_lock] = ACTIONS(711),
    [anon_sym_yield] = ACTIONS(713),
    [anon_sym_switch] = ACTIONS(715),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(739),
    [anon_sym_try] = ACTIONS(719),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(741),
    [anon_sym_foreach] = ACTIONS(723),
    [anon_sym_goto] = ACTIONS(725),
    [anon_sym_if] = ACTIONS(727),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(731),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [39] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2659),
    [sym_variable_declaration] = STATE(9524),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6870),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2732),
    [sym_break_statement] = STATE(2659),
    [sym_checked_statement] = STATE(2659),
    [sym_continue_statement] = STATE(2659),
    [sym_do_statement] = STATE(2659),
    [sym_empty_statement] = STATE(2659),
    [sym_expression_statement] = STATE(2659),
    [sym_fixed_statement] = STATE(2659),
    [sym_for_statement] = STATE(2659),
    [sym_return_statement] = STATE(2659),
    [sym_lock_statement] = STATE(2659),
    [sym_yield_statement] = STATE(2659),
    [sym_switch_statement] = STATE(2659),
    [sym_throw_statement] = STATE(2659),
    [sym_try_statement] = STATE(2659),
    [sym_unsafe_statement] = STATE(2659),
    [sym_using_statement] = STATE(2659),
    [sym_foreach_statement] = STATE(2659),
    [sym_goto_statement] = STATE(2659),
    [sym_labeled_statement] = STATE(2659),
    [sym_if_statement] = STATE(2659),
    [sym_while_statement] = STATE(2659),
    [sym_local_declaration_statement] = STATE(2659),
    [sym_local_function_statement] = STATE(2659),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6347),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2847),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2659),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(39),
    [sym_preproc_endregion] = STATE(39),
    [sym_preproc_line] = STATE(39),
    [sym_preproc_pragma] = STATE(39),
    [sym_preproc_nullable] = STATE(39),
    [sym_preproc_error] = STATE(39),
    [sym_preproc_warning] = STATE(39),
    [sym_preproc_define] = STATE(39),
    [sym_preproc_undef] = STATE(39),
    [aux_sym_class_declaration_repeat1] = STATE(2935),
    [aux_sym_class_declaration_repeat2] = STATE(3094),
    [aux_sym_block_repeat1] = STATE(27),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(663),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(665),
    [anon_sym_unsafe] = ACTIONS(667),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(677),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_RBRACE] = ACTIONS(963),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(689),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(693),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(701),
    [anon_sym_unchecked] = ACTIONS(693),
    [anon_sym_continue] = ACTIONS(703),
    [anon_sym_do] = ACTIONS(705),
    [anon_sym_while] = ACTIONS(707),
    [anon_sym_for] = ACTIONS(709),
    [anon_sym_lock] = ACTIONS(711),
    [anon_sym_yield] = ACTIONS(713),
    [anon_sym_switch] = ACTIONS(715),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(739),
    [anon_sym_try] = ACTIONS(719),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(741),
    [anon_sym_foreach] = ACTIONS(723),
    [anon_sym_goto] = ACTIONS(725),
    [anon_sym_if] = ACTIONS(727),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(731),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [40] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2659),
    [sym_variable_declaration] = STATE(9524),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6870),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2732),
    [sym_break_statement] = STATE(2659),
    [sym_checked_statement] = STATE(2659),
    [sym_continue_statement] = STATE(2659),
    [sym_do_statement] = STATE(2659),
    [sym_empty_statement] = STATE(2659),
    [sym_expression_statement] = STATE(2659),
    [sym_fixed_statement] = STATE(2659),
    [sym_for_statement] = STATE(2659),
    [sym_return_statement] = STATE(2659),
    [sym_lock_statement] = STATE(2659),
    [sym_yield_statement] = STATE(2659),
    [sym_switch_statement] = STATE(2659),
    [sym_throw_statement] = STATE(2659),
    [sym_try_statement] = STATE(2659),
    [sym_unsafe_statement] = STATE(2659),
    [sym_using_statement] = STATE(2659),
    [sym_foreach_statement] = STATE(2659),
    [sym_goto_statement] = STATE(2659),
    [sym_labeled_statement] = STATE(2659),
    [sym_if_statement] = STATE(2659),
    [sym_while_statement] = STATE(2659),
    [sym_local_declaration_statement] = STATE(2659),
    [sym_local_function_statement] = STATE(2659),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6347),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2847),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2659),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(40),
    [sym_preproc_endregion] = STATE(40),
    [sym_preproc_line] = STATE(40),
    [sym_preproc_pragma] = STATE(40),
    [sym_preproc_nullable] = STATE(40),
    [sym_preproc_error] = STATE(40),
    [sym_preproc_warning] = STATE(40),
    [sym_preproc_define] = STATE(40),
    [sym_preproc_undef] = STATE(40),
    [aux_sym_class_declaration_repeat1] = STATE(2935),
    [aux_sym_class_declaration_repeat2] = STATE(3094),
    [aux_sym_block_repeat1] = STATE(27),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(663),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(665),
    [anon_sym_unsafe] = ACTIONS(667),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(677),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_RBRACE] = ACTIONS(965),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(689),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(693),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(701),
    [anon_sym_unchecked] = ACTIONS(693),
    [anon_sym_continue] = ACTIONS(703),
    [anon_sym_do] = ACTIONS(705),
    [anon_sym_while] = ACTIONS(707),
    [anon_sym_for] = ACTIONS(709),
    [anon_sym_lock] = ACTIONS(711),
    [anon_sym_yield] = ACTIONS(713),
    [anon_sym_switch] = ACTIONS(715),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(739),
    [anon_sym_try] = ACTIONS(719),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(741),
    [anon_sym_foreach] = ACTIONS(723),
    [anon_sym_goto] = ACTIONS(725),
    [anon_sym_if] = ACTIONS(727),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(731),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [41] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2659),
    [sym_variable_declaration] = STATE(9524),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6870),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2732),
    [sym_break_statement] = STATE(2659),
    [sym_checked_statement] = STATE(2659),
    [sym_continue_statement] = STATE(2659),
    [sym_do_statement] = STATE(2659),
    [sym_empty_statement] = STATE(2659),
    [sym_expression_statement] = STATE(2659),
    [sym_fixed_statement] = STATE(2659),
    [sym_for_statement] = STATE(2659),
    [sym_return_statement] = STATE(2659),
    [sym_lock_statement] = STATE(2659),
    [sym_yield_statement] = STATE(2659),
    [sym_switch_statement] = STATE(2659),
    [sym_throw_statement] = STATE(2659),
    [sym_try_statement] = STATE(2659),
    [sym_unsafe_statement] = STATE(2659),
    [sym_using_statement] = STATE(2659),
    [sym_foreach_statement] = STATE(2659),
    [sym_goto_statement] = STATE(2659),
    [sym_labeled_statement] = STATE(2659),
    [sym_if_statement] = STATE(2659),
    [sym_while_statement] = STATE(2659),
    [sym_local_declaration_statement] = STATE(2659),
    [sym_local_function_statement] = STATE(2659),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6347),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2847),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2659),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(41),
    [sym_preproc_endregion] = STATE(41),
    [sym_preproc_line] = STATE(41),
    [sym_preproc_pragma] = STATE(41),
    [sym_preproc_nullable] = STATE(41),
    [sym_preproc_error] = STATE(41),
    [sym_preproc_warning] = STATE(41),
    [sym_preproc_define] = STATE(41),
    [sym_preproc_undef] = STATE(41),
    [aux_sym_class_declaration_repeat1] = STATE(2935),
    [aux_sym_class_declaration_repeat2] = STATE(3094),
    [aux_sym_block_repeat1] = STATE(45),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(663),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(665),
    [anon_sym_unsafe] = ACTIONS(667),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(677),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_RBRACE] = ACTIONS(967),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(689),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(693),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(701),
    [anon_sym_unchecked] = ACTIONS(693),
    [anon_sym_continue] = ACTIONS(703),
    [anon_sym_do] = ACTIONS(705),
    [anon_sym_while] = ACTIONS(707),
    [anon_sym_for] = ACTIONS(709),
    [anon_sym_lock] = ACTIONS(711),
    [anon_sym_yield] = ACTIONS(713),
    [anon_sym_switch] = ACTIONS(715),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(739),
    [anon_sym_try] = ACTIONS(719),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(741),
    [anon_sym_foreach] = ACTIONS(723),
    [anon_sym_goto] = ACTIONS(725),
    [anon_sym_if] = ACTIONS(727),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(731),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [42] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2659),
    [sym_variable_declaration] = STATE(9524),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6870),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2732),
    [sym_break_statement] = STATE(2659),
    [sym_checked_statement] = STATE(2659),
    [sym_continue_statement] = STATE(2659),
    [sym_do_statement] = STATE(2659),
    [sym_empty_statement] = STATE(2659),
    [sym_expression_statement] = STATE(2659),
    [sym_fixed_statement] = STATE(2659),
    [sym_for_statement] = STATE(2659),
    [sym_return_statement] = STATE(2659),
    [sym_lock_statement] = STATE(2659),
    [sym_yield_statement] = STATE(2659),
    [sym_switch_statement] = STATE(2659),
    [sym_throw_statement] = STATE(2659),
    [sym_try_statement] = STATE(2659),
    [sym_unsafe_statement] = STATE(2659),
    [sym_using_statement] = STATE(2659),
    [sym_foreach_statement] = STATE(2659),
    [sym_goto_statement] = STATE(2659),
    [sym_labeled_statement] = STATE(2659),
    [sym_if_statement] = STATE(2659),
    [sym_while_statement] = STATE(2659),
    [sym_local_declaration_statement] = STATE(2659),
    [sym_local_function_statement] = STATE(2659),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6347),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2847),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2659),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(42),
    [sym_preproc_endregion] = STATE(42),
    [sym_preproc_line] = STATE(42),
    [sym_preproc_pragma] = STATE(42),
    [sym_preproc_nullable] = STATE(42),
    [sym_preproc_error] = STATE(42),
    [sym_preproc_warning] = STATE(42),
    [sym_preproc_define] = STATE(42),
    [sym_preproc_undef] = STATE(42),
    [aux_sym_class_declaration_repeat1] = STATE(2935),
    [aux_sym_class_declaration_repeat2] = STATE(3094),
    [aux_sym_block_repeat1] = STATE(27),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(663),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(665),
    [anon_sym_unsafe] = ACTIONS(667),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(677),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_RBRACE] = ACTIONS(969),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(689),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(693),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(701),
    [anon_sym_unchecked] = ACTIONS(693),
    [anon_sym_continue] = ACTIONS(703),
    [anon_sym_do] = ACTIONS(705),
    [anon_sym_while] = ACTIONS(707),
    [anon_sym_for] = ACTIONS(709),
    [anon_sym_lock] = ACTIONS(711),
    [anon_sym_yield] = ACTIONS(713),
    [anon_sym_switch] = ACTIONS(715),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(739),
    [anon_sym_try] = ACTIONS(719),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(741),
    [anon_sym_foreach] = ACTIONS(723),
    [anon_sym_goto] = ACTIONS(725),
    [anon_sym_if] = ACTIONS(727),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(731),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [43] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2659),
    [sym_variable_declaration] = STATE(9524),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6870),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2732),
    [sym_break_statement] = STATE(2659),
    [sym_checked_statement] = STATE(2659),
    [sym_continue_statement] = STATE(2659),
    [sym_do_statement] = STATE(2659),
    [sym_empty_statement] = STATE(2659),
    [sym_expression_statement] = STATE(2659),
    [sym_fixed_statement] = STATE(2659),
    [sym_for_statement] = STATE(2659),
    [sym_return_statement] = STATE(2659),
    [sym_lock_statement] = STATE(2659),
    [sym_yield_statement] = STATE(2659),
    [sym_switch_statement] = STATE(2659),
    [sym_throw_statement] = STATE(2659),
    [sym_try_statement] = STATE(2659),
    [sym_unsafe_statement] = STATE(2659),
    [sym_using_statement] = STATE(2659),
    [sym_foreach_statement] = STATE(2659),
    [sym_goto_statement] = STATE(2659),
    [sym_labeled_statement] = STATE(2659),
    [sym_if_statement] = STATE(2659),
    [sym_while_statement] = STATE(2659),
    [sym_local_declaration_statement] = STATE(2659),
    [sym_local_function_statement] = STATE(2659),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6347),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2847),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2659),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(43),
    [sym_preproc_endregion] = STATE(43),
    [sym_preproc_line] = STATE(43),
    [sym_preproc_pragma] = STATE(43),
    [sym_preproc_nullable] = STATE(43),
    [sym_preproc_error] = STATE(43),
    [sym_preproc_warning] = STATE(43),
    [sym_preproc_define] = STATE(43),
    [sym_preproc_undef] = STATE(43),
    [aux_sym_class_declaration_repeat1] = STATE(2935),
    [aux_sym_class_declaration_repeat2] = STATE(3094),
    [aux_sym_block_repeat1] = STATE(40),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(663),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(665),
    [anon_sym_unsafe] = ACTIONS(667),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(677),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_RBRACE] = ACTIONS(971),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(689),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(693),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(701),
    [anon_sym_unchecked] = ACTIONS(693),
    [anon_sym_continue] = ACTIONS(703),
    [anon_sym_do] = ACTIONS(705),
    [anon_sym_while] = ACTIONS(707),
    [anon_sym_for] = ACTIONS(709),
    [anon_sym_lock] = ACTIONS(711),
    [anon_sym_yield] = ACTIONS(713),
    [anon_sym_switch] = ACTIONS(715),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(739),
    [anon_sym_try] = ACTIONS(719),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(741),
    [anon_sym_foreach] = ACTIONS(723),
    [anon_sym_goto] = ACTIONS(725),
    [anon_sym_if] = ACTIONS(727),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(731),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [44] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2659),
    [sym_variable_declaration] = STATE(9524),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6870),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2732),
    [sym_break_statement] = STATE(2659),
    [sym_checked_statement] = STATE(2659),
    [sym_continue_statement] = STATE(2659),
    [sym_do_statement] = STATE(2659),
    [sym_empty_statement] = STATE(2659),
    [sym_expression_statement] = STATE(2659),
    [sym_fixed_statement] = STATE(2659),
    [sym_for_statement] = STATE(2659),
    [sym_return_statement] = STATE(2659),
    [sym_lock_statement] = STATE(2659),
    [sym_yield_statement] = STATE(2659),
    [sym_switch_statement] = STATE(2659),
    [sym_throw_statement] = STATE(2659),
    [sym_try_statement] = STATE(2659),
    [sym_unsafe_statement] = STATE(2659),
    [sym_using_statement] = STATE(2659),
    [sym_foreach_statement] = STATE(2659),
    [sym_goto_statement] = STATE(2659),
    [sym_labeled_statement] = STATE(2659),
    [sym_if_statement] = STATE(2659),
    [sym_while_statement] = STATE(2659),
    [sym_local_declaration_statement] = STATE(2659),
    [sym_local_function_statement] = STATE(2659),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6347),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2847),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2659),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(44),
    [sym_preproc_endregion] = STATE(44),
    [sym_preproc_line] = STATE(44),
    [sym_preproc_pragma] = STATE(44),
    [sym_preproc_nullable] = STATE(44),
    [sym_preproc_error] = STATE(44),
    [sym_preproc_warning] = STATE(44),
    [sym_preproc_define] = STATE(44),
    [sym_preproc_undef] = STATE(44),
    [aux_sym_class_declaration_repeat1] = STATE(2935),
    [aux_sym_class_declaration_repeat2] = STATE(3094),
    [aux_sym_block_repeat1] = STATE(48),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(663),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(665),
    [anon_sym_unsafe] = ACTIONS(667),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(677),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_RBRACE] = ACTIONS(973),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(689),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(693),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(701),
    [anon_sym_unchecked] = ACTIONS(693),
    [anon_sym_continue] = ACTIONS(703),
    [anon_sym_do] = ACTIONS(705),
    [anon_sym_while] = ACTIONS(707),
    [anon_sym_for] = ACTIONS(709),
    [anon_sym_lock] = ACTIONS(711),
    [anon_sym_yield] = ACTIONS(713),
    [anon_sym_switch] = ACTIONS(715),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(739),
    [anon_sym_try] = ACTIONS(719),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(741),
    [anon_sym_foreach] = ACTIONS(723),
    [anon_sym_goto] = ACTIONS(725),
    [anon_sym_if] = ACTIONS(727),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(731),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [45] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2659),
    [sym_variable_declaration] = STATE(9524),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6870),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2732),
    [sym_break_statement] = STATE(2659),
    [sym_checked_statement] = STATE(2659),
    [sym_continue_statement] = STATE(2659),
    [sym_do_statement] = STATE(2659),
    [sym_empty_statement] = STATE(2659),
    [sym_expression_statement] = STATE(2659),
    [sym_fixed_statement] = STATE(2659),
    [sym_for_statement] = STATE(2659),
    [sym_return_statement] = STATE(2659),
    [sym_lock_statement] = STATE(2659),
    [sym_yield_statement] = STATE(2659),
    [sym_switch_statement] = STATE(2659),
    [sym_throw_statement] = STATE(2659),
    [sym_try_statement] = STATE(2659),
    [sym_unsafe_statement] = STATE(2659),
    [sym_using_statement] = STATE(2659),
    [sym_foreach_statement] = STATE(2659),
    [sym_goto_statement] = STATE(2659),
    [sym_labeled_statement] = STATE(2659),
    [sym_if_statement] = STATE(2659),
    [sym_while_statement] = STATE(2659),
    [sym_local_declaration_statement] = STATE(2659),
    [sym_local_function_statement] = STATE(2659),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6347),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2847),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2659),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(45),
    [sym_preproc_endregion] = STATE(45),
    [sym_preproc_line] = STATE(45),
    [sym_preproc_pragma] = STATE(45),
    [sym_preproc_nullable] = STATE(45),
    [sym_preproc_error] = STATE(45),
    [sym_preproc_warning] = STATE(45),
    [sym_preproc_define] = STATE(45),
    [sym_preproc_undef] = STATE(45),
    [aux_sym_class_declaration_repeat1] = STATE(2935),
    [aux_sym_class_declaration_repeat2] = STATE(3094),
    [aux_sym_block_repeat1] = STATE(27),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(663),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(665),
    [anon_sym_unsafe] = ACTIONS(667),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(677),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_RBRACE] = ACTIONS(975),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(689),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(693),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(701),
    [anon_sym_unchecked] = ACTIONS(693),
    [anon_sym_continue] = ACTIONS(703),
    [anon_sym_do] = ACTIONS(705),
    [anon_sym_while] = ACTIONS(707),
    [anon_sym_for] = ACTIONS(709),
    [anon_sym_lock] = ACTIONS(711),
    [anon_sym_yield] = ACTIONS(713),
    [anon_sym_switch] = ACTIONS(715),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(739),
    [anon_sym_try] = ACTIONS(719),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(741),
    [anon_sym_foreach] = ACTIONS(723),
    [anon_sym_goto] = ACTIONS(725),
    [anon_sym_if] = ACTIONS(727),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(731),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [46] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2659),
    [sym_variable_declaration] = STATE(9524),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6870),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2732),
    [sym_break_statement] = STATE(2659),
    [sym_checked_statement] = STATE(2659),
    [sym_continue_statement] = STATE(2659),
    [sym_do_statement] = STATE(2659),
    [sym_empty_statement] = STATE(2659),
    [sym_expression_statement] = STATE(2659),
    [sym_fixed_statement] = STATE(2659),
    [sym_for_statement] = STATE(2659),
    [sym_return_statement] = STATE(2659),
    [sym_lock_statement] = STATE(2659),
    [sym_yield_statement] = STATE(2659),
    [sym_switch_statement] = STATE(2659),
    [sym_throw_statement] = STATE(2659),
    [sym_try_statement] = STATE(2659),
    [sym_unsafe_statement] = STATE(2659),
    [sym_using_statement] = STATE(2659),
    [sym_foreach_statement] = STATE(2659),
    [sym_goto_statement] = STATE(2659),
    [sym_labeled_statement] = STATE(2659),
    [sym_if_statement] = STATE(2659),
    [sym_while_statement] = STATE(2659),
    [sym_local_declaration_statement] = STATE(2659),
    [sym_local_function_statement] = STATE(2659),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6347),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2847),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2659),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(46),
    [sym_preproc_endregion] = STATE(46),
    [sym_preproc_line] = STATE(46),
    [sym_preproc_pragma] = STATE(46),
    [sym_preproc_nullable] = STATE(46),
    [sym_preproc_error] = STATE(46),
    [sym_preproc_warning] = STATE(46),
    [sym_preproc_define] = STATE(46),
    [sym_preproc_undef] = STATE(46),
    [aux_sym_class_declaration_repeat1] = STATE(2935),
    [aux_sym_class_declaration_repeat2] = STATE(3094),
    [aux_sym_block_repeat1] = STATE(39),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(663),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(665),
    [anon_sym_unsafe] = ACTIONS(667),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(677),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_RBRACE] = ACTIONS(977),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(689),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(693),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(701),
    [anon_sym_unchecked] = ACTIONS(693),
    [anon_sym_continue] = ACTIONS(703),
    [anon_sym_do] = ACTIONS(705),
    [anon_sym_while] = ACTIONS(707),
    [anon_sym_for] = ACTIONS(709),
    [anon_sym_lock] = ACTIONS(711),
    [anon_sym_yield] = ACTIONS(713),
    [anon_sym_switch] = ACTIONS(715),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(739),
    [anon_sym_try] = ACTIONS(719),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(741),
    [anon_sym_foreach] = ACTIONS(723),
    [anon_sym_goto] = ACTIONS(725),
    [anon_sym_if] = ACTIONS(727),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(731),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [47] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2659),
    [sym_variable_declaration] = STATE(9524),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6870),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2732),
    [sym_break_statement] = STATE(2659),
    [sym_checked_statement] = STATE(2659),
    [sym_continue_statement] = STATE(2659),
    [sym_do_statement] = STATE(2659),
    [sym_empty_statement] = STATE(2659),
    [sym_expression_statement] = STATE(2659),
    [sym_fixed_statement] = STATE(2659),
    [sym_for_statement] = STATE(2659),
    [sym_return_statement] = STATE(2659),
    [sym_lock_statement] = STATE(2659),
    [sym_yield_statement] = STATE(2659),
    [sym_switch_statement] = STATE(2659),
    [sym_throw_statement] = STATE(2659),
    [sym_try_statement] = STATE(2659),
    [sym_unsafe_statement] = STATE(2659),
    [sym_using_statement] = STATE(2659),
    [sym_foreach_statement] = STATE(2659),
    [sym_goto_statement] = STATE(2659),
    [sym_labeled_statement] = STATE(2659),
    [sym_if_statement] = STATE(2659),
    [sym_while_statement] = STATE(2659),
    [sym_local_declaration_statement] = STATE(2659),
    [sym_local_function_statement] = STATE(2659),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6347),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2847),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2659),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(47),
    [sym_preproc_endregion] = STATE(47),
    [sym_preproc_line] = STATE(47),
    [sym_preproc_pragma] = STATE(47),
    [sym_preproc_nullable] = STATE(47),
    [sym_preproc_error] = STATE(47),
    [sym_preproc_warning] = STATE(47),
    [sym_preproc_define] = STATE(47),
    [sym_preproc_undef] = STATE(47),
    [aux_sym_class_declaration_repeat1] = STATE(2935),
    [aux_sym_class_declaration_repeat2] = STATE(3094),
    [aux_sym_block_repeat1] = STATE(55),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(663),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(665),
    [anon_sym_unsafe] = ACTIONS(667),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(677),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_RBRACE] = ACTIONS(979),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(689),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(693),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(701),
    [anon_sym_unchecked] = ACTIONS(693),
    [anon_sym_continue] = ACTIONS(703),
    [anon_sym_do] = ACTIONS(705),
    [anon_sym_while] = ACTIONS(707),
    [anon_sym_for] = ACTIONS(709),
    [anon_sym_lock] = ACTIONS(711),
    [anon_sym_yield] = ACTIONS(713),
    [anon_sym_switch] = ACTIONS(715),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(739),
    [anon_sym_try] = ACTIONS(719),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(741),
    [anon_sym_foreach] = ACTIONS(723),
    [anon_sym_goto] = ACTIONS(725),
    [anon_sym_if] = ACTIONS(727),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(731),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [48] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2659),
    [sym_variable_declaration] = STATE(9524),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6870),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2732),
    [sym_break_statement] = STATE(2659),
    [sym_checked_statement] = STATE(2659),
    [sym_continue_statement] = STATE(2659),
    [sym_do_statement] = STATE(2659),
    [sym_empty_statement] = STATE(2659),
    [sym_expression_statement] = STATE(2659),
    [sym_fixed_statement] = STATE(2659),
    [sym_for_statement] = STATE(2659),
    [sym_return_statement] = STATE(2659),
    [sym_lock_statement] = STATE(2659),
    [sym_yield_statement] = STATE(2659),
    [sym_switch_statement] = STATE(2659),
    [sym_throw_statement] = STATE(2659),
    [sym_try_statement] = STATE(2659),
    [sym_unsafe_statement] = STATE(2659),
    [sym_using_statement] = STATE(2659),
    [sym_foreach_statement] = STATE(2659),
    [sym_goto_statement] = STATE(2659),
    [sym_labeled_statement] = STATE(2659),
    [sym_if_statement] = STATE(2659),
    [sym_while_statement] = STATE(2659),
    [sym_local_declaration_statement] = STATE(2659),
    [sym_local_function_statement] = STATE(2659),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6347),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2847),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2659),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(48),
    [sym_preproc_endregion] = STATE(48),
    [sym_preproc_line] = STATE(48),
    [sym_preproc_pragma] = STATE(48),
    [sym_preproc_nullable] = STATE(48),
    [sym_preproc_error] = STATE(48),
    [sym_preproc_warning] = STATE(48),
    [sym_preproc_define] = STATE(48),
    [sym_preproc_undef] = STATE(48),
    [aux_sym_class_declaration_repeat1] = STATE(2935),
    [aux_sym_class_declaration_repeat2] = STATE(3094),
    [aux_sym_block_repeat1] = STATE(27),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(663),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(665),
    [anon_sym_unsafe] = ACTIONS(667),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(677),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_RBRACE] = ACTIONS(981),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(689),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(693),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(701),
    [anon_sym_unchecked] = ACTIONS(693),
    [anon_sym_continue] = ACTIONS(703),
    [anon_sym_do] = ACTIONS(705),
    [anon_sym_while] = ACTIONS(707),
    [anon_sym_for] = ACTIONS(709),
    [anon_sym_lock] = ACTIONS(711),
    [anon_sym_yield] = ACTIONS(713),
    [anon_sym_switch] = ACTIONS(715),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(739),
    [anon_sym_try] = ACTIONS(719),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(741),
    [anon_sym_foreach] = ACTIONS(723),
    [anon_sym_goto] = ACTIONS(725),
    [anon_sym_if] = ACTIONS(727),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(731),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [49] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2659),
    [sym_variable_declaration] = STATE(9524),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6870),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2732),
    [sym_break_statement] = STATE(2659),
    [sym_checked_statement] = STATE(2659),
    [sym_continue_statement] = STATE(2659),
    [sym_do_statement] = STATE(2659),
    [sym_empty_statement] = STATE(2659),
    [sym_expression_statement] = STATE(2659),
    [sym_fixed_statement] = STATE(2659),
    [sym_for_statement] = STATE(2659),
    [sym_return_statement] = STATE(2659),
    [sym_lock_statement] = STATE(2659),
    [sym_yield_statement] = STATE(2659),
    [sym_switch_statement] = STATE(2659),
    [sym_throw_statement] = STATE(2659),
    [sym_try_statement] = STATE(2659),
    [sym_unsafe_statement] = STATE(2659),
    [sym_using_statement] = STATE(2659),
    [sym_foreach_statement] = STATE(2659),
    [sym_goto_statement] = STATE(2659),
    [sym_labeled_statement] = STATE(2659),
    [sym_if_statement] = STATE(2659),
    [sym_while_statement] = STATE(2659),
    [sym_local_declaration_statement] = STATE(2659),
    [sym_local_function_statement] = STATE(2659),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6347),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2847),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2659),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(49),
    [sym_preproc_endregion] = STATE(49),
    [sym_preproc_line] = STATE(49),
    [sym_preproc_pragma] = STATE(49),
    [sym_preproc_nullable] = STATE(49),
    [sym_preproc_error] = STATE(49),
    [sym_preproc_warning] = STATE(49),
    [sym_preproc_define] = STATE(49),
    [sym_preproc_undef] = STATE(49),
    [aux_sym_class_declaration_repeat1] = STATE(2935),
    [aux_sym_class_declaration_repeat2] = STATE(3094),
    [aux_sym_block_repeat1] = STATE(27),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(663),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(665),
    [anon_sym_unsafe] = ACTIONS(667),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(677),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_RBRACE] = ACTIONS(983),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(689),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(693),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(701),
    [anon_sym_unchecked] = ACTIONS(693),
    [anon_sym_continue] = ACTIONS(703),
    [anon_sym_do] = ACTIONS(705),
    [anon_sym_while] = ACTIONS(707),
    [anon_sym_for] = ACTIONS(709),
    [anon_sym_lock] = ACTIONS(711),
    [anon_sym_yield] = ACTIONS(713),
    [anon_sym_switch] = ACTIONS(715),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(739),
    [anon_sym_try] = ACTIONS(719),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(741),
    [anon_sym_foreach] = ACTIONS(723),
    [anon_sym_goto] = ACTIONS(725),
    [anon_sym_if] = ACTIONS(727),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(731),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [50] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2659),
    [sym_variable_declaration] = STATE(9524),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6870),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2732),
    [sym_break_statement] = STATE(2659),
    [sym_checked_statement] = STATE(2659),
    [sym_continue_statement] = STATE(2659),
    [sym_do_statement] = STATE(2659),
    [sym_empty_statement] = STATE(2659),
    [sym_expression_statement] = STATE(2659),
    [sym_fixed_statement] = STATE(2659),
    [sym_for_statement] = STATE(2659),
    [sym_return_statement] = STATE(2659),
    [sym_lock_statement] = STATE(2659),
    [sym_yield_statement] = STATE(2659),
    [sym_switch_statement] = STATE(2659),
    [sym_throw_statement] = STATE(2659),
    [sym_try_statement] = STATE(2659),
    [sym_unsafe_statement] = STATE(2659),
    [sym_using_statement] = STATE(2659),
    [sym_foreach_statement] = STATE(2659),
    [sym_goto_statement] = STATE(2659),
    [sym_labeled_statement] = STATE(2659),
    [sym_if_statement] = STATE(2659),
    [sym_while_statement] = STATE(2659),
    [sym_local_declaration_statement] = STATE(2659),
    [sym_local_function_statement] = STATE(2659),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6347),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2847),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2659),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(50),
    [sym_preproc_endregion] = STATE(50),
    [sym_preproc_line] = STATE(50),
    [sym_preproc_pragma] = STATE(50),
    [sym_preproc_nullable] = STATE(50),
    [sym_preproc_error] = STATE(50),
    [sym_preproc_warning] = STATE(50),
    [sym_preproc_define] = STATE(50),
    [sym_preproc_undef] = STATE(50),
    [aux_sym_class_declaration_repeat1] = STATE(2935),
    [aux_sym_class_declaration_repeat2] = STATE(3094),
    [aux_sym_block_repeat1] = STATE(51),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(663),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(665),
    [anon_sym_unsafe] = ACTIONS(667),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(677),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_RBRACE] = ACTIONS(985),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(689),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(693),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(701),
    [anon_sym_unchecked] = ACTIONS(693),
    [anon_sym_continue] = ACTIONS(703),
    [anon_sym_do] = ACTIONS(705),
    [anon_sym_while] = ACTIONS(707),
    [anon_sym_for] = ACTIONS(709),
    [anon_sym_lock] = ACTIONS(711),
    [anon_sym_yield] = ACTIONS(713),
    [anon_sym_switch] = ACTIONS(715),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(739),
    [anon_sym_try] = ACTIONS(719),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(741),
    [anon_sym_foreach] = ACTIONS(723),
    [anon_sym_goto] = ACTIONS(725),
    [anon_sym_if] = ACTIONS(727),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(731),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [51] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2659),
    [sym_variable_declaration] = STATE(9524),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6870),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2732),
    [sym_break_statement] = STATE(2659),
    [sym_checked_statement] = STATE(2659),
    [sym_continue_statement] = STATE(2659),
    [sym_do_statement] = STATE(2659),
    [sym_empty_statement] = STATE(2659),
    [sym_expression_statement] = STATE(2659),
    [sym_fixed_statement] = STATE(2659),
    [sym_for_statement] = STATE(2659),
    [sym_return_statement] = STATE(2659),
    [sym_lock_statement] = STATE(2659),
    [sym_yield_statement] = STATE(2659),
    [sym_switch_statement] = STATE(2659),
    [sym_throw_statement] = STATE(2659),
    [sym_try_statement] = STATE(2659),
    [sym_unsafe_statement] = STATE(2659),
    [sym_using_statement] = STATE(2659),
    [sym_foreach_statement] = STATE(2659),
    [sym_goto_statement] = STATE(2659),
    [sym_labeled_statement] = STATE(2659),
    [sym_if_statement] = STATE(2659),
    [sym_while_statement] = STATE(2659),
    [sym_local_declaration_statement] = STATE(2659),
    [sym_local_function_statement] = STATE(2659),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6347),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2847),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2659),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(51),
    [sym_preproc_endregion] = STATE(51),
    [sym_preproc_line] = STATE(51),
    [sym_preproc_pragma] = STATE(51),
    [sym_preproc_nullable] = STATE(51),
    [sym_preproc_error] = STATE(51),
    [sym_preproc_warning] = STATE(51),
    [sym_preproc_define] = STATE(51),
    [sym_preproc_undef] = STATE(51),
    [aux_sym_class_declaration_repeat1] = STATE(2935),
    [aux_sym_class_declaration_repeat2] = STATE(3094),
    [aux_sym_block_repeat1] = STATE(27),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(663),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(665),
    [anon_sym_unsafe] = ACTIONS(667),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(677),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_RBRACE] = ACTIONS(987),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(689),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(693),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(701),
    [anon_sym_unchecked] = ACTIONS(693),
    [anon_sym_continue] = ACTIONS(703),
    [anon_sym_do] = ACTIONS(705),
    [anon_sym_while] = ACTIONS(707),
    [anon_sym_for] = ACTIONS(709),
    [anon_sym_lock] = ACTIONS(711),
    [anon_sym_yield] = ACTIONS(713),
    [anon_sym_switch] = ACTIONS(715),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(739),
    [anon_sym_try] = ACTIONS(719),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(741),
    [anon_sym_foreach] = ACTIONS(723),
    [anon_sym_goto] = ACTIONS(725),
    [anon_sym_if] = ACTIONS(727),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(731),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [52] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2659),
    [sym_variable_declaration] = STATE(9524),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6870),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2732),
    [sym_break_statement] = STATE(2659),
    [sym_checked_statement] = STATE(2659),
    [sym_continue_statement] = STATE(2659),
    [sym_do_statement] = STATE(2659),
    [sym_empty_statement] = STATE(2659),
    [sym_expression_statement] = STATE(2659),
    [sym_fixed_statement] = STATE(2659),
    [sym_for_statement] = STATE(2659),
    [sym_return_statement] = STATE(2659),
    [sym_lock_statement] = STATE(2659),
    [sym_yield_statement] = STATE(2659),
    [sym_switch_statement] = STATE(2659),
    [sym_throw_statement] = STATE(2659),
    [sym_try_statement] = STATE(2659),
    [sym_unsafe_statement] = STATE(2659),
    [sym_using_statement] = STATE(2659),
    [sym_foreach_statement] = STATE(2659),
    [sym_goto_statement] = STATE(2659),
    [sym_labeled_statement] = STATE(2659),
    [sym_if_statement] = STATE(2659),
    [sym_while_statement] = STATE(2659),
    [sym_local_declaration_statement] = STATE(2659),
    [sym_local_function_statement] = STATE(2659),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6347),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2847),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2659),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(52),
    [sym_preproc_endregion] = STATE(52),
    [sym_preproc_line] = STATE(52),
    [sym_preproc_pragma] = STATE(52),
    [sym_preproc_nullable] = STATE(52),
    [sym_preproc_error] = STATE(52),
    [sym_preproc_warning] = STATE(52),
    [sym_preproc_define] = STATE(52),
    [sym_preproc_undef] = STATE(52),
    [aux_sym_class_declaration_repeat1] = STATE(2935),
    [aux_sym_class_declaration_repeat2] = STATE(3094),
    [aux_sym_block_repeat1] = STATE(42),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(663),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(665),
    [anon_sym_unsafe] = ACTIONS(667),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(677),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_RBRACE] = ACTIONS(989),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(689),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(693),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(701),
    [anon_sym_unchecked] = ACTIONS(693),
    [anon_sym_continue] = ACTIONS(703),
    [anon_sym_do] = ACTIONS(705),
    [anon_sym_while] = ACTIONS(707),
    [anon_sym_for] = ACTIONS(709),
    [anon_sym_lock] = ACTIONS(711),
    [anon_sym_yield] = ACTIONS(713),
    [anon_sym_switch] = ACTIONS(715),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(739),
    [anon_sym_try] = ACTIONS(719),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(741),
    [anon_sym_foreach] = ACTIONS(723),
    [anon_sym_goto] = ACTIONS(725),
    [anon_sym_if] = ACTIONS(727),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(731),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [53] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2659),
    [sym_variable_declaration] = STATE(9524),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6870),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2732),
    [sym_break_statement] = STATE(2659),
    [sym_checked_statement] = STATE(2659),
    [sym_continue_statement] = STATE(2659),
    [sym_do_statement] = STATE(2659),
    [sym_empty_statement] = STATE(2659),
    [sym_expression_statement] = STATE(2659),
    [sym_fixed_statement] = STATE(2659),
    [sym_for_statement] = STATE(2659),
    [sym_return_statement] = STATE(2659),
    [sym_lock_statement] = STATE(2659),
    [sym_yield_statement] = STATE(2659),
    [sym_switch_statement] = STATE(2659),
    [sym_throw_statement] = STATE(2659),
    [sym_try_statement] = STATE(2659),
    [sym_unsafe_statement] = STATE(2659),
    [sym_using_statement] = STATE(2659),
    [sym_foreach_statement] = STATE(2659),
    [sym_goto_statement] = STATE(2659),
    [sym_labeled_statement] = STATE(2659),
    [sym_if_statement] = STATE(2659),
    [sym_while_statement] = STATE(2659),
    [sym_local_declaration_statement] = STATE(2659),
    [sym_local_function_statement] = STATE(2659),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6347),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2847),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2659),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(53),
    [sym_preproc_endregion] = STATE(53),
    [sym_preproc_line] = STATE(53),
    [sym_preproc_pragma] = STATE(53),
    [sym_preproc_nullable] = STATE(53),
    [sym_preproc_error] = STATE(53),
    [sym_preproc_warning] = STATE(53),
    [sym_preproc_define] = STATE(53),
    [sym_preproc_undef] = STATE(53),
    [aux_sym_class_declaration_repeat1] = STATE(2935),
    [aux_sym_class_declaration_repeat2] = STATE(3094),
    [aux_sym_block_repeat1] = STATE(54),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(663),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(665),
    [anon_sym_unsafe] = ACTIONS(667),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(677),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_RBRACE] = ACTIONS(991),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(689),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(693),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(701),
    [anon_sym_unchecked] = ACTIONS(693),
    [anon_sym_continue] = ACTIONS(703),
    [anon_sym_do] = ACTIONS(705),
    [anon_sym_while] = ACTIONS(707),
    [anon_sym_for] = ACTIONS(709),
    [anon_sym_lock] = ACTIONS(711),
    [anon_sym_yield] = ACTIONS(713),
    [anon_sym_switch] = ACTIONS(715),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(739),
    [anon_sym_try] = ACTIONS(719),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(741),
    [anon_sym_foreach] = ACTIONS(723),
    [anon_sym_goto] = ACTIONS(725),
    [anon_sym_if] = ACTIONS(727),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(731),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [54] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2659),
    [sym_variable_declaration] = STATE(9524),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6870),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2732),
    [sym_break_statement] = STATE(2659),
    [sym_checked_statement] = STATE(2659),
    [sym_continue_statement] = STATE(2659),
    [sym_do_statement] = STATE(2659),
    [sym_empty_statement] = STATE(2659),
    [sym_expression_statement] = STATE(2659),
    [sym_fixed_statement] = STATE(2659),
    [sym_for_statement] = STATE(2659),
    [sym_return_statement] = STATE(2659),
    [sym_lock_statement] = STATE(2659),
    [sym_yield_statement] = STATE(2659),
    [sym_switch_statement] = STATE(2659),
    [sym_throw_statement] = STATE(2659),
    [sym_try_statement] = STATE(2659),
    [sym_unsafe_statement] = STATE(2659),
    [sym_using_statement] = STATE(2659),
    [sym_foreach_statement] = STATE(2659),
    [sym_goto_statement] = STATE(2659),
    [sym_labeled_statement] = STATE(2659),
    [sym_if_statement] = STATE(2659),
    [sym_while_statement] = STATE(2659),
    [sym_local_declaration_statement] = STATE(2659),
    [sym_local_function_statement] = STATE(2659),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6347),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2847),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2659),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(54),
    [sym_preproc_endregion] = STATE(54),
    [sym_preproc_line] = STATE(54),
    [sym_preproc_pragma] = STATE(54),
    [sym_preproc_nullable] = STATE(54),
    [sym_preproc_error] = STATE(54),
    [sym_preproc_warning] = STATE(54),
    [sym_preproc_define] = STATE(54),
    [sym_preproc_undef] = STATE(54),
    [aux_sym_class_declaration_repeat1] = STATE(2935),
    [aux_sym_class_declaration_repeat2] = STATE(3094),
    [aux_sym_block_repeat1] = STATE(27),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(663),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(665),
    [anon_sym_unsafe] = ACTIONS(667),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(677),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_RBRACE] = ACTIONS(993),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(689),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(693),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(701),
    [anon_sym_unchecked] = ACTIONS(693),
    [anon_sym_continue] = ACTIONS(703),
    [anon_sym_do] = ACTIONS(705),
    [anon_sym_while] = ACTIONS(707),
    [anon_sym_for] = ACTIONS(709),
    [anon_sym_lock] = ACTIONS(711),
    [anon_sym_yield] = ACTIONS(713),
    [anon_sym_switch] = ACTIONS(715),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(739),
    [anon_sym_try] = ACTIONS(719),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(741),
    [anon_sym_foreach] = ACTIONS(723),
    [anon_sym_goto] = ACTIONS(725),
    [anon_sym_if] = ACTIONS(727),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(731),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [55] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2659),
    [sym_variable_declaration] = STATE(9524),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6870),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2732),
    [sym_break_statement] = STATE(2659),
    [sym_checked_statement] = STATE(2659),
    [sym_continue_statement] = STATE(2659),
    [sym_do_statement] = STATE(2659),
    [sym_empty_statement] = STATE(2659),
    [sym_expression_statement] = STATE(2659),
    [sym_fixed_statement] = STATE(2659),
    [sym_for_statement] = STATE(2659),
    [sym_return_statement] = STATE(2659),
    [sym_lock_statement] = STATE(2659),
    [sym_yield_statement] = STATE(2659),
    [sym_switch_statement] = STATE(2659),
    [sym_throw_statement] = STATE(2659),
    [sym_try_statement] = STATE(2659),
    [sym_unsafe_statement] = STATE(2659),
    [sym_using_statement] = STATE(2659),
    [sym_foreach_statement] = STATE(2659),
    [sym_goto_statement] = STATE(2659),
    [sym_labeled_statement] = STATE(2659),
    [sym_if_statement] = STATE(2659),
    [sym_while_statement] = STATE(2659),
    [sym_local_declaration_statement] = STATE(2659),
    [sym_local_function_statement] = STATE(2659),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6347),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2847),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2659),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(55),
    [sym_preproc_endregion] = STATE(55),
    [sym_preproc_line] = STATE(55),
    [sym_preproc_pragma] = STATE(55),
    [sym_preproc_nullable] = STATE(55),
    [sym_preproc_error] = STATE(55),
    [sym_preproc_warning] = STATE(55),
    [sym_preproc_define] = STATE(55),
    [sym_preproc_undef] = STATE(55),
    [aux_sym_class_declaration_repeat1] = STATE(2935),
    [aux_sym_class_declaration_repeat2] = STATE(3094),
    [aux_sym_block_repeat1] = STATE(27),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(663),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(665),
    [anon_sym_unsafe] = ACTIONS(667),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(677),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_RBRACE] = ACTIONS(995),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(689),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(693),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(701),
    [anon_sym_unchecked] = ACTIONS(693),
    [anon_sym_continue] = ACTIONS(703),
    [anon_sym_do] = ACTIONS(705),
    [anon_sym_while] = ACTIONS(707),
    [anon_sym_for] = ACTIONS(709),
    [anon_sym_lock] = ACTIONS(711),
    [anon_sym_yield] = ACTIONS(713),
    [anon_sym_switch] = ACTIONS(715),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(739),
    [anon_sym_try] = ACTIONS(719),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(741),
    [anon_sym_foreach] = ACTIONS(723),
    [anon_sym_goto] = ACTIONS(725),
    [anon_sym_if] = ACTIONS(727),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(731),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [56] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2659),
    [sym_variable_declaration] = STATE(9524),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6870),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2732),
    [sym_break_statement] = STATE(2659),
    [sym_checked_statement] = STATE(2659),
    [sym_continue_statement] = STATE(2659),
    [sym_do_statement] = STATE(2659),
    [sym_empty_statement] = STATE(2659),
    [sym_expression_statement] = STATE(2659),
    [sym_fixed_statement] = STATE(2659),
    [sym_for_statement] = STATE(2659),
    [sym_return_statement] = STATE(2659),
    [sym_lock_statement] = STATE(2659),
    [sym_yield_statement] = STATE(2659),
    [sym_switch_statement] = STATE(2659),
    [sym_throw_statement] = STATE(2659),
    [sym_try_statement] = STATE(2659),
    [sym_unsafe_statement] = STATE(2659),
    [sym_using_statement] = STATE(2659),
    [sym_foreach_statement] = STATE(2659),
    [sym_goto_statement] = STATE(2659),
    [sym_labeled_statement] = STATE(2659),
    [sym_if_statement] = STATE(2659),
    [sym_while_statement] = STATE(2659),
    [sym_local_declaration_statement] = STATE(2659),
    [sym_local_function_statement] = STATE(2659),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6347),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2847),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2659),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(56),
    [sym_preproc_endregion] = STATE(56),
    [sym_preproc_line] = STATE(56),
    [sym_preproc_pragma] = STATE(56),
    [sym_preproc_nullable] = STATE(56),
    [sym_preproc_error] = STATE(56),
    [sym_preproc_warning] = STATE(56),
    [sym_preproc_define] = STATE(56),
    [sym_preproc_undef] = STATE(56),
    [aux_sym_class_declaration_repeat1] = STATE(2935),
    [aux_sym_class_declaration_repeat2] = STATE(3094),
    [aux_sym_block_repeat1] = STATE(57),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(663),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(665),
    [anon_sym_unsafe] = ACTIONS(667),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(677),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_RBRACE] = ACTIONS(997),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(689),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(693),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(701),
    [anon_sym_unchecked] = ACTIONS(693),
    [anon_sym_continue] = ACTIONS(703),
    [anon_sym_do] = ACTIONS(705),
    [anon_sym_while] = ACTIONS(707),
    [anon_sym_for] = ACTIONS(709),
    [anon_sym_lock] = ACTIONS(711),
    [anon_sym_yield] = ACTIONS(713),
    [anon_sym_switch] = ACTIONS(715),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(739),
    [anon_sym_try] = ACTIONS(719),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(741),
    [anon_sym_foreach] = ACTIONS(723),
    [anon_sym_goto] = ACTIONS(725),
    [anon_sym_if] = ACTIONS(727),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(731),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [57] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2659),
    [sym_variable_declaration] = STATE(9524),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6870),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2732),
    [sym_break_statement] = STATE(2659),
    [sym_checked_statement] = STATE(2659),
    [sym_continue_statement] = STATE(2659),
    [sym_do_statement] = STATE(2659),
    [sym_empty_statement] = STATE(2659),
    [sym_expression_statement] = STATE(2659),
    [sym_fixed_statement] = STATE(2659),
    [sym_for_statement] = STATE(2659),
    [sym_return_statement] = STATE(2659),
    [sym_lock_statement] = STATE(2659),
    [sym_yield_statement] = STATE(2659),
    [sym_switch_statement] = STATE(2659),
    [sym_throw_statement] = STATE(2659),
    [sym_try_statement] = STATE(2659),
    [sym_unsafe_statement] = STATE(2659),
    [sym_using_statement] = STATE(2659),
    [sym_foreach_statement] = STATE(2659),
    [sym_goto_statement] = STATE(2659),
    [sym_labeled_statement] = STATE(2659),
    [sym_if_statement] = STATE(2659),
    [sym_while_statement] = STATE(2659),
    [sym_local_declaration_statement] = STATE(2659),
    [sym_local_function_statement] = STATE(2659),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6347),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2847),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2659),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(57),
    [sym_preproc_endregion] = STATE(57),
    [sym_preproc_line] = STATE(57),
    [sym_preproc_pragma] = STATE(57),
    [sym_preproc_nullable] = STATE(57),
    [sym_preproc_error] = STATE(57),
    [sym_preproc_warning] = STATE(57),
    [sym_preproc_define] = STATE(57),
    [sym_preproc_undef] = STATE(57),
    [aux_sym_class_declaration_repeat1] = STATE(2935),
    [aux_sym_class_declaration_repeat2] = STATE(3094),
    [aux_sym_block_repeat1] = STATE(27),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(663),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(665),
    [anon_sym_unsafe] = ACTIONS(667),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(677),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_RBRACE] = ACTIONS(999),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(689),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(693),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(701),
    [anon_sym_unchecked] = ACTIONS(693),
    [anon_sym_continue] = ACTIONS(703),
    [anon_sym_do] = ACTIONS(705),
    [anon_sym_while] = ACTIONS(707),
    [anon_sym_for] = ACTIONS(709),
    [anon_sym_lock] = ACTIONS(711),
    [anon_sym_yield] = ACTIONS(713),
    [anon_sym_switch] = ACTIONS(715),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(739),
    [anon_sym_try] = ACTIONS(719),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(741),
    [anon_sym_foreach] = ACTIONS(723),
    [anon_sym_goto] = ACTIONS(725),
    [anon_sym_if] = ACTIONS(727),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(731),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [58] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2659),
    [sym_variable_declaration] = STATE(9524),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6870),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2732),
    [sym_break_statement] = STATE(2659),
    [sym_checked_statement] = STATE(2659),
    [sym_continue_statement] = STATE(2659),
    [sym_do_statement] = STATE(2659),
    [sym_empty_statement] = STATE(2659),
    [sym_expression_statement] = STATE(2659),
    [sym_fixed_statement] = STATE(2659),
    [sym_for_statement] = STATE(2659),
    [sym_return_statement] = STATE(2659),
    [sym_lock_statement] = STATE(2659),
    [sym_yield_statement] = STATE(2659),
    [sym_switch_statement] = STATE(2659),
    [sym_throw_statement] = STATE(2659),
    [sym_try_statement] = STATE(2659),
    [sym_unsafe_statement] = STATE(2659),
    [sym_using_statement] = STATE(2659),
    [sym_foreach_statement] = STATE(2659),
    [sym_goto_statement] = STATE(2659),
    [sym_labeled_statement] = STATE(2659),
    [sym_if_statement] = STATE(2659),
    [sym_while_statement] = STATE(2659),
    [sym_local_declaration_statement] = STATE(2659),
    [sym_local_function_statement] = STATE(2659),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6347),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2847),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2659),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(58),
    [sym_preproc_endregion] = STATE(58),
    [sym_preproc_line] = STATE(58),
    [sym_preproc_pragma] = STATE(58),
    [sym_preproc_nullable] = STATE(58),
    [sym_preproc_error] = STATE(58),
    [sym_preproc_warning] = STATE(58),
    [sym_preproc_define] = STATE(58),
    [sym_preproc_undef] = STATE(58),
    [aux_sym_class_declaration_repeat1] = STATE(2935),
    [aux_sym_class_declaration_repeat2] = STATE(3094),
    [aux_sym_block_repeat1] = STATE(59),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(663),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(665),
    [anon_sym_unsafe] = ACTIONS(667),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(677),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_RBRACE] = ACTIONS(1001),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(689),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(693),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(701),
    [anon_sym_unchecked] = ACTIONS(693),
    [anon_sym_continue] = ACTIONS(703),
    [anon_sym_do] = ACTIONS(705),
    [anon_sym_while] = ACTIONS(707),
    [anon_sym_for] = ACTIONS(709),
    [anon_sym_lock] = ACTIONS(711),
    [anon_sym_yield] = ACTIONS(713),
    [anon_sym_switch] = ACTIONS(715),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(739),
    [anon_sym_try] = ACTIONS(719),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(741),
    [anon_sym_foreach] = ACTIONS(723),
    [anon_sym_goto] = ACTIONS(725),
    [anon_sym_if] = ACTIONS(727),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(731),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [59] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2659),
    [sym_variable_declaration] = STATE(9524),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6870),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2732),
    [sym_break_statement] = STATE(2659),
    [sym_checked_statement] = STATE(2659),
    [sym_continue_statement] = STATE(2659),
    [sym_do_statement] = STATE(2659),
    [sym_empty_statement] = STATE(2659),
    [sym_expression_statement] = STATE(2659),
    [sym_fixed_statement] = STATE(2659),
    [sym_for_statement] = STATE(2659),
    [sym_return_statement] = STATE(2659),
    [sym_lock_statement] = STATE(2659),
    [sym_yield_statement] = STATE(2659),
    [sym_switch_statement] = STATE(2659),
    [sym_throw_statement] = STATE(2659),
    [sym_try_statement] = STATE(2659),
    [sym_unsafe_statement] = STATE(2659),
    [sym_using_statement] = STATE(2659),
    [sym_foreach_statement] = STATE(2659),
    [sym_goto_statement] = STATE(2659),
    [sym_labeled_statement] = STATE(2659),
    [sym_if_statement] = STATE(2659),
    [sym_while_statement] = STATE(2659),
    [sym_local_declaration_statement] = STATE(2659),
    [sym_local_function_statement] = STATE(2659),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6347),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2847),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2659),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(59),
    [sym_preproc_endregion] = STATE(59),
    [sym_preproc_line] = STATE(59),
    [sym_preproc_pragma] = STATE(59),
    [sym_preproc_nullable] = STATE(59),
    [sym_preproc_error] = STATE(59),
    [sym_preproc_warning] = STATE(59),
    [sym_preproc_define] = STATE(59),
    [sym_preproc_undef] = STATE(59),
    [aux_sym_class_declaration_repeat1] = STATE(2935),
    [aux_sym_class_declaration_repeat2] = STATE(3094),
    [aux_sym_block_repeat1] = STATE(27),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(663),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(665),
    [anon_sym_unsafe] = ACTIONS(667),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(677),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_RBRACE] = ACTIONS(1003),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(689),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(693),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(701),
    [anon_sym_unchecked] = ACTIONS(693),
    [anon_sym_continue] = ACTIONS(703),
    [anon_sym_do] = ACTIONS(705),
    [anon_sym_while] = ACTIONS(707),
    [anon_sym_for] = ACTIONS(709),
    [anon_sym_lock] = ACTIONS(711),
    [anon_sym_yield] = ACTIONS(713),
    [anon_sym_switch] = ACTIONS(715),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(739),
    [anon_sym_try] = ACTIONS(719),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(741),
    [anon_sym_foreach] = ACTIONS(723),
    [anon_sym_goto] = ACTIONS(725),
    [anon_sym_if] = ACTIONS(727),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(731),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [60] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2493),
    [sym_variable_declaration] = STATE(9635),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6854),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2462),
    [sym_break_statement] = STATE(2493),
    [sym_checked_statement] = STATE(2493),
    [sym_continue_statement] = STATE(2493),
    [sym_do_statement] = STATE(2493),
    [sym_empty_statement] = STATE(2493),
    [sym_expression_statement] = STATE(2493),
    [sym_fixed_statement] = STATE(2493),
    [sym_for_statement] = STATE(2493),
    [sym_return_statement] = STATE(2493),
    [sym_lock_statement] = STATE(2493),
    [sym_yield_statement] = STATE(2493),
    [sym_switch_statement] = STATE(2493),
    [sym_throw_statement] = STATE(2493),
    [sym_try_statement] = STATE(2493),
    [sym_unsafe_statement] = STATE(2493),
    [sym_using_statement] = STATE(2493),
    [sym_foreach_statement] = STATE(2493),
    [sym_goto_statement] = STATE(2493),
    [sym_labeled_statement] = STATE(2493),
    [sym_if_statement] = STATE(2493),
    [sym_while_statement] = STATE(2493),
    [sym_local_declaration_statement] = STATE(2493),
    [sym_local_function_statement] = STATE(2493),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6748),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2907),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2493),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(60),
    [sym_preproc_endregion] = STATE(60),
    [sym_preproc_line] = STATE(60),
    [sym_preproc_pragma] = STATE(60),
    [sym_preproc_nullable] = STATE(60),
    [sym_preproc_error] = STATE(60),
    [sym_preproc_warning] = STATE(60),
    [sym_preproc_define] = STATE(60),
    [sym_preproc_undef] = STATE(60),
    [aux_sym_class_declaration_repeat1] = STATE(2936),
    [aux_sym_class_declaration_repeat2] = STATE(3108),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(31),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1005),
    [anon_sym_unsafe] = ACTIONS(1007),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(45),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1009),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(73),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_unchecked] = ACTIONS(73),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_do] = ACTIONS(97),
    [anon_sym_while] = ACTIONS(99),
    [anon_sym_for] = ACTIONS(101),
    [anon_sym_lock] = ACTIONS(103),
    [anon_sym_yield] = ACTIONS(105),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(111),
    [anon_sym_try] = ACTIONS(113),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(115),
    [anon_sym_foreach] = ACTIONS(117),
    [anon_sym_goto] = ACTIONS(119),
    [anon_sym_if] = ACTIONS(121),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(147),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [61] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2659),
    [sym_variable_declaration] = STATE(9524),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6870),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2720),
    [sym_break_statement] = STATE(2659),
    [sym_checked_statement] = STATE(2659),
    [sym_continue_statement] = STATE(2659),
    [sym_do_statement] = STATE(2659),
    [sym_empty_statement] = STATE(2659),
    [sym_expression_statement] = STATE(2659),
    [sym_fixed_statement] = STATE(2659),
    [sym_for_statement] = STATE(2659),
    [sym_return_statement] = STATE(2659),
    [sym_lock_statement] = STATE(2659),
    [sym_yield_statement] = STATE(2659),
    [sym_switch_statement] = STATE(2659),
    [sym_throw_statement] = STATE(2659),
    [sym_try_statement] = STATE(2659),
    [sym_unsafe_statement] = STATE(2659),
    [sym_using_statement] = STATE(2659),
    [sym_foreach_statement] = STATE(2659),
    [sym_goto_statement] = STATE(2659),
    [sym_labeled_statement] = STATE(2659),
    [sym_if_statement] = STATE(2659),
    [sym_while_statement] = STATE(2659),
    [sym_local_declaration_statement] = STATE(2659),
    [sym_local_function_statement] = STATE(2659),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6347),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2847),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2659),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(61),
    [sym_preproc_endregion] = STATE(61),
    [sym_preproc_line] = STATE(61),
    [sym_preproc_pragma] = STATE(61),
    [sym_preproc_nullable] = STATE(61),
    [sym_preproc_error] = STATE(61),
    [sym_preproc_warning] = STATE(61),
    [sym_preproc_define] = STATE(61),
    [sym_preproc_undef] = STATE(61),
    [aux_sym_class_declaration_repeat1] = STATE(2935),
    [aux_sym_class_declaration_repeat2] = STATE(3094),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(663),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(665),
    [anon_sym_unsafe] = ACTIONS(667),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(677),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(689),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(693),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(701),
    [anon_sym_unchecked] = ACTIONS(693),
    [anon_sym_continue] = ACTIONS(703),
    [anon_sym_do] = ACTIONS(705),
    [anon_sym_while] = ACTIONS(707),
    [anon_sym_for] = ACTIONS(709),
    [anon_sym_lock] = ACTIONS(711),
    [anon_sym_yield] = ACTIONS(713),
    [anon_sym_switch] = ACTIONS(715),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(739),
    [anon_sym_try] = ACTIONS(719),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(741),
    [anon_sym_foreach] = ACTIONS(723),
    [anon_sym_goto] = ACTIONS(725),
    [anon_sym_if] = ACTIONS(727),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(731),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [62] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2659),
    [sym_variable_declaration] = STATE(9524),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6870),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2724),
    [sym_break_statement] = STATE(2659),
    [sym_checked_statement] = STATE(2659),
    [sym_continue_statement] = STATE(2659),
    [sym_do_statement] = STATE(2659),
    [sym_empty_statement] = STATE(2659),
    [sym_expression_statement] = STATE(2659),
    [sym_fixed_statement] = STATE(2659),
    [sym_for_statement] = STATE(2659),
    [sym_return_statement] = STATE(2659),
    [sym_lock_statement] = STATE(2659),
    [sym_yield_statement] = STATE(2659),
    [sym_switch_statement] = STATE(2659),
    [sym_throw_statement] = STATE(2659),
    [sym_try_statement] = STATE(2659),
    [sym_unsafe_statement] = STATE(2659),
    [sym_using_statement] = STATE(2659),
    [sym_foreach_statement] = STATE(2659),
    [sym_goto_statement] = STATE(2659),
    [sym_labeled_statement] = STATE(2659),
    [sym_if_statement] = STATE(2659),
    [sym_while_statement] = STATE(2659),
    [sym_local_declaration_statement] = STATE(2659),
    [sym_local_function_statement] = STATE(2659),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6347),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2847),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2659),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(62),
    [sym_preproc_endregion] = STATE(62),
    [sym_preproc_line] = STATE(62),
    [sym_preproc_pragma] = STATE(62),
    [sym_preproc_nullable] = STATE(62),
    [sym_preproc_error] = STATE(62),
    [sym_preproc_warning] = STATE(62),
    [sym_preproc_define] = STATE(62),
    [sym_preproc_undef] = STATE(62),
    [aux_sym_class_declaration_repeat1] = STATE(2935),
    [aux_sym_class_declaration_repeat2] = STATE(3094),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(663),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(665),
    [anon_sym_unsafe] = ACTIONS(667),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(677),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(689),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(693),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(701),
    [anon_sym_unchecked] = ACTIONS(693),
    [anon_sym_continue] = ACTIONS(703),
    [anon_sym_do] = ACTIONS(705),
    [anon_sym_while] = ACTIONS(707),
    [anon_sym_for] = ACTIONS(709),
    [anon_sym_lock] = ACTIONS(711),
    [anon_sym_yield] = ACTIONS(713),
    [anon_sym_switch] = ACTIONS(715),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(739),
    [anon_sym_try] = ACTIONS(719),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(741),
    [anon_sym_foreach] = ACTIONS(723),
    [anon_sym_goto] = ACTIONS(725),
    [anon_sym_if] = ACTIONS(727),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(731),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [63] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2659),
    [sym_variable_declaration] = STATE(9524),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6870),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2655),
    [sym_break_statement] = STATE(2659),
    [sym_checked_statement] = STATE(2659),
    [sym_continue_statement] = STATE(2659),
    [sym_do_statement] = STATE(2659),
    [sym_empty_statement] = STATE(2659),
    [sym_expression_statement] = STATE(2659),
    [sym_fixed_statement] = STATE(2659),
    [sym_for_statement] = STATE(2659),
    [sym_return_statement] = STATE(2659),
    [sym_lock_statement] = STATE(2659),
    [sym_yield_statement] = STATE(2659),
    [sym_switch_statement] = STATE(2659),
    [sym_throw_statement] = STATE(2659),
    [sym_try_statement] = STATE(2659),
    [sym_unsafe_statement] = STATE(2659),
    [sym_using_statement] = STATE(2659),
    [sym_foreach_statement] = STATE(2659),
    [sym_goto_statement] = STATE(2659),
    [sym_labeled_statement] = STATE(2659),
    [sym_if_statement] = STATE(2659),
    [sym_while_statement] = STATE(2659),
    [sym_local_declaration_statement] = STATE(2659),
    [sym_local_function_statement] = STATE(2659),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6347),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2847),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2659),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(63),
    [sym_preproc_endregion] = STATE(63),
    [sym_preproc_line] = STATE(63),
    [sym_preproc_pragma] = STATE(63),
    [sym_preproc_nullable] = STATE(63),
    [sym_preproc_error] = STATE(63),
    [sym_preproc_warning] = STATE(63),
    [sym_preproc_define] = STATE(63),
    [sym_preproc_undef] = STATE(63),
    [aux_sym_class_declaration_repeat1] = STATE(2935),
    [aux_sym_class_declaration_repeat2] = STATE(3094),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(663),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(665),
    [anon_sym_unsafe] = ACTIONS(667),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(677),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(689),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(693),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(701),
    [anon_sym_unchecked] = ACTIONS(693),
    [anon_sym_continue] = ACTIONS(703),
    [anon_sym_do] = ACTIONS(705),
    [anon_sym_while] = ACTIONS(707),
    [anon_sym_for] = ACTIONS(709),
    [anon_sym_lock] = ACTIONS(711),
    [anon_sym_yield] = ACTIONS(713),
    [anon_sym_switch] = ACTIONS(715),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(739),
    [anon_sym_try] = ACTIONS(719),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(741),
    [anon_sym_foreach] = ACTIONS(723),
    [anon_sym_goto] = ACTIONS(725),
    [anon_sym_if] = ACTIONS(727),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(731),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [64] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2659),
    [sym_variable_declaration] = STATE(9524),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6870),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2668),
    [sym_break_statement] = STATE(2659),
    [sym_checked_statement] = STATE(2659),
    [sym_continue_statement] = STATE(2659),
    [sym_do_statement] = STATE(2659),
    [sym_empty_statement] = STATE(2659),
    [sym_expression_statement] = STATE(2659),
    [sym_fixed_statement] = STATE(2659),
    [sym_for_statement] = STATE(2659),
    [sym_return_statement] = STATE(2659),
    [sym_lock_statement] = STATE(2659),
    [sym_yield_statement] = STATE(2659),
    [sym_switch_statement] = STATE(2659),
    [sym_throw_statement] = STATE(2659),
    [sym_try_statement] = STATE(2659),
    [sym_unsafe_statement] = STATE(2659),
    [sym_using_statement] = STATE(2659),
    [sym_foreach_statement] = STATE(2659),
    [sym_goto_statement] = STATE(2659),
    [sym_labeled_statement] = STATE(2659),
    [sym_if_statement] = STATE(2659),
    [sym_while_statement] = STATE(2659),
    [sym_local_declaration_statement] = STATE(2659),
    [sym_local_function_statement] = STATE(2659),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6347),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2847),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2659),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(64),
    [sym_preproc_endregion] = STATE(64),
    [sym_preproc_line] = STATE(64),
    [sym_preproc_pragma] = STATE(64),
    [sym_preproc_nullable] = STATE(64),
    [sym_preproc_error] = STATE(64),
    [sym_preproc_warning] = STATE(64),
    [sym_preproc_define] = STATE(64),
    [sym_preproc_undef] = STATE(64),
    [aux_sym_class_declaration_repeat1] = STATE(2935),
    [aux_sym_class_declaration_repeat2] = STATE(3094),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(663),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(665),
    [anon_sym_unsafe] = ACTIONS(667),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(677),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(689),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(693),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(701),
    [anon_sym_unchecked] = ACTIONS(693),
    [anon_sym_continue] = ACTIONS(703),
    [anon_sym_do] = ACTIONS(705),
    [anon_sym_while] = ACTIONS(707),
    [anon_sym_for] = ACTIONS(709),
    [anon_sym_lock] = ACTIONS(711),
    [anon_sym_yield] = ACTIONS(713),
    [anon_sym_switch] = ACTIONS(715),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(739),
    [anon_sym_try] = ACTIONS(719),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(741),
    [anon_sym_foreach] = ACTIONS(723),
    [anon_sym_goto] = ACTIONS(725),
    [anon_sym_if] = ACTIONS(727),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(731),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [65] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2659),
    [sym_variable_declaration] = STATE(9524),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6870),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2682),
    [sym_break_statement] = STATE(2659),
    [sym_checked_statement] = STATE(2659),
    [sym_continue_statement] = STATE(2659),
    [sym_do_statement] = STATE(2659),
    [sym_empty_statement] = STATE(2659),
    [sym_expression_statement] = STATE(2659),
    [sym_fixed_statement] = STATE(2659),
    [sym_for_statement] = STATE(2659),
    [sym_return_statement] = STATE(2659),
    [sym_lock_statement] = STATE(2659),
    [sym_yield_statement] = STATE(2659),
    [sym_switch_statement] = STATE(2659),
    [sym_throw_statement] = STATE(2659),
    [sym_try_statement] = STATE(2659),
    [sym_unsafe_statement] = STATE(2659),
    [sym_using_statement] = STATE(2659),
    [sym_foreach_statement] = STATE(2659),
    [sym_goto_statement] = STATE(2659),
    [sym_labeled_statement] = STATE(2659),
    [sym_if_statement] = STATE(2659),
    [sym_while_statement] = STATE(2659),
    [sym_local_declaration_statement] = STATE(2659),
    [sym_local_function_statement] = STATE(2659),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6347),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2847),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2659),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(65),
    [sym_preproc_endregion] = STATE(65),
    [sym_preproc_line] = STATE(65),
    [sym_preproc_pragma] = STATE(65),
    [sym_preproc_nullable] = STATE(65),
    [sym_preproc_error] = STATE(65),
    [sym_preproc_warning] = STATE(65),
    [sym_preproc_define] = STATE(65),
    [sym_preproc_undef] = STATE(65),
    [aux_sym_class_declaration_repeat1] = STATE(2935),
    [aux_sym_class_declaration_repeat2] = STATE(3094),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(663),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(665),
    [anon_sym_unsafe] = ACTIONS(667),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(677),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(689),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(693),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(701),
    [anon_sym_unchecked] = ACTIONS(693),
    [anon_sym_continue] = ACTIONS(703),
    [anon_sym_do] = ACTIONS(705),
    [anon_sym_while] = ACTIONS(707),
    [anon_sym_for] = ACTIONS(709),
    [anon_sym_lock] = ACTIONS(711),
    [anon_sym_yield] = ACTIONS(713),
    [anon_sym_switch] = ACTIONS(715),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(739),
    [anon_sym_try] = ACTIONS(719),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(741),
    [anon_sym_foreach] = ACTIONS(723),
    [anon_sym_goto] = ACTIONS(725),
    [anon_sym_if] = ACTIONS(727),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(731),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [66] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2659),
    [sym_variable_declaration] = STATE(9524),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6870),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2683),
    [sym_break_statement] = STATE(2659),
    [sym_checked_statement] = STATE(2659),
    [sym_continue_statement] = STATE(2659),
    [sym_do_statement] = STATE(2659),
    [sym_empty_statement] = STATE(2659),
    [sym_expression_statement] = STATE(2659),
    [sym_fixed_statement] = STATE(2659),
    [sym_for_statement] = STATE(2659),
    [sym_return_statement] = STATE(2659),
    [sym_lock_statement] = STATE(2659),
    [sym_yield_statement] = STATE(2659),
    [sym_switch_statement] = STATE(2659),
    [sym_throw_statement] = STATE(2659),
    [sym_try_statement] = STATE(2659),
    [sym_unsafe_statement] = STATE(2659),
    [sym_using_statement] = STATE(2659),
    [sym_foreach_statement] = STATE(2659),
    [sym_goto_statement] = STATE(2659),
    [sym_labeled_statement] = STATE(2659),
    [sym_if_statement] = STATE(2659),
    [sym_while_statement] = STATE(2659),
    [sym_local_declaration_statement] = STATE(2659),
    [sym_local_function_statement] = STATE(2659),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6347),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2847),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2659),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(66),
    [sym_preproc_endregion] = STATE(66),
    [sym_preproc_line] = STATE(66),
    [sym_preproc_pragma] = STATE(66),
    [sym_preproc_nullable] = STATE(66),
    [sym_preproc_error] = STATE(66),
    [sym_preproc_warning] = STATE(66),
    [sym_preproc_define] = STATE(66),
    [sym_preproc_undef] = STATE(66),
    [aux_sym_class_declaration_repeat1] = STATE(2935),
    [aux_sym_class_declaration_repeat2] = STATE(3094),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(663),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(665),
    [anon_sym_unsafe] = ACTIONS(667),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(677),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(689),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(693),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(701),
    [anon_sym_unchecked] = ACTIONS(693),
    [anon_sym_continue] = ACTIONS(703),
    [anon_sym_do] = ACTIONS(705),
    [anon_sym_while] = ACTIONS(707),
    [anon_sym_for] = ACTIONS(709),
    [anon_sym_lock] = ACTIONS(711),
    [anon_sym_yield] = ACTIONS(713),
    [anon_sym_switch] = ACTIONS(715),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(739),
    [anon_sym_try] = ACTIONS(719),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(741),
    [anon_sym_foreach] = ACTIONS(723),
    [anon_sym_goto] = ACTIONS(725),
    [anon_sym_if] = ACTIONS(727),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(731),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [67] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2659),
    [sym_variable_declaration] = STATE(9524),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6870),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2685),
    [sym_break_statement] = STATE(2659),
    [sym_checked_statement] = STATE(2659),
    [sym_continue_statement] = STATE(2659),
    [sym_do_statement] = STATE(2659),
    [sym_empty_statement] = STATE(2659),
    [sym_expression_statement] = STATE(2659),
    [sym_fixed_statement] = STATE(2659),
    [sym_for_statement] = STATE(2659),
    [sym_return_statement] = STATE(2659),
    [sym_lock_statement] = STATE(2659),
    [sym_yield_statement] = STATE(2659),
    [sym_switch_statement] = STATE(2659),
    [sym_throw_statement] = STATE(2659),
    [sym_try_statement] = STATE(2659),
    [sym_unsafe_statement] = STATE(2659),
    [sym_using_statement] = STATE(2659),
    [sym_foreach_statement] = STATE(2659),
    [sym_goto_statement] = STATE(2659),
    [sym_labeled_statement] = STATE(2659),
    [sym_if_statement] = STATE(2659),
    [sym_while_statement] = STATE(2659),
    [sym_local_declaration_statement] = STATE(2659),
    [sym_local_function_statement] = STATE(2659),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6347),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2847),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2659),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(67),
    [sym_preproc_endregion] = STATE(67),
    [sym_preproc_line] = STATE(67),
    [sym_preproc_pragma] = STATE(67),
    [sym_preproc_nullable] = STATE(67),
    [sym_preproc_error] = STATE(67),
    [sym_preproc_warning] = STATE(67),
    [sym_preproc_define] = STATE(67),
    [sym_preproc_undef] = STATE(67),
    [aux_sym_class_declaration_repeat1] = STATE(2935),
    [aux_sym_class_declaration_repeat2] = STATE(3094),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(663),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(665),
    [anon_sym_unsafe] = ACTIONS(667),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(677),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(689),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(693),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(701),
    [anon_sym_unchecked] = ACTIONS(693),
    [anon_sym_continue] = ACTIONS(703),
    [anon_sym_do] = ACTIONS(705),
    [anon_sym_while] = ACTIONS(707),
    [anon_sym_for] = ACTIONS(709),
    [anon_sym_lock] = ACTIONS(711),
    [anon_sym_yield] = ACTIONS(713),
    [anon_sym_switch] = ACTIONS(715),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(739),
    [anon_sym_try] = ACTIONS(719),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(741),
    [anon_sym_foreach] = ACTIONS(723),
    [anon_sym_goto] = ACTIONS(725),
    [anon_sym_if] = ACTIONS(727),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(731),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [68] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(8858),
    [sym_variable_declaration] = STATE(9360),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6862),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(9801),
    [sym_break_statement] = STATE(8858),
    [sym_checked_statement] = STATE(8858),
    [sym_continue_statement] = STATE(8858),
    [sym_do_statement] = STATE(8858),
    [sym_empty_statement] = STATE(8858),
    [sym_expression_statement] = STATE(8858),
    [sym_fixed_statement] = STATE(8858),
    [sym_for_statement] = STATE(8858),
    [sym_return_statement] = STATE(8858),
    [sym_lock_statement] = STATE(8858),
    [sym_yield_statement] = STATE(8858),
    [sym_switch_statement] = STATE(8858),
    [sym_throw_statement] = STATE(8858),
    [sym_try_statement] = STATE(8858),
    [sym_unsafe_statement] = STATE(8858),
    [sym_using_statement] = STATE(8858),
    [sym_foreach_statement] = STATE(8858),
    [sym_goto_statement] = STATE(8858),
    [sym_labeled_statement] = STATE(8858),
    [sym_if_statement] = STATE(8858),
    [sym_while_statement] = STATE(8858),
    [sym_local_declaration_statement] = STATE(8858),
    [sym_local_function_statement] = STATE(8858),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6755),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2904),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(8858),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(68),
    [sym_preproc_endregion] = STATE(68),
    [sym_preproc_line] = STATE(68),
    [sym_preproc_pragma] = STATE(68),
    [sym_preproc_nullable] = STATE(68),
    [sym_preproc_error] = STATE(68),
    [sym_preproc_warning] = STATE(68),
    [sym_preproc_define] = STATE(68),
    [sym_preproc_undef] = STATE(68),
    [aux_sym_class_declaration_repeat1] = STATE(2931),
    [aux_sym_class_declaration_repeat2] = STATE(3115),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(1011),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1013),
    [anon_sym_unsafe] = ACTIONS(1015),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(1017),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1019),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1021),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1023),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(1025),
    [anon_sym_unchecked] = ACTIONS(1023),
    [anon_sym_continue] = ACTIONS(1027),
    [anon_sym_do] = ACTIONS(1029),
    [anon_sym_while] = ACTIONS(1031),
    [anon_sym_for] = ACTIONS(1033),
    [anon_sym_lock] = ACTIONS(1035),
    [anon_sym_yield] = ACTIONS(1037),
    [anon_sym_switch] = ACTIONS(1039),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1041),
    [anon_sym_try] = ACTIONS(1043),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1045),
    [anon_sym_foreach] = ACTIONS(1047),
    [anon_sym_goto] = ACTIONS(1049),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1053),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [69] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2659),
    [sym_variable_declaration] = STATE(9524),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6870),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2661),
    [sym_break_statement] = STATE(2659),
    [sym_checked_statement] = STATE(2659),
    [sym_continue_statement] = STATE(2659),
    [sym_do_statement] = STATE(2659),
    [sym_empty_statement] = STATE(2659),
    [sym_expression_statement] = STATE(2659),
    [sym_fixed_statement] = STATE(2659),
    [sym_for_statement] = STATE(2659),
    [sym_return_statement] = STATE(2659),
    [sym_lock_statement] = STATE(2659),
    [sym_yield_statement] = STATE(2659),
    [sym_switch_statement] = STATE(2659),
    [sym_throw_statement] = STATE(2659),
    [sym_try_statement] = STATE(2659),
    [sym_unsafe_statement] = STATE(2659),
    [sym_using_statement] = STATE(2659),
    [sym_foreach_statement] = STATE(2659),
    [sym_goto_statement] = STATE(2659),
    [sym_labeled_statement] = STATE(2659),
    [sym_if_statement] = STATE(2659),
    [sym_while_statement] = STATE(2659),
    [sym_local_declaration_statement] = STATE(2659),
    [sym_local_function_statement] = STATE(2659),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6347),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2847),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2659),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(69),
    [sym_preproc_endregion] = STATE(69),
    [sym_preproc_line] = STATE(69),
    [sym_preproc_pragma] = STATE(69),
    [sym_preproc_nullable] = STATE(69),
    [sym_preproc_error] = STATE(69),
    [sym_preproc_warning] = STATE(69),
    [sym_preproc_define] = STATE(69),
    [sym_preproc_undef] = STATE(69),
    [aux_sym_class_declaration_repeat1] = STATE(2935),
    [aux_sym_class_declaration_repeat2] = STATE(3094),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(663),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(665),
    [anon_sym_unsafe] = ACTIONS(667),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(677),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(689),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(693),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(701),
    [anon_sym_unchecked] = ACTIONS(693),
    [anon_sym_continue] = ACTIONS(703),
    [anon_sym_do] = ACTIONS(705),
    [anon_sym_while] = ACTIONS(707),
    [anon_sym_for] = ACTIONS(709),
    [anon_sym_lock] = ACTIONS(711),
    [anon_sym_yield] = ACTIONS(713),
    [anon_sym_switch] = ACTIONS(715),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(739),
    [anon_sym_try] = ACTIONS(719),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(741),
    [anon_sym_foreach] = ACTIONS(723),
    [anon_sym_goto] = ACTIONS(725),
    [anon_sym_if] = ACTIONS(727),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(731),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [70] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2659),
    [sym_variable_declaration] = STATE(9524),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6870),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2694),
    [sym_break_statement] = STATE(2659),
    [sym_checked_statement] = STATE(2659),
    [sym_continue_statement] = STATE(2659),
    [sym_do_statement] = STATE(2659),
    [sym_empty_statement] = STATE(2659),
    [sym_expression_statement] = STATE(2659),
    [sym_fixed_statement] = STATE(2659),
    [sym_for_statement] = STATE(2659),
    [sym_return_statement] = STATE(2659),
    [sym_lock_statement] = STATE(2659),
    [sym_yield_statement] = STATE(2659),
    [sym_switch_statement] = STATE(2659),
    [sym_throw_statement] = STATE(2659),
    [sym_try_statement] = STATE(2659),
    [sym_unsafe_statement] = STATE(2659),
    [sym_using_statement] = STATE(2659),
    [sym_foreach_statement] = STATE(2659),
    [sym_goto_statement] = STATE(2659),
    [sym_labeled_statement] = STATE(2659),
    [sym_if_statement] = STATE(2659),
    [sym_while_statement] = STATE(2659),
    [sym_local_declaration_statement] = STATE(2659),
    [sym_local_function_statement] = STATE(2659),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6347),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2847),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2659),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(70),
    [sym_preproc_endregion] = STATE(70),
    [sym_preproc_line] = STATE(70),
    [sym_preproc_pragma] = STATE(70),
    [sym_preproc_nullable] = STATE(70),
    [sym_preproc_error] = STATE(70),
    [sym_preproc_warning] = STATE(70),
    [sym_preproc_define] = STATE(70),
    [sym_preproc_undef] = STATE(70),
    [aux_sym_class_declaration_repeat1] = STATE(2935),
    [aux_sym_class_declaration_repeat2] = STATE(3094),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(663),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(665),
    [anon_sym_unsafe] = ACTIONS(667),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(677),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(689),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(693),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(701),
    [anon_sym_unchecked] = ACTIONS(693),
    [anon_sym_continue] = ACTIONS(703),
    [anon_sym_do] = ACTIONS(705),
    [anon_sym_while] = ACTIONS(707),
    [anon_sym_for] = ACTIONS(709),
    [anon_sym_lock] = ACTIONS(711),
    [anon_sym_yield] = ACTIONS(713),
    [anon_sym_switch] = ACTIONS(715),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(739),
    [anon_sym_try] = ACTIONS(719),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(741),
    [anon_sym_foreach] = ACTIONS(723),
    [anon_sym_goto] = ACTIONS(725),
    [anon_sym_if] = ACTIONS(727),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(731),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [71] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2659),
    [sym_variable_declaration] = STATE(9524),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6870),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2695),
    [sym_break_statement] = STATE(2659),
    [sym_checked_statement] = STATE(2659),
    [sym_continue_statement] = STATE(2659),
    [sym_do_statement] = STATE(2659),
    [sym_empty_statement] = STATE(2659),
    [sym_expression_statement] = STATE(2659),
    [sym_fixed_statement] = STATE(2659),
    [sym_for_statement] = STATE(2659),
    [sym_return_statement] = STATE(2659),
    [sym_lock_statement] = STATE(2659),
    [sym_yield_statement] = STATE(2659),
    [sym_switch_statement] = STATE(2659),
    [sym_throw_statement] = STATE(2659),
    [sym_try_statement] = STATE(2659),
    [sym_unsafe_statement] = STATE(2659),
    [sym_using_statement] = STATE(2659),
    [sym_foreach_statement] = STATE(2659),
    [sym_goto_statement] = STATE(2659),
    [sym_labeled_statement] = STATE(2659),
    [sym_if_statement] = STATE(2659),
    [sym_while_statement] = STATE(2659),
    [sym_local_declaration_statement] = STATE(2659),
    [sym_local_function_statement] = STATE(2659),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6347),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2847),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2659),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(71),
    [sym_preproc_endregion] = STATE(71),
    [sym_preproc_line] = STATE(71),
    [sym_preproc_pragma] = STATE(71),
    [sym_preproc_nullable] = STATE(71),
    [sym_preproc_error] = STATE(71),
    [sym_preproc_warning] = STATE(71),
    [sym_preproc_define] = STATE(71),
    [sym_preproc_undef] = STATE(71),
    [aux_sym_class_declaration_repeat1] = STATE(2935),
    [aux_sym_class_declaration_repeat2] = STATE(3094),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(663),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(665),
    [anon_sym_unsafe] = ACTIONS(667),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(677),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(689),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(693),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(701),
    [anon_sym_unchecked] = ACTIONS(693),
    [anon_sym_continue] = ACTIONS(703),
    [anon_sym_do] = ACTIONS(705),
    [anon_sym_while] = ACTIONS(707),
    [anon_sym_for] = ACTIONS(709),
    [anon_sym_lock] = ACTIONS(711),
    [anon_sym_yield] = ACTIONS(713),
    [anon_sym_switch] = ACTIONS(715),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(739),
    [anon_sym_try] = ACTIONS(719),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(741),
    [anon_sym_foreach] = ACTIONS(723),
    [anon_sym_goto] = ACTIONS(725),
    [anon_sym_if] = ACTIONS(727),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(731),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [72] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2659),
    [sym_variable_declaration] = STATE(9524),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6870),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2698),
    [sym_break_statement] = STATE(2659),
    [sym_checked_statement] = STATE(2659),
    [sym_continue_statement] = STATE(2659),
    [sym_do_statement] = STATE(2659),
    [sym_empty_statement] = STATE(2659),
    [sym_expression_statement] = STATE(2659),
    [sym_fixed_statement] = STATE(2659),
    [sym_for_statement] = STATE(2659),
    [sym_return_statement] = STATE(2659),
    [sym_lock_statement] = STATE(2659),
    [sym_yield_statement] = STATE(2659),
    [sym_switch_statement] = STATE(2659),
    [sym_throw_statement] = STATE(2659),
    [sym_try_statement] = STATE(2659),
    [sym_unsafe_statement] = STATE(2659),
    [sym_using_statement] = STATE(2659),
    [sym_foreach_statement] = STATE(2659),
    [sym_goto_statement] = STATE(2659),
    [sym_labeled_statement] = STATE(2659),
    [sym_if_statement] = STATE(2659),
    [sym_while_statement] = STATE(2659),
    [sym_local_declaration_statement] = STATE(2659),
    [sym_local_function_statement] = STATE(2659),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6347),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2847),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2659),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(72),
    [sym_preproc_endregion] = STATE(72),
    [sym_preproc_line] = STATE(72),
    [sym_preproc_pragma] = STATE(72),
    [sym_preproc_nullable] = STATE(72),
    [sym_preproc_error] = STATE(72),
    [sym_preproc_warning] = STATE(72),
    [sym_preproc_define] = STATE(72),
    [sym_preproc_undef] = STATE(72),
    [aux_sym_class_declaration_repeat1] = STATE(2935),
    [aux_sym_class_declaration_repeat2] = STATE(3094),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(663),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(665),
    [anon_sym_unsafe] = ACTIONS(667),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(677),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(689),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(693),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(701),
    [anon_sym_unchecked] = ACTIONS(693),
    [anon_sym_continue] = ACTIONS(703),
    [anon_sym_do] = ACTIONS(705),
    [anon_sym_while] = ACTIONS(707),
    [anon_sym_for] = ACTIONS(709),
    [anon_sym_lock] = ACTIONS(711),
    [anon_sym_yield] = ACTIONS(713),
    [anon_sym_switch] = ACTIONS(715),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(739),
    [anon_sym_try] = ACTIONS(719),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(741),
    [anon_sym_foreach] = ACTIONS(723),
    [anon_sym_goto] = ACTIONS(725),
    [anon_sym_if] = ACTIONS(727),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(731),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [73] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2659),
    [sym_variable_declaration] = STATE(9524),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6870),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2699),
    [sym_break_statement] = STATE(2659),
    [sym_checked_statement] = STATE(2659),
    [sym_continue_statement] = STATE(2659),
    [sym_do_statement] = STATE(2659),
    [sym_empty_statement] = STATE(2659),
    [sym_expression_statement] = STATE(2659),
    [sym_fixed_statement] = STATE(2659),
    [sym_for_statement] = STATE(2659),
    [sym_return_statement] = STATE(2659),
    [sym_lock_statement] = STATE(2659),
    [sym_yield_statement] = STATE(2659),
    [sym_switch_statement] = STATE(2659),
    [sym_throw_statement] = STATE(2659),
    [sym_try_statement] = STATE(2659),
    [sym_unsafe_statement] = STATE(2659),
    [sym_using_statement] = STATE(2659),
    [sym_foreach_statement] = STATE(2659),
    [sym_goto_statement] = STATE(2659),
    [sym_labeled_statement] = STATE(2659),
    [sym_if_statement] = STATE(2659),
    [sym_while_statement] = STATE(2659),
    [sym_local_declaration_statement] = STATE(2659),
    [sym_local_function_statement] = STATE(2659),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6347),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2847),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2659),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(73),
    [sym_preproc_endregion] = STATE(73),
    [sym_preproc_line] = STATE(73),
    [sym_preproc_pragma] = STATE(73),
    [sym_preproc_nullable] = STATE(73),
    [sym_preproc_error] = STATE(73),
    [sym_preproc_warning] = STATE(73),
    [sym_preproc_define] = STATE(73),
    [sym_preproc_undef] = STATE(73),
    [aux_sym_class_declaration_repeat1] = STATE(2935),
    [aux_sym_class_declaration_repeat2] = STATE(3094),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(663),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(665),
    [anon_sym_unsafe] = ACTIONS(667),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(677),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(689),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(693),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(701),
    [anon_sym_unchecked] = ACTIONS(693),
    [anon_sym_continue] = ACTIONS(703),
    [anon_sym_do] = ACTIONS(705),
    [anon_sym_while] = ACTIONS(707),
    [anon_sym_for] = ACTIONS(709),
    [anon_sym_lock] = ACTIONS(711),
    [anon_sym_yield] = ACTIONS(713),
    [anon_sym_switch] = ACTIONS(715),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(739),
    [anon_sym_try] = ACTIONS(719),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(741),
    [anon_sym_foreach] = ACTIONS(723),
    [anon_sym_goto] = ACTIONS(725),
    [anon_sym_if] = ACTIONS(727),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(731),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [74] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2659),
    [sym_variable_declaration] = STATE(9524),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6870),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2700),
    [sym_break_statement] = STATE(2659),
    [sym_checked_statement] = STATE(2659),
    [sym_continue_statement] = STATE(2659),
    [sym_do_statement] = STATE(2659),
    [sym_empty_statement] = STATE(2659),
    [sym_expression_statement] = STATE(2659),
    [sym_fixed_statement] = STATE(2659),
    [sym_for_statement] = STATE(2659),
    [sym_return_statement] = STATE(2659),
    [sym_lock_statement] = STATE(2659),
    [sym_yield_statement] = STATE(2659),
    [sym_switch_statement] = STATE(2659),
    [sym_throw_statement] = STATE(2659),
    [sym_try_statement] = STATE(2659),
    [sym_unsafe_statement] = STATE(2659),
    [sym_using_statement] = STATE(2659),
    [sym_foreach_statement] = STATE(2659),
    [sym_goto_statement] = STATE(2659),
    [sym_labeled_statement] = STATE(2659),
    [sym_if_statement] = STATE(2659),
    [sym_while_statement] = STATE(2659),
    [sym_local_declaration_statement] = STATE(2659),
    [sym_local_function_statement] = STATE(2659),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6347),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2847),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2659),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(74),
    [sym_preproc_endregion] = STATE(74),
    [sym_preproc_line] = STATE(74),
    [sym_preproc_pragma] = STATE(74),
    [sym_preproc_nullable] = STATE(74),
    [sym_preproc_error] = STATE(74),
    [sym_preproc_warning] = STATE(74),
    [sym_preproc_define] = STATE(74),
    [sym_preproc_undef] = STATE(74),
    [aux_sym_class_declaration_repeat1] = STATE(2935),
    [aux_sym_class_declaration_repeat2] = STATE(3094),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(663),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(665),
    [anon_sym_unsafe] = ACTIONS(667),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(677),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(689),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(693),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(701),
    [anon_sym_unchecked] = ACTIONS(693),
    [anon_sym_continue] = ACTIONS(703),
    [anon_sym_do] = ACTIONS(705),
    [anon_sym_while] = ACTIONS(707),
    [anon_sym_for] = ACTIONS(709),
    [anon_sym_lock] = ACTIONS(711),
    [anon_sym_yield] = ACTIONS(713),
    [anon_sym_switch] = ACTIONS(715),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(739),
    [anon_sym_try] = ACTIONS(719),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(741),
    [anon_sym_foreach] = ACTIONS(723),
    [anon_sym_goto] = ACTIONS(725),
    [anon_sym_if] = ACTIONS(727),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(731),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [75] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2659),
    [sym_variable_declaration] = STATE(9524),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6870),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2709),
    [sym_break_statement] = STATE(2659),
    [sym_checked_statement] = STATE(2659),
    [sym_continue_statement] = STATE(2659),
    [sym_do_statement] = STATE(2659),
    [sym_empty_statement] = STATE(2659),
    [sym_expression_statement] = STATE(2659),
    [sym_fixed_statement] = STATE(2659),
    [sym_for_statement] = STATE(2659),
    [sym_return_statement] = STATE(2659),
    [sym_lock_statement] = STATE(2659),
    [sym_yield_statement] = STATE(2659),
    [sym_switch_statement] = STATE(2659),
    [sym_throw_statement] = STATE(2659),
    [sym_try_statement] = STATE(2659),
    [sym_unsafe_statement] = STATE(2659),
    [sym_using_statement] = STATE(2659),
    [sym_foreach_statement] = STATE(2659),
    [sym_goto_statement] = STATE(2659),
    [sym_labeled_statement] = STATE(2659),
    [sym_if_statement] = STATE(2659),
    [sym_while_statement] = STATE(2659),
    [sym_local_declaration_statement] = STATE(2659),
    [sym_local_function_statement] = STATE(2659),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6347),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2847),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2659),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(75),
    [sym_preproc_endregion] = STATE(75),
    [sym_preproc_line] = STATE(75),
    [sym_preproc_pragma] = STATE(75),
    [sym_preproc_nullable] = STATE(75),
    [sym_preproc_error] = STATE(75),
    [sym_preproc_warning] = STATE(75),
    [sym_preproc_define] = STATE(75),
    [sym_preproc_undef] = STATE(75),
    [aux_sym_class_declaration_repeat1] = STATE(2935),
    [aux_sym_class_declaration_repeat2] = STATE(3094),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(663),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(665),
    [anon_sym_unsafe] = ACTIONS(667),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(677),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(689),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(693),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(701),
    [anon_sym_unchecked] = ACTIONS(693),
    [anon_sym_continue] = ACTIONS(703),
    [anon_sym_do] = ACTIONS(705),
    [anon_sym_while] = ACTIONS(707),
    [anon_sym_for] = ACTIONS(709),
    [anon_sym_lock] = ACTIONS(711),
    [anon_sym_yield] = ACTIONS(713),
    [anon_sym_switch] = ACTIONS(715),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(739),
    [anon_sym_try] = ACTIONS(719),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(741),
    [anon_sym_foreach] = ACTIONS(723),
    [anon_sym_goto] = ACTIONS(725),
    [anon_sym_if] = ACTIONS(727),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(731),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [76] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2659),
    [sym_variable_declaration] = STATE(9524),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6870),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2710),
    [sym_break_statement] = STATE(2659),
    [sym_checked_statement] = STATE(2659),
    [sym_continue_statement] = STATE(2659),
    [sym_do_statement] = STATE(2659),
    [sym_empty_statement] = STATE(2659),
    [sym_expression_statement] = STATE(2659),
    [sym_fixed_statement] = STATE(2659),
    [sym_for_statement] = STATE(2659),
    [sym_return_statement] = STATE(2659),
    [sym_lock_statement] = STATE(2659),
    [sym_yield_statement] = STATE(2659),
    [sym_switch_statement] = STATE(2659),
    [sym_throw_statement] = STATE(2659),
    [sym_try_statement] = STATE(2659),
    [sym_unsafe_statement] = STATE(2659),
    [sym_using_statement] = STATE(2659),
    [sym_foreach_statement] = STATE(2659),
    [sym_goto_statement] = STATE(2659),
    [sym_labeled_statement] = STATE(2659),
    [sym_if_statement] = STATE(2659),
    [sym_while_statement] = STATE(2659),
    [sym_local_declaration_statement] = STATE(2659),
    [sym_local_function_statement] = STATE(2659),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6347),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2847),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2659),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(76),
    [sym_preproc_endregion] = STATE(76),
    [sym_preproc_line] = STATE(76),
    [sym_preproc_pragma] = STATE(76),
    [sym_preproc_nullable] = STATE(76),
    [sym_preproc_error] = STATE(76),
    [sym_preproc_warning] = STATE(76),
    [sym_preproc_define] = STATE(76),
    [sym_preproc_undef] = STATE(76),
    [aux_sym_class_declaration_repeat1] = STATE(2935),
    [aux_sym_class_declaration_repeat2] = STATE(3094),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(663),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(665),
    [anon_sym_unsafe] = ACTIONS(667),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(677),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(689),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(693),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(701),
    [anon_sym_unchecked] = ACTIONS(693),
    [anon_sym_continue] = ACTIONS(703),
    [anon_sym_do] = ACTIONS(705),
    [anon_sym_while] = ACTIONS(707),
    [anon_sym_for] = ACTIONS(709),
    [anon_sym_lock] = ACTIONS(711),
    [anon_sym_yield] = ACTIONS(713),
    [anon_sym_switch] = ACTIONS(715),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(739),
    [anon_sym_try] = ACTIONS(719),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(741),
    [anon_sym_foreach] = ACTIONS(723),
    [anon_sym_goto] = ACTIONS(725),
    [anon_sym_if] = ACTIONS(727),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(731),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [77] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2659),
    [sym_variable_declaration] = STATE(9524),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6870),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2712),
    [sym_break_statement] = STATE(2659),
    [sym_checked_statement] = STATE(2659),
    [sym_continue_statement] = STATE(2659),
    [sym_do_statement] = STATE(2659),
    [sym_empty_statement] = STATE(2659),
    [sym_expression_statement] = STATE(2659),
    [sym_fixed_statement] = STATE(2659),
    [sym_for_statement] = STATE(2659),
    [sym_return_statement] = STATE(2659),
    [sym_lock_statement] = STATE(2659),
    [sym_yield_statement] = STATE(2659),
    [sym_switch_statement] = STATE(2659),
    [sym_throw_statement] = STATE(2659),
    [sym_try_statement] = STATE(2659),
    [sym_unsafe_statement] = STATE(2659),
    [sym_using_statement] = STATE(2659),
    [sym_foreach_statement] = STATE(2659),
    [sym_goto_statement] = STATE(2659),
    [sym_labeled_statement] = STATE(2659),
    [sym_if_statement] = STATE(2659),
    [sym_while_statement] = STATE(2659),
    [sym_local_declaration_statement] = STATE(2659),
    [sym_local_function_statement] = STATE(2659),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6347),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2847),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2659),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(77),
    [sym_preproc_endregion] = STATE(77),
    [sym_preproc_line] = STATE(77),
    [sym_preproc_pragma] = STATE(77),
    [sym_preproc_nullable] = STATE(77),
    [sym_preproc_error] = STATE(77),
    [sym_preproc_warning] = STATE(77),
    [sym_preproc_define] = STATE(77),
    [sym_preproc_undef] = STATE(77),
    [aux_sym_class_declaration_repeat1] = STATE(2935),
    [aux_sym_class_declaration_repeat2] = STATE(3094),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(663),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(665),
    [anon_sym_unsafe] = ACTIONS(667),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(677),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(689),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(693),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(701),
    [anon_sym_unchecked] = ACTIONS(693),
    [anon_sym_continue] = ACTIONS(703),
    [anon_sym_do] = ACTIONS(705),
    [anon_sym_while] = ACTIONS(707),
    [anon_sym_for] = ACTIONS(709),
    [anon_sym_lock] = ACTIONS(711),
    [anon_sym_yield] = ACTIONS(713),
    [anon_sym_switch] = ACTIONS(715),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(739),
    [anon_sym_try] = ACTIONS(719),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(741),
    [anon_sym_foreach] = ACTIONS(723),
    [anon_sym_goto] = ACTIONS(725),
    [anon_sym_if] = ACTIONS(727),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(731),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [78] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2659),
    [sym_variable_declaration] = STATE(9524),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6870),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2713),
    [sym_break_statement] = STATE(2659),
    [sym_checked_statement] = STATE(2659),
    [sym_continue_statement] = STATE(2659),
    [sym_do_statement] = STATE(2659),
    [sym_empty_statement] = STATE(2659),
    [sym_expression_statement] = STATE(2659),
    [sym_fixed_statement] = STATE(2659),
    [sym_for_statement] = STATE(2659),
    [sym_return_statement] = STATE(2659),
    [sym_lock_statement] = STATE(2659),
    [sym_yield_statement] = STATE(2659),
    [sym_switch_statement] = STATE(2659),
    [sym_throw_statement] = STATE(2659),
    [sym_try_statement] = STATE(2659),
    [sym_unsafe_statement] = STATE(2659),
    [sym_using_statement] = STATE(2659),
    [sym_foreach_statement] = STATE(2659),
    [sym_goto_statement] = STATE(2659),
    [sym_labeled_statement] = STATE(2659),
    [sym_if_statement] = STATE(2659),
    [sym_while_statement] = STATE(2659),
    [sym_local_declaration_statement] = STATE(2659),
    [sym_local_function_statement] = STATE(2659),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6347),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2847),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2659),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(78),
    [sym_preproc_endregion] = STATE(78),
    [sym_preproc_line] = STATE(78),
    [sym_preproc_pragma] = STATE(78),
    [sym_preproc_nullable] = STATE(78),
    [sym_preproc_error] = STATE(78),
    [sym_preproc_warning] = STATE(78),
    [sym_preproc_define] = STATE(78),
    [sym_preproc_undef] = STATE(78),
    [aux_sym_class_declaration_repeat1] = STATE(2935),
    [aux_sym_class_declaration_repeat2] = STATE(3094),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(663),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(665),
    [anon_sym_unsafe] = ACTIONS(667),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(677),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(689),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(693),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(701),
    [anon_sym_unchecked] = ACTIONS(693),
    [anon_sym_continue] = ACTIONS(703),
    [anon_sym_do] = ACTIONS(705),
    [anon_sym_while] = ACTIONS(707),
    [anon_sym_for] = ACTIONS(709),
    [anon_sym_lock] = ACTIONS(711),
    [anon_sym_yield] = ACTIONS(713),
    [anon_sym_switch] = ACTIONS(715),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(739),
    [anon_sym_try] = ACTIONS(719),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(741),
    [anon_sym_foreach] = ACTIONS(723),
    [anon_sym_goto] = ACTIONS(725),
    [anon_sym_if] = ACTIONS(727),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(731),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [79] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2659),
    [sym_variable_declaration] = STATE(9524),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6870),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2714),
    [sym_break_statement] = STATE(2659),
    [sym_checked_statement] = STATE(2659),
    [sym_continue_statement] = STATE(2659),
    [sym_do_statement] = STATE(2659),
    [sym_empty_statement] = STATE(2659),
    [sym_expression_statement] = STATE(2659),
    [sym_fixed_statement] = STATE(2659),
    [sym_for_statement] = STATE(2659),
    [sym_return_statement] = STATE(2659),
    [sym_lock_statement] = STATE(2659),
    [sym_yield_statement] = STATE(2659),
    [sym_switch_statement] = STATE(2659),
    [sym_throw_statement] = STATE(2659),
    [sym_try_statement] = STATE(2659),
    [sym_unsafe_statement] = STATE(2659),
    [sym_using_statement] = STATE(2659),
    [sym_foreach_statement] = STATE(2659),
    [sym_goto_statement] = STATE(2659),
    [sym_labeled_statement] = STATE(2659),
    [sym_if_statement] = STATE(2659),
    [sym_while_statement] = STATE(2659),
    [sym_local_declaration_statement] = STATE(2659),
    [sym_local_function_statement] = STATE(2659),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6347),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2847),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2659),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(79),
    [sym_preproc_endregion] = STATE(79),
    [sym_preproc_line] = STATE(79),
    [sym_preproc_pragma] = STATE(79),
    [sym_preproc_nullable] = STATE(79),
    [sym_preproc_error] = STATE(79),
    [sym_preproc_warning] = STATE(79),
    [sym_preproc_define] = STATE(79),
    [sym_preproc_undef] = STATE(79),
    [aux_sym_class_declaration_repeat1] = STATE(2935),
    [aux_sym_class_declaration_repeat2] = STATE(3094),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(663),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(665),
    [anon_sym_unsafe] = ACTIONS(667),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(677),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(689),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(693),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(701),
    [anon_sym_unchecked] = ACTIONS(693),
    [anon_sym_continue] = ACTIONS(703),
    [anon_sym_do] = ACTIONS(705),
    [anon_sym_while] = ACTIONS(707),
    [anon_sym_for] = ACTIONS(709),
    [anon_sym_lock] = ACTIONS(711),
    [anon_sym_yield] = ACTIONS(713),
    [anon_sym_switch] = ACTIONS(715),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(739),
    [anon_sym_try] = ACTIONS(719),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(741),
    [anon_sym_foreach] = ACTIONS(723),
    [anon_sym_goto] = ACTIONS(725),
    [anon_sym_if] = ACTIONS(727),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(731),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [80] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2659),
    [sym_variable_declaration] = STATE(9524),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6870),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2717),
    [sym_break_statement] = STATE(2659),
    [sym_checked_statement] = STATE(2659),
    [sym_continue_statement] = STATE(2659),
    [sym_do_statement] = STATE(2659),
    [sym_empty_statement] = STATE(2659),
    [sym_expression_statement] = STATE(2659),
    [sym_fixed_statement] = STATE(2659),
    [sym_for_statement] = STATE(2659),
    [sym_return_statement] = STATE(2659),
    [sym_lock_statement] = STATE(2659),
    [sym_yield_statement] = STATE(2659),
    [sym_switch_statement] = STATE(2659),
    [sym_throw_statement] = STATE(2659),
    [sym_try_statement] = STATE(2659),
    [sym_unsafe_statement] = STATE(2659),
    [sym_using_statement] = STATE(2659),
    [sym_foreach_statement] = STATE(2659),
    [sym_goto_statement] = STATE(2659),
    [sym_labeled_statement] = STATE(2659),
    [sym_if_statement] = STATE(2659),
    [sym_while_statement] = STATE(2659),
    [sym_local_declaration_statement] = STATE(2659),
    [sym_local_function_statement] = STATE(2659),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6347),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2847),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2659),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(80),
    [sym_preproc_endregion] = STATE(80),
    [sym_preproc_line] = STATE(80),
    [sym_preproc_pragma] = STATE(80),
    [sym_preproc_nullable] = STATE(80),
    [sym_preproc_error] = STATE(80),
    [sym_preproc_warning] = STATE(80),
    [sym_preproc_define] = STATE(80),
    [sym_preproc_undef] = STATE(80),
    [aux_sym_class_declaration_repeat1] = STATE(2935),
    [aux_sym_class_declaration_repeat2] = STATE(3094),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(663),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(665),
    [anon_sym_unsafe] = ACTIONS(667),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(677),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(689),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(693),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(701),
    [anon_sym_unchecked] = ACTIONS(693),
    [anon_sym_continue] = ACTIONS(703),
    [anon_sym_do] = ACTIONS(705),
    [anon_sym_while] = ACTIONS(707),
    [anon_sym_for] = ACTIONS(709),
    [anon_sym_lock] = ACTIONS(711),
    [anon_sym_yield] = ACTIONS(713),
    [anon_sym_switch] = ACTIONS(715),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(739),
    [anon_sym_try] = ACTIONS(719),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(741),
    [anon_sym_foreach] = ACTIONS(723),
    [anon_sym_goto] = ACTIONS(725),
    [anon_sym_if] = ACTIONS(727),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(731),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [81] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2659),
    [sym_variable_declaration] = STATE(9524),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6870),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2656),
    [sym_break_statement] = STATE(2659),
    [sym_checked_statement] = STATE(2659),
    [sym_continue_statement] = STATE(2659),
    [sym_do_statement] = STATE(2659),
    [sym_empty_statement] = STATE(2659),
    [sym_expression_statement] = STATE(2659),
    [sym_fixed_statement] = STATE(2659),
    [sym_for_statement] = STATE(2659),
    [sym_return_statement] = STATE(2659),
    [sym_lock_statement] = STATE(2659),
    [sym_yield_statement] = STATE(2659),
    [sym_switch_statement] = STATE(2659),
    [sym_throw_statement] = STATE(2659),
    [sym_try_statement] = STATE(2659),
    [sym_unsafe_statement] = STATE(2659),
    [sym_using_statement] = STATE(2659),
    [sym_foreach_statement] = STATE(2659),
    [sym_goto_statement] = STATE(2659),
    [sym_labeled_statement] = STATE(2659),
    [sym_if_statement] = STATE(2659),
    [sym_while_statement] = STATE(2659),
    [sym_local_declaration_statement] = STATE(2659),
    [sym_local_function_statement] = STATE(2659),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6347),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2847),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2659),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(81),
    [sym_preproc_endregion] = STATE(81),
    [sym_preproc_line] = STATE(81),
    [sym_preproc_pragma] = STATE(81),
    [sym_preproc_nullable] = STATE(81),
    [sym_preproc_error] = STATE(81),
    [sym_preproc_warning] = STATE(81),
    [sym_preproc_define] = STATE(81),
    [sym_preproc_undef] = STATE(81),
    [aux_sym_class_declaration_repeat1] = STATE(2935),
    [aux_sym_class_declaration_repeat2] = STATE(3094),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(663),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(665),
    [anon_sym_unsafe] = ACTIONS(667),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(677),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(689),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(693),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(701),
    [anon_sym_unchecked] = ACTIONS(693),
    [anon_sym_continue] = ACTIONS(703),
    [anon_sym_do] = ACTIONS(705),
    [anon_sym_while] = ACTIONS(707),
    [anon_sym_for] = ACTIONS(709),
    [anon_sym_lock] = ACTIONS(711),
    [anon_sym_yield] = ACTIONS(713),
    [anon_sym_switch] = ACTIONS(715),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(739),
    [anon_sym_try] = ACTIONS(719),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(741),
    [anon_sym_foreach] = ACTIONS(723),
    [anon_sym_goto] = ACTIONS(725),
    [anon_sym_if] = ACTIONS(727),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(731),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [82] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2659),
    [sym_variable_declaration] = STATE(9524),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6870),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2687),
    [sym_break_statement] = STATE(2659),
    [sym_checked_statement] = STATE(2659),
    [sym_continue_statement] = STATE(2659),
    [sym_do_statement] = STATE(2659),
    [sym_empty_statement] = STATE(2659),
    [sym_expression_statement] = STATE(2659),
    [sym_fixed_statement] = STATE(2659),
    [sym_for_statement] = STATE(2659),
    [sym_return_statement] = STATE(2659),
    [sym_lock_statement] = STATE(2659),
    [sym_yield_statement] = STATE(2659),
    [sym_switch_statement] = STATE(2659),
    [sym_throw_statement] = STATE(2659),
    [sym_try_statement] = STATE(2659),
    [sym_unsafe_statement] = STATE(2659),
    [sym_using_statement] = STATE(2659),
    [sym_foreach_statement] = STATE(2659),
    [sym_goto_statement] = STATE(2659),
    [sym_labeled_statement] = STATE(2659),
    [sym_if_statement] = STATE(2659),
    [sym_while_statement] = STATE(2659),
    [sym_local_declaration_statement] = STATE(2659),
    [sym_local_function_statement] = STATE(2659),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6347),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2847),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2659),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(82),
    [sym_preproc_endregion] = STATE(82),
    [sym_preproc_line] = STATE(82),
    [sym_preproc_pragma] = STATE(82),
    [sym_preproc_nullable] = STATE(82),
    [sym_preproc_error] = STATE(82),
    [sym_preproc_warning] = STATE(82),
    [sym_preproc_define] = STATE(82),
    [sym_preproc_undef] = STATE(82),
    [aux_sym_class_declaration_repeat1] = STATE(2935),
    [aux_sym_class_declaration_repeat2] = STATE(3094),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(663),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(665),
    [anon_sym_unsafe] = ACTIONS(667),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(677),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(689),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(693),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(701),
    [anon_sym_unchecked] = ACTIONS(693),
    [anon_sym_continue] = ACTIONS(703),
    [anon_sym_do] = ACTIONS(705),
    [anon_sym_while] = ACTIONS(707),
    [anon_sym_for] = ACTIONS(709),
    [anon_sym_lock] = ACTIONS(711),
    [anon_sym_yield] = ACTIONS(713),
    [anon_sym_switch] = ACTIONS(715),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(739),
    [anon_sym_try] = ACTIONS(719),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(741),
    [anon_sym_foreach] = ACTIONS(723),
    [anon_sym_goto] = ACTIONS(725),
    [anon_sym_if] = ACTIONS(727),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(731),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [83] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2659),
    [sym_variable_declaration] = STATE(9524),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6870),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2673),
    [sym_break_statement] = STATE(2659),
    [sym_checked_statement] = STATE(2659),
    [sym_continue_statement] = STATE(2659),
    [sym_do_statement] = STATE(2659),
    [sym_empty_statement] = STATE(2659),
    [sym_expression_statement] = STATE(2659),
    [sym_fixed_statement] = STATE(2659),
    [sym_for_statement] = STATE(2659),
    [sym_return_statement] = STATE(2659),
    [sym_lock_statement] = STATE(2659),
    [sym_yield_statement] = STATE(2659),
    [sym_switch_statement] = STATE(2659),
    [sym_throw_statement] = STATE(2659),
    [sym_try_statement] = STATE(2659),
    [sym_unsafe_statement] = STATE(2659),
    [sym_using_statement] = STATE(2659),
    [sym_foreach_statement] = STATE(2659),
    [sym_goto_statement] = STATE(2659),
    [sym_labeled_statement] = STATE(2659),
    [sym_if_statement] = STATE(2659),
    [sym_while_statement] = STATE(2659),
    [sym_local_declaration_statement] = STATE(2659),
    [sym_local_function_statement] = STATE(2659),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6347),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2847),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2659),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(83),
    [sym_preproc_endregion] = STATE(83),
    [sym_preproc_line] = STATE(83),
    [sym_preproc_pragma] = STATE(83),
    [sym_preproc_nullable] = STATE(83),
    [sym_preproc_error] = STATE(83),
    [sym_preproc_warning] = STATE(83),
    [sym_preproc_define] = STATE(83),
    [sym_preproc_undef] = STATE(83),
    [aux_sym_class_declaration_repeat1] = STATE(2935),
    [aux_sym_class_declaration_repeat2] = STATE(3094),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(663),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(665),
    [anon_sym_unsafe] = ACTIONS(667),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(677),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(689),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(693),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(701),
    [anon_sym_unchecked] = ACTIONS(693),
    [anon_sym_continue] = ACTIONS(703),
    [anon_sym_do] = ACTIONS(705),
    [anon_sym_while] = ACTIONS(707),
    [anon_sym_for] = ACTIONS(709),
    [anon_sym_lock] = ACTIONS(711),
    [anon_sym_yield] = ACTIONS(713),
    [anon_sym_switch] = ACTIONS(715),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(739),
    [anon_sym_try] = ACTIONS(719),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(741),
    [anon_sym_foreach] = ACTIONS(723),
    [anon_sym_goto] = ACTIONS(725),
    [anon_sym_if] = ACTIONS(727),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(731),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [84] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2659),
    [sym_variable_declaration] = STATE(9524),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6870),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2657),
    [sym_break_statement] = STATE(2659),
    [sym_checked_statement] = STATE(2659),
    [sym_continue_statement] = STATE(2659),
    [sym_do_statement] = STATE(2659),
    [sym_empty_statement] = STATE(2659),
    [sym_expression_statement] = STATE(2659),
    [sym_fixed_statement] = STATE(2659),
    [sym_for_statement] = STATE(2659),
    [sym_return_statement] = STATE(2659),
    [sym_lock_statement] = STATE(2659),
    [sym_yield_statement] = STATE(2659),
    [sym_switch_statement] = STATE(2659),
    [sym_throw_statement] = STATE(2659),
    [sym_try_statement] = STATE(2659),
    [sym_unsafe_statement] = STATE(2659),
    [sym_using_statement] = STATE(2659),
    [sym_foreach_statement] = STATE(2659),
    [sym_goto_statement] = STATE(2659),
    [sym_labeled_statement] = STATE(2659),
    [sym_if_statement] = STATE(2659),
    [sym_while_statement] = STATE(2659),
    [sym_local_declaration_statement] = STATE(2659),
    [sym_local_function_statement] = STATE(2659),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6347),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2847),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2659),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(84),
    [sym_preproc_endregion] = STATE(84),
    [sym_preproc_line] = STATE(84),
    [sym_preproc_pragma] = STATE(84),
    [sym_preproc_nullable] = STATE(84),
    [sym_preproc_error] = STATE(84),
    [sym_preproc_warning] = STATE(84),
    [sym_preproc_define] = STATE(84),
    [sym_preproc_undef] = STATE(84),
    [aux_sym_class_declaration_repeat1] = STATE(2935),
    [aux_sym_class_declaration_repeat2] = STATE(3094),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(663),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(665),
    [anon_sym_unsafe] = ACTIONS(667),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(677),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(689),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(693),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(701),
    [anon_sym_unchecked] = ACTIONS(693),
    [anon_sym_continue] = ACTIONS(703),
    [anon_sym_do] = ACTIONS(705),
    [anon_sym_while] = ACTIONS(707),
    [anon_sym_for] = ACTIONS(709),
    [anon_sym_lock] = ACTIONS(711),
    [anon_sym_yield] = ACTIONS(713),
    [anon_sym_switch] = ACTIONS(715),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(739),
    [anon_sym_try] = ACTIONS(719),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(741),
    [anon_sym_foreach] = ACTIONS(723),
    [anon_sym_goto] = ACTIONS(725),
    [anon_sym_if] = ACTIONS(727),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(731),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [85] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2659),
    [sym_variable_declaration] = STATE(9524),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6870),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2716),
    [sym_break_statement] = STATE(2659),
    [sym_checked_statement] = STATE(2659),
    [sym_continue_statement] = STATE(2659),
    [sym_do_statement] = STATE(2659),
    [sym_empty_statement] = STATE(2659),
    [sym_expression_statement] = STATE(2659),
    [sym_fixed_statement] = STATE(2659),
    [sym_for_statement] = STATE(2659),
    [sym_return_statement] = STATE(2659),
    [sym_lock_statement] = STATE(2659),
    [sym_yield_statement] = STATE(2659),
    [sym_switch_statement] = STATE(2659),
    [sym_throw_statement] = STATE(2659),
    [sym_try_statement] = STATE(2659),
    [sym_unsafe_statement] = STATE(2659),
    [sym_using_statement] = STATE(2659),
    [sym_foreach_statement] = STATE(2659),
    [sym_goto_statement] = STATE(2659),
    [sym_labeled_statement] = STATE(2659),
    [sym_if_statement] = STATE(2659),
    [sym_while_statement] = STATE(2659),
    [sym_local_declaration_statement] = STATE(2659),
    [sym_local_function_statement] = STATE(2659),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6347),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2847),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2659),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(85),
    [sym_preproc_endregion] = STATE(85),
    [sym_preproc_line] = STATE(85),
    [sym_preproc_pragma] = STATE(85),
    [sym_preproc_nullable] = STATE(85),
    [sym_preproc_error] = STATE(85),
    [sym_preproc_warning] = STATE(85),
    [sym_preproc_define] = STATE(85),
    [sym_preproc_undef] = STATE(85),
    [aux_sym_class_declaration_repeat1] = STATE(2935),
    [aux_sym_class_declaration_repeat2] = STATE(3094),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(663),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(665),
    [anon_sym_unsafe] = ACTIONS(667),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(677),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(689),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(693),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(701),
    [anon_sym_unchecked] = ACTIONS(693),
    [anon_sym_continue] = ACTIONS(703),
    [anon_sym_do] = ACTIONS(705),
    [anon_sym_while] = ACTIONS(707),
    [anon_sym_for] = ACTIONS(709),
    [anon_sym_lock] = ACTIONS(711),
    [anon_sym_yield] = ACTIONS(713),
    [anon_sym_switch] = ACTIONS(715),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(739),
    [anon_sym_try] = ACTIONS(719),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(741),
    [anon_sym_foreach] = ACTIONS(723),
    [anon_sym_goto] = ACTIONS(725),
    [anon_sym_if] = ACTIONS(727),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(731),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [86] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2659),
    [sym_variable_declaration] = STATE(9524),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6870),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2663),
    [sym_break_statement] = STATE(2659),
    [sym_checked_statement] = STATE(2659),
    [sym_continue_statement] = STATE(2659),
    [sym_do_statement] = STATE(2659),
    [sym_empty_statement] = STATE(2659),
    [sym_expression_statement] = STATE(2659),
    [sym_fixed_statement] = STATE(2659),
    [sym_for_statement] = STATE(2659),
    [sym_return_statement] = STATE(2659),
    [sym_lock_statement] = STATE(2659),
    [sym_yield_statement] = STATE(2659),
    [sym_switch_statement] = STATE(2659),
    [sym_throw_statement] = STATE(2659),
    [sym_try_statement] = STATE(2659),
    [sym_unsafe_statement] = STATE(2659),
    [sym_using_statement] = STATE(2659),
    [sym_foreach_statement] = STATE(2659),
    [sym_goto_statement] = STATE(2659),
    [sym_labeled_statement] = STATE(2659),
    [sym_if_statement] = STATE(2659),
    [sym_while_statement] = STATE(2659),
    [sym_local_declaration_statement] = STATE(2659),
    [sym_local_function_statement] = STATE(2659),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6347),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2847),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2659),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(86),
    [sym_preproc_endregion] = STATE(86),
    [sym_preproc_line] = STATE(86),
    [sym_preproc_pragma] = STATE(86),
    [sym_preproc_nullable] = STATE(86),
    [sym_preproc_error] = STATE(86),
    [sym_preproc_warning] = STATE(86),
    [sym_preproc_define] = STATE(86),
    [sym_preproc_undef] = STATE(86),
    [aux_sym_class_declaration_repeat1] = STATE(2935),
    [aux_sym_class_declaration_repeat2] = STATE(3094),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(663),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(665),
    [anon_sym_unsafe] = ACTIONS(667),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(677),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(689),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(693),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(701),
    [anon_sym_unchecked] = ACTIONS(693),
    [anon_sym_continue] = ACTIONS(703),
    [anon_sym_do] = ACTIONS(705),
    [anon_sym_while] = ACTIONS(707),
    [anon_sym_for] = ACTIONS(709),
    [anon_sym_lock] = ACTIONS(711),
    [anon_sym_yield] = ACTIONS(713),
    [anon_sym_switch] = ACTIONS(715),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(739),
    [anon_sym_try] = ACTIONS(719),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(741),
    [anon_sym_foreach] = ACTIONS(723),
    [anon_sym_goto] = ACTIONS(725),
    [anon_sym_if] = ACTIONS(727),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(731),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [87] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(8858),
    [sym_variable_declaration] = STATE(9360),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6862),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(8711),
    [sym_break_statement] = STATE(8858),
    [sym_checked_statement] = STATE(8858),
    [sym_continue_statement] = STATE(8858),
    [sym_do_statement] = STATE(8858),
    [sym_empty_statement] = STATE(8858),
    [sym_expression_statement] = STATE(8858),
    [sym_fixed_statement] = STATE(8858),
    [sym_for_statement] = STATE(8858),
    [sym_return_statement] = STATE(8858),
    [sym_lock_statement] = STATE(8858),
    [sym_yield_statement] = STATE(8858),
    [sym_switch_statement] = STATE(8858),
    [sym_throw_statement] = STATE(8858),
    [sym_try_statement] = STATE(8858),
    [sym_unsafe_statement] = STATE(8858),
    [sym_using_statement] = STATE(8858),
    [sym_foreach_statement] = STATE(8858),
    [sym_goto_statement] = STATE(8858),
    [sym_labeled_statement] = STATE(8858),
    [sym_if_statement] = STATE(8858),
    [sym_while_statement] = STATE(8858),
    [sym_local_declaration_statement] = STATE(8858),
    [sym_local_function_statement] = STATE(8858),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6755),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2904),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(8858),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(87),
    [sym_preproc_endregion] = STATE(87),
    [sym_preproc_line] = STATE(87),
    [sym_preproc_pragma] = STATE(87),
    [sym_preproc_nullable] = STATE(87),
    [sym_preproc_error] = STATE(87),
    [sym_preproc_warning] = STATE(87),
    [sym_preproc_define] = STATE(87),
    [sym_preproc_undef] = STATE(87),
    [aux_sym_class_declaration_repeat1] = STATE(2931),
    [aux_sym_class_declaration_repeat2] = STATE(3115),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(1011),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1013),
    [anon_sym_unsafe] = ACTIONS(1015),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(1017),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1019),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1021),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1023),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(1025),
    [anon_sym_unchecked] = ACTIONS(1023),
    [anon_sym_continue] = ACTIONS(1027),
    [anon_sym_do] = ACTIONS(1029),
    [anon_sym_while] = ACTIONS(1031),
    [anon_sym_for] = ACTIONS(1033),
    [anon_sym_lock] = ACTIONS(1035),
    [anon_sym_yield] = ACTIONS(1037),
    [anon_sym_switch] = ACTIONS(1039),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1041),
    [anon_sym_try] = ACTIONS(1043),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1045),
    [anon_sym_foreach] = ACTIONS(1047),
    [anon_sym_goto] = ACTIONS(1049),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1053),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [88] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(8858),
    [sym_variable_declaration] = STATE(9360),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6862),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(8879),
    [sym_break_statement] = STATE(8858),
    [sym_checked_statement] = STATE(8858),
    [sym_continue_statement] = STATE(8858),
    [sym_do_statement] = STATE(8858),
    [sym_empty_statement] = STATE(8858),
    [sym_expression_statement] = STATE(8858),
    [sym_fixed_statement] = STATE(8858),
    [sym_for_statement] = STATE(8858),
    [sym_return_statement] = STATE(8858),
    [sym_lock_statement] = STATE(8858),
    [sym_yield_statement] = STATE(8858),
    [sym_switch_statement] = STATE(8858),
    [sym_throw_statement] = STATE(8858),
    [sym_try_statement] = STATE(8858),
    [sym_unsafe_statement] = STATE(8858),
    [sym_using_statement] = STATE(8858),
    [sym_foreach_statement] = STATE(8858),
    [sym_goto_statement] = STATE(8858),
    [sym_labeled_statement] = STATE(8858),
    [sym_if_statement] = STATE(8858),
    [sym_while_statement] = STATE(8858),
    [sym_local_declaration_statement] = STATE(8858),
    [sym_local_function_statement] = STATE(8858),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6755),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2904),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(8858),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(88),
    [sym_preproc_endregion] = STATE(88),
    [sym_preproc_line] = STATE(88),
    [sym_preproc_pragma] = STATE(88),
    [sym_preproc_nullable] = STATE(88),
    [sym_preproc_error] = STATE(88),
    [sym_preproc_warning] = STATE(88),
    [sym_preproc_define] = STATE(88),
    [sym_preproc_undef] = STATE(88),
    [aux_sym_class_declaration_repeat1] = STATE(2931),
    [aux_sym_class_declaration_repeat2] = STATE(3115),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(1011),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1013),
    [anon_sym_unsafe] = ACTIONS(1015),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(1017),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1019),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1021),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1023),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(1025),
    [anon_sym_unchecked] = ACTIONS(1023),
    [anon_sym_continue] = ACTIONS(1027),
    [anon_sym_do] = ACTIONS(1029),
    [anon_sym_while] = ACTIONS(1031),
    [anon_sym_for] = ACTIONS(1033),
    [anon_sym_lock] = ACTIONS(1035),
    [anon_sym_yield] = ACTIONS(1037),
    [anon_sym_switch] = ACTIONS(1039),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1041),
    [anon_sym_try] = ACTIONS(1043),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1045),
    [anon_sym_foreach] = ACTIONS(1047),
    [anon_sym_goto] = ACTIONS(1049),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1053),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [89] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(8858),
    [sym_variable_declaration] = STATE(9360),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6862),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(8948),
    [sym_break_statement] = STATE(8858),
    [sym_checked_statement] = STATE(8858),
    [sym_continue_statement] = STATE(8858),
    [sym_do_statement] = STATE(8858),
    [sym_empty_statement] = STATE(8858),
    [sym_expression_statement] = STATE(8858),
    [sym_fixed_statement] = STATE(8858),
    [sym_for_statement] = STATE(8858),
    [sym_return_statement] = STATE(8858),
    [sym_lock_statement] = STATE(8858),
    [sym_yield_statement] = STATE(8858),
    [sym_switch_statement] = STATE(8858),
    [sym_throw_statement] = STATE(8858),
    [sym_try_statement] = STATE(8858),
    [sym_unsafe_statement] = STATE(8858),
    [sym_using_statement] = STATE(8858),
    [sym_foreach_statement] = STATE(8858),
    [sym_goto_statement] = STATE(8858),
    [sym_labeled_statement] = STATE(8858),
    [sym_if_statement] = STATE(8858),
    [sym_while_statement] = STATE(8858),
    [sym_local_declaration_statement] = STATE(8858),
    [sym_local_function_statement] = STATE(8858),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6755),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2904),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(8858),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(89),
    [sym_preproc_endregion] = STATE(89),
    [sym_preproc_line] = STATE(89),
    [sym_preproc_pragma] = STATE(89),
    [sym_preproc_nullable] = STATE(89),
    [sym_preproc_error] = STATE(89),
    [sym_preproc_warning] = STATE(89),
    [sym_preproc_define] = STATE(89),
    [sym_preproc_undef] = STATE(89),
    [aux_sym_class_declaration_repeat1] = STATE(2931),
    [aux_sym_class_declaration_repeat2] = STATE(3115),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(1011),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1013),
    [anon_sym_unsafe] = ACTIONS(1015),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(1017),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1019),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1021),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1023),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(1025),
    [anon_sym_unchecked] = ACTIONS(1023),
    [anon_sym_continue] = ACTIONS(1027),
    [anon_sym_do] = ACTIONS(1029),
    [anon_sym_while] = ACTIONS(1031),
    [anon_sym_for] = ACTIONS(1033),
    [anon_sym_lock] = ACTIONS(1035),
    [anon_sym_yield] = ACTIONS(1037),
    [anon_sym_switch] = ACTIONS(1039),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1041),
    [anon_sym_try] = ACTIONS(1043),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1045),
    [anon_sym_foreach] = ACTIONS(1047),
    [anon_sym_goto] = ACTIONS(1049),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1053),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [90] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(8858),
    [sym_variable_declaration] = STATE(9360),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6862),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(8957),
    [sym_break_statement] = STATE(8858),
    [sym_checked_statement] = STATE(8858),
    [sym_continue_statement] = STATE(8858),
    [sym_do_statement] = STATE(8858),
    [sym_empty_statement] = STATE(8858),
    [sym_expression_statement] = STATE(8858),
    [sym_fixed_statement] = STATE(8858),
    [sym_for_statement] = STATE(8858),
    [sym_return_statement] = STATE(8858),
    [sym_lock_statement] = STATE(8858),
    [sym_yield_statement] = STATE(8858),
    [sym_switch_statement] = STATE(8858),
    [sym_throw_statement] = STATE(8858),
    [sym_try_statement] = STATE(8858),
    [sym_unsafe_statement] = STATE(8858),
    [sym_using_statement] = STATE(8858),
    [sym_foreach_statement] = STATE(8858),
    [sym_goto_statement] = STATE(8858),
    [sym_labeled_statement] = STATE(8858),
    [sym_if_statement] = STATE(8858),
    [sym_while_statement] = STATE(8858),
    [sym_local_declaration_statement] = STATE(8858),
    [sym_local_function_statement] = STATE(8858),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6755),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2904),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(8858),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(90),
    [sym_preproc_endregion] = STATE(90),
    [sym_preproc_line] = STATE(90),
    [sym_preproc_pragma] = STATE(90),
    [sym_preproc_nullable] = STATE(90),
    [sym_preproc_error] = STATE(90),
    [sym_preproc_warning] = STATE(90),
    [sym_preproc_define] = STATE(90),
    [sym_preproc_undef] = STATE(90),
    [aux_sym_class_declaration_repeat1] = STATE(2931),
    [aux_sym_class_declaration_repeat2] = STATE(3115),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(1011),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1013),
    [anon_sym_unsafe] = ACTIONS(1015),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(1017),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1019),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1021),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1023),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(1025),
    [anon_sym_unchecked] = ACTIONS(1023),
    [anon_sym_continue] = ACTIONS(1027),
    [anon_sym_do] = ACTIONS(1029),
    [anon_sym_while] = ACTIONS(1031),
    [anon_sym_for] = ACTIONS(1033),
    [anon_sym_lock] = ACTIONS(1035),
    [anon_sym_yield] = ACTIONS(1037),
    [anon_sym_switch] = ACTIONS(1039),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1041),
    [anon_sym_try] = ACTIONS(1043),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1045),
    [anon_sym_foreach] = ACTIONS(1047),
    [anon_sym_goto] = ACTIONS(1049),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1053),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [91] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(8858),
    [sym_variable_declaration] = STATE(9360),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6862),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(8960),
    [sym_break_statement] = STATE(8858),
    [sym_checked_statement] = STATE(8858),
    [sym_continue_statement] = STATE(8858),
    [sym_do_statement] = STATE(8858),
    [sym_empty_statement] = STATE(8858),
    [sym_expression_statement] = STATE(8858),
    [sym_fixed_statement] = STATE(8858),
    [sym_for_statement] = STATE(8858),
    [sym_return_statement] = STATE(8858),
    [sym_lock_statement] = STATE(8858),
    [sym_yield_statement] = STATE(8858),
    [sym_switch_statement] = STATE(8858),
    [sym_throw_statement] = STATE(8858),
    [sym_try_statement] = STATE(8858),
    [sym_unsafe_statement] = STATE(8858),
    [sym_using_statement] = STATE(8858),
    [sym_foreach_statement] = STATE(8858),
    [sym_goto_statement] = STATE(8858),
    [sym_labeled_statement] = STATE(8858),
    [sym_if_statement] = STATE(8858),
    [sym_while_statement] = STATE(8858),
    [sym_local_declaration_statement] = STATE(8858),
    [sym_local_function_statement] = STATE(8858),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6755),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2904),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(8858),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(91),
    [sym_preproc_endregion] = STATE(91),
    [sym_preproc_line] = STATE(91),
    [sym_preproc_pragma] = STATE(91),
    [sym_preproc_nullable] = STATE(91),
    [sym_preproc_error] = STATE(91),
    [sym_preproc_warning] = STATE(91),
    [sym_preproc_define] = STATE(91),
    [sym_preproc_undef] = STATE(91),
    [aux_sym_class_declaration_repeat1] = STATE(2931),
    [aux_sym_class_declaration_repeat2] = STATE(3115),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(1011),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1013),
    [anon_sym_unsafe] = ACTIONS(1015),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(1017),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1019),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1021),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1023),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(1025),
    [anon_sym_unchecked] = ACTIONS(1023),
    [anon_sym_continue] = ACTIONS(1027),
    [anon_sym_do] = ACTIONS(1029),
    [anon_sym_while] = ACTIONS(1031),
    [anon_sym_for] = ACTIONS(1033),
    [anon_sym_lock] = ACTIONS(1035),
    [anon_sym_yield] = ACTIONS(1037),
    [anon_sym_switch] = ACTIONS(1039),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1041),
    [anon_sym_try] = ACTIONS(1043),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1045),
    [anon_sym_foreach] = ACTIONS(1047),
    [anon_sym_goto] = ACTIONS(1049),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1053),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [92] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(8858),
    [sym_variable_declaration] = STATE(9360),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6862),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(8972),
    [sym_break_statement] = STATE(8858),
    [sym_checked_statement] = STATE(8858),
    [sym_continue_statement] = STATE(8858),
    [sym_do_statement] = STATE(8858),
    [sym_empty_statement] = STATE(8858),
    [sym_expression_statement] = STATE(8858),
    [sym_fixed_statement] = STATE(8858),
    [sym_for_statement] = STATE(8858),
    [sym_return_statement] = STATE(8858),
    [sym_lock_statement] = STATE(8858),
    [sym_yield_statement] = STATE(8858),
    [sym_switch_statement] = STATE(8858),
    [sym_throw_statement] = STATE(8858),
    [sym_try_statement] = STATE(8858),
    [sym_unsafe_statement] = STATE(8858),
    [sym_using_statement] = STATE(8858),
    [sym_foreach_statement] = STATE(8858),
    [sym_goto_statement] = STATE(8858),
    [sym_labeled_statement] = STATE(8858),
    [sym_if_statement] = STATE(8858),
    [sym_while_statement] = STATE(8858),
    [sym_local_declaration_statement] = STATE(8858),
    [sym_local_function_statement] = STATE(8858),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6755),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2904),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(8858),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(92),
    [sym_preproc_endregion] = STATE(92),
    [sym_preproc_line] = STATE(92),
    [sym_preproc_pragma] = STATE(92),
    [sym_preproc_nullable] = STATE(92),
    [sym_preproc_error] = STATE(92),
    [sym_preproc_warning] = STATE(92),
    [sym_preproc_define] = STATE(92),
    [sym_preproc_undef] = STATE(92),
    [aux_sym_class_declaration_repeat1] = STATE(2931),
    [aux_sym_class_declaration_repeat2] = STATE(3115),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(1011),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1013),
    [anon_sym_unsafe] = ACTIONS(1015),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(1017),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1019),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1021),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1023),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(1025),
    [anon_sym_unchecked] = ACTIONS(1023),
    [anon_sym_continue] = ACTIONS(1027),
    [anon_sym_do] = ACTIONS(1029),
    [anon_sym_while] = ACTIONS(1031),
    [anon_sym_for] = ACTIONS(1033),
    [anon_sym_lock] = ACTIONS(1035),
    [anon_sym_yield] = ACTIONS(1037),
    [anon_sym_switch] = ACTIONS(1039),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1041),
    [anon_sym_try] = ACTIONS(1043),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1045),
    [anon_sym_foreach] = ACTIONS(1047),
    [anon_sym_goto] = ACTIONS(1049),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1053),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [93] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(8858),
    [sym_variable_declaration] = STATE(9360),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6862),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(8861),
    [sym_break_statement] = STATE(8858),
    [sym_checked_statement] = STATE(8858),
    [sym_continue_statement] = STATE(8858),
    [sym_do_statement] = STATE(8858),
    [sym_empty_statement] = STATE(8858),
    [sym_expression_statement] = STATE(8858),
    [sym_fixed_statement] = STATE(8858),
    [sym_for_statement] = STATE(8858),
    [sym_return_statement] = STATE(8858),
    [sym_lock_statement] = STATE(8858),
    [sym_yield_statement] = STATE(8858),
    [sym_switch_statement] = STATE(8858),
    [sym_throw_statement] = STATE(8858),
    [sym_try_statement] = STATE(8858),
    [sym_unsafe_statement] = STATE(8858),
    [sym_using_statement] = STATE(8858),
    [sym_foreach_statement] = STATE(8858),
    [sym_goto_statement] = STATE(8858),
    [sym_labeled_statement] = STATE(8858),
    [sym_if_statement] = STATE(8858),
    [sym_while_statement] = STATE(8858),
    [sym_local_declaration_statement] = STATE(8858),
    [sym_local_function_statement] = STATE(8858),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6755),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2904),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(8858),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(93),
    [sym_preproc_endregion] = STATE(93),
    [sym_preproc_line] = STATE(93),
    [sym_preproc_pragma] = STATE(93),
    [sym_preproc_nullable] = STATE(93),
    [sym_preproc_error] = STATE(93),
    [sym_preproc_warning] = STATE(93),
    [sym_preproc_define] = STATE(93),
    [sym_preproc_undef] = STATE(93),
    [aux_sym_class_declaration_repeat1] = STATE(2931),
    [aux_sym_class_declaration_repeat2] = STATE(3115),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(1011),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1013),
    [anon_sym_unsafe] = ACTIONS(1015),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(1017),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1019),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1021),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1023),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(1025),
    [anon_sym_unchecked] = ACTIONS(1023),
    [anon_sym_continue] = ACTIONS(1027),
    [anon_sym_do] = ACTIONS(1029),
    [anon_sym_while] = ACTIONS(1031),
    [anon_sym_for] = ACTIONS(1033),
    [anon_sym_lock] = ACTIONS(1035),
    [anon_sym_yield] = ACTIONS(1037),
    [anon_sym_switch] = ACTIONS(1039),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1041),
    [anon_sym_try] = ACTIONS(1043),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1045),
    [anon_sym_foreach] = ACTIONS(1047),
    [anon_sym_goto] = ACTIONS(1049),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1053),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [94] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(8858),
    [sym_variable_declaration] = STATE(9360),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6862),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(8881),
    [sym_break_statement] = STATE(8858),
    [sym_checked_statement] = STATE(8858),
    [sym_continue_statement] = STATE(8858),
    [sym_do_statement] = STATE(8858),
    [sym_empty_statement] = STATE(8858),
    [sym_expression_statement] = STATE(8858),
    [sym_fixed_statement] = STATE(8858),
    [sym_for_statement] = STATE(8858),
    [sym_return_statement] = STATE(8858),
    [sym_lock_statement] = STATE(8858),
    [sym_yield_statement] = STATE(8858),
    [sym_switch_statement] = STATE(8858),
    [sym_throw_statement] = STATE(8858),
    [sym_try_statement] = STATE(8858),
    [sym_unsafe_statement] = STATE(8858),
    [sym_using_statement] = STATE(8858),
    [sym_foreach_statement] = STATE(8858),
    [sym_goto_statement] = STATE(8858),
    [sym_labeled_statement] = STATE(8858),
    [sym_if_statement] = STATE(8858),
    [sym_while_statement] = STATE(8858),
    [sym_local_declaration_statement] = STATE(8858),
    [sym_local_function_statement] = STATE(8858),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6755),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2904),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(8858),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(94),
    [sym_preproc_endregion] = STATE(94),
    [sym_preproc_line] = STATE(94),
    [sym_preproc_pragma] = STATE(94),
    [sym_preproc_nullable] = STATE(94),
    [sym_preproc_error] = STATE(94),
    [sym_preproc_warning] = STATE(94),
    [sym_preproc_define] = STATE(94),
    [sym_preproc_undef] = STATE(94),
    [aux_sym_class_declaration_repeat1] = STATE(2931),
    [aux_sym_class_declaration_repeat2] = STATE(3115),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(1011),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1013),
    [anon_sym_unsafe] = ACTIONS(1015),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(1017),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1019),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1021),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1023),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(1025),
    [anon_sym_unchecked] = ACTIONS(1023),
    [anon_sym_continue] = ACTIONS(1027),
    [anon_sym_do] = ACTIONS(1029),
    [anon_sym_while] = ACTIONS(1031),
    [anon_sym_for] = ACTIONS(1033),
    [anon_sym_lock] = ACTIONS(1035),
    [anon_sym_yield] = ACTIONS(1037),
    [anon_sym_switch] = ACTIONS(1039),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1041),
    [anon_sym_try] = ACTIONS(1043),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1045),
    [anon_sym_foreach] = ACTIONS(1047),
    [anon_sym_goto] = ACTIONS(1049),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1053),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [95] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(8858),
    [sym_variable_declaration] = STATE(9360),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6862),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(8876),
    [sym_break_statement] = STATE(8858),
    [sym_checked_statement] = STATE(8858),
    [sym_continue_statement] = STATE(8858),
    [sym_do_statement] = STATE(8858),
    [sym_empty_statement] = STATE(8858),
    [sym_expression_statement] = STATE(8858),
    [sym_fixed_statement] = STATE(8858),
    [sym_for_statement] = STATE(8858),
    [sym_return_statement] = STATE(8858),
    [sym_lock_statement] = STATE(8858),
    [sym_yield_statement] = STATE(8858),
    [sym_switch_statement] = STATE(8858),
    [sym_throw_statement] = STATE(8858),
    [sym_try_statement] = STATE(8858),
    [sym_unsafe_statement] = STATE(8858),
    [sym_using_statement] = STATE(8858),
    [sym_foreach_statement] = STATE(8858),
    [sym_goto_statement] = STATE(8858),
    [sym_labeled_statement] = STATE(8858),
    [sym_if_statement] = STATE(8858),
    [sym_while_statement] = STATE(8858),
    [sym_local_declaration_statement] = STATE(8858),
    [sym_local_function_statement] = STATE(8858),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6755),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2904),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(8858),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(95),
    [sym_preproc_endregion] = STATE(95),
    [sym_preproc_line] = STATE(95),
    [sym_preproc_pragma] = STATE(95),
    [sym_preproc_nullable] = STATE(95),
    [sym_preproc_error] = STATE(95),
    [sym_preproc_warning] = STATE(95),
    [sym_preproc_define] = STATE(95),
    [sym_preproc_undef] = STATE(95),
    [aux_sym_class_declaration_repeat1] = STATE(2931),
    [aux_sym_class_declaration_repeat2] = STATE(3115),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(1011),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1013),
    [anon_sym_unsafe] = ACTIONS(1015),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(1017),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1019),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1021),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1023),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(1025),
    [anon_sym_unchecked] = ACTIONS(1023),
    [anon_sym_continue] = ACTIONS(1027),
    [anon_sym_do] = ACTIONS(1029),
    [anon_sym_while] = ACTIONS(1031),
    [anon_sym_for] = ACTIONS(1033),
    [anon_sym_lock] = ACTIONS(1035),
    [anon_sym_yield] = ACTIONS(1037),
    [anon_sym_switch] = ACTIONS(1039),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1041),
    [anon_sym_try] = ACTIONS(1043),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1045),
    [anon_sym_foreach] = ACTIONS(1047),
    [anon_sym_goto] = ACTIONS(1049),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1053),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [96] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(8858),
    [sym_variable_declaration] = STATE(9360),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6862),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(8880),
    [sym_break_statement] = STATE(8858),
    [sym_checked_statement] = STATE(8858),
    [sym_continue_statement] = STATE(8858),
    [sym_do_statement] = STATE(8858),
    [sym_empty_statement] = STATE(8858),
    [sym_expression_statement] = STATE(8858),
    [sym_fixed_statement] = STATE(8858),
    [sym_for_statement] = STATE(8858),
    [sym_return_statement] = STATE(8858),
    [sym_lock_statement] = STATE(8858),
    [sym_yield_statement] = STATE(8858),
    [sym_switch_statement] = STATE(8858),
    [sym_throw_statement] = STATE(8858),
    [sym_try_statement] = STATE(8858),
    [sym_unsafe_statement] = STATE(8858),
    [sym_using_statement] = STATE(8858),
    [sym_foreach_statement] = STATE(8858),
    [sym_goto_statement] = STATE(8858),
    [sym_labeled_statement] = STATE(8858),
    [sym_if_statement] = STATE(8858),
    [sym_while_statement] = STATE(8858),
    [sym_local_declaration_statement] = STATE(8858),
    [sym_local_function_statement] = STATE(8858),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6755),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2904),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(8858),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(96),
    [sym_preproc_endregion] = STATE(96),
    [sym_preproc_line] = STATE(96),
    [sym_preproc_pragma] = STATE(96),
    [sym_preproc_nullable] = STATE(96),
    [sym_preproc_error] = STATE(96),
    [sym_preproc_warning] = STATE(96),
    [sym_preproc_define] = STATE(96),
    [sym_preproc_undef] = STATE(96),
    [aux_sym_class_declaration_repeat1] = STATE(2931),
    [aux_sym_class_declaration_repeat2] = STATE(3115),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(1011),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1013),
    [anon_sym_unsafe] = ACTIONS(1015),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(1017),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1019),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1021),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1023),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(1025),
    [anon_sym_unchecked] = ACTIONS(1023),
    [anon_sym_continue] = ACTIONS(1027),
    [anon_sym_do] = ACTIONS(1029),
    [anon_sym_while] = ACTIONS(1031),
    [anon_sym_for] = ACTIONS(1033),
    [anon_sym_lock] = ACTIONS(1035),
    [anon_sym_yield] = ACTIONS(1037),
    [anon_sym_switch] = ACTIONS(1039),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1041),
    [anon_sym_try] = ACTIONS(1043),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1045),
    [anon_sym_foreach] = ACTIONS(1047),
    [anon_sym_goto] = ACTIONS(1049),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1053),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [97] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(8858),
    [sym_variable_declaration] = STATE(9360),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6862),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(8925),
    [sym_break_statement] = STATE(8858),
    [sym_checked_statement] = STATE(8858),
    [sym_continue_statement] = STATE(8858),
    [sym_do_statement] = STATE(8858),
    [sym_empty_statement] = STATE(8858),
    [sym_expression_statement] = STATE(8858),
    [sym_fixed_statement] = STATE(8858),
    [sym_for_statement] = STATE(8858),
    [sym_return_statement] = STATE(8858),
    [sym_lock_statement] = STATE(8858),
    [sym_yield_statement] = STATE(8858),
    [sym_switch_statement] = STATE(8858),
    [sym_throw_statement] = STATE(8858),
    [sym_try_statement] = STATE(8858),
    [sym_unsafe_statement] = STATE(8858),
    [sym_using_statement] = STATE(8858),
    [sym_foreach_statement] = STATE(8858),
    [sym_goto_statement] = STATE(8858),
    [sym_labeled_statement] = STATE(8858),
    [sym_if_statement] = STATE(8858),
    [sym_while_statement] = STATE(8858),
    [sym_local_declaration_statement] = STATE(8858),
    [sym_local_function_statement] = STATE(8858),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6755),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2904),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(8858),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(97),
    [sym_preproc_endregion] = STATE(97),
    [sym_preproc_line] = STATE(97),
    [sym_preproc_pragma] = STATE(97),
    [sym_preproc_nullable] = STATE(97),
    [sym_preproc_error] = STATE(97),
    [sym_preproc_warning] = STATE(97),
    [sym_preproc_define] = STATE(97),
    [sym_preproc_undef] = STATE(97),
    [aux_sym_class_declaration_repeat1] = STATE(2931),
    [aux_sym_class_declaration_repeat2] = STATE(3115),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(1011),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1013),
    [anon_sym_unsafe] = ACTIONS(1015),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(1017),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1019),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1021),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1023),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(1025),
    [anon_sym_unchecked] = ACTIONS(1023),
    [anon_sym_continue] = ACTIONS(1027),
    [anon_sym_do] = ACTIONS(1029),
    [anon_sym_while] = ACTIONS(1031),
    [anon_sym_for] = ACTIONS(1033),
    [anon_sym_lock] = ACTIONS(1035),
    [anon_sym_yield] = ACTIONS(1037),
    [anon_sym_switch] = ACTIONS(1039),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1041),
    [anon_sym_try] = ACTIONS(1043),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1045),
    [anon_sym_foreach] = ACTIONS(1047),
    [anon_sym_goto] = ACTIONS(1049),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1053),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [98] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(8858),
    [sym_variable_declaration] = STATE(9360),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6862),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(8889),
    [sym_break_statement] = STATE(8858),
    [sym_checked_statement] = STATE(8858),
    [sym_continue_statement] = STATE(8858),
    [sym_do_statement] = STATE(8858),
    [sym_empty_statement] = STATE(8858),
    [sym_expression_statement] = STATE(8858),
    [sym_fixed_statement] = STATE(8858),
    [sym_for_statement] = STATE(8858),
    [sym_return_statement] = STATE(8858),
    [sym_lock_statement] = STATE(8858),
    [sym_yield_statement] = STATE(8858),
    [sym_switch_statement] = STATE(8858),
    [sym_throw_statement] = STATE(8858),
    [sym_try_statement] = STATE(8858),
    [sym_unsafe_statement] = STATE(8858),
    [sym_using_statement] = STATE(8858),
    [sym_foreach_statement] = STATE(8858),
    [sym_goto_statement] = STATE(8858),
    [sym_labeled_statement] = STATE(8858),
    [sym_if_statement] = STATE(8858),
    [sym_while_statement] = STATE(8858),
    [sym_local_declaration_statement] = STATE(8858),
    [sym_local_function_statement] = STATE(8858),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6755),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2904),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(8858),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(98),
    [sym_preproc_endregion] = STATE(98),
    [sym_preproc_line] = STATE(98),
    [sym_preproc_pragma] = STATE(98),
    [sym_preproc_nullable] = STATE(98),
    [sym_preproc_error] = STATE(98),
    [sym_preproc_warning] = STATE(98),
    [sym_preproc_define] = STATE(98),
    [sym_preproc_undef] = STATE(98),
    [aux_sym_class_declaration_repeat1] = STATE(2931),
    [aux_sym_class_declaration_repeat2] = STATE(3115),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(1011),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1013),
    [anon_sym_unsafe] = ACTIONS(1015),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(1017),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1019),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1021),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1023),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(1025),
    [anon_sym_unchecked] = ACTIONS(1023),
    [anon_sym_continue] = ACTIONS(1027),
    [anon_sym_do] = ACTIONS(1029),
    [anon_sym_while] = ACTIONS(1031),
    [anon_sym_for] = ACTIONS(1033),
    [anon_sym_lock] = ACTIONS(1035),
    [anon_sym_yield] = ACTIONS(1037),
    [anon_sym_switch] = ACTIONS(1039),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1041),
    [anon_sym_try] = ACTIONS(1043),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1045),
    [anon_sym_foreach] = ACTIONS(1047),
    [anon_sym_goto] = ACTIONS(1049),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1053),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [99] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(8858),
    [sym_variable_declaration] = STATE(9360),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6862),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(8891),
    [sym_break_statement] = STATE(8858),
    [sym_checked_statement] = STATE(8858),
    [sym_continue_statement] = STATE(8858),
    [sym_do_statement] = STATE(8858),
    [sym_empty_statement] = STATE(8858),
    [sym_expression_statement] = STATE(8858),
    [sym_fixed_statement] = STATE(8858),
    [sym_for_statement] = STATE(8858),
    [sym_return_statement] = STATE(8858),
    [sym_lock_statement] = STATE(8858),
    [sym_yield_statement] = STATE(8858),
    [sym_switch_statement] = STATE(8858),
    [sym_throw_statement] = STATE(8858),
    [sym_try_statement] = STATE(8858),
    [sym_unsafe_statement] = STATE(8858),
    [sym_using_statement] = STATE(8858),
    [sym_foreach_statement] = STATE(8858),
    [sym_goto_statement] = STATE(8858),
    [sym_labeled_statement] = STATE(8858),
    [sym_if_statement] = STATE(8858),
    [sym_while_statement] = STATE(8858),
    [sym_local_declaration_statement] = STATE(8858),
    [sym_local_function_statement] = STATE(8858),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6755),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2904),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(8858),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(99),
    [sym_preproc_endregion] = STATE(99),
    [sym_preproc_line] = STATE(99),
    [sym_preproc_pragma] = STATE(99),
    [sym_preproc_nullable] = STATE(99),
    [sym_preproc_error] = STATE(99),
    [sym_preproc_warning] = STATE(99),
    [sym_preproc_define] = STATE(99),
    [sym_preproc_undef] = STATE(99),
    [aux_sym_class_declaration_repeat1] = STATE(2931),
    [aux_sym_class_declaration_repeat2] = STATE(3115),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(1011),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1013),
    [anon_sym_unsafe] = ACTIONS(1015),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(1017),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1019),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1021),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1023),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(1025),
    [anon_sym_unchecked] = ACTIONS(1023),
    [anon_sym_continue] = ACTIONS(1027),
    [anon_sym_do] = ACTIONS(1029),
    [anon_sym_while] = ACTIONS(1031),
    [anon_sym_for] = ACTIONS(1033),
    [anon_sym_lock] = ACTIONS(1035),
    [anon_sym_yield] = ACTIONS(1037),
    [anon_sym_switch] = ACTIONS(1039),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1041),
    [anon_sym_try] = ACTIONS(1043),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1045),
    [anon_sym_foreach] = ACTIONS(1047),
    [anon_sym_goto] = ACTIONS(1049),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1053),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [100] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(8858),
    [sym_variable_declaration] = STATE(9360),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6862),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(8815),
    [sym_break_statement] = STATE(8858),
    [sym_checked_statement] = STATE(8858),
    [sym_continue_statement] = STATE(8858),
    [sym_do_statement] = STATE(8858),
    [sym_empty_statement] = STATE(8858),
    [sym_expression_statement] = STATE(8858),
    [sym_fixed_statement] = STATE(8858),
    [sym_for_statement] = STATE(8858),
    [sym_return_statement] = STATE(8858),
    [sym_lock_statement] = STATE(8858),
    [sym_yield_statement] = STATE(8858),
    [sym_switch_statement] = STATE(8858),
    [sym_throw_statement] = STATE(8858),
    [sym_try_statement] = STATE(8858),
    [sym_unsafe_statement] = STATE(8858),
    [sym_using_statement] = STATE(8858),
    [sym_foreach_statement] = STATE(8858),
    [sym_goto_statement] = STATE(8858),
    [sym_labeled_statement] = STATE(8858),
    [sym_if_statement] = STATE(8858),
    [sym_while_statement] = STATE(8858),
    [sym_local_declaration_statement] = STATE(8858),
    [sym_local_function_statement] = STATE(8858),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6755),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2904),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(8858),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(100),
    [sym_preproc_endregion] = STATE(100),
    [sym_preproc_line] = STATE(100),
    [sym_preproc_pragma] = STATE(100),
    [sym_preproc_nullable] = STATE(100),
    [sym_preproc_error] = STATE(100),
    [sym_preproc_warning] = STATE(100),
    [sym_preproc_define] = STATE(100),
    [sym_preproc_undef] = STATE(100),
    [aux_sym_class_declaration_repeat1] = STATE(2931),
    [aux_sym_class_declaration_repeat2] = STATE(3115),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(1011),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1013),
    [anon_sym_unsafe] = ACTIONS(1015),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(1017),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1019),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1021),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1023),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(1025),
    [anon_sym_unchecked] = ACTIONS(1023),
    [anon_sym_continue] = ACTIONS(1027),
    [anon_sym_do] = ACTIONS(1029),
    [anon_sym_while] = ACTIONS(1031),
    [anon_sym_for] = ACTIONS(1033),
    [anon_sym_lock] = ACTIONS(1035),
    [anon_sym_yield] = ACTIONS(1037),
    [anon_sym_switch] = ACTIONS(1039),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1041),
    [anon_sym_try] = ACTIONS(1043),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1045),
    [anon_sym_foreach] = ACTIONS(1047),
    [anon_sym_goto] = ACTIONS(1049),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1053),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [101] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(8858),
    [sym_variable_declaration] = STATE(9360),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6862),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(8822),
    [sym_break_statement] = STATE(8858),
    [sym_checked_statement] = STATE(8858),
    [sym_continue_statement] = STATE(8858),
    [sym_do_statement] = STATE(8858),
    [sym_empty_statement] = STATE(8858),
    [sym_expression_statement] = STATE(8858),
    [sym_fixed_statement] = STATE(8858),
    [sym_for_statement] = STATE(8858),
    [sym_return_statement] = STATE(8858),
    [sym_lock_statement] = STATE(8858),
    [sym_yield_statement] = STATE(8858),
    [sym_switch_statement] = STATE(8858),
    [sym_throw_statement] = STATE(8858),
    [sym_try_statement] = STATE(8858),
    [sym_unsafe_statement] = STATE(8858),
    [sym_using_statement] = STATE(8858),
    [sym_foreach_statement] = STATE(8858),
    [sym_goto_statement] = STATE(8858),
    [sym_labeled_statement] = STATE(8858),
    [sym_if_statement] = STATE(8858),
    [sym_while_statement] = STATE(8858),
    [sym_local_declaration_statement] = STATE(8858),
    [sym_local_function_statement] = STATE(8858),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6755),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2904),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(8858),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(101),
    [sym_preproc_endregion] = STATE(101),
    [sym_preproc_line] = STATE(101),
    [sym_preproc_pragma] = STATE(101),
    [sym_preproc_nullable] = STATE(101),
    [sym_preproc_error] = STATE(101),
    [sym_preproc_warning] = STATE(101),
    [sym_preproc_define] = STATE(101),
    [sym_preproc_undef] = STATE(101),
    [aux_sym_class_declaration_repeat1] = STATE(2931),
    [aux_sym_class_declaration_repeat2] = STATE(3115),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(1011),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1013),
    [anon_sym_unsafe] = ACTIONS(1015),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(1017),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1019),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1021),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1023),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(1025),
    [anon_sym_unchecked] = ACTIONS(1023),
    [anon_sym_continue] = ACTIONS(1027),
    [anon_sym_do] = ACTIONS(1029),
    [anon_sym_while] = ACTIONS(1031),
    [anon_sym_for] = ACTIONS(1033),
    [anon_sym_lock] = ACTIONS(1035),
    [anon_sym_yield] = ACTIONS(1037),
    [anon_sym_switch] = ACTIONS(1039),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1041),
    [anon_sym_try] = ACTIONS(1043),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1045),
    [anon_sym_foreach] = ACTIONS(1047),
    [anon_sym_goto] = ACTIONS(1049),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1053),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [102] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(8858),
    [sym_variable_declaration] = STATE(9360),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6862),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(8831),
    [sym_break_statement] = STATE(8858),
    [sym_checked_statement] = STATE(8858),
    [sym_continue_statement] = STATE(8858),
    [sym_do_statement] = STATE(8858),
    [sym_empty_statement] = STATE(8858),
    [sym_expression_statement] = STATE(8858),
    [sym_fixed_statement] = STATE(8858),
    [sym_for_statement] = STATE(8858),
    [sym_return_statement] = STATE(8858),
    [sym_lock_statement] = STATE(8858),
    [sym_yield_statement] = STATE(8858),
    [sym_switch_statement] = STATE(8858),
    [sym_throw_statement] = STATE(8858),
    [sym_try_statement] = STATE(8858),
    [sym_unsafe_statement] = STATE(8858),
    [sym_using_statement] = STATE(8858),
    [sym_foreach_statement] = STATE(8858),
    [sym_goto_statement] = STATE(8858),
    [sym_labeled_statement] = STATE(8858),
    [sym_if_statement] = STATE(8858),
    [sym_while_statement] = STATE(8858),
    [sym_local_declaration_statement] = STATE(8858),
    [sym_local_function_statement] = STATE(8858),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6755),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2904),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(8858),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(102),
    [sym_preproc_endregion] = STATE(102),
    [sym_preproc_line] = STATE(102),
    [sym_preproc_pragma] = STATE(102),
    [sym_preproc_nullable] = STATE(102),
    [sym_preproc_error] = STATE(102),
    [sym_preproc_warning] = STATE(102),
    [sym_preproc_define] = STATE(102),
    [sym_preproc_undef] = STATE(102),
    [aux_sym_class_declaration_repeat1] = STATE(2931),
    [aux_sym_class_declaration_repeat2] = STATE(3115),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(1011),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1013),
    [anon_sym_unsafe] = ACTIONS(1015),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(1017),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1019),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1021),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1023),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(1025),
    [anon_sym_unchecked] = ACTIONS(1023),
    [anon_sym_continue] = ACTIONS(1027),
    [anon_sym_do] = ACTIONS(1029),
    [anon_sym_while] = ACTIONS(1031),
    [anon_sym_for] = ACTIONS(1033),
    [anon_sym_lock] = ACTIONS(1035),
    [anon_sym_yield] = ACTIONS(1037),
    [anon_sym_switch] = ACTIONS(1039),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1041),
    [anon_sym_try] = ACTIONS(1043),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1045),
    [anon_sym_foreach] = ACTIONS(1047),
    [anon_sym_goto] = ACTIONS(1049),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1053),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [103] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(8858),
    [sym_variable_declaration] = STATE(9360),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6862),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(8845),
    [sym_break_statement] = STATE(8858),
    [sym_checked_statement] = STATE(8858),
    [sym_continue_statement] = STATE(8858),
    [sym_do_statement] = STATE(8858),
    [sym_empty_statement] = STATE(8858),
    [sym_expression_statement] = STATE(8858),
    [sym_fixed_statement] = STATE(8858),
    [sym_for_statement] = STATE(8858),
    [sym_return_statement] = STATE(8858),
    [sym_lock_statement] = STATE(8858),
    [sym_yield_statement] = STATE(8858),
    [sym_switch_statement] = STATE(8858),
    [sym_throw_statement] = STATE(8858),
    [sym_try_statement] = STATE(8858),
    [sym_unsafe_statement] = STATE(8858),
    [sym_using_statement] = STATE(8858),
    [sym_foreach_statement] = STATE(8858),
    [sym_goto_statement] = STATE(8858),
    [sym_labeled_statement] = STATE(8858),
    [sym_if_statement] = STATE(8858),
    [sym_while_statement] = STATE(8858),
    [sym_local_declaration_statement] = STATE(8858),
    [sym_local_function_statement] = STATE(8858),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6755),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2904),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(8858),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(103),
    [sym_preproc_endregion] = STATE(103),
    [sym_preproc_line] = STATE(103),
    [sym_preproc_pragma] = STATE(103),
    [sym_preproc_nullable] = STATE(103),
    [sym_preproc_error] = STATE(103),
    [sym_preproc_warning] = STATE(103),
    [sym_preproc_define] = STATE(103),
    [sym_preproc_undef] = STATE(103),
    [aux_sym_class_declaration_repeat1] = STATE(2931),
    [aux_sym_class_declaration_repeat2] = STATE(3115),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(1011),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1013),
    [anon_sym_unsafe] = ACTIONS(1015),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(1017),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1019),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1021),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1023),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(1025),
    [anon_sym_unchecked] = ACTIONS(1023),
    [anon_sym_continue] = ACTIONS(1027),
    [anon_sym_do] = ACTIONS(1029),
    [anon_sym_while] = ACTIONS(1031),
    [anon_sym_for] = ACTIONS(1033),
    [anon_sym_lock] = ACTIONS(1035),
    [anon_sym_yield] = ACTIONS(1037),
    [anon_sym_switch] = ACTIONS(1039),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1041),
    [anon_sym_try] = ACTIONS(1043),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1045),
    [anon_sym_foreach] = ACTIONS(1047),
    [anon_sym_goto] = ACTIONS(1049),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1053),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [104] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(8858),
    [sym_variable_declaration] = STATE(9360),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6862),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(8892),
    [sym_break_statement] = STATE(8858),
    [sym_checked_statement] = STATE(8858),
    [sym_continue_statement] = STATE(8858),
    [sym_do_statement] = STATE(8858),
    [sym_empty_statement] = STATE(8858),
    [sym_expression_statement] = STATE(8858),
    [sym_fixed_statement] = STATE(8858),
    [sym_for_statement] = STATE(8858),
    [sym_return_statement] = STATE(8858),
    [sym_lock_statement] = STATE(8858),
    [sym_yield_statement] = STATE(8858),
    [sym_switch_statement] = STATE(8858),
    [sym_throw_statement] = STATE(8858),
    [sym_try_statement] = STATE(8858),
    [sym_unsafe_statement] = STATE(8858),
    [sym_using_statement] = STATE(8858),
    [sym_foreach_statement] = STATE(8858),
    [sym_goto_statement] = STATE(8858),
    [sym_labeled_statement] = STATE(8858),
    [sym_if_statement] = STATE(8858),
    [sym_while_statement] = STATE(8858),
    [sym_local_declaration_statement] = STATE(8858),
    [sym_local_function_statement] = STATE(8858),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6755),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2904),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(8858),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(104),
    [sym_preproc_endregion] = STATE(104),
    [sym_preproc_line] = STATE(104),
    [sym_preproc_pragma] = STATE(104),
    [sym_preproc_nullable] = STATE(104),
    [sym_preproc_error] = STATE(104),
    [sym_preproc_warning] = STATE(104),
    [sym_preproc_define] = STATE(104),
    [sym_preproc_undef] = STATE(104),
    [aux_sym_class_declaration_repeat1] = STATE(2931),
    [aux_sym_class_declaration_repeat2] = STATE(3115),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(1011),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1013),
    [anon_sym_unsafe] = ACTIONS(1015),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(1017),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1019),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1021),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1023),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(1025),
    [anon_sym_unchecked] = ACTIONS(1023),
    [anon_sym_continue] = ACTIONS(1027),
    [anon_sym_do] = ACTIONS(1029),
    [anon_sym_while] = ACTIONS(1031),
    [anon_sym_for] = ACTIONS(1033),
    [anon_sym_lock] = ACTIONS(1035),
    [anon_sym_yield] = ACTIONS(1037),
    [anon_sym_switch] = ACTIONS(1039),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1041),
    [anon_sym_try] = ACTIONS(1043),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1045),
    [anon_sym_foreach] = ACTIONS(1047),
    [anon_sym_goto] = ACTIONS(1049),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1053),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [105] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(8858),
    [sym_variable_declaration] = STATE(9360),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6862),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(8920),
    [sym_break_statement] = STATE(8858),
    [sym_checked_statement] = STATE(8858),
    [sym_continue_statement] = STATE(8858),
    [sym_do_statement] = STATE(8858),
    [sym_empty_statement] = STATE(8858),
    [sym_expression_statement] = STATE(8858),
    [sym_fixed_statement] = STATE(8858),
    [sym_for_statement] = STATE(8858),
    [sym_return_statement] = STATE(8858),
    [sym_lock_statement] = STATE(8858),
    [sym_yield_statement] = STATE(8858),
    [sym_switch_statement] = STATE(8858),
    [sym_throw_statement] = STATE(8858),
    [sym_try_statement] = STATE(8858),
    [sym_unsafe_statement] = STATE(8858),
    [sym_using_statement] = STATE(8858),
    [sym_foreach_statement] = STATE(8858),
    [sym_goto_statement] = STATE(8858),
    [sym_labeled_statement] = STATE(8858),
    [sym_if_statement] = STATE(8858),
    [sym_while_statement] = STATE(8858),
    [sym_local_declaration_statement] = STATE(8858),
    [sym_local_function_statement] = STATE(8858),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6755),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2904),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(8858),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(105),
    [sym_preproc_endregion] = STATE(105),
    [sym_preproc_line] = STATE(105),
    [sym_preproc_pragma] = STATE(105),
    [sym_preproc_nullable] = STATE(105),
    [sym_preproc_error] = STATE(105),
    [sym_preproc_warning] = STATE(105),
    [sym_preproc_define] = STATE(105),
    [sym_preproc_undef] = STATE(105),
    [aux_sym_class_declaration_repeat1] = STATE(2931),
    [aux_sym_class_declaration_repeat2] = STATE(3115),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(1011),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1013),
    [anon_sym_unsafe] = ACTIONS(1015),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(1017),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1019),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1021),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1023),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(1025),
    [anon_sym_unchecked] = ACTIONS(1023),
    [anon_sym_continue] = ACTIONS(1027),
    [anon_sym_do] = ACTIONS(1029),
    [anon_sym_while] = ACTIONS(1031),
    [anon_sym_for] = ACTIONS(1033),
    [anon_sym_lock] = ACTIONS(1035),
    [anon_sym_yield] = ACTIONS(1037),
    [anon_sym_switch] = ACTIONS(1039),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1041),
    [anon_sym_try] = ACTIONS(1043),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1045),
    [anon_sym_foreach] = ACTIONS(1047),
    [anon_sym_goto] = ACTIONS(1049),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1053),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [106] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(8858),
    [sym_variable_declaration] = STATE(9360),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6862),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(8921),
    [sym_break_statement] = STATE(8858),
    [sym_checked_statement] = STATE(8858),
    [sym_continue_statement] = STATE(8858),
    [sym_do_statement] = STATE(8858),
    [sym_empty_statement] = STATE(8858),
    [sym_expression_statement] = STATE(8858),
    [sym_fixed_statement] = STATE(8858),
    [sym_for_statement] = STATE(8858),
    [sym_return_statement] = STATE(8858),
    [sym_lock_statement] = STATE(8858),
    [sym_yield_statement] = STATE(8858),
    [sym_switch_statement] = STATE(8858),
    [sym_throw_statement] = STATE(8858),
    [sym_try_statement] = STATE(8858),
    [sym_unsafe_statement] = STATE(8858),
    [sym_using_statement] = STATE(8858),
    [sym_foreach_statement] = STATE(8858),
    [sym_goto_statement] = STATE(8858),
    [sym_labeled_statement] = STATE(8858),
    [sym_if_statement] = STATE(8858),
    [sym_while_statement] = STATE(8858),
    [sym_local_declaration_statement] = STATE(8858),
    [sym_local_function_statement] = STATE(8858),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6755),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2904),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(8858),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(106),
    [sym_preproc_endregion] = STATE(106),
    [sym_preproc_line] = STATE(106),
    [sym_preproc_pragma] = STATE(106),
    [sym_preproc_nullable] = STATE(106),
    [sym_preproc_error] = STATE(106),
    [sym_preproc_warning] = STATE(106),
    [sym_preproc_define] = STATE(106),
    [sym_preproc_undef] = STATE(106),
    [aux_sym_class_declaration_repeat1] = STATE(2931),
    [aux_sym_class_declaration_repeat2] = STATE(3115),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(1011),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1013),
    [anon_sym_unsafe] = ACTIONS(1015),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(1017),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1019),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1021),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1023),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(1025),
    [anon_sym_unchecked] = ACTIONS(1023),
    [anon_sym_continue] = ACTIONS(1027),
    [anon_sym_do] = ACTIONS(1029),
    [anon_sym_while] = ACTIONS(1031),
    [anon_sym_for] = ACTIONS(1033),
    [anon_sym_lock] = ACTIONS(1035),
    [anon_sym_yield] = ACTIONS(1037),
    [anon_sym_switch] = ACTIONS(1039),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1041),
    [anon_sym_try] = ACTIONS(1043),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1045),
    [anon_sym_foreach] = ACTIONS(1047),
    [anon_sym_goto] = ACTIONS(1049),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1053),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [107] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(8858),
    [sym_variable_declaration] = STATE(9360),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6862),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(8878),
    [sym_break_statement] = STATE(8858),
    [sym_checked_statement] = STATE(8858),
    [sym_continue_statement] = STATE(8858),
    [sym_do_statement] = STATE(8858),
    [sym_empty_statement] = STATE(8858),
    [sym_expression_statement] = STATE(8858),
    [sym_fixed_statement] = STATE(8858),
    [sym_for_statement] = STATE(8858),
    [sym_return_statement] = STATE(8858),
    [sym_lock_statement] = STATE(8858),
    [sym_yield_statement] = STATE(8858),
    [sym_switch_statement] = STATE(8858),
    [sym_throw_statement] = STATE(8858),
    [sym_try_statement] = STATE(8858),
    [sym_unsafe_statement] = STATE(8858),
    [sym_using_statement] = STATE(8858),
    [sym_foreach_statement] = STATE(8858),
    [sym_goto_statement] = STATE(8858),
    [sym_labeled_statement] = STATE(8858),
    [sym_if_statement] = STATE(8858),
    [sym_while_statement] = STATE(8858),
    [sym_local_declaration_statement] = STATE(8858),
    [sym_local_function_statement] = STATE(8858),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6755),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2904),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(8858),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(107),
    [sym_preproc_endregion] = STATE(107),
    [sym_preproc_line] = STATE(107),
    [sym_preproc_pragma] = STATE(107),
    [sym_preproc_nullable] = STATE(107),
    [sym_preproc_error] = STATE(107),
    [sym_preproc_warning] = STATE(107),
    [sym_preproc_define] = STATE(107),
    [sym_preproc_undef] = STATE(107),
    [aux_sym_class_declaration_repeat1] = STATE(2931),
    [aux_sym_class_declaration_repeat2] = STATE(3115),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(1011),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1013),
    [anon_sym_unsafe] = ACTIONS(1015),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(1017),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1019),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1021),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1023),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(1025),
    [anon_sym_unchecked] = ACTIONS(1023),
    [anon_sym_continue] = ACTIONS(1027),
    [anon_sym_do] = ACTIONS(1029),
    [anon_sym_while] = ACTIONS(1031),
    [anon_sym_for] = ACTIONS(1033),
    [anon_sym_lock] = ACTIONS(1035),
    [anon_sym_yield] = ACTIONS(1037),
    [anon_sym_switch] = ACTIONS(1039),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1041),
    [anon_sym_try] = ACTIONS(1043),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1045),
    [anon_sym_foreach] = ACTIONS(1047),
    [anon_sym_goto] = ACTIONS(1049),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1053),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [108] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(8858),
    [sym_variable_declaration] = STATE(9360),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6862),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(8896),
    [sym_break_statement] = STATE(8858),
    [sym_checked_statement] = STATE(8858),
    [sym_continue_statement] = STATE(8858),
    [sym_do_statement] = STATE(8858),
    [sym_empty_statement] = STATE(8858),
    [sym_expression_statement] = STATE(8858),
    [sym_fixed_statement] = STATE(8858),
    [sym_for_statement] = STATE(8858),
    [sym_return_statement] = STATE(8858),
    [sym_lock_statement] = STATE(8858),
    [sym_yield_statement] = STATE(8858),
    [sym_switch_statement] = STATE(8858),
    [sym_throw_statement] = STATE(8858),
    [sym_try_statement] = STATE(8858),
    [sym_unsafe_statement] = STATE(8858),
    [sym_using_statement] = STATE(8858),
    [sym_foreach_statement] = STATE(8858),
    [sym_goto_statement] = STATE(8858),
    [sym_labeled_statement] = STATE(8858),
    [sym_if_statement] = STATE(8858),
    [sym_while_statement] = STATE(8858),
    [sym_local_declaration_statement] = STATE(8858),
    [sym_local_function_statement] = STATE(8858),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6755),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2904),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(8858),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(108),
    [sym_preproc_endregion] = STATE(108),
    [sym_preproc_line] = STATE(108),
    [sym_preproc_pragma] = STATE(108),
    [sym_preproc_nullable] = STATE(108),
    [sym_preproc_error] = STATE(108),
    [sym_preproc_warning] = STATE(108),
    [sym_preproc_define] = STATE(108),
    [sym_preproc_undef] = STATE(108),
    [aux_sym_class_declaration_repeat1] = STATE(2931),
    [aux_sym_class_declaration_repeat2] = STATE(3115),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(1011),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1013),
    [anon_sym_unsafe] = ACTIONS(1015),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(1017),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1019),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1021),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1023),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(1025),
    [anon_sym_unchecked] = ACTIONS(1023),
    [anon_sym_continue] = ACTIONS(1027),
    [anon_sym_do] = ACTIONS(1029),
    [anon_sym_while] = ACTIONS(1031),
    [anon_sym_for] = ACTIONS(1033),
    [anon_sym_lock] = ACTIONS(1035),
    [anon_sym_yield] = ACTIONS(1037),
    [anon_sym_switch] = ACTIONS(1039),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1041),
    [anon_sym_try] = ACTIONS(1043),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1045),
    [anon_sym_foreach] = ACTIONS(1047),
    [anon_sym_goto] = ACTIONS(1049),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1053),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [109] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(8858),
    [sym_variable_declaration] = STATE(9360),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6862),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(8913),
    [sym_break_statement] = STATE(8858),
    [sym_checked_statement] = STATE(8858),
    [sym_continue_statement] = STATE(8858),
    [sym_do_statement] = STATE(8858),
    [sym_empty_statement] = STATE(8858),
    [sym_expression_statement] = STATE(8858),
    [sym_fixed_statement] = STATE(8858),
    [sym_for_statement] = STATE(8858),
    [sym_return_statement] = STATE(8858),
    [sym_lock_statement] = STATE(8858),
    [sym_yield_statement] = STATE(8858),
    [sym_switch_statement] = STATE(8858),
    [sym_throw_statement] = STATE(8858),
    [sym_try_statement] = STATE(8858),
    [sym_unsafe_statement] = STATE(8858),
    [sym_using_statement] = STATE(8858),
    [sym_foreach_statement] = STATE(8858),
    [sym_goto_statement] = STATE(8858),
    [sym_labeled_statement] = STATE(8858),
    [sym_if_statement] = STATE(8858),
    [sym_while_statement] = STATE(8858),
    [sym_local_declaration_statement] = STATE(8858),
    [sym_local_function_statement] = STATE(8858),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6755),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2904),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(8858),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(109),
    [sym_preproc_endregion] = STATE(109),
    [sym_preproc_line] = STATE(109),
    [sym_preproc_pragma] = STATE(109),
    [sym_preproc_nullable] = STATE(109),
    [sym_preproc_error] = STATE(109),
    [sym_preproc_warning] = STATE(109),
    [sym_preproc_define] = STATE(109),
    [sym_preproc_undef] = STATE(109),
    [aux_sym_class_declaration_repeat1] = STATE(2931),
    [aux_sym_class_declaration_repeat2] = STATE(3115),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(1011),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1013),
    [anon_sym_unsafe] = ACTIONS(1015),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(1017),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1019),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1021),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1023),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(1025),
    [anon_sym_unchecked] = ACTIONS(1023),
    [anon_sym_continue] = ACTIONS(1027),
    [anon_sym_do] = ACTIONS(1029),
    [anon_sym_while] = ACTIONS(1031),
    [anon_sym_for] = ACTIONS(1033),
    [anon_sym_lock] = ACTIONS(1035),
    [anon_sym_yield] = ACTIONS(1037),
    [anon_sym_switch] = ACTIONS(1039),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1041),
    [anon_sym_try] = ACTIONS(1043),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1045),
    [anon_sym_foreach] = ACTIONS(1047),
    [anon_sym_goto] = ACTIONS(1049),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1053),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [110] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(8858),
    [sym_variable_declaration] = STATE(9360),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6862),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(8915),
    [sym_break_statement] = STATE(8858),
    [sym_checked_statement] = STATE(8858),
    [sym_continue_statement] = STATE(8858),
    [sym_do_statement] = STATE(8858),
    [sym_empty_statement] = STATE(8858),
    [sym_expression_statement] = STATE(8858),
    [sym_fixed_statement] = STATE(8858),
    [sym_for_statement] = STATE(8858),
    [sym_return_statement] = STATE(8858),
    [sym_lock_statement] = STATE(8858),
    [sym_yield_statement] = STATE(8858),
    [sym_switch_statement] = STATE(8858),
    [sym_throw_statement] = STATE(8858),
    [sym_try_statement] = STATE(8858),
    [sym_unsafe_statement] = STATE(8858),
    [sym_using_statement] = STATE(8858),
    [sym_foreach_statement] = STATE(8858),
    [sym_goto_statement] = STATE(8858),
    [sym_labeled_statement] = STATE(8858),
    [sym_if_statement] = STATE(8858),
    [sym_while_statement] = STATE(8858),
    [sym_local_declaration_statement] = STATE(8858),
    [sym_local_function_statement] = STATE(8858),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6755),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2904),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(8858),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(110),
    [sym_preproc_endregion] = STATE(110),
    [sym_preproc_line] = STATE(110),
    [sym_preproc_pragma] = STATE(110),
    [sym_preproc_nullable] = STATE(110),
    [sym_preproc_error] = STATE(110),
    [sym_preproc_warning] = STATE(110),
    [sym_preproc_define] = STATE(110),
    [sym_preproc_undef] = STATE(110),
    [aux_sym_class_declaration_repeat1] = STATE(2931),
    [aux_sym_class_declaration_repeat2] = STATE(3115),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(1011),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1013),
    [anon_sym_unsafe] = ACTIONS(1015),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(1017),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1019),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1021),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1023),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(1025),
    [anon_sym_unchecked] = ACTIONS(1023),
    [anon_sym_continue] = ACTIONS(1027),
    [anon_sym_do] = ACTIONS(1029),
    [anon_sym_while] = ACTIONS(1031),
    [anon_sym_for] = ACTIONS(1033),
    [anon_sym_lock] = ACTIONS(1035),
    [anon_sym_yield] = ACTIONS(1037),
    [anon_sym_switch] = ACTIONS(1039),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1041),
    [anon_sym_try] = ACTIONS(1043),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1045),
    [anon_sym_foreach] = ACTIONS(1047),
    [anon_sym_goto] = ACTIONS(1049),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1053),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [111] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(8858),
    [sym_variable_declaration] = STATE(9360),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6862),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(8954),
    [sym_break_statement] = STATE(8858),
    [sym_checked_statement] = STATE(8858),
    [sym_continue_statement] = STATE(8858),
    [sym_do_statement] = STATE(8858),
    [sym_empty_statement] = STATE(8858),
    [sym_expression_statement] = STATE(8858),
    [sym_fixed_statement] = STATE(8858),
    [sym_for_statement] = STATE(8858),
    [sym_return_statement] = STATE(8858),
    [sym_lock_statement] = STATE(8858),
    [sym_yield_statement] = STATE(8858),
    [sym_switch_statement] = STATE(8858),
    [sym_throw_statement] = STATE(8858),
    [sym_try_statement] = STATE(8858),
    [sym_unsafe_statement] = STATE(8858),
    [sym_using_statement] = STATE(8858),
    [sym_foreach_statement] = STATE(8858),
    [sym_goto_statement] = STATE(8858),
    [sym_labeled_statement] = STATE(8858),
    [sym_if_statement] = STATE(8858),
    [sym_while_statement] = STATE(8858),
    [sym_local_declaration_statement] = STATE(8858),
    [sym_local_function_statement] = STATE(8858),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6755),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2904),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(8858),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(111),
    [sym_preproc_endregion] = STATE(111),
    [sym_preproc_line] = STATE(111),
    [sym_preproc_pragma] = STATE(111),
    [sym_preproc_nullable] = STATE(111),
    [sym_preproc_error] = STATE(111),
    [sym_preproc_warning] = STATE(111),
    [sym_preproc_define] = STATE(111),
    [sym_preproc_undef] = STATE(111),
    [aux_sym_class_declaration_repeat1] = STATE(2931),
    [aux_sym_class_declaration_repeat2] = STATE(3115),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(1011),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1013),
    [anon_sym_unsafe] = ACTIONS(1015),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(1017),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1019),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1021),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1023),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(1025),
    [anon_sym_unchecked] = ACTIONS(1023),
    [anon_sym_continue] = ACTIONS(1027),
    [anon_sym_do] = ACTIONS(1029),
    [anon_sym_while] = ACTIONS(1031),
    [anon_sym_for] = ACTIONS(1033),
    [anon_sym_lock] = ACTIONS(1035),
    [anon_sym_yield] = ACTIONS(1037),
    [anon_sym_switch] = ACTIONS(1039),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1041),
    [anon_sym_try] = ACTIONS(1043),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1045),
    [anon_sym_foreach] = ACTIONS(1047),
    [anon_sym_goto] = ACTIONS(1049),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1053),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [112] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(8858),
    [sym_variable_declaration] = STATE(9360),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6862),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(8981),
    [sym_break_statement] = STATE(8858),
    [sym_checked_statement] = STATE(8858),
    [sym_continue_statement] = STATE(8858),
    [sym_do_statement] = STATE(8858),
    [sym_empty_statement] = STATE(8858),
    [sym_expression_statement] = STATE(8858),
    [sym_fixed_statement] = STATE(8858),
    [sym_for_statement] = STATE(8858),
    [sym_return_statement] = STATE(8858),
    [sym_lock_statement] = STATE(8858),
    [sym_yield_statement] = STATE(8858),
    [sym_switch_statement] = STATE(8858),
    [sym_throw_statement] = STATE(8858),
    [sym_try_statement] = STATE(8858),
    [sym_unsafe_statement] = STATE(8858),
    [sym_using_statement] = STATE(8858),
    [sym_foreach_statement] = STATE(8858),
    [sym_goto_statement] = STATE(8858),
    [sym_labeled_statement] = STATE(8858),
    [sym_if_statement] = STATE(8858),
    [sym_while_statement] = STATE(8858),
    [sym_local_declaration_statement] = STATE(8858),
    [sym_local_function_statement] = STATE(8858),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6755),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2904),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(8858),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(112),
    [sym_preproc_endregion] = STATE(112),
    [sym_preproc_line] = STATE(112),
    [sym_preproc_pragma] = STATE(112),
    [sym_preproc_nullable] = STATE(112),
    [sym_preproc_error] = STATE(112),
    [sym_preproc_warning] = STATE(112),
    [sym_preproc_define] = STATE(112),
    [sym_preproc_undef] = STATE(112),
    [aux_sym_class_declaration_repeat1] = STATE(2931),
    [aux_sym_class_declaration_repeat2] = STATE(3115),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(1011),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1013),
    [anon_sym_unsafe] = ACTIONS(1015),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(1017),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1019),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1021),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1023),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(1025),
    [anon_sym_unchecked] = ACTIONS(1023),
    [anon_sym_continue] = ACTIONS(1027),
    [anon_sym_do] = ACTIONS(1029),
    [anon_sym_while] = ACTIONS(1031),
    [anon_sym_for] = ACTIONS(1033),
    [anon_sym_lock] = ACTIONS(1035),
    [anon_sym_yield] = ACTIONS(1037),
    [anon_sym_switch] = ACTIONS(1039),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1041),
    [anon_sym_try] = ACTIONS(1043),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1045),
    [anon_sym_foreach] = ACTIONS(1047),
    [anon_sym_goto] = ACTIONS(1049),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1053),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [113] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(8858),
    [sym_variable_declaration] = STATE(9360),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6862),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(8726),
    [sym_break_statement] = STATE(8858),
    [sym_checked_statement] = STATE(8858),
    [sym_continue_statement] = STATE(8858),
    [sym_do_statement] = STATE(8858),
    [sym_empty_statement] = STATE(8858),
    [sym_expression_statement] = STATE(8858),
    [sym_fixed_statement] = STATE(8858),
    [sym_for_statement] = STATE(8858),
    [sym_return_statement] = STATE(8858),
    [sym_lock_statement] = STATE(8858),
    [sym_yield_statement] = STATE(8858),
    [sym_switch_statement] = STATE(8858),
    [sym_throw_statement] = STATE(8858),
    [sym_try_statement] = STATE(8858),
    [sym_unsafe_statement] = STATE(8858),
    [sym_using_statement] = STATE(8858),
    [sym_foreach_statement] = STATE(8858),
    [sym_goto_statement] = STATE(8858),
    [sym_labeled_statement] = STATE(8858),
    [sym_if_statement] = STATE(8858),
    [sym_while_statement] = STATE(8858),
    [sym_local_declaration_statement] = STATE(8858),
    [sym_local_function_statement] = STATE(8858),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6755),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2904),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(8858),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(113),
    [sym_preproc_endregion] = STATE(113),
    [sym_preproc_line] = STATE(113),
    [sym_preproc_pragma] = STATE(113),
    [sym_preproc_nullable] = STATE(113),
    [sym_preproc_error] = STATE(113),
    [sym_preproc_warning] = STATE(113),
    [sym_preproc_define] = STATE(113),
    [sym_preproc_undef] = STATE(113),
    [aux_sym_class_declaration_repeat1] = STATE(2931),
    [aux_sym_class_declaration_repeat2] = STATE(3115),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(1011),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1013),
    [anon_sym_unsafe] = ACTIONS(1015),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(1017),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1019),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1021),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1023),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(1025),
    [anon_sym_unchecked] = ACTIONS(1023),
    [anon_sym_continue] = ACTIONS(1027),
    [anon_sym_do] = ACTIONS(1029),
    [anon_sym_while] = ACTIONS(1031),
    [anon_sym_for] = ACTIONS(1033),
    [anon_sym_lock] = ACTIONS(1035),
    [anon_sym_yield] = ACTIONS(1037),
    [anon_sym_switch] = ACTIONS(1039),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1041),
    [anon_sym_try] = ACTIONS(1043),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1045),
    [anon_sym_foreach] = ACTIONS(1047),
    [anon_sym_goto] = ACTIONS(1049),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1053),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [114] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(8858),
    [sym_variable_declaration] = STATE(9360),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6862),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(8739),
    [sym_break_statement] = STATE(8858),
    [sym_checked_statement] = STATE(8858),
    [sym_continue_statement] = STATE(8858),
    [sym_do_statement] = STATE(8858),
    [sym_empty_statement] = STATE(8858),
    [sym_expression_statement] = STATE(8858),
    [sym_fixed_statement] = STATE(8858),
    [sym_for_statement] = STATE(8858),
    [sym_return_statement] = STATE(8858),
    [sym_lock_statement] = STATE(8858),
    [sym_yield_statement] = STATE(8858),
    [sym_switch_statement] = STATE(8858),
    [sym_throw_statement] = STATE(8858),
    [sym_try_statement] = STATE(8858),
    [sym_unsafe_statement] = STATE(8858),
    [sym_using_statement] = STATE(8858),
    [sym_foreach_statement] = STATE(8858),
    [sym_goto_statement] = STATE(8858),
    [sym_labeled_statement] = STATE(8858),
    [sym_if_statement] = STATE(8858),
    [sym_while_statement] = STATE(8858),
    [sym_local_declaration_statement] = STATE(8858),
    [sym_local_function_statement] = STATE(8858),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6755),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2904),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(8858),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(114),
    [sym_preproc_endregion] = STATE(114),
    [sym_preproc_line] = STATE(114),
    [sym_preproc_pragma] = STATE(114),
    [sym_preproc_nullable] = STATE(114),
    [sym_preproc_error] = STATE(114),
    [sym_preproc_warning] = STATE(114),
    [sym_preproc_define] = STATE(114),
    [sym_preproc_undef] = STATE(114),
    [aux_sym_class_declaration_repeat1] = STATE(2931),
    [aux_sym_class_declaration_repeat2] = STATE(3115),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(1011),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1013),
    [anon_sym_unsafe] = ACTIONS(1015),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(1017),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1019),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1021),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1023),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(1025),
    [anon_sym_unchecked] = ACTIONS(1023),
    [anon_sym_continue] = ACTIONS(1027),
    [anon_sym_do] = ACTIONS(1029),
    [anon_sym_while] = ACTIONS(1031),
    [anon_sym_for] = ACTIONS(1033),
    [anon_sym_lock] = ACTIONS(1035),
    [anon_sym_yield] = ACTIONS(1037),
    [anon_sym_switch] = ACTIONS(1039),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1041),
    [anon_sym_try] = ACTIONS(1043),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1045),
    [anon_sym_foreach] = ACTIONS(1047),
    [anon_sym_goto] = ACTIONS(1049),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1053),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [115] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(8858),
    [sym_variable_declaration] = STATE(9360),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6862),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(8743),
    [sym_break_statement] = STATE(8858),
    [sym_checked_statement] = STATE(8858),
    [sym_continue_statement] = STATE(8858),
    [sym_do_statement] = STATE(8858),
    [sym_empty_statement] = STATE(8858),
    [sym_expression_statement] = STATE(8858),
    [sym_fixed_statement] = STATE(8858),
    [sym_for_statement] = STATE(8858),
    [sym_return_statement] = STATE(8858),
    [sym_lock_statement] = STATE(8858),
    [sym_yield_statement] = STATE(8858),
    [sym_switch_statement] = STATE(8858),
    [sym_throw_statement] = STATE(8858),
    [sym_try_statement] = STATE(8858),
    [sym_unsafe_statement] = STATE(8858),
    [sym_using_statement] = STATE(8858),
    [sym_foreach_statement] = STATE(8858),
    [sym_goto_statement] = STATE(8858),
    [sym_labeled_statement] = STATE(8858),
    [sym_if_statement] = STATE(8858),
    [sym_while_statement] = STATE(8858),
    [sym_local_declaration_statement] = STATE(8858),
    [sym_local_function_statement] = STATE(8858),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6755),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2904),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(8858),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(115),
    [sym_preproc_endregion] = STATE(115),
    [sym_preproc_line] = STATE(115),
    [sym_preproc_pragma] = STATE(115),
    [sym_preproc_nullable] = STATE(115),
    [sym_preproc_error] = STATE(115),
    [sym_preproc_warning] = STATE(115),
    [sym_preproc_define] = STATE(115),
    [sym_preproc_undef] = STATE(115),
    [aux_sym_class_declaration_repeat1] = STATE(2931),
    [aux_sym_class_declaration_repeat2] = STATE(3115),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(1011),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1013),
    [anon_sym_unsafe] = ACTIONS(1015),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(1017),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1019),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1021),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1023),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(1025),
    [anon_sym_unchecked] = ACTIONS(1023),
    [anon_sym_continue] = ACTIONS(1027),
    [anon_sym_do] = ACTIONS(1029),
    [anon_sym_while] = ACTIONS(1031),
    [anon_sym_for] = ACTIONS(1033),
    [anon_sym_lock] = ACTIONS(1035),
    [anon_sym_yield] = ACTIONS(1037),
    [anon_sym_switch] = ACTIONS(1039),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1041),
    [anon_sym_try] = ACTIONS(1043),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1045),
    [anon_sym_foreach] = ACTIONS(1047),
    [anon_sym_goto] = ACTIONS(1049),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1053),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [116] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(8858),
    [sym_variable_declaration] = STATE(9360),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6862),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(8772),
    [sym_break_statement] = STATE(8858),
    [sym_checked_statement] = STATE(8858),
    [sym_continue_statement] = STATE(8858),
    [sym_do_statement] = STATE(8858),
    [sym_empty_statement] = STATE(8858),
    [sym_expression_statement] = STATE(8858),
    [sym_fixed_statement] = STATE(8858),
    [sym_for_statement] = STATE(8858),
    [sym_return_statement] = STATE(8858),
    [sym_lock_statement] = STATE(8858),
    [sym_yield_statement] = STATE(8858),
    [sym_switch_statement] = STATE(8858),
    [sym_throw_statement] = STATE(8858),
    [sym_try_statement] = STATE(8858),
    [sym_unsafe_statement] = STATE(8858),
    [sym_using_statement] = STATE(8858),
    [sym_foreach_statement] = STATE(8858),
    [sym_goto_statement] = STATE(8858),
    [sym_labeled_statement] = STATE(8858),
    [sym_if_statement] = STATE(8858),
    [sym_while_statement] = STATE(8858),
    [sym_local_declaration_statement] = STATE(8858),
    [sym_local_function_statement] = STATE(8858),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6755),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2904),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(8858),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(116),
    [sym_preproc_endregion] = STATE(116),
    [sym_preproc_line] = STATE(116),
    [sym_preproc_pragma] = STATE(116),
    [sym_preproc_nullable] = STATE(116),
    [sym_preproc_error] = STATE(116),
    [sym_preproc_warning] = STATE(116),
    [sym_preproc_define] = STATE(116),
    [sym_preproc_undef] = STATE(116),
    [aux_sym_class_declaration_repeat1] = STATE(2931),
    [aux_sym_class_declaration_repeat2] = STATE(3115),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(1011),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1013),
    [anon_sym_unsafe] = ACTIONS(1015),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(1017),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1019),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1021),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1023),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(1025),
    [anon_sym_unchecked] = ACTIONS(1023),
    [anon_sym_continue] = ACTIONS(1027),
    [anon_sym_do] = ACTIONS(1029),
    [anon_sym_while] = ACTIONS(1031),
    [anon_sym_for] = ACTIONS(1033),
    [anon_sym_lock] = ACTIONS(1035),
    [anon_sym_yield] = ACTIONS(1037),
    [anon_sym_switch] = ACTIONS(1039),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1041),
    [anon_sym_try] = ACTIONS(1043),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1045),
    [anon_sym_foreach] = ACTIONS(1047),
    [anon_sym_goto] = ACTIONS(1049),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1053),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [117] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2270),
    [sym_variable_declaration] = STATE(9038),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6880),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2295),
    [sym_break_statement] = STATE(2270),
    [sym_checked_statement] = STATE(2270),
    [sym_continue_statement] = STATE(2270),
    [sym_do_statement] = STATE(2270),
    [sym_empty_statement] = STATE(2270),
    [sym_expression_statement] = STATE(2270),
    [sym_fixed_statement] = STATE(2270),
    [sym_for_statement] = STATE(2270),
    [sym_return_statement] = STATE(2270),
    [sym_lock_statement] = STATE(2270),
    [sym_yield_statement] = STATE(2270),
    [sym_switch_statement] = STATE(2270),
    [sym_throw_statement] = STATE(2270),
    [sym_try_statement] = STATE(2270),
    [sym_unsafe_statement] = STATE(2270),
    [sym_using_statement] = STATE(2270),
    [sym_foreach_statement] = STATE(2270),
    [sym_goto_statement] = STATE(2270),
    [sym_labeled_statement] = STATE(2270),
    [sym_if_statement] = STATE(2270),
    [sym_while_statement] = STATE(2270),
    [sym_local_declaration_statement] = STATE(2270),
    [sym_local_function_statement] = STATE(2270),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6279),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2841),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2270),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(117),
    [sym_preproc_endregion] = STATE(117),
    [sym_preproc_line] = STATE(117),
    [sym_preproc_pragma] = STATE(117),
    [sym_preproc_nullable] = STATE(117),
    [sym_preproc_error] = STATE(117),
    [sym_preproc_warning] = STATE(117),
    [sym_preproc_define] = STATE(117),
    [sym_preproc_undef] = STATE(117),
    [aux_sym_class_declaration_repeat1] = STATE(2937),
    [aux_sym_class_declaration_repeat2] = STATE(3097),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(161),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1055),
    [anon_sym_unsafe] = ACTIONS(1057),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(171),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1059),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(193),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(195),
    [anon_sym_unchecked] = ACTIONS(193),
    [anon_sym_continue] = ACTIONS(197),
    [anon_sym_do] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_lock] = ACTIONS(205),
    [anon_sym_yield] = ACTIONS(207),
    [anon_sym_switch] = ACTIONS(209),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(211),
    [anon_sym_try] = ACTIONS(213),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(215),
    [anon_sym_foreach] = ACTIONS(217),
    [anon_sym_goto] = ACTIONS(219),
    [anon_sym_if] = ACTIONS(221),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(223),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [118] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2270),
    [sym_variable_declaration] = STATE(9038),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6880),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2267),
    [sym_break_statement] = STATE(2270),
    [sym_checked_statement] = STATE(2270),
    [sym_continue_statement] = STATE(2270),
    [sym_do_statement] = STATE(2270),
    [sym_empty_statement] = STATE(2270),
    [sym_expression_statement] = STATE(2270),
    [sym_fixed_statement] = STATE(2270),
    [sym_for_statement] = STATE(2270),
    [sym_return_statement] = STATE(2270),
    [sym_lock_statement] = STATE(2270),
    [sym_yield_statement] = STATE(2270),
    [sym_switch_statement] = STATE(2270),
    [sym_throw_statement] = STATE(2270),
    [sym_try_statement] = STATE(2270),
    [sym_unsafe_statement] = STATE(2270),
    [sym_using_statement] = STATE(2270),
    [sym_foreach_statement] = STATE(2270),
    [sym_goto_statement] = STATE(2270),
    [sym_labeled_statement] = STATE(2270),
    [sym_if_statement] = STATE(2270),
    [sym_while_statement] = STATE(2270),
    [sym_local_declaration_statement] = STATE(2270),
    [sym_local_function_statement] = STATE(2270),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6279),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2841),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2270),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(118),
    [sym_preproc_endregion] = STATE(118),
    [sym_preproc_line] = STATE(118),
    [sym_preproc_pragma] = STATE(118),
    [sym_preproc_nullable] = STATE(118),
    [sym_preproc_error] = STATE(118),
    [sym_preproc_warning] = STATE(118),
    [sym_preproc_define] = STATE(118),
    [sym_preproc_undef] = STATE(118),
    [aux_sym_class_declaration_repeat1] = STATE(2937),
    [aux_sym_class_declaration_repeat2] = STATE(3097),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(161),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1055),
    [anon_sym_unsafe] = ACTIONS(1057),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(171),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1059),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(193),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(195),
    [anon_sym_unchecked] = ACTIONS(193),
    [anon_sym_continue] = ACTIONS(197),
    [anon_sym_do] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_lock] = ACTIONS(205),
    [anon_sym_yield] = ACTIONS(207),
    [anon_sym_switch] = ACTIONS(209),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(211),
    [anon_sym_try] = ACTIONS(213),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(215),
    [anon_sym_foreach] = ACTIONS(217),
    [anon_sym_goto] = ACTIONS(219),
    [anon_sym_if] = ACTIONS(221),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(223),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [119] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2270),
    [sym_variable_declaration] = STATE(9038),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6880),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2258),
    [sym_break_statement] = STATE(2270),
    [sym_checked_statement] = STATE(2270),
    [sym_continue_statement] = STATE(2270),
    [sym_do_statement] = STATE(2270),
    [sym_empty_statement] = STATE(2270),
    [sym_expression_statement] = STATE(2270),
    [sym_fixed_statement] = STATE(2270),
    [sym_for_statement] = STATE(2270),
    [sym_return_statement] = STATE(2270),
    [sym_lock_statement] = STATE(2270),
    [sym_yield_statement] = STATE(2270),
    [sym_switch_statement] = STATE(2270),
    [sym_throw_statement] = STATE(2270),
    [sym_try_statement] = STATE(2270),
    [sym_unsafe_statement] = STATE(2270),
    [sym_using_statement] = STATE(2270),
    [sym_foreach_statement] = STATE(2270),
    [sym_goto_statement] = STATE(2270),
    [sym_labeled_statement] = STATE(2270),
    [sym_if_statement] = STATE(2270),
    [sym_while_statement] = STATE(2270),
    [sym_local_declaration_statement] = STATE(2270),
    [sym_local_function_statement] = STATE(2270),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6279),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2841),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2270),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(119),
    [sym_preproc_endregion] = STATE(119),
    [sym_preproc_line] = STATE(119),
    [sym_preproc_pragma] = STATE(119),
    [sym_preproc_nullable] = STATE(119),
    [sym_preproc_error] = STATE(119),
    [sym_preproc_warning] = STATE(119),
    [sym_preproc_define] = STATE(119),
    [sym_preproc_undef] = STATE(119),
    [aux_sym_class_declaration_repeat1] = STATE(2937),
    [aux_sym_class_declaration_repeat2] = STATE(3097),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(161),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1055),
    [anon_sym_unsafe] = ACTIONS(1057),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(171),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1059),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(193),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(195),
    [anon_sym_unchecked] = ACTIONS(193),
    [anon_sym_continue] = ACTIONS(197),
    [anon_sym_do] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_lock] = ACTIONS(205),
    [anon_sym_yield] = ACTIONS(207),
    [anon_sym_switch] = ACTIONS(209),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(211),
    [anon_sym_try] = ACTIONS(213),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(215),
    [anon_sym_foreach] = ACTIONS(217),
    [anon_sym_goto] = ACTIONS(219),
    [anon_sym_if] = ACTIONS(221),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(223),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [120] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2270),
    [sym_variable_declaration] = STATE(9038),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6880),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2259),
    [sym_break_statement] = STATE(2270),
    [sym_checked_statement] = STATE(2270),
    [sym_continue_statement] = STATE(2270),
    [sym_do_statement] = STATE(2270),
    [sym_empty_statement] = STATE(2270),
    [sym_expression_statement] = STATE(2270),
    [sym_fixed_statement] = STATE(2270),
    [sym_for_statement] = STATE(2270),
    [sym_return_statement] = STATE(2270),
    [sym_lock_statement] = STATE(2270),
    [sym_yield_statement] = STATE(2270),
    [sym_switch_statement] = STATE(2270),
    [sym_throw_statement] = STATE(2270),
    [sym_try_statement] = STATE(2270),
    [sym_unsafe_statement] = STATE(2270),
    [sym_using_statement] = STATE(2270),
    [sym_foreach_statement] = STATE(2270),
    [sym_goto_statement] = STATE(2270),
    [sym_labeled_statement] = STATE(2270),
    [sym_if_statement] = STATE(2270),
    [sym_while_statement] = STATE(2270),
    [sym_local_declaration_statement] = STATE(2270),
    [sym_local_function_statement] = STATE(2270),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6279),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2841),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2270),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(120),
    [sym_preproc_endregion] = STATE(120),
    [sym_preproc_line] = STATE(120),
    [sym_preproc_pragma] = STATE(120),
    [sym_preproc_nullable] = STATE(120),
    [sym_preproc_error] = STATE(120),
    [sym_preproc_warning] = STATE(120),
    [sym_preproc_define] = STATE(120),
    [sym_preproc_undef] = STATE(120),
    [aux_sym_class_declaration_repeat1] = STATE(2937),
    [aux_sym_class_declaration_repeat2] = STATE(3097),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(161),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1055),
    [anon_sym_unsafe] = ACTIONS(1057),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(171),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1059),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(193),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(195),
    [anon_sym_unchecked] = ACTIONS(193),
    [anon_sym_continue] = ACTIONS(197),
    [anon_sym_do] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_lock] = ACTIONS(205),
    [anon_sym_yield] = ACTIONS(207),
    [anon_sym_switch] = ACTIONS(209),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(211),
    [anon_sym_try] = ACTIONS(213),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(215),
    [anon_sym_foreach] = ACTIONS(217),
    [anon_sym_goto] = ACTIONS(219),
    [anon_sym_if] = ACTIONS(221),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(223),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [121] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2270),
    [sym_variable_declaration] = STATE(9038),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6880),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2260),
    [sym_break_statement] = STATE(2270),
    [sym_checked_statement] = STATE(2270),
    [sym_continue_statement] = STATE(2270),
    [sym_do_statement] = STATE(2270),
    [sym_empty_statement] = STATE(2270),
    [sym_expression_statement] = STATE(2270),
    [sym_fixed_statement] = STATE(2270),
    [sym_for_statement] = STATE(2270),
    [sym_return_statement] = STATE(2270),
    [sym_lock_statement] = STATE(2270),
    [sym_yield_statement] = STATE(2270),
    [sym_switch_statement] = STATE(2270),
    [sym_throw_statement] = STATE(2270),
    [sym_try_statement] = STATE(2270),
    [sym_unsafe_statement] = STATE(2270),
    [sym_using_statement] = STATE(2270),
    [sym_foreach_statement] = STATE(2270),
    [sym_goto_statement] = STATE(2270),
    [sym_labeled_statement] = STATE(2270),
    [sym_if_statement] = STATE(2270),
    [sym_while_statement] = STATE(2270),
    [sym_local_declaration_statement] = STATE(2270),
    [sym_local_function_statement] = STATE(2270),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6279),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2841),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2270),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(121),
    [sym_preproc_endregion] = STATE(121),
    [sym_preproc_line] = STATE(121),
    [sym_preproc_pragma] = STATE(121),
    [sym_preproc_nullable] = STATE(121),
    [sym_preproc_error] = STATE(121),
    [sym_preproc_warning] = STATE(121),
    [sym_preproc_define] = STATE(121),
    [sym_preproc_undef] = STATE(121),
    [aux_sym_class_declaration_repeat1] = STATE(2937),
    [aux_sym_class_declaration_repeat2] = STATE(3097),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(161),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1055),
    [anon_sym_unsafe] = ACTIONS(1057),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(171),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1059),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(193),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(195),
    [anon_sym_unchecked] = ACTIONS(193),
    [anon_sym_continue] = ACTIONS(197),
    [anon_sym_do] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_lock] = ACTIONS(205),
    [anon_sym_yield] = ACTIONS(207),
    [anon_sym_switch] = ACTIONS(209),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(211),
    [anon_sym_try] = ACTIONS(213),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(215),
    [anon_sym_foreach] = ACTIONS(217),
    [anon_sym_goto] = ACTIONS(219),
    [anon_sym_if] = ACTIONS(221),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(223),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [122] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2270),
    [sym_variable_declaration] = STATE(9038),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6880),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2281),
    [sym_break_statement] = STATE(2270),
    [sym_checked_statement] = STATE(2270),
    [sym_continue_statement] = STATE(2270),
    [sym_do_statement] = STATE(2270),
    [sym_empty_statement] = STATE(2270),
    [sym_expression_statement] = STATE(2270),
    [sym_fixed_statement] = STATE(2270),
    [sym_for_statement] = STATE(2270),
    [sym_return_statement] = STATE(2270),
    [sym_lock_statement] = STATE(2270),
    [sym_yield_statement] = STATE(2270),
    [sym_switch_statement] = STATE(2270),
    [sym_throw_statement] = STATE(2270),
    [sym_try_statement] = STATE(2270),
    [sym_unsafe_statement] = STATE(2270),
    [sym_using_statement] = STATE(2270),
    [sym_foreach_statement] = STATE(2270),
    [sym_goto_statement] = STATE(2270),
    [sym_labeled_statement] = STATE(2270),
    [sym_if_statement] = STATE(2270),
    [sym_while_statement] = STATE(2270),
    [sym_local_declaration_statement] = STATE(2270),
    [sym_local_function_statement] = STATE(2270),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6279),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2841),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2270),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(122),
    [sym_preproc_endregion] = STATE(122),
    [sym_preproc_line] = STATE(122),
    [sym_preproc_pragma] = STATE(122),
    [sym_preproc_nullable] = STATE(122),
    [sym_preproc_error] = STATE(122),
    [sym_preproc_warning] = STATE(122),
    [sym_preproc_define] = STATE(122),
    [sym_preproc_undef] = STATE(122),
    [aux_sym_class_declaration_repeat1] = STATE(2937),
    [aux_sym_class_declaration_repeat2] = STATE(3097),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(161),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1055),
    [anon_sym_unsafe] = ACTIONS(1057),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(171),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1059),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(193),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(195),
    [anon_sym_unchecked] = ACTIONS(193),
    [anon_sym_continue] = ACTIONS(197),
    [anon_sym_do] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_lock] = ACTIONS(205),
    [anon_sym_yield] = ACTIONS(207),
    [anon_sym_switch] = ACTIONS(209),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(211),
    [anon_sym_try] = ACTIONS(213),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(215),
    [anon_sym_foreach] = ACTIONS(217),
    [anon_sym_goto] = ACTIONS(219),
    [anon_sym_if] = ACTIONS(221),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(223),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [123] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2270),
    [sym_variable_declaration] = STATE(9038),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6880),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2223),
    [sym_break_statement] = STATE(2270),
    [sym_checked_statement] = STATE(2270),
    [sym_continue_statement] = STATE(2270),
    [sym_do_statement] = STATE(2270),
    [sym_empty_statement] = STATE(2270),
    [sym_expression_statement] = STATE(2270),
    [sym_fixed_statement] = STATE(2270),
    [sym_for_statement] = STATE(2270),
    [sym_return_statement] = STATE(2270),
    [sym_lock_statement] = STATE(2270),
    [sym_yield_statement] = STATE(2270),
    [sym_switch_statement] = STATE(2270),
    [sym_throw_statement] = STATE(2270),
    [sym_try_statement] = STATE(2270),
    [sym_unsafe_statement] = STATE(2270),
    [sym_using_statement] = STATE(2270),
    [sym_foreach_statement] = STATE(2270),
    [sym_goto_statement] = STATE(2270),
    [sym_labeled_statement] = STATE(2270),
    [sym_if_statement] = STATE(2270),
    [sym_while_statement] = STATE(2270),
    [sym_local_declaration_statement] = STATE(2270),
    [sym_local_function_statement] = STATE(2270),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6279),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2841),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2270),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(123),
    [sym_preproc_endregion] = STATE(123),
    [sym_preproc_line] = STATE(123),
    [sym_preproc_pragma] = STATE(123),
    [sym_preproc_nullable] = STATE(123),
    [sym_preproc_error] = STATE(123),
    [sym_preproc_warning] = STATE(123),
    [sym_preproc_define] = STATE(123),
    [sym_preproc_undef] = STATE(123),
    [aux_sym_class_declaration_repeat1] = STATE(2937),
    [aux_sym_class_declaration_repeat2] = STATE(3097),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(161),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1055),
    [anon_sym_unsafe] = ACTIONS(1057),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(171),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1059),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(193),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(195),
    [anon_sym_unchecked] = ACTIONS(193),
    [anon_sym_continue] = ACTIONS(197),
    [anon_sym_do] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_lock] = ACTIONS(205),
    [anon_sym_yield] = ACTIONS(207),
    [anon_sym_switch] = ACTIONS(209),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(211),
    [anon_sym_try] = ACTIONS(213),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(215),
    [anon_sym_foreach] = ACTIONS(217),
    [anon_sym_goto] = ACTIONS(219),
    [anon_sym_if] = ACTIONS(221),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(223),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [124] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2270),
    [sym_variable_declaration] = STATE(9038),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6880),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2224),
    [sym_break_statement] = STATE(2270),
    [sym_checked_statement] = STATE(2270),
    [sym_continue_statement] = STATE(2270),
    [sym_do_statement] = STATE(2270),
    [sym_empty_statement] = STATE(2270),
    [sym_expression_statement] = STATE(2270),
    [sym_fixed_statement] = STATE(2270),
    [sym_for_statement] = STATE(2270),
    [sym_return_statement] = STATE(2270),
    [sym_lock_statement] = STATE(2270),
    [sym_yield_statement] = STATE(2270),
    [sym_switch_statement] = STATE(2270),
    [sym_throw_statement] = STATE(2270),
    [sym_try_statement] = STATE(2270),
    [sym_unsafe_statement] = STATE(2270),
    [sym_using_statement] = STATE(2270),
    [sym_foreach_statement] = STATE(2270),
    [sym_goto_statement] = STATE(2270),
    [sym_labeled_statement] = STATE(2270),
    [sym_if_statement] = STATE(2270),
    [sym_while_statement] = STATE(2270),
    [sym_local_declaration_statement] = STATE(2270),
    [sym_local_function_statement] = STATE(2270),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6279),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2841),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2270),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(124),
    [sym_preproc_endregion] = STATE(124),
    [sym_preproc_line] = STATE(124),
    [sym_preproc_pragma] = STATE(124),
    [sym_preproc_nullable] = STATE(124),
    [sym_preproc_error] = STATE(124),
    [sym_preproc_warning] = STATE(124),
    [sym_preproc_define] = STATE(124),
    [sym_preproc_undef] = STATE(124),
    [aux_sym_class_declaration_repeat1] = STATE(2937),
    [aux_sym_class_declaration_repeat2] = STATE(3097),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(161),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1055),
    [anon_sym_unsafe] = ACTIONS(1057),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(171),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1059),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(193),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(195),
    [anon_sym_unchecked] = ACTIONS(193),
    [anon_sym_continue] = ACTIONS(197),
    [anon_sym_do] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_lock] = ACTIONS(205),
    [anon_sym_yield] = ACTIONS(207),
    [anon_sym_switch] = ACTIONS(209),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(211),
    [anon_sym_try] = ACTIONS(213),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(215),
    [anon_sym_foreach] = ACTIONS(217),
    [anon_sym_goto] = ACTIONS(219),
    [anon_sym_if] = ACTIONS(221),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(223),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [125] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2270),
    [sym_variable_declaration] = STATE(9038),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6880),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2231),
    [sym_break_statement] = STATE(2270),
    [sym_checked_statement] = STATE(2270),
    [sym_continue_statement] = STATE(2270),
    [sym_do_statement] = STATE(2270),
    [sym_empty_statement] = STATE(2270),
    [sym_expression_statement] = STATE(2270),
    [sym_fixed_statement] = STATE(2270),
    [sym_for_statement] = STATE(2270),
    [sym_return_statement] = STATE(2270),
    [sym_lock_statement] = STATE(2270),
    [sym_yield_statement] = STATE(2270),
    [sym_switch_statement] = STATE(2270),
    [sym_throw_statement] = STATE(2270),
    [sym_try_statement] = STATE(2270),
    [sym_unsafe_statement] = STATE(2270),
    [sym_using_statement] = STATE(2270),
    [sym_foreach_statement] = STATE(2270),
    [sym_goto_statement] = STATE(2270),
    [sym_labeled_statement] = STATE(2270),
    [sym_if_statement] = STATE(2270),
    [sym_while_statement] = STATE(2270),
    [sym_local_declaration_statement] = STATE(2270),
    [sym_local_function_statement] = STATE(2270),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6279),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2841),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2270),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(125),
    [sym_preproc_endregion] = STATE(125),
    [sym_preproc_line] = STATE(125),
    [sym_preproc_pragma] = STATE(125),
    [sym_preproc_nullable] = STATE(125),
    [sym_preproc_error] = STATE(125),
    [sym_preproc_warning] = STATE(125),
    [sym_preproc_define] = STATE(125),
    [sym_preproc_undef] = STATE(125),
    [aux_sym_class_declaration_repeat1] = STATE(2937),
    [aux_sym_class_declaration_repeat2] = STATE(3097),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(161),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1055),
    [anon_sym_unsafe] = ACTIONS(1057),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(171),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1059),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(193),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(195),
    [anon_sym_unchecked] = ACTIONS(193),
    [anon_sym_continue] = ACTIONS(197),
    [anon_sym_do] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_lock] = ACTIONS(205),
    [anon_sym_yield] = ACTIONS(207),
    [anon_sym_switch] = ACTIONS(209),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(211),
    [anon_sym_try] = ACTIONS(213),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(215),
    [anon_sym_foreach] = ACTIONS(217),
    [anon_sym_goto] = ACTIONS(219),
    [anon_sym_if] = ACTIONS(221),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(223),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [126] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2270),
    [sym_variable_declaration] = STATE(9038),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6880),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2306),
    [sym_break_statement] = STATE(2270),
    [sym_checked_statement] = STATE(2270),
    [sym_continue_statement] = STATE(2270),
    [sym_do_statement] = STATE(2270),
    [sym_empty_statement] = STATE(2270),
    [sym_expression_statement] = STATE(2270),
    [sym_fixed_statement] = STATE(2270),
    [sym_for_statement] = STATE(2270),
    [sym_return_statement] = STATE(2270),
    [sym_lock_statement] = STATE(2270),
    [sym_yield_statement] = STATE(2270),
    [sym_switch_statement] = STATE(2270),
    [sym_throw_statement] = STATE(2270),
    [sym_try_statement] = STATE(2270),
    [sym_unsafe_statement] = STATE(2270),
    [sym_using_statement] = STATE(2270),
    [sym_foreach_statement] = STATE(2270),
    [sym_goto_statement] = STATE(2270),
    [sym_labeled_statement] = STATE(2270),
    [sym_if_statement] = STATE(2270),
    [sym_while_statement] = STATE(2270),
    [sym_local_declaration_statement] = STATE(2270),
    [sym_local_function_statement] = STATE(2270),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6279),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2841),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2270),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(126),
    [sym_preproc_endregion] = STATE(126),
    [sym_preproc_line] = STATE(126),
    [sym_preproc_pragma] = STATE(126),
    [sym_preproc_nullable] = STATE(126),
    [sym_preproc_error] = STATE(126),
    [sym_preproc_warning] = STATE(126),
    [sym_preproc_define] = STATE(126),
    [sym_preproc_undef] = STATE(126),
    [aux_sym_class_declaration_repeat1] = STATE(2937),
    [aux_sym_class_declaration_repeat2] = STATE(3097),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(161),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1055),
    [anon_sym_unsafe] = ACTIONS(1057),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(171),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1059),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(193),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(195),
    [anon_sym_unchecked] = ACTIONS(193),
    [anon_sym_continue] = ACTIONS(197),
    [anon_sym_do] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_lock] = ACTIONS(205),
    [anon_sym_yield] = ACTIONS(207),
    [anon_sym_switch] = ACTIONS(209),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(211),
    [anon_sym_try] = ACTIONS(213),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(215),
    [anon_sym_foreach] = ACTIONS(217),
    [anon_sym_goto] = ACTIONS(219),
    [anon_sym_if] = ACTIONS(221),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(223),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [127] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2270),
    [sym_variable_declaration] = STATE(9038),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6880),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2233),
    [sym_break_statement] = STATE(2270),
    [sym_checked_statement] = STATE(2270),
    [sym_continue_statement] = STATE(2270),
    [sym_do_statement] = STATE(2270),
    [sym_empty_statement] = STATE(2270),
    [sym_expression_statement] = STATE(2270),
    [sym_fixed_statement] = STATE(2270),
    [sym_for_statement] = STATE(2270),
    [sym_return_statement] = STATE(2270),
    [sym_lock_statement] = STATE(2270),
    [sym_yield_statement] = STATE(2270),
    [sym_switch_statement] = STATE(2270),
    [sym_throw_statement] = STATE(2270),
    [sym_try_statement] = STATE(2270),
    [sym_unsafe_statement] = STATE(2270),
    [sym_using_statement] = STATE(2270),
    [sym_foreach_statement] = STATE(2270),
    [sym_goto_statement] = STATE(2270),
    [sym_labeled_statement] = STATE(2270),
    [sym_if_statement] = STATE(2270),
    [sym_while_statement] = STATE(2270),
    [sym_local_declaration_statement] = STATE(2270),
    [sym_local_function_statement] = STATE(2270),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6279),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2841),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2270),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(127),
    [sym_preproc_endregion] = STATE(127),
    [sym_preproc_line] = STATE(127),
    [sym_preproc_pragma] = STATE(127),
    [sym_preproc_nullable] = STATE(127),
    [sym_preproc_error] = STATE(127),
    [sym_preproc_warning] = STATE(127),
    [sym_preproc_define] = STATE(127),
    [sym_preproc_undef] = STATE(127),
    [aux_sym_class_declaration_repeat1] = STATE(2937),
    [aux_sym_class_declaration_repeat2] = STATE(3097),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(161),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1055),
    [anon_sym_unsafe] = ACTIONS(1057),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(171),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1059),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(193),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(195),
    [anon_sym_unchecked] = ACTIONS(193),
    [anon_sym_continue] = ACTIONS(197),
    [anon_sym_do] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_lock] = ACTIONS(205),
    [anon_sym_yield] = ACTIONS(207),
    [anon_sym_switch] = ACTIONS(209),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(211),
    [anon_sym_try] = ACTIONS(213),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(215),
    [anon_sym_foreach] = ACTIONS(217),
    [anon_sym_goto] = ACTIONS(219),
    [anon_sym_if] = ACTIONS(221),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(223),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [128] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2270),
    [sym_variable_declaration] = STATE(9038),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6880),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2234),
    [sym_break_statement] = STATE(2270),
    [sym_checked_statement] = STATE(2270),
    [sym_continue_statement] = STATE(2270),
    [sym_do_statement] = STATE(2270),
    [sym_empty_statement] = STATE(2270),
    [sym_expression_statement] = STATE(2270),
    [sym_fixed_statement] = STATE(2270),
    [sym_for_statement] = STATE(2270),
    [sym_return_statement] = STATE(2270),
    [sym_lock_statement] = STATE(2270),
    [sym_yield_statement] = STATE(2270),
    [sym_switch_statement] = STATE(2270),
    [sym_throw_statement] = STATE(2270),
    [sym_try_statement] = STATE(2270),
    [sym_unsafe_statement] = STATE(2270),
    [sym_using_statement] = STATE(2270),
    [sym_foreach_statement] = STATE(2270),
    [sym_goto_statement] = STATE(2270),
    [sym_labeled_statement] = STATE(2270),
    [sym_if_statement] = STATE(2270),
    [sym_while_statement] = STATE(2270),
    [sym_local_declaration_statement] = STATE(2270),
    [sym_local_function_statement] = STATE(2270),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6279),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2841),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2270),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(128),
    [sym_preproc_endregion] = STATE(128),
    [sym_preproc_line] = STATE(128),
    [sym_preproc_pragma] = STATE(128),
    [sym_preproc_nullable] = STATE(128),
    [sym_preproc_error] = STATE(128),
    [sym_preproc_warning] = STATE(128),
    [sym_preproc_define] = STATE(128),
    [sym_preproc_undef] = STATE(128),
    [aux_sym_class_declaration_repeat1] = STATE(2937),
    [aux_sym_class_declaration_repeat2] = STATE(3097),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(161),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1055),
    [anon_sym_unsafe] = ACTIONS(1057),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(171),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1059),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(193),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(195),
    [anon_sym_unchecked] = ACTIONS(193),
    [anon_sym_continue] = ACTIONS(197),
    [anon_sym_do] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_lock] = ACTIONS(205),
    [anon_sym_yield] = ACTIONS(207),
    [anon_sym_switch] = ACTIONS(209),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(211),
    [anon_sym_try] = ACTIONS(213),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(215),
    [anon_sym_foreach] = ACTIONS(217),
    [anon_sym_goto] = ACTIONS(219),
    [anon_sym_if] = ACTIONS(221),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(223),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [129] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2270),
    [sym_variable_declaration] = STATE(9038),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6880),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2235),
    [sym_break_statement] = STATE(2270),
    [sym_checked_statement] = STATE(2270),
    [sym_continue_statement] = STATE(2270),
    [sym_do_statement] = STATE(2270),
    [sym_empty_statement] = STATE(2270),
    [sym_expression_statement] = STATE(2270),
    [sym_fixed_statement] = STATE(2270),
    [sym_for_statement] = STATE(2270),
    [sym_return_statement] = STATE(2270),
    [sym_lock_statement] = STATE(2270),
    [sym_yield_statement] = STATE(2270),
    [sym_switch_statement] = STATE(2270),
    [sym_throw_statement] = STATE(2270),
    [sym_try_statement] = STATE(2270),
    [sym_unsafe_statement] = STATE(2270),
    [sym_using_statement] = STATE(2270),
    [sym_foreach_statement] = STATE(2270),
    [sym_goto_statement] = STATE(2270),
    [sym_labeled_statement] = STATE(2270),
    [sym_if_statement] = STATE(2270),
    [sym_while_statement] = STATE(2270),
    [sym_local_declaration_statement] = STATE(2270),
    [sym_local_function_statement] = STATE(2270),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6279),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2841),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2270),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(129),
    [sym_preproc_endregion] = STATE(129),
    [sym_preproc_line] = STATE(129),
    [sym_preproc_pragma] = STATE(129),
    [sym_preproc_nullable] = STATE(129),
    [sym_preproc_error] = STATE(129),
    [sym_preproc_warning] = STATE(129),
    [sym_preproc_define] = STATE(129),
    [sym_preproc_undef] = STATE(129),
    [aux_sym_class_declaration_repeat1] = STATE(2937),
    [aux_sym_class_declaration_repeat2] = STATE(3097),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(161),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1055),
    [anon_sym_unsafe] = ACTIONS(1057),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(171),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1059),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(193),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(195),
    [anon_sym_unchecked] = ACTIONS(193),
    [anon_sym_continue] = ACTIONS(197),
    [anon_sym_do] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_lock] = ACTIONS(205),
    [anon_sym_yield] = ACTIONS(207),
    [anon_sym_switch] = ACTIONS(209),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(211),
    [anon_sym_try] = ACTIONS(213),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(215),
    [anon_sym_foreach] = ACTIONS(217),
    [anon_sym_goto] = ACTIONS(219),
    [anon_sym_if] = ACTIONS(221),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(223),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [130] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2270),
    [sym_variable_declaration] = STATE(9038),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6880),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2239),
    [sym_break_statement] = STATE(2270),
    [sym_checked_statement] = STATE(2270),
    [sym_continue_statement] = STATE(2270),
    [sym_do_statement] = STATE(2270),
    [sym_empty_statement] = STATE(2270),
    [sym_expression_statement] = STATE(2270),
    [sym_fixed_statement] = STATE(2270),
    [sym_for_statement] = STATE(2270),
    [sym_return_statement] = STATE(2270),
    [sym_lock_statement] = STATE(2270),
    [sym_yield_statement] = STATE(2270),
    [sym_switch_statement] = STATE(2270),
    [sym_throw_statement] = STATE(2270),
    [sym_try_statement] = STATE(2270),
    [sym_unsafe_statement] = STATE(2270),
    [sym_using_statement] = STATE(2270),
    [sym_foreach_statement] = STATE(2270),
    [sym_goto_statement] = STATE(2270),
    [sym_labeled_statement] = STATE(2270),
    [sym_if_statement] = STATE(2270),
    [sym_while_statement] = STATE(2270),
    [sym_local_declaration_statement] = STATE(2270),
    [sym_local_function_statement] = STATE(2270),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6279),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2841),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2270),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(130),
    [sym_preproc_endregion] = STATE(130),
    [sym_preproc_line] = STATE(130),
    [sym_preproc_pragma] = STATE(130),
    [sym_preproc_nullable] = STATE(130),
    [sym_preproc_error] = STATE(130),
    [sym_preproc_warning] = STATE(130),
    [sym_preproc_define] = STATE(130),
    [sym_preproc_undef] = STATE(130),
    [aux_sym_class_declaration_repeat1] = STATE(2937),
    [aux_sym_class_declaration_repeat2] = STATE(3097),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(161),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1055),
    [anon_sym_unsafe] = ACTIONS(1057),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(171),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1059),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(193),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(195),
    [anon_sym_unchecked] = ACTIONS(193),
    [anon_sym_continue] = ACTIONS(197),
    [anon_sym_do] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_lock] = ACTIONS(205),
    [anon_sym_yield] = ACTIONS(207),
    [anon_sym_switch] = ACTIONS(209),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(211),
    [anon_sym_try] = ACTIONS(213),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(215),
    [anon_sym_foreach] = ACTIONS(217),
    [anon_sym_goto] = ACTIONS(219),
    [anon_sym_if] = ACTIONS(221),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(223),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [131] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2270),
    [sym_variable_declaration] = STATE(9038),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6880),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2240),
    [sym_break_statement] = STATE(2270),
    [sym_checked_statement] = STATE(2270),
    [sym_continue_statement] = STATE(2270),
    [sym_do_statement] = STATE(2270),
    [sym_empty_statement] = STATE(2270),
    [sym_expression_statement] = STATE(2270),
    [sym_fixed_statement] = STATE(2270),
    [sym_for_statement] = STATE(2270),
    [sym_return_statement] = STATE(2270),
    [sym_lock_statement] = STATE(2270),
    [sym_yield_statement] = STATE(2270),
    [sym_switch_statement] = STATE(2270),
    [sym_throw_statement] = STATE(2270),
    [sym_try_statement] = STATE(2270),
    [sym_unsafe_statement] = STATE(2270),
    [sym_using_statement] = STATE(2270),
    [sym_foreach_statement] = STATE(2270),
    [sym_goto_statement] = STATE(2270),
    [sym_labeled_statement] = STATE(2270),
    [sym_if_statement] = STATE(2270),
    [sym_while_statement] = STATE(2270),
    [sym_local_declaration_statement] = STATE(2270),
    [sym_local_function_statement] = STATE(2270),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6279),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2841),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2270),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(131),
    [sym_preproc_endregion] = STATE(131),
    [sym_preproc_line] = STATE(131),
    [sym_preproc_pragma] = STATE(131),
    [sym_preproc_nullable] = STATE(131),
    [sym_preproc_error] = STATE(131),
    [sym_preproc_warning] = STATE(131),
    [sym_preproc_define] = STATE(131),
    [sym_preproc_undef] = STATE(131),
    [aux_sym_class_declaration_repeat1] = STATE(2937),
    [aux_sym_class_declaration_repeat2] = STATE(3097),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(161),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1055),
    [anon_sym_unsafe] = ACTIONS(1057),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(171),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1059),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(193),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(195),
    [anon_sym_unchecked] = ACTIONS(193),
    [anon_sym_continue] = ACTIONS(197),
    [anon_sym_do] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_lock] = ACTIONS(205),
    [anon_sym_yield] = ACTIONS(207),
    [anon_sym_switch] = ACTIONS(209),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(211),
    [anon_sym_try] = ACTIONS(213),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(215),
    [anon_sym_foreach] = ACTIONS(217),
    [anon_sym_goto] = ACTIONS(219),
    [anon_sym_if] = ACTIONS(221),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(223),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [132] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2270),
    [sym_variable_declaration] = STATE(9038),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6880),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2241),
    [sym_break_statement] = STATE(2270),
    [sym_checked_statement] = STATE(2270),
    [sym_continue_statement] = STATE(2270),
    [sym_do_statement] = STATE(2270),
    [sym_empty_statement] = STATE(2270),
    [sym_expression_statement] = STATE(2270),
    [sym_fixed_statement] = STATE(2270),
    [sym_for_statement] = STATE(2270),
    [sym_return_statement] = STATE(2270),
    [sym_lock_statement] = STATE(2270),
    [sym_yield_statement] = STATE(2270),
    [sym_switch_statement] = STATE(2270),
    [sym_throw_statement] = STATE(2270),
    [sym_try_statement] = STATE(2270),
    [sym_unsafe_statement] = STATE(2270),
    [sym_using_statement] = STATE(2270),
    [sym_foreach_statement] = STATE(2270),
    [sym_goto_statement] = STATE(2270),
    [sym_labeled_statement] = STATE(2270),
    [sym_if_statement] = STATE(2270),
    [sym_while_statement] = STATE(2270),
    [sym_local_declaration_statement] = STATE(2270),
    [sym_local_function_statement] = STATE(2270),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6279),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2841),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2270),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(132),
    [sym_preproc_endregion] = STATE(132),
    [sym_preproc_line] = STATE(132),
    [sym_preproc_pragma] = STATE(132),
    [sym_preproc_nullable] = STATE(132),
    [sym_preproc_error] = STATE(132),
    [sym_preproc_warning] = STATE(132),
    [sym_preproc_define] = STATE(132),
    [sym_preproc_undef] = STATE(132),
    [aux_sym_class_declaration_repeat1] = STATE(2937),
    [aux_sym_class_declaration_repeat2] = STATE(3097),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(161),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1055),
    [anon_sym_unsafe] = ACTIONS(1057),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(171),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1059),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(193),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(195),
    [anon_sym_unchecked] = ACTIONS(193),
    [anon_sym_continue] = ACTIONS(197),
    [anon_sym_do] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_lock] = ACTIONS(205),
    [anon_sym_yield] = ACTIONS(207),
    [anon_sym_switch] = ACTIONS(209),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(211),
    [anon_sym_try] = ACTIONS(213),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(215),
    [anon_sym_foreach] = ACTIONS(217),
    [anon_sym_goto] = ACTIONS(219),
    [anon_sym_if] = ACTIONS(221),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(223),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [133] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2270),
    [sym_variable_declaration] = STATE(9038),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6880),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2242),
    [sym_break_statement] = STATE(2270),
    [sym_checked_statement] = STATE(2270),
    [sym_continue_statement] = STATE(2270),
    [sym_do_statement] = STATE(2270),
    [sym_empty_statement] = STATE(2270),
    [sym_expression_statement] = STATE(2270),
    [sym_fixed_statement] = STATE(2270),
    [sym_for_statement] = STATE(2270),
    [sym_return_statement] = STATE(2270),
    [sym_lock_statement] = STATE(2270),
    [sym_yield_statement] = STATE(2270),
    [sym_switch_statement] = STATE(2270),
    [sym_throw_statement] = STATE(2270),
    [sym_try_statement] = STATE(2270),
    [sym_unsafe_statement] = STATE(2270),
    [sym_using_statement] = STATE(2270),
    [sym_foreach_statement] = STATE(2270),
    [sym_goto_statement] = STATE(2270),
    [sym_labeled_statement] = STATE(2270),
    [sym_if_statement] = STATE(2270),
    [sym_while_statement] = STATE(2270),
    [sym_local_declaration_statement] = STATE(2270),
    [sym_local_function_statement] = STATE(2270),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6279),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2841),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2270),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(133),
    [sym_preproc_endregion] = STATE(133),
    [sym_preproc_line] = STATE(133),
    [sym_preproc_pragma] = STATE(133),
    [sym_preproc_nullable] = STATE(133),
    [sym_preproc_error] = STATE(133),
    [sym_preproc_warning] = STATE(133),
    [sym_preproc_define] = STATE(133),
    [sym_preproc_undef] = STATE(133),
    [aux_sym_class_declaration_repeat1] = STATE(2937),
    [aux_sym_class_declaration_repeat2] = STATE(3097),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(161),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1055),
    [anon_sym_unsafe] = ACTIONS(1057),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(171),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1059),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(193),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(195),
    [anon_sym_unchecked] = ACTIONS(193),
    [anon_sym_continue] = ACTIONS(197),
    [anon_sym_do] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_lock] = ACTIONS(205),
    [anon_sym_yield] = ACTIONS(207),
    [anon_sym_switch] = ACTIONS(209),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(211),
    [anon_sym_try] = ACTIONS(213),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(215),
    [anon_sym_foreach] = ACTIONS(217),
    [anon_sym_goto] = ACTIONS(219),
    [anon_sym_if] = ACTIONS(221),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(223),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [134] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2270),
    [sym_variable_declaration] = STATE(9038),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6880),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2243),
    [sym_break_statement] = STATE(2270),
    [sym_checked_statement] = STATE(2270),
    [sym_continue_statement] = STATE(2270),
    [sym_do_statement] = STATE(2270),
    [sym_empty_statement] = STATE(2270),
    [sym_expression_statement] = STATE(2270),
    [sym_fixed_statement] = STATE(2270),
    [sym_for_statement] = STATE(2270),
    [sym_return_statement] = STATE(2270),
    [sym_lock_statement] = STATE(2270),
    [sym_yield_statement] = STATE(2270),
    [sym_switch_statement] = STATE(2270),
    [sym_throw_statement] = STATE(2270),
    [sym_try_statement] = STATE(2270),
    [sym_unsafe_statement] = STATE(2270),
    [sym_using_statement] = STATE(2270),
    [sym_foreach_statement] = STATE(2270),
    [sym_goto_statement] = STATE(2270),
    [sym_labeled_statement] = STATE(2270),
    [sym_if_statement] = STATE(2270),
    [sym_while_statement] = STATE(2270),
    [sym_local_declaration_statement] = STATE(2270),
    [sym_local_function_statement] = STATE(2270),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6279),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2841),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2270),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(134),
    [sym_preproc_endregion] = STATE(134),
    [sym_preproc_line] = STATE(134),
    [sym_preproc_pragma] = STATE(134),
    [sym_preproc_nullable] = STATE(134),
    [sym_preproc_error] = STATE(134),
    [sym_preproc_warning] = STATE(134),
    [sym_preproc_define] = STATE(134),
    [sym_preproc_undef] = STATE(134),
    [aux_sym_class_declaration_repeat1] = STATE(2937),
    [aux_sym_class_declaration_repeat2] = STATE(3097),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(161),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1055),
    [anon_sym_unsafe] = ACTIONS(1057),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(171),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1059),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(193),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(195),
    [anon_sym_unchecked] = ACTIONS(193),
    [anon_sym_continue] = ACTIONS(197),
    [anon_sym_do] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_lock] = ACTIONS(205),
    [anon_sym_yield] = ACTIONS(207),
    [anon_sym_switch] = ACTIONS(209),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(211),
    [anon_sym_try] = ACTIONS(213),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(215),
    [anon_sym_foreach] = ACTIONS(217),
    [anon_sym_goto] = ACTIONS(219),
    [anon_sym_if] = ACTIONS(221),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(223),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [135] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2270),
    [sym_variable_declaration] = STATE(9038),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6880),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2244),
    [sym_break_statement] = STATE(2270),
    [sym_checked_statement] = STATE(2270),
    [sym_continue_statement] = STATE(2270),
    [sym_do_statement] = STATE(2270),
    [sym_empty_statement] = STATE(2270),
    [sym_expression_statement] = STATE(2270),
    [sym_fixed_statement] = STATE(2270),
    [sym_for_statement] = STATE(2270),
    [sym_return_statement] = STATE(2270),
    [sym_lock_statement] = STATE(2270),
    [sym_yield_statement] = STATE(2270),
    [sym_switch_statement] = STATE(2270),
    [sym_throw_statement] = STATE(2270),
    [sym_try_statement] = STATE(2270),
    [sym_unsafe_statement] = STATE(2270),
    [sym_using_statement] = STATE(2270),
    [sym_foreach_statement] = STATE(2270),
    [sym_goto_statement] = STATE(2270),
    [sym_labeled_statement] = STATE(2270),
    [sym_if_statement] = STATE(2270),
    [sym_while_statement] = STATE(2270),
    [sym_local_declaration_statement] = STATE(2270),
    [sym_local_function_statement] = STATE(2270),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6279),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2841),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2270),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(135),
    [sym_preproc_endregion] = STATE(135),
    [sym_preproc_line] = STATE(135),
    [sym_preproc_pragma] = STATE(135),
    [sym_preproc_nullable] = STATE(135),
    [sym_preproc_error] = STATE(135),
    [sym_preproc_warning] = STATE(135),
    [sym_preproc_define] = STATE(135),
    [sym_preproc_undef] = STATE(135),
    [aux_sym_class_declaration_repeat1] = STATE(2937),
    [aux_sym_class_declaration_repeat2] = STATE(3097),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(161),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1055),
    [anon_sym_unsafe] = ACTIONS(1057),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(171),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1059),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(193),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(195),
    [anon_sym_unchecked] = ACTIONS(193),
    [anon_sym_continue] = ACTIONS(197),
    [anon_sym_do] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_lock] = ACTIONS(205),
    [anon_sym_yield] = ACTIONS(207),
    [anon_sym_switch] = ACTIONS(209),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(211),
    [anon_sym_try] = ACTIONS(213),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(215),
    [anon_sym_foreach] = ACTIONS(217),
    [anon_sym_goto] = ACTIONS(219),
    [anon_sym_if] = ACTIONS(221),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(223),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [136] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2270),
    [sym_variable_declaration] = STATE(9038),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6880),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2245),
    [sym_break_statement] = STATE(2270),
    [sym_checked_statement] = STATE(2270),
    [sym_continue_statement] = STATE(2270),
    [sym_do_statement] = STATE(2270),
    [sym_empty_statement] = STATE(2270),
    [sym_expression_statement] = STATE(2270),
    [sym_fixed_statement] = STATE(2270),
    [sym_for_statement] = STATE(2270),
    [sym_return_statement] = STATE(2270),
    [sym_lock_statement] = STATE(2270),
    [sym_yield_statement] = STATE(2270),
    [sym_switch_statement] = STATE(2270),
    [sym_throw_statement] = STATE(2270),
    [sym_try_statement] = STATE(2270),
    [sym_unsafe_statement] = STATE(2270),
    [sym_using_statement] = STATE(2270),
    [sym_foreach_statement] = STATE(2270),
    [sym_goto_statement] = STATE(2270),
    [sym_labeled_statement] = STATE(2270),
    [sym_if_statement] = STATE(2270),
    [sym_while_statement] = STATE(2270),
    [sym_local_declaration_statement] = STATE(2270),
    [sym_local_function_statement] = STATE(2270),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6279),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2841),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2270),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(136),
    [sym_preproc_endregion] = STATE(136),
    [sym_preproc_line] = STATE(136),
    [sym_preproc_pragma] = STATE(136),
    [sym_preproc_nullable] = STATE(136),
    [sym_preproc_error] = STATE(136),
    [sym_preproc_warning] = STATE(136),
    [sym_preproc_define] = STATE(136),
    [sym_preproc_undef] = STATE(136),
    [aux_sym_class_declaration_repeat1] = STATE(2937),
    [aux_sym_class_declaration_repeat2] = STATE(3097),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(161),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1055),
    [anon_sym_unsafe] = ACTIONS(1057),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(171),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1059),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(193),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(195),
    [anon_sym_unchecked] = ACTIONS(193),
    [anon_sym_continue] = ACTIONS(197),
    [anon_sym_do] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_lock] = ACTIONS(205),
    [anon_sym_yield] = ACTIONS(207),
    [anon_sym_switch] = ACTIONS(209),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(211),
    [anon_sym_try] = ACTIONS(213),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(215),
    [anon_sym_foreach] = ACTIONS(217),
    [anon_sym_goto] = ACTIONS(219),
    [anon_sym_if] = ACTIONS(221),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(223),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [137] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2270),
    [sym_variable_declaration] = STATE(9038),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6880),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2247),
    [sym_break_statement] = STATE(2270),
    [sym_checked_statement] = STATE(2270),
    [sym_continue_statement] = STATE(2270),
    [sym_do_statement] = STATE(2270),
    [sym_empty_statement] = STATE(2270),
    [sym_expression_statement] = STATE(2270),
    [sym_fixed_statement] = STATE(2270),
    [sym_for_statement] = STATE(2270),
    [sym_return_statement] = STATE(2270),
    [sym_lock_statement] = STATE(2270),
    [sym_yield_statement] = STATE(2270),
    [sym_switch_statement] = STATE(2270),
    [sym_throw_statement] = STATE(2270),
    [sym_try_statement] = STATE(2270),
    [sym_unsafe_statement] = STATE(2270),
    [sym_using_statement] = STATE(2270),
    [sym_foreach_statement] = STATE(2270),
    [sym_goto_statement] = STATE(2270),
    [sym_labeled_statement] = STATE(2270),
    [sym_if_statement] = STATE(2270),
    [sym_while_statement] = STATE(2270),
    [sym_local_declaration_statement] = STATE(2270),
    [sym_local_function_statement] = STATE(2270),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6279),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2841),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2270),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(137),
    [sym_preproc_endregion] = STATE(137),
    [sym_preproc_line] = STATE(137),
    [sym_preproc_pragma] = STATE(137),
    [sym_preproc_nullable] = STATE(137),
    [sym_preproc_error] = STATE(137),
    [sym_preproc_warning] = STATE(137),
    [sym_preproc_define] = STATE(137),
    [sym_preproc_undef] = STATE(137),
    [aux_sym_class_declaration_repeat1] = STATE(2937),
    [aux_sym_class_declaration_repeat2] = STATE(3097),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(161),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1055),
    [anon_sym_unsafe] = ACTIONS(1057),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(171),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1059),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(193),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(195),
    [anon_sym_unchecked] = ACTIONS(193),
    [anon_sym_continue] = ACTIONS(197),
    [anon_sym_do] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_lock] = ACTIONS(205),
    [anon_sym_yield] = ACTIONS(207),
    [anon_sym_switch] = ACTIONS(209),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(211),
    [anon_sym_try] = ACTIONS(213),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(215),
    [anon_sym_foreach] = ACTIONS(217),
    [anon_sym_goto] = ACTIONS(219),
    [anon_sym_if] = ACTIONS(221),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(223),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [138] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2270),
    [sym_variable_declaration] = STATE(9038),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6880),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2248),
    [sym_break_statement] = STATE(2270),
    [sym_checked_statement] = STATE(2270),
    [sym_continue_statement] = STATE(2270),
    [sym_do_statement] = STATE(2270),
    [sym_empty_statement] = STATE(2270),
    [sym_expression_statement] = STATE(2270),
    [sym_fixed_statement] = STATE(2270),
    [sym_for_statement] = STATE(2270),
    [sym_return_statement] = STATE(2270),
    [sym_lock_statement] = STATE(2270),
    [sym_yield_statement] = STATE(2270),
    [sym_switch_statement] = STATE(2270),
    [sym_throw_statement] = STATE(2270),
    [sym_try_statement] = STATE(2270),
    [sym_unsafe_statement] = STATE(2270),
    [sym_using_statement] = STATE(2270),
    [sym_foreach_statement] = STATE(2270),
    [sym_goto_statement] = STATE(2270),
    [sym_labeled_statement] = STATE(2270),
    [sym_if_statement] = STATE(2270),
    [sym_while_statement] = STATE(2270),
    [sym_local_declaration_statement] = STATE(2270),
    [sym_local_function_statement] = STATE(2270),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6279),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2841),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2270),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(138),
    [sym_preproc_endregion] = STATE(138),
    [sym_preproc_line] = STATE(138),
    [sym_preproc_pragma] = STATE(138),
    [sym_preproc_nullable] = STATE(138),
    [sym_preproc_error] = STATE(138),
    [sym_preproc_warning] = STATE(138),
    [sym_preproc_define] = STATE(138),
    [sym_preproc_undef] = STATE(138),
    [aux_sym_class_declaration_repeat1] = STATE(2937),
    [aux_sym_class_declaration_repeat2] = STATE(3097),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(161),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1055),
    [anon_sym_unsafe] = ACTIONS(1057),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(171),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1059),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(193),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(195),
    [anon_sym_unchecked] = ACTIONS(193),
    [anon_sym_continue] = ACTIONS(197),
    [anon_sym_do] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_lock] = ACTIONS(205),
    [anon_sym_yield] = ACTIONS(207),
    [anon_sym_switch] = ACTIONS(209),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(211),
    [anon_sym_try] = ACTIONS(213),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(215),
    [anon_sym_foreach] = ACTIONS(217),
    [anon_sym_goto] = ACTIONS(219),
    [anon_sym_if] = ACTIONS(221),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(223),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [139] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2270),
    [sym_variable_declaration] = STATE(9038),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6880),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2249),
    [sym_break_statement] = STATE(2270),
    [sym_checked_statement] = STATE(2270),
    [sym_continue_statement] = STATE(2270),
    [sym_do_statement] = STATE(2270),
    [sym_empty_statement] = STATE(2270),
    [sym_expression_statement] = STATE(2270),
    [sym_fixed_statement] = STATE(2270),
    [sym_for_statement] = STATE(2270),
    [sym_return_statement] = STATE(2270),
    [sym_lock_statement] = STATE(2270),
    [sym_yield_statement] = STATE(2270),
    [sym_switch_statement] = STATE(2270),
    [sym_throw_statement] = STATE(2270),
    [sym_try_statement] = STATE(2270),
    [sym_unsafe_statement] = STATE(2270),
    [sym_using_statement] = STATE(2270),
    [sym_foreach_statement] = STATE(2270),
    [sym_goto_statement] = STATE(2270),
    [sym_labeled_statement] = STATE(2270),
    [sym_if_statement] = STATE(2270),
    [sym_while_statement] = STATE(2270),
    [sym_local_declaration_statement] = STATE(2270),
    [sym_local_function_statement] = STATE(2270),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6279),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2841),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2270),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(139),
    [sym_preproc_endregion] = STATE(139),
    [sym_preproc_line] = STATE(139),
    [sym_preproc_pragma] = STATE(139),
    [sym_preproc_nullable] = STATE(139),
    [sym_preproc_error] = STATE(139),
    [sym_preproc_warning] = STATE(139),
    [sym_preproc_define] = STATE(139),
    [sym_preproc_undef] = STATE(139),
    [aux_sym_class_declaration_repeat1] = STATE(2937),
    [aux_sym_class_declaration_repeat2] = STATE(3097),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(161),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1055),
    [anon_sym_unsafe] = ACTIONS(1057),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(171),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1059),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(193),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(195),
    [anon_sym_unchecked] = ACTIONS(193),
    [anon_sym_continue] = ACTIONS(197),
    [anon_sym_do] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_lock] = ACTIONS(205),
    [anon_sym_yield] = ACTIONS(207),
    [anon_sym_switch] = ACTIONS(209),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(211),
    [anon_sym_try] = ACTIONS(213),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(215),
    [anon_sym_foreach] = ACTIONS(217),
    [anon_sym_goto] = ACTIONS(219),
    [anon_sym_if] = ACTIONS(221),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(223),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [140] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2270),
    [sym_variable_declaration] = STATE(9038),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6880),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2250),
    [sym_break_statement] = STATE(2270),
    [sym_checked_statement] = STATE(2270),
    [sym_continue_statement] = STATE(2270),
    [sym_do_statement] = STATE(2270),
    [sym_empty_statement] = STATE(2270),
    [sym_expression_statement] = STATE(2270),
    [sym_fixed_statement] = STATE(2270),
    [sym_for_statement] = STATE(2270),
    [sym_return_statement] = STATE(2270),
    [sym_lock_statement] = STATE(2270),
    [sym_yield_statement] = STATE(2270),
    [sym_switch_statement] = STATE(2270),
    [sym_throw_statement] = STATE(2270),
    [sym_try_statement] = STATE(2270),
    [sym_unsafe_statement] = STATE(2270),
    [sym_using_statement] = STATE(2270),
    [sym_foreach_statement] = STATE(2270),
    [sym_goto_statement] = STATE(2270),
    [sym_labeled_statement] = STATE(2270),
    [sym_if_statement] = STATE(2270),
    [sym_while_statement] = STATE(2270),
    [sym_local_declaration_statement] = STATE(2270),
    [sym_local_function_statement] = STATE(2270),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6279),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2841),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2270),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(140),
    [sym_preproc_endregion] = STATE(140),
    [sym_preproc_line] = STATE(140),
    [sym_preproc_pragma] = STATE(140),
    [sym_preproc_nullable] = STATE(140),
    [sym_preproc_error] = STATE(140),
    [sym_preproc_warning] = STATE(140),
    [sym_preproc_define] = STATE(140),
    [sym_preproc_undef] = STATE(140),
    [aux_sym_class_declaration_repeat1] = STATE(2937),
    [aux_sym_class_declaration_repeat2] = STATE(3097),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(161),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1055),
    [anon_sym_unsafe] = ACTIONS(1057),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(171),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1059),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(193),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(195),
    [anon_sym_unchecked] = ACTIONS(193),
    [anon_sym_continue] = ACTIONS(197),
    [anon_sym_do] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_lock] = ACTIONS(205),
    [anon_sym_yield] = ACTIONS(207),
    [anon_sym_switch] = ACTIONS(209),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(211),
    [anon_sym_try] = ACTIONS(213),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(215),
    [anon_sym_foreach] = ACTIONS(217),
    [anon_sym_goto] = ACTIONS(219),
    [anon_sym_if] = ACTIONS(221),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(223),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [141] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2270),
    [sym_variable_declaration] = STATE(9038),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6880),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2251),
    [sym_break_statement] = STATE(2270),
    [sym_checked_statement] = STATE(2270),
    [sym_continue_statement] = STATE(2270),
    [sym_do_statement] = STATE(2270),
    [sym_empty_statement] = STATE(2270),
    [sym_expression_statement] = STATE(2270),
    [sym_fixed_statement] = STATE(2270),
    [sym_for_statement] = STATE(2270),
    [sym_return_statement] = STATE(2270),
    [sym_lock_statement] = STATE(2270),
    [sym_yield_statement] = STATE(2270),
    [sym_switch_statement] = STATE(2270),
    [sym_throw_statement] = STATE(2270),
    [sym_try_statement] = STATE(2270),
    [sym_unsafe_statement] = STATE(2270),
    [sym_using_statement] = STATE(2270),
    [sym_foreach_statement] = STATE(2270),
    [sym_goto_statement] = STATE(2270),
    [sym_labeled_statement] = STATE(2270),
    [sym_if_statement] = STATE(2270),
    [sym_while_statement] = STATE(2270),
    [sym_local_declaration_statement] = STATE(2270),
    [sym_local_function_statement] = STATE(2270),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6279),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2841),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2270),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(141),
    [sym_preproc_endregion] = STATE(141),
    [sym_preproc_line] = STATE(141),
    [sym_preproc_pragma] = STATE(141),
    [sym_preproc_nullable] = STATE(141),
    [sym_preproc_error] = STATE(141),
    [sym_preproc_warning] = STATE(141),
    [sym_preproc_define] = STATE(141),
    [sym_preproc_undef] = STATE(141),
    [aux_sym_class_declaration_repeat1] = STATE(2937),
    [aux_sym_class_declaration_repeat2] = STATE(3097),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(161),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1055),
    [anon_sym_unsafe] = ACTIONS(1057),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(171),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1059),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(193),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(195),
    [anon_sym_unchecked] = ACTIONS(193),
    [anon_sym_continue] = ACTIONS(197),
    [anon_sym_do] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_lock] = ACTIONS(205),
    [anon_sym_yield] = ACTIONS(207),
    [anon_sym_switch] = ACTIONS(209),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(211),
    [anon_sym_try] = ACTIONS(213),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(215),
    [anon_sym_foreach] = ACTIONS(217),
    [anon_sym_goto] = ACTIONS(219),
    [anon_sym_if] = ACTIONS(221),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(223),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [142] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2270),
    [sym_variable_declaration] = STATE(9038),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6880),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2252),
    [sym_break_statement] = STATE(2270),
    [sym_checked_statement] = STATE(2270),
    [sym_continue_statement] = STATE(2270),
    [sym_do_statement] = STATE(2270),
    [sym_empty_statement] = STATE(2270),
    [sym_expression_statement] = STATE(2270),
    [sym_fixed_statement] = STATE(2270),
    [sym_for_statement] = STATE(2270),
    [sym_return_statement] = STATE(2270),
    [sym_lock_statement] = STATE(2270),
    [sym_yield_statement] = STATE(2270),
    [sym_switch_statement] = STATE(2270),
    [sym_throw_statement] = STATE(2270),
    [sym_try_statement] = STATE(2270),
    [sym_unsafe_statement] = STATE(2270),
    [sym_using_statement] = STATE(2270),
    [sym_foreach_statement] = STATE(2270),
    [sym_goto_statement] = STATE(2270),
    [sym_labeled_statement] = STATE(2270),
    [sym_if_statement] = STATE(2270),
    [sym_while_statement] = STATE(2270),
    [sym_local_declaration_statement] = STATE(2270),
    [sym_local_function_statement] = STATE(2270),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6279),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2841),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2270),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(142),
    [sym_preproc_endregion] = STATE(142),
    [sym_preproc_line] = STATE(142),
    [sym_preproc_pragma] = STATE(142),
    [sym_preproc_nullable] = STATE(142),
    [sym_preproc_error] = STATE(142),
    [sym_preproc_warning] = STATE(142),
    [sym_preproc_define] = STATE(142),
    [sym_preproc_undef] = STATE(142),
    [aux_sym_class_declaration_repeat1] = STATE(2937),
    [aux_sym_class_declaration_repeat2] = STATE(3097),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(161),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1055),
    [anon_sym_unsafe] = ACTIONS(1057),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(171),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1059),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(193),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(195),
    [anon_sym_unchecked] = ACTIONS(193),
    [anon_sym_continue] = ACTIONS(197),
    [anon_sym_do] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_lock] = ACTIONS(205),
    [anon_sym_yield] = ACTIONS(207),
    [anon_sym_switch] = ACTIONS(209),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(211),
    [anon_sym_try] = ACTIONS(213),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(215),
    [anon_sym_foreach] = ACTIONS(217),
    [anon_sym_goto] = ACTIONS(219),
    [anon_sym_if] = ACTIONS(221),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(223),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [143] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2270),
    [sym_variable_declaration] = STATE(9038),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6880),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2253),
    [sym_break_statement] = STATE(2270),
    [sym_checked_statement] = STATE(2270),
    [sym_continue_statement] = STATE(2270),
    [sym_do_statement] = STATE(2270),
    [sym_empty_statement] = STATE(2270),
    [sym_expression_statement] = STATE(2270),
    [sym_fixed_statement] = STATE(2270),
    [sym_for_statement] = STATE(2270),
    [sym_return_statement] = STATE(2270),
    [sym_lock_statement] = STATE(2270),
    [sym_yield_statement] = STATE(2270),
    [sym_switch_statement] = STATE(2270),
    [sym_throw_statement] = STATE(2270),
    [sym_try_statement] = STATE(2270),
    [sym_unsafe_statement] = STATE(2270),
    [sym_using_statement] = STATE(2270),
    [sym_foreach_statement] = STATE(2270),
    [sym_goto_statement] = STATE(2270),
    [sym_labeled_statement] = STATE(2270),
    [sym_if_statement] = STATE(2270),
    [sym_while_statement] = STATE(2270),
    [sym_local_declaration_statement] = STATE(2270),
    [sym_local_function_statement] = STATE(2270),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6279),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2841),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2270),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(143),
    [sym_preproc_endregion] = STATE(143),
    [sym_preproc_line] = STATE(143),
    [sym_preproc_pragma] = STATE(143),
    [sym_preproc_nullable] = STATE(143),
    [sym_preproc_error] = STATE(143),
    [sym_preproc_warning] = STATE(143),
    [sym_preproc_define] = STATE(143),
    [sym_preproc_undef] = STATE(143),
    [aux_sym_class_declaration_repeat1] = STATE(2937),
    [aux_sym_class_declaration_repeat2] = STATE(3097),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(161),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1055),
    [anon_sym_unsafe] = ACTIONS(1057),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(171),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1059),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(193),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(195),
    [anon_sym_unchecked] = ACTIONS(193),
    [anon_sym_continue] = ACTIONS(197),
    [anon_sym_do] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_lock] = ACTIONS(205),
    [anon_sym_yield] = ACTIONS(207),
    [anon_sym_switch] = ACTIONS(209),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(211),
    [anon_sym_try] = ACTIONS(213),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(215),
    [anon_sym_foreach] = ACTIONS(217),
    [anon_sym_goto] = ACTIONS(219),
    [anon_sym_if] = ACTIONS(221),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(223),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [144] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2270),
    [sym_variable_declaration] = STATE(9038),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6880),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2254),
    [sym_break_statement] = STATE(2270),
    [sym_checked_statement] = STATE(2270),
    [sym_continue_statement] = STATE(2270),
    [sym_do_statement] = STATE(2270),
    [sym_empty_statement] = STATE(2270),
    [sym_expression_statement] = STATE(2270),
    [sym_fixed_statement] = STATE(2270),
    [sym_for_statement] = STATE(2270),
    [sym_return_statement] = STATE(2270),
    [sym_lock_statement] = STATE(2270),
    [sym_yield_statement] = STATE(2270),
    [sym_switch_statement] = STATE(2270),
    [sym_throw_statement] = STATE(2270),
    [sym_try_statement] = STATE(2270),
    [sym_unsafe_statement] = STATE(2270),
    [sym_using_statement] = STATE(2270),
    [sym_foreach_statement] = STATE(2270),
    [sym_goto_statement] = STATE(2270),
    [sym_labeled_statement] = STATE(2270),
    [sym_if_statement] = STATE(2270),
    [sym_while_statement] = STATE(2270),
    [sym_local_declaration_statement] = STATE(2270),
    [sym_local_function_statement] = STATE(2270),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6279),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2841),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2270),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(144),
    [sym_preproc_endregion] = STATE(144),
    [sym_preproc_line] = STATE(144),
    [sym_preproc_pragma] = STATE(144),
    [sym_preproc_nullable] = STATE(144),
    [sym_preproc_error] = STATE(144),
    [sym_preproc_warning] = STATE(144),
    [sym_preproc_define] = STATE(144),
    [sym_preproc_undef] = STATE(144),
    [aux_sym_class_declaration_repeat1] = STATE(2937),
    [aux_sym_class_declaration_repeat2] = STATE(3097),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(161),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1055),
    [anon_sym_unsafe] = ACTIONS(1057),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(171),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1059),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(193),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(195),
    [anon_sym_unchecked] = ACTIONS(193),
    [anon_sym_continue] = ACTIONS(197),
    [anon_sym_do] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_lock] = ACTIONS(205),
    [anon_sym_yield] = ACTIONS(207),
    [anon_sym_switch] = ACTIONS(209),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(211),
    [anon_sym_try] = ACTIONS(213),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(215),
    [anon_sym_foreach] = ACTIONS(217),
    [anon_sym_goto] = ACTIONS(219),
    [anon_sym_if] = ACTIONS(221),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(223),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [145] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2270),
    [sym_variable_declaration] = STATE(9038),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6880),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2255),
    [sym_break_statement] = STATE(2270),
    [sym_checked_statement] = STATE(2270),
    [sym_continue_statement] = STATE(2270),
    [sym_do_statement] = STATE(2270),
    [sym_empty_statement] = STATE(2270),
    [sym_expression_statement] = STATE(2270),
    [sym_fixed_statement] = STATE(2270),
    [sym_for_statement] = STATE(2270),
    [sym_return_statement] = STATE(2270),
    [sym_lock_statement] = STATE(2270),
    [sym_yield_statement] = STATE(2270),
    [sym_switch_statement] = STATE(2270),
    [sym_throw_statement] = STATE(2270),
    [sym_try_statement] = STATE(2270),
    [sym_unsafe_statement] = STATE(2270),
    [sym_using_statement] = STATE(2270),
    [sym_foreach_statement] = STATE(2270),
    [sym_goto_statement] = STATE(2270),
    [sym_labeled_statement] = STATE(2270),
    [sym_if_statement] = STATE(2270),
    [sym_while_statement] = STATE(2270),
    [sym_local_declaration_statement] = STATE(2270),
    [sym_local_function_statement] = STATE(2270),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6279),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2841),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2270),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(145),
    [sym_preproc_endregion] = STATE(145),
    [sym_preproc_line] = STATE(145),
    [sym_preproc_pragma] = STATE(145),
    [sym_preproc_nullable] = STATE(145),
    [sym_preproc_error] = STATE(145),
    [sym_preproc_warning] = STATE(145),
    [sym_preproc_define] = STATE(145),
    [sym_preproc_undef] = STATE(145),
    [aux_sym_class_declaration_repeat1] = STATE(2937),
    [aux_sym_class_declaration_repeat2] = STATE(3097),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(161),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1055),
    [anon_sym_unsafe] = ACTIONS(1057),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(171),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1059),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(193),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(195),
    [anon_sym_unchecked] = ACTIONS(193),
    [anon_sym_continue] = ACTIONS(197),
    [anon_sym_do] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_lock] = ACTIONS(205),
    [anon_sym_yield] = ACTIONS(207),
    [anon_sym_switch] = ACTIONS(209),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(211),
    [anon_sym_try] = ACTIONS(213),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(215),
    [anon_sym_foreach] = ACTIONS(217),
    [anon_sym_goto] = ACTIONS(219),
    [anon_sym_if] = ACTIONS(221),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(223),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [146] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2270),
    [sym_variable_declaration] = STATE(9038),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6880),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2256),
    [sym_break_statement] = STATE(2270),
    [sym_checked_statement] = STATE(2270),
    [sym_continue_statement] = STATE(2270),
    [sym_do_statement] = STATE(2270),
    [sym_empty_statement] = STATE(2270),
    [sym_expression_statement] = STATE(2270),
    [sym_fixed_statement] = STATE(2270),
    [sym_for_statement] = STATE(2270),
    [sym_return_statement] = STATE(2270),
    [sym_lock_statement] = STATE(2270),
    [sym_yield_statement] = STATE(2270),
    [sym_switch_statement] = STATE(2270),
    [sym_throw_statement] = STATE(2270),
    [sym_try_statement] = STATE(2270),
    [sym_unsafe_statement] = STATE(2270),
    [sym_using_statement] = STATE(2270),
    [sym_foreach_statement] = STATE(2270),
    [sym_goto_statement] = STATE(2270),
    [sym_labeled_statement] = STATE(2270),
    [sym_if_statement] = STATE(2270),
    [sym_while_statement] = STATE(2270),
    [sym_local_declaration_statement] = STATE(2270),
    [sym_local_function_statement] = STATE(2270),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6279),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2841),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2270),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(146),
    [sym_preproc_endregion] = STATE(146),
    [sym_preproc_line] = STATE(146),
    [sym_preproc_pragma] = STATE(146),
    [sym_preproc_nullable] = STATE(146),
    [sym_preproc_error] = STATE(146),
    [sym_preproc_warning] = STATE(146),
    [sym_preproc_define] = STATE(146),
    [sym_preproc_undef] = STATE(146),
    [aux_sym_class_declaration_repeat1] = STATE(2937),
    [aux_sym_class_declaration_repeat2] = STATE(3097),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(161),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1055),
    [anon_sym_unsafe] = ACTIONS(1057),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(171),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(183),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1059),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(193),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(195),
    [anon_sym_unchecked] = ACTIONS(193),
    [anon_sym_continue] = ACTIONS(197),
    [anon_sym_do] = ACTIONS(199),
    [anon_sym_while] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(203),
    [anon_sym_lock] = ACTIONS(205),
    [anon_sym_yield] = ACTIONS(207),
    [anon_sym_switch] = ACTIONS(209),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(211),
    [anon_sym_try] = ACTIONS(213),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(215),
    [anon_sym_foreach] = ACTIONS(217),
    [anon_sym_goto] = ACTIONS(219),
    [anon_sym_if] = ACTIONS(221),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(223),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [147] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2493),
    [sym_variable_declaration] = STATE(9635),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6854),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2456),
    [sym_break_statement] = STATE(2493),
    [sym_checked_statement] = STATE(2493),
    [sym_continue_statement] = STATE(2493),
    [sym_do_statement] = STATE(2493),
    [sym_empty_statement] = STATE(2493),
    [sym_expression_statement] = STATE(2493),
    [sym_fixed_statement] = STATE(2493),
    [sym_for_statement] = STATE(2493),
    [sym_return_statement] = STATE(2493),
    [sym_lock_statement] = STATE(2493),
    [sym_yield_statement] = STATE(2493),
    [sym_switch_statement] = STATE(2493),
    [sym_throw_statement] = STATE(2493),
    [sym_try_statement] = STATE(2493),
    [sym_unsafe_statement] = STATE(2493),
    [sym_using_statement] = STATE(2493),
    [sym_foreach_statement] = STATE(2493),
    [sym_goto_statement] = STATE(2493),
    [sym_labeled_statement] = STATE(2493),
    [sym_if_statement] = STATE(2493),
    [sym_while_statement] = STATE(2493),
    [sym_local_declaration_statement] = STATE(2493),
    [sym_local_function_statement] = STATE(2493),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6748),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2907),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2493),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(147),
    [sym_preproc_endregion] = STATE(147),
    [sym_preproc_line] = STATE(147),
    [sym_preproc_pragma] = STATE(147),
    [sym_preproc_nullable] = STATE(147),
    [sym_preproc_error] = STATE(147),
    [sym_preproc_warning] = STATE(147),
    [sym_preproc_define] = STATE(147),
    [sym_preproc_undef] = STATE(147),
    [aux_sym_class_declaration_repeat1] = STATE(2936),
    [aux_sym_class_declaration_repeat2] = STATE(3108),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(31),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1005),
    [anon_sym_unsafe] = ACTIONS(1007),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(45),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1009),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(73),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_unchecked] = ACTIONS(73),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_do] = ACTIONS(97),
    [anon_sym_while] = ACTIONS(99),
    [anon_sym_for] = ACTIONS(101),
    [anon_sym_lock] = ACTIONS(103),
    [anon_sym_yield] = ACTIONS(105),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(111),
    [anon_sym_try] = ACTIONS(113),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(115),
    [anon_sym_foreach] = ACTIONS(117),
    [anon_sym_goto] = ACTIONS(119),
    [anon_sym_if] = ACTIONS(121),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(147),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [148] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2493),
    [sym_variable_declaration] = STATE(9635),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6854),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2457),
    [sym_break_statement] = STATE(2493),
    [sym_checked_statement] = STATE(2493),
    [sym_continue_statement] = STATE(2493),
    [sym_do_statement] = STATE(2493),
    [sym_empty_statement] = STATE(2493),
    [sym_expression_statement] = STATE(2493),
    [sym_fixed_statement] = STATE(2493),
    [sym_for_statement] = STATE(2493),
    [sym_return_statement] = STATE(2493),
    [sym_lock_statement] = STATE(2493),
    [sym_yield_statement] = STATE(2493),
    [sym_switch_statement] = STATE(2493),
    [sym_throw_statement] = STATE(2493),
    [sym_try_statement] = STATE(2493),
    [sym_unsafe_statement] = STATE(2493),
    [sym_using_statement] = STATE(2493),
    [sym_foreach_statement] = STATE(2493),
    [sym_goto_statement] = STATE(2493),
    [sym_labeled_statement] = STATE(2493),
    [sym_if_statement] = STATE(2493),
    [sym_while_statement] = STATE(2493),
    [sym_local_declaration_statement] = STATE(2493),
    [sym_local_function_statement] = STATE(2493),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6748),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2907),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2493),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(148),
    [sym_preproc_endregion] = STATE(148),
    [sym_preproc_line] = STATE(148),
    [sym_preproc_pragma] = STATE(148),
    [sym_preproc_nullable] = STATE(148),
    [sym_preproc_error] = STATE(148),
    [sym_preproc_warning] = STATE(148),
    [sym_preproc_define] = STATE(148),
    [sym_preproc_undef] = STATE(148),
    [aux_sym_class_declaration_repeat1] = STATE(2936),
    [aux_sym_class_declaration_repeat2] = STATE(3108),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(31),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1005),
    [anon_sym_unsafe] = ACTIONS(1007),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(45),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1009),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(73),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_unchecked] = ACTIONS(73),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_do] = ACTIONS(97),
    [anon_sym_while] = ACTIONS(99),
    [anon_sym_for] = ACTIONS(101),
    [anon_sym_lock] = ACTIONS(103),
    [anon_sym_yield] = ACTIONS(105),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(111),
    [anon_sym_try] = ACTIONS(113),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(115),
    [anon_sym_foreach] = ACTIONS(117),
    [anon_sym_goto] = ACTIONS(119),
    [anon_sym_if] = ACTIONS(121),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(147),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [149] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2493),
    [sym_variable_declaration] = STATE(9635),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6854),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2451),
    [sym_break_statement] = STATE(2493),
    [sym_checked_statement] = STATE(2493),
    [sym_continue_statement] = STATE(2493),
    [sym_do_statement] = STATE(2493),
    [sym_empty_statement] = STATE(2493),
    [sym_expression_statement] = STATE(2493),
    [sym_fixed_statement] = STATE(2493),
    [sym_for_statement] = STATE(2493),
    [sym_return_statement] = STATE(2493),
    [sym_lock_statement] = STATE(2493),
    [sym_yield_statement] = STATE(2493),
    [sym_switch_statement] = STATE(2493),
    [sym_throw_statement] = STATE(2493),
    [sym_try_statement] = STATE(2493),
    [sym_unsafe_statement] = STATE(2493),
    [sym_using_statement] = STATE(2493),
    [sym_foreach_statement] = STATE(2493),
    [sym_goto_statement] = STATE(2493),
    [sym_labeled_statement] = STATE(2493),
    [sym_if_statement] = STATE(2493),
    [sym_while_statement] = STATE(2493),
    [sym_local_declaration_statement] = STATE(2493),
    [sym_local_function_statement] = STATE(2493),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6748),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2907),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2493),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(149),
    [sym_preproc_endregion] = STATE(149),
    [sym_preproc_line] = STATE(149),
    [sym_preproc_pragma] = STATE(149),
    [sym_preproc_nullable] = STATE(149),
    [sym_preproc_error] = STATE(149),
    [sym_preproc_warning] = STATE(149),
    [sym_preproc_define] = STATE(149),
    [sym_preproc_undef] = STATE(149),
    [aux_sym_class_declaration_repeat1] = STATE(2936),
    [aux_sym_class_declaration_repeat2] = STATE(3108),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(31),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1005),
    [anon_sym_unsafe] = ACTIONS(1007),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(45),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1009),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(73),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_unchecked] = ACTIONS(73),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_do] = ACTIONS(97),
    [anon_sym_while] = ACTIONS(99),
    [anon_sym_for] = ACTIONS(101),
    [anon_sym_lock] = ACTIONS(103),
    [anon_sym_yield] = ACTIONS(105),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(111),
    [anon_sym_try] = ACTIONS(113),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(115),
    [anon_sym_foreach] = ACTIONS(117),
    [anon_sym_goto] = ACTIONS(119),
    [anon_sym_if] = ACTIONS(121),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(147),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [150] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2493),
    [sym_variable_declaration] = STATE(9635),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6854),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2455),
    [sym_break_statement] = STATE(2493),
    [sym_checked_statement] = STATE(2493),
    [sym_continue_statement] = STATE(2493),
    [sym_do_statement] = STATE(2493),
    [sym_empty_statement] = STATE(2493),
    [sym_expression_statement] = STATE(2493),
    [sym_fixed_statement] = STATE(2493),
    [sym_for_statement] = STATE(2493),
    [sym_return_statement] = STATE(2493),
    [sym_lock_statement] = STATE(2493),
    [sym_yield_statement] = STATE(2493),
    [sym_switch_statement] = STATE(2493),
    [sym_throw_statement] = STATE(2493),
    [sym_try_statement] = STATE(2493),
    [sym_unsafe_statement] = STATE(2493),
    [sym_using_statement] = STATE(2493),
    [sym_foreach_statement] = STATE(2493),
    [sym_goto_statement] = STATE(2493),
    [sym_labeled_statement] = STATE(2493),
    [sym_if_statement] = STATE(2493),
    [sym_while_statement] = STATE(2493),
    [sym_local_declaration_statement] = STATE(2493),
    [sym_local_function_statement] = STATE(2493),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6748),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2907),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2493),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(150),
    [sym_preproc_endregion] = STATE(150),
    [sym_preproc_line] = STATE(150),
    [sym_preproc_pragma] = STATE(150),
    [sym_preproc_nullable] = STATE(150),
    [sym_preproc_error] = STATE(150),
    [sym_preproc_warning] = STATE(150),
    [sym_preproc_define] = STATE(150),
    [sym_preproc_undef] = STATE(150),
    [aux_sym_class_declaration_repeat1] = STATE(2936),
    [aux_sym_class_declaration_repeat2] = STATE(3108),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(31),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1005),
    [anon_sym_unsafe] = ACTIONS(1007),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(45),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1009),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(73),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_unchecked] = ACTIONS(73),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_do] = ACTIONS(97),
    [anon_sym_while] = ACTIONS(99),
    [anon_sym_for] = ACTIONS(101),
    [anon_sym_lock] = ACTIONS(103),
    [anon_sym_yield] = ACTIONS(105),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(111),
    [anon_sym_try] = ACTIONS(113),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(115),
    [anon_sym_foreach] = ACTIONS(117),
    [anon_sym_goto] = ACTIONS(119),
    [anon_sym_if] = ACTIONS(121),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(147),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [151] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2493),
    [sym_variable_declaration] = STATE(9635),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6854),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2461),
    [sym_break_statement] = STATE(2493),
    [sym_checked_statement] = STATE(2493),
    [sym_continue_statement] = STATE(2493),
    [sym_do_statement] = STATE(2493),
    [sym_empty_statement] = STATE(2493),
    [sym_expression_statement] = STATE(2493),
    [sym_fixed_statement] = STATE(2493),
    [sym_for_statement] = STATE(2493),
    [sym_return_statement] = STATE(2493),
    [sym_lock_statement] = STATE(2493),
    [sym_yield_statement] = STATE(2493),
    [sym_switch_statement] = STATE(2493),
    [sym_throw_statement] = STATE(2493),
    [sym_try_statement] = STATE(2493),
    [sym_unsafe_statement] = STATE(2493),
    [sym_using_statement] = STATE(2493),
    [sym_foreach_statement] = STATE(2493),
    [sym_goto_statement] = STATE(2493),
    [sym_labeled_statement] = STATE(2493),
    [sym_if_statement] = STATE(2493),
    [sym_while_statement] = STATE(2493),
    [sym_local_declaration_statement] = STATE(2493),
    [sym_local_function_statement] = STATE(2493),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6748),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2907),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2493),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(151),
    [sym_preproc_endregion] = STATE(151),
    [sym_preproc_line] = STATE(151),
    [sym_preproc_pragma] = STATE(151),
    [sym_preproc_nullable] = STATE(151),
    [sym_preproc_error] = STATE(151),
    [sym_preproc_warning] = STATE(151),
    [sym_preproc_define] = STATE(151),
    [sym_preproc_undef] = STATE(151),
    [aux_sym_class_declaration_repeat1] = STATE(2936),
    [aux_sym_class_declaration_repeat2] = STATE(3108),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(31),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1005),
    [anon_sym_unsafe] = ACTIONS(1007),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(45),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1009),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(73),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_unchecked] = ACTIONS(73),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_do] = ACTIONS(97),
    [anon_sym_while] = ACTIONS(99),
    [anon_sym_for] = ACTIONS(101),
    [anon_sym_lock] = ACTIONS(103),
    [anon_sym_yield] = ACTIONS(105),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(111),
    [anon_sym_try] = ACTIONS(113),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(115),
    [anon_sym_foreach] = ACTIONS(117),
    [anon_sym_goto] = ACTIONS(119),
    [anon_sym_if] = ACTIONS(121),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(147),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [152] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2493),
    [sym_variable_declaration] = STATE(9635),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6854),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2472),
    [sym_break_statement] = STATE(2493),
    [sym_checked_statement] = STATE(2493),
    [sym_continue_statement] = STATE(2493),
    [sym_do_statement] = STATE(2493),
    [sym_empty_statement] = STATE(2493),
    [sym_expression_statement] = STATE(2493),
    [sym_fixed_statement] = STATE(2493),
    [sym_for_statement] = STATE(2493),
    [sym_return_statement] = STATE(2493),
    [sym_lock_statement] = STATE(2493),
    [sym_yield_statement] = STATE(2493),
    [sym_switch_statement] = STATE(2493),
    [sym_throw_statement] = STATE(2493),
    [sym_try_statement] = STATE(2493),
    [sym_unsafe_statement] = STATE(2493),
    [sym_using_statement] = STATE(2493),
    [sym_foreach_statement] = STATE(2493),
    [sym_goto_statement] = STATE(2493),
    [sym_labeled_statement] = STATE(2493),
    [sym_if_statement] = STATE(2493),
    [sym_while_statement] = STATE(2493),
    [sym_local_declaration_statement] = STATE(2493),
    [sym_local_function_statement] = STATE(2493),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6748),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2907),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2493),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(152),
    [sym_preproc_endregion] = STATE(152),
    [sym_preproc_line] = STATE(152),
    [sym_preproc_pragma] = STATE(152),
    [sym_preproc_nullable] = STATE(152),
    [sym_preproc_error] = STATE(152),
    [sym_preproc_warning] = STATE(152),
    [sym_preproc_define] = STATE(152),
    [sym_preproc_undef] = STATE(152),
    [aux_sym_class_declaration_repeat1] = STATE(2936),
    [aux_sym_class_declaration_repeat2] = STATE(3108),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(31),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1005),
    [anon_sym_unsafe] = ACTIONS(1007),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(45),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1009),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(73),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_unchecked] = ACTIONS(73),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_do] = ACTIONS(97),
    [anon_sym_while] = ACTIONS(99),
    [anon_sym_for] = ACTIONS(101),
    [anon_sym_lock] = ACTIONS(103),
    [anon_sym_yield] = ACTIONS(105),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(111),
    [anon_sym_try] = ACTIONS(113),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(115),
    [anon_sym_foreach] = ACTIONS(117),
    [anon_sym_goto] = ACTIONS(119),
    [anon_sym_if] = ACTIONS(121),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(147),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [153] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2493),
    [sym_variable_declaration] = STATE(9635),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6854),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2467),
    [sym_break_statement] = STATE(2493),
    [sym_checked_statement] = STATE(2493),
    [sym_continue_statement] = STATE(2493),
    [sym_do_statement] = STATE(2493),
    [sym_empty_statement] = STATE(2493),
    [sym_expression_statement] = STATE(2493),
    [sym_fixed_statement] = STATE(2493),
    [sym_for_statement] = STATE(2493),
    [sym_return_statement] = STATE(2493),
    [sym_lock_statement] = STATE(2493),
    [sym_yield_statement] = STATE(2493),
    [sym_switch_statement] = STATE(2493),
    [sym_throw_statement] = STATE(2493),
    [sym_try_statement] = STATE(2493),
    [sym_unsafe_statement] = STATE(2493),
    [sym_using_statement] = STATE(2493),
    [sym_foreach_statement] = STATE(2493),
    [sym_goto_statement] = STATE(2493),
    [sym_labeled_statement] = STATE(2493),
    [sym_if_statement] = STATE(2493),
    [sym_while_statement] = STATE(2493),
    [sym_local_declaration_statement] = STATE(2493),
    [sym_local_function_statement] = STATE(2493),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6748),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2907),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2493),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(153),
    [sym_preproc_endregion] = STATE(153),
    [sym_preproc_line] = STATE(153),
    [sym_preproc_pragma] = STATE(153),
    [sym_preproc_nullable] = STATE(153),
    [sym_preproc_error] = STATE(153),
    [sym_preproc_warning] = STATE(153),
    [sym_preproc_define] = STATE(153),
    [sym_preproc_undef] = STATE(153),
    [aux_sym_class_declaration_repeat1] = STATE(2936),
    [aux_sym_class_declaration_repeat2] = STATE(3108),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(31),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1005),
    [anon_sym_unsafe] = ACTIONS(1007),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(45),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1009),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(73),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_unchecked] = ACTIONS(73),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_do] = ACTIONS(97),
    [anon_sym_while] = ACTIONS(99),
    [anon_sym_for] = ACTIONS(101),
    [anon_sym_lock] = ACTIONS(103),
    [anon_sym_yield] = ACTIONS(105),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(111),
    [anon_sym_try] = ACTIONS(113),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(115),
    [anon_sym_foreach] = ACTIONS(117),
    [anon_sym_goto] = ACTIONS(119),
    [anon_sym_if] = ACTIONS(121),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(147),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [154] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2493),
    [sym_variable_declaration] = STATE(9635),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6854),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2465),
    [sym_break_statement] = STATE(2493),
    [sym_checked_statement] = STATE(2493),
    [sym_continue_statement] = STATE(2493),
    [sym_do_statement] = STATE(2493),
    [sym_empty_statement] = STATE(2493),
    [sym_expression_statement] = STATE(2493),
    [sym_fixed_statement] = STATE(2493),
    [sym_for_statement] = STATE(2493),
    [sym_return_statement] = STATE(2493),
    [sym_lock_statement] = STATE(2493),
    [sym_yield_statement] = STATE(2493),
    [sym_switch_statement] = STATE(2493),
    [sym_throw_statement] = STATE(2493),
    [sym_try_statement] = STATE(2493),
    [sym_unsafe_statement] = STATE(2493),
    [sym_using_statement] = STATE(2493),
    [sym_foreach_statement] = STATE(2493),
    [sym_goto_statement] = STATE(2493),
    [sym_labeled_statement] = STATE(2493),
    [sym_if_statement] = STATE(2493),
    [sym_while_statement] = STATE(2493),
    [sym_local_declaration_statement] = STATE(2493),
    [sym_local_function_statement] = STATE(2493),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6748),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2907),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2493),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(154),
    [sym_preproc_endregion] = STATE(154),
    [sym_preproc_line] = STATE(154),
    [sym_preproc_pragma] = STATE(154),
    [sym_preproc_nullable] = STATE(154),
    [sym_preproc_error] = STATE(154),
    [sym_preproc_warning] = STATE(154),
    [sym_preproc_define] = STATE(154),
    [sym_preproc_undef] = STATE(154),
    [aux_sym_class_declaration_repeat1] = STATE(2936),
    [aux_sym_class_declaration_repeat2] = STATE(3108),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(31),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1005),
    [anon_sym_unsafe] = ACTIONS(1007),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(45),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1009),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(73),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_unchecked] = ACTIONS(73),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_do] = ACTIONS(97),
    [anon_sym_while] = ACTIONS(99),
    [anon_sym_for] = ACTIONS(101),
    [anon_sym_lock] = ACTIONS(103),
    [anon_sym_yield] = ACTIONS(105),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(111),
    [anon_sym_try] = ACTIONS(113),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(115),
    [anon_sym_foreach] = ACTIONS(117),
    [anon_sym_goto] = ACTIONS(119),
    [anon_sym_if] = ACTIONS(121),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(147),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [155] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2493),
    [sym_variable_declaration] = STATE(9635),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6854),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2466),
    [sym_break_statement] = STATE(2493),
    [sym_checked_statement] = STATE(2493),
    [sym_continue_statement] = STATE(2493),
    [sym_do_statement] = STATE(2493),
    [sym_empty_statement] = STATE(2493),
    [sym_expression_statement] = STATE(2493),
    [sym_fixed_statement] = STATE(2493),
    [sym_for_statement] = STATE(2493),
    [sym_return_statement] = STATE(2493),
    [sym_lock_statement] = STATE(2493),
    [sym_yield_statement] = STATE(2493),
    [sym_switch_statement] = STATE(2493),
    [sym_throw_statement] = STATE(2493),
    [sym_try_statement] = STATE(2493),
    [sym_unsafe_statement] = STATE(2493),
    [sym_using_statement] = STATE(2493),
    [sym_foreach_statement] = STATE(2493),
    [sym_goto_statement] = STATE(2493),
    [sym_labeled_statement] = STATE(2493),
    [sym_if_statement] = STATE(2493),
    [sym_while_statement] = STATE(2493),
    [sym_local_declaration_statement] = STATE(2493),
    [sym_local_function_statement] = STATE(2493),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6748),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2907),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2493),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(155),
    [sym_preproc_endregion] = STATE(155),
    [sym_preproc_line] = STATE(155),
    [sym_preproc_pragma] = STATE(155),
    [sym_preproc_nullable] = STATE(155),
    [sym_preproc_error] = STATE(155),
    [sym_preproc_warning] = STATE(155),
    [sym_preproc_define] = STATE(155),
    [sym_preproc_undef] = STATE(155),
    [aux_sym_class_declaration_repeat1] = STATE(2936),
    [aux_sym_class_declaration_repeat2] = STATE(3108),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(31),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1005),
    [anon_sym_unsafe] = ACTIONS(1007),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(45),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1009),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(73),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_unchecked] = ACTIONS(73),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_do] = ACTIONS(97),
    [anon_sym_while] = ACTIONS(99),
    [anon_sym_for] = ACTIONS(101),
    [anon_sym_lock] = ACTIONS(103),
    [anon_sym_yield] = ACTIONS(105),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(111),
    [anon_sym_try] = ACTIONS(113),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(115),
    [anon_sym_foreach] = ACTIONS(117),
    [anon_sym_goto] = ACTIONS(119),
    [anon_sym_if] = ACTIONS(121),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(147),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [156] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2493),
    [sym_variable_declaration] = STATE(9635),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6854),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2489),
    [sym_break_statement] = STATE(2493),
    [sym_checked_statement] = STATE(2493),
    [sym_continue_statement] = STATE(2493),
    [sym_do_statement] = STATE(2493),
    [sym_empty_statement] = STATE(2493),
    [sym_expression_statement] = STATE(2493),
    [sym_fixed_statement] = STATE(2493),
    [sym_for_statement] = STATE(2493),
    [sym_return_statement] = STATE(2493),
    [sym_lock_statement] = STATE(2493),
    [sym_yield_statement] = STATE(2493),
    [sym_switch_statement] = STATE(2493),
    [sym_throw_statement] = STATE(2493),
    [sym_try_statement] = STATE(2493),
    [sym_unsafe_statement] = STATE(2493),
    [sym_using_statement] = STATE(2493),
    [sym_foreach_statement] = STATE(2493),
    [sym_goto_statement] = STATE(2493),
    [sym_labeled_statement] = STATE(2493),
    [sym_if_statement] = STATE(2493),
    [sym_while_statement] = STATE(2493),
    [sym_local_declaration_statement] = STATE(2493),
    [sym_local_function_statement] = STATE(2493),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6748),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2907),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2493),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(156),
    [sym_preproc_endregion] = STATE(156),
    [sym_preproc_line] = STATE(156),
    [sym_preproc_pragma] = STATE(156),
    [sym_preproc_nullable] = STATE(156),
    [sym_preproc_error] = STATE(156),
    [sym_preproc_warning] = STATE(156),
    [sym_preproc_define] = STATE(156),
    [sym_preproc_undef] = STATE(156),
    [aux_sym_class_declaration_repeat1] = STATE(2936),
    [aux_sym_class_declaration_repeat2] = STATE(3108),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(31),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1005),
    [anon_sym_unsafe] = ACTIONS(1007),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(45),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1009),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(73),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_unchecked] = ACTIONS(73),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_do] = ACTIONS(97),
    [anon_sym_while] = ACTIONS(99),
    [anon_sym_for] = ACTIONS(101),
    [anon_sym_lock] = ACTIONS(103),
    [anon_sym_yield] = ACTIONS(105),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(111),
    [anon_sym_try] = ACTIONS(113),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(115),
    [anon_sym_foreach] = ACTIONS(117),
    [anon_sym_goto] = ACTIONS(119),
    [anon_sym_if] = ACTIONS(121),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(147),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [157] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2493),
    [sym_variable_declaration] = STATE(9635),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6854),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2490),
    [sym_break_statement] = STATE(2493),
    [sym_checked_statement] = STATE(2493),
    [sym_continue_statement] = STATE(2493),
    [sym_do_statement] = STATE(2493),
    [sym_empty_statement] = STATE(2493),
    [sym_expression_statement] = STATE(2493),
    [sym_fixed_statement] = STATE(2493),
    [sym_for_statement] = STATE(2493),
    [sym_return_statement] = STATE(2493),
    [sym_lock_statement] = STATE(2493),
    [sym_yield_statement] = STATE(2493),
    [sym_switch_statement] = STATE(2493),
    [sym_throw_statement] = STATE(2493),
    [sym_try_statement] = STATE(2493),
    [sym_unsafe_statement] = STATE(2493),
    [sym_using_statement] = STATE(2493),
    [sym_foreach_statement] = STATE(2493),
    [sym_goto_statement] = STATE(2493),
    [sym_labeled_statement] = STATE(2493),
    [sym_if_statement] = STATE(2493),
    [sym_while_statement] = STATE(2493),
    [sym_local_declaration_statement] = STATE(2493),
    [sym_local_function_statement] = STATE(2493),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6748),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2907),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2493),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(157),
    [sym_preproc_endregion] = STATE(157),
    [sym_preproc_line] = STATE(157),
    [sym_preproc_pragma] = STATE(157),
    [sym_preproc_nullable] = STATE(157),
    [sym_preproc_error] = STATE(157),
    [sym_preproc_warning] = STATE(157),
    [sym_preproc_define] = STATE(157),
    [sym_preproc_undef] = STATE(157),
    [aux_sym_class_declaration_repeat1] = STATE(2936),
    [aux_sym_class_declaration_repeat2] = STATE(3108),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(31),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1005),
    [anon_sym_unsafe] = ACTIONS(1007),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(45),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1009),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(73),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_unchecked] = ACTIONS(73),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_do] = ACTIONS(97),
    [anon_sym_while] = ACTIONS(99),
    [anon_sym_for] = ACTIONS(101),
    [anon_sym_lock] = ACTIONS(103),
    [anon_sym_yield] = ACTIONS(105),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(111),
    [anon_sym_try] = ACTIONS(113),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(115),
    [anon_sym_foreach] = ACTIONS(117),
    [anon_sym_goto] = ACTIONS(119),
    [anon_sym_if] = ACTIONS(121),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(147),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [158] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2493),
    [sym_variable_declaration] = STATE(9635),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6854),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2497),
    [sym_break_statement] = STATE(2493),
    [sym_checked_statement] = STATE(2493),
    [sym_continue_statement] = STATE(2493),
    [sym_do_statement] = STATE(2493),
    [sym_empty_statement] = STATE(2493),
    [sym_expression_statement] = STATE(2493),
    [sym_fixed_statement] = STATE(2493),
    [sym_for_statement] = STATE(2493),
    [sym_return_statement] = STATE(2493),
    [sym_lock_statement] = STATE(2493),
    [sym_yield_statement] = STATE(2493),
    [sym_switch_statement] = STATE(2493),
    [sym_throw_statement] = STATE(2493),
    [sym_try_statement] = STATE(2493),
    [sym_unsafe_statement] = STATE(2493),
    [sym_using_statement] = STATE(2493),
    [sym_foreach_statement] = STATE(2493),
    [sym_goto_statement] = STATE(2493),
    [sym_labeled_statement] = STATE(2493),
    [sym_if_statement] = STATE(2493),
    [sym_while_statement] = STATE(2493),
    [sym_local_declaration_statement] = STATE(2493),
    [sym_local_function_statement] = STATE(2493),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6748),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2907),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2493),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(158),
    [sym_preproc_endregion] = STATE(158),
    [sym_preproc_line] = STATE(158),
    [sym_preproc_pragma] = STATE(158),
    [sym_preproc_nullable] = STATE(158),
    [sym_preproc_error] = STATE(158),
    [sym_preproc_warning] = STATE(158),
    [sym_preproc_define] = STATE(158),
    [sym_preproc_undef] = STATE(158),
    [aux_sym_class_declaration_repeat1] = STATE(2936),
    [aux_sym_class_declaration_repeat2] = STATE(3108),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(31),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1005),
    [anon_sym_unsafe] = ACTIONS(1007),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(45),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1009),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(73),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_unchecked] = ACTIONS(73),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_do] = ACTIONS(97),
    [anon_sym_while] = ACTIONS(99),
    [anon_sym_for] = ACTIONS(101),
    [anon_sym_lock] = ACTIONS(103),
    [anon_sym_yield] = ACTIONS(105),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(111),
    [anon_sym_try] = ACTIONS(113),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(115),
    [anon_sym_foreach] = ACTIONS(117),
    [anon_sym_goto] = ACTIONS(119),
    [anon_sym_if] = ACTIONS(121),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(147),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [159] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2493),
    [sym_variable_declaration] = STATE(9635),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6854),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2500),
    [sym_break_statement] = STATE(2493),
    [sym_checked_statement] = STATE(2493),
    [sym_continue_statement] = STATE(2493),
    [sym_do_statement] = STATE(2493),
    [sym_empty_statement] = STATE(2493),
    [sym_expression_statement] = STATE(2493),
    [sym_fixed_statement] = STATE(2493),
    [sym_for_statement] = STATE(2493),
    [sym_return_statement] = STATE(2493),
    [sym_lock_statement] = STATE(2493),
    [sym_yield_statement] = STATE(2493),
    [sym_switch_statement] = STATE(2493),
    [sym_throw_statement] = STATE(2493),
    [sym_try_statement] = STATE(2493),
    [sym_unsafe_statement] = STATE(2493),
    [sym_using_statement] = STATE(2493),
    [sym_foreach_statement] = STATE(2493),
    [sym_goto_statement] = STATE(2493),
    [sym_labeled_statement] = STATE(2493),
    [sym_if_statement] = STATE(2493),
    [sym_while_statement] = STATE(2493),
    [sym_local_declaration_statement] = STATE(2493),
    [sym_local_function_statement] = STATE(2493),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6748),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2907),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2493),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(159),
    [sym_preproc_endregion] = STATE(159),
    [sym_preproc_line] = STATE(159),
    [sym_preproc_pragma] = STATE(159),
    [sym_preproc_nullable] = STATE(159),
    [sym_preproc_error] = STATE(159),
    [sym_preproc_warning] = STATE(159),
    [sym_preproc_define] = STATE(159),
    [sym_preproc_undef] = STATE(159),
    [aux_sym_class_declaration_repeat1] = STATE(2936),
    [aux_sym_class_declaration_repeat2] = STATE(3108),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(31),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1005),
    [anon_sym_unsafe] = ACTIONS(1007),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(45),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1009),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(73),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_unchecked] = ACTIONS(73),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_do] = ACTIONS(97),
    [anon_sym_while] = ACTIONS(99),
    [anon_sym_for] = ACTIONS(101),
    [anon_sym_lock] = ACTIONS(103),
    [anon_sym_yield] = ACTIONS(105),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(111),
    [anon_sym_try] = ACTIONS(113),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(115),
    [anon_sym_foreach] = ACTIONS(117),
    [anon_sym_goto] = ACTIONS(119),
    [anon_sym_if] = ACTIONS(121),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(147),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [160] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2493),
    [sym_variable_declaration] = STATE(9635),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6854),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2501),
    [sym_break_statement] = STATE(2493),
    [sym_checked_statement] = STATE(2493),
    [sym_continue_statement] = STATE(2493),
    [sym_do_statement] = STATE(2493),
    [sym_empty_statement] = STATE(2493),
    [sym_expression_statement] = STATE(2493),
    [sym_fixed_statement] = STATE(2493),
    [sym_for_statement] = STATE(2493),
    [sym_return_statement] = STATE(2493),
    [sym_lock_statement] = STATE(2493),
    [sym_yield_statement] = STATE(2493),
    [sym_switch_statement] = STATE(2493),
    [sym_throw_statement] = STATE(2493),
    [sym_try_statement] = STATE(2493),
    [sym_unsafe_statement] = STATE(2493),
    [sym_using_statement] = STATE(2493),
    [sym_foreach_statement] = STATE(2493),
    [sym_goto_statement] = STATE(2493),
    [sym_labeled_statement] = STATE(2493),
    [sym_if_statement] = STATE(2493),
    [sym_while_statement] = STATE(2493),
    [sym_local_declaration_statement] = STATE(2493),
    [sym_local_function_statement] = STATE(2493),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6748),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2907),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2493),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(160),
    [sym_preproc_endregion] = STATE(160),
    [sym_preproc_line] = STATE(160),
    [sym_preproc_pragma] = STATE(160),
    [sym_preproc_nullable] = STATE(160),
    [sym_preproc_error] = STATE(160),
    [sym_preproc_warning] = STATE(160),
    [sym_preproc_define] = STATE(160),
    [sym_preproc_undef] = STATE(160),
    [aux_sym_class_declaration_repeat1] = STATE(2936),
    [aux_sym_class_declaration_repeat2] = STATE(3108),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(31),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1005),
    [anon_sym_unsafe] = ACTIONS(1007),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(45),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1009),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(73),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_unchecked] = ACTIONS(73),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_do] = ACTIONS(97),
    [anon_sym_while] = ACTIONS(99),
    [anon_sym_for] = ACTIONS(101),
    [anon_sym_lock] = ACTIONS(103),
    [anon_sym_yield] = ACTIONS(105),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(111),
    [anon_sym_try] = ACTIONS(113),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(115),
    [anon_sym_foreach] = ACTIONS(117),
    [anon_sym_goto] = ACTIONS(119),
    [anon_sym_if] = ACTIONS(121),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(147),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [161] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2493),
    [sym_variable_declaration] = STATE(9635),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6854),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2507),
    [sym_break_statement] = STATE(2493),
    [sym_checked_statement] = STATE(2493),
    [sym_continue_statement] = STATE(2493),
    [sym_do_statement] = STATE(2493),
    [sym_empty_statement] = STATE(2493),
    [sym_expression_statement] = STATE(2493),
    [sym_fixed_statement] = STATE(2493),
    [sym_for_statement] = STATE(2493),
    [sym_return_statement] = STATE(2493),
    [sym_lock_statement] = STATE(2493),
    [sym_yield_statement] = STATE(2493),
    [sym_switch_statement] = STATE(2493),
    [sym_throw_statement] = STATE(2493),
    [sym_try_statement] = STATE(2493),
    [sym_unsafe_statement] = STATE(2493),
    [sym_using_statement] = STATE(2493),
    [sym_foreach_statement] = STATE(2493),
    [sym_goto_statement] = STATE(2493),
    [sym_labeled_statement] = STATE(2493),
    [sym_if_statement] = STATE(2493),
    [sym_while_statement] = STATE(2493),
    [sym_local_declaration_statement] = STATE(2493),
    [sym_local_function_statement] = STATE(2493),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6748),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2907),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2493),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(161),
    [sym_preproc_endregion] = STATE(161),
    [sym_preproc_line] = STATE(161),
    [sym_preproc_pragma] = STATE(161),
    [sym_preproc_nullable] = STATE(161),
    [sym_preproc_error] = STATE(161),
    [sym_preproc_warning] = STATE(161),
    [sym_preproc_define] = STATE(161),
    [sym_preproc_undef] = STATE(161),
    [aux_sym_class_declaration_repeat1] = STATE(2936),
    [aux_sym_class_declaration_repeat2] = STATE(3108),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(31),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1005),
    [anon_sym_unsafe] = ACTIONS(1007),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(45),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1009),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(73),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_unchecked] = ACTIONS(73),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_do] = ACTIONS(97),
    [anon_sym_while] = ACTIONS(99),
    [anon_sym_for] = ACTIONS(101),
    [anon_sym_lock] = ACTIONS(103),
    [anon_sym_yield] = ACTIONS(105),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(111),
    [anon_sym_try] = ACTIONS(113),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(115),
    [anon_sym_foreach] = ACTIONS(117),
    [anon_sym_goto] = ACTIONS(119),
    [anon_sym_if] = ACTIONS(121),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(147),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [162] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2493),
    [sym_variable_declaration] = STATE(9635),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6854),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2509),
    [sym_break_statement] = STATE(2493),
    [sym_checked_statement] = STATE(2493),
    [sym_continue_statement] = STATE(2493),
    [sym_do_statement] = STATE(2493),
    [sym_empty_statement] = STATE(2493),
    [sym_expression_statement] = STATE(2493),
    [sym_fixed_statement] = STATE(2493),
    [sym_for_statement] = STATE(2493),
    [sym_return_statement] = STATE(2493),
    [sym_lock_statement] = STATE(2493),
    [sym_yield_statement] = STATE(2493),
    [sym_switch_statement] = STATE(2493),
    [sym_throw_statement] = STATE(2493),
    [sym_try_statement] = STATE(2493),
    [sym_unsafe_statement] = STATE(2493),
    [sym_using_statement] = STATE(2493),
    [sym_foreach_statement] = STATE(2493),
    [sym_goto_statement] = STATE(2493),
    [sym_labeled_statement] = STATE(2493),
    [sym_if_statement] = STATE(2493),
    [sym_while_statement] = STATE(2493),
    [sym_local_declaration_statement] = STATE(2493),
    [sym_local_function_statement] = STATE(2493),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6748),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2907),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2493),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(162),
    [sym_preproc_endregion] = STATE(162),
    [sym_preproc_line] = STATE(162),
    [sym_preproc_pragma] = STATE(162),
    [sym_preproc_nullable] = STATE(162),
    [sym_preproc_error] = STATE(162),
    [sym_preproc_warning] = STATE(162),
    [sym_preproc_define] = STATE(162),
    [sym_preproc_undef] = STATE(162),
    [aux_sym_class_declaration_repeat1] = STATE(2936),
    [aux_sym_class_declaration_repeat2] = STATE(3108),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(31),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1005),
    [anon_sym_unsafe] = ACTIONS(1007),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(45),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1009),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(73),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_unchecked] = ACTIONS(73),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_do] = ACTIONS(97),
    [anon_sym_while] = ACTIONS(99),
    [anon_sym_for] = ACTIONS(101),
    [anon_sym_lock] = ACTIONS(103),
    [anon_sym_yield] = ACTIONS(105),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(111),
    [anon_sym_try] = ACTIONS(113),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(115),
    [anon_sym_foreach] = ACTIONS(117),
    [anon_sym_goto] = ACTIONS(119),
    [anon_sym_if] = ACTIONS(121),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(147),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [163] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2493),
    [sym_variable_declaration] = STATE(9635),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6854),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2468),
    [sym_break_statement] = STATE(2493),
    [sym_checked_statement] = STATE(2493),
    [sym_continue_statement] = STATE(2493),
    [sym_do_statement] = STATE(2493),
    [sym_empty_statement] = STATE(2493),
    [sym_expression_statement] = STATE(2493),
    [sym_fixed_statement] = STATE(2493),
    [sym_for_statement] = STATE(2493),
    [sym_return_statement] = STATE(2493),
    [sym_lock_statement] = STATE(2493),
    [sym_yield_statement] = STATE(2493),
    [sym_switch_statement] = STATE(2493),
    [sym_throw_statement] = STATE(2493),
    [sym_try_statement] = STATE(2493),
    [sym_unsafe_statement] = STATE(2493),
    [sym_using_statement] = STATE(2493),
    [sym_foreach_statement] = STATE(2493),
    [sym_goto_statement] = STATE(2493),
    [sym_labeled_statement] = STATE(2493),
    [sym_if_statement] = STATE(2493),
    [sym_while_statement] = STATE(2493),
    [sym_local_declaration_statement] = STATE(2493),
    [sym_local_function_statement] = STATE(2493),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6748),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2907),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2493),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(163),
    [sym_preproc_endregion] = STATE(163),
    [sym_preproc_line] = STATE(163),
    [sym_preproc_pragma] = STATE(163),
    [sym_preproc_nullable] = STATE(163),
    [sym_preproc_error] = STATE(163),
    [sym_preproc_warning] = STATE(163),
    [sym_preproc_define] = STATE(163),
    [sym_preproc_undef] = STATE(163),
    [aux_sym_class_declaration_repeat1] = STATE(2936),
    [aux_sym_class_declaration_repeat2] = STATE(3108),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(31),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1005),
    [anon_sym_unsafe] = ACTIONS(1007),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(45),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1009),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(73),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_unchecked] = ACTIONS(73),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_do] = ACTIONS(97),
    [anon_sym_while] = ACTIONS(99),
    [anon_sym_for] = ACTIONS(101),
    [anon_sym_lock] = ACTIONS(103),
    [anon_sym_yield] = ACTIONS(105),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(111),
    [anon_sym_try] = ACTIONS(113),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(115),
    [anon_sym_foreach] = ACTIONS(117),
    [anon_sym_goto] = ACTIONS(119),
    [anon_sym_if] = ACTIONS(121),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(147),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [164] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2493),
    [sym_variable_declaration] = STATE(9635),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6854),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2508),
    [sym_break_statement] = STATE(2493),
    [sym_checked_statement] = STATE(2493),
    [sym_continue_statement] = STATE(2493),
    [sym_do_statement] = STATE(2493),
    [sym_empty_statement] = STATE(2493),
    [sym_expression_statement] = STATE(2493),
    [sym_fixed_statement] = STATE(2493),
    [sym_for_statement] = STATE(2493),
    [sym_return_statement] = STATE(2493),
    [sym_lock_statement] = STATE(2493),
    [sym_yield_statement] = STATE(2493),
    [sym_switch_statement] = STATE(2493),
    [sym_throw_statement] = STATE(2493),
    [sym_try_statement] = STATE(2493),
    [sym_unsafe_statement] = STATE(2493),
    [sym_using_statement] = STATE(2493),
    [sym_foreach_statement] = STATE(2493),
    [sym_goto_statement] = STATE(2493),
    [sym_labeled_statement] = STATE(2493),
    [sym_if_statement] = STATE(2493),
    [sym_while_statement] = STATE(2493),
    [sym_local_declaration_statement] = STATE(2493),
    [sym_local_function_statement] = STATE(2493),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6748),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2907),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2493),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(164),
    [sym_preproc_endregion] = STATE(164),
    [sym_preproc_line] = STATE(164),
    [sym_preproc_pragma] = STATE(164),
    [sym_preproc_nullable] = STATE(164),
    [sym_preproc_error] = STATE(164),
    [sym_preproc_warning] = STATE(164),
    [sym_preproc_define] = STATE(164),
    [sym_preproc_undef] = STATE(164),
    [aux_sym_class_declaration_repeat1] = STATE(2936),
    [aux_sym_class_declaration_repeat2] = STATE(3108),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(31),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1005),
    [anon_sym_unsafe] = ACTIONS(1007),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(45),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1009),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(73),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_unchecked] = ACTIONS(73),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_do] = ACTIONS(97),
    [anon_sym_while] = ACTIONS(99),
    [anon_sym_for] = ACTIONS(101),
    [anon_sym_lock] = ACTIONS(103),
    [anon_sym_yield] = ACTIONS(105),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(111),
    [anon_sym_try] = ACTIONS(113),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(115),
    [anon_sym_foreach] = ACTIONS(117),
    [anon_sym_goto] = ACTIONS(119),
    [anon_sym_if] = ACTIONS(121),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(147),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [165] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2493),
    [sym_variable_declaration] = STATE(9635),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6854),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2512),
    [sym_break_statement] = STATE(2493),
    [sym_checked_statement] = STATE(2493),
    [sym_continue_statement] = STATE(2493),
    [sym_do_statement] = STATE(2493),
    [sym_empty_statement] = STATE(2493),
    [sym_expression_statement] = STATE(2493),
    [sym_fixed_statement] = STATE(2493),
    [sym_for_statement] = STATE(2493),
    [sym_return_statement] = STATE(2493),
    [sym_lock_statement] = STATE(2493),
    [sym_yield_statement] = STATE(2493),
    [sym_switch_statement] = STATE(2493),
    [sym_throw_statement] = STATE(2493),
    [sym_try_statement] = STATE(2493),
    [sym_unsafe_statement] = STATE(2493),
    [sym_using_statement] = STATE(2493),
    [sym_foreach_statement] = STATE(2493),
    [sym_goto_statement] = STATE(2493),
    [sym_labeled_statement] = STATE(2493),
    [sym_if_statement] = STATE(2493),
    [sym_while_statement] = STATE(2493),
    [sym_local_declaration_statement] = STATE(2493),
    [sym_local_function_statement] = STATE(2493),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6748),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2907),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2493),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(165),
    [sym_preproc_endregion] = STATE(165),
    [sym_preproc_line] = STATE(165),
    [sym_preproc_pragma] = STATE(165),
    [sym_preproc_nullable] = STATE(165),
    [sym_preproc_error] = STATE(165),
    [sym_preproc_warning] = STATE(165),
    [sym_preproc_define] = STATE(165),
    [sym_preproc_undef] = STATE(165),
    [aux_sym_class_declaration_repeat1] = STATE(2936),
    [aux_sym_class_declaration_repeat2] = STATE(3108),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(31),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1005),
    [anon_sym_unsafe] = ACTIONS(1007),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(45),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1009),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(73),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_unchecked] = ACTIONS(73),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_do] = ACTIONS(97),
    [anon_sym_while] = ACTIONS(99),
    [anon_sym_for] = ACTIONS(101),
    [anon_sym_lock] = ACTIONS(103),
    [anon_sym_yield] = ACTIONS(105),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(111),
    [anon_sym_try] = ACTIONS(113),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(115),
    [anon_sym_foreach] = ACTIONS(117),
    [anon_sym_goto] = ACTIONS(119),
    [anon_sym_if] = ACTIONS(121),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(147),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [166] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2493),
    [sym_variable_declaration] = STATE(9635),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6854),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2491),
    [sym_break_statement] = STATE(2493),
    [sym_checked_statement] = STATE(2493),
    [sym_continue_statement] = STATE(2493),
    [sym_do_statement] = STATE(2493),
    [sym_empty_statement] = STATE(2493),
    [sym_expression_statement] = STATE(2493),
    [sym_fixed_statement] = STATE(2493),
    [sym_for_statement] = STATE(2493),
    [sym_return_statement] = STATE(2493),
    [sym_lock_statement] = STATE(2493),
    [sym_yield_statement] = STATE(2493),
    [sym_switch_statement] = STATE(2493),
    [sym_throw_statement] = STATE(2493),
    [sym_try_statement] = STATE(2493),
    [sym_unsafe_statement] = STATE(2493),
    [sym_using_statement] = STATE(2493),
    [sym_foreach_statement] = STATE(2493),
    [sym_goto_statement] = STATE(2493),
    [sym_labeled_statement] = STATE(2493),
    [sym_if_statement] = STATE(2493),
    [sym_while_statement] = STATE(2493),
    [sym_local_declaration_statement] = STATE(2493),
    [sym_local_function_statement] = STATE(2493),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6748),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2907),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2493),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(166),
    [sym_preproc_endregion] = STATE(166),
    [sym_preproc_line] = STATE(166),
    [sym_preproc_pragma] = STATE(166),
    [sym_preproc_nullable] = STATE(166),
    [sym_preproc_error] = STATE(166),
    [sym_preproc_warning] = STATE(166),
    [sym_preproc_define] = STATE(166),
    [sym_preproc_undef] = STATE(166),
    [aux_sym_class_declaration_repeat1] = STATE(2936),
    [aux_sym_class_declaration_repeat2] = STATE(3108),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(31),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1005),
    [anon_sym_unsafe] = ACTIONS(1007),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(45),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1009),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(73),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_unchecked] = ACTIONS(73),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_do] = ACTIONS(97),
    [anon_sym_while] = ACTIONS(99),
    [anon_sym_for] = ACTIONS(101),
    [anon_sym_lock] = ACTIONS(103),
    [anon_sym_yield] = ACTIONS(105),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(111),
    [anon_sym_try] = ACTIONS(113),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(115),
    [anon_sym_foreach] = ACTIONS(117),
    [anon_sym_goto] = ACTIONS(119),
    [anon_sym_if] = ACTIONS(121),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(147),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [167] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2493),
    [sym_variable_declaration] = STATE(9635),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6854),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2494),
    [sym_break_statement] = STATE(2493),
    [sym_checked_statement] = STATE(2493),
    [sym_continue_statement] = STATE(2493),
    [sym_do_statement] = STATE(2493),
    [sym_empty_statement] = STATE(2493),
    [sym_expression_statement] = STATE(2493),
    [sym_fixed_statement] = STATE(2493),
    [sym_for_statement] = STATE(2493),
    [sym_return_statement] = STATE(2493),
    [sym_lock_statement] = STATE(2493),
    [sym_yield_statement] = STATE(2493),
    [sym_switch_statement] = STATE(2493),
    [sym_throw_statement] = STATE(2493),
    [sym_try_statement] = STATE(2493),
    [sym_unsafe_statement] = STATE(2493),
    [sym_using_statement] = STATE(2493),
    [sym_foreach_statement] = STATE(2493),
    [sym_goto_statement] = STATE(2493),
    [sym_labeled_statement] = STATE(2493),
    [sym_if_statement] = STATE(2493),
    [sym_while_statement] = STATE(2493),
    [sym_local_declaration_statement] = STATE(2493),
    [sym_local_function_statement] = STATE(2493),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6748),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2907),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2493),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(167),
    [sym_preproc_endregion] = STATE(167),
    [sym_preproc_line] = STATE(167),
    [sym_preproc_pragma] = STATE(167),
    [sym_preproc_nullable] = STATE(167),
    [sym_preproc_error] = STATE(167),
    [sym_preproc_warning] = STATE(167),
    [sym_preproc_define] = STATE(167),
    [sym_preproc_undef] = STATE(167),
    [aux_sym_class_declaration_repeat1] = STATE(2936),
    [aux_sym_class_declaration_repeat2] = STATE(3108),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(31),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1005),
    [anon_sym_unsafe] = ACTIONS(1007),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(45),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1009),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(73),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_unchecked] = ACTIONS(73),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_do] = ACTIONS(97),
    [anon_sym_while] = ACTIONS(99),
    [anon_sym_for] = ACTIONS(101),
    [anon_sym_lock] = ACTIONS(103),
    [anon_sym_yield] = ACTIONS(105),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(111),
    [anon_sym_try] = ACTIONS(113),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(115),
    [anon_sym_foreach] = ACTIONS(117),
    [anon_sym_goto] = ACTIONS(119),
    [anon_sym_if] = ACTIONS(121),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(147),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [168] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2493),
    [sym_variable_declaration] = STATE(9635),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6854),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2475),
    [sym_break_statement] = STATE(2493),
    [sym_checked_statement] = STATE(2493),
    [sym_continue_statement] = STATE(2493),
    [sym_do_statement] = STATE(2493),
    [sym_empty_statement] = STATE(2493),
    [sym_expression_statement] = STATE(2493),
    [sym_fixed_statement] = STATE(2493),
    [sym_for_statement] = STATE(2493),
    [sym_return_statement] = STATE(2493),
    [sym_lock_statement] = STATE(2493),
    [sym_yield_statement] = STATE(2493),
    [sym_switch_statement] = STATE(2493),
    [sym_throw_statement] = STATE(2493),
    [sym_try_statement] = STATE(2493),
    [sym_unsafe_statement] = STATE(2493),
    [sym_using_statement] = STATE(2493),
    [sym_foreach_statement] = STATE(2493),
    [sym_goto_statement] = STATE(2493),
    [sym_labeled_statement] = STATE(2493),
    [sym_if_statement] = STATE(2493),
    [sym_while_statement] = STATE(2493),
    [sym_local_declaration_statement] = STATE(2493),
    [sym_local_function_statement] = STATE(2493),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6748),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2907),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2493),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(168),
    [sym_preproc_endregion] = STATE(168),
    [sym_preproc_line] = STATE(168),
    [sym_preproc_pragma] = STATE(168),
    [sym_preproc_nullable] = STATE(168),
    [sym_preproc_error] = STATE(168),
    [sym_preproc_warning] = STATE(168),
    [sym_preproc_define] = STATE(168),
    [sym_preproc_undef] = STATE(168),
    [aux_sym_class_declaration_repeat1] = STATE(2936),
    [aux_sym_class_declaration_repeat2] = STATE(3108),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(31),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1005),
    [anon_sym_unsafe] = ACTIONS(1007),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(45),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1009),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(73),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_unchecked] = ACTIONS(73),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_do] = ACTIONS(97),
    [anon_sym_while] = ACTIONS(99),
    [anon_sym_for] = ACTIONS(101),
    [anon_sym_lock] = ACTIONS(103),
    [anon_sym_yield] = ACTIONS(105),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(111),
    [anon_sym_try] = ACTIONS(113),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(115),
    [anon_sym_foreach] = ACTIONS(117),
    [anon_sym_goto] = ACTIONS(119),
    [anon_sym_if] = ACTIONS(121),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(147),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [169] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2493),
    [sym_variable_declaration] = STATE(9635),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6854),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2484),
    [sym_break_statement] = STATE(2493),
    [sym_checked_statement] = STATE(2493),
    [sym_continue_statement] = STATE(2493),
    [sym_do_statement] = STATE(2493),
    [sym_empty_statement] = STATE(2493),
    [sym_expression_statement] = STATE(2493),
    [sym_fixed_statement] = STATE(2493),
    [sym_for_statement] = STATE(2493),
    [sym_return_statement] = STATE(2493),
    [sym_lock_statement] = STATE(2493),
    [sym_yield_statement] = STATE(2493),
    [sym_switch_statement] = STATE(2493),
    [sym_throw_statement] = STATE(2493),
    [sym_try_statement] = STATE(2493),
    [sym_unsafe_statement] = STATE(2493),
    [sym_using_statement] = STATE(2493),
    [sym_foreach_statement] = STATE(2493),
    [sym_goto_statement] = STATE(2493),
    [sym_labeled_statement] = STATE(2493),
    [sym_if_statement] = STATE(2493),
    [sym_while_statement] = STATE(2493),
    [sym_local_declaration_statement] = STATE(2493),
    [sym_local_function_statement] = STATE(2493),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6748),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2907),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2493),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(169),
    [sym_preproc_endregion] = STATE(169),
    [sym_preproc_line] = STATE(169),
    [sym_preproc_pragma] = STATE(169),
    [sym_preproc_nullable] = STATE(169),
    [sym_preproc_error] = STATE(169),
    [sym_preproc_warning] = STATE(169),
    [sym_preproc_define] = STATE(169),
    [sym_preproc_undef] = STATE(169),
    [aux_sym_class_declaration_repeat1] = STATE(2936),
    [aux_sym_class_declaration_repeat2] = STATE(3108),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(31),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1005),
    [anon_sym_unsafe] = ACTIONS(1007),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(45),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1009),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(73),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_unchecked] = ACTIONS(73),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_do] = ACTIONS(97),
    [anon_sym_while] = ACTIONS(99),
    [anon_sym_for] = ACTIONS(101),
    [anon_sym_lock] = ACTIONS(103),
    [anon_sym_yield] = ACTIONS(105),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(111),
    [anon_sym_try] = ACTIONS(113),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(115),
    [anon_sym_foreach] = ACTIONS(117),
    [anon_sym_goto] = ACTIONS(119),
    [anon_sym_if] = ACTIONS(121),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(147),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [170] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2493),
    [sym_variable_declaration] = STATE(9635),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6854),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2452),
    [sym_break_statement] = STATE(2493),
    [sym_checked_statement] = STATE(2493),
    [sym_continue_statement] = STATE(2493),
    [sym_do_statement] = STATE(2493),
    [sym_empty_statement] = STATE(2493),
    [sym_expression_statement] = STATE(2493),
    [sym_fixed_statement] = STATE(2493),
    [sym_for_statement] = STATE(2493),
    [sym_return_statement] = STATE(2493),
    [sym_lock_statement] = STATE(2493),
    [sym_yield_statement] = STATE(2493),
    [sym_switch_statement] = STATE(2493),
    [sym_throw_statement] = STATE(2493),
    [sym_try_statement] = STATE(2493),
    [sym_unsafe_statement] = STATE(2493),
    [sym_using_statement] = STATE(2493),
    [sym_foreach_statement] = STATE(2493),
    [sym_goto_statement] = STATE(2493),
    [sym_labeled_statement] = STATE(2493),
    [sym_if_statement] = STATE(2493),
    [sym_while_statement] = STATE(2493),
    [sym_local_declaration_statement] = STATE(2493),
    [sym_local_function_statement] = STATE(2493),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6748),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2907),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2493),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(170),
    [sym_preproc_endregion] = STATE(170),
    [sym_preproc_line] = STATE(170),
    [sym_preproc_pragma] = STATE(170),
    [sym_preproc_nullable] = STATE(170),
    [sym_preproc_error] = STATE(170),
    [sym_preproc_warning] = STATE(170),
    [sym_preproc_define] = STATE(170),
    [sym_preproc_undef] = STATE(170),
    [aux_sym_class_declaration_repeat1] = STATE(2936),
    [aux_sym_class_declaration_repeat2] = STATE(3108),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(31),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1005),
    [anon_sym_unsafe] = ACTIONS(1007),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(45),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1009),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(73),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_unchecked] = ACTIONS(73),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_do] = ACTIONS(97),
    [anon_sym_while] = ACTIONS(99),
    [anon_sym_for] = ACTIONS(101),
    [anon_sym_lock] = ACTIONS(103),
    [anon_sym_yield] = ACTIONS(105),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(111),
    [anon_sym_try] = ACTIONS(113),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(115),
    [anon_sym_foreach] = ACTIONS(117),
    [anon_sym_goto] = ACTIONS(119),
    [anon_sym_if] = ACTIONS(121),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(147),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [171] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2493),
    [sym_variable_declaration] = STATE(9635),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6854),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2438),
    [sym_break_statement] = STATE(2493),
    [sym_checked_statement] = STATE(2493),
    [sym_continue_statement] = STATE(2493),
    [sym_do_statement] = STATE(2493),
    [sym_empty_statement] = STATE(2493),
    [sym_expression_statement] = STATE(2493),
    [sym_fixed_statement] = STATE(2493),
    [sym_for_statement] = STATE(2493),
    [sym_return_statement] = STATE(2493),
    [sym_lock_statement] = STATE(2493),
    [sym_yield_statement] = STATE(2493),
    [sym_switch_statement] = STATE(2493),
    [sym_throw_statement] = STATE(2493),
    [sym_try_statement] = STATE(2493),
    [sym_unsafe_statement] = STATE(2493),
    [sym_using_statement] = STATE(2493),
    [sym_foreach_statement] = STATE(2493),
    [sym_goto_statement] = STATE(2493),
    [sym_labeled_statement] = STATE(2493),
    [sym_if_statement] = STATE(2493),
    [sym_while_statement] = STATE(2493),
    [sym_local_declaration_statement] = STATE(2493),
    [sym_local_function_statement] = STATE(2493),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6748),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2907),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2493),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(171),
    [sym_preproc_endregion] = STATE(171),
    [sym_preproc_line] = STATE(171),
    [sym_preproc_pragma] = STATE(171),
    [sym_preproc_nullable] = STATE(171),
    [sym_preproc_error] = STATE(171),
    [sym_preproc_warning] = STATE(171),
    [sym_preproc_define] = STATE(171),
    [sym_preproc_undef] = STATE(171),
    [aux_sym_class_declaration_repeat1] = STATE(2936),
    [aux_sym_class_declaration_repeat2] = STATE(3108),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(31),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1005),
    [anon_sym_unsafe] = ACTIONS(1007),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(45),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1009),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(73),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_unchecked] = ACTIONS(73),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_do] = ACTIONS(97),
    [anon_sym_while] = ACTIONS(99),
    [anon_sym_for] = ACTIONS(101),
    [anon_sym_lock] = ACTIONS(103),
    [anon_sym_yield] = ACTIONS(105),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(111),
    [anon_sym_try] = ACTIONS(113),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(115),
    [anon_sym_foreach] = ACTIONS(117),
    [anon_sym_goto] = ACTIONS(119),
    [anon_sym_if] = ACTIONS(121),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(147),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [172] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2493),
    [sym_variable_declaration] = STATE(9635),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6854),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2445),
    [sym_break_statement] = STATE(2493),
    [sym_checked_statement] = STATE(2493),
    [sym_continue_statement] = STATE(2493),
    [sym_do_statement] = STATE(2493),
    [sym_empty_statement] = STATE(2493),
    [sym_expression_statement] = STATE(2493),
    [sym_fixed_statement] = STATE(2493),
    [sym_for_statement] = STATE(2493),
    [sym_return_statement] = STATE(2493),
    [sym_lock_statement] = STATE(2493),
    [sym_yield_statement] = STATE(2493),
    [sym_switch_statement] = STATE(2493),
    [sym_throw_statement] = STATE(2493),
    [sym_try_statement] = STATE(2493),
    [sym_unsafe_statement] = STATE(2493),
    [sym_using_statement] = STATE(2493),
    [sym_foreach_statement] = STATE(2493),
    [sym_goto_statement] = STATE(2493),
    [sym_labeled_statement] = STATE(2493),
    [sym_if_statement] = STATE(2493),
    [sym_while_statement] = STATE(2493),
    [sym_local_declaration_statement] = STATE(2493),
    [sym_local_function_statement] = STATE(2493),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6748),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2907),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2493),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(172),
    [sym_preproc_endregion] = STATE(172),
    [sym_preproc_line] = STATE(172),
    [sym_preproc_pragma] = STATE(172),
    [sym_preproc_nullable] = STATE(172),
    [sym_preproc_error] = STATE(172),
    [sym_preproc_warning] = STATE(172),
    [sym_preproc_define] = STATE(172),
    [sym_preproc_undef] = STATE(172),
    [aux_sym_class_declaration_repeat1] = STATE(2936),
    [aux_sym_class_declaration_repeat2] = STATE(3108),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(31),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1005),
    [anon_sym_unsafe] = ACTIONS(1007),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(45),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1009),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(73),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_unchecked] = ACTIONS(73),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_do] = ACTIONS(97),
    [anon_sym_while] = ACTIONS(99),
    [anon_sym_for] = ACTIONS(101),
    [anon_sym_lock] = ACTIONS(103),
    [anon_sym_yield] = ACTIONS(105),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(111),
    [anon_sym_try] = ACTIONS(113),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(115),
    [anon_sym_foreach] = ACTIONS(117),
    [anon_sym_goto] = ACTIONS(119),
    [anon_sym_if] = ACTIONS(121),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(147),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [173] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2493),
    [sym_variable_declaration] = STATE(9635),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6854),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2446),
    [sym_break_statement] = STATE(2493),
    [sym_checked_statement] = STATE(2493),
    [sym_continue_statement] = STATE(2493),
    [sym_do_statement] = STATE(2493),
    [sym_empty_statement] = STATE(2493),
    [sym_expression_statement] = STATE(2493),
    [sym_fixed_statement] = STATE(2493),
    [sym_for_statement] = STATE(2493),
    [sym_return_statement] = STATE(2493),
    [sym_lock_statement] = STATE(2493),
    [sym_yield_statement] = STATE(2493),
    [sym_switch_statement] = STATE(2493),
    [sym_throw_statement] = STATE(2493),
    [sym_try_statement] = STATE(2493),
    [sym_unsafe_statement] = STATE(2493),
    [sym_using_statement] = STATE(2493),
    [sym_foreach_statement] = STATE(2493),
    [sym_goto_statement] = STATE(2493),
    [sym_labeled_statement] = STATE(2493),
    [sym_if_statement] = STATE(2493),
    [sym_while_statement] = STATE(2493),
    [sym_local_declaration_statement] = STATE(2493),
    [sym_local_function_statement] = STATE(2493),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6748),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2907),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2493),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(173),
    [sym_preproc_endregion] = STATE(173),
    [sym_preproc_line] = STATE(173),
    [sym_preproc_pragma] = STATE(173),
    [sym_preproc_nullable] = STATE(173),
    [sym_preproc_error] = STATE(173),
    [sym_preproc_warning] = STATE(173),
    [sym_preproc_define] = STATE(173),
    [sym_preproc_undef] = STATE(173),
    [aux_sym_class_declaration_repeat1] = STATE(2936),
    [aux_sym_class_declaration_repeat2] = STATE(3108),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(31),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1005),
    [anon_sym_unsafe] = ACTIONS(1007),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(45),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1009),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(73),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_unchecked] = ACTIONS(73),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_do] = ACTIONS(97),
    [anon_sym_while] = ACTIONS(99),
    [anon_sym_for] = ACTIONS(101),
    [anon_sym_lock] = ACTIONS(103),
    [anon_sym_yield] = ACTIONS(105),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(111),
    [anon_sym_try] = ACTIONS(113),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(115),
    [anon_sym_foreach] = ACTIONS(117),
    [anon_sym_goto] = ACTIONS(119),
    [anon_sym_if] = ACTIONS(121),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(147),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [174] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2493),
    [sym_variable_declaration] = STATE(9635),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6854),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2447),
    [sym_break_statement] = STATE(2493),
    [sym_checked_statement] = STATE(2493),
    [sym_continue_statement] = STATE(2493),
    [sym_do_statement] = STATE(2493),
    [sym_empty_statement] = STATE(2493),
    [sym_expression_statement] = STATE(2493),
    [sym_fixed_statement] = STATE(2493),
    [sym_for_statement] = STATE(2493),
    [sym_return_statement] = STATE(2493),
    [sym_lock_statement] = STATE(2493),
    [sym_yield_statement] = STATE(2493),
    [sym_switch_statement] = STATE(2493),
    [sym_throw_statement] = STATE(2493),
    [sym_try_statement] = STATE(2493),
    [sym_unsafe_statement] = STATE(2493),
    [sym_using_statement] = STATE(2493),
    [sym_foreach_statement] = STATE(2493),
    [sym_goto_statement] = STATE(2493),
    [sym_labeled_statement] = STATE(2493),
    [sym_if_statement] = STATE(2493),
    [sym_while_statement] = STATE(2493),
    [sym_local_declaration_statement] = STATE(2493),
    [sym_local_function_statement] = STATE(2493),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6748),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2907),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2493),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(174),
    [sym_preproc_endregion] = STATE(174),
    [sym_preproc_line] = STATE(174),
    [sym_preproc_pragma] = STATE(174),
    [sym_preproc_nullable] = STATE(174),
    [sym_preproc_error] = STATE(174),
    [sym_preproc_warning] = STATE(174),
    [sym_preproc_define] = STATE(174),
    [sym_preproc_undef] = STATE(174),
    [aux_sym_class_declaration_repeat1] = STATE(2936),
    [aux_sym_class_declaration_repeat2] = STATE(3108),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(31),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1005),
    [anon_sym_unsafe] = ACTIONS(1007),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(45),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1009),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(73),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_unchecked] = ACTIONS(73),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_do] = ACTIONS(97),
    [anon_sym_while] = ACTIONS(99),
    [anon_sym_for] = ACTIONS(101),
    [anon_sym_lock] = ACTIONS(103),
    [anon_sym_yield] = ACTIONS(105),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(111),
    [anon_sym_try] = ACTIONS(113),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(115),
    [anon_sym_foreach] = ACTIONS(117),
    [anon_sym_goto] = ACTIONS(119),
    [anon_sym_if] = ACTIONS(121),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(147),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [175] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2493),
    [sym_variable_declaration] = STATE(9635),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6854),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2513),
    [sym_break_statement] = STATE(2493),
    [sym_checked_statement] = STATE(2493),
    [sym_continue_statement] = STATE(2493),
    [sym_do_statement] = STATE(2493),
    [sym_empty_statement] = STATE(2493),
    [sym_expression_statement] = STATE(2493),
    [sym_fixed_statement] = STATE(2493),
    [sym_for_statement] = STATE(2493),
    [sym_return_statement] = STATE(2493),
    [sym_lock_statement] = STATE(2493),
    [sym_yield_statement] = STATE(2493),
    [sym_switch_statement] = STATE(2493),
    [sym_throw_statement] = STATE(2493),
    [sym_try_statement] = STATE(2493),
    [sym_unsafe_statement] = STATE(2493),
    [sym_using_statement] = STATE(2493),
    [sym_foreach_statement] = STATE(2493),
    [sym_goto_statement] = STATE(2493),
    [sym_labeled_statement] = STATE(2493),
    [sym_if_statement] = STATE(2493),
    [sym_while_statement] = STATE(2493),
    [sym_local_declaration_statement] = STATE(2493),
    [sym_local_function_statement] = STATE(2493),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6748),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2907),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2493),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(175),
    [sym_preproc_endregion] = STATE(175),
    [sym_preproc_line] = STATE(175),
    [sym_preproc_pragma] = STATE(175),
    [sym_preproc_nullable] = STATE(175),
    [sym_preproc_error] = STATE(175),
    [sym_preproc_warning] = STATE(175),
    [sym_preproc_define] = STATE(175),
    [sym_preproc_undef] = STATE(175),
    [aux_sym_class_declaration_repeat1] = STATE(2936),
    [aux_sym_class_declaration_repeat2] = STATE(3108),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(31),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1005),
    [anon_sym_unsafe] = ACTIONS(1007),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(45),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(57),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1009),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(73),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_unchecked] = ACTIONS(73),
    [anon_sym_continue] = ACTIONS(95),
    [anon_sym_do] = ACTIONS(97),
    [anon_sym_while] = ACTIONS(99),
    [anon_sym_for] = ACTIONS(101),
    [anon_sym_lock] = ACTIONS(103),
    [anon_sym_yield] = ACTIONS(105),
    [anon_sym_switch] = ACTIONS(107),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(111),
    [anon_sym_try] = ACTIONS(113),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(115),
    [anon_sym_foreach] = ACTIONS(117),
    [anon_sym_goto] = ACTIONS(119),
    [anon_sym_if] = ACTIONS(121),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(147),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [176] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2659),
    [sym_variable_declaration] = STATE(9524),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6870),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2696),
    [sym_break_statement] = STATE(2659),
    [sym_checked_statement] = STATE(2659),
    [sym_continue_statement] = STATE(2659),
    [sym_do_statement] = STATE(2659),
    [sym_empty_statement] = STATE(2659),
    [sym_expression_statement] = STATE(2659),
    [sym_fixed_statement] = STATE(2659),
    [sym_for_statement] = STATE(2659),
    [sym_return_statement] = STATE(2659),
    [sym_lock_statement] = STATE(2659),
    [sym_yield_statement] = STATE(2659),
    [sym_switch_statement] = STATE(2659),
    [sym_throw_statement] = STATE(2659),
    [sym_try_statement] = STATE(2659),
    [sym_unsafe_statement] = STATE(2659),
    [sym_using_statement] = STATE(2659),
    [sym_foreach_statement] = STATE(2659),
    [sym_goto_statement] = STATE(2659),
    [sym_labeled_statement] = STATE(2659),
    [sym_if_statement] = STATE(2659),
    [sym_while_statement] = STATE(2659),
    [sym_local_declaration_statement] = STATE(2659),
    [sym_local_function_statement] = STATE(2659),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6347),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2847),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2659),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(176),
    [sym_preproc_endregion] = STATE(176),
    [sym_preproc_line] = STATE(176),
    [sym_preproc_pragma] = STATE(176),
    [sym_preproc_nullable] = STATE(176),
    [sym_preproc_error] = STATE(176),
    [sym_preproc_warning] = STATE(176),
    [sym_preproc_define] = STATE(176),
    [sym_preproc_undef] = STATE(176),
    [aux_sym_class_declaration_repeat1] = STATE(2935),
    [aux_sym_class_declaration_repeat2] = STATE(3094),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(663),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(665),
    [anon_sym_unsafe] = ACTIONS(667),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(677),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(689),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(693),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(701),
    [anon_sym_unchecked] = ACTIONS(693),
    [anon_sym_continue] = ACTIONS(703),
    [anon_sym_do] = ACTIONS(705),
    [anon_sym_while] = ACTIONS(707),
    [anon_sym_for] = ACTIONS(709),
    [anon_sym_lock] = ACTIONS(711),
    [anon_sym_yield] = ACTIONS(713),
    [anon_sym_switch] = ACTIONS(715),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(739),
    [anon_sym_try] = ACTIONS(719),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(741),
    [anon_sym_foreach] = ACTIONS(723),
    [anon_sym_goto] = ACTIONS(725),
    [anon_sym_if] = ACTIONS(727),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(731),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [177] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2659),
    [sym_variable_declaration] = STATE(9524),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6870),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2715),
    [sym_break_statement] = STATE(2659),
    [sym_checked_statement] = STATE(2659),
    [sym_continue_statement] = STATE(2659),
    [sym_do_statement] = STATE(2659),
    [sym_empty_statement] = STATE(2659),
    [sym_expression_statement] = STATE(2659),
    [sym_fixed_statement] = STATE(2659),
    [sym_for_statement] = STATE(2659),
    [sym_return_statement] = STATE(2659),
    [sym_lock_statement] = STATE(2659),
    [sym_yield_statement] = STATE(2659),
    [sym_switch_statement] = STATE(2659),
    [sym_throw_statement] = STATE(2659),
    [sym_try_statement] = STATE(2659),
    [sym_unsafe_statement] = STATE(2659),
    [sym_using_statement] = STATE(2659),
    [sym_foreach_statement] = STATE(2659),
    [sym_goto_statement] = STATE(2659),
    [sym_labeled_statement] = STATE(2659),
    [sym_if_statement] = STATE(2659),
    [sym_while_statement] = STATE(2659),
    [sym_local_declaration_statement] = STATE(2659),
    [sym_local_function_statement] = STATE(2659),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6347),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2847),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2659),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(177),
    [sym_preproc_endregion] = STATE(177),
    [sym_preproc_line] = STATE(177),
    [sym_preproc_pragma] = STATE(177),
    [sym_preproc_nullable] = STATE(177),
    [sym_preproc_error] = STATE(177),
    [sym_preproc_warning] = STATE(177),
    [sym_preproc_define] = STATE(177),
    [sym_preproc_undef] = STATE(177),
    [aux_sym_class_declaration_repeat1] = STATE(2935),
    [aux_sym_class_declaration_repeat2] = STATE(3094),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(663),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(665),
    [anon_sym_unsafe] = ACTIONS(667),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(677),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(689),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(693),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(701),
    [anon_sym_unchecked] = ACTIONS(693),
    [anon_sym_continue] = ACTIONS(703),
    [anon_sym_do] = ACTIONS(705),
    [anon_sym_while] = ACTIONS(707),
    [anon_sym_for] = ACTIONS(709),
    [anon_sym_lock] = ACTIONS(711),
    [anon_sym_yield] = ACTIONS(713),
    [anon_sym_switch] = ACTIONS(715),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(739),
    [anon_sym_try] = ACTIONS(719),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(741),
    [anon_sym_foreach] = ACTIONS(723),
    [anon_sym_goto] = ACTIONS(725),
    [anon_sym_if] = ACTIONS(727),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(731),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [178] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2659),
    [sym_variable_declaration] = STATE(9524),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6870),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2718),
    [sym_break_statement] = STATE(2659),
    [sym_checked_statement] = STATE(2659),
    [sym_continue_statement] = STATE(2659),
    [sym_do_statement] = STATE(2659),
    [sym_empty_statement] = STATE(2659),
    [sym_expression_statement] = STATE(2659),
    [sym_fixed_statement] = STATE(2659),
    [sym_for_statement] = STATE(2659),
    [sym_return_statement] = STATE(2659),
    [sym_lock_statement] = STATE(2659),
    [sym_yield_statement] = STATE(2659),
    [sym_switch_statement] = STATE(2659),
    [sym_throw_statement] = STATE(2659),
    [sym_try_statement] = STATE(2659),
    [sym_unsafe_statement] = STATE(2659),
    [sym_using_statement] = STATE(2659),
    [sym_foreach_statement] = STATE(2659),
    [sym_goto_statement] = STATE(2659),
    [sym_labeled_statement] = STATE(2659),
    [sym_if_statement] = STATE(2659),
    [sym_while_statement] = STATE(2659),
    [sym_local_declaration_statement] = STATE(2659),
    [sym_local_function_statement] = STATE(2659),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6347),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2847),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2659),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(178),
    [sym_preproc_endregion] = STATE(178),
    [sym_preproc_line] = STATE(178),
    [sym_preproc_pragma] = STATE(178),
    [sym_preproc_nullable] = STATE(178),
    [sym_preproc_error] = STATE(178),
    [sym_preproc_warning] = STATE(178),
    [sym_preproc_define] = STATE(178),
    [sym_preproc_undef] = STATE(178),
    [aux_sym_class_declaration_repeat1] = STATE(2935),
    [aux_sym_class_declaration_repeat2] = STATE(3094),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(663),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(665),
    [anon_sym_unsafe] = ACTIONS(667),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(677),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(689),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(693),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(701),
    [anon_sym_unchecked] = ACTIONS(693),
    [anon_sym_continue] = ACTIONS(703),
    [anon_sym_do] = ACTIONS(705),
    [anon_sym_while] = ACTIONS(707),
    [anon_sym_for] = ACTIONS(709),
    [anon_sym_lock] = ACTIONS(711),
    [anon_sym_yield] = ACTIONS(713),
    [anon_sym_switch] = ACTIONS(715),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(739),
    [anon_sym_try] = ACTIONS(719),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(741),
    [anon_sym_foreach] = ACTIONS(723),
    [anon_sym_goto] = ACTIONS(725),
    [anon_sym_if] = ACTIONS(727),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(731),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [179] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2659),
    [sym_variable_declaration] = STATE(9524),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6870),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2719),
    [sym_break_statement] = STATE(2659),
    [sym_checked_statement] = STATE(2659),
    [sym_continue_statement] = STATE(2659),
    [sym_do_statement] = STATE(2659),
    [sym_empty_statement] = STATE(2659),
    [sym_expression_statement] = STATE(2659),
    [sym_fixed_statement] = STATE(2659),
    [sym_for_statement] = STATE(2659),
    [sym_return_statement] = STATE(2659),
    [sym_lock_statement] = STATE(2659),
    [sym_yield_statement] = STATE(2659),
    [sym_switch_statement] = STATE(2659),
    [sym_throw_statement] = STATE(2659),
    [sym_try_statement] = STATE(2659),
    [sym_unsafe_statement] = STATE(2659),
    [sym_using_statement] = STATE(2659),
    [sym_foreach_statement] = STATE(2659),
    [sym_goto_statement] = STATE(2659),
    [sym_labeled_statement] = STATE(2659),
    [sym_if_statement] = STATE(2659),
    [sym_while_statement] = STATE(2659),
    [sym_local_declaration_statement] = STATE(2659),
    [sym_local_function_statement] = STATE(2659),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6347),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2847),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2659),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(179),
    [sym_preproc_endregion] = STATE(179),
    [sym_preproc_line] = STATE(179),
    [sym_preproc_pragma] = STATE(179),
    [sym_preproc_nullable] = STATE(179),
    [sym_preproc_error] = STATE(179),
    [sym_preproc_warning] = STATE(179),
    [sym_preproc_define] = STATE(179),
    [sym_preproc_undef] = STATE(179),
    [aux_sym_class_declaration_repeat1] = STATE(2935),
    [aux_sym_class_declaration_repeat2] = STATE(3094),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(663),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(665),
    [anon_sym_unsafe] = ACTIONS(667),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(677),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(689),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(693),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(701),
    [anon_sym_unchecked] = ACTIONS(693),
    [anon_sym_continue] = ACTIONS(703),
    [anon_sym_do] = ACTIONS(705),
    [anon_sym_while] = ACTIONS(707),
    [anon_sym_for] = ACTIONS(709),
    [anon_sym_lock] = ACTIONS(711),
    [anon_sym_yield] = ACTIONS(713),
    [anon_sym_switch] = ACTIONS(715),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(739),
    [anon_sym_try] = ACTIONS(719),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(741),
    [anon_sym_foreach] = ACTIONS(723),
    [anon_sym_goto] = ACTIONS(725),
    [anon_sym_if] = ACTIONS(727),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(731),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [180] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(8858),
    [sym_variable_declaration] = STATE(9360),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6862),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(9977),
    [sym_break_statement] = STATE(8858),
    [sym_checked_statement] = STATE(8858),
    [sym_continue_statement] = STATE(8858),
    [sym_do_statement] = STATE(8858),
    [sym_empty_statement] = STATE(8858),
    [sym_expression_statement] = STATE(8858),
    [sym_fixed_statement] = STATE(8858),
    [sym_for_statement] = STATE(8858),
    [sym_return_statement] = STATE(8858),
    [sym_lock_statement] = STATE(8858),
    [sym_yield_statement] = STATE(8858),
    [sym_switch_statement] = STATE(8858),
    [sym_throw_statement] = STATE(8858),
    [sym_try_statement] = STATE(8858),
    [sym_unsafe_statement] = STATE(8858),
    [sym_using_statement] = STATE(8858),
    [sym_foreach_statement] = STATE(8858),
    [sym_goto_statement] = STATE(8858),
    [sym_labeled_statement] = STATE(8858),
    [sym_if_statement] = STATE(8858),
    [sym_while_statement] = STATE(8858),
    [sym_local_declaration_statement] = STATE(8858),
    [sym_local_function_statement] = STATE(8858),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6755),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2904),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(8858),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(180),
    [sym_preproc_endregion] = STATE(180),
    [sym_preproc_line] = STATE(180),
    [sym_preproc_pragma] = STATE(180),
    [sym_preproc_nullable] = STATE(180),
    [sym_preproc_error] = STATE(180),
    [sym_preproc_warning] = STATE(180),
    [sym_preproc_define] = STATE(180),
    [sym_preproc_undef] = STATE(180),
    [aux_sym_class_declaration_repeat1] = STATE(2931),
    [aux_sym_class_declaration_repeat2] = STATE(3115),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(1011),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1013),
    [anon_sym_unsafe] = ACTIONS(1015),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(1017),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1019),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1021),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1023),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(1025),
    [anon_sym_unchecked] = ACTIONS(1023),
    [anon_sym_continue] = ACTIONS(1027),
    [anon_sym_do] = ACTIONS(1029),
    [anon_sym_while] = ACTIONS(1031),
    [anon_sym_for] = ACTIONS(1033),
    [anon_sym_lock] = ACTIONS(1035),
    [anon_sym_yield] = ACTIONS(1037),
    [anon_sym_switch] = ACTIONS(1039),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1041),
    [anon_sym_try] = ACTIONS(1043),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1045),
    [anon_sym_foreach] = ACTIONS(1047),
    [anon_sym_goto] = ACTIONS(1049),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1053),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [181] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(8858),
    [sym_variable_declaration] = STATE(9360),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6862),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(9965),
    [sym_break_statement] = STATE(8858),
    [sym_checked_statement] = STATE(8858),
    [sym_continue_statement] = STATE(8858),
    [sym_do_statement] = STATE(8858),
    [sym_empty_statement] = STATE(8858),
    [sym_expression_statement] = STATE(8858),
    [sym_fixed_statement] = STATE(8858),
    [sym_for_statement] = STATE(8858),
    [sym_return_statement] = STATE(8858),
    [sym_lock_statement] = STATE(8858),
    [sym_yield_statement] = STATE(8858),
    [sym_switch_statement] = STATE(8858),
    [sym_throw_statement] = STATE(8858),
    [sym_try_statement] = STATE(8858),
    [sym_unsafe_statement] = STATE(8858),
    [sym_using_statement] = STATE(8858),
    [sym_foreach_statement] = STATE(8858),
    [sym_goto_statement] = STATE(8858),
    [sym_labeled_statement] = STATE(8858),
    [sym_if_statement] = STATE(8858),
    [sym_while_statement] = STATE(8858),
    [sym_local_declaration_statement] = STATE(8858),
    [sym_local_function_statement] = STATE(8858),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6755),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2904),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(8858),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(181),
    [sym_preproc_endregion] = STATE(181),
    [sym_preproc_line] = STATE(181),
    [sym_preproc_pragma] = STATE(181),
    [sym_preproc_nullable] = STATE(181),
    [sym_preproc_error] = STATE(181),
    [sym_preproc_warning] = STATE(181),
    [sym_preproc_define] = STATE(181),
    [sym_preproc_undef] = STATE(181),
    [aux_sym_class_declaration_repeat1] = STATE(2931),
    [aux_sym_class_declaration_repeat2] = STATE(3115),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(1011),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1013),
    [anon_sym_unsafe] = ACTIONS(1015),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(1017),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1019),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1021),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1023),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(1025),
    [anon_sym_unchecked] = ACTIONS(1023),
    [anon_sym_continue] = ACTIONS(1027),
    [anon_sym_do] = ACTIONS(1029),
    [anon_sym_while] = ACTIONS(1031),
    [anon_sym_for] = ACTIONS(1033),
    [anon_sym_lock] = ACTIONS(1035),
    [anon_sym_yield] = ACTIONS(1037),
    [anon_sym_switch] = ACTIONS(1039),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1041),
    [anon_sym_try] = ACTIONS(1043),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1045),
    [anon_sym_foreach] = ACTIONS(1047),
    [anon_sym_goto] = ACTIONS(1049),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1053),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [182] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(8858),
    [sym_variable_declaration] = STATE(9360),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6862),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(9973),
    [sym_break_statement] = STATE(8858),
    [sym_checked_statement] = STATE(8858),
    [sym_continue_statement] = STATE(8858),
    [sym_do_statement] = STATE(8858),
    [sym_empty_statement] = STATE(8858),
    [sym_expression_statement] = STATE(8858),
    [sym_fixed_statement] = STATE(8858),
    [sym_for_statement] = STATE(8858),
    [sym_return_statement] = STATE(8858),
    [sym_lock_statement] = STATE(8858),
    [sym_yield_statement] = STATE(8858),
    [sym_switch_statement] = STATE(8858),
    [sym_throw_statement] = STATE(8858),
    [sym_try_statement] = STATE(8858),
    [sym_unsafe_statement] = STATE(8858),
    [sym_using_statement] = STATE(8858),
    [sym_foreach_statement] = STATE(8858),
    [sym_goto_statement] = STATE(8858),
    [sym_labeled_statement] = STATE(8858),
    [sym_if_statement] = STATE(8858),
    [sym_while_statement] = STATE(8858),
    [sym_local_declaration_statement] = STATE(8858),
    [sym_local_function_statement] = STATE(8858),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6755),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2904),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(8858),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(182),
    [sym_preproc_endregion] = STATE(182),
    [sym_preproc_line] = STATE(182),
    [sym_preproc_pragma] = STATE(182),
    [sym_preproc_nullable] = STATE(182),
    [sym_preproc_error] = STATE(182),
    [sym_preproc_warning] = STATE(182),
    [sym_preproc_define] = STATE(182),
    [sym_preproc_undef] = STATE(182),
    [aux_sym_class_declaration_repeat1] = STATE(2931),
    [aux_sym_class_declaration_repeat2] = STATE(3115),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(1011),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(1013),
    [anon_sym_unsafe] = ACTIONS(1015),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(1017),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1019),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(1021),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1023),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(1025),
    [anon_sym_unchecked] = ACTIONS(1023),
    [anon_sym_continue] = ACTIONS(1027),
    [anon_sym_do] = ACTIONS(1029),
    [anon_sym_while] = ACTIONS(1031),
    [anon_sym_for] = ACTIONS(1033),
    [anon_sym_lock] = ACTIONS(1035),
    [anon_sym_yield] = ACTIONS(1037),
    [anon_sym_switch] = ACTIONS(1039),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1041),
    [anon_sym_try] = ACTIONS(1043),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1045),
    [anon_sym_foreach] = ACTIONS(1047),
    [anon_sym_goto] = ACTIONS(1049),
    [anon_sym_if] = ACTIONS(1051),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1053),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [183] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(2659),
    [sym_variable_declaration] = STATE(9524),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6870),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_statement] = STATE(2660),
    [sym_break_statement] = STATE(2659),
    [sym_checked_statement] = STATE(2659),
    [sym_continue_statement] = STATE(2659),
    [sym_do_statement] = STATE(2659),
    [sym_empty_statement] = STATE(2659),
    [sym_expression_statement] = STATE(2659),
    [sym_fixed_statement] = STATE(2659),
    [sym_for_statement] = STATE(2659),
    [sym_return_statement] = STATE(2659),
    [sym_lock_statement] = STATE(2659),
    [sym_yield_statement] = STATE(2659),
    [sym_switch_statement] = STATE(2659),
    [sym_throw_statement] = STATE(2659),
    [sym_try_statement] = STATE(2659),
    [sym_unsafe_statement] = STATE(2659),
    [sym_using_statement] = STATE(2659),
    [sym_foreach_statement] = STATE(2659),
    [sym_goto_statement] = STATE(2659),
    [sym_labeled_statement] = STATE(2659),
    [sym_if_statement] = STATE(2659),
    [sym_while_statement] = STATE(2659),
    [sym_local_declaration_statement] = STATE(2659),
    [sym_local_function_statement] = STATE(2659),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(6347),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2847),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_top_level] = STATE(2659),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(183),
    [sym_preproc_endregion] = STATE(183),
    [sym_preproc_line] = STATE(183),
    [sym_preproc_pragma] = STATE(183),
    [sym_preproc_nullable] = STATE(183),
    [sym_preproc_error] = STATE(183),
    [sym_preproc_warning] = STATE(183),
    [sym_preproc_define] = STATE(183),
    [sym_preproc_undef] = STATE(183),
    [aux_sym_class_declaration_repeat1] = STATE(2935),
    [aux_sym_class_declaration_repeat2] = STATE(3094),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(663),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(665),
    [anon_sym_unsafe] = ACTIONS(667),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(671),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_return] = ACTIONS(677),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(681),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(689),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(691),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(693),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_break] = ACTIONS(701),
    [anon_sym_unchecked] = ACTIONS(693),
    [anon_sym_continue] = ACTIONS(703),
    [anon_sym_do] = ACTIONS(705),
    [anon_sym_while] = ACTIONS(707),
    [anon_sym_for] = ACTIONS(709),
    [anon_sym_lock] = ACTIONS(711),
    [anon_sym_yield] = ACTIONS(713),
    [anon_sym_switch] = ACTIONS(715),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(739),
    [anon_sym_try] = ACTIONS(719),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(741),
    [anon_sym_foreach] = ACTIONS(723),
    [anon_sym_goto] = ACTIONS(725),
    [anon_sym_if] = ACTIONS(727),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(731),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [184] = {
    [sym_attribute] = STATE(8640),
    [sym_attribute_list] = STATE(6699),
    [sym_attribute_target_specifier] = STATE(6811),
    [sym_parameter_list] = STATE(9685),
    [sym_argument] = STATE(8466),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6466),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2798),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6033),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_pattern] = STATE(8065),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6158),
    [sym_property_pattern_clause] = STATE(6724),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6285),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5060),
    [sym_postfix_unary_expression] = STATE(5061),
    [sym_prefix_unary_expression] = STATE(5061),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5060),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5061),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5060),
    [sym_member_access_expression] = STATE(3797),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5061),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(5060),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5060),
    [sym_typeof_expression] = STATE(5060),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3797),
    [sym_literal] = STATE(5060),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2779),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(184),
    [sym_preproc_endregion] = STATE(184),
    [sym_preproc_line] = STATE(184),
    [sym_preproc_pragma] = STATE(184),
    [sym_preproc_nullable] = STATE(184),
    [sym_preproc_error] = STATE(184),
    [sym_preproc_warning] = STATE(184),
    [sym_preproc_define] = STATE(184),
    [sym_preproc_undef] = STATE(184),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_RBRACK] = ACTIONS(1065),
    [anon_sym_LPAREN] = ACTIONS(1067),
    [anon_sym_field] = ACTIONS(1069),
    [anon_sym_event] = ACTIONS(1069),
    [anon_sym_method] = ACTIONS(1069),
    [anon_sym_param] = ACTIONS(1069),
    [anon_sym_property] = ACTIONS(1069),
    [anon_sym_return] = ACTIONS(1069),
    [anon_sym_type] = ACTIONS(1069),
    [anon_sym_ref] = ACTIONS(1071),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(1077),
    [anon_sym_GT] = ACTIONS(1077),
    [anon_sym_in] = ACTIONS(1079),
    [anon_sym_out] = ACTIONS(1079),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1083),
    [anon_sym_PLUS_PLUS] = ACTIONS(1083),
    [anon_sym_DASH_DASH] = ACTIONS(1083),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1085),
    [anon_sym_DASH] = ACTIONS(1085),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1083),
    [anon_sym_AMP] = ACTIONS(1083),
    [anon_sym_GT_EQ] = ACTIONS(1087),
    [anon_sym_LT_EQ] = ACTIONS(1087),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(1089),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1091),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(1099),
    [anon_sym_not] = ACTIONS(1101),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [185] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8790),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2798),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6003),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8977),
    [sym_pattern] = STATE(8296),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6158),
    [sym_property_pattern_clause] = STATE(6724),
    [sym_subpattern] = STATE(8710),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym__variable_designation] = STATE(8647),
    [sym_parenthesized_variable_designation] = STATE(4153),
    [sym_expression] = STATE(6179),
    [sym_non_lvalue_expression] = STATE(6534),
    [sym_lvalue_expression] = STATE(4340),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5060),
    [sym_postfix_unary_expression] = STATE(5061),
    [sym_prefix_unary_expression] = STATE(5061),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5060),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5061),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5060),
    [sym_member_access_expression] = STATE(3797),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5061),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9065),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(5060),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5060),
    [sym_typeof_expression] = STATE(5060),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3797),
    [sym_literal] = STATE(5060),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2785),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(185),
    [sym_preproc_endregion] = STATE(185),
    [sym_preproc_line] = STATE(185),
    [sym_preproc_pragma] = STATE(185),
    [sym_preproc_nullable] = STATE(185),
    [sym_preproc_error] = STATE(185),
    [sym_preproc_warning] = STATE(185),
    [sym_preproc_define] = STATE(185),
    [sym_preproc_undef] = STATE(185),
    [aux_sym_class_declaration_repeat1] = STATE(3574),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4311),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1105),
    [anon_sym_RPAREN] = ACTIONS(1107),
    [anon_sym_ref] = ACTIONS(1109),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_LT] = ACTIONS(1077),
    [anon_sym_GT] = ACTIONS(1077),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1117),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(1121),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_AMP] = ACTIONS(1117),
    [anon_sym_GT_EQ] = ACTIONS(1087),
    [anon_sym_LT_EQ] = ACTIONS(1087),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1091),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1129),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1131),
    [sym_discard] = ACTIONS(1133),
    [anon_sym_DOT_DOT] = ACTIONS(1135),
    [anon_sym_not] = ACTIONS(1137),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [186] = {
    [sym_attribute] = STATE(8640),
    [sym_attribute_list] = STATE(6699),
    [sym_attribute_target_specifier] = STATE(6811),
    [sym_parameter_list] = STATE(9685),
    [sym_argument] = STATE(8466),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6466),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2798),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6033),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_pattern] = STATE(8095),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6158),
    [sym_property_pattern_clause] = STATE(6724),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6285),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5060),
    [sym_postfix_unary_expression] = STATE(5061),
    [sym_prefix_unary_expression] = STATE(5061),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5060),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5061),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5060),
    [sym_member_access_expression] = STATE(3797),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5061),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(5060),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5060),
    [sym_typeof_expression] = STATE(5060),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3797),
    [sym_literal] = STATE(5060),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2779),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(186),
    [sym_preproc_endregion] = STATE(186),
    [sym_preproc_line] = STATE(186),
    [sym_preproc_pragma] = STATE(186),
    [sym_preproc_nullable] = STATE(186),
    [sym_preproc_error] = STATE(186),
    [sym_preproc_warning] = STATE(186),
    [sym_preproc_define] = STATE(186),
    [sym_preproc_undef] = STATE(186),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_RBRACK] = ACTIONS(1139),
    [anon_sym_LPAREN] = ACTIONS(1067),
    [anon_sym_field] = ACTIONS(1069),
    [anon_sym_event] = ACTIONS(1069),
    [anon_sym_method] = ACTIONS(1069),
    [anon_sym_param] = ACTIONS(1069),
    [anon_sym_property] = ACTIONS(1069),
    [anon_sym_return] = ACTIONS(1069),
    [anon_sym_type] = ACTIONS(1069),
    [anon_sym_ref] = ACTIONS(1071),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(1077),
    [anon_sym_GT] = ACTIONS(1077),
    [anon_sym_in] = ACTIONS(1079),
    [anon_sym_out] = ACTIONS(1079),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1083),
    [anon_sym_PLUS_PLUS] = ACTIONS(1083),
    [anon_sym_DASH_DASH] = ACTIONS(1083),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1085),
    [anon_sym_DASH] = ACTIONS(1085),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1083),
    [anon_sym_AMP] = ACTIONS(1083),
    [anon_sym_GT_EQ] = ACTIONS(1087),
    [anon_sym_LT_EQ] = ACTIONS(1087),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(1089),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1091),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(1141),
    [anon_sym_not] = ACTIONS(1101),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [187] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8790),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2798),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6003),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8977),
    [sym_pattern] = STATE(8296),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6158),
    [sym_property_pattern_clause] = STATE(6724),
    [sym_subpattern] = STATE(8710),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym__variable_designation] = STATE(8647),
    [sym_parenthesized_variable_designation] = STATE(4153),
    [sym_expression] = STATE(6179),
    [sym_non_lvalue_expression] = STATE(6534),
    [sym_lvalue_expression] = STATE(4340),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5060),
    [sym_postfix_unary_expression] = STATE(5061),
    [sym_prefix_unary_expression] = STATE(5061),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5060),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5061),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5060),
    [sym_member_access_expression] = STATE(3797),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5061),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9065),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(5060),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5060),
    [sym_typeof_expression] = STATE(5060),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3797),
    [sym_literal] = STATE(5060),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2785),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(187),
    [sym_preproc_endregion] = STATE(187),
    [sym_preproc_line] = STATE(187),
    [sym_preproc_pragma] = STATE(187),
    [sym_preproc_nullable] = STATE(187),
    [sym_preproc_error] = STATE(187),
    [sym_preproc_warning] = STATE(187),
    [sym_preproc_define] = STATE(187),
    [sym_preproc_undef] = STATE(187),
    [aux_sym_class_declaration_repeat1] = STATE(3574),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4311),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1105),
    [anon_sym_RPAREN] = ACTIONS(1143),
    [anon_sym_ref] = ACTIONS(1109),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_LT] = ACTIONS(1077),
    [anon_sym_GT] = ACTIONS(1077),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1117),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(1121),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_AMP] = ACTIONS(1117),
    [anon_sym_GT_EQ] = ACTIONS(1087),
    [anon_sym_LT_EQ] = ACTIONS(1087),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1091),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1129),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1131),
    [sym_discard] = ACTIONS(1133),
    [anon_sym_DOT_DOT] = ACTIONS(1135),
    [anon_sym_not] = ACTIONS(1137),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [188] = {
    [sym_attribute] = STATE(8640),
    [sym_attribute_list] = STATE(6699),
    [sym_attribute_target_specifier] = STATE(6811),
    [sym_parameter_list] = STATE(9685),
    [sym_argument] = STATE(8466),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6466),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2798),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6033),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_pattern] = STATE(8230),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6158),
    [sym_property_pattern_clause] = STATE(6724),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6285),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5060),
    [sym_postfix_unary_expression] = STATE(5061),
    [sym_prefix_unary_expression] = STATE(5061),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5060),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5061),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5060),
    [sym_member_access_expression] = STATE(3797),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5061),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(5060),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5060),
    [sym_typeof_expression] = STATE(5060),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3797),
    [sym_literal] = STATE(5060),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2779),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(188),
    [sym_preproc_endregion] = STATE(188),
    [sym_preproc_line] = STATE(188),
    [sym_preproc_pragma] = STATE(188),
    [sym_preproc_nullable] = STATE(188),
    [sym_preproc_error] = STATE(188),
    [sym_preproc_warning] = STATE(188),
    [sym_preproc_define] = STATE(188),
    [sym_preproc_undef] = STATE(188),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_RBRACK] = ACTIONS(1145),
    [anon_sym_LPAREN] = ACTIONS(1067),
    [anon_sym_field] = ACTIONS(1069),
    [anon_sym_event] = ACTIONS(1069),
    [anon_sym_method] = ACTIONS(1069),
    [anon_sym_param] = ACTIONS(1069),
    [anon_sym_property] = ACTIONS(1069),
    [anon_sym_return] = ACTIONS(1069),
    [anon_sym_type] = ACTIONS(1069),
    [anon_sym_ref] = ACTIONS(1071),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(1077),
    [anon_sym_GT] = ACTIONS(1077),
    [anon_sym_in] = ACTIONS(1079),
    [anon_sym_out] = ACTIONS(1079),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1083),
    [anon_sym_PLUS_PLUS] = ACTIONS(1083),
    [anon_sym_DASH_DASH] = ACTIONS(1083),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1085),
    [anon_sym_DASH] = ACTIONS(1085),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1083),
    [anon_sym_AMP] = ACTIONS(1083),
    [anon_sym_GT_EQ] = ACTIONS(1087),
    [anon_sym_LT_EQ] = ACTIONS(1087),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(1089),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1091),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(1147),
    [anon_sym_not] = ACTIONS(1101),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [189] = {
    [sym_attribute] = STATE(8640),
    [sym_attribute_list] = STATE(6699),
    [sym_attribute_target_specifier] = STATE(6811),
    [sym_parameter_list] = STATE(9685),
    [sym_argument] = STATE(8466),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6466),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2798),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6033),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_pattern] = STATE(8234),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6158),
    [sym_property_pattern_clause] = STATE(6724),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6285),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5060),
    [sym_postfix_unary_expression] = STATE(5061),
    [sym_prefix_unary_expression] = STATE(5061),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5060),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5061),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5060),
    [sym_member_access_expression] = STATE(3797),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5061),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(5060),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5060),
    [sym_typeof_expression] = STATE(5060),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3797),
    [sym_literal] = STATE(5060),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2779),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(189),
    [sym_preproc_endregion] = STATE(189),
    [sym_preproc_line] = STATE(189),
    [sym_preproc_pragma] = STATE(189),
    [sym_preproc_nullable] = STATE(189),
    [sym_preproc_error] = STATE(189),
    [sym_preproc_warning] = STATE(189),
    [sym_preproc_define] = STATE(189),
    [sym_preproc_undef] = STATE(189),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_RBRACK] = ACTIONS(1149),
    [anon_sym_LPAREN] = ACTIONS(1067),
    [anon_sym_field] = ACTIONS(1069),
    [anon_sym_event] = ACTIONS(1069),
    [anon_sym_method] = ACTIONS(1069),
    [anon_sym_param] = ACTIONS(1069),
    [anon_sym_property] = ACTIONS(1069),
    [anon_sym_return] = ACTIONS(1069),
    [anon_sym_type] = ACTIONS(1069),
    [anon_sym_ref] = ACTIONS(1071),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(1077),
    [anon_sym_GT] = ACTIONS(1077),
    [anon_sym_in] = ACTIONS(1079),
    [anon_sym_out] = ACTIONS(1079),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1083),
    [anon_sym_PLUS_PLUS] = ACTIONS(1083),
    [anon_sym_DASH_DASH] = ACTIONS(1083),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1085),
    [anon_sym_DASH] = ACTIONS(1085),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1083),
    [anon_sym_AMP] = ACTIONS(1083),
    [anon_sym_GT_EQ] = ACTIONS(1087),
    [anon_sym_LT_EQ] = ACTIONS(1087),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(1089),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1091),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(1151),
    [anon_sym_not] = ACTIONS(1101),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [190] = {
    [sym_attribute] = STATE(8640),
    [sym_attribute_list] = STATE(6699),
    [sym_attribute_target_specifier] = STATE(6811),
    [sym_parameter_list] = STATE(9685),
    [sym_argument] = STATE(8466),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6466),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2798),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6033),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_pattern] = STATE(7952),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6158),
    [sym_property_pattern_clause] = STATE(6724),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6285),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5060),
    [sym_postfix_unary_expression] = STATE(5061),
    [sym_prefix_unary_expression] = STATE(5061),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5060),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5061),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5060),
    [sym_member_access_expression] = STATE(3797),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5061),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(5060),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5060),
    [sym_typeof_expression] = STATE(5060),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3797),
    [sym_literal] = STATE(5060),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2779),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(190),
    [sym_preproc_endregion] = STATE(190),
    [sym_preproc_line] = STATE(190),
    [sym_preproc_pragma] = STATE(190),
    [sym_preproc_nullable] = STATE(190),
    [sym_preproc_error] = STATE(190),
    [sym_preproc_warning] = STATE(190),
    [sym_preproc_define] = STATE(190),
    [sym_preproc_undef] = STATE(190),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_RBRACK] = ACTIONS(1153),
    [anon_sym_LPAREN] = ACTIONS(1067),
    [anon_sym_field] = ACTIONS(1069),
    [anon_sym_event] = ACTIONS(1069),
    [anon_sym_method] = ACTIONS(1069),
    [anon_sym_param] = ACTIONS(1069),
    [anon_sym_property] = ACTIONS(1069),
    [anon_sym_return] = ACTIONS(1069),
    [anon_sym_type] = ACTIONS(1069),
    [anon_sym_ref] = ACTIONS(1071),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(1077),
    [anon_sym_GT] = ACTIONS(1077),
    [anon_sym_in] = ACTIONS(1079),
    [anon_sym_out] = ACTIONS(1079),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1083),
    [anon_sym_PLUS_PLUS] = ACTIONS(1083),
    [anon_sym_DASH_DASH] = ACTIONS(1083),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1085),
    [anon_sym_DASH] = ACTIONS(1085),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1083),
    [anon_sym_AMP] = ACTIONS(1083),
    [anon_sym_GT_EQ] = ACTIONS(1087),
    [anon_sym_LT_EQ] = ACTIONS(1087),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(1089),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1091),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(1155),
    [anon_sym_not] = ACTIONS(1101),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [191] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6915),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7018),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4480),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3585),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7418),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9926),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(191),
    [sym_preproc_endregion] = STATE(191),
    [sym_preproc_line] = STATE(191),
    [sym_preproc_pragma] = STATE(191),
    [sym_preproc_nullable] = STATE(191),
    [sym_preproc_error] = STATE(191),
    [sym_preproc_warning] = STATE(191),
    [sym_preproc_define] = STATE(191),
    [sym_preproc_undef] = STATE(191),
    [aux_sym_class_declaration_repeat1] = STATE(3825),
    [aux_sym_lambda_expression_repeat1] = STATE(4244),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(1157),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_COMMA] = ACTIONS(1157),
    [anon_sym_RBRACK] = ACTIONS(1157),
    [anon_sym_LPAREN] = ACTIONS(1161),
    [anon_sym_RPAREN] = ACTIONS(1157),
    [anon_sym_ref] = ACTIONS(1163),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_RBRACE] = ACTIONS(1157),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_LT] = ACTIONS(1171),
    [anon_sym_GT] = ACTIONS(1171),
    [anon_sym_in] = ACTIONS(1171),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1171),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1175),
    [anon_sym_TILDE] = ACTIONS(1177),
    [anon_sym_PLUS_PLUS] = ACTIONS(1177),
    [anon_sym_DASH_DASH] = ACTIONS(1177),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1175),
    [anon_sym_DASH] = ACTIONS(1175),
    [anon_sym_STAR] = ACTIONS(1181),
    [anon_sym_SLASH] = ACTIONS(1171),
    [anon_sym_PERCENT] = ACTIONS(1157),
    [anon_sym_CARET] = ACTIONS(1177),
    [anon_sym_PIPE] = ACTIONS(1171),
    [anon_sym_AMP] = ACTIONS(1175),
    [anon_sym_LT_LT] = ACTIONS(1157),
    [anon_sym_GT_GT] = ACTIONS(1171),
    [anon_sym_GT_GT_GT] = ACTIONS(1157),
    [anon_sym_EQ_EQ] = ACTIONS(1157),
    [anon_sym_BANG_EQ] = ACTIONS(1157),
    [anon_sym_GT_EQ] = ACTIONS(1157),
    [anon_sym_LT_EQ] = ACTIONS(1157),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_DOT] = ACTIONS(1171),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1171),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1191),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1193),
    [anon_sym_DOT_DOT] = ACTIONS(1195),
    [anon_sym_and] = ACTIONS(1171),
    [anon_sym_or] = ACTIONS(1171),
    [anon_sym_AMP_AMP] = ACTIONS(1157),
    [anon_sym_PIPE_PIPE] = ACTIONS(1157),
    [anon_sym_QMARK_QMARK] = ACTIONS(1157),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1171),
    [anon_sym_is] = ACTIONS(1171),
    [anon_sym_DASH_GT] = ACTIONS(1157),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_with] = ACTIONS(1171),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_if_token3] = ACTIONS(1157),
    [aux_sym_preproc_else_token1] = ACTIONS(1157),
    [aux_sym_preproc_elif_token1] = ACTIONS(1157),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [192] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6915),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7018),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4502),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3585),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7418),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9926),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(192),
    [sym_preproc_endregion] = STATE(192),
    [sym_preproc_line] = STATE(192),
    [sym_preproc_pragma] = STATE(192),
    [sym_preproc_nullable] = STATE(192),
    [sym_preproc_error] = STATE(192),
    [sym_preproc_warning] = STATE(192),
    [sym_preproc_define] = STATE(192),
    [sym_preproc_undef] = STATE(192),
    [aux_sym_class_declaration_repeat1] = STATE(3825),
    [aux_sym_lambda_expression_repeat1] = STATE(4244),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(1227),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_COMMA] = ACTIONS(1227),
    [anon_sym_RBRACK] = ACTIONS(1227),
    [anon_sym_LPAREN] = ACTIONS(1161),
    [anon_sym_RPAREN] = ACTIONS(1227),
    [anon_sym_ref] = ACTIONS(1163),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_RBRACE] = ACTIONS(1227),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_LT] = ACTIONS(1229),
    [anon_sym_GT] = ACTIONS(1229),
    [anon_sym_in] = ACTIONS(1229),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1229),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1175),
    [anon_sym_TILDE] = ACTIONS(1177),
    [anon_sym_PLUS_PLUS] = ACTIONS(1177),
    [anon_sym_DASH_DASH] = ACTIONS(1177),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1175),
    [anon_sym_DASH] = ACTIONS(1175),
    [anon_sym_STAR] = ACTIONS(1181),
    [anon_sym_SLASH] = ACTIONS(1229),
    [anon_sym_PERCENT] = ACTIONS(1227),
    [anon_sym_CARET] = ACTIONS(1177),
    [anon_sym_PIPE] = ACTIONS(1229),
    [anon_sym_AMP] = ACTIONS(1175),
    [anon_sym_LT_LT] = ACTIONS(1227),
    [anon_sym_GT_GT] = ACTIONS(1229),
    [anon_sym_GT_GT_GT] = ACTIONS(1227),
    [anon_sym_EQ_EQ] = ACTIONS(1227),
    [anon_sym_BANG_EQ] = ACTIONS(1227),
    [anon_sym_GT_EQ] = ACTIONS(1227),
    [anon_sym_LT_EQ] = ACTIONS(1227),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_DOT] = ACTIONS(1229),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1229),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1191),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1193),
    [anon_sym_DOT_DOT] = ACTIONS(1195),
    [anon_sym_and] = ACTIONS(1229),
    [anon_sym_or] = ACTIONS(1229),
    [anon_sym_AMP_AMP] = ACTIONS(1227),
    [anon_sym_PIPE_PIPE] = ACTIONS(1227),
    [anon_sym_QMARK_QMARK] = ACTIONS(1227),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1229),
    [anon_sym_is] = ACTIONS(1229),
    [anon_sym_DASH_GT] = ACTIONS(1227),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_with] = ACTIONS(1229),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_if_token3] = ACTIONS(1227),
    [aux_sym_preproc_else_token1] = ACTIONS(1227),
    [aux_sym_preproc_elif_token1] = ACTIONS(1227),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [193] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8982),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2798),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(5833),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8759),
    [sym_pattern] = STATE(8282),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6158),
    [sym_property_pattern_clause] = STATE(6724),
    [sym_subpattern] = STATE(8710),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6179),
    [sym_non_lvalue_expression] = STATE(6390),
    [sym_lvalue_expression] = STATE(4340),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5060),
    [sym_postfix_unary_expression] = STATE(5061),
    [sym_prefix_unary_expression] = STATE(5061),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5060),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5061),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5060),
    [sym_member_access_expression] = STATE(3797),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5061),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9065),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(5060),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5060),
    [sym_typeof_expression] = STATE(5060),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3797),
    [sym_literal] = STATE(5060),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(193),
    [sym_preproc_endregion] = STATE(193),
    [sym_preproc_line] = STATE(193),
    [sym_preproc_pragma] = STATE(193),
    [sym_preproc_nullable] = STATE(193),
    [sym_preproc_error] = STATE(193),
    [sym_preproc_warning] = STATE(193),
    [sym_preproc_define] = STATE(193),
    [sym_preproc_undef] = STATE(193),
    [aux_sym_class_declaration_repeat1] = STATE(3574),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4311),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1231),
    [anon_sym_RPAREN] = ACTIONS(1233),
    [anon_sym_ref] = ACTIONS(1109),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_LT] = ACTIONS(1077),
    [anon_sym_GT] = ACTIONS(1077),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1117),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(1121),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_AMP] = ACTIONS(1117),
    [anon_sym_GT_EQ] = ACTIONS(1087),
    [anon_sym_LT_EQ] = ACTIONS(1087),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1091),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1129),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1131),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(1135),
    [anon_sym_not] = ACTIONS(1137),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [194] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8790),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2798),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6082),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8759),
    [sym_pattern] = STATE(8296),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6158),
    [sym_property_pattern_clause] = STATE(6724),
    [sym_subpattern] = STATE(8710),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6179),
    [sym_non_lvalue_expression] = STATE(6534),
    [sym_lvalue_expression] = STATE(4340),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5060),
    [sym_postfix_unary_expression] = STATE(5061),
    [sym_prefix_unary_expression] = STATE(5061),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5060),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5061),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5060),
    [sym_member_access_expression] = STATE(3797),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5061),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9065),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(5060),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5060),
    [sym_typeof_expression] = STATE(5060),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3797),
    [sym_literal] = STATE(5060),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(194),
    [sym_preproc_endregion] = STATE(194),
    [sym_preproc_line] = STATE(194),
    [sym_preproc_pragma] = STATE(194),
    [sym_preproc_nullable] = STATE(194),
    [sym_preproc_error] = STATE(194),
    [sym_preproc_warning] = STATE(194),
    [sym_preproc_define] = STATE(194),
    [sym_preproc_undef] = STATE(194),
    [aux_sym_class_declaration_repeat1] = STATE(3574),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4311),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1231),
    [anon_sym_RPAREN] = ACTIONS(1233),
    [anon_sym_ref] = ACTIONS(1109),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_LT] = ACTIONS(1077),
    [anon_sym_GT] = ACTIONS(1077),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1117),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(1121),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_AMP] = ACTIONS(1117),
    [anon_sym_GT_EQ] = ACTIONS(1087),
    [anon_sym_LT_EQ] = ACTIONS(1087),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1091),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1129),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1131),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(1135),
    [anon_sym_not] = ACTIONS(1137),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [195] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8982),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2798),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(5983),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8759),
    [sym_pattern] = STATE(8282),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6158),
    [sym_property_pattern_clause] = STATE(6724),
    [sym_subpattern] = STATE(8710),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6179),
    [sym_non_lvalue_expression] = STATE(6390),
    [sym_lvalue_expression] = STATE(4340),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5060),
    [sym_postfix_unary_expression] = STATE(5061),
    [sym_prefix_unary_expression] = STATE(5061),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5060),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5061),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5060),
    [sym_member_access_expression] = STATE(3797),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5061),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9065),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(5060),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5060),
    [sym_typeof_expression] = STATE(5060),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3797),
    [sym_literal] = STATE(5060),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(195),
    [sym_preproc_endregion] = STATE(195),
    [sym_preproc_line] = STATE(195),
    [sym_preproc_pragma] = STATE(195),
    [sym_preproc_nullable] = STATE(195),
    [sym_preproc_error] = STATE(195),
    [sym_preproc_warning] = STATE(195),
    [sym_preproc_define] = STATE(195),
    [sym_preproc_undef] = STATE(195),
    [aux_sym_class_declaration_repeat1] = STATE(3574),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4311),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1231),
    [anon_sym_RPAREN] = ACTIONS(1233),
    [anon_sym_ref] = ACTIONS(1109),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_LT] = ACTIONS(1077),
    [anon_sym_GT] = ACTIONS(1077),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1117),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(1121),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_AMP] = ACTIONS(1117),
    [anon_sym_GT_EQ] = ACTIONS(1087),
    [anon_sym_LT_EQ] = ACTIONS(1087),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1091),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1129),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1131),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(1135),
    [anon_sym_not] = ACTIONS(1137),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [196] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8749),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2798),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(5948),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8759),
    [sym_pattern] = STATE(8334),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6158),
    [sym_property_pattern_clause] = STATE(6724),
    [sym_subpattern] = STATE(8710),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6179),
    [sym_non_lvalue_expression] = STATE(6351),
    [sym_lvalue_expression] = STATE(4340),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5060),
    [sym_postfix_unary_expression] = STATE(5061),
    [sym_prefix_unary_expression] = STATE(5061),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5060),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5061),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5060),
    [sym_member_access_expression] = STATE(3797),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5061),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9065),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(5060),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5060),
    [sym_typeof_expression] = STATE(5060),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3797),
    [sym_literal] = STATE(5060),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(196),
    [sym_preproc_endregion] = STATE(196),
    [sym_preproc_line] = STATE(196),
    [sym_preproc_pragma] = STATE(196),
    [sym_preproc_nullable] = STATE(196),
    [sym_preproc_error] = STATE(196),
    [sym_preproc_warning] = STATE(196),
    [sym_preproc_define] = STATE(196),
    [sym_preproc_undef] = STATE(196),
    [aux_sym_class_declaration_repeat1] = STATE(3574),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4311),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1231),
    [anon_sym_RPAREN] = ACTIONS(1233),
    [anon_sym_ref] = ACTIONS(1109),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_LT] = ACTIONS(1077),
    [anon_sym_GT] = ACTIONS(1077),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1117),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(1121),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_AMP] = ACTIONS(1117),
    [anon_sym_GT_EQ] = ACTIONS(1087),
    [anon_sym_LT_EQ] = ACTIONS(1087),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1091),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1129),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1131),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(1135),
    [anon_sym_not] = ACTIONS(1137),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [197] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8982),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2798),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(5975),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8759),
    [sym_pattern] = STATE(8282),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6158),
    [sym_property_pattern_clause] = STATE(6724),
    [sym_subpattern] = STATE(8710),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6179),
    [sym_non_lvalue_expression] = STATE(6390),
    [sym_lvalue_expression] = STATE(4340),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5060),
    [sym_postfix_unary_expression] = STATE(5061),
    [sym_prefix_unary_expression] = STATE(5061),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5060),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5061),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5060),
    [sym_member_access_expression] = STATE(3797),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5061),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9065),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(5060),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5060),
    [sym_typeof_expression] = STATE(5060),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3797),
    [sym_literal] = STATE(5060),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(197),
    [sym_preproc_endregion] = STATE(197),
    [sym_preproc_line] = STATE(197),
    [sym_preproc_pragma] = STATE(197),
    [sym_preproc_nullable] = STATE(197),
    [sym_preproc_error] = STATE(197),
    [sym_preproc_warning] = STATE(197),
    [sym_preproc_define] = STATE(197),
    [sym_preproc_undef] = STATE(197),
    [aux_sym_class_declaration_repeat1] = STATE(3574),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4311),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1231),
    [anon_sym_RPAREN] = ACTIONS(1233),
    [anon_sym_ref] = ACTIONS(1109),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_LT] = ACTIONS(1077),
    [anon_sym_GT] = ACTIONS(1077),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1117),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(1121),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_AMP] = ACTIONS(1117),
    [anon_sym_GT_EQ] = ACTIONS(1087),
    [anon_sym_LT_EQ] = ACTIONS(1087),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1091),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1129),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1131),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(1135),
    [anon_sym_not] = ACTIONS(1137),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [198] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8749),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2798),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6050),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8759),
    [sym_pattern] = STATE(8334),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6158),
    [sym_property_pattern_clause] = STATE(6724),
    [sym_subpattern] = STATE(8710),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6179),
    [sym_non_lvalue_expression] = STATE(6351),
    [sym_lvalue_expression] = STATE(4340),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5060),
    [sym_postfix_unary_expression] = STATE(5061),
    [sym_prefix_unary_expression] = STATE(5061),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5060),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5061),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5060),
    [sym_member_access_expression] = STATE(3797),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5061),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9065),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(5060),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5060),
    [sym_typeof_expression] = STATE(5060),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3797),
    [sym_literal] = STATE(5060),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(198),
    [sym_preproc_endregion] = STATE(198),
    [sym_preproc_line] = STATE(198),
    [sym_preproc_pragma] = STATE(198),
    [sym_preproc_nullable] = STATE(198),
    [sym_preproc_error] = STATE(198),
    [sym_preproc_warning] = STATE(198),
    [sym_preproc_define] = STATE(198),
    [sym_preproc_undef] = STATE(198),
    [aux_sym_class_declaration_repeat1] = STATE(3574),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4311),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1231),
    [anon_sym_RPAREN] = ACTIONS(1233),
    [anon_sym_ref] = ACTIONS(1109),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_LT] = ACTIONS(1077),
    [anon_sym_GT] = ACTIONS(1077),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1117),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(1121),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_AMP] = ACTIONS(1117),
    [anon_sym_GT_EQ] = ACTIONS(1087),
    [anon_sym_LT_EQ] = ACTIONS(1087),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1091),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1129),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1131),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(1135),
    [anon_sym_not] = ACTIONS(1137),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [199] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8776),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2798),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(5874),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8812),
    [sym_pattern] = STATE(8327),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6158),
    [sym_property_pattern_clause] = STATE(6724),
    [sym_subpattern] = STATE(8851),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6179),
    [sym_non_lvalue_expression] = STATE(6500),
    [sym_lvalue_expression] = STATE(4340),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5060),
    [sym_postfix_unary_expression] = STATE(5061),
    [sym_prefix_unary_expression] = STATE(5061),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5060),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5061),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5060),
    [sym_member_access_expression] = STATE(3797),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5061),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9065),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(5060),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5060),
    [sym_typeof_expression] = STATE(5060),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3797),
    [sym_literal] = STATE(5060),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(199),
    [sym_preproc_endregion] = STATE(199),
    [sym_preproc_line] = STATE(199),
    [sym_preproc_pragma] = STATE(199),
    [sym_preproc_nullable] = STATE(199),
    [sym_preproc_error] = STATE(199),
    [sym_preproc_warning] = STATE(199),
    [sym_preproc_define] = STATE(199),
    [sym_preproc_undef] = STATE(199),
    [aux_sym_class_declaration_repeat1] = STATE(3574),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4311),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1231),
    [anon_sym_RPAREN] = ACTIONS(1235),
    [anon_sym_ref] = ACTIONS(1109),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_LT] = ACTIONS(1077),
    [anon_sym_GT] = ACTIONS(1077),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1117),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(1121),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_AMP] = ACTIONS(1117),
    [anon_sym_GT_EQ] = ACTIONS(1087),
    [anon_sym_LT_EQ] = ACTIONS(1087),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1091),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1129),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1131),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(1135),
    [anon_sym_not] = ACTIONS(1137),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [200] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8754),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2798),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(5796),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8759),
    [sym_pattern] = STATE(8372),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6158),
    [sym_property_pattern_clause] = STATE(6724),
    [sym_subpattern] = STATE(8710),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6179),
    [sym_non_lvalue_expression] = STATE(6583),
    [sym_lvalue_expression] = STATE(4340),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5060),
    [sym_postfix_unary_expression] = STATE(5061),
    [sym_prefix_unary_expression] = STATE(5061),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5060),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5061),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5060),
    [sym_member_access_expression] = STATE(3797),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5061),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9065),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(5060),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5060),
    [sym_typeof_expression] = STATE(5060),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3797),
    [sym_literal] = STATE(5060),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(200),
    [sym_preproc_endregion] = STATE(200),
    [sym_preproc_line] = STATE(200),
    [sym_preproc_pragma] = STATE(200),
    [sym_preproc_nullable] = STATE(200),
    [sym_preproc_error] = STATE(200),
    [sym_preproc_warning] = STATE(200),
    [sym_preproc_define] = STATE(200),
    [sym_preproc_undef] = STATE(200),
    [aux_sym_class_declaration_repeat1] = STATE(3574),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4311),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1231),
    [anon_sym_RPAREN] = ACTIONS(1233),
    [anon_sym_ref] = ACTIONS(1109),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_LT] = ACTIONS(1077),
    [anon_sym_GT] = ACTIONS(1077),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1117),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(1121),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_AMP] = ACTIONS(1117),
    [anon_sym_GT_EQ] = ACTIONS(1087),
    [anon_sym_LT_EQ] = ACTIONS(1087),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1091),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1129),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1131),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(1135),
    [anon_sym_not] = ACTIONS(1137),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [201] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8790),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2798),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(5987),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8977),
    [sym_pattern] = STATE(8296),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6158),
    [sym_property_pattern_clause] = STATE(6724),
    [sym_subpattern] = STATE(8710),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6179),
    [sym_non_lvalue_expression] = STATE(6534),
    [sym_lvalue_expression] = STATE(4340),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5060),
    [sym_postfix_unary_expression] = STATE(5061),
    [sym_prefix_unary_expression] = STATE(5061),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5060),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5061),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5060),
    [sym_member_access_expression] = STATE(3797),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5061),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9065),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(5060),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5060),
    [sym_typeof_expression] = STATE(5060),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3797),
    [sym_literal] = STATE(5060),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(201),
    [sym_preproc_endregion] = STATE(201),
    [sym_preproc_line] = STATE(201),
    [sym_preproc_pragma] = STATE(201),
    [sym_preproc_nullable] = STATE(201),
    [sym_preproc_error] = STATE(201),
    [sym_preproc_warning] = STATE(201),
    [sym_preproc_define] = STATE(201),
    [sym_preproc_undef] = STATE(201),
    [aux_sym_class_declaration_repeat1] = STATE(3574),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4311),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1231),
    [anon_sym_RPAREN] = ACTIONS(1237),
    [anon_sym_ref] = ACTIONS(1109),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_LT] = ACTIONS(1077),
    [anon_sym_GT] = ACTIONS(1077),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1117),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(1121),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_AMP] = ACTIONS(1117),
    [anon_sym_GT_EQ] = ACTIONS(1087),
    [anon_sym_LT_EQ] = ACTIONS(1087),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1091),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1129),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1131),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(1135),
    [anon_sym_not] = ACTIONS(1137),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [202] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8776),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2798),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(5875),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8812),
    [sym_pattern] = STATE(8327),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6158),
    [sym_property_pattern_clause] = STATE(6724),
    [sym_subpattern] = STATE(8851),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6179),
    [sym_non_lvalue_expression] = STATE(6500),
    [sym_lvalue_expression] = STATE(4340),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5060),
    [sym_postfix_unary_expression] = STATE(5061),
    [sym_prefix_unary_expression] = STATE(5061),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5060),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5061),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5060),
    [sym_member_access_expression] = STATE(3797),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5061),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9065),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(5060),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5060),
    [sym_typeof_expression] = STATE(5060),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3797),
    [sym_literal] = STATE(5060),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(202),
    [sym_preproc_endregion] = STATE(202),
    [sym_preproc_line] = STATE(202),
    [sym_preproc_pragma] = STATE(202),
    [sym_preproc_nullable] = STATE(202),
    [sym_preproc_error] = STATE(202),
    [sym_preproc_warning] = STATE(202),
    [sym_preproc_define] = STATE(202),
    [sym_preproc_undef] = STATE(202),
    [aux_sym_class_declaration_repeat1] = STATE(3574),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4311),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1231),
    [anon_sym_RPAREN] = ACTIONS(1235),
    [anon_sym_ref] = ACTIONS(1109),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_LT] = ACTIONS(1077),
    [anon_sym_GT] = ACTIONS(1077),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1117),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(1121),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_AMP] = ACTIONS(1117),
    [anon_sym_GT_EQ] = ACTIONS(1087),
    [anon_sym_LT_EQ] = ACTIONS(1087),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1091),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1129),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1131),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(1135),
    [anon_sym_not] = ACTIONS(1137),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [203] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8982),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2798),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(5900),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8759),
    [sym_pattern] = STATE(8282),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6158),
    [sym_property_pattern_clause] = STATE(6724),
    [sym_subpattern] = STATE(8710),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6179),
    [sym_non_lvalue_expression] = STATE(6390),
    [sym_lvalue_expression] = STATE(4340),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5060),
    [sym_postfix_unary_expression] = STATE(5061),
    [sym_prefix_unary_expression] = STATE(5061),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5060),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5061),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5060),
    [sym_member_access_expression] = STATE(3797),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5061),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9065),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(5060),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5060),
    [sym_typeof_expression] = STATE(5060),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3797),
    [sym_literal] = STATE(5060),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(203),
    [sym_preproc_endregion] = STATE(203),
    [sym_preproc_line] = STATE(203),
    [sym_preproc_pragma] = STATE(203),
    [sym_preproc_nullable] = STATE(203),
    [sym_preproc_error] = STATE(203),
    [sym_preproc_warning] = STATE(203),
    [sym_preproc_define] = STATE(203),
    [sym_preproc_undef] = STATE(203),
    [aux_sym_class_declaration_repeat1] = STATE(3574),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4311),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1231),
    [anon_sym_RPAREN] = ACTIONS(1237),
    [anon_sym_ref] = ACTIONS(1109),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_LT] = ACTIONS(1077),
    [anon_sym_GT] = ACTIONS(1077),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1117),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(1121),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_AMP] = ACTIONS(1117),
    [anon_sym_GT_EQ] = ACTIONS(1087),
    [anon_sym_LT_EQ] = ACTIONS(1087),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1091),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1129),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1131),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(1135),
    [anon_sym_not] = ACTIONS(1137),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [204] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8982),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2798),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(5903),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8759),
    [sym_pattern] = STATE(8282),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6158),
    [sym_property_pattern_clause] = STATE(6724),
    [sym_subpattern] = STATE(8710),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6179),
    [sym_non_lvalue_expression] = STATE(6390),
    [sym_lvalue_expression] = STATE(4340),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5060),
    [sym_postfix_unary_expression] = STATE(5061),
    [sym_prefix_unary_expression] = STATE(5061),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5060),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5061),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5060),
    [sym_member_access_expression] = STATE(3797),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5061),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9065),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(5060),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5060),
    [sym_typeof_expression] = STATE(5060),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3797),
    [sym_literal] = STATE(5060),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(204),
    [sym_preproc_endregion] = STATE(204),
    [sym_preproc_line] = STATE(204),
    [sym_preproc_pragma] = STATE(204),
    [sym_preproc_nullable] = STATE(204),
    [sym_preproc_error] = STATE(204),
    [sym_preproc_warning] = STATE(204),
    [sym_preproc_define] = STATE(204),
    [sym_preproc_undef] = STATE(204),
    [aux_sym_class_declaration_repeat1] = STATE(3574),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4311),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1231),
    [anon_sym_RPAREN] = ACTIONS(1233),
    [anon_sym_ref] = ACTIONS(1109),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_LT] = ACTIONS(1077),
    [anon_sym_GT] = ACTIONS(1077),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1117),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(1121),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_AMP] = ACTIONS(1117),
    [anon_sym_GT_EQ] = ACTIONS(1087),
    [anon_sym_LT_EQ] = ACTIONS(1087),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1091),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1129),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1131),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(1135),
    [anon_sym_not] = ACTIONS(1137),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [205] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8790),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2798),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6034),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8759),
    [sym_pattern] = STATE(8296),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6158),
    [sym_property_pattern_clause] = STATE(6724),
    [sym_subpattern] = STATE(8710),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6179),
    [sym_non_lvalue_expression] = STATE(6534),
    [sym_lvalue_expression] = STATE(4340),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5060),
    [sym_postfix_unary_expression] = STATE(5061),
    [sym_prefix_unary_expression] = STATE(5061),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5060),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5061),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5060),
    [sym_member_access_expression] = STATE(3797),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5061),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9065),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(5060),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5060),
    [sym_typeof_expression] = STATE(5060),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3797),
    [sym_literal] = STATE(5060),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(205),
    [sym_preproc_endregion] = STATE(205),
    [sym_preproc_line] = STATE(205),
    [sym_preproc_pragma] = STATE(205),
    [sym_preproc_nullable] = STATE(205),
    [sym_preproc_error] = STATE(205),
    [sym_preproc_warning] = STATE(205),
    [sym_preproc_define] = STATE(205),
    [sym_preproc_undef] = STATE(205),
    [aux_sym_class_declaration_repeat1] = STATE(3574),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4311),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1231),
    [anon_sym_RPAREN] = ACTIONS(1233),
    [anon_sym_ref] = ACTIONS(1109),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_LT] = ACTIONS(1077),
    [anon_sym_GT] = ACTIONS(1077),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1117),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(1121),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_AMP] = ACTIONS(1117),
    [anon_sym_GT_EQ] = ACTIONS(1087),
    [anon_sym_LT_EQ] = ACTIONS(1087),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1091),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1129),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1131),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(1135),
    [anon_sym_not] = ACTIONS(1137),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [206] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8982),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2798),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(5909),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8759),
    [sym_pattern] = STATE(8282),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6158),
    [sym_property_pattern_clause] = STATE(6724),
    [sym_subpattern] = STATE(8710),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6179),
    [sym_non_lvalue_expression] = STATE(6390),
    [sym_lvalue_expression] = STATE(4340),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5060),
    [sym_postfix_unary_expression] = STATE(5061),
    [sym_prefix_unary_expression] = STATE(5061),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5060),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5061),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5060),
    [sym_member_access_expression] = STATE(3797),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5061),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9065),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(5060),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5060),
    [sym_typeof_expression] = STATE(5060),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3797),
    [sym_literal] = STATE(5060),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(206),
    [sym_preproc_endregion] = STATE(206),
    [sym_preproc_line] = STATE(206),
    [sym_preproc_pragma] = STATE(206),
    [sym_preproc_nullable] = STATE(206),
    [sym_preproc_error] = STATE(206),
    [sym_preproc_warning] = STATE(206),
    [sym_preproc_define] = STATE(206),
    [sym_preproc_undef] = STATE(206),
    [aux_sym_class_declaration_repeat1] = STATE(3574),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4311),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1231),
    [anon_sym_RPAREN] = ACTIONS(1233),
    [anon_sym_ref] = ACTIONS(1109),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_LT] = ACTIONS(1077),
    [anon_sym_GT] = ACTIONS(1077),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1117),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(1121),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_AMP] = ACTIONS(1117),
    [anon_sym_GT_EQ] = ACTIONS(1087),
    [anon_sym_LT_EQ] = ACTIONS(1087),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1091),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1129),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1131),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(1135),
    [anon_sym_not] = ACTIONS(1137),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [207] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8982),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2798),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(5911),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8759),
    [sym_pattern] = STATE(8282),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6158),
    [sym_property_pattern_clause] = STATE(6724),
    [sym_subpattern] = STATE(8710),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6179),
    [sym_non_lvalue_expression] = STATE(6390),
    [sym_lvalue_expression] = STATE(4340),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5060),
    [sym_postfix_unary_expression] = STATE(5061),
    [sym_prefix_unary_expression] = STATE(5061),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5060),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5061),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5060),
    [sym_member_access_expression] = STATE(3797),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5061),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9065),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(5060),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5060),
    [sym_typeof_expression] = STATE(5060),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3797),
    [sym_literal] = STATE(5060),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(207),
    [sym_preproc_endregion] = STATE(207),
    [sym_preproc_line] = STATE(207),
    [sym_preproc_pragma] = STATE(207),
    [sym_preproc_nullable] = STATE(207),
    [sym_preproc_error] = STATE(207),
    [sym_preproc_warning] = STATE(207),
    [sym_preproc_define] = STATE(207),
    [sym_preproc_undef] = STATE(207),
    [aux_sym_class_declaration_repeat1] = STATE(3574),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4311),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1231),
    [anon_sym_RPAREN] = ACTIONS(1237),
    [anon_sym_ref] = ACTIONS(1109),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_LT] = ACTIONS(1077),
    [anon_sym_GT] = ACTIONS(1077),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1117),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(1121),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_AMP] = ACTIONS(1117),
    [anon_sym_GT_EQ] = ACTIONS(1087),
    [anon_sym_LT_EQ] = ACTIONS(1087),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1091),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1129),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1131),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(1135),
    [anon_sym_not] = ACTIONS(1137),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [208] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8790),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2798),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(5934),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8977),
    [sym_pattern] = STATE(8296),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6158),
    [sym_property_pattern_clause] = STATE(6724),
    [sym_subpattern] = STATE(8710),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6179),
    [sym_non_lvalue_expression] = STATE(6534),
    [sym_lvalue_expression] = STATE(4340),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5060),
    [sym_postfix_unary_expression] = STATE(5061),
    [sym_prefix_unary_expression] = STATE(5061),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5060),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5061),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5060),
    [sym_member_access_expression] = STATE(3797),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5061),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9065),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(5060),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5060),
    [sym_typeof_expression] = STATE(5060),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3797),
    [sym_literal] = STATE(5060),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(208),
    [sym_preproc_endregion] = STATE(208),
    [sym_preproc_line] = STATE(208),
    [sym_preproc_pragma] = STATE(208),
    [sym_preproc_nullable] = STATE(208),
    [sym_preproc_error] = STATE(208),
    [sym_preproc_warning] = STATE(208),
    [sym_preproc_define] = STATE(208),
    [sym_preproc_undef] = STATE(208),
    [aux_sym_class_declaration_repeat1] = STATE(3574),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4311),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1231),
    [anon_sym_RPAREN] = ACTIONS(1233),
    [anon_sym_ref] = ACTIONS(1109),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_LT] = ACTIONS(1077),
    [anon_sym_GT] = ACTIONS(1077),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1117),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(1121),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_AMP] = ACTIONS(1117),
    [anon_sym_GT_EQ] = ACTIONS(1087),
    [anon_sym_LT_EQ] = ACTIONS(1087),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1091),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1129),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1131),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(1135),
    [anon_sym_not] = ACTIONS(1137),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [209] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8790),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2798),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(5987),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8759),
    [sym_pattern] = STATE(8296),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6158),
    [sym_property_pattern_clause] = STATE(6724),
    [sym_subpattern] = STATE(8710),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6179),
    [sym_non_lvalue_expression] = STATE(6534),
    [sym_lvalue_expression] = STATE(4340),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5060),
    [sym_postfix_unary_expression] = STATE(5061),
    [sym_prefix_unary_expression] = STATE(5061),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5060),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5061),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5060),
    [sym_member_access_expression] = STATE(3797),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5061),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9065),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(5060),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5060),
    [sym_typeof_expression] = STATE(5060),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3797),
    [sym_literal] = STATE(5060),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(209),
    [sym_preproc_endregion] = STATE(209),
    [sym_preproc_line] = STATE(209),
    [sym_preproc_pragma] = STATE(209),
    [sym_preproc_nullable] = STATE(209),
    [sym_preproc_error] = STATE(209),
    [sym_preproc_warning] = STATE(209),
    [sym_preproc_define] = STATE(209),
    [sym_preproc_undef] = STATE(209),
    [aux_sym_class_declaration_repeat1] = STATE(3574),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4311),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1231),
    [anon_sym_RPAREN] = ACTIONS(1237),
    [anon_sym_ref] = ACTIONS(1109),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_LT] = ACTIONS(1077),
    [anon_sym_GT] = ACTIONS(1077),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1117),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(1121),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_AMP] = ACTIONS(1117),
    [anon_sym_GT_EQ] = ACTIONS(1087),
    [anon_sym_LT_EQ] = ACTIONS(1087),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1091),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1129),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1131),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(1135),
    [anon_sym_not] = ACTIONS(1137),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [210] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8754),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2798),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6106),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8759),
    [sym_pattern] = STATE(8372),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6158),
    [sym_property_pattern_clause] = STATE(6724),
    [sym_subpattern] = STATE(8710),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6179),
    [sym_non_lvalue_expression] = STATE(6583),
    [sym_lvalue_expression] = STATE(4340),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5060),
    [sym_postfix_unary_expression] = STATE(5061),
    [sym_prefix_unary_expression] = STATE(5061),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5060),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5061),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5060),
    [sym_member_access_expression] = STATE(3797),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5061),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9065),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(5060),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5060),
    [sym_typeof_expression] = STATE(5060),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3797),
    [sym_literal] = STATE(5060),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(210),
    [sym_preproc_endregion] = STATE(210),
    [sym_preproc_line] = STATE(210),
    [sym_preproc_pragma] = STATE(210),
    [sym_preproc_nullable] = STATE(210),
    [sym_preproc_error] = STATE(210),
    [sym_preproc_warning] = STATE(210),
    [sym_preproc_define] = STATE(210),
    [sym_preproc_undef] = STATE(210),
    [aux_sym_class_declaration_repeat1] = STATE(3574),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4311),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1231),
    [anon_sym_RPAREN] = ACTIONS(1233),
    [anon_sym_ref] = ACTIONS(1109),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_LT] = ACTIONS(1077),
    [anon_sym_GT] = ACTIONS(1077),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1117),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(1121),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_AMP] = ACTIONS(1117),
    [anon_sym_GT_EQ] = ACTIONS(1087),
    [anon_sym_LT_EQ] = ACTIONS(1087),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1091),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1129),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1131),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(1135),
    [anon_sym_not] = ACTIONS(1137),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [211] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8790),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2798),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(5934),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8759),
    [sym_pattern] = STATE(8296),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6158),
    [sym_property_pattern_clause] = STATE(6724),
    [sym_subpattern] = STATE(8710),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6179),
    [sym_non_lvalue_expression] = STATE(6534),
    [sym_lvalue_expression] = STATE(4340),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5060),
    [sym_postfix_unary_expression] = STATE(5061),
    [sym_prefix_unary_expression] = STATE(5061),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5060),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5061),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5060),
    [sym_member_access_expression] = STATE(3797),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5061),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9065),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(5060),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5060),
    [sym_typeof_expression] = STATE(5060),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3797),
    [sym_literal] = STATE(5060),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(211),
    [sym_preproc_endregion] = STATE(211),
    [sym_preproc_line] = STATE(211),
    [sym_preproc_pragma] = STATE(211),
    [sym_preproc_nullable] = STATE(211),
    [sym_preproc_error] = STATE(211),
    [sym_preproc_warning] = STATE(211),
    [sym_preproc_define] = STATE(211),
    [sym_preproc_undef] = STATE(211),
    [aux_sym_class_declaration_repeat1] = STATE(3574),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4311),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1231),
    [anon_sym_RPAREN] = ACTIONS(1233),
    [anon_sym_ref] = ACTIONS(1109),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_LT] = ACTIONS(1077),
    [anon_sym_GT] = ACTIONS(1077),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1117),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(1121),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_AMP] = ACTIONS(1117),
    [anon_sym_GT_EQ] = ACTIONS(1087),
    [anon_sym_LT_EQ] = ACTIONS(1087),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1091),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1129),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1131),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(1135),
    [anon_sym_not] = ACTIONS(1137),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [212] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8790),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2798),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6003),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8977),
    [sym_pattern] = STATE(8296),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6158),
    [sym_property_pattern_clause] = STATE(6724),
    [sym_subpattern] = STATE(8710),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6179),
    [sym_non_lvalue_expression] = STATE(6534),
    [sym_lvalue_expression] = STATE(4340),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5060),
    [sym_postfix_unary_expression] = STATE(5061),
    [sym_prefix_unary_expression] = STATE(5061),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5060),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5061),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5060),
    [sym_member_access_expression] = STATE(3797),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5061),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9065),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(5060),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5060),
    [sym_typeof_expression] = STATE(5060),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3797),
    [sym_literal] = STATE(5060),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(212),
    [sym_preproc_endregion] = STATE(212),
    [sym_preproc_line] = STATE(212),
    [sym_preproc_pragma] = STATE(212),
    [sym_preproc_nullable] = STATE(212),
    [sym_preproc_error] = STATE(212),
    [sym_preproc_warning] = STATE(212),
    [sym_preproc_define] = STATE(212),
    [sym_preproc_undef] = STATE(212),
    [aux_sym_class_declaration_repeat1] = STATE(3574),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4311),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1231),
    [anon_sym_RPAREN] = ACTIONS(1233),
    [anon_sym_ref] = ACTIONS(1109),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_LT] = ACTIONS(1077),
    [anon_sym_GT] = ACTIONS(1077),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1117),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(1121),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_AMP] = ACTIONS(1117),
    [anon_sym_GT_EQ] = ACTIONS(1087),
    [anon_sym_LT_EQ] = ACTIONS(1087),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1091),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1129),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1131),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(1135),
    [anon_sym_not] = ACTIONS(1137),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [213] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8790),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2798),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6059),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8759),
    [sym_pattern] = STATE(8296),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6158),
    [sym_property_pattern_clause] = STATE(6724),
    [sym_subpattern] = STATE(8710),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6179),
    [sym_non_lvalue_expression] = STATE(6534),
    [sym_lvalue_expression] = STATE(4340),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5060),
    [sym_postfix_unary_expression] = STATE(5061),
    [sym_prefix_unary_expression] = STATE(5061),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5060),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5061),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5060),
    [sym_member_access_expression] = STATE(3797),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5061),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9065),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(5060),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5060),
    [sym_typeof_expression] = STATE(5060),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3797),
    [sym_literal] = STATE(5060),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(213),
    [sym_preproc_endregion] = STATE(213),
    [sym_preproc_line] = STATE(213),
    [sym_preproc_pragma] = STATE(213),
    [sym_preproc_nullable] = STATE(213),
    [sym_preproc_error] = STATE(213),
    [sym_preproc_warning] = STATE(213),
    [sym_preproc_define] = STATE(213),
    [sym_preproc_undef] = STATE(213),
    [aux_sym_class_declaration_repeat1] = STATE(3574),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4311),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1231),
    [anon_sym_RPAREN] = ACTIONS(1237),
    [anon_sym_ref] = ACTIONS(1109),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_LT] = ACTIONS(1077),
    [anon_sym_GT] = ACTIONS(1077),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1117),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(1121),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_AMP] = ACTIONS(1117),
    [anon_sym_GT_EQ] = ACTIONS(1087),
    [anon_sym_LT_EQ] = ACTIONS(1087),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1091),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1129),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1131),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(1135),
    [anon_sym_not] = ACTIONS(1137),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [214] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8790),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2798),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6037),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8759),
    [sym_pattern] = STATE(8296),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6158),
    [sym_property_pattern_clause] = STATE(6724),
    [sym_subpattern] = STATE(8710),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6179),
    [sym_non_lvalue_expression] = STATE(6534),
    [sym_lvalue_expression] = STATE(4340),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5060),
    [sym_postfix_unary_expression] = STATE(5061),
    [sym_prefix_unary_expression] = STATE(5061),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5060),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5061),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5060),
    [sym_member_access_expression] = STATE(3797),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5061),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9065),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(5060),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5060),
    [sym_typeof_expression] = STATE(5060),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3797),
    [sym_literal] = STATE(5060),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(214),
    [sym_preproc_endregion] = STATE(214),
    [sym_preproc_line] = STATE(214),
    [sym_preproc_pragma] = STATE(214),
    [sym_preproc_nullable] = STATE(214),
    [sym_preproc_error] = STATE(214),
    [sym_preproc_warning] = STATE(214),
    [sym_preproc_define] = STATE(214),
    [sym_preproc_undef] = STATE(214),
    [aux_sym_class_declaration_repeat1] = STATE(3574),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4311),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1231),
    [anon_sym_RPAREN] = ACTIONS(1233),
    [anon_sym_ref] = ACTIONS(1109),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_LT] = ACTIONS(1077),
    [anon_sym_GT] = ACTIONS(1077),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1117),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(1121),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_AMP] = ACTIONS(1117),
    [anon_sym_GT_EQ] = ACTIONS(1087),
    [anon_sym_LT_EQ] = ACTIONS(1087),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1091),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1129),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1131),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(1135),
    [anon_sym_not] = ACTIONS(1137),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [215] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8790),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2798),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6024),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8977),
    [sym_pattern] = STATE(8296),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6158),
    [sym_property_pattern_clause] = STATE(6724),
    [sym_subpattern] = STATE(8710),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6179),
    [sym_non_lvalue_expression] = STATE(6534),
    [sym_lvalue_expression] = STATE(4340),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5060),
    [sym_postfix_unary_expression] = STATE(5061),
    [sym_prefix_unary_expression] = STATE(5061),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5060),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5061),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5060),
    [sym_member_access_expression] = STATE(3797),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5061),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9065),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(5060),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5060),
    [sym_typeof_expression] = STATE(5060),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3797),
    [sym_literal] = STATE(5060),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(215),
    [sym_preproc_endregion] = STATE(215),
    [sym_preproc_line] = STATE(215),
    [sym_preproc_pragma] = STATE(215),
    [sym_preproc_nullable] = STATE(215),
    [sym_preproc_error] = STATE(215),
    [sym_preproc_warning] = STATE(215),
    [sym_preproc_define] = STATE(215),
    [sym_preproc_undef] = STATE(215),
    [aux_sym_class_declaration_repeat1] = STATE(3574),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4311),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1231),
    [anon_sym_RPAREN] = ACTIONS(1233),
    [anon_sym_ref] = ACTIONS(1109),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_LT] = ACTIONS(1077),
    [anon_sym_GT] = ACTIONS(1077),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1117),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(1121),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_AMP] = ACTIONS(1117),
    [anon_sym_GT_EQ] = ACTIONS(1087),
    [anon_sym_LT_EQ] = ACTIONS(1087),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1091),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1129),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1131),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(1135),
    [anon_sym_not] = ACTIONS(1137),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [216] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8790),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2798),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6046),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8759),
    [sym_pattern] = STATE(8296),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6158),
    [sym_property_pattern_clause] = STATE(6724),
    [sym_subpattern] = STATE(8710),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6179),
    [sym_non_lvalue_expression] = STATE(6534),
    [sym_lvalue_expression] = STATE(4340),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5060),
    [sym_postfix_unary_expression] = STATE(5061),
    [sym_prefix_unary_expression] = STATE(5061),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5060),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5061),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5060),
    [sym_member_access_expression] = STATE(3797),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5061),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9065),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(5060),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5060),
    [sym_typeof_expression] = STATE(5060),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3797),
    [sym_literal] = STATE(5060),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(216),
    [sym_preproc_endregion] = STATE(216),
    [sym_preproc_line] = STATE(216),
    [sym_preproc_pragma] = STATE(216),
    [sym_preproc_nullable] = STATE(216),
    [sym_preproc_error] = STATE(216),
    [sym_preproc_warning] = STATE(216),
    [sym_preproc_define] = STATE(216),
    [sym_preproc_undef] = STATE(216),
    [aux_sym_class_declaration_repeat1] = STATE(3574),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4311),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1231),
    [anon_sym_RPAREN] = ACTIONS(1233),
    [anon_sym_ref] = ACTIONS(1109),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_LT] = ACTIONS(1077),
    [anon_sym_GT] = ACTIONS(1077),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1117),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(1121),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_AMP] = ACTIONS(1117),
    [anon_sym_GT_EQ] = ACTIONS(1087),
    [anon_sym_LT_EQ] = ACTIONS(1087),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1091),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1129),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1131),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(1135),
    [anon_sym_not] = ACTIONS(1137),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [217] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8790),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2798),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6003),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8759),
    [sym_pattern] = STATE(8296),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6158),
    [sym_property_pattern_clause] = STATE(6724),
    [sym_subpattern] = STATE(8710),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6179),
    [sym_non_lvalue_expression] = STATE(6534),
    [sym_lvalue_expression] = STATE(4340),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5060),
    [sym_postfix_unary_expression] = STATE(5061),
    [sym_prefix_unary_expression] = STATE(5061),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5060),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5061),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5060),
    [sym_member_access_expression] = STATE(3797),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5061),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9065),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(5060),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5060),
    [sym_typeof_expression] = STATE(5060),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3797),
    [sym_literal] = STATE(5060),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(217),
    [sym_preproc_endregion] = STATE(217),
    [sym_preproc_line] = STATE(217),
    [sym_preproc_pragma] = STATE(217),
    [sym_preproc_nullable] = STATE(217),
    [sym_preproc_error] = STATE(217),
    [sym_preproc_warning] = STATE(217),
    [sym_preproc_define] = STATE(217),
    [sym_preproc_undef] = STATE(217),
    [aux_sym_class_declaration_repeat1] = STATE(3574),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4311),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1231),
    [anon_sym_RPAREN] = ACTIONS(1233),
    [anon_sym_ref] = ACTIONS(1109),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_LT] = ACTIONS(1077),
    [anon_sym_GT] = ACTIONS(1077),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1117),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(1121),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_AMP] = ACTIONS(1117),
    [anon_sym_GT_EQ] = ACTIONS(1087),
    [anon_sym_LT_EQ] = ACTIONS(1087),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1091),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1129),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1131),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(1135),
    [anon_sym_not] = ACTIONS(1137),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [218] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8790),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2798),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6052),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8759),
    [sym_pattern] = STATE(8296),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6158),
    [sym_property_pattern_clause] = STATE(6724),
    [sym_subpattern] = STATE(8710),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6179),
    [sym_non_lvalue_expression] = STATE(6534),
    [sym_lvalue_expression] = STATE(4340),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5060),
    [sym_postfix_unary_expression] = STATE(5061),
    [sym_prefix_unary_expression] = STATE(5061),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5060),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5061),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5060),
    [sym_member_access_expression] = STATE(3797),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5061),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9065),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(5060),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5060),
    [sym_typeof_expression] = STATE(5060),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3797),
    [sym_literal] = STATE(5060),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(218),
    [sym_preproc_endregion] = STATE(218),
    [sym_preproc_line] = STATE(218),
    [sym_preproc_pragma] = STATE(218),
    [sym_preproc_nullable] = STATE(218),
    [sym_preproc_error] = STATE(218),
    [sym_preproc_warning] = STATE(218),
    [sym_preproc_define] = STATE(218),
    [sym_preproc_undef] = STATE(218),
    [aux_sym_class_declaration_repeat1] = STATE(3574),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4311),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1231),
    [anon_sym_RPAREN] = ACTIONS(1233),
    [anon_sym_ref] = ACTIONS(1109),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_LT] = ACTIONS(1077),
    [anon_sym_GT] = ACTIONS(1077),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1117),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(1121),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_AMP] = ACTIONS(1117),
    [anon_sym_GT_EQ] = ACTIONS(1087),
    [anon_sym_LT_EQ] = ACTIONS(1087),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1091),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1129),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1131),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(1135),
    [anon_sym_not] = ACTIONS(1137),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [219] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8790),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2798),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6055),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8759),
    [sym_pattern] = STATE(8296),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6158),
    [sym_property_pattern_clause] = STATE(6724),
    [sym_subpattern] = STATE(8710),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6179),
    [sym_non_lvalue_expression] = STATE(6534),
    [sym_lvalue_expression] = STATE(4340),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5060),
    [sym_postfix_unary_expression] = STATE(5061),
    [sym_prefix_unary_expression] = STATE(5061),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5060),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5061),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5060),
    [sym_member_access_expression] = STATE(3797),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5061),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9065),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(5060),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5060),
    [sym_typeof_expression] = STATE(5060),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3797),
    [sym_literal] = STATE(5060),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(219),
    [sym_preproc_endregion] = STATE(219),
    [sym_preproc_line] = STATE(219),
    [sym_preproc_pragma] = STATE(219),
    [sym_preproc_nullable] = STATE(219),
    [sym_preproc_error] = STATE(219),
    [sym_preproc_warning] = STATE(219),
    [sym_preproc_define] = STATE(219),
    [sym_preproc_undef] = STATE(219),
    [aux_sym_class_declaration_repeat1] = STATE(3574),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4311),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1231),
    [anon_sym_RPAREN] = ACTIONS(1233),
    [anon_sym_ref] = ACTIONS(1109),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_LT] = ACTIONS(1077),
    [anon_sym_GT] = ACTIONS(1077),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1117),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(1121),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_AMP] = ACTIONS(1117),
    [anon_sym_GT_EQ] = ACTIONS(1087),
    [anon_sym_LT_EQ] = ACTIONS(1087),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1091),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1129),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1131),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(1135),
    [anon_sym_not] = ACTIONS(1137),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [220] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8790),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2798),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6024),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8759),
    [sym_pattern] = STATE(8296),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6158),
    [sym_property_pattern_clause] = STATE(6724),
    [sym_subpattern] = STATE(8710),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6179),
    [sym_non_lvalue_expression] = STATE(6534),
    [sym_lvalue_expression] = STATE(4340),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5060),
    [sym_postfix_unary_expression] = STATE(5061),
    [sym_prefix_unary_expression] = STATE(5061),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5060),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5061),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5060),
    [sym_member_access_expression] = STATE(3797),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5061),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9065),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(5060),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5060),
    [sym_typeof_expression] = STATE(5060),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3797),
    [sym_literal] = STATE(5060),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(220),
    [sym_preproc_endregion] = STATE(220),
    [sym_preproc_line] = STATE(220),
    [sym_preproc_pragma] = STATE(220),
    [sym_preproc_nullable] = STATE(220),
    [sym_preproc_error] = STATE(220),
    [sym_preproc_warning] = STATE(220),
    [sym_preproc_define] = STATE(220),
    [sym_preproc_undef] = STATE(220),
    [aux_sym_class_declaration_repeat1] = STATE(3574),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4311),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1231),
    [anon_sym_RPAREN] = ACTIONS(1233),
    [anon_sym_ref] = ACTIONS(1109),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_LT] = ACTIONS(1077),
    [anon_sym_GT] = ACTIONS(1077),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1117),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(1121),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_AMP] = ACTIONS(1117),
    [anon_sym_GT_EQ] = ACTIONS(1087),
    [anon_sym_LT_EQ] = ACTIONS(1087),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1091),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1129),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1131),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(1135),
    [anon_sym_not] = ACTIONS(1137),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [221] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8982),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2798),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(5906),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8759),
    [sym_pattern] = STATE(8282),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6158),
    [sym_property_pattern_clause] = STATE(6724),
    [sym_subpattern] = STATE(8710),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6179),
    [sym_non_lvalue_expression] = STATE(6390),
    [sym_lvalue_expression] = STATE(4340),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5060),
    [sym_postfix_unary_expression] = STATE(5061),
    [sym_prefix_unary_expression] = STATE(5061),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5060),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5061),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5060),
    [sym_member_access_expression] = STATE(3797),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5061),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9065),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(5060),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5060),
    [sym_typeof_expression] = STATE(5060),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3797),
    [sym_literal] = STATE(5060),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(221),
    [sym_preproc_endregion] = STATE(221),
    [sym_preproc_line] = STATE(221),
    [sym_preproc_pragma] = STATE(221),
    [sym_preproc_nullable] = STATE(221),
    [sym_preproc_error] = STATE(221),
    [sym_preproc_warning] = STATE(221),
    [sym_preproc_define] = STATE(221),
    [sym_preproc_undef] = STATE(221),
    [aux_sym_class_declaration_repeat1] = STATE(3574),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4311),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1231),
    [anon_sym_RPAREN] = ACTIONS(1233),
    [anon_sym_ref] = ACTIONS(1109),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_LT] = ACTIONS(1077),
    [anon_sym_GT] = ACTIONS(1077),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1117),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(1121),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_AMP] = ACTIONS(1117),
    [anon_sym_GT_EQ] = ACTIONS(1087),
    [anon_sym_LT_EQ] = ACTIONS(1087),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1091),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1129),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1131),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(1135),
    [anon_sym_not] = ACTIONS(1137),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [222] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6916),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7128),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4943),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3752),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7413),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9092),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(222),
    [sym_preproc_endregion] = STATE(222),
    [sym_preproc_line] = STATE(222),
    [sym_preproc_pragma] = STATE(222),
    [sym_preproc_nullable] = STATE(222),
    [sym_preproc_error] = STATE(222),
    [sym_preproc_warning] = STATE(222),
    [sym_preproc_define] = STATE(222),
    [sym_preproc_undef] = STATE(222),
    [aux_sym_class_declaration_repeat1] = STATE(3845),
    [aux_sym_lambda_expression_repeat1] = STATE(4181),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(1227),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_COMMA] = ACTIONS(1227),
    [anon_sym_RBRACK] = ACTIONS(1227),
    [anon_sym_LPAREN] = ACTIONS(1241),
    [anon_sym_RPAREN] = ACTIONS(1227),
    [anon_sym_ref] = ACTIONS(1243),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_RBRACE] = ACTIONS(1227),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LT] = ACTIONS(1229),
    [anon_sym_GT] = ACTIONS(1229),
    [anon_sym_in] = ACTIONS(1229),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1229),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1253),
    [anon_sym_TILDE] = ACTIONS(1255),
    [anon_sym_PLUS_PLUS] = ACTIONS(1255),
    [anon_sym_DASH_DASH] = ACTIONS(1255),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1253),
    [anon_sym_DASH] = ACTIONS(1253),
    [anon_sym_STAR] = ACTIONS(1259),
    [anon_sym_SLASH] = ACTIONS(1229),
    [anon_sym_PERCENT] = ACTIONS(1227),
    [anon_sym_CARET] = ACTIONS(1255),
    [anon_sym_PIPE] = ACTIONS(1229),
    [anon_sym_AMP] = ACTIONS(1253),
    [anon_sym_LT_LT] = ACTIONS(1227),
    [anon_sym_GT_GT] = ACTIONS(1229),
    [anon_sym_GT_GT_GT] = ACTIONS(1227),
    [anon_sym_EQ_EQ] = ACTIONS(1227),
    [anon_sym_BANG_EQ] = ACTIONS(1227),
    [anon_sym_GT_EQ] = ACTIONS(1227),
    [anon_sym_LT_EQ] = ACTIONS(1227),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_DOT] = ACTIONS(1229),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1229),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1269),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1271),
    [anon_sym_DOT_DOT] = ACTIONS(1273),
    [anon_sym_AMP_AMP] = ACTIONS(1227),
    [anon_sym_PIPE_PIPE] = ACTIONS(1227),
    [anon_sym_QMARK_QMARK] = ACTIONS(1227),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1229),
    [anon_sym_is] = ACTIONS(1229),
    [anon_sym_DASH_GT] = ACTIONS(1227),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_with] = ACTIONS(1229),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_if_token3] = ACTIONS(1227),
    [aux_sym_preproc_else_token1] = ACTIONS(1227),
    [aux_sym_preproc_elif_token1] = ACTIONS(1227),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [223] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6916),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7128),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4751),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3752),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7413),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9092),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(223),
    [sym_preproc_endregion] = STATE(223),
    [sym_preproc_line] = STATE(223),
    [sym_preproc_pragma] = STATE(223),
    [sym_preproc_nullable] = STATE(223),
    [sym_preproc_error] = STATE(223),
    [sym_preproc_warning] = STATE(223),
    [sym_preproc_define] = STATE(223),
    [sym_preproc_undef] = STATE(223),
    [aux_sym_class_declaration_repeat1] = STATE(3845),
    [aux_sym_lambda_expression_repeat1] = STATE(4181),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(1157),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_COMMA] = ACTIONS(1157),
    [anon_sym_RBRACK] = ACTIONS(1157),
    [anon_sym_LPAREN] = ACTIONS(1241),
    [anon_sym_RPAREN] = ACTIONS(1157),
    [anon_sym_ref] = ACTIONS(1243),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_RBRACE] = ACTIONS(1157),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LT] = ACTIONS(1171),
    [anon_sym_GT] = ACTIONS(1171),
    [anon_sym_in] = ACTIONS(1171),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1171),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1253),
    [anon_sym_TILDE] = ACTIONS(1255),
    [anon_sym_PLUS_PLUS] = ACTIONS(1255),
    [anon_sym_DASH_DASH] = ACTIONS(1255),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1253),
    [anon_sym_DASH] = ACTIONS(1253),
    [anon_sym_STAR] = ACTIONS(1259),
    [anon_sym_SLASH] = ACTIONS(1171),
    [anon_sym_PERCENT] = ACTIONS(1157),
    [anon_sym_CARET] = ACTIONS(1255),
    [anon_sym_PIPE] = ACTIONS(1171),
    [anon_sym_AMP] = ACTIONS(1253),
    [anon_sym_LT_LT] = ACTIONS(1157),
    [anon_sym_GT_GT] = ACTIONS(1171),
    [anon_sym_GT_GT_GT] = ACTIONS(1157),
    [anon_sym_EQ_EQ] = ACTIONS(1157),
    [anon_sym_BANG_EQ] = ACTIONS(1157),
    [anon_sym_GT_EQ] = ACTIONS(1157),
    [anon_sym_LT_EQ] = ACTIONS(1157),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_DOT] = ACTIONS(1171),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1171),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1269),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1271),
    [anon_sym_DOT_DOT] = ACTIONS(1273),
    [anon_sym_AMP_AMP] = ACTIONS(1157),
    [anon_sym_PIPE_PIPE] = ACTIONS(1157),
    [anon_sym_QMARK_QMARK] = ACTIONS(1157),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1171),
    [anon_sym_is] = ACTIONS(1171),
    [anon_sym_DASH_GT] = ACTIONS(1157),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_with] = ACTIONS(1171),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_if_token3] = ACTIONS(1157),
    [aux_sym_preproc_else_token1] = ACTIONS(1157),
    [aux_sym_preproc_elif_token1] = ACTIONS(1157),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [224] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2802),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6263),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_pattern] = STATE(8333),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6158),
    [sym_property_pattern_clause] = STATE(6724),
    [sym_subpattern] = STATE(8710),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym__variable_designation] = STATE(8647),
    [sym_parenthesized_variable_designation] = STATE(4153),
    [sym_expression] = STATE(6690),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5302),
    [sym_postfix_unary_expression] = STATE(5343),
    [sym_prefix_unary_expression] = STATE(5343),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5302),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5343),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5302),
    [sym_member_access_expression] = STATE(3862),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5343),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(5302),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5302),
    [sym_typeof_expression] = STATE(5302),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3862),
    [sym_literal] = STATE(5302),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2790),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(224),
    [sym_preproc_endregion] = STATE(224),
    [sym_preproc_line] = STATE(224),
    [sym_preproc_pragma] = STATE(224),
    [sym_preproc_nullable] = STATE(224),
    [sym_preproc_error] = STATE(224),
    [sym_preproc_warning] = STATE(224),
    [sym_preproc_define] = STATE(224),
    [sym_preproc_undef] = STATE(224),
    [aux_sym_class_declaration_repeat1] = STATE(3581),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1305),
    [anon_sym_RPAREN] = ACTIONS(1107),
    [anon_sym_ref] = ACTIONS(1307),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_LT] = ACTIONS(1077),
    [anon_sym_GT] = ACTIONS(1077),
    [anon_sym_in] = ACTIONS(1113),
    [anon_sym_out] = ACTIONS(1113),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1117),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_AMP] = ACTIONS(1117),
    [anon_sym_GT_EQ] = ACTIONS(1087),
    [anon_sym_LT_EQ] = ACTIONS(1087),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1311),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [sym_discard] = ACTIONS(1133),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_not] = ACTIONS(1101),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [225] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2802),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6263),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_pattern] = STATE(8333),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6158),
    [sym_property_pattern_clause] = STATE(6724),
    [sym_subpattern] = STATE(8710),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym__variable_designation] = STATE(8647),
    [sym_parenthesized_variable_designation] = STATE(4153),
    [sym_expression] = STATE(6690),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5302),
    [sym_postfix_unary_expression] = STATE(5343),
    [sym_prefix_unary_expression] = STATE(5343),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5302),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5343),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5302),
    [sym_member_access_expression] = STATE(3862),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5343),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(5302),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5302),
    [sym_typeof_expression] = STATE(5302),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3862),
    [sym_literal] = STATE(5302),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2790),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(225),
    [sym_preproc_endregion] = STATE(225),
    [sym_preproc_line] = STATE(225),
    [sym_preproc_pragma] = STATE(225),
    [sym_preproc_nullable] = STATE(225),
    [sym_preproc_error] = STATE(225),
    [sym_preproc_warning] = STATE(225),
    [sym_preproc_define] = STATE(225),
    [sym_preproc_undef] = STATE(225),
    [aux_sym_class_declaration_repeat1] = STATE(3581),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1305),
    [anon_sym_RPAREN] = ACTIONS(1319),
    [anon_sym_ref] = ACTIONS(1307),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_LT] = ACTIONS(1077),
    [anon_sym_GT] = ACTIONS(1077),
    [anon_sym_in] = ACTIONS(1113),
    [anon_sym_out] = ACTIONS(1113),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1117),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_AMP] = ACTIONS(1117),
    [anon_sym_GT_EQ] = ACTIONS(1087),
    [anon_sym_LT_EQ] = ACTIONS(1087),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1311),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [sym_discard] = ACTIONS(1133),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_not] = ACTIONS(1101),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [226] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6967),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5080),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3813),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9209),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(226),
    [sym_preproc_endregion] = STATE(226),
    [sym_preproc_line] = STATE(226),
    [sym_preproc_pragma] = STATE(226),
    [sym_preproc_nullable] = STATE(226),
    [sym_preproc_error] = STATE(226),
    [sym_preproc_warning] = STATE(226),
    [sym_preproc_define] = STATE(226),
    [sym_preproc_undef] = STATE(226),
    [aux_sym_class_declaration_repeat1] = STATE(3814),
    [aux_sym_lambda_expression_repeat1] = STATE(4209),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(1227),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_COMMA] = ACTIONS(1227),
    [anon_sym_RBRACK] = ACTIONS(1227),
    [anon_sym_LPAREN] = ACTIONS(1323),
    [anon_sym_RPAREN] = ACTIONS(1227),
    [anon_sym_ref] = ACTIONS(1325),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_RBRACE] = ACTIONS(1227),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_LT] = ACTIONS(1229),
    [anon_sym_GT] = ACTIONS(1229),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1229),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1085),
    [anon_sym_TILDE] = ACTIONS(1083),
    [anon_sym_PLUS_PLUS] = ACTIONS(1083),
    [anon_sym_DASH_DASH] = ACTIONS(1083),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1085),
    [anon_sym_DASH] = ACTIONS(1085),
    [anon_sym_STAR] = ACTIONS(1335),
    [anon_sym_SLASH] = ACTIONS(1229),
    [anon_sym_PERCENT] = ACTIONS(1227),
    [anon_sym_CARET] = ACTIONS(1083),
    [anon_sym_PIPE] = ACTIONS(1229),
    [anon_sym_AMP] = ACTIONS(1085),
    [anon_sym_LT_LT] = ACTIONS(1227),
    [anon_sym_GT_GT] = ACTIONS(1229),
    [anon_sym_GT_GT_GT] = ACTIONS(1227),
    [anon_sym_EQ_EQ] = ACTIONS(1227),
    [anon_sym_BANG_EQ] = ACTIONS(1227),
    [anon_sym_GT_EQ] = ACTIONS(1227),
    [anon_sym_LT_EQ] = ACTIONS(1227),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_DOT] = ACTIONS(1229),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1229),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1341),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1343),
    [anon_sym_DOT_DOT] = ACTIONS(1345),
    [anon_sym_and] = ACTIONS(1229),
    [anon_sym_or] = ACTIONS(1229),
    [anon_sym_AMP_AMP] = ACTIONS(1227),
    [anon_sym_PIPE_PIPE] = ACTIONS(1227),
    [anon_sym_QMARK_QMARK] = ACTIONS(1227),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1229),
    [anon_sym_is] = ACTIONS(1229),
    [anon_sym_DASH_GT] = ACTIONS(1227),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_with] = ACTIONS(1229),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [227] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6967),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5097),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3813),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9209),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(227),
    [sym_preproc_endregion] = STATE(227),
    [sym_preproc_line] = STATE(227),
    [sym_preproc_pragma] = STATE(227),
    [sym_preproc_nullable] = STATE(227),
    [sym_preproc_error] = STATE(227),
    [sym_preproc_warning] = STATE(227),
    [sym_preproc_define] = STATE(227),
    [sym_preproc_undef] = STATE(227),
    [aux_sym_class_declaration_repeat1] = STATE(3814),
    [aux_sym_lambda_expression_repeat1] = STATE(4209),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(1157),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_COMMA] = ACTIONS(1157),
    [anon_sym_RBRACK] = ACTIONS(1157),
    [anon_sym_LPAREN] = ACTIONS(1323),
    [anon_sym_RPAREN] = ACTIONS(1157),
    [anon_sym_ref] = ACTIONS(1325),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_RBRACE] = ACTIONS(1157),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_LT] = ACTIONS(1171),
    [anon_sym_GT] = ACTIONS(1171),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1171),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1085),
    [anon_sym_TILDE] = ACTIONS(1083),
    [anon_sym_PLUS_PLUS] = ACTIONS(1083),
    [anon_sym_DASH_DASH] = ACTIONS(1083),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1085),
    [anon_sym_DASH] = ACTIONS(1085),
    [anon_sym_STAR] = ACTIONS(1335),
    [anon_sym_SLASH] = ACTIONS(1171),
    [anon_sym_PERCENT] = ACTIONS(1157),
    [anon_sym_CARET] = ACTIONS(1083),
    [anon_sym_PIPE] = ACTIONS(1171),
    [anon_sym_AMP] = ACTIONS(1085),
    [anon_sym_LT_LT] = ACTIONS(1157),
    [anon_sym_GT_GT] = ACTIONS(1171),
    [anon_sym_GT_GT_GT] = ACTIONS(1157),
    [anon_sym_EQ_EQ] = ACTIONS(1157),
    [anon_sym_BANG_EQ] = ACTIONS(1157),
    [anon_sym_GT_EQ] = ACTIONS(1157),
    [anon_sym_LT_EQ] = ACTIONS(1157),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_DOT] = ACTIONS(1171),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1171),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1341),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1343),
    [anon_sym_DOT_DOT] = ACTIONS(1345),
    [anon_sym_and] = ACTIONS(1171),
    [anon_sym_or] = ACTIONS(1171),
    [anon_sym_AMP_AMP] = ACTIONS(1157),
    [anon_sym_PIPE_PIPE] = ACTIONS(1157),
    [anon_sym_QMARK_QMARK] = ACTIONS(1157),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1171),
    [anon_sym_is] = ACTIONS(1171),
    [anon_sym_DASH_GT] = ACTIONS(1157),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_with] = ACTIONS(1171),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [228] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6950),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7044),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5057),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3868),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7432),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9127),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(228),
    [sym_preproc_endregion] = STATE(228),
    [sym_preproc_line] = STATE(228),
    [sym_preproc_pragma] = STATE(228),
    [sym_preproc_nullable] = STATE(228),
    [sym_preproc_error] = STATE(228),
    [sym_preproc_warning] = STATE(228),
    [sym_preproc_define] = STATE(228),
    [sym_preproc_undef] = STATE(228),
    [aux_sym_class_declaration_repeat1] = STATE(3832),
    [aux_sym_lambda_expression_repeat1] = STATE(4259),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_COLON] = ACTIONS(1157),
    [anon_sym_COMMA] = ACTIONS(1157),
    [anon_sym_LPAREN] = ACTIONS(1357),
    [anon_sym_RPAREN] = ACTIONS(1157),
    [anon_sym_ref] = ACTIONS(1359),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_RBRACE] = ACTIONS(1157),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_LT] = ACTIONS(1171),
    [anon_sym_GT] = ACTIONS(1171),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1171),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1361),
    [anon_sym_TILDE] = ACTIONS(1363),
    [anon_sym_PLUS_PLUS] = ACTIONS(1363),
    [anon_sym_DASH_DASH] = ACTIONS(1363),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1361),
    [anon_sym_DASH] = ACTIONS(1361),
    [anon_sym_STAR] = ACTIONS(1365),
    [anon_sym_SLASH] = ACTIONS(1171),
    [anon_sym_PERCENT] = ACTIONS(1157),
    [anon_sym_CARET] = ACTIONS(1363),
    [anon_sym_PIPE] = ACTIONS(1171),
    [anon_sym_AMP] = ACTIONS(1361),
    [anon_sym_LT_LT] = ACTIONS(1157),
    [anon_sym_GT_GT] = ACTIONS(1171),
    [anon_sym_GT_GT_GT] = ACTIONS(1157),
    [anon_sym_EQ_EQ] = ACTIONS(1157),
    [anon_sym_BANG_EQ] = ACTIONS(1157),
    [anon_sym_GT_EQ] = ACTIONS(1157),
    [anon_sym_LT_EQ] = ACTIONS(1157),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_DOT] = ACTIONS(1171),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1171),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1367),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1369),
    [anon_sym_DOT_DOT] = ACTIONS(1371),
    [anon_sym_and] = ACTIONS(1171),
    [anon_sym_or] = ACTIONS(1171),
    [anon_sym_AMP_AMP] = ACTIONS(1157),
    [anon_sym_PIPE_PIPE] = ACTIONS(1157),
    [anon_sym_QMARK_QMARK] = ACTIONS(1157),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1171),
    [anon_sym_is] = ACTIONS(1171),
    [anon_sym_DASH_GT] = ACTIONS(1157),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_with] = ACTIONS(1171),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [229] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6962),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5158),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3931),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9818),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(229),
    [sym_preproc_endregion] = STATE(229),
    [sym_preproc_line] = STATE(229),
    [sym_preproc_pragma] = STATE(229),
    [sym_preproc_nullable] = STATE(229),
    [sym_preproc_error] = STATE(229),
    [sym_preproc_warning] = STATE(229),
    [sym_preproc_define] = STATE(229),
    [sym_preproc_undef] = STATE(229),
    [aux_sym_class_declaration_repeat1] = STATE(3811),
    [aux_sym_lambda_expression_repeat1] = STATE(4201),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(1227),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1373),
    [anon_sym_ref] = ACTIONS(1375),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_LT] = ACTIONS(1229),
    [anon_sym_GT] = ACTIONS(1229),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1229),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1377),
    [anon_sym_TILDE] = ACTIONS(1379),
    [anon_sym_PLUS_PLUS] = ACTIONS(1379),
    [anon_sym_DASH_DASH] = ACTIONS(1379),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1377),
    [anon_sym_DASH] = ACTIONS(1377),
    [anon_sym_STAR] = ACTIONS(1381),
    [anon_sym_SLASH] = ACTIONS(1229),
    [anon_sym_PERCENT] = ACTIONS(1227),
    [anon_sym_CARET] = ACTIONS(1379),
    [anon_sym_PIPE] = ACTIONS(1229),
    [anon_sym_AMP] = ACTIONS(1377),
    [anon_sym_LT_LT] = ACTIONS(1227),
    [anon_sym_GT_GT] = ACTIONS(1229),
    [anon_sym_GT_GT_GT] = ACTIONS(1227),
    [anon_sym_EQ_EQ] = ACTIONS(1227),
    [anon_sym_BANG_EQ] = ACTIONS(1227),
    [anon_sym_GT_EQ] = ACTIONS(1227),
    [anon_sym_LT_EQ] = ACTIONS(1227),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_DOT] = ACTIONS(1229),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1229),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1383),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1385),
    [anon_sym_DOT_DOT] = ACTIONS(1387),
    [anon_sym_and] = ACTIONS(1229),
    [anon_sym_or] = ACTIONS(1229),
    [anon_sym_AMP_AMP] = ACTIONS(1227),
    [anon_sym_PIPE_PIPE] = ACTIONS(1227),
    [anon_sym_QMARK_QMARK] = ACTIONS(1227),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1229),
    [anon_sym_is] = ACTIONS(1229),
    [anon_sym_DASH_GT] = ACTIONS(1227),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_with] = ACTIONS(1229),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_if_token3] = ACTIONS(1227),
    [aux_sym_preproc_else_token1] = ACTIONS(1227),
    [aux_sym_preproc_elif_token1] = ACTIONS(1227),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [230] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6962),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5149),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3931),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9818),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(230),
    [sym_preproc_endregion] = STATE(230),
    [sym_preproc_line] = STATE(230),
    [sym_preproc_pragma] = STATE(230),
    [sym_preproc_nullable] = STATE(230),
    [sym_preproc_error] = STATE(230),
    [sym_preproc_warning] = STATE(230),
    [sym_preproc_define] = STATE(230),
    [sym_preproc_undef] = STATE(230),
    [aux_sym_class_declaration_repeat1] = STATE(3811),
    [aux_sym_lambda_expression_repeat1] = STATE(4201),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(1157),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1373),
    [anon_sym_ref] = ACTIONS(1375),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_LT] = ACTIONS(1171),
    [anon_sym_GT] = ACTIONS(1171),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1171),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1377),
    [anon_sym_TILDE] = ACTIONS(1379),
    [anon_sym_PLUS_PLUS] = ACTIONS(1379),
    [anon_sym_DASH_DASH] = ACTIONS(1379),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1377),
    [anon_sym_DASH] = ACTIONS(1377),
    [anon_sym_STAR] = ACTIONS(1381),
    [anon_sym_SLASH] = ACTIONS(1171),
    [anon_sym_PERCENT] = ACTIONS(1157),
    [anon_sym_CARET] = ACTIONS(1379),
    [anon_sym_PIPE] = ACTIONS(1171),
    [anon_sym_AMP] = ACTIONS(1377),
    [anon_sym_LT_LT] = ACTIONS(1157),
    [anon_sym_GT_GT] = ACTIONS(1171),
    [anon_sym_GT_GT_GT] = ACTIONS(1157),
    [anon_sym_EQ_EQ] = ACTIONS(1157),
    [anon_sym_BANG_EQ] = ACTIONS(1157),
    [anon_sym_GT_EQ] = ACTIONS(1157),
    [anon_sym_LT_EQ] = ACTIONS(1157),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_DOT] = ACTIONS(1171),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1171),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1383),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1385),
    [anon_sym_DOT_DOT] = ACTIONS(1387),
    [anon_sym_and] = ACTIONS(1171),
    [anon_sym_or] = ACTIONS(1171),
    [anon_sym_AMP_AMP] = ACTIONS(1157),
    [anon_sym_PIPE_PIPE] = ACTIONS(1157),
    [anon_sym_QMARK_QMARK] = ACTIONS(1157),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1171),
    [anon_sym_is] = ACTIONS(1171),
    [anon_sym_DASH_GT] = ACTIONS(1157),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_with] = ACTIONS(1171),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_if_token3] = ACTIONS(1157),
    [aux_sym_preproc_else_token1] = ACTIONS(1157),
    [aux_sym_preproc_elif_token1] = ACTIONS(1157),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [231] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6950),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7044),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5102),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3868),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7432),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9127),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(231),
    [sym_preproc_endregion] = STATE(231),
    [sym_preproc_line] = STATE(231),
    [sym_preproc_pragma] = STATE(231),
    [sym_preproc_nullable] = STATE(231),
    [sym_preproc_error] = STATE(231),
    [sym_preproc_warning] = STATE(231),
    [sym_preproc_define] = STATE(231),
    [sym_preproc_undef] = STATE(231),
    [aux_sym_class_declaration_repeat1] = STATE(3832),
    [aux_sym_lambda_expression_repeat1] = STATE(4259),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_COLON] = ACTIONS(1227),
    [anon_sym_COMMA] = ACTIONS(1227),
    [anon_sym_LPAREN] = ACTIONS(1357),
    [anon_sym_RPAREN] = ACTIONS(1227),
    [anon_sym_ref] = ACTIONS(1359),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_RBRACE] = ACTIONS(1227),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_LT] = ACTIONS(1229),
    [anon_sym_GT] = ACTIONS(1229),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1229),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1361),
    [anon_sym_TILDE] = ACTIONS(1363),
    [anon_sym_PLUS_PLUS] = ACTIONS(1363),
    [anon_sym_DASH_DASH] = ACTIONS(1363),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1361),
    [anon_sym_DASH] = ACTIONS(1361),
    [anon_sym_STAR] = ACTIONS(1365),
    [anon_sym_SLASH] = ACTIONS(1229),
    [anon_sym_PERCENT] = ACTIONS(1227),
    [anon_sym_CARET] = ACTIONS(1363),
    [anon_sym_PIPE] = ACTIONS(1229),
    [anon_sym_AMP] = ACTIONS(1361),
    [anon_sym_LT_LT] = ACTIONS(1227),
    [anon_sym_GT_GT] = ACTIONS(1229),
    [anon_sym_GT_GT_GT] = ACTIONS(1227),
    [anon_sym_EQ_EQ] = ACTIONS(1227),
    [anon_sym_BANG_EQ] = ACTIONS(1227),
    [anon_sym_GT_EQ] = ACTIONS(1227),
    [anon_sym_LT_EQ] = ACTIONS(1227),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_DOT] = ACTIONS(1229),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1229),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1367),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1369),
    [anon_sym_DOT_DOT] = ACTIONS(1371),
    [anon_sym_and] = ACTIONS(1229),
    [anon_sym_or] = ACTIONS(1229),
    [anon_sym_AMP_AMP] = ACTIONS(1227),
    [anon_sym_PIPE_PIPE] = ACTIONS(1227),
    [anon_sym_QMARK_QMARK] = ACTIONS(1227),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1229),
    [anon_sym_is] = ACTIONS(1229),
    [anon_sym_DASH_GT] = ACTIONS(1227),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_with] = ACTIONS(1229),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [232] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6984),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5163),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3903),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7428),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9348),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(232),
    [sym_preproc_endregion] = STATE(232),
    [sym_preproc_line] = STATE(232),
    [sym_preproc_pragma] = STATE(232),
    [sym_preproc_nullable] = STATE(232),
    [sym_preproc_error] = STATE(232),
    [sym_preproc_warning] = STATE(232),
    [sym_preproc_define] = STATE(232),
    [sym_preproc_undef] = STATE(232),
    [aux_sym_class_declaration_repeat1] = STATE(3817),
    [aux_sym_lambda_expression_repeat1] = STATE(4227),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_COLON] = ACTIONS(1157),
    [anon_sym_COMMA] = ACTIONS(1157),
    [anon_sym_LPAREN] = ACTIONS(1389),
    [anon_sym_RPAREN] = ACTIONS(1157),
    [anon_sym_ref] = ACTIONS(1391),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_RBRACE] = ACTIONS(1157),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_LT] = ACTIONS(1171),
    [anon_sym_GT] = ACTIONS(1171),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1171),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1119),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(1393),
    [anon_sym_SLASH] = ACTIONS(1171),
    [anon_sym_PERCENT] = ACTIONS(1157),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_PIPE] = ACTIONS(1171),
    [anon_sym_AMP] = ACTIONS(1119),
    [anon_sym_LT_LT] = ACTIONS(1157),
    [anon_sym_GT_GT] = ACTIONS(1171),
    [anon_sym_GT_GT_GT] = ACTIONS(1157),
    [anon_sym_EQ_EQ] = ACTIONS(1157),
    [anon_sym_BANG_EQ] = ACTIONS(1157),
    [anon_sym_GT_EQ] = ACTIONS(1157),
    [anon_sym_LT_EQ] = ACTIONS(1157),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_DOT] = ACTIONS(1171),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1171),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1395),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1397),
    [anon_sym_DOT_DOT] = ACTIONS(1399),
    [anon_sym_and] = ACTIONS(1171),
    [anon_sym_or] = ACTIONS(1171),
    [anon_sym_AMP_AMP] = ACTIONS(1157),
    [anon_sym_PIPE_PIPE] = ACTIONS(1157),
    [anon_sym_QMARK_QMARK] = ACTIONS(1157),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1171),
    [anon_sym_is] = ACTIONS(1171),
    [anon_sym_DASH_GT] = ACTIONS(1157),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_with] = ACTIONS(1171),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [233] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6984),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5228),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3903),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7428),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9348),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(233),
    [sym_preproc_endregion] = STATE(233),
    [sym_preproc_line] = STATE(233),
    [sym_preproc_pragma] = STATE(233),
    [sym_preproc_nullable] = STATE(233),
    [sym_preproc_error] = STATE(233),
    [sym_preproc_warning] = STATE(233),
    [sym_preproc_define] = STATE(233),
    [sym_preproc_undef] = STATE(233),
    [aux_sym_class_declaration_repeat1] = STATE(3817),
    [aux_sym_lambda_expression_repeat1] = STATE(4227),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_COLON] = ACTIONS(1227),
    [anon_sym_COMMA] = ACTIONS(1227),
    [anon_sym_LPAREN] = ACTIONS(1389),
    [anon_sym_RPAREN] = ACTIONS(1227),
    [anon_sym_ref] = ACTIONS(1391),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_RBRACE] = ACTIONS(1227),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_LT] = ACTIONS(1229),
    [anon_sym_GT] = ACTIONS(1229),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1229),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1119),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(1393),
    [anon_sym_SLASH] = ACTIONS(1229),
    [anon_sym_PERCENT] = ACTIONS(1227),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_PIPE] = ACTIONS(1229),
    [anon_sym_AMP] = ACTIONS(1119),
    [anon_sym_LT_LT] = ACTIONS(1227),
    [anon_sym_GT_GT] = ACTIONS(1229),
    [anon_sym_GT_GT_GT] = ACTIONS(1227),
    [anon_sym_EQ_EQ] = ACTIONS(1227),
    [anon_sym_BANG_EQ] = ACTIONS(1227),
    [anon_sym_GT_EQ] = ACTIONS(1227),
    [anon_sym_LT_EQ] = ACTIONS(1227),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_DOT] = ACTIONS(1229),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1229),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1395),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1397),
    [anon_sym_DOT_DOT] = ACTIONS(1399),
    [anon_sym_and] = ACTIONS(1229),
    [anon_sym_or] = ACTIONS(1229),
    [anon_sym_AMP_AMP] = ACTIONS(1227),
    [anon_sym_PIPE_PIPE] = ACTIONS(1227),
    [anon_sym_QMARK_QMARK] = ACTIONS(1227),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1229),
    [anon_sym_is] = ACTIONS(1229),
    [anon_sym_DASH_GT] = ACTIONS(1227),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_with] = ACTIONS(1229),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [234] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6921),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2873),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7036),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5395),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4038),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7429),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9220),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(234),
    [sym_preproc_endregion] = STATE(234),
    [sym_preproc_line] = STATE(234),
    [sym_preproc_pragma] = STATE(234),
    [sym_preproc_nullable] = STATE(234),
    [sym_preproc_error] = STATE(234),
    [sym_preproc_warning] = STATE(234),
    [sym_preproc_define] = STATE(234),
    [sym_preproc_undef] = STATE(234),
    [aux_sym_class_declaration_repeat1] = STATE(3830),
    [aux_sym_lambda_expression_repeat1] = STATE(4255),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_COLON] = ACTIONS(1157),
    [anon_sym_COMMA] = ACTIONS(1157),
    [anon_sym_LPAREN] = ACTIONS(1407),
    [anon_sym_ref] = ACTIONS(1409),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1415),
    [anon_sym_LT] = ACTIONS(1171),
    [anon_sym_GT] = ACTIONS(1171),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_QMARK] = ACTIONS(1171),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1419),
    [anon_sym_TILDE] = ACTIONS(1421),
    [anon_sym_PLUS_PLUS] = ACTIONS(1421),
    [anon_sym_DASH_DASH] = ACTIONS(1421),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1419),
    [anon_sym_DASH] = ACTIONS(1419),
    [anon_sym_STAR] = ACTIONS(1425),
    [anon_sym_SLASH] = ACTIONS(1171),
    [anon_sym_PERCENT] = ACTIONS(1157),
    [anon_sym_CARET] = ACTIONS(1421),
    [anon_sym_PIPE] = ACTIONS(1171),
    [anon_sym_AMP] = ACTIONS(1419),
    [anon_sym_LT_LT] = ACTIONS(1157),
    [anon_sym_GT_GT] = ACTIONS(1171),
    [anon_sym_GT_GT_GT] = ACTIONS(1157),
    [anon_sym_EQ_EQ] = ACTIONS(1157),
    [anon_sym_BANG_EQ] = ACTIONS(1157),
    [anon_sym_GT_EQ] = ACTIONS(1157),
    [anon_sym_LT_EQ] = ACTIONS(1157),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_DOT] = ACTIONS(1171),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_switch] = ACTIONS(1171),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1439),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1441),
    [anon_sym_DOT_DOT] = ACTIONS(1443),
    [anon_sym_and] = ACTIONS(1171),
    [anon_sym_or] = ACTIONS(1171),
    [anon_sym_AMP_AMP] = ACTIONS(1157),
    [anon_sym_PIPE_PIPE] = ACTIONS(1157),
    [anon_sym_QMARK_QMARK] = ACTIONS(1157),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_as] = ACTIONS(1171),
    [anon_sym_is] = ACTIONS(1171),
    [anon_sym_DASH_GT] = ACTIONS(1157),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_with] = ACTIONS(1171),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_interpolation_close_brace] = ACTIONS(1157),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [235] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6921),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2873),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7036),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5310),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4038),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7429),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9220),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(235),
    [sym_preproc_endregion] = STATE(235),
    [sym_preproc_line] = STATE(235),
    [sym_preproc_pragma] = STATE(235),
    [sym_preproc_nullable] = STATE(235),
    [sym_preproc_error] = STATE(235),
    [sym_preproc_warning] = STATE(235),
    [sym_preproc_define] = STATE(235),
    [sym_preproc_undef] = STATE(235),
    [aux_sym_class_declaration_repeat1] = STATE(3830),
    [aux_sym_lambda_expression_repeat1] = STATE(4255),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_COLON] = ACTIONS(1227),
    [anon_sym_COMMA] = ACTIONS(1227),
    [anon_sym_LPAREN] = ACTIONS(1407),
    [anon_sym_ref] = ACTIONS(1409),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1415),
    [anon_sym_LT] = ACTIONS(1229),
    [anon_sym_GT] = ACTIONS(1229),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_QMARK] = ACTIONS(1229),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1419),
    [anon_sym_TILDE] = ACTIONS(1421),
    [anon_sym_PLUS_PLUS] = ACTIONS(1421),
    [anon_sym_DASH_DASH] = ACTIONS(1421),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1419),
    [anon_sym_DASH] = ACTIONS(1419),
    [anon_sym_STAR] = ACTIONS(1425),
    [anon_sym_SLASH] = ACTIONS(1229),
    [anon_sym_PERCENT] = ACTIONS(1227),
    [anon_sym_CARET] = ACTIONS(1421),
    [anon_sym_PIPE] = ACTIONS(1229),
    [anon_sym_AMP] = ACTIONS(1419),
    [anon_sym_LT_LT] = ACTIONS(1227),
    [anon_sym_GT_GT] = ACTIONS(1229),
    [anon_sym_GT_GT_GT] = ACTIONS(1227),
    [anon_sym_EQ_EQ] = ACTIONS(1227),
    [anon_sym_BANG_EQ] = ACTIONS(1227),
    [anon_sym_GT_EQ] = ACTIONS(1227),
    [anon_sym_LT_EQ] = ACTIONS(1227),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_DOT] = ACTIONS(1229),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_switch] = ACTIONS(1229),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1439),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1441),
    [anon_sym_DOT_DOT] = ACTIONS(1443),
    [anon_sym_and] = ACTIONS(1229),
    [anon_sym_or] = ACTIONS(1229),
    [anon_sym_AMP_AMP] = ACTIONS(1227),
    [anon_sym_PIPE_PIPE] = ACTIONS(1227),
    [anon_sym_QMARK_QMARK] = ACTIONS(1227),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_as] = ACTIONS(1229),
    [anon_sym_is] = ACTIONS(1229),
    [anon_sym_DASH_GT] = ACTIONS(1227),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_with] = ACTIONS(1229),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_interpolation_close_brace] = ACTIONS(1227),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [236] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6937),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2861),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7081),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5151),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(3898),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7429),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9350),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(236),
    [sym_preproc_endregion] = STATE(236),
    [sym_preproc_line] = STATE(236),
    [sym_preproc_pragma] = STATE(236),
    [sym_preproc_nullable] = STATE(236),
    [sym_preproc_error] = STATE(236),
    [sym_preproc_warning] = STATE(236),
    [sym_preproc_define] = STATE(236),
    [sym_preproc_undef] = STATE(236),
    [aux_sym_class_declaration_repeat1] = STATE(3879),
    [aux_sym_lambda_expression_repeat1] = STATE(4092),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_COLON] = ACTIONS(1157),
    [anon_sym_COMMA] = ACTIONS(1157),
    [anon_sym_LPAREN] = ACTIONS(1477),
    [anon_sym_ref] = ACTIONS(1479),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1481),
    [anon_sym_LT] = ACTIONS(1171),
    [anon_sym_GT] = ACTIONS(1171),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_QMARK] = ACTIONS(1171),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1483),
    [anon_sym_TILDE] = ACTIONS(1485),
    [anon_sym_PLUS_PLUS] = ACTIONS(1485),
    [anon_sym_DASH_DASH] = ACTIONS(1485),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1483),
    [anon_sym_DASH] = ACTIONS(1483),
    [anon_sym_STAR] = ACTIONS(1487),
    [anon_sym_SLASH] = ACTIONS(1171),
    [anon_sym_PERCENT] = ACTIONS(1157),
    [anon_sym_CARET] = ACTIONS(1485),
    [anon_sym_PIPE] = ACTIONS(1171),
    [anon_sym_AMP] = ACTIONS(1483),
    [anon_sym_LT_LT] = ACTIONS(1157),
    [anon_sym_GT_GT] = ACTIONS(1171),
    [anon_sym_GT_GT_GT] = ACTIONS(1157),
    [anon_sym_EQ_EQ] = ACTIONS(1157),
    [anon_sym_BANG_EQ] = ACTIONS(1157),
    [anon_sym_GT_EQ] = ACTIONS(1157),
    [anon_sym_LT_EQ] = ACTIONS(1157),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_DOT] = ACTIONS(1171),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_switch] = ACTIONS(1171),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1489),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1491),
    [anon_sym_DOT_DOT] = ACTIONS(1493),
    [anon_sym_and] = ACTIONS(1171),
    [anon_sym_or] = ACTIONS(1171),
    [anon_sym_AMP_AMP] = ACTIONS(1157),
    [anon_sym_PIPE_PIPE] = ACTIONS(1157),
    [anon_sym_QMARK_QMARK] = ACTIONS(1157),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_as] = ACTIONS(1171),
    [anon_sym_is] = ACTIONS(1171),
    [anon_sym_DASH_GT] = ACTIONS(1157),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_with] = ACTIONS(1171),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_interpolation_close_brace] = ACTIONS(1157),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [237] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6937),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2861),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7081),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5155),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(3898),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7429),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9350),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(237),
    [sym_preproc_endregion] = STATE(237),
    [sym_preproc_line] = STATE(237),
    [sym_preproc_pragma] = STATE(237),
    [sym_preproc_nullable] = STATE(237),
    [sym_preproc_error] = STATE(237),
    [sym_preproc_warning] = STATE(237),
    [sym_preproc_define] = STATE(237),
    [sym_preproc_undef] = STATE(237),
    [aux_sym_class_declaration_repeat1] = STATE(3879),
    [aux_sym_lambda_expression_repeat1] = STATE(4092),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_COLON] = ACTIONS(1227),
    [anon_sym_COMMA] = ACTIONS(1227),
    [anon_sym_LPAREN] = ACTIONS(1477),
    [anon_sym_ref] = ACTIONS(1479),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1481),
    [anon_sym_LT] = ACTIONS(1229),
    [anon_sym_GT] = ACTIONS(1229),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_QMARK] = ACTIONS(1229),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1483),
    [anon_sym_TILDE] = ACTIONS(1485),
    [anon_sym_PLUS_PLUS] = ACTIONS(1485),
    [anon_sym_DASH_DASH] = ACTIONS(1485),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1483),
    [anon_sym_DASH] = ACTIONS(1483),
    [anon_sym_STAR] = ACTIONS(1487),
    [anon_sym_SLASH] = ACTIONS(1229),
    [anon_sym_PERCENT] = ACTIONS(1227),
    [anon_sym_CARET] = ACTIONS(1485),
    [anon_sym_PIPE] = ACTIONS(1229),
    [anon_sym_AMP] = ACTIONS(1483),
    [anon_sym_LT_LT] = ACTIONS(1227),
    [anon_sym_GT_GT] = ACTIONS(1229),
    [anon_sym_GT_GT_GT] = ACTIONS(1227),
    [anon_sym_EQ_EQ] = ACTIONS(1227),
    [anon_sym_BANG_EQ] = ACTIONS(1227),
    [anon_sym_GT_EQ] = ACTIONS(1227),
    [anon_sym_LT_EQ] = ACTIONS(1227),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_DOT] = ACTIONS(1229),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_switch] = ACTIONS(1229),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1489),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1491),
    [anon_sym_DOT_DOT] = ACTIONS(1493),
    [anon_sym_and] = ACTIONS(1229),
    [anon_sym_or] = ACTIONS(1229),
    [anon_sym_AMP_AMP] = ACTIONS(1227),
    [anon_sym_PIPE_PIPE] = ACTIONS(1227),
    [anon_sym_QMARK_QMARK] = ACTIONS(1227),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_as] = ACTIONS(1229),
    [anon_sym_is] = ACTIONS(1229),
    [anon_sym_DASH_GT] = ACTIONS(1227),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_with] = ACTIONS(1229),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_interpolation_close_brace] = ACTIONS(1227),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [238] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6956),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5653),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9482),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(238),
    [sym_preproc_endregion] = STATE(238),
    [sym_preproc_line] = STATE(238),
    [sym_preproc_pragma] = STATE(238),
    [sym_preproc_nullable] = STATE(238),
    [sym_preproc_error] = STATE(238),
    [sym_preproc_warning] = STATE(238),
    [sym_preproc_define] = STATE(238),
    [sym_preproc_undef] = STATE(238),
    [aux_sym_class_declaration_repeat1] = STATE(3853),
    [aux_sym_lambda_expression_repeat1] = STATE(4299),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(1157),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1497),
    [anon_sym_ref] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_LT] = ACTIONS(1171),
    [anon_sym_GT] = ACTIONS(1171),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1171),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_SLASH] = ACTIONS(1171),
    [anon_sym_PERCENT] = ACTIONS(1157),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_PIPE] = ACTIONS(1171),
    [anon_sym_AMP] = ACTIONS(79),
    [anon_sym_LT_LT] = ACTIONS(1157),
    [anon_sym_GT_GT] = ACTIONS(1171),
    [anon_sym_GT_GT_GT] = ACTIONS(1157),
    [anon_sym_EQ_EQ] = ACTIONS(1157),
    [anon_sym_BANG_EQ] = ACTIONS(1157),
    [anon_sym_GT_EQ] = ACTIONS(1157),
    [anon_sym_LT_EQ] = ACTIONS(1157),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(1171),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1171),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1505),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1507),
    [anon_sym_DOT_DOT] = ACTIONS(1509),
    [anon_sym_AMP_AMP] = ACTIONS(1157),
    [anon_sym_PIPE_PIPE] = ACTIONS(1157),
    [anon_sym_QMARK_QMARK] = ACTIONS(1157),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1171),
    [anon_sym_is] = ACTIONS(1171),
    [anon_sym_DASH_GT] = ACTIONS(1157),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_with] = ACTIONS(1171),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_if_token3] = ACTIONS(1157),
    [aux_sym_preproc_else_token1] = ACTIONS(1157),
    [aux_sym_preproc_elif_token1] = ACTIONS(1157),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [239] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5601),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(239),
    [sym_preproc_endregion] = STATE(239),
    [sym_preproc_line] = STATE(239),
    [sym_preproc_pragma] = STATE(239),
    [sym_preproc_nullable] = STATE(239),
    [sym_preproc_error] = STATE(239),
    [sym_preproc_warning] = STATE(239),
    [sym_preproc_define] = STATE(239),
    [sym_preproc_undef] = STATE(239),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_COMMA] = ACTIONS(1227),
    [anon_sym_RBRACK] = ACTIONS(1227),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(1227),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_RBRACE] = ACTIONS(1227),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(1229),
    [anon_sym_GT] = ACTIONS(1229),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1229),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1511),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_SLASH] = ACTIONS(1229),
    [anon_sym_PERCENT] = ACTIONS(1227),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_PIPE] = ACTIONS(1229),
    [anon_sym_AMP] = ACTIONS(1511),
    [anon_sym_LT_LT] = ACTIONS(1227),
    [anon_sym_GT_GT] = ACTIONS(1229),
    [anon_sym_GT_GT_GT] = ACTIONS(1227),
    [anon_sym_EQ_EQ] = ACTIONS(1227),
    [anon_sym_BANG_EQ] = ACTIONS(1227),
    [anon_sym_GT_EQ] = ACTIONS(1227),
    [anon_sym_LT_EQ] = ACTIONS(1227),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(1229),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1229),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_AMP_AMP] = ACTIONS(1227),
    [anon_sym_PIPE_PIPE] = ACTIONS(1227),
    [anon_sym_QMARK_QMARK] = ACTIONS(1227),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1229),
    [anon_sym_is] = ACTIONS(1229),
    [anon_sym_DASH_GT] = ACTIONS(1227),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_with] = ACTIONS(1229),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [240] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6918),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6973),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5347),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4069),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7443),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9676),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(240),
    [sym_preproc_endregion] = STATE(240),
    [sym_preproc_line] = STATE(240),
    [sym_preproc_pragma] = STATE(240),
    [sym_preproc_nullable] = STATE(240),
    [sym_preproc_error] = STATE(240),
    [sym_preproc_warning] = STATE(240),
    [sym_preproc_define] = STATE(240),
    [sym_preproc_undef] = STATE(240),
    [aux_sym_class_declaration_repeat1] = STATE(3815),
    [aux_sym_lambda_expression_repeat1] = STATE(4217),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_COLON] = ACTIONS(1157),
    [anon_sym_COMMA] = ACTIONS(1157),
    [anon_sym_LPAREN] = ACTIONS(1515),
    [anon_sym_RPAREN] = ACTIONS(1157),
    [anon_sym_ref] = ACTIONS(1517),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_RBRACE] = ACTIONS(1157),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LT] = ACTIONS(1171),
    [anon_sym_GT] = ACTIONS(1171),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1171),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1519),
    [anon_sym_TILDE] = ACTIONS(1521),
    [anon_sym_PLUS_PLUS] = ACTIONS(1521),
    [anon_sym_DASH_DASH] = ACTIONS(1521),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1519),
    [anon_sym_DASH] = ACTIONS(1519),
    [anon_sym_STAR] = ACTIONS(1523),
    [anon_sym_SLASH] = ACTIONS(1171),
    [anon_sym_PERCENT] = ACTIONS(1157),
    [anon_sym_CARET] = ACTIONS(1521),
    [anon_sym_PIPE] = ACTIONS(1171),
    [anon_sym_AMP] = ACTIONS(1519),
    [anon_sym_LT_LT] = ACTIONS(1157),
    [anon_sym_GT_GT] = ACTIONS(1171),
    [anon_sym_GT_GT_GT] = ACTIONS(1157),
    [anon_sym_EQ_EQ] = ACTIONS(1157),
    [anon_sym_BANG_EQ] = ACTIONS(1157),
    [anon_sym_GT_EQ] = ACTIONS(1157),
    [anon_sym_LT_EQ] = ACTIONS(1157),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_DOT] = ACTIONS(1171),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1171),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1525),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1527),
    [anon_sym_DOT_DOT] = ACTIONS(1529),
    [anon_sym_AMP_AMP] = ACTIONS(1157),
    [anon_sym_PIPE_PIPE] = ACTIONS(1157),
    [anon_sym_QMARK_QMARK] = ACTIONS(1157),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1171),
    [anon_sym_is] = ACTIONS(1171),
    [anon_sym_DASH_GT] = ACTIONS(1157),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_with] = ACTIONS(1171),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [241] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6918),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6973),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5374),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4069),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7443),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9676),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(241),
    [sym_preproc_endregion] = STATE(241),
    [sym_preproc_line] = STATE(241),
    [sym_preproc_pragma] = STATE(241),
    [sym_preproc_nullable] = STATE(241),
    [sym_preproc_error] = STATE(241),
    [sym_preproc_warning] = STATE(241),
    [sym_preproc_define] = STATE(241),
    [sym_preproc_undef] = STATE(241),
    [aux_sym_class_declaration_repeat1] = STATE(3815),
    [aux_sym_lambda_expression_repeat1] = STATE(4217),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_COLON] = ACTIONS(1227),
    [anon_sym_COMMA] = ACTIONS(1227),
    [anon_sym_LPAREN] = ACTIONS(1515),
    [anon_sym_RPAREN] = ACTIONS(1227),
    [anon_sym_ref] = ACTIONS(1517),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_RBRACE] = ACTIONS(1227),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LT] = ACTIONS(1229),
    [anon_sym_GT] = ACTIONS(1229),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1229),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1519),
    [anon_sym_TILDE] = ACTIONS(1521),
    [anon_sym_PLUS_PLUS] = ACTIONS(1521),
    [anon_sym_DASH_DASH] = ACTIONS(1521),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1519),
    [anon_sym_DASH] = ACTIONS(1519),
    [anon_sym_STAR] = ACTIONS(1523),
    [anon_sym_SLASH] = ACTIONS(1229),
    [anon_sym_PERCENT] = ACTIONS(1227),
    [anon_sym_CARET] = ACTIONS(1521),
    [anon_sym_PIPE] = ACTIONS(1229),
    [anon_sym_AMP] = ACTIONS(1519),
    [anon_sym_LT_LT] = ACTIONS(1227),
    [anon_sym_GT_GT] = ACTIONS(1229),
    [anon_sym_GT_GT_GT] = ACTIONS(1227),
    [anon_sym_EQ_EQ] = ACTIONS(1227),
    [anon_sym_BANG_EQ] = ACTIONS(1227),
    [anon_sym_GT_EQ] = ACTIONS(1227),
    [anon_sym_LT_EQ] = ACTIONS(1227),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_DOT] = ACTIONS(1229),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1229),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1525),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1527),
    [anon_sym_DOT_DOT] = ACTIONS(1529),
    [anon_sym_AMP_AMP] = ACTIONS(1227),
    [anon_sym_PIPE_PIPE] = ACTIONS(1227),
    [anon_sym_QMARK_QMARK] = ACTIONS(1227),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1229),
    [anon_sym_is] = ACTIONS(1229),
    [anon_sym_DASH_GT] = ACTIONS(1227),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_with] = ACTIONS(1229),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [242] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6956),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5768),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9482),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(242),
    [sym_preproc_endregion] = STATE(242),
    [sym_preproc_line] = STATE(242),
    [sym_preproc_pragma] = STATE(242),
    [sym_preproc_nullable] = STATE(242),
    [sym_preproc_error] = STATE(242),
    [sym_preproc_warning] = STATE(242),
    [sym_preproc_define] = STATE(242),
    [sym_preproc_undef] = STATE(242),
    [aux_sym_class_declaration_repeat1] = STATE(3853),
    [aux_sym_lambda_expression_repeat1] = STATE(4299),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(1227),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1497),
    [anon_sym_ref] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_LT] = ACTIONS(1229),
    [anon_sym_GT] = ACTIONS(1229),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1229),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_SLASH] = ACTIONS(1229),
    [anon_sym_PERCENT] = ACTIONS(1227),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_PIPE] = ACTIONS(1229),
    [anon_sym_AMP] = ACTIONS(79),
    [anon_sym_LT_LT] = ACTIONS(1227),
    [anon_sym_GT_GT] = ACTIONS(1229),
    [anon_sym_GT_GT_GT] = ACTIONS(1227),
    [anon_sym_EQ_EQ] = ACTIONS(1227),
    [anon_sym_BANG_EQ] = ACTIONS(1227),
    [anon_sym_GT_EQ] = ACTIONS(1227),
    [anon_sym_LT_EQ] = ACTIONS(1227),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(1229),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1229),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1505),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1507),
    [anon_sym_DOT_DOT] = ACTIONS(1509),
    [anon_sym_AMP_AMP] = ACTIONS(1227),
    [anon_sym_PIPE_PIPE] = ACTIONS(1227),
    [anon_sym_QMARK_QMARK] = ACTIONS(1227),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1229),
    [anon_sym_is] = ACTIONS(1229),
    [anon_sym_DASH_GT] = ACTIONS(1227),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_with] = ACTIONS(1229),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_if_token3] = ACTIONS(1227),
    [aux_sym_preproc_else_token1] = ACTIONS(1227),
    [aux_sym_preproc_elif_token1] = ACTIONS(1227),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [243] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7147),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5727),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4216),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9065),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(243),
    [sym_preproc_endregion] = STATE(243),
    [sym_preproc_line] = STATE(243),
    [sym_preproc_pragma] = STATE(243),
    [sym_preproc_nullable] = STATE(243),
    [sym_preproc_error] = STATE(243),
    [sym_preproc_warning] = STATE(243),
    [sym_preproc_define] = STATE(243),
    [sym_preproc_undef] = STATE(243),
    [aux_sym_class_declaration_repeat1] = STATE(3874),
    [aux_sym_lambda_expression_repeat1] = STATE(4311),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_COLON] = ACTIONS(1157),
    [anon_sym_COMMA] = ACTIONS(1157),
    [anon_sym_LPAREN] = ACTIONS(1531),
    [anon_sym_RPAREN] = ACTIONS(1157),
    [anon_sym_ref] = ACTIONS(1533),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_RBRACE] = ACTIONS(1157),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_LT] = ACTIONS(1171),
    [anon_sym_GT] = ACTIONS(1171),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1171),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1535),
    [anon_sym_TILDE] = ACTIONS(1537),
    [anon_sym_PLUS_PLUS] = ACTIONS(1537),
    [anon_sym_DASH_DASH] = ACTIONS(1537),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1535),
    [anon_sym_DASH] = ACTIONS(1535),
    [anon_sym_STAR] = ACTIONS(1121),
    [anon_sym_SLASH] = ACTIONS(1171),
    [anon_sym_PERCENT] = ACTIONS(1157),
    [anon_sym_CARET] = ACTIONS(1537),
    [anon_sym_PIPE] = ACTIONS(1171),
    [anon_sym_AMP] = ACTIONS(1535),
    [anon_sym_LT_LT] = ACTIONS(1157),
    [anon_sym_GT_GT] = ACTIONS(1171),
    [anon_sym_GT_GT_GT] = ACTIONS(1157),
    [anon_sym_EQ_EQ] = ACTIONS(1157),
    [anon_sym_BANG_EQ] = ACTIONS(1157),
    [anon_sym_GT_EQ] = ACTIONS(1157),
    [anon_sym_LT_EQ] = ACTIONS(1157),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(1171),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1171),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1129),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1131),
    [anon_sym_DOT_DOT] = ACTIONS(1135),
    [anon_sym_AMP_AMP] = ACTIONS(1157),
    [anon_sym_PIPE_PIPE] = ACTIONS(1157),
    [anon_sym_QMARK_QMARK] = ACTIONS(1157),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1171),
    [anon_sym_is] = ACTIONS(1171),
    [anon_sym_DASH_GT] = ACTIONS(1157),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_with] = ACTIONS(1171),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [244] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7147),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5518),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4216),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9065),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(244),
    [sym_preproc_endregion] = STATE(244),
    [sym_preproc_line] = STATE(244),
    [sym_preproc_pragma] = STATE(244),
    [sym_preproc_nullable] = STATE(244),
    [sym_preproc_error] = STATE(244),
    [sym_preproc_warning] = STATE(244),
    [sym_preproc_define] = STATE(244),
    [sym_preproc_undef] = STATE(244),
    [aux_sym_class_declaration_repeat1] = STATE(3874),
    [aux_sym_lambda_expression_repeat1] = STATE(4311),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_COLON] = ACTIONS(1227),
    [anon_sym_COMMA] = ACTIONS(1227),
    [anon_sym_LPAREN] = ACTIONS(1531),
    [anon_sym_RPAREN] = ACTIONS(1227),
    [anon_sym_ref] = ACTIONS(1533),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_RBRACE] = ACTIONS(1227),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_LT] = ACTIONS(1229),
    [anon_sym_GT] = ACTIONS(1229),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1229),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1535),
    [anon_sym_TILDE] = ACTIONS(1537),
    [anon_sym_PLUS_PLUS] = ACTIONS(1537),
    [anon_sym_DASH_DASH] = ACTIONS(1537),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1535),
    [anon_sym_DASH] = ACTIONS(1535),
    [anon_sym_STAR] = ACTIONS(1121),
    [anon_sym_SLASH] = ACTIONS(1229),
    [anon_sym_PERCENT] = ACTIONS(1227),
    [anon_sym_CARET] = ACTIONS(1537),
    [anon_sym_PIPE] = ACTIONS(1229),
    [anon_sym_AMP] = ACTIONS(1535),
    [anon_sym_LT_LT] = ACTIONS(1227),
    [anon_sym_GT_GT] = ACTIONS(1229),
    [anon_sym_GT_GT_GT] = ACTIONS(1227),
    [anon_sym_EQ_EQ] = ACTIONS(1227),
    [anon_sym_BANG_EQ] = ACTIONS(1227),
    [anon_sym_GT_EQ] = ACTIONS(1227),
    [anon_sym_LT_EQ] = ACTIONS(1227),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(1229),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1229),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1129),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1131),
    [anon_sym_DOT_DOT] = ACTIONS(1135),
    [anon_sym_AMP_AMP] = ACTIONS(1227),
    [anon_sym_PIPE_PIPE] = ACTIONS(1227),
    [anon_sym_QMARK_QMARK] = ACTIONS(1227),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1229),
    [anon_sym_is] = ACTIONS(1229),
    [anon_sym_DASH_GT] = ACTIONS(1227),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_with] = ACTIONS(1229),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [245] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5608),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(245),
    [sym_preproc_endregion] = STATE(245),
    [sym_preproc_line] = STATE(245),
    [sym_preproc_pragma] = STATE(245),
    [sym_preproc_nullable] = STATE(245),
    [sym_preproc_error] = STATE(245),
    [sym_preproc_warning] = STATE(245),
    [sym_preproc_define] = STATE(245),
    [sym_preproc_undef] = STATE(245),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_COMMA] = ACTIONS(1157),
    [anon_sym_RBRACK] = ACTIONS(1157),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(1157),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_RBRACE] = ACTIONS(1157),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(1171),
    [anon_sym_GT] = ACTIONS(1171),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1171),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1511),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_SLASH] = ACTIONS(1171),
    [anon_sym_PERCENT] = ACTIONS(1157),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_PIPE] = ACTIONS(1171),
    [anon_sym_AMP] = ACTIONS(1511),
    [anon_sym_LT_LT] = ACTIONS(1157),
    [anon_sym_GT_GT] = ACTIONS(1171),
    [anon_sym_GT_GT_GT] = ACTIONS(1157),
    [anon_sym_EQ_EQ] = ACTIONS(1157),
    [anon_sym_BANG_EQ] = ACTIONS(1157),
    [anon_sym_GT_EQ] = ACTIONS(1157),
    [anon_sym_LT_EQ] = ACTIONS(1157),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(1171),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1171),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_AMP_AMP] = ACTIONS(1157),
    [anon_sym_PIPE_PIPE] = ACTIONS(1157),
    [anon_sym_QMARK_QMARK] = ACTIONS(1157),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1171),
    [anon_sym_is] = ACTIONS(1171),
    [anon_sym_DASH_GT] = ACTIONS(1157),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_with] = ACTIONS(1171),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [246] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7014),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6006),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4335),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7428),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9866),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(246),
    [sym_preproc_endregion] = STATE(246),
    [sym_preproc_line] = STATE(246),
    [sym_preproc_pragma] = STATE(246),
    [sym_preproc_nullable] = STATE(246),
    [sym_preproc_error] = STATE(246),
    [sym_preproc_warning] = STATE(246),
    [sym_preproc_define] = STATE(246),
    [sym_preproc_undef] = STATE(246),
    [aux_sym_class_declaration_repeat1] = STATE(3824),
    [aux_sym_lambda_expression_repeat1] = STATE(4242),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_COLON] = ACTIONS(1227),
    [anon_sym_LPAREN] = ACTIONS(1539),
    [anon_sym_ref] = ACTIONS(1541),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_LT] = ACTIONS(1229),
    [anon_sym_GT] = ACTIONS(1229),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1229),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1543),
    [anon_sym_TILDE] = ACTIONS(1545),
    [anon_sym_PLUS_PLUS] = ACTIONS(1545),
    [anon_sym_DASH_DASH] = ACTIONS(1545),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1543),
    [anon_sym_DASH] = ACTIONS(1543),
    [anon_sym_STAR] = ACTIONS(1547),
    [anon_sym_SLASH] = ACTIONS(1229),
    [anon_sym_PERCENT] = ACTIONS(1227),
    [anon_sym_CARET] = ACTIONS(1545),
    [anon_sym_PIPE] = ACTIONS(1229),
    [anon_sym_AMP] = ACTIONS(1543),
    [anon_sym_LT_LT] = ACTIONS(1227),
    [anon_sym_GT_GT] = ACTIONS(1229),
    [anon_sym_GT_GT_GT] = ACTIONS(1227),
    [anon_sym_EQ_EQ] = ACTIONS(1227),
    [anon_sym_BANG_EQ] = ACTIONS(1227),
    [anon_sym_GT_EQ] = ACTIONS(1227),
    [anon_sym_LT_EQ] = ACTIONS(1227),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_DOT] = ACTIONS(1229),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1229),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1549),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1551),
    [anon_sym_DOT_DOT] = ACTIONS(1553),
    [anon_sym_and] = ACTIONS(1229),
    [anon_sym_or] = ACTIONS(1229),
    [anon_sym_AMP_AMP] = ACTIONS(1227),
    [anon_sym_PIPE_PIPE] = ACTIONS(1227),
    [anon_sym_QMARK_QMARK] = ACTIONS(1227),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1229),
    [anon_sym_is] = ACTIONS(1229),
    [anon_sym_DASH_GT] = ACTIONS(1227),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_with] = ACTIONS(1229),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [247] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7131),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6002),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4364),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9470),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(247),
    [sym_preproc_endregion] = STATE(247),
    [sym_preproc_line] = STATE(247),
    [sym_preproc_pragma] = STATE(247),
    [sym_preproc_nullable] = STATE(247),
    [sym_preproc_error] = STATE(247),
    [sym_preproc_warning] = STATE(247),
    [sym_preproc_define] = STATE(247),
    [sym_preproc_undef] = STATE(247),
    [aux_sym_class_declaration_repeat1] = STATE(3870),
    [aux_sym_lambda_expression_repeat1] = STATE(4302),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(1157),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_COMMA] = ACTIONS(1157),
    [anon_sym_LPAREN] = ACTIONS(1555),
    [anon_sym_ref] = ACTIONS(1557),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_RBRACE] = ACTIONS(1157),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_LT] = ACTIONS(1171),
    [anon_sym_GT] = ACTIONS(1171),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1171),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(697),
    [anon_sym_TILDE] = ACTIONS(695),
    [anon_sym_PLUS_PLUS] = ACTIONS(695),
    [anon_sym_DASH_DASH] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(697),
    [anon_sym_DASH] = ACTIONS(697),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_SLASH] = ACTIONS(1171),
    [anon_sym_PERCENT] = ACTIONS(1157),
    [anon_sym_CARET] = ACTIONS(695),
    [anon_sym_PIPE] = ACTIONS(1171),
    [anon_sym_AMP] = ACTIONS(697),
    [anon_sym_LT_LT] = ACTIONS(1157),
    [anon_sym_GT_GT] = ACTIONS(1171),
    [anon_sym_GT_GT_GT] = ACTIONS(1157),
    [anon_sym_EQ_EQ] = ACTIONS(1157),
    [anon_sym_BANG_EQ] = ACTIONS(1157),
    [anon_sym_GT_EQ] = ACTIONS(1157),
    [anon_sym_LT_EQ] = ACTIONS(1157),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(1171),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1171),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1559),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1561),
    [anon_sym_DOT_DOT] = ACTIONS(1563),
    [anon_sym_AMP_AMP] = ACTIONS(1157),
    [anon_sym_PIPE_PIPE] = ACTIONS(1157),
    [anon_sym_QMARK_QMARK] = ACTIONS(1157),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1171),
    [anon_sym_is] = ACTIONS(1171),
    [anon_sym_DASH_GT] = ACTIONS(1157),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_with] = ACTIONS(1171),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [248] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7105),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5808),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(248),
    [sym_preproc_endregion] = STATE(248),
    [sym_preproc_line] = STATE(248),
    [sym_preproc_pragma] = STATE(248),
    [sym_preproc_nullable] = STATE(248),
    [sym_preproc_error] = STATE(248),
    [sym_preproc_warning] = STATE(248),
    [sym_preproc_define] = STATE(248),
    [sym_preproc_undef] = STATE(248),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(1171),
    [anon_sym_GT] = ACTIONS(1171),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1171),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1565),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_SLASH] = ACTIONS(1171),
    [anon_sym_PERCENT] = ACTIONS(1157),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_PIPE] = ACTIONS(1171),
    [anon_sym_AMP] = ACTIONS(1565),
    [anon_sym_LT_LT] = ACTIONS(1157),
    [anon_sym_GT_GT] = ACTIONS(1171),
    [anon_sym_GT_GT_GT] = ACTIONS(1157),
    [anon_sym_EQ_EQ] = ACTIONS(1157),
    [anon_sym_BANG_EQ] = ACTIONS(1157),
    [anon_sym_GT_EQ] = ACTIONS(1157),
    [anon_sym_LT_EQ] = ACTIONS(1157),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(1171),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1171),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_AMP_AMP] = ACTIONS(1157),
    [anon_sym_PIPE_PIPE] = ACTIONS(1157),
    [anon_sym_QMARK_QMARK] = ACTIONS(1157),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1171),
    [anon_sym_is] = ACTIONS(1171),
    [anon_sym_DASH_GT] = ACTIONS(1157),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_with] = ACTIONS(1171),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_if_token3] = ACTIONS(1157),
    [aux_sym_preproc_else_token1] = ACTIONS(1157),
    [aux_sym_preproc_elif_token1] = ACTIONS(1157),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [249] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6913),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2905),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6979),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5657),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4178),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7433),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9183),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(249),
    [sym_preproc_endregion] = STATE(249),
    [sym_preproc_line] = STATE(249),
    [sym_preproc_pragma] = STATE(249),
    [sym_preproc_nullable] = STATE(249),
    [sym_preproc_error] = STATE(249),
    [sym_preproc_warning] = STATE(249),
    [sym_preproc_define] = STATE(249),
    [sym_preproc_undef] = STATE(249),
    [aux_sym_class_declaration_repeat1] = STATE(3816),
    [aux_sym_lambda_expression_repeat1] = STATE(4225),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1573),
    [anon_sym_ref] = ACTIONS(1575),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1577),
    [anon_sym_LT] = ACTIONS(1171),
    [anon_sym_GT] = ACTIONS(1171),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1171),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1579),
    [anon_sym_TILDE] = ACTIONS(1581),
    [anon_sym_PLUS_PLUS] = ACTIONS(1581),
    [anon_sym_DASH_DASH] = ACTIONS(1581),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1579),
    [anon_sym_DASH] = ACTIONS(1579),
    [anon_sym_STAR] = ACTIONS(1583),
    [anon_sym_SLASH] = ACTIONS(1171),
    [anon_sym_PERCENT] = ACTIONS(1157),
    [anon_sym_CARET] = ACTIONS(1581),
    [anon_sym_PIPE] = ACTIONS(1171),
    [anon_sym_AMP] = ACTIONS(1579),
    [anon_sym_LT_LT] = ACTIONS(1157),
    [anon_sym_GT_GT] = ACTIONS(1171),
    [anon_sym_GT_GT_GT] = ACTIONS(1157),
    [anon_sym_EQ_EQ] = ACTIONS(1157),
    [anon_sym_BANG_EQ] = ACTIONS(1157),
    [anon_sym_GT_EQ] = ACTIONS(1157),
    [anon_sym_LT_EQ] = ACTIONS(1157),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_DOT] = ACTIONS(1171),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_EQ_GT] = ACTIONS(1157),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1171),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1585),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1587),
    [anon_sym_DOT_DOT] = ACTIONS(1589),
    [anon_sym_and] = ACTIONS(1171),
    [anon_sym_or] = ACTIONS(1171),
    [anon_sym_AMP_AMP] = ACTIONS(1157),
    [anon_sym_PIPE_PIPE] = ACTIONS(1157),
    [anon_sym_QMARK_QMARK] = ACTIONS(1157),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1171),
    [anon_sym_is] = ACTIONS(1171),
    [anon_sym_DASH_GT] = ACTIONS(1157),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_with] = ACTIONS(1171),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [250] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6913),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2905),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6979),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5445),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4178),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7433),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9183),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(250),
    [sym_preproc_endregion] = STATE(250),
    [sym_preproc_line] = STATE(250),
    [sym_preproc_pragma] = STATE(250),
    [sym_preproc_nullable] = STATE(250),
    [sym_preproc_error] = STATE(250),
    [sym_preproc_warning] = STATE(250),
    [sym_preproc_define] = STATE(250),
    [sym_preproc_undef] = STATE(250),
    [aux_sym_class_declaration_repeat1] = STATE(3816),
    [aux_sym_lambda_expression_repeat1] = STATE(4225),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1573),
    [anon_sym_ref] = ACTIONS(1575),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1577),
    [anon_sym_LT] = ACTIONS(1229),
    [anon_sym_GT] = ACTIONS(1229),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1229),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1579),
    [anon_sym_TILDE] = ACTIONS(1581),
    [anon_sym_PLUS_PLUS] = ACTIONS(1581),
    [anon_sym_DASH_DASH] = ACTIONS(1581),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1579),
    [anon_sym_DASH] = ACTIONS(1579),
    [anon_sym_STAR] = ACTIONS(1583),
    [anon_sym_SLASH] = ACTIONS(1229),
    [anon_sym_PERCENT] = ACTIONS(1227),
    [anon_sym_CARET] = ACTIONS(1581),
    [anon_sym_PIPE] = ACTIONS(1229),
    [anon_sym_AMP] = ACTIONS(1579),
    [anon_sym_LT_LT] = ACTIONS(1227),
    [anon_sym_GT_GT] = ACTIONS(1229),
    [anon_sym_GT_GT_GT] = ACTIONS(1227),
    [anon_sym_EQ_EQ] = ACTIONS(1227),
    [anon_sym_BANG_EQ] = ACTIONS(1227),
    [anon_sym_GT_EQ] = ACTIONS(1227),
    [anon_sym_LT_EQ] = ACTIONS(1227),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_DOT] = ACTIONS(1229),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_EQ_GT] = ACTIONS(1227),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1229),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1585),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1587),
    [anon_sym_DOT_DOT] = ACTIONS(1589),
    [anon_sym_and] = ACTIONS(1229),
    [anon_sym_or] = ACTIONS(1229),
    [anon_sym_AMP_AMP] = ACTIONS(1227),
    [anon_sym_PIPE_PIPE] = ACTIONS(1227),
    [anon_sym_QMARK_QMARK] = ACTIONS(1227),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1229),
    [anon_sym_is] = ACTIONS(1229),
    [anon_sym_DASH_GT] = ACTIONS(1227),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_with] = ACTIONS(1229),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [251] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7131),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5950),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4364),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9470),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(251),
    [sym_preproc_endregion] = STATE(251),
    [sym_preproc_line] = STATE(251),
    [sym_preproc_pragma] = STATE(251),
    [sym_preproc_nullable] = STATE(251),
    [sym_preproc_error] = STATE(251),
    [sym_preproc_warning] = STATE(251),
    [sym_preproc_define] = STATE(251),
    [sym_preproc_undef] = STATE(251),
    [aux_sym_class_declaration_repeat1] = STATE(3870),
    [aux_sym_lambda_expression_repeat1] = STATE(4302),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(1227),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_COMMA] = ACTIONS(1227),
    [anon_sym_LPAREN] = ACTIONS(1555),
    [anon_sym_ref] = ACTIONS(1557),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_RBRACE] = ACTIONS(1227),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_LT] = ACTIONS(1229),
    [anon_sym_GT] = ACTIONS(1229),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1229),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(697),
    [anon_sym_TILDE] = ACTIONS(695),
    [anon_sym_PLUS_PLUS] = ACTIONS(695),
    [anon_sym_DASH_DASH] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(697),
    [anon_sym_DASH] = ACTIONS(697),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_SLASH] = ACTIONS(1229),
    [anon_sym_PERCENT] = ACTIONS(1227),
    [anon_sym_CARET] = ACTIONS(695),
    [anon_sym_PIPE] = ACTIONS(1229),
    [anon_sym_AMP] = ACTIONS(697),
    [anon_sym_LT_LT] = ACTIONS(1227),
    [anon_sym_GT_GT] = ACTIONS(1229),
    [anon_sym_GT_GT_GT] = ACTIONS(1227),
    [anon_sym_EQ_EQ] = ACTIONS(1227),
    [anon_sym_BANG_EQ] = ACTIONS(1227),
    [anon_sym_GT_EQ] = ACTIONS(1227),
    [anon_sym_LT_EQ] = ACTIONS(1227),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(1229),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1229),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1559),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1561),
    [anon_sym_DOT_DOT] = ACTIONS(1563),
    [anon_sym_AMP_AMP] = ACTIONS(1227),
    [anon_sym_PIPE_PIPE] = ACTIONS(1227),
    [anon_sym_QMARK_QMARK] = ACTIONS(1227),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1229),
    [anon_sym_is] = ACTIONS(1229),
    [anon_sym_DASH_GT] = ACTIONS(1227),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_with] = ACTIONS(1229),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [252] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6927),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2912),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7057),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5356),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3960),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7439),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9222),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(252),
    [sym_preproc_endregion] = STATE(252),
    [sym_preproc_line] = STATE(252),
    [sym_preproc_pragma] = STATE(252),
    [sym_preproc_nullable] = STATE(252),
    [sym_preproc_error] = STATE(252),
    [sym_preproc_warning] = STATE(252),
    [sym_preproc_define] = STATE(252),
    [sym_preproc_undef] = STATE(252),
    [aux_sym_class_declaration_repeat1] = STATE(3837),
    [aux_sym_lambda_expression_repeat1] = STATE(4265),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_COLON] = ACTIONS(1157),
    [anon_sym_LPAREN] = ACTIONS(1591),
    [anon_sym_ref] = ACTIONS(1593),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1595),
    [anon_sym_LT] = ACTIONS(1171),
    [anon_sym_GT] = ACTIONS(1171),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1171),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1597),
    [anon_sym_TILDE] = ACTIONS(1599),
    [anon_sym_PLUS_PLUS] = ACTIONS(1599),
    [anon_sym_DASH_DASH] = ACTIONS(1599),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1597),
    [anon_sym_DASH] = ACTIONS(1597),
    [anon_sym_STAR] = ACTIONS(1601),
    [anon_sym_SLASH] = ACTIONS(1171),
    [anon_sym_PERCENT] = ACTIONS(1157),
    [anon_sym_CARET] = ACTIONS(1599),
    [anon_sym_PIPE] = ACTIONS(1171),
    [anon_sym_AMP] = ACTIONS(1597),
    [anon_sym_LT_LT] = ACTIONS(1157),
    [anon_sym_GT_GT] = ACTIONS(1171),
    [anon_sym_GT_GT_GT] = ACTIONS(1157),
    [anon_sym_EQ_EQ] = ACTIONS(1157),
    [anon_sym_BANG_EQ] = ACTIONS(1157),
    [anon_sym_GT_EQ] = ACTIONS(1157),
    [anon_sym_LT_EQ] = ACTIONS(1157),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_DOT] = ACTIONS(1171),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1171),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1603),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1605),
    [anon_sym_DOT_DOT] = ACTIONS(1607),
    [anon_sym_and] = ACTIONS(1171),
    [anon_sym_or] = ACTIONS(1171),
    [anon_sym_AMP_AMP] = ACTIONS(1157),
    [anon_sym_PIPE_PIPE] = ACTIONS(1157),
    [anon_sym_QMARK_QMARK] = ACTIONS(1157),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1171),
    [anon_sym_is] = ACTIONS(1171),
    [anon_sym_DASH_GT] = ACTIONS(1157),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_with] = ACTIONS(1171),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [253] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6927),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2912),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7057),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5364),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3960),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7439),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9222),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(253),
    [sym_preproc_endregion] = STATE(253),
    [sym_preproc_line] = STATE(253),
    [sym_preproc_pragma] = STATE(253),
    [sym_preproc_nullable] = STATE(253),
    [sym_preproc_error] = STATE(253),
    [sym_preproc_warning] = STATE(253),
    [sym_preproc_define] = STATE(253),
    [sym_preproc_undef] = STATE(253),
    [aux_sym_class_declaration_repeat1] = STATE(3837),
    [aux_sym_lambda_expression_repeat1] = STATE(4265),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_COLON] = ACTIONS(1227),
    [anon_sym_LPAREN] = ACTIONS(1591),
    [anon_sym_ref] = ACTIONS(1593),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1595),
    [anon_sym_LT] = ACTIONS(1229),
    [anon_sym_GT] = ACTIONS(1229),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1229),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1597),
    [anon_sym_TILDE] = ACTIONS(1599),
    [anon_sym_PLUS_PLUS] = ACTIONS(1599),
    [anon_sym_DASH_DASH] = ACTIONS(1599),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1597),
    [anon_sym_DASH] = ACTIONS(1597),
    [anon_sym_STAR] = ACTIONS(1601),
    [anon_sym_SLASH] = ACTIONS(1229),
    [anon_sym_PERCENT] = ACTIONS(1227),
    [anon_sym_CARET] = ACTIONS(1599),
    [anon_sym_PIPE] = ACTIONS(1229),
    [anon_sym_AMP] = ACTIONS(1597),
    [anon_sym_LT_LT] = ACTIONS(1227),
    [anon_sym_GT_GT] = ACTIONS(1229),
    [anon_sym_GT_GT_GT] = ACTIONS(1227),
    [anon_sym_EQ_EQ] = ACTIONS(1227),
    [anon_sym_BANG_EQ] = ACTIONS(1227),
    [anon_sym_GT_EQ] = ACTIONS(1227),
    [anon_sym_LT_EQ] = ACTIONS(1227),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_DOT] = ACTIONS(1229),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1229),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1603),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1605),
    [anon_sym_DOT_DOT] = ACTIONS(1607),
    [anon_sym_and] = ACTIONS(1229),
    [anon_sym_or] = ACTIONS(1229),
    [anon_sym_AMP_AMP] = ACTIONS(1227),
    [anon_sym_PIPE_PIPE] = ACTIONS(1227),
    [anon_sym_QMARK_QMARK] = ACTIONS(1227),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1229),
    [anon_sym_is] = ACTIONS(1229),
    [anon_sym_DASH_GT] = ACTIONS(1227),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_with] = ACTIONS(1229),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [254] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6937),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2861),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7001),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5621),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4149),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7445),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9763),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(254),
    [sym_preproc_endregion] = STATE(254),
    [sym_preproc_line] = STATE(254),
    [sym_preproc_pragma] = STATE(254),
    [sym_preproc_nullable] = STATE(254),
    [sym_preproc_error] = STATE(254),
    [sym_preproc_warning] = STATE(254),
    [sym_preproc_define] = STATE(254),
    [sym_preproc_undef] = STATE(254),
    [aux_sym_class_declaration_repeat1] = STATE(3821),
    [aux_sym_lambda_expression_repeat1] = STATE(4236),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_COLON] = ACTIONS(1157),
    [anon_sym_COMMA] = ACTIONS(1157),
    [anon_sym_LPAREN] = ACTIONS(1609),
    [anon_sym_ref] = ACTIONS(1611),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1481),
    [anon_sym_LT] = ACTIONS(1171),
    [anon_sym_GT] = ACTIONS(1171),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_QMARK] = ACTIONS(1171),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1613),
    [anon_sym_TILDE] = ACTIONS(1615),
    [anon_sym_PLUS_PLUS] = ACTIONS(1615),
    [anon_sym_DASH_DASH] = ACTIONS(1615),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1613),
    [anon_sym_DASH] = ACTIONS(1613),
    [anon_sym_STAR] = ACTIONS(1487),
    [anon_sym_SLASH] = ACTIONS(1171),
    [anon_sym_PERCENT] = ACTIONS(1157),
    [anon_sym_CARET] = ACTIONS(1615),
    [anon_sym_PIPE] = ACTIONS(1171),
    [anon_sym_AMP] = ACTIONS(1613),
    [anon_sym_LT_LT] = ACTIONS(1157),
    [anon_sym_GT_GT] = ACTIONS(1171),
    [anon_sym_GT_GT_GT] = ACTIONS(1157),
    [anon_sym_EQ_EQ] = ACTIONS(1157),
    [anon_sym_BANG_EQ] = ACTIONS(1157),
    [anon_sym_GT_EQ] = ACTIONS(1157),
    [anon_sym_LT_EQ] = ACTIONS(1157),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_DOT] = ACTIONS(1171),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_switch] = ACTIONS(1171),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1617),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1619),
    [anon_sym_DOT_DOT] = ACTIONS(1621),
    [anon_sym_AMP_AMP] = ACTIONS(1157),
    [anon_sym_PIPE_PIPE] = ACTIONS(1157),
    [anon_sym_QMARK_QMARK] = ACTIONS(1157),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_as] = ACTIONS(1171),
    [anon_sym_is] = ACTIONS(1171),
    [anon_sym_DASH_GT] = ACTIONS(1157),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_with] = ACTIONS(1171),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_interpolation_close_brace] = ACTIONS(1157),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [255] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7105),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5851),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(255),
    [sym_preproc_endregion] = STATE(255),
    [sym_preproc_line] = STATE(255),
    [sym_preproc_pragma] = STATE(255),
    [sym_preproc_nullable] = STATE(255),
    [sym_preproc_error] = STATE(255),
    [sym_preproc_warning] = STATE(255),
    [sym_preproc_define] = STATE(255),
    [sym_preproc_undef] = STATE(255),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(1229),
    [anon_sym_GT] = ACTIONS(1229),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1229),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1565),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_SLASH] = ACTIONS(1229),
    [anon_sym_PERCENT] = ACTIONS(1227),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_PIPE] = ACTIONS(1229),
    [anon_sym_AMP] = ACTIONS(1565),
    [anon_sym_LT_LT] = ACTIONS(1227),
    [anon_sym_GT_GT] = ACTIONS(1229),
    [anon_sym_GT_GT_GT] = ACTIONS(1227),
    [anon_sym_EQ_EQ] = ACTIONS(1227),
    [anon_sym_BANG_EQ] = ACTIONS(1227),
    [anon_sym_GT_EQ] = ACTIONS(1227),
    [anon_sym_LT_EQ] = ACTIONS(1227),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(1229),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1229),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_AMP_AMP] = ACTIONS(1227),
    [anon_sym_PIPE_PIPE] = ACTIONS(1227),
    [anon_sym_QMARK_QMARK] = ACTIONS(1227),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1229),
    [anon_sym_is] = ACTIONS(1229),
    [anon_sym_DASH_GT] = ACTIONS(1227),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_with] = ACTIONS(1229),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_if_token3] = ACTIONS(1227),
    [aux_sym_preproc_else_token1] = ACTIONS(1227),
    [aux_sym_preproc_elif_token1] = ACTIONS(1227),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [256] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5608),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(256),
    [sym_preproc_endregion] = STATE(256),
    [sym_preproc_line] = STATE(256),
    [sym_preproc_pragma] = STATE(256),
    [sym_preproc_nullable] = STATE(256),
    [sym_preproc_error] = STATE(256),
    [sym_preproc_warning] = STATE(256),
    [sym_preproc_define] = STATE(256),
    [sym_preproc_undef] = STATE(256),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_list_pattern_repeat1] = STATE(8507),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_COMMA] = ACTIONS(1157),
    [anon_sym_RBRACK] = ACTIONS(1157),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(1171),
    [anon_sym_GT] = ACTIONS(1171),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1171),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1511),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_SLASH] = ACTIONS(1171),
    [anon_sym_PERCENT] = ACTIONS(1157),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_PIPE] = ACTIONS(1171),
    [anon_sym_AMP] = ACTIONS(1511),
    [anon_sym_LT_LT] = ACTIONS(1157),
    [anon_sym_GT_GT] = ACTIONS(1171),
    [anon_sym_GT_GT_GT] = ACTIONS(1157),
    [anon_sym_EQ_EQ] = ACTIONS(1157),
    [anon_sym_BANG_EQ] = ACTIONS(1157),
    [anon_sym_GT_EQ] = ACTIONS(1157),
    [anon_sym_LT_EQ] = ACTIONS(1157),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(1171),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1171),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_AMP_AMP] = ACTIONS(1157),
    [anon_sym_PIPE_PIPE] = ACTIONS(1157),
    [anon_sym_QMARK_QMARK] = ACTIONS(1157),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1171),
    [anon_sym_is] = ACTIONS(1171),
    [anon_sym_DASH_GT] = ACTIONS(1157),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_with] = ACTIONS(1171),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [257] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6917),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2905),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7006),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5713),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4199),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7447),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9823),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(257),
    [sym_preproc_endregion] = STATE(257),
    [sym_preproc_line] = STATE(257),
    [sym_preproc_pragma] = STATE(257),
    [sym_preproc_nullable] = STATE(257),
    [sym_preproc_error] = STATE(257),
    [sym_preproc_warning] = STATE(257),
    [sym_preproc_define] = STATE(257),
    [sym_preproc_undef] = STATE(257),
    [aux_sym_class_declaration_repeat1] = STATE(3822),
    [aux_sym_lambda_expression_repeat1] = STATE(4238),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_COLON] = ACTIONS(1157),
    [anon_sym_LPAREN] = ACTIONS(1623),
    [anon_sym_ref] = ACTIONS(1625),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1577),
    [anon_sym_LT] = ACTIONS(1171),
    [anon_sym_GT] = ACTIONS(1171),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1171),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1627),
    [anon_sym_TILDE] = ACTIONS(1629),
    [anon_sym_PLUS_PLUS] = ACTIONS(1629),
    [anon_sym_DASH_DASH] = ACTIONS(1629),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1627),
    [anon_sym_DASH] = ACTIONS(1627),
    [anon_sym_STAR] = ACTIONS(1631),
    [anon_sym_SLASH] = ACTIONS(1171),
    [anon_sym_PERCENT] = ACTIONS(1157),
    [anon_sym_CARET] = ACTIONS(1629),
    [anon_sym_PIPE] = ACTIONS(1171),
    [anon_sym_AMP] = ACTIONS(1627),
    [anon_sym_LT_LT] = ACTIONS(1157),
    [anon_sym_GT_GT] = ACTIONS(1171),
    [anon_sym_GT_GT_GT] = ACTIONS(1157),
    [anon_sym_EQ_EQ] = ACTIONS(1157),
    [anon_sym_BANG_EQ] = ACTIONS(1157),
    [anon_sym_GT_EQ] = ACTIONS(1157),
    [anon_sym_LT_EQ] = ACTIONS(1157),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_DOT] = ACTIONS(1171),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1171),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1633),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1635),
    [anon_sym_DOT_DOT] = ACTIONS(1637),
    [anon_sym_and] = ACTIONS(1171),
    [anon_sym_or] = ACTIONS(1171),
    [anon_sym_AMP_AMP] = ACTIONS(1157),
    [anon_sym_PIPE_PIPE] = ACTIONS(1157),
    [anon_sym_QMARK_QMARK] = ACTIONS(1157),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1171),
    [anon_sym_is] = ACTIONS(1171),
    [anon_sym_DASH_GT] = ACTIONS(1157),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_with] = ACTIONS(1171),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [258] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6917),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2905),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7006),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5491),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4199),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7447),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9823),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(258),
    [sym_preproc_endregion] = STATE(258),
    [sym_preproc_line] = STATE(258),
    [sym_preproc_pragma] = STATE(258),
    [sym_preproc_nullable] = STATE(258),
    [sym_preproc_error] = STATE(258),
    [sym_preproc_warning] = STATE(258),
    [sym_preproc_define] = STATE(258),
    [sym_preproc_undef] = STATE(258),
    [aux_sym_class_declaration_repeat1] = STATE(3822),
    [aux_sym_lambda_expression_repeat1] = STATE(4238),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_COLON] = ACTIONS(1227),
    [anon_sym_LPAREN] = ACTIONS(1623),
    [anon_sym_ref] = ACTIONS(1625),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1577),
    [anon_sym_LT] = ACTIONS(1229),
    [anon_sym_GT] = ACTIONS(1229),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1229),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1627),
    [anon_sym_TILDE] = ACTIONS(1629),
    [anon_sym_PLUS_PLUS] = ACTIONS(1629),
    [anon_sym_DASH_DASH] = ACTIONS(1629),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1627),
    [anon_sym_DASH] = ACTIONS(1627),
    [anon_sym_STAR] = ACTIONS(1631),
    [anon_sym_SLASH] = ACTIONS(1229),
    [anon_sym_PERCENT] = ACTIONS(1227),
    [anon_sym_CARET] = ACTIONS(1629),
    [anon_sym_PIPE] = ACTIONS(1229),
    [anon_sym_AMP] = ACTIONS(1627),
    [anon_sym_LT_LT] = ACTIONS(1227),
    [anon_sym_GT_GT] = ACTIONS(1229),
    [anon_sym_GT_GT_GT] = ACTIONS(1227),
    [anon_sym_EQ_EQ] = ACTIONS(1227),
    [anon_sym_BANG_EQ] = ACTIONS(1227),
    [anon_sym_GT_EQ] = ACTIONS(1227),
    [anon_sym_LT_EQ] = ACTIONS(1227),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_DOT] = ACTIONS(1229),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1229),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1633),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1635),
    [anon_sym_DOT_DOT] = ACTIONS(1637),
    [anon_sym_and] = ACTIONS(1229),
    [anon_sym_or] = ACTIONS(1229),
    [anon_sym_AMP_AMP] = ACTIONS(1227),
    [anon_sym_PIPE_PIPE] = ACTIONS(1227),
    [anon_sym_QMARK_QMARK] = ACTIONS(1227),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1229),
    [anon_sym_is] = ACTIONS(1229),
    [anon_sym_DASH_GT] = ACTIONS(1227),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_with] = ACTIONS(1229),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [259] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6921),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2873),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(6957),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5795),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4346),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7445),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9875),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(259),
    [sym_preproc_endregion] = STATE(259),
    [sym_preproc_line] = STATE(259),
    [sym_preproc_pragma] = STATE(259),
    [sym_preproc_nullable] = STATE(259),
    [sym_preproc_error] = STATE(259),
    [sym_preproc_warning] = STATE(259),
    [sym_preproc_define] = STATE(259),
    [sym_preproc_undef] = STATE(259),
    [aux_sym_class_declaration_repeat1] = STATE(3810),
    [aux_sym_lambda_expression_repeat1] = STATE(4192),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_COLON] = ACTIONS(1157),
    [anon_sym_COMMA] = ACTIONS(1157),
    [anon_sym_LPAREN] = ACTIONS(1639),
    [anon_sym_ref] = ACTIONS(1641),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1415),
    [anon_sym_LT] = ACTIONS(1171),
    [anon_sym_GT] = ACTIONS(1171),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_QMARK] = ACTIONS(1171),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1643),
    [anon_sym_TILDE] = ACTIONS(1645),
    [anon_sym_PLUS_PLUS] = ACTIONS(1645),
    [anon_sym_DASH_DASH] = ACTIONS(1645),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1643),
    [anon_sym_DASH] = ACTIONS(1643),
    [anon_sym_STAR] = ACTIONS(1425),
    [anon_sym_SLASH] = ACTIONS(1171),
    [anon_sym_PERCENT] = ACTIONS(1157),
    [anon_sym_CARET] = ACTIONS(1645),
    [anon_sym_PIPE] = ACTIONS(1171),
    [anon_sym_AMP] = ACTIONS(1643),
    [anon_sym_LT_LT] = ACTIONS(1157),
    [anon_sym_GT_GT] = ACTIONS(1171),
    [anon_sym_GT_GT_GT] = ACTIONS(1157),
    [anon_sym_EQ_EQ] = ACTIONS(1157),
    [anon_sym_BANG_EQ] = ACTIONS(1157),
    [anon_sym_GT_EQ] = ACTIONS(1157),
    [anon_sym_LT_EQ] = ACTIONS(1157),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_DOT] = ACTIONS(1171),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_switch] = ACTIONS(1171),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1647),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1649),
    [anon_sym_DOT_DOT] = ACTIONS(1651),
    [anon_sym_AMP_AMP] = ACTIONS(1157),
    [anon_sym_PIPE_PIPE] = ACTIONS(1157),
    [anon_sym_QMARK_QMARK] = ACTIONS(1157),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_as] = ACTIONS(1171),
    [anon_sym_is] = ACTIONS(1171),
    [anon_sym_DASH_GT] = ACTIONS(1157),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_with] = ACTIONS(1171),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_interpolation_close_brace] = ACTIONS(1157),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [260] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7014),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6042),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4335),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7428),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9866),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(260),
    [sym_preproc_endregion] = STATE(260),
    [sym_preproc_line] = STATE(260),
    [sym_preproc_pragma] = STATE(260),
    [sym_preproc_nullable] = STATE(260),
    [sym_preproc_error] = STATE(260),
    [sym_preproc_warning] = STATE(260),
    [sym_preproc_define] = STATE(260),
    [sym_preproc_undef] = STATE(260),
    [aux_sym_class_declaration_repeat1] = STATE(3824),
    [aux_sym_lambda_expression_repeat1] = STATE(4242),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_COLON] = ACTIONS(1157),
    [anon_sym_LPAREN] = ACTIONS(1539),
    [anon_sym_ref] = ACTIONS(1541),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_LT] = ACTIONS(1171),
    [anon_sym_GT] = ACTIONS(1171),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1171),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1543),
    [anon_sym_TILDE] = ACTIONS(1545),
    [anon_sym_PLUS_PLUS] = ACTIONS(1545),
    [anon_sym_DASH_DASH] = ACTIONS(1545),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1543),
    [anon_sym_DASH] = ACTIONS(1543),
    [anon_sym_STAR] = ACTIONS(1547),
    [anon_sym_SLASH] = ACTIONS(1171),
    [anon_sym_PERCENT] = ACTIONS(1157),
    [anon_sym_CARET] = ACTIONS(1545),
    [anon_sym_PIPE] = ACTIONS(1171),
    [anon_sym_AMP] = ACTIONS(1543),
    [anon_sym_LT_LT] = ACTIONS(1157),
    [anon_sym_GT_GT] = ACTIONS(1171),
    [anon_sym_GT_GT_GT] = ACTIONS(1157),
    [anon_sym_EQ_EQ] = ACTIONS(1157),
    [anon_sym_BANG_EQ] = ACTIONS(1157),
    [anon_sym_GT_EQ] = ACTIONS(1157),
    [anon_sym_LT_EQ] = ACTIONS(1157),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_DOT] = ACTIONS(1171),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1171),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1549),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1551),
    [anon_sym_DOT_DOT] = ACTIONS(1553),
    [anon_sym_and] = ACTIONS(1171),
    [anon_sym_or] = ACTIONS(1171),
    [anon_sym_AMP_AMP] = ACTIONS(1157),
    [anon_sym_PIPE_PIPE] = ACTIONS(1157),
    [anon_sym_QMARK_QMARK] = ACTIONS(1157),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1171),
    [anon_sym_is] = ACTIONS(1171),
    [anon_sym_DASH_GT] = ACTIONS(1157),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_with] = ACTIONS(1171),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [261] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6921),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2873),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(6957),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6023),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4346),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7445),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9875),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(261),
    [sym_preproc_endregion] = STATE(261),
    [sym_preproc_line] = STATE(261),
    [sym_preproc_pragma] = STATE(261),
    [sym_preproc_nullable] = STATE(261),
    [sym_preproc_error] = STATE(261),
    [sym_preproc_warning] = STATE(261),
    [sym_preproc_define] = STATE(261),
    [sym_preproc_undef] = STATE(261),
    [aux_sym_class_declaration_repeat1] = STATE(3810),
    [aux_sym_lambda_expression_repeat1] = STATE(4192),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_COLON] = ACTIONS(1227),
    [anon_sym_COMMA] = ACTIONS(1227),
    [anon_sym_LPAREN] = ACTIONS(1639),
    [anon_sym_ref] = ACTIONS(1641),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1415),
    [anon_sym_LT] = ACTIONS(1229),
    [anon_sym_GT] = ACTIONS(1229),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_QMARK] = ACTIONS(1229),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1643),
    [anon_sym_TILDE] = ACTIONS(1645),
    [anon_sym_PLUS_PLUS] = ACTIONS(1645),
    [anon_sym_DASH_DASH] = ACTIONS(1645),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1643),
    [anon_sym_DASH] = ACTIONS(1643),
    [anon_sym_STAR] = ACTIONS(1425),
    [anon_sym_SLASH] = ACTIONS(1229),
    [anon_sym_PERCENT] = ACTIONS(1227),
    [anon_sym_CARET] = ACTIONS(1645),
    [anon_sym_PIPE] = ACTIONS(1229),
    [anon_sym_AMP] = ACTIONS(1643),
    [anon_sym_LT_LT] = ACTIONS(1227),
    [anon_sym_GT_GT] = ACTIONS(1229),
    [anon_sym_GT_GT_GT] = ACTIONS(1227),
    [anon_sym_EQ_EQ] = ACTIONS(1227),
    [anon_sym_BANG_EQ] = ACTIONS(1227),
    [anon_sym_GT_EQ] = ACTIONS(1227),
    [anon_sym_LT_EQ] = ACTIONS(1227),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_DOT] = ACTIONS(1229),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_switch] = ACTIONS(1229),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1647),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1649),
    [anon_sym_DOT_DOT] = ACTIONS(1651),
    [anon_sym_AMP_AMP] = ACTIONS(1227),
    [anon_sym_PIPE_PIPE] = ACTIONS(1227),
    [anon_sym_QMARK_QMARK] = ACTIONS(1227),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_as] = ACTIONS(1229),
    [anon_sym_is] = ACTIONS(1229),
    [anon_sym_DASH_GT] = ACTIONS(1227),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_with] = ACTIONS(1229),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_interpolation_close_brace] = ACTIONS(1227),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [262] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6937),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2861),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7001),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5677),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4149),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7445),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9763),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(262),
    [sym_preproc_endregion] = STATE(262),
    [sym_preproc_line] = STATE(262),
    [sym_preproc_pragma] = STATE(262),
    [sym_preproc_nullable] = STATE(262),
    [sym_preproc_error] = STATE(262),
    [sym_preproc_warning] = STATE(262),
    [sym_preproc_define] = STATE(262),
    [sym_preproc_undef] = STATE(262),
    [aux_sym_class_declaration_repeat1] = STATE(3821),
    [aux_sym_lambda_expression_repeat1] = STATE(4236),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_COLON] = ACTIONS(1227),
    [anon_sym_COMMA] = ACTIONS(1227),
    [anon_sym_LPAREN] = ACTIONS(1609),
    [anon_sym_ref] = ACTIONS(1611),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1481),
    [anon_sym_LT] = ACTIONS(1229),
    [anon_sym_GT] = ACTIONS(1229),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_QMARK] = ACTIONS(1229),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1613),
    [anon_sym_TILDE] = ACTIONS(1615),
    [anon_sym_PLUS_PLUS] = ACTIONS(1615),
    [anon_sym_DASH_DASH] = ACTIONS(1615),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1613),
    [anon_sym_DASH] = ACTIONS(1613),
    [anon_sym_STAR] = ACTIONS(1487),
    [anon_sym_SLASH] = ACTIONS(1229),
    [anon_sym_PERCENT] = ACTIONS(1227),
    [anon_sym_CARET] = ACTIONS(1615),
    [anon_sym_PIPE] = ACTIONS(1229),
    [anon_sym_AMP] = ACTIONS(1613),
    [anon_sym_LT_LT] = ACTIONS(1227),
    [anon_sym_GT_GT] = ACTIONS(1229),
    [anon_sym_GT_GT_GT] = ACTIONS(1227),
    [anon_sym_EQ_EQ] = ACTIONS(1227),
    [anon_sym_BANG_EQ] = ACTIONS(1227),
    [anon_sym_GT_EQ] = ACTIONS(1227),
    [anon_sym_LT_EQ] = ACTIONS(1227),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_DOT] = ACTIONS(1229),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_switch] = ACTIONS(1229),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1617),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1619),
    [anon_sym_DOT_DOT] = ACTIONS(1621),
    [anon_sym_AMP_AMP] = ACTIONS(1227),
    [anon_sym_PIPE_PIPE] = ACTIONS(1227),
    [anon_sym_QMARK_QMARK] = ACTIONS(1227),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_as] = ACTIONS(1229),
    [anon_sym_is] = ACTIONS(1229),
    [anon_sym_DASH_GT] = ACTIONS(1227),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_with] = ACTIONS(1229),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_interpolation_close_brace] = ACTIONS(1227),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [263] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6915),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7099),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5729),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4224),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7442),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9174),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(263),
    [sym_preproc_endregion] = STATE(263),
    [sym_preproc_line] = STATE(263),
    [sym_preproc_pragma] = STATE(263),
    [sym_preproc_nullable] = STATE(263),
    [sym_preproc_error] = STATE(263),
    [sym_preproc_warning] = STATE(263),
    [sym_preproc_define] = STATE(263),
    [sym_preproc_undef] = STATE(263),
    [aux_sym_class_declaration_repeat1] = STATE(3849),
    [aux_sym_lambda_expression_repeat1] = STATE(4284),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1653),
    [anon_sym_ref] = ACTIONS(1655),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_LT] = ACTIONS(1171),
    [anon_sym_GT] = ACTIONS(1171),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1171),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1657),
    [anon_sym_TILDE] = ACTIONS(1659),
    [anon_sym_PLUS_PLUS] = ACTIONS(1659),
    [anon_sym_DASH_DASH] = ACTIONS(1659),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1657),
    [anon_sym_DASH] = ACTIONS(1657),
    [anon_sym_STAR] = ACTIONS(1661),
    [anon_sym_SLASH] = ACTIONS(1171),
    [anon_sym_PERCENT] = ACTIONS(1157),
    [anon_sym_CARET] = ACTIONS(1659),
    [anon_sym_PIPE] = ACTIONS(1171),
    [anon_sym_AMP] = ACTIONS(1657),
    [anon_sym_LT_LT] = ACTIONS(1157),
    [anon_sym_GT_GT] = ACTIONS(1171),
    [anon_sym_GT_GT_GT] = ACTIONS(1157),
    [anon_sym_EQ_EQ] = ACTIONS(1157),
    [anon_sym_BANG_EQ] = ACTIONS(1157),
    [anon_sym_GT_EQ] = ACTIONS(1157),
    [anon_sym_LT_EQ] = ACTIONS(1157),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_DOT] = ACTIONS(1171),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_EQ_GT] = ACTIONS(1157),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1171),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1663),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1665),
    [anon_sym_DOT_DOT] = ACTIONS(1667),
    [anon_sym_and] = ACTIONS(1171),
    [anon_sym_or] = ACTIONS(1171),
    [anon_sym_AMP_AMP] = ACTIONS(1157),
    [anon_sym_PIPE_PIPE] = ACTIONS(1157),
    [anon_sym_QMARK_QMARK] = ACTIONS(1157),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1171),
    [anon_sym_is] = ACTIONS(1171),
    [anon_sym_DASH_GT] = ACTIONS(1157),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_with] = ACTIONS(1171),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [264] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6915),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7099),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5556),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4224),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7442),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9174),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(264),
    [sym_preproc_endregion] = STATE(264),
    [sym_preproc_line] = STATE(264),
    [sym_preproc_pragma] = STATE(264),
    [sym_preproc_nullable] = STATE(264),
    [sym_preproc_error] = STATE(264),
    [sym_preproc_warning] = STATE(264),
    [sym_preproc_define] = STATE(264),
    [sym_preproc_undef] = STATE(264),
    [aux_sym_class_declaration_repeat1] = STATE(3849),
    [aux_sym_lambda_expression_repeat1] = STATE(4284),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1653),
    [anon_sym_ref] = ACTIONS(1655),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_LT] = ACTIONS(1229),
    [anon_sym_GT] = ACTIONS(1229),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1229),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1657),
    [anon_sym_TILDE] = ACTIONS(1659),
    [anon_sym_PLUS_PLUS] = ACTIONS(1659),
    [anon_sym_DASH_DASH] = ACTIONS(1659),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1657),
    [anon_sym_DASH] = ACTIONS(1657),
    [anon_sym_STAR] = ACTIONS(1661),
    [anon_sym_SLASH] = ACTIONS(1229),
    [anon_sym_PERCENT] = ACTIONS(1227),
    [anon_sym_CARET] = ACTIONS(1659),
    [anon_sym_PIPE] = ACTIONS(1229),
    [anon_sym_AMP] = ACTIONS(1657),
    [anon_sym_LT_LT] = ACTIONS(1227),
    [anon_sym_GT_GT] = ACTIONS(1229),
    [anon_sym_GT_GT_GT] = ACTIONS(1227),
    [anon_sym_EQ_EQ] = ACTIONS(1227),
    [anon_sym_BANG_EQ] = ACTIONS(1227),
    [anon_sym_GT_EQ] = ACTIONS(1227),
    [anon_sym_LT_EQ] = ACTIONS(1227),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_DOT] = ACTIONS(1229),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_EQ_GT] = ACTIONS(1227),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1229),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1663),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1665),
    [anon_sym_DOT_DOT] = ACTIONS(1667),
    [anon_sym_and] = ACTIONS(1229),
    [anon_sym_or] = ACTIONS(1229),
    [anon_sym_AMP_AMP] = ACTIONS(1227),
    [anon_sym_PIPE_PIPE] = ACTIONS(1227),
    [anon_sym_QMARK_QMARK] = ACTIONS(1227),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1229),
    [anon_sym_is] = ACTIONS(1229),
    [anon_sym_DASH_GT] = ACTIONS(1227),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_with] = ACTIONS(1229),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [265] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7085),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6062),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4345),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7436),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9001),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(265),
    [sym_preproc_endregion] = STATE(265),
    [sym_preproc_line] = STATE(265),
    [sym_preproc_pragma] = STATE(265),
    [sym_preproc_nullable] = STATE(265),
    [sym_preproc_error] = STATE(265),
    [sym_preproc_warning] = STATE(265),
    [sym_preproc_define] = STATE(265),
    [sym_preproc_undef] = STATE(265),
    [aux_sym_class_declaration_repeat1] = STATE(3846),
    [aux_sym_lambda_expression_repeat1] = STATE(4278),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1669),
    [anon_sym_ref] = ACTIONS(1671),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_LT] = ACTIONS(1171),
    [anon_sym_GT] = ACTIONS(1171),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1171),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1673),
    [anon_sym_TILDE] = ACTIONS(1675),
    [anon_sym_PLUS_PLUS] = ACTIONS(1675),
    [anon_sym_DASH_DASH] = ACTIONS(1675),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_STAR] = ACTIONS(1677),
    [anon_sym_SLASH] = ACTIONS(1171),
    [anon_sym_PERCENT] = ACTIONS(1157),
    [anon_sym_CARET] = ACTIONS(1675),
    [anon_sym_PIPE] = ACTIONS(1171),
    [anon_sym_AMP] = ACTIONS(1673),
    [anon_sym_LT_LT] = ACTIONS(1157),
    [anon_sym_GT_GT] = ACTIONS(1171),
    [anon_sym_GT_GT_GT] = ACTIONS(1157),
    [anon_sym_EQ_EQ] = ACTIONS(1157),
    [anon_sym_BANG_EQ] = ACTIONS(1157),
    [anon_sym_GT_EQ] = ACTIONS(1157),
    [anon_sym_LT_EQ] = ACTIONS(1157),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_DOT] = ACTIONS(1171),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_EQ_GT] = ACTIONS(1157),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1171),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1679),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1681),
    [anon_sym_DOT_DOT] = ACTIONS(1683),
    [anon_sym_and] = ACTIONS(1171),
    [anon_sym_or] = ACTIONS(1171),
    [anon_sym_AMP_AMP] = ACTIONS(1157),
    [anon_sym_PIPE_PIPE] = ACTIONS(1157),
    [anon_sym_QMARK_QMARK] = ACTIONS(1157),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1171),
    [anon_sym_is] = ACTIONS(1171),
    [anon_sym_DASH_GT] = ACTIONS(1157),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_with] = ACTIONS(1171),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [266] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7085),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5888),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4345),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7436),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9001),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(266),
    [sym_preproc_endregion] = STATE(266),
    [sym_preproc_line] = STATE(266),
    [sym_preproc_pragma] = STATE(266),
    [sym_preproc_nullable] = STATE(266),
    [sym_preproc_error] = STATE(266),
    [sym_preproc_warning] = STATE(266),
    [sym_preproc_define] = STATE(266),
    [sym_preproc_undef] = STATE(266),
    [aux_sym_class_declaration_repeat1] = STATE(3846),
    [aux_sym_lambda_expression_repeat1] = STATE(4278),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1669),
    [anon_sym_ref] = ACTIONS(1671),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_LT] = ACTIONS(1229),
    [anon_sym_GT] = ACTIONS(1229),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1229),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1673),
    [anon_sym_TILDE] = ACTIONS(1675),
    [anon_sym_PLUS_PLUS] = ACTIONS(1675),
    [anon_sym_DASH_DASH] = ACTIONS(1675),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_STAR] = ACTIONS(1677),
    [anon_sym_SLASH] = ACTIONS(1229),
    [anon_sym_PERCENT] = ACTIONS(1227),
    [anon_sym_CARET] = ACTIONS(1675),
    [anon_sym_PIPE] = ACTIONS(1229),
    [anon_sym_AMP] = ACTIONS(1673),
    [anon_sym_LT_LT] = ACTIONS(1227),
    [anon_sym_GT_GT] = ACTIONS(1229),
    [anon_sym_GT_GT_GT] = ACTIONS(1227),
    [anon_sym_EQ_EQ] = ACTIONS(1227),
    [anon_sym_BANG_EQ] = ACTIONS(1227),
    [anon_sym_GT_EQ] = ACTIONS(1227),
    [anon_sym_LT_EQ] = ACTIONS(1227),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_DOT] = ACTIONS(1229),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_EQ_GT] = ACTIONS(1227),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1229),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1679),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1681),
    [anon_sym_DOT_DOT] = ACTIONS(1683),
    [anon_sym_and] = ACTIONS(1229),
    [anon_sym_or] = ACTIONS(1229),
    [anon_sym_AMP_AMP] = ACTIONS(1227),
    [anon_sym_PIPE_PIPE] = ACTIONS(1227),
    [anon_sym_QMARK_QMARK] = ACTIONS(1227),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1229),
    [anon_sym_is] = ACTIONS(1229),
    [anon_sym_DASH_GT] = ACTIONS(1227),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_with] = ACTIONS(1229),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [267] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5608),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(267),
    [sym_preproc_endregion] = STATE(267),
    [sym_preproc_line] = STATE(267),
    [sym_preproc_pragma] = STATE(267),
    [sym_preproc_nullable] = STATE(267),
    [sym_preproc_error] = STATE(267),
    [sym_preproc_warning] = STATE(267),
    [sym_preproc_define] = STATE(267),
    [sym_preproc_undef] = STATE(267),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_list_pattern_repeat1] = STATE(8636),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_COMMA] = ACTIONS(1157),
    [anon_sym_RBRACK] = ACTIONS(1157),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(1171),
    [anon_sym_GT] = ACTIONS(1171),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1171),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1511),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_SLASH] = ACTIONS(1171),
    [anon_sym_PERCENT] = ACTIONS(1157),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_PIPE] = ACTIONS(1171),
    [anon_sym_AMP] = ACTIONS(1511),
    [anon_sym_LT_LT] = ACTIONS(1157),
    [anon_sym_GT_GT] = ACTIONS(1171),
    [anon_sym_GT_GT_GT] = ACTIONS(1157),
    [anon_sym_EQ_EQ] = ACTIONS(1157),
    [anon_sym_BANG_EQ] = ACTIONS(1157),
    [anon_sym_GT_EQ] = ACTIONS(1157),
    [anon_sym_LT_EQ] = ACTIONS(1157),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(1171),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1171),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_AMP_AMP] = ACTIONS(1157),
    [anon_sym_PIPE_PIPE] = ACTIONS(1157),
    [anon_sym_QMARK_QMARK] = ACTIONS(1157),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1171),
    [anon_sym_is] = ACTIONS(1171),
    [anon_sym_DASH_GT] = ACTIONS(1157),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_with] = ACTIONS(1171),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [268] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6911),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2930),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7027),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4474),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3605),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7434),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9856),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(268),
    [sym_preproc_endregion] = STATE(268),
    [sym_preproc_line] = STATE(268),
    [sym_preproc_pragma] = STATE(268),
    [sym_preproc_nullable] = STATE(268),
    [sym_preproc_error] = STATE(268),
    [sym_preproc_warning] = STATE(268),
    [sym_preproc_define] = STATE(268),
    [sym_preproc_undef] = STATE(268),
    [aux_sym_class_declaration_repeat1] = STATE(3828),
    [aux_sym_lambda_expression_repeat1] = STATE(4248),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_COMMA] = ACTIONS(1227),
    [anon_sym_LPAREN] = ACTIONS(1687),
    [anon_sym_ref] = ACTIONS(1689),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1695),
    [anon_sym_LT] = ACTIONS(1229),
    [anon_sym_GT] = ACTIONS(1229),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1229),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1699),
    [anon_sym_TILDE] = ACTIONS(1701),
    [anon_sym_PLUS_PLUS] = ACTIONS(1701),
    [anon_sym_DASH_DASH] = ACTIONS(1701),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1699),
    [anon_sym_DASH] = ACTIONS(1699),
    [anon_sym_STAR] = ACTIONS(1705),
    [anon_sym_SLASH] = ACTIONS(1229),
    [anon_sym_PERCENT] = ACTIONS(1227),
    [anon_sym_CARET] = ACTIONS(1701),
    [anon_sym_PIPE] = ACTIONS(1229),
    [anon_sym_AMP] = ACTIONS(1699),
    [anon_sym_LT_LT] = ACTIONS(1227),
    [anon_sym_GT_GT] = ACTIONS(1229),
    [anon_sym_GT_GT_GT] = ACTIONS(1227),
    [anon_sym_EQ_EQ] = ACTIONS(1227),
    [anon_sym_BANG_EQ] = ACTIONS(1227),
    [anon_sym_GT_EQ] = ACTIONS(1227),
    [anon_sym_LT_EQ] = ACTIONS(1227),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_DOT] = ACTIONS(1229),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1229),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(1715),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1717),
    [anon_sym_DOT_DOT] = ACTIONS(1719),
    [anon_sym_and] = ACTIONS(1229),
    [anon_sym_or] = ACTIONS(1229),
    [anon_sym_AMP_AMP] = ACTIONS(1227),
    [anon_sym_PIPE_PIPE] = ACTIONS(1227),
    [anon_sym_QMARK_QMARK] = ACTIONS(1227),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1229),
    [anon_sym_is] = ACTIONS(1229),
    [anon_sym_DASH_GT] = ACTIONS(1227),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_with] = ACTIONS(1229),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [269] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7010),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6084),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4334),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9265),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(269),
    [sym_preproc_endregion] = STATE(269),
    [sym_preproc_line] = STATE(269),
    [sym_preproc_pragma] = STATE(269),
    [sym_preproc_nullable] = STATE(269),
    [sym_preproc_error] = STATE(269),
    [sym_preproc_warning] = STATE(269),
    [sym_preproc_define] = STATE(269),
    [sym_preproc_undef] = STATE(269),
    [aux_sym_class_declaration_repeat1] = STATE(3823),
    [aux_sym_lambda_expression_repeat1] = STATE(4240),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1751),
    [anon_sym_ref] = ACTIONS(1753),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1755),
    [anon_sym_LT] = ACTIONS(1171),
    [anon_sym_GT] = ACTIONS(1171),
    [anon_sym_in] = ACTIONS(1171),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1171),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1757),
    [anon_sym_TILDE] = ACTIONS(1759),
    [anon_sym_PLUS_PLUS] = ACTIONS(1759),
    [anon_sym_DASH_DASH] = ACTIONS(1759),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1757),
    [anon_sym_DASH] = ACTIONS(1757),
    [anon_sym_STAR] = ACTIONS(1381),
    [anon_sym_SLASH] = ACTIONS(1171),
    [anon_sym_PERCENT] = ACTIONS(1157),
    [anon_sym_CARET] = ACTIONS(1759),
    [anon_sym_PIPE] = ACTIONS(1171),
    [anon_sym_AMP] = ACTIONS(1757),
    [anon_sym_LT_LT] = ACTIONS(1157),
    [anon_sym_GT_GT] = ACTIONS(1171),
    [anon_sym_GT_GT_GT] = ACTIONS(1157),
    [anon_sym_EQ_EQ] = ACTIONS(1157),
    [anon_sym_BANG_EQ] = ACTIONS(1157),
    [anon_sym_GT_EQ] = ACTIONS(1157),
    [anon_sym_LT_EQ] = ACTIONS(1157),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_DOT] = ACTIONS(1171),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1171),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1761),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1763),
    [anon_sym_DOT_DOT] = ACTIONS(1765),
    [anon_sym_and] = ACTIONS(1171),
    [anon_sym_or] = ACTIONS(1171),
    [anon_sym_AMP_AMP] = ACTIONS(1157),
    [anon_sym_PIPE_PIPE] = ACTIONS(1157),
    [anon_sym_QMARK_QMARK] = ACTIONS(1157),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1171),
    [anon_sym_is] = ACTIONS(1171),
    [anon_sym_DASH_GT] = ACTIONS(1157),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_with] = ACTIONS(1171),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [270] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7010),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5960),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4334),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9265),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(270),
    [sym_preproc_endregion] = STATE(270),
    [sym_preproc_line] = STATE(270),
    [sym_preproc_pragma] = STATE(270),
    [sym_preproc_nullable] = STATE(270),
    [sym_preproc_error] = STATE(270),
    [sym_preproc_warning] = STATE(270),
    [sym_preproc_define] = STATE(270),
    [sym_preproc_undef] = STATE(270),
    [aux_sym_class_declaration_repeat1] = STATE(3823),
    [aux_sym_lambda_expression_repeat1] = STATE(4240),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1751),
    [anon_sym_ref] = ACTIONS(1753),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1755),
    [anon_sym_LT] = ACTIONS(1229),
    [anon_sym_GT] = ACTIONS(1229),
    [anon_sym_in] = ACTIONS(1229),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1229),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1757),
    [anon_sym_TILDE] = ACTIONS(1759),
    [anon_sym_PLUS_PLUS] = ACTIONS(1759),
    [anon_sym_DASH_DASH] = ACTIONS(1759),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1757),
    [anon_sym_DASH] = ACTIONS(1757),
    [anon_sym_STAR] = ACTIONS(1381),
    [anon_sym_SLASH] = ACTIONS(1229),
    [anon_sym_PERCENT] = ACTIONS(1227),
    [anon_sym_CARET] = ACTIONS(1759),
    [anon_sym_PIPE] = ACTIONS(1229),
    [anon_sym_AMP] = ACTIONS(1757),
    [anon_sym_LT_LT] = ACTIONS(1227),
    [anon_sym_GT_GT] = ACTIONS(1229),
    [anon_sym_GT_GT_GT] = ACTIONS(1227),
    [anon_sym_EQ_EQ] = ACTIONS(1227),
    [anon_sym_BANG_EQ] = ACTIONS(1227),
    [anon_sym_GT_EQ] = ACTIONS(1227),
    [anon_sym_LT_EQ] = ACTIONS(1227),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_DOT] = ACTIONS(1229),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1229),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1761),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1763),
    [anon_sym_DOT_DOT] = ACTIONS(1765),
    [anon_sym_and] = ACTIONS(1229),
    [anon_sym_or] = ACTIONS(1229),
    [anon_sym_AMP_AMP] = ACTIONS(1227),
    [anon_sym_PIPE_PIPE] = ACTIONS(1227),
    [anon_sym_QMARK_QMARK] = ACTIONS(1227),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1229),
    [anon_sym_is] = ACTIONS(1229),
    [anon_sym_DASH_GT] = ACTIONS(1227),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_with] = ACTIONS(1229),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [271] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6925),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2932),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7073),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4410),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3565),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7434),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9324),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(271),
    [sym_preproc_endregion] = STATE(271),
    [sym_preproc_line] = STATE(271),
    [sym_preproc_pragma] = STATE(271),
    [sym_preproc_nullable] = STATE(271),
    [sym_preproc_error] = STATE(271),
    [sym_preproc_warning] = STATE(271),
    [sym_preproc_define] = STATE(271),
    [sym_preproc_undef] = STATE(271),
    [aux_sym_class_declaration_repeat1] = STATE(3842),
    [aux_sym_lambda_expression_repeat1] = STATE(4273),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_COMMA] = ACTIONS(1227),
    [anon_sym_LPAREN] = ACTIONS(1767),
    [anon_sym_ref] = ACTIONS(1769),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1771),
    [anon_sym_LT] = ACTIONS(1229),
    [anon_sym_GT] = ACTIONS(1229),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1229),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1773),
    [anon_sym_TILDE] = ACTIONS(1775),
    [anon_sym_PLUS_PLUS] = ACTIONS(1775),
    [anon_sym_DASH_DASH] = ACTIONS(1775),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1773),
    [anon_sym_DASH] = ACTIONS(1773),
    [anon_sym_STAR] = ACTIONS(1777),
    [anon_sym_SLASH] = ACTIONS(1229),
    [anon_sym_PERCENT] = ACTIONS(1227),
    [anon_sym_CARET] = ACTIONS(1775),
    [anon_sym_PIPE] = ACTIONS(1229),
    [anon_sym_AMP] = ACTIONS(1773),
    [anon_sym_LT_LT] = ACTIONS(1227),
    [anon_sym_GT_GT] = ACTIONS(1229),
    [anon_sym_GT_GT_GT] = ACTIONS(1227),
    [anon_sym_EQ_EQ] = ACTIONS(1227),
    [anon_sym_BANG_EQ] = ACTIONS(1227),
    [anon_sym_GT_EQ] = ACTIONS(1227),
    [anon_sym_LT_EQ] = ACTIONS(1227),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_DOT] = ACTIONS(1229),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1229),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(1779),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1781),
    [anon_sym_DOT_DOT] = ACTIONS(1783),
    [anon_sym_and] = ACTIONS(1229),
    [anon_sym_or] = ACTIONS(1229),
    [anon_sym_AMP_AMP] = ACTIONS(1227),
    [anon_sym_PIPE_PIPE] = ACTIONS(1227),
    [anon_sym_QMARK_QMARK] = ACTIONS(1227),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1229),
    [anon_sym_is] = ACTIONS(1229),
    [anon_sym_DASH_GT] = ACTIONS(1227),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_with] = ACTIONS(1229),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [272] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5608),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(272),
    [sym_preproc_endregion] = STATE(272),
    [sym_preproc_line] = STATE(272),
    [sym_preproc_pragma] = STATE(272),
    [sym_preproc_nullable] = STATE(272),
    [sym_preproc_error] = STATE(272),
    [sym_preproc_warning] = STATE(272),
    [sym_preproc_define] = STATE(272),
    [sym_preproc_undef] = STATE(272),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_list_pattern_repeat1] = STATE(8698),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_COMMA] = ACTIONS(1157),
    [anon_sym_RBRACK] = ACTIONS(1157),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(1171),
    [anon_sym_GT] = ACTIONS(1171),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1171),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1511),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_SLASH] = ACTIONS(1171),
    [anon_sym_PERCENT] = ACTIONS(1157),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_PIPE] = ACTIONS(1171),
    [anon_sym_AMP] = ACTIONS(1511),
    [anon_sym_LT_LT] = ACTIONS(1157),
    [anon_sym_GT_GT] = ACTIONS(1171),
    [anon_sym_GT_GT_GT] = ACTIONS(1157),
    [anon_sym_EQ_EQ] = ACTIONS(1157),
    [anon_sym_BANG_EQ] = ACTIONS(1157),
    [anon_sym_GT_EQ] = ACTIONS(1157),
    [anon_sym_LT_EQ] = ACTIONS(1157),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(1171),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1171),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_AMP_AMP] = ACTIONS(1157),
    [anon_sym_PIPE_PIPE] = ACTIONS(1157),
    [anon_sym_QMARK_QMARK] = ACTIONS(1157),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1171),
    [anon_sym_is] = ACTIONS(1171),
    [anon_sym_DASH_GT] = ACTIONS(1157),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_with] = ACTIONS(1171),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [273] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5608),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(273),
    [sym_preproc_endregion] = STATE(273),
    [sym_preproc_line] = STATE(273),
    [sym_preproc_pragma] = STATE(273),
    [sym_preproc_nullable] = STATE(273),
    [sym_preproc_error] = STATE(273),
    [sym_preproc_warning] = STATE(273),
    [sym_preproc_define] = STATE(273),
    [sym_preproc_undef] = STATE(273),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_list_pattern_repeat1] = STATE(8614),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_COMMA] = ACTIONS(1157),
    [anon_sym_RBRACK] = ACTIONS(1157),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(1171),
    [anon_sym_GT] = ACTIONS(1171),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1171),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1511),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_SLASH] = ACTIONS(1171),
    [anon_sym_PERCENT] = ACTIONS(1157),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_PIPE] = ACTIONS(1171),
    [anon_sym_AMP] = ACTIONS(1511),
    [anon_sym_LT_LT] = ACTIONS(1157),
    [anon_sym_GT_GT] = ACTIONS(1171),
    [anon_sym_GT_GT_GT] = ACTIONS(1157),
    [anon_sym_EQ_EQ] = ACTIONS(1157),
    [anon_sym_BANG_EQ] = ACTIONS(1157),
    [anon_sym_GT_EQ] = ACTIONS(1157),
    [anon_sym_LT_EQ] = ACTIONS(1157),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(1171),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1171),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_AMP_AMP] = ACTIONS(1157),
    [anon_sym_PIPE_PIPE] = ACTIONS(1157),
    [anon_sym_QMARK_QMARK] = ACTIONS(1157),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1171),
    [anon_sym_is] = ACTIONS(1171),
    [anon_sym_DASH_GT] = ACTIONS(1157),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_with] = ACTIONS(1171),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [274] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5608),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(274),
    [sym_preproc_endregion] = STATE(274),
    [sym_preproc_line] = STATE(274),
    [sym_preproc_pragma] = STATE(274),
    [sym_preproc_nullable] = STATE(274),
    [sym_preproc_error] = STATE(274),
    [sym_preproc_warning] = STATE(274),
    [sym_preproc_define] = STATE(274),
    [sym_preproc_undef] = STATE(274),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_list_pattern_repeat1] = STATE(8561),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_COMMA] = ACTIONS(1157),
    [anon_sym_RBRACK] = ACTIONS(1157),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(1171),
    [anon_sym_GT] = ACTIONS(1171),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1171),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1511),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_SLASH] = ACTIONS(1171),
    [anon_sym_PERCENT] = ACTIONS(1157),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_PIPE] = ACTIONS(1171),
    [anon_sym_AMP] = ACTIONS(1511),
    [anon_sym_LT_LT] = ACTIONS(1157),
    [anon_sym_GT_GT] = ACTIONS(1171),
    [anon_sym_GT_GT_GT] = ACTIONS(1157),
    [anon_sym_EQ_EQ] = ACTIONS(1157),
    [anon_sym_BANG_EQ] = ACTIONS(1157),
    [anon_sym_GT_EQ] = ACTIONS(1157),
    [anon_sym_LT_EQ] = ACTIONS(1157),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(1171),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1171),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_AMP_AMP] = ACTIONS(1157),
    [anon_sym_PIPE_PIPE] = ACTIONS(1157),
    [anon_sym_QMARK_QMARK] = ACTIONS(1157),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1171),
    [anon_sym_is] = ACTIONS(1171),
    [anon_sym_DASH_GT] = ACTIONS(1157),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_with] = ACTIONS(1171),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [275] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6912),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2912),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7040),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5407),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3963),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7448),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9641),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(275),
    [sym_preproc_endregion] = STATE(275),
    [sym_preproc_line] = STATE(275),
    [sym_preproc_pragma] = STATE(275),
    [sym_preproc_nullable] = STATE(275),
    [sym_preproc_error] = STATE(275),
    [sym_preproc_warning] = STATE(275),
    [sym_preproc_define] = STATE(275),
    [sym_preproc_undef] = STATE(275),
    [aux_sym_class_declaration_repeat1] = STATE(3831),
    [aux_sym_lambda_expression_repeat1] = STATE(4257),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1785),
    [anon_sym_ref] = ACTIONS(1787),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1595),
    [anon_sym_LT] = ACTIONS(1171),
    [anon_sym_GT] = ACTIONS(1171),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1171),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1789),
    [anon_sym_TILDE] = ACTIONS(1791),
    [anon_sym_PLUS_PLUS] = ACTIONS(1791),
    [anon_sym_DASH_DASH] = ACTIONS(1791),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1789),
    [anon_sym_DASH] = ACTIONS(1789),
    [anon_sym_STAR] = ACTIONS(1793),
    [anon_sym_SLASH] = ACTIONS(1171),
    [anon_sym_PERCENT] = ACTIONS(1157),
    [anon_sym_CARET] = ACTIONS(1791),
    [anon_sym_PIPE] = ACTIONS(1171),
    [anon_sym_AMP] = ACTIONS(1789),
    [anon_sym_LT_LT] = ACTIONS(1157),
    [anon_sym_GT_GT] = ACTIONS(1171),
    [anon_sym_GT_GT_GT] = ACTIONS(1157),
    [anon_sym_EQ_EQ] = ACTIONS(1157),
    [anon_sym_BANG_EQ] = ACTIONS(1157),
    [anon_sym_GT_EQ] = ACTIONS(1157),
    [anon_sym_LT_EQ] = ACTIONS(1157),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_DOT] = ACTIONS(1171),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_EQ_GT] = ACTIONS(1157),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1171),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1795),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1797),
    [anon_sym_DOT_DOT] = ACTIONS(1799),
    [anon_sym_and] = ACTIONS(1171),
    [anon_sym_or] = ACTIONS(1171),
    [anon_sym_AMP_AMP] = ACTIONS(1157),
    [anon_sym_PIPE_PIPE] = ACTIONS(1157),
    [anon_sym_QMARK_QMARK] = ACTIONS(1157),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1171),
    [anon_sym_is] = ACTIONS(1171),
    [anon_sym_DASH_GT] = ACTIONS(1157),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_with] = ACTIONS(1171),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [276] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6911),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2930),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7027),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4475),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3605),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7434),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9856),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(276),
    [sym_preproc_endregion] = STATE(276),
    [sym_preproc_line] = STATE(276),
    [sym_preproc_pragma] = STATE(276),
    [sym_preproc_nullable] = STATE(276),
    [sym_preproc_error] = STATE(276),
    [sym_preproc_warning] = STATE(276),
    [sym_preproc_define] = STATE(276),
    [sym_preproc_undef] = STATE(276),
    [aux_sym_class_declaration_repeat1] = STATE(3828),
    [aux_sym_lambda_expression_repeat1] = STATE(4248),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_COMMA] = ACTIONS(1157),
    [anon_sym_LPAREN] = ACTIONS(1687),
    [anon_sym_ref] = ACTIONS(1689),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1695),
    [anon_sym_LT] = ACTIONS(1171),
    [anon_sym_GT] = ACTIONS(1171),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1171),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1699),
    [anon_sym_TILDE] = ACTIONS(1701),
    [anon_sym_PLUS_PLUS] = ACTIONS(1701),
    [anon_sym_DASH_DASH] = ACTIONS(1701),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1699),
    [anon_sym_DASH] = ACTIONS(1699),
    [anon_sym_STAR] = ACTIONS(1705),
    [anon_sym_SLASH] = ACTIONS(1171),
    [anon_sym_PERCENT] = ACTIONS(1157),
    [anon_sym_CARET] = ACTIONS(1701),
    [anon_sym_PIPE] = ACTIONS(1171),
    [anon_sym_AMP] = ACTIONS(1699),
    [anon_sym_LT_LT] = ACTIONS(1157),
    [anon_sym_GT_GT] = ACTIONS(1171),
    [anon_sym_GT_GT_GT] = ACTIONS(1157),
    [anon_sym_EQ_EQ] = ACTIONS(1157),
    [anon_sym_BANG_EQ] = ACTIONS(1157),
    [anon_sym_GT_EQ] = ACTIONS(1157),
    [anon_sym_LT_EQ] = ACTIONS(1157),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_DOT] = ACTIONS(1171),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1171),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(1715),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1717),
    [anon_sym_DOT_DOT] = ACTIONS(1719),
    [anon_sym_and] = ACTIONS(1171),
    [anon_sym_or] = ACTIONS(1171),
    [anon_sym_AMP_AMP] = ACTIONS(1157),
    [anon_sym_PIPE_PIPE] = ACTIONS(1157),
    [anon_sym_QMARK_QMARK] = ACTIONS(1157),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1171),
    [anon_sym_is] = ACTIONS(1171),
    [anon_sym_DASH_GT] = ACTIONS(1157),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_with] = ACTIONS(1171),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [277] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6925),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2932),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7073),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4450),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3565),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7434),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9324),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(277),
    [sym_preproc_endregion] = STATE(277),
    [sym_preproc_line] = STATE(277),
    [sym_preproc_pragma] = STATE(277),
    [sym_preproc_nullable] = STATE(277),
    [sym_preproc_error] = STATE(277),
    [sym_preproc_warning] = STATE(277),
    [sym_preproc_define] = STATE(277),
    [sym_preproc_undef] = STATE(277),
    [aux_sym_class_declaration_repeat1] = STATE(3842),
    [aux_sym_lambda_expression_repeat1] = STATE(4273),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_COMMA] = ACTIONS(1157),
    [anon_sym_LPAREN] = ACTIONS(1767),
    [anon_sym_ref] = ACTIONS(1769),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1771),
    [anon_sym_LT] = ACTIONS(1171),
    [anon_sym_GT] = ACTIONS(1171),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1171),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1773),
    [anon_sym_TILDE] = ACTIONS(1775),
    [anon_sym_PLUS_PLUS] = ACTIONS(1775),
    [anon_sym_DASH_DASH] = ACTIONS(1775),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1773),
    [anon_sym_DASH] = ACTIONS(1773),
    [anon_sym_STAR] = ACTIONS(1777),
    [anon_sym_SLASH] = ACTIONS(1171),
    [anon_sym_PERCENT] = ACTIONS(1157),
    [anon_sym_CARET] = ACTIONS(1775),
    [anon_sym_PIPE] = ACTIONS(1171),
    [anon_sym_AMP] = ACTIONS(1773),
    [anon_sym_LT_LT] = ACTIONS(1157),
    [anon_sym_GT_GT] = ACTIONS(1171),
    [anon_sym_GT_GT_GT] = ACTIONS(1157),
    [anon_sym_EQ_EQ] = ACTIONS(1157),
    [anon_sym_BANG_EQ] = ACTIONS(1157),
    [anon_sym_GT_EQ] = ACTIONS(1157),
    [anon_sym_LT_EQ] = ACTIONS(1157),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_DOT] = ACTIONS(1171),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1171),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(1779),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1781),
    [anon_sym_DOT_DOT] = ACTIONS(1783),
    [anon_sym_and] = ACTIONS(1171),
    [anon_sym_or] = ACTIONS(1171),
    [anon_sym_AMP_AMP] = ACTIONS(1157),
    [anon_sym_PIPE_PIPE] = ACTIONS(1157),
    [anon_sym_QMARK_QMARK] = ACTIONS(1157),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1171),
    [anon_sym_is] = ACTIONS(1171),
    [anon_sym_DASH_GT] = ACTIONS(1157),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_with] = ACTIONS(1171),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [278] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6912),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2912),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7040),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5337),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3963),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7448),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9641),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(278),
    [sym_preproc_endregion] = STATE(278),
    [sym_preproc_line] = STATE(278),
    [sym_preproc_pragma] = STATE(278),
    [sym_preproc_nullable] = STATE(278),
    [sym_preproc_error] = STATE(278),
    [sym_preproc_warning] = STATE(278),
    [sym_preproc_define] = STATE(278),
    [sym_preproc_undef] = STATE(278),
    [aux_sym_class_declaration_repeat1] = STATE(3831),
    [aux_sym_lambda_expression_repeat1] = STATE(4257),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1785),
    [anon_sym_ref] = ACTIONS(1787),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1595),
    [anon_sym_LT] = ACTIONS(1229),
    [anon_sym_GT] = ACTIONS(1229),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1229),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1789),
    [anon_sym_TILDE] = ACTIONS(1791),
    [anon_sym_PLUS_PLUS] = ACTIONS(1791),
    [anon_sym_DASH_DASH] = ACTIONS(1791),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1789),
    [anon_sym_DASH] = ACTIONS(1789),
    [anon_sym_STAR] = ACTIONS(1793),
    [anon_sym_SLASH] = ACTIONS(1229),
    [anon_sym_PERCENT] = ACTIONS(1227),
    [anon_sym_CARET] = ACTIONS(1791),
    [anon_sym_PIPE] = ACTIONS(1229),
    [anon_sym_AMP] = ACTIONS(1789),
    [anon_sym_LT_LT] = ACTIONS(1227),
    [anon_sym_GT_GT] = ACTIONS(1229),
    [anon_sym_GT_GT_GT] = ACTIONS(1227),
    [anon_sym_EQ_EQ] = ACTIONS(1227),
    [anon_sym_BANG_EQ] = ACTIONS(1227),
    [anon_sym_GT_EQ] = ACTIONS(1227),
    [anon_sym_LT_EQ] = ACTIONS(1227),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_DOT] = ACTIONS(1229),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_EQ_GT] = ACTIONS(1227),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1229),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1795),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1797),
    [anon_sym_DOT_DOT] = ACTIONS(1799),
    [anon_sym_and] = ACTIONS(1229),
    [anon_sym_or] = ACTIONS(1229),
    [anon_sym_AMP_AMP] = ACTIONS(1227),
    [anon_sym_PIPE_PIPE] = ACTIONS(1227),
    [anon_sym_QMARK_QMARK] = ACTIONS(1227),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1229),
    [anon_sym_is] = ACTIONS(1229),
    [anon_sym_DASH_GT] = ACTIONS(1227),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_with] = ACTIONS(1229),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [279] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6920),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2942),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7032),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6087),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4337),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7427),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9283),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(279),
    [sym_preproc_endregion] = STATE(279),
    [sym_preproc_line] = STATE(279),
    [sym_preproc_pragma] = STATE(279),
    [sym_preproc_nullable] = STATE(279),
    [sym_preproc_error] = STATE(279),
    [sym_preproc_warning] = STATE(279),
    [sym_preproc_define] = STATE(279),
    [sym_preproc_undef] = STATE(279),
    [aux_sym_class_declaration_repeat1] = STATE(3829),
    [aux_sym_lambda_expression_repeat1] = STATE(4252),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1801),
    [anon_sym_ref] = ACTIONS(1803),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1805),
    [anon_sym_LT] = ACTIONS(1229),
    [anon_sym_GT] = ACTIONS(1229),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1229),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1807),
    [anon_sym_TILDE] = ACTIONS(1809),
    [anon_sym_PLUS_PLUS] = ACTIONS(1809),
    [anon_sym_DASH_DASH] = ACTIONS(1809),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1807),
    [anon_sym_DASH] = ACTIONS(1807),
    [anon_sym_STAR] = ACTIONS(1811),
    [anon_sym_SLASH] = ACTIONS(1229),
    [anon_sym_PERCENT] = ACTIONS(1227),
    [anon_sym_CARET] = ACTIONS(1809),
    [anon_sym_PIPE] = ACTIONS(1229),
    [anon_sym_AMP] = ACTIONS(1807),
    [anon_sym_LT_LT] = ACTIONS(1227),
    [anon_sym_GT_GT] = ACTIONS(1229),
    [anon_sym_GT_GT_GT] = ACTIONS(1227),
    [anon_sym_EQ_EQ] = ACTIONS(1227),
    [anon_sym_BANG_EQ] = ACTIONS(1227),
    [anon_sym_GT_EQ] = ACTIONS(1227),
    [anon_sym_LT_EQ] = ACTIONS(1227),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_DOT] = ACTIONS(1229),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1229),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1813),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1815),
    [anon_sym_DOT_DOT] = ACTIONS(1817),
    [anon_sym_and] = ACTIONS(1229),
    [anon_sym_or] = ACTIONS(1229),
    [anon_sym_AMP_AMP] = ACTIONS(1227),
    [anon_sym_PIPE_PIPE] = ACTIONS(1227),
    [anon_sym_QMARK_QMARK] = ACTIONS(1227),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1229),
    [anon_sym_is] = ACTIONS(1229),
    [anon_sym_DASH_GT] = ACTIONS(1227),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_with] = ACTIONS(1229),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [280] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6910),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2960),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7091),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5508),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4208),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7438),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9067),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(280),
    [sym_preproc_endregion] = STATE(280),
    [sym_preproc_line] = STATE(280),
    [sym_preproc_pragma] = STATE(280),
    [sym_preproc_nullable] = STATE(280),
    [sym_preproc_error] = STATE(280),
    [sym_preproc_warning] = STATE(280),
    [sym_preproc_define] = STATE(280),
    [sym_preproc_undef] = STATE(280),
    [aux_sym_class_declaration_repeat1] = STATE(3847),
    [aux_sym_lambda_expression_repeat1] = STATE(4280),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1819),
    [anon_sym_ref] = ACTIONS(1821),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1823),
    [anon_sym_LT] = ACTIONS(1229),
    [anon_sym_GT] = ACTIONS(1229),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1229),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1825),
    [anon_sym_TILDE] = ACTIONS(1827),
    [anon_sym_PLUS_PLUS] = ACTIONS(1827),
    [anon_sym_DASH_DASH] = ACTIONS(1827),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1825),
    [anon_sym_DASH] = ACTIONS(1825),
    [anon_sym_STAR] = ACTIONS(1829),
    [anon_sym_SLASH] = ACTIONS(1229),
    [anon_sym_PERCENT] = ACTIONS(1227),
    [anon_sym_CARET] = ACTIONS(1827),
    [anon_sym_PIPE] = ACTIONS(1229),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_LT_LT] = ACTIONS(1227),
    [anon_sym_GT_GT] = ACTIONS(1229),
    [anon_sym_GT_GT_GT] = ACTIONS(1227),
    [anon_sym_EQ_EQ] = ACTIONS(1227),
    [anon_sym_BANG_EQ] = ACTIONS(1227),
    [anon_sym_GT_EQ] = ACTIONS(1227),
    [anon_sym_LT_EQ] = ACTIONS(1227),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_DOT] = ACTIONS(1229),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1229),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1831),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1833),
    [anon_sym_DOT_DOT] = ACTIONS(1835),
    [anon_sym_and] = ACTIONS(1229),
    [anon_sym_or] = ACTIONS(1229),
    [anon_sym_AMP_AMP] = ACTIONS(1227),
    [anon_sym_PIPE_PIPE] = ACTIONS(1227),
    [anon_sym_QMARK_QMARK] = ACTIONS(1227),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1229),
    [anon_sym_is] = ACTIONS(1229),
    [anon_sym_DASH_GT] = ACTIONS(1227),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_with] = ACTIONS(1229),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [281] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6920),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2942),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7032),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6049),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4337),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7427),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9283),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(281),
    [sym_preproc_endregion] = STATE(281),
    [sym_preproc_line] = STATE(281),
    [sym_preproc_pragma] = STATE(281),
    [sym_preproc_nullable] = STATE(281),
    [sym_preproc_error] = STATE(281),
    [sym_preproc_warning] = STATE(281),
    [sym_preproc_define] = STATE(281),
    [sym_preproc_undef] = STATE(281),
    [aux_sym_class_declaration_repeat1] = STATE(3829),
    [aux_sym_lambda_expression_repeat1] = STATE(4252),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1801),
    [anon_sym_ref] = ACTIONS(1803),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1805),
    [anon_sym_LT] = ACTIONS(1171),
    [anon_sym_GT] = ACTIONS(1171),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1171),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1807),
    [anon_sym_TILDE] = ACTIONS(1809),
    [anon_sym_PLUS_PLUS] = ACTIONS(1809),
    [anon_sym_DASH_DASH] = ACTIONS(1809),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1807),
    [anon_sym_DASH] = ACTIONS(1807),
    [anon_sym_STAR] = ACTIONS(1811),
    [anon_sym_SLASH] = ACTIONS(1171),
    [anon_sym_PERCENT] = ACTIONS(1157),
    [anon_sym_CARET] = ACTIONS(1809),
    [anon_sym_PIPE] = ACTIONS(1171),
    [anon_sym_AMP] = ACTIONS(1807),
    [anon_sym_LT_LT] = ACTIONS(1157),
    [anon_sym_GT_GT] = ACTIONS(1171),
    [anon_sym_GT_GT_GT] = ACTIONS(1157),
    [anon_sym_EQ_EQ] = ACTIONS(1157),
    [anon_sym_BANG_EQ] = ACTIONS(1157),
    [anon_sym_GT_EQ] = ACTIONS(1157),
    [anon_sym_LT_EQ] = ACTIONS(1157),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_DOT] = ACTIONS(1171),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1171),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1813),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1815),
    [anon_sym_DOT_DOT] = ACTIONS(1817),
    [anon_sym_and] = ACTIONS(1171),
    [anon_sym_or] = ACTIONS(1171),
    [anon_sym_AMP_AMP] = ACTIONS(1157),
    [anon_sym_PIPE_PIPE] = ACTIONS(1157),
    [anon_sym_QMARK_QMARK] = ACTIONS(1157),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1171),
    [anon_sym_is] = ACTIONS(1171),
    [anon_sym_DASH_GT] = ACTIONS(1157),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_with] = ACTIONS(1171),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [282] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6933),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2950),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7095),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5728),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4215),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7446),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9108),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(282),
    [sym_preproc_endregion] = STATE(282),
    [sym_preproc_line] = STATE(282),
    [sym_preproc_pragma] = STATE(282),
    [sym_preproc_nullable] = STATE(282),
    [sym_preproc_error] = STATE(282),
    [sym_preproc_warning] = STATE(282),
    [sym_preproc_define] = STATE(282),
    [sym_preproc_undef] = STATE(282),
    [aux_sym_class_declaration_repeat1] = STATE(3848),
    [aux_sym_lambda_expression_repeat1] = STATE(4282),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1837),
    [anon_sym_ref] = ACTIONS(1839),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1841),
    [anon_sym_LT] = ACTIONS(1171),
    [anon_sym_GT] = ACTIONS(1171),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1171),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1843),
    [anon_sym_TILDE] = ACTIONS(1845),
    [anon_sym_PLUS_PLUS] = ACTIONS(1845),
    [anon_sym_DASH_DASH] = ACTIONS(1845),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1843),
    [anon_sym_DASH] = ACTIONS(1843),
    [anon_sym_STAR] = ACTIONS(1847),
    [anon_sym_SLASH] = ACTIONS(1171),
    [anon_sym_PERCENT] = ACTIONS(1157),
    [anon_sym_CARET] = ACTIONS(1845),
    [anon_sym_PIPE] = ACTIONS(1171),
    [anon_sym_AMP] = ACTIONS(1843),
    [anon_sym_LT_LT] = ACTIONS(1157),
    [anon_sym_GT_GT] = ACTIONS(1171),
    [anon_sym_GT_GT_GT] = ACTIONS(1157),
    [anon_sym_EQ_EQ] = ACTIONS(1157),
    [anon_sym_BANG_EQ] = ACTIONS(1157),
    [anon_sym_GT_EQ] = ACTIONS(1157),
    [anon_sym_LT_EQ] = ACTIONS(1157),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_DOT] = ACTIONS(1171),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1171),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1849),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1851),
    [anon_sym_DOT_DOT] = ACTIONS(1853),
    [anon_sym_and] = ACTIONS(1171),
    [anon_sym_or] = ACTIONS(1171),
    [anon_sym_AMP_AMP] = ACTIONS(1157),
    [anon_sym_PIPE_PIPE] = ACTIONS(1157),
    [anon_sym_QMARK_QMARK] = ACTIONS(1157),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1171),
    [anon_sym_is] = ACTIONS(1171),
    [anon_sym_DASH_GT] = ACTIONS(1157),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_with] = ACTIONS(1171),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [283] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6933),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2950),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7095),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5535),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4215),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7446),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9108),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(283),
    [sym_preproc_endregion] = STATE(283),
    [sym_preproc_line] = STATE(283),
    [sym_preproc_pragma] = STATE(283),
    [sym_preproc_nullable] = STATE(283),
    [sym_preproc_error] = STATE(283),
    [sym_preproc_warning] = STATE(283),
    [sym_preproc_define] = STATE(283),
    [sym_preproc_undef] = STATE(283),
    [aux_sym_class_declaration_repeat1] = STATE(3848),
    [aux_sym_lambda_expression_repeat1] = STATE(4282),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1837),
    [anon_sym_ref] = ACTIONS(1839),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1841),
    [anon_sym_LT] = ACTIONS(1229),
    [anon_sym_GT] = ACTIONS(1229),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1229),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1843),
    [anon_sym_TILDE] = ACTIONS(1845),
    [anon_sym_PLUS_PLUS] = ACTIONS(1845),
    [anon_sym_DASH_DASH] = ACTIONS(1845),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1843),
    [anon_sym_DASH] = ACTIONS(1843),
    [anon_sym_STAR] = ACTIONS(1847),
    [anon_sym_SLASH] = ACTIONS(1229),
    [anon_sym_PERCENT] = ACTIONS(1227),
    [anon_sym_CARET] = ACTIONS(1845),
    [anon_sym_PIPE] = ACTIONS(1229),
    [anon_sym_AMP] = ACTIONS(1843),
    [anon_sym_LT_LT] = ACTIONS(1227),
    [anon_sym_GT_GT] = ACTIONS(1229),
    [anon_sym_GT_GT_GT] = ACTIONS(1227),
    [anon_sym_EQ_EQ] = ACTIONS(1227),
    [anon_sym_BANG_EQ] = ACTIONS(1227),
    [anon_sym_GT_EQ] = ACTIONS(1227),
    [anon_sym_LT_EQ] = ACTIONS(1227),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_DOT] = ACTIONS(1229),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1229),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1849),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1851),
    [anon_sym_DOT_DOT] = ACTIONS(1853),
    [anon_sym_and] = ACTIONS(1229),
    [anon_sym_or] = ACTIONS(1229),
    [anon_sym_AMP_AMP] = ACTIONS(1227),
    [anon_sym_PIPE_PIPE] = ACTIONS(1227),
    [anon_sym_QMARK_QMARK] = ACTIONS(1227),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1229),
    [anon_sym_is] = ACTIONS(1229),
    [anon_sym_DASH_GT] = ACTIONS(1227),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_with] = ACTIONS(1229),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [284] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6943),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2986),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7065),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6054),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4342),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7419),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9334),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(284),
    [sym_preproc_endregion] = STATE(284),
    [sym_preproc_line] = STATE(284),
    [sym_preproc_pragma] = STATE(284),
    [sym_preproc_nullable] = STATE(284),
    [sym_preproc_error] = STATE(284),
    [sym_preproc_warning] = STATE(284),
    [sym_preproc_define] = STATE(284),
    [sym_preproc_undef] = STATE(284),
    [aux_sym_class_declaration_repeat1] = STATE(3840),
    [aux_sym_lambda_expression_repeat1] = STATE(4269),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1855),
    [anon_sym_ref] = ACTIONS(1857),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1859),
    [anon_sym_LT] = ACTIONS(1171),
    [anon_sym_GT] = ACTIONS(1171),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1171),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1861),
    [anon_sym_TILDE] = ACTIONS(1863),
    [anon_sym_PLUS_PLUS] = ACTIONS(1863),
    [anon_sym_DASH_DASH] = ACTIONS(1863),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1861),
    [anon_sym_DASH] = ACTIONS(1861),
    [anon_sym_STAR] = ACTIONS(1865),
    [anon_sym_SLASH] = ACTIONS(1171),
    [anon_sym_PERCENT] = ACTIONS(1157),
    [anon_sym_CARET] = ACTIONS(1863),
    [anon_sym_PIPE] = ACTIONS(1171),
    [anon_sym_AMP] = ACTIONS(1861),
    [anon_sym_LT_LT] = ACTIONS(1157),
    [anon_sym_GT_GT] = ACTIONS(1171),
    [anon_sym_GT_GT_GT] = ACTIONS(1157),
    [anon_sym_EQ_EQ] = ACTIONS(1157),
    [anon_sym_BANG_EQ] = ACTIONS(1157),
    [anon_sym_GT_EQ] = ACTIONS(1157),
    [anon_sym_LT_EQ] = ACTIONS(1157),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_DOT] = ACTIONS(1171),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1171),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1867),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1869),
    [anon_sym_DOT_DOT] = ACTIONS(1871),
    [anon_sym_and] = ACTIONS(1171),
    [anon_sym_or] = ACTIONS(1171),
    [anon_sym_AMP_AMP] = ACTIONS(1157),
    [anon_sym_PIPE_PIPE] = ACTIONS(1157),
    [anon_sym_QMARK_QMARK] = ACTIONS(1157),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1171),
    [anon_sym_is] = ACTIONS(1171),
    [anon_sym_DASH_GT] = ACTIONS(1157),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_with] = ACTIONS(1171),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [285] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6943),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2986),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7065),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5811),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4342),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7419),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9334),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(285),
    [sym_preproc_endregion] = STATE(285),
    [sym_preproc_line] = STATE(285),
    [sym_preproc_pragma] = STATE(285),
    [sym_preproc_nullable] = STATE(285),
    [sym_preproc_error] = STATE(285),
    [sym_preproc_warning] = STATE(285),
    [sym_preproc_define] = STATE(285),
    [sym_preproc_undef] = STATE(285),
    [aux_sym_class_declaration_repeat1] = STATE(3840),
    [aux_sym_lambda_expression_repeat1] = STATE(4269),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1855),
    [anon_sym_ref] = ACTIONS(1857),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1859),
    [anon_sym_LT] = ACTIONS(1229),
    [anon_sym_GT] = ACTIONS(1229),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1229),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1861),
    [anon_sym_TILDE] = ACTIONS(1863),
    [anon_sym_PLUS_PLUS] = ACTIONS(1863),
    [anon_sym_DASH_DASH] = ACTIONS(1863),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1861),
    [anon_sym_DASH] = ACTIONS(1861),
    [anon_sym_STAR] = ACTIONS(1865),
    [anon_sym_SLASH] = ACTIONS(1229),
    [anon_sym_PERCENT] = ACTIONS(1227),
    [anon_sym_CARET] = ACTIONS(1863),
    [anon_sym_PIPE] = ACTIONS(1229),
    [anon_sym_AMP] = ACTIONS(1861),
    [anon_sym_LT_LT] = ACTIONS(1227),
    [anon_sym_GT_GT] = ACTIONS(1229),
    [anon_sym_GT_GT_GT] = ACTIONS(1227),
    [anon_sym_EQ_EQ] = ACTIONS(1227),
    [anon_sym_BANG_EQ] = ACTIONS(1227),
    [anon_sym_GT_EQ] = ACTIONS(1227),
    [anon_sym_LT_EQ] = ACTIONS(1227),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_DOT] = ACTIONS(1229),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1229),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1867),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1869),
    [anon_sym_DOT_DOT] = ACTIONS(1871),
    [anon_sym_and] = ACTIONS(1229),
    [anon_sym_or] = ACTIONS(1229),
    [anon_sym_AMP_AMP] = ACTIONS(1227),
    [anon_sym_PIPE_PIPE] = ACTIONS(1227),
    [anon_sym_QMARK_QMARK] = ACTIONS(1227),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1229),
    [anon_sym_is] = ACTIONS(1229),
    [anon_sym_DASH_GT] = ACTIONS(1227),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_with] = ACTIONS(1229),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [286] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7105),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5808),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(286),
    [sym_preproc_endregion] = STATE(286),
    [sym_preproc_line] = STATE(286),
    [sym_preproc_pragma] = STATE(286),
    [sym_preproc_nullable] = STATE(286),
    [sym_preproc_error] = STATE(286),
    [sym_preproc_warning] = STATE(286),
    [sym_preproc_define] = STATE(286),
    [sym_preproc_undef] = STATE(286),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_COMMA] = ACTIONS(1873),
    [anon_sym_RBRACK] = ACTIONS(1873),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(1171),
    [anon_sym_GT] = ACTIONS(1171),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1171),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1565),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_SLASH] = ACTIONS(1171),
    [anon_sym_PERCENT] = ACTIONS(1157),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_PIPE] = ACTIONS(1171),
    [anon_sym_AMP] = ACTIONS(1565),
    [anon_sym_LT_LT] = ACTIONS(1157),
    [anon_sym_GT_GT] = ACTIONS(1171),
    [anon_sym_GT_GT_GT] = ACTIONS(1157),
    [anon_sym_EQ_EQ] = ACTIONS(1157),
    [anon_sym_BANG_EQ] = ACTIONS(1157),
    [anon_sym_GT_EQ] = ACTIONS(1157),
    [anon_sym_LT_EQ] = ACTIONS(1157),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(1171),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1171),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_AMP_AMP] = ACTIONS(1157),
    [anon_sym_PIPE_PIPE] = ACTIONS(1157),
    [anon_sym_QMARK_QMARK] = ACTIONS(1157),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1171),
    [anon_sym_is] = ACTIONS(1171),
    [anon_sym_DASH_GT] = ACTIONS(1157),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_with] = ACTIONS(1171),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [287] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6922),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2984),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7069),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6058),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4344),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7423),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9604),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(287),
    [sym_preproc_endregion] = STATE(287),
    [sym_preproc_line] = STATE(287),
    [sym_preproc_pragma] = STATE(287),
    [sym_preproc_nullable] = STATE(287),
    [sym_preproc_error] = STATE(287),
    [sym_preproc_warning] = STATE(287),
    [sym_preproc_define] = STATE(287),
    [sym_preproc_undef] = STATE(287),
    [aux_sym_class_declaration_repeat1] = STATE(3841),
    [aux_sym_lambda_expression_repeat1] = STATE(4271),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1875),
    [anon_sym_ref] = ACTIONS(1877),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1879),
    [anon_sym_LT] = ACTIONS(1171),
    [anon_sym_GT] = ACTIONS(1171),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1171),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1881),
    [anon_sym_TILDE] = ACTIONS(1883),
    [anon_sym_PLUS_PLUS] = ACTIONS(1883),
    [anon_sym_DASH_DASH] = ACTIONS(1883),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1881),
    [anon_sym_DASH] = ACTIONS(1881),
    [anon_sym_STAR] = ACTIONS(1885),
    [anon_sym_SLASH] = ACTIONS(1171),
    [anon_sym_PERCENT] = ACTIONS(1157),
    [anon_sym_CARET] = ACTIONS(1883),
    [anon_sym_PIPE] = ACTIONS(1171),
    [anon_sym_AMP] = ACTIONS(1881),
    [anon_sym_LT_LT] = ACTIONS(1157),
    [anon_sym_GT_GT] = ACTIONS(1171),
    [anon_sym_GT_GT_GT] = ACTIONS(1157),
    [anon_sym_EQ_EQ] = ACTIONS(1157),
    [anon_sym_BANG_EQ] = ACTIONS(1157),
    [anon_sym_GT_EQ] = ACTIONS(1157),
    [anon_sym_LT_EQ] = ACTIONS(1157),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_DOT] = ACTIONS(1171),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1171),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1887),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1889),
    [anon_sym_DOT_DOT] = ACTIONS(1891),
    [anon_sym_and] = ACTIONS(1171),
    [anon_sym_or] = ACTIONS(1171),
    [anon_sym_AMP_AMP] = ACTIONS(1157),
    [anon_sym_PIPE_PIPE] = ACTIONS(1157),
    [anon_sym_QMARK_QMARK] = ACTIONS(1157),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1171),
    [anon_sym_is] = ACTIONS(1171),
    [anon_sym_DASH_GT] = ACTIONS(1157),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_with] = ACTIONS(1171),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [288] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6922),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2984),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7069),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5856),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4344),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7423),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9604),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(288),
    [sym_preproc_endregion] = STATE(288),
    [sym_preproc_line] = STATE(288),
    [sym_preproc_pragma] = STATE(288),
    [sym_preproc_nullable] = STATE(288),
    [sym_preproc_error] = STATE(288),
    [sym_preproc_warning] = STATE(288),
    [sym_preproc_define] = STATE(288),
    [sym_preproc_undef] = STATE(288),
    [aux_sym_class_declaration_repeat1] = STATE(3841),
    [aux_sym_lambda_expression_repeat1] = STATE(4271),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1875),
    [anon_sym_ref] = ACTIONS(1877),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1879),
    [anon_sym_LT] = ACTIONS(1229),
    [anon_sym_GT] = ACTIONS(1229),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1229),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1881),
    [anon_sym_TILDE] = ACTIONS(1883),
    [anon_sym_PLUS_PLUS] = ACTIONS(1883),
    [anon_sym_DASH_DASH] = ACTIONS(1883),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1881),
    [anon_sym_DASH] = ACTIONS(1881),
    [anon_sym_STAR] = ACTIONS(1885),
    [anon_sym_SLASH] = ACTIONS(1229),
    [anon_sym_PERCENT] = ACTIONS(1227),
    [anon_sym_CARET] = ACTIONS(1883),
    [anon_sym_PIPE] = ACTIONS(1229),
    [anon_sym_AMP] = ACTIONS(1881),
    [anon_sym_LT_LT] = ACTIONS(1227),
    [anon_sym_GT_GT] = ACTIONS(1229),
    [anon_sym_GT_GT_GT] = ACTIONS(1227),
    [anon_sym_EQ_EQ] = ACTIONS(1227),
    [anon_sym_BANG_EQ] = ACTIONS(1227),
    [anon_sym_GT_EQ] = ACTIONS(1227),
    [anon_sym_LT_EQ] = ACTIONS(1227),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_DOT] = ACTIONS(1229),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1229),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1887),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1889),
    [anon_sym_DOT_DOT] = ACTIONS(1891),
    [anon_sym_and] = ACTIONS(1229),
    [anon_sym_or] = ACTIONS(1229),
    [anon_sym_AMP_AMP] = ACTIONS(1227),
    [anon_sym_PIPE_PIPE] = ACTIONS(1227),
    [anon_sym_QMARK_QMARK] = ACTIONS(1227),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1229),
    [anon_sym_is] = ACTIONS(1229),
    [anon_sym_DASH_GT] = ACTIONS(1227),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_with] = ACTIONS(1229),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [289] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6948),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2940),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7022),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4973),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3795),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7417),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9004),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(289),
    [sym_preproc_endregion] = STATE(289),
    [sym_preproc_line] = STATE(289),
    [sym_preproc_pragma] = STATE(289),
    [sym_preproc_nullable] = STATE(289),
    [sym_preproc_error] = STATE(289),
    [sym_preproc_warning] = STATE(289),
    [sym_preproc_define] = STATE(289),
    [sym_preproc_undef] = STATE(289),
    [aux_sym_class_declaration_repeat1] = STATE(3827),
    [aux_sym_lambda_expression_repeat1] = STATE(4246),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1893),
    [anon_sym_ref] = ACTIONS(1895),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1897),
    [anon_sym_LT] = ACTIONS(1229),
    [anon_sym_GT] = ACTIONS(1229),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1229),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1899),
    [anon_sym_TILDE] = ACTIONS(1901),
    [anon_sym_PLUS_PLUS] = ACTIONS(1901),
    [anon_sym_DASH_DASH] = ACTIONS(1901),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1899),
    [anon_sym_DASH] = ACTIONS(1899),
    [anon_sym_STAR] = ACTIONS(1903),
    [anon_sym_SLASH] = ACTIONS(1229),
    [anon_sym_PERCENT] = ACTIONS(1227),
    [anon_sym_CARET] = ACTIONS(1901),
    [anon_sym_PIPE] = ACTIONS(1229),
    [anon_sym_AMP] = ACTIONS(1899),
    [anon_sym_LT_LT] = ACTIONS(1227),
    [anon_sym_GT_GT] = ACTIONS(1229),
    [anon_sym_GT_GT_GT] = ACTIONS(1227),
    [anon_sym_EQ_EQ] = ACTIONS(1227),
    [anon_sym_BANG_EQ] = ACTIONS(1227),
    [anon_sym_GT_EQ] = ACTIONS(1227),
    [anon_sym_LT_EQ] = ACTIONS(1227),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(1229),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1229),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1905),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1907),
    [anon_sym_DOT_DOT] = ACTIONS(1909),
    [anon_sym_and] = ACTIONS(1229),
    [anon_sym_or] = ACTIONS(1229),
    [anon_sym_AMP_AMP] = ACTIONS(1227),
    [anon_sym_PIPE_PIPE] = ACTIONS(1227),
    [anon_sym_QMARK_QMARK] = ACTIONS(1227),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1229),
    [anon_sym_is] = ACTIONS(1229),
    [anon_sym_DASH_GT] = ACTIONS(1227),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_with] = ACTIONS(1229),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [290] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6941),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2977),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7077),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5714),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4200),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7415),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9773),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(290),
    [sym_preproc_endregion] = STATE(290),
    [sym_preproc_line] = STATE(290),
    [sym_preproc_pragma] = STATE(290),
    [sym_preproc_nullable] = STATE(290),
    [sym_preproc_error] = STATE(290),
    [sym_preproc_warning] = STATE(290),
    [sym_preproc_define] = STATE(290),
    [sym_preproc_undef] = STATE(290),
    [aux_sym_class_declaration_repeat1] = STATE(3843),
    [aux_sym_lambda_expression_repeat1] = STATE(4275),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1911),
    [anon_sym_ref] = ACTIONS(1913),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1915),
    [anon_sym_LT] = ACTIONS(1171),
    [anon_sym_GT] = ACTIONS(1171),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1171),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1917),
    [anon_sym_TILDE] = ACTIONS(1919),
    [anon_sym_PLUS_PLUS] = ACTIONS(1919),
    [anon_sym_DASH_DASH] = ACTIONS(1919),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1917),
    [anon_sym_DASH] = ACTIONS(1917),
    [anon_sym_STAR] = ACTIONS(1921),
    [anon_sym_SLASH] = ACTIONS(1171),
    [anon_sym_PERCENT] = ACTIONS(1157),
    [anon_sym_CARET] = ACTIONS(1919),
    [anon_sym_PIPE] = ACTIONS(1171),
    [anon_sym_AMP] = ACTIONS(1917),
    [anon_sym_LT_LT] = ACTIONS(1157),
    [anon_sym_GT_GT] = ACTIONS(1171),
    [anon_sym_GT_GT_GT] = ACTIONS(1157),
    [anon_sym_EQ_EQ] = ACTIONS(1157),
    [anon_sym_BANG_EQ] = ACTIONS(1157),
    [anon_sym_GT_EQ] = ACTIONS(1157),
    [anon_sym_LT_EQ] = ACTIONS(1157),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_DOT] = ACTIONS(1171),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1171),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1923),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1925),
    [anon_sym_DOT_DOT] = ACTIONS(1927),
    [anon_sym_and] = ACTIONS(1171),
    [anon_sym_or] = ACTIONS(1171),
    [anon_sym_AMP_AMP] = ACTIONS(1157),
    [anon_sym_PIPE_PIPE] = ACTIONS(1157),
    [anon_sym_QMARK_QMARK] = ACTIONS(1157),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1171),
    [anon_sym_is] = ACTIONS(1171),
    [anon_sym_DASH_GT] = ACTIONS(1157),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_with] = ACTIONS(1171),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [291] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6941),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2977),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7077),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5501),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4200),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7415),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9773),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(291),
    [sym_preproc_endregion] = STATE(291),
    [sym_preproc_line] = STATE(291),
    [sym_preproc_pragma] = STATE(291),
    [sym_preproc_nullable] = STATE(291),
    [sym_preproc_error] = STATE(291),
    [sym_preproc_warning] = STATE(291),
    [sym_preproc_define] = STATE(291),
    [sym_preproc_undef] = STATE(291),
    [aux_sym_class_declaration_repeat1] = STATE(3843),
    [aux_sym_lambda_expression_repeat1] = STATE(4275),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1911),
    [anon_sym_ref] = ACTIONS(1913),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1915),
    [anon_sym_LT] = ACTIONS(1229),
    [anon_sym_GT] = ACTIONS(1229),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1229),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1917),
    [anon_sym_TILDE] = ACTIONS(1919),
    [anon_sym_PLUS_PLUS] = ACTIONS(1919),
    [anon_sym_DASH_DASH] = ACTIONS(1919),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1917),
    [anon_sym_DASH] = ACTIONS(1917),
    [anon_sym_STAR] = ACTIONS(1921),
    [anon_sym_SLASH] = ACTIONS(1229),
    [anon_sym_PERCENT] = ACTIONS(1227),
    [anon_sym_CARET] = ACTIONS(1919),
    [anon_sym_PIPE] = ACTIONS(1229),
    [anon_sym_AMP] = ACTIONS(1917),
    [anon_sym_LT_LT] = ACTIONS(1227),
    [anon_sym_GT_GT] = ACTIONS(1229),
    [anon_sym_GT_GT_GT] = ACTIONS(1227),
    [anon_sym_EQ_EQ] = ACTIONS(1227),
    [anon_sym_BANG_EQ] = ACTIONS(1227),
    [anon_sym_GT_EQ] = ACTIONS(1227),
    [anon_sym_LT_EQ] = ACTIONS(1227),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_DOT] = ACTIONS(1229),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1229),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1923),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1925),
    [anon_sym_DOT_DOT] = ACTIONS(1927),
    [anon_sym_and] = ACTIONS(1229),
    [anon_sym_or] = ACTIONS(1229),
    [anon_sym_AMP_AMP] = ACTIONS(1227),
    [anon_sym_PIPE_PIPE] = ACTIONS(1227),
    [anon_sym_QMARK_QMARK] = ACTIONS(1227),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1229),
    [anon_sym_is] = ACTIONS(1229),
    [anon_sym_DASH_GT] = ACTIONS(1227),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_with] = ACTIONS(1229),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [292] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6948),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2940),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7022),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4960),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3795),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7417),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9004),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(292),
    [sym_preproc_endregion] = STATE(292),
    [sym_preproc_line] = STATE(292),
    [sym_preproc_pragma] = STATE(292),
    [sym_preproc_nullable] = STATE(292),
    [sym_preproc_error] = STATE(292),
    [sym_preproc_warning] = STATE(292),
    [sym_preproc_define] = STATE(292),
    [sym_preproc_undef] = STATE(292),
    [aux_sym_class_declaration_repeat1] = STATE(3827),
    [aux_sym_lambda_expression_repeat1] = STATE(4246),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1893),
    [anon_sym_ref] = ACTIONS(1895),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1897),
    [anon_sym_LT] = ACTIONS(1171),
    [anon_sym_GT] = ACTIONS(1171),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1171),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1899),
    [anon_sym_TILDE] = ACTIONS(1901),
    [anon_sym_PLUS_PLUS] = ACTIONS(1901),
    [anon_sym_DASH_DASH] = ACTIONS(1901),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1899),
    [anon_sym_DASH] = ACTIONS(1899),
    [anon_sym_STAR] = ACTIONS(1903),
    [anon_sym_SLASH] = ACTIONS(1171),
    [anon_sym_PERCENT] = ACTIONS(1157),
    [anon_sym_CARET] = ACTIONS(1901),
    [anon_sym_PIPE] = ACTIONS(1171),
    [anon_sym_AMP] = ACTIONS(1899),
    [anon_sym_LT_LT] = ACTIONS(1157),
    [anon_sym_GT_GT] = ACTIONS(1171),
    [anon_sym_GT_GT_GT] = ACTIONS(1157),
    [anon_sym_EQ_EQ] = ACTIONS(1157),
    [anon_sym_BANG_EQ] = ACTIONS(1157),
    [anon_sym_GT_EQ] = ACTIONS(1157),
    [anon_sym_LT_EQ] = ACTIONS(1157),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(1171),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1171),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1905),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1907),
    [anon_sym_DOT_DOT] = ACTIONS(1909),
    [anon_sym_and] = ACTIONS(1171),
    [anon_sym_or] = ACTIONS(1171),
    [anon_sym_AMP_AMP] = ACTIONS(1157),
    [anon_sym_PIPE_PIPE] = ACTIONS(1157),
    [anon_sym_QMARK_QMARK] = ACTIONS(1157),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1171),
    [anon_sym_is] = ACTIONS(1171),
    [anon_sym_DASH_GT] = ACTIONS(1157),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_with] = ACTIONS(1171),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [293] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6910),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2960),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7091),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5724),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4208),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7438),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9067),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(293),
    [sym_preproc_endregion] = STATE(293),
    [sym_preproc_line] = STATE(293),
    [sym_preproc_pragma] = STATE(293),
    [sym_preproc_nullable] = STATE(293),
    [sym_preproc_error] = STATE(293),
    [sym_preproc_warning] = STATE(293),
    [sym_preproc_define] = STATE(293),
    [sym_preproc_undef] = STATE(293),
    [aux_sym_class_declaration_repeat1] = STATE(3847),
    [aux_sym_lambda_expression_repeat1] = STATE(4280),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1819),
    [anon_sym_ref] = ACTIONS(1821),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1823),
    [anon_sym_LT] = ACTIONS(1171),
    [anon_sym_GT] = ACTIONS(1171),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1171),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1825),
    [anon_sym_TILDE] = ACTIONS(1827),
    [anon_sym_PLUS_PLUS] = ACTIONS(1827),
    [anon_sym_DASH_DASH] = ACTIONS(1827),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1825),
    [anon_sym_DASH] = ACTIONS(1825),
    [anon_sym_STAR] = ACTIONS(1829),
    [anon_sym_SLASH] = ACTIONS(1171),
    [anon_sym_PERCENT] = ACTIONS(1157),
    [anon_sym_CARET] = ACTIONS(1827),
    [anon_sym_PIPE] = ACTIONS(1171),
    [anon_sym_AMP] = ACTIONS(1825),
    [anon_sym_LT_LT] = ACTIONS(1157),
    [anon_sym_GT_GT] = ACTIONS(1171),
    [anon_sym_GT_GT_GT] = ACTIONS(1157),
    [anon_sym_EQ_EQ] = ACTIONS(1157),
    [anon_sym_BANG_EQ] = ACTIONS(1157),
    [anon_sym_GT_EQ] = ACTIONS(1157),
    [anon_sym_LT_EQ] = ACTIONS(1157),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_DOT] = ACTIONS(1171),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1171),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1831),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1833),
    [anon_sym_DOT_DOT] = ACTIONS(1835),
    [anon_sym_and] = ACTIONS(1171),
    [anon_sym_or] = ACTIONS(1171),
    [anon_sym_AMP_AMP] = ACTIONS(1157),
    [anon_sym_PIPE_PIPE] = ACTIONS(1157),
    [anon_sym_QMARK_QMARK] = ACTIONS(1157),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1171),
    [anon_sym_is] = ACTIONS(1171),
    [anon_sym_DASH_GT] = ACTIONS(1157),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_with] = ACTIONS(1171),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [294] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6955),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2975),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7120),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4900),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3789),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7416),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9625),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(294),
    [sym_preproc_endregion] = STATE(294),
    [sym_preproc_line] = STATE(294),
    [sym_preproc_pragma] = STATE(294),
    [sym_preproc_nullable] = STATE(294),
    [sym_preproc_error] = STATE(294),
    [sym_preproc_warning] = STATE(294),
    [sym_preproc_define] = STATE(294),
    [sym_preproc_undef] = STATE(294),
    [aux_sym_class_declaration_repeat1] = STATE(3864),
    [aux_sym_lambda_expression_repeat1] = STATE(4297),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1929),
    [anon_sym_ref] = ACTIONS(1931),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1933),
    [anon_sym_LT] = ACTIONS(1229),
    [anon_sym_GT] = ACTIONS(1229),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1229),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1935),
    [anon_sym_TILDE] = ACTIONS(1937),
    [anon_sym_PLUS_PLUS] = ACTIONS(1937),
    [anon_sym_DASH_DASH] = ACTIONS(1937),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1935),
    [anon_sym_DASH] = ACTIONS(1935),
    [anon_sym_STAR] = ACTIONS(1939),
    [anon_sym_SLASH] = ACTIONS(1229),
    [anon_sym_PERCENT] = ACTIONS(1227),
    [anon_sym_CARET] = ACTIONS(1937),
    [anon_sym_PIPE] = ACTIONS(1229),
    [anon_sym_AMP] = ACTIONS(1935),
    [anon_sym_LT_LT] = ACTIONS(1227),
    [anon_sym_GT_GT] = ACTIONS(1229),
    [anon_sym_GT_GT_GT] = ACTIONS(1227),
    [anon_sym_EQ_EQ] = ACTIONS(1227),
    [anon_sym_BANG_EQ] = ACTIONS(1227),
    [anon_sym_GT_EQ] = ACTIONS(1227),
    [anon_sym_LT_EQ] = ACTIONS(1227),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_DOT] = ACTIONS(1229),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1229),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1941),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1943),
    [anon_sym_DOT_DOT] = ACTIONS(1945),
    [anon_sym_and] = ACTIONS(1229),
    [anon_sym_or] = ACTIONS(1229),
    [anon_sym_AMP_AMP] = ACTIONS(1227),
    [anon_sym_PIPE_PIPE] = ACTIONS(1227),
    [anon_sym_QMARK_QMARK] = ACTIONS(1227),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1229),
    [anon_sym_is] = ACTIONS(1229),
    [anon_sym_DASH_GT] = ACTIONS(1227),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_with] = ACTIONS(1229),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [295] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6955),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2975),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7120),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4913),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3789),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7416),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9625),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(295),
    [sym_preproc_endregion] = STATE(295),
    [sym_preproc_line] = STATE(295),
    [sym_preproc_pragma] = STATE(295),
    [sym_preproc_nullable] = STATE(295),
    [sym_preproc_error] = STATE(295),
    [sym_preproc_warning] = STATE(295),
    [sym_preproc_define] = STATE(295),
    [sym_preproc_undef] = STATE(295),
    [aux_sym_class_declaration_repeat1] = STATE(3864),
    [aux_sym_lambda_expression_repeat1] = STATE(4297),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1929),
    [anon_sym_ref] = ACTIONS(1931),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1933),
    [anon_sym_LT] = ACTIONS(1171),
    [anon_sym_GT] = ACTIONS(1171),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1171),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1935),
    [anon_sym_TILDE] = ACTIONS(1937),
    [anon_sym_PLUS_PLUS] = ACTIONS(1937),
    [anon_sym_DASH_DASH] = ACTIONS(1937),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1935),
    [anon_sym_DASH] = ACTIONS(1935),
    [anon_sym_STAR] = ACTIONS(1939),
    [anon_sym_SLASH] = ACTIONS(1171),
    [anon_sym_PERCENT] = ACTIONS(1157),
    [anon_sym_CARET] = ACTIONS(1937),
    [anon_sym_PIPE] = ACTIONS(1171),
    [anon_sym_AMP] = ACTIONS(1935),
    [anon_sym_LT_LT] = ACTIONS(1157),
    [anon_sym_GT_GT] = ACTIONS(1171),
    [anon_sym_GT_GT_GT] = ACTIONS(1157),
    [anon_sym_EQ_EQ] = ACTIONS(1157),
    [anon_sym_BANG_EQ] = ACTIONS(1157),
    [anon_sym_GT_EQ] = ACTIONS(1157),
    [anon_sym_LT_EQ] = ACTIONS(1157),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_DOT] = ACTIONS(1171),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1171),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1941),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1943),
    [anon_sym_DOT_DOT] = ACTIONS(1945),
    [anon_sym_and] = ACTIONS(1171),
    [anon_sym_or] = ACTIONS(1171),
    [anon_sym_AMP_AMP] = ACTIONS(1157),
    [anon_sym_PIPE_PIPE] = ACTIONS(1157),
    [anon_sym_QMARK_QMARK] = ACTIONS(1157),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1171),
    [anon_sym_is] = ACTIONS(1171),
    [anon_sym_DASH_GT] = ACTIONS(1157),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_with] = ACTIONS(1171),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [296] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6759),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2844),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6163),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_pattern] = STATE(8123),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6721),
    [sym_property_pattern_clause] = STATE(6770),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6727),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5060),
    [sym_postfix_unary_expression] = STATE(5061),
    [sym_prefix_unary_expression] = STATE(5061),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5060),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5061),
    [sym_switch_expression] = STATE(3765),
    [sym_switch_expression_arm] = STATE(8412),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5060),
    [sym_member_access_expression] = STATE(3797),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5061),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(5060),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5060),
    [sym_typeof_expression] = STATE(5060),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3797),
    [sym_literal] = STATE(5060),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(296),
    [sym_preproc_endregion] = STATE(296),
    [sym_preproc_line] = STATE(296),
    [sym_preproc_pragma] = STATE(296),
    [sym_preproc_nullable] = STATE(296),
    [sym_preproc_error] = STATE(296),
    [sym_preproc_warning] = STATE(296),
    [sym_preproc_define] = STATE(296),
    [sym_preproc_undef] = STATE(296),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_COMMA] = ACTIONS(1947),
    [anon_sym_LPAREN] = ACTIONS(1949),
    [anon_sym_ref] = ACTIONS(1951),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_RBRACE] = ACTIONS(1953),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(1955),
    [anon_sym_GT] = ACTIONS(1955),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1581),
    [anon_sym_TILDE] = ACTIONS(1581),
    [anon_sym_PLUS_PLUS] = ACTIONS(1581),
    [anon_sym_DASH_DASH] = ACTIONS(1581),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1579),
    [anon_sym_DASH] = ACTIONS(1579),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1581),
    [anon_sym_AMP] = ACTIONS(1581),
    [anon_sym_GT_EQ] = ACTIONS(1957),
    [anon_sym_LT_EQ] = ACTIONS(1957),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(1089),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1959),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(1961),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [297] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6916),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7061),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6189),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4369),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7437),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9284),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(297),
    [sym_preproc_endregion] = STATE(297),
    [sym_preproc_line] = STATE(297),
    [sym_preproc_pragma] = STATE(297),
    [sym_preproc_nullable] = STATE(297),
    [sym_preproc_error] = STATE(297),
    [sym_preproc_warning] = STATE(297),
    [sym_preproc_define] = STATE(297),
    [sym_preproc_undef] = STATE(297),
    [aux_sym_class_declaration_repeat1] = STATE(3839),
    [aux_sym_lambda_expression_repeat1] = STATE(4267),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1963),
    [anon_sym_ref] = ACTIONS(1965),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LT] = ACTIONS(1171),
    [anon_sym_GT] = ACTIONS(1171),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1171),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1967),
    [anon_sym_TILDE] = ACTIONS(1969),
    [anon_sym_PLUS_PLUS] = ACTIONS(1969),
    [anon_sym_DASH_DASH] = ACTIONS(1969),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1967),
    [anon_sym_DASH] = ACTIONS(1967),
    [anon_sym_STAR] = ACTIONS(1971),
    [anon_sym_SLASH] = ACTIONS(1171),
    [anon_sym_PERCENT] = ACTIONS(1157),
    [anon_sym_CARET] = ACTIONS(1969),
    [anon_sym_PIPE] = ACTIONS(1171),
    [anon_sym_AMP] = ACTIONS(1967),
    [anon_sym_LT_LT] = ACTIONS(1157),
    [anon_sym_GT_GT] = ACTIONS(1171),
    [anon_sym_GT_GT_GT] = ACTIONS(1157),
    [anon_sym_EQ_EQ] = ACTIONS(1157),
    [anon_sym_BANG_EQ] = ACTIONS(1157),
    [anon_sym_GT_EQ] = ACTIONS(1157),
    [anon_sym_LT_EQ] = ACTIONS(1157),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_DOT] = ACTIONS(1171),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_EQ_GT] = ACTIONS(1157),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1171),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1973),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1975),
    [anon_sym_DOT_DOT] = ACTIONS(1977),
    [anon_sym_AMP_AMP] = ACTIONS(1157),
    [anon_sym_PIPE_PIPE] = ACTIONS(1157),
    [anon_sym_QMARK_QMARK] = ACTIONS(1157),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1171),
    [anon_sym_is] = ACTIONS(1171),
    [anon_sym_DASH_GT] = ACTIONS(1157),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_with] = ACTIONS(1171),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [298] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7159),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6325),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4487),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7422),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9176),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(298),
    [sym_preproc_endregion] = STATE(298),
    [sym_preproc_line] = STATE(298),
    [sym_preproc_pragma] = STATE(298),
    [sym_preproc_nullable] = STATE(298),
    [sym_preproc_error] = STATE(298),
    [sym_preproc_warning] = STATE(298),
    [sym_preproc_define] = STATE(298),
    [sym_preproc_undef] = STATE(298),
    [aux_sym_class_declaration_repeat1] = STATE(3877),
    [aux_sym_lambda_expression_repeat1] = STATE(4320),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1979),
    [anon_sym_ref] = ACTIONS(1981),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(1229),
    [anon_sym_GT] = ACTIONS(1229),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1229),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1983),
    [anon_sym_TILDE] = ACTIONS(1985),
    [anon_sym_PLUS_PLUS] = ACTIONS(1985),
    [anon_sym_DASH_DASH] = ACTIONS(1985),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1983),
    [anon_sym_DASH] = ACTIONS(1983),
    [anon_sym_STAR] = ACTIONS(1987),
    [anon_sym_SLASH] = ACTIONS(1229),
    [anon_sym_PERCENT] = ACTIONS(1227),
    [anon_sym_CARET] = ACTIONS(1985),
    [anon_sym_PIPE] = ACTIONS(1229),
    [anon_sym_AMP] = ACTIONS(1983),
    [anon_sym_LT_LT] = ACTIONS(1227),
    [anon_sym_GT_GT] = ACTIONS(1229),
    [anon_sym_GT_GT_GT] = ACTIONS(1227),
    [anon_sym_EQ_EQ] = ACTIONS(1227),
    [anon_sym_BANG_EQ] = ACTIONS(1227),
    [anon_sym_GT_EQ] = ACTIONS(1227),
    [anon_sym_LT_EQ] = ACTIONS(1227),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(1229),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_EQ_GT] = ACTIONS(1227),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1229),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1989),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1991),
    [anon_sym_DOT_DOT] = ACTIONS(1993),
    [anon_sym_AMP_AMP] = ACTIONS(1227),
    [anon_sym_PIPE_PIPE] = ACTIONS(1227),
    [anon_sym_QMARK_QMARK] = ACTIONS(1227),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1229),
    [anon_sym_is] = ACTIONS(1229),
    [anon_sym_DASH_GT] = ACTIONS(1227),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_with] = ACTIONS(1229),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [299] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6925),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2932),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6992),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4580),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3702),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7420),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9634),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(299),
    [sym_preproc_endregion] = STATE(299),
    [sym_preproc_line] = STATE(299),
    [sym_preproc_pragma] = STATE(299),
    [sym_preproc_nullable] = STATE(299),
    [sym_preproc_error] = STATE(299),
    [sym_preproc_warning] = STATE(299),
    [sym_preproc_define] = STATE(299),
    [sym_preproc_undef] = STATE(299),
    [aux_sym_class_declaration_repeat1] = STATE(3819),
    [aux_sym_lambda_expression_repeat1] = STATE(4232),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_COMMA] = ACTIONS(1227),
    [anon_sym_LPAREN] = ACTIONS(1995),
    [anon_sym_ref] = ACTIONS(1997),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1771),
    [anon_sym_LT] = ACTIONS(1229),
    [anon_sym_GT] = ACTIONS(1229),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1229),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1999),
    [anon_sym_TILDE] = ACTIONS(2001),
    [anon_sym_PLUS_PLUS] = ACTIONS(2001),
    [anon_sym_DASH_DASH] = ACTIONS(2001),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1999),
    [anon_sym_DASH] = ACTIONS(1999),
    [anon_sym_STAR] = ACTIONS(1777),
    [anon_sym_SLASH] = ACTIONS(1229),
    [anon_sym_PERCENT] = ACTIONS(1227),
    [anon_sym_CARET] = ACTIONS(2001),
    [anon_sym_PIPE] = ACTIONS(1229),
    [anon_sym_AMP] = ACTIONS(1999),
    [anon_sym_LT_LT] = ACTIONS(1227),
    [anon_sym_GT_GT] = ACTIONS(1229),
    [anon_sym_GT_GT_GT] = ACTIONS(1227),
    [anon_sym_EQ_EQ] = ACTIONS(1227),
    [anon_sym_BANG_EQ] = ACTIONS(1227),
    [anon_sym_GT_EQ] = ACTIONS(1227),
    [anon_sym_LT_EQ] = ACTIONS(1227),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_DOT] = ACTIONS(1229),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1229),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(2003),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2005),
    [anon_sym_DOT_DOT] = ACTIONS(2007),
    [anon_sym_AMP_AMP] = ACTIONS(1227),
    [anon_sym_PIPE_PIPE] = ACTIONS(1227),
    [anon_sym_QMARK_QMARK] = ACTIONS(1227),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1229),
    [anon_sym_is] = ACTIONS(1229),
    [anon_sym_DASH_GT] = ACTIONS(1227),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_with] = ACTIONS(1229),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [300] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7139),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6439),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(300),
    [sym_preproc_endregion] = STATE(300),
    [sym_preproc_line] = STATE(300),
    [sym_preproc_pragma] = STATE(300),
    [sym_preproc_nullable] = STATE(300),
    [sym_preproc_error] = STATE(300),
    [sym_preproc_warning] = STATE(300),
    [sym_preproc_define] = STATE(300),
    [sym_preproc_undef] = STATE(300),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_COLON] = ACTIONS(1227),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2011),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_LT] = ACTIONS(1229),
    [anon_sym_GT] = ACTIONS(1229),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1229),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2013),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_SLASH] = ACTIONS(1229),
    [anon_sym_PERCENT] = ACTIONS(1227),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_PIPE] = ACTIONS(1229),
    [anon_sym_AMP] = ACTIONS(2013),
    [anon_sym_LT_LT] = ACTIONS(1227),
    [anon_sym_GT_GT] = ACTIONS(1229),
    [anon_sym_GT_GT_GT] = ACTIONS(1227),
    [anon_sym_EQ_EQ] = ACTIONS(1227),
    [anon_sym_BANG_EQ] = ACTIONS(1227),
    [anon_sym_GT_EQ] = ACTIONS(1227),
    [anon_sym_LT_EQ] = ACTIONS(1227),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(1229),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1229),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_AMP_AMP] = ACTIONS(1227),
    [anon_sym_PIPE_PIPE] = ACTIONS(1227),
    [anon_sym_QMARK_QMARK] = ACTIONS(1227),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1229),
    [anon_sym_is] = ACTIONS(1229),
    [anon_sym_DASH_GT] = ACTIONS(1227),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_with] = ACTIONS(1229),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [301] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6759),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2844),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6163),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_pattern] = STATE(8123),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6721),
    [sym_property_pattern_clause] = STATE(6770),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6727),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5060),
    [sym_postfix_unary_expression] = STATE(5061),
    [sym_prefix_unary_expression] = STATE(5061),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5060),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5061),
    [sym_switch_expression] = STATE(3765),
    [sym_switch_expression_arm] = STATE(8550),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5060),
    [sym_member_access_expression] = STATE(3797),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5061),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(5060),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5060),
    [sym_typeof_expression] = STATE(5060),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3797),
    [sym_literal] = STATE(5060),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(301),
    [sym_preproc_endregion] = STATE(301),
    [sym_preproc_line] = STATE(301),
    [sym_preproc_pragma] = STATE(301),
    [sym_preproc_nullable] = STATE(301),
    [sym_preproc_error] = STATE(301),
    [sym_preproc_warning] = STATE(301),
    [sym_preproc_define] = STATE(301),
    [sym_preproc_undef] = STATE(301),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_COMMA] = ACTIONS(2017),
    [anon_sym_LPAREN] = ACTIONS(1949),
    [anon_sym_ref] = ACTIONS(1951),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_RBRACE] = ACTIONS(2019),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(1955),
    [anon_sym_GT] = ACTIONS(1955),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1581),
    [anon_sym_TILDE] = ACTIONS(1581),
    [anon_sym_PLUS_PLUS] = ACTIONS(1581),
    [anon_sym_DASH_DASH] = ACTIONS(1581),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1579),
    [anon_sym_DASH] = ACTIONS(1579),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1581),
    [anon_sym_AMP] = ACTIONS(1581),
    [anon_sym_GT_EQ] = ACTIONS(1957),
    [anon_sym_LT_EQ] = ACTIONS(1957),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(1089),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1959),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(1961),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [302] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7159),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6561),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4487),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7422),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9176),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(302),
    [sym_preproc_endregion] = STATE(302),
    [sym_preproc_line] = STATE(302),
    [sym_preproc_pragma] = STATE(302),
    [sym_preproc_nullable] = STATE(302),
    [sym_preproc_error] = STATE(302),
    [sym_preproc_warning] = STATE(302),
    [sym_preproc_define] = STATE(302),
    [sym_preproc_undef] = STATE(302),
    [aux_sym_class_declaration_repeat1] = STATE(3877),
    [aux_sym_lambda_expression_repeat1] = STATE(4320),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1979),
    [anon_sym_ref] = ACTIONS(1981),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(1171),
    [anon_sym_GT] = ACTIONS(1171),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1171),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1983),
    [anon_sym_TILDE] = ACTIONS(1985),
    [anon_sym_PLUS_PLUS] = ACTIONS(1985),
    [anon_sym_DASH_DASH] = ACTIONS(1985),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1983),
    [anon_sym_DASH] = ACTIONS(1983),
    [anon_sym_STAR] = ACTIONS(1987),
    [anon_sym_SLASH] = ACTIONS(1171),
    [anon_sym_PERCENT] = ACTIONS(1157),
    [anon_sym_CARET] = ACTIONS(1985),
    [anon_sym_PIPE] = ACTIONS(1171),
    [anon_sym_AMP] = ACTIONS(1983),
    [anon_sym_LT_LT] = ACTIONS(1157),
    [anon_sym_GT_GT] = ACTIONS(1171),
    [anon_sym_GT_GT_GT] = ACTIONS(1157),
    [anon_sym_EQ_EQ] = ACTIONS(1157),
    [anon_sym_BANG_EQ] = ACTIONS(1157),
    [anon_sym_GT_EQ] = ACTIONS(1157),
    [anon_sym_LT_EQ] = ACTIONS(1157),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(1171),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_EQ_GT] = ACTIONS(1157),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1171),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1989),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1991),
    [anon_sym_DOT_DOT] = ACTIONS(1993),
    [anon_sym_AMP_AMP] = ACTIONS(1157),
    [anon_sym_PIPE_PIPE] = ACTIONS(1157),
    [anon_sym_QMARK_QMARK] = ACTIONS(1157),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1171),
    [anon_sym_is] = ACTIONS(1171),
    [anon_sym_DASH_GT] = ACTIONS(1157),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_with] = ACTIONS(1171),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [303] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6759),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2844),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6163),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_pattern] = STATE(8123),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6721),
    [sym_property_pattern_clause] = STATE(6770),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6727),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5060),
    [sym_postfix_unary_expression] = STATE(5061),
    [sym_prefix_unary_expression] = STATE(5061),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5060),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5061),
    [sym_switch_expression] = STATE(3765),
    [sym_switch_expression_arm] = STATE(8684),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5060),
    [sym_member_access_expression] = STATE(3797),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5061),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(5060),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5060),
    [sym_typeof_expression] = STATE(5060),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3797),
    [sym_literal] = STATE(5060),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(303),
    [sym_preproc_endregion] = STATE(303),
    [sym_preproc_line] = STATE(303),
    [sym_preproc_pragma] = STATE(303),
    [sym_preproc_nullable] = STATE(303),
    [sym_preproc_error] = STATE(303),
    [sym_preproc_warning] = STATE(303),
    [sym_preproc_define] = STATE(303),
    [sym_preproc_undef] = STATE(303),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_COMMA] = ACTIONS(2021),
    [anon_sym_LPAREN] = ACTIONS(1949),
    [anon_sym_ref] = ACTIONS(1951),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_RBRACE] = ACTIONS(2023),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(1955),
    [anon_sym_GT] = ACTIONS(1955),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1581),
    [anon_sym_TILDE] = ACTIONS(1581),
    [anon_sym_PLUS_PLUS] = ACTIONS(1581),
    [anon_sym_DASH_DASH] = ACTIONS(1581),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1579),
    [anon_sym_DASH] = ACTIONS(1579),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1581),
    [anon_sym_AMP] = ACTIONS(1581),
    [anon_sym_GT_EQ] = ACTIONS(1957),
    [anon_sym_LT_EQ] = ACTIONS(1957),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(1089),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1959),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(1961),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [304] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6956),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6621),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9482),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(304),
    [sym_preproc_endregion] = STATE(304),
    [sym_preproc_line] = STATE(304),
    [sym_preproc_pragma] = STATE(304),
    [sym_preproc_nullable] = STATE(304),
    [sym_preproc_error] = STATE(304),
    [sym_preproc_warning] = STATE(304),
    [sym_preproc_define] = STATE(304),
    [sym_preproc_undef] = STATE(304),
    [aux_sym_class_declaration_repeat1] = STATE(3853),
    [aux_sym_lambda_expression_repeat1] = STATE(4299),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(2025),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2027),
    [anon_sym_ref] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_LT] = ACTIONS(2029),
    [anon_sym_GT] = ACTIONS(2029),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(2029),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_SLASH] = ACTIONS(2029),
    [anon_sym_PERCENT] = ACTIONS(2031),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_PIPE] = ACTIONS(2029),
    [anon_sym_AMP] = ACTIONS(79),
    [anon_sym_LT_LT] = ACTIONS(2031),
    [anon_sym_GT_GT] = ACTIONS(2029),
    [anon_sym_GT_GT_GT] = ACTIONS(2031),
    [anon_sym_EQ_EQ] = ACTIONS(2031),
    [anon_sym_BANG_EQ] = ACTIONS(2031),
    [anon_sym_GT_EQ] = ACTIONS(2031),
    [anon_sym_LT_EQ] = ACTIONS(2031),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(2029),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(2029),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1505),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1507),
    [anon_sym_DOT_DOT] = ACTIONS(1509),
    [anon_sym_AMP_AMP] = ACTIONS(2031),
    [anon_sym_PIPE_PIPE] = ACTIONS(2031),
    [anon_sym_QMARK_QMARK] = ACTIONS(2031),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(2029),
    [anon_sym_is] = ACTIONS(2029),
    [anon_sym_DASH_GT] = ACTIONS(2031),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_with] = ACTIONS(2029),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [305] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6956),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6617),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9482),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(305),
    [sym_preproc_endregion] = STATE(305),
    [sym_preproc_line] = STATE(305),
    [sym_preproc_pragma] = STATE(305),
    [sym_preproc_nullable] = STATE(305),
    [sym_preproc_error] = STATE(305),
    [sym_preproc_warning] = STATE(305),
    [sym_preproc_define] = STATE(305),
    [sym_preproc_undef] = STATE(305),
    [aux_sym_class_declaration_repeat1] = STATE(3853),
    [aux_sym_lambda_expression_repeat1] = STATE(4299),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(2033),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2027),
    [anon_sym_ref] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_LT] = ACTIONS(2029),
    [anon_sym_GT] = ACTIONS(2029),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(2029),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_SLASH] = ACTIONS(2029),
    [anon_sym_PERCENT] = ACTIONS(2031),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_PIPE] = ACTIONS(2029),
    [anon_sym_AMP] = ACTIONS(79),
    [anon_sym_LT_LT] = ACTIONS(2031),
    [anon_sym_GT_GT] = ACTIONS(2029),
    [anon_sym_GT_GT_GT] = ACTIONS(2031),
    [anon_sym_EQ_EQ] = ACTIONS(2031),
    [anon_sym_BANG_EQ] = ACTIONS(2031),
    [anon_sym_GT_EQ] = ACTIONS(2031),
    [anon_sym_LT_EQ] = ACTIONS(2031),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(2029),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(2029),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1505),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1507),
    [anon_sym_DOT_DOT] = ACTIONS(1509),
    [anon_sym_AMP_AMP] = ACTIONS(2031),
    [anon_sym_PIPE_PIPE] = ACTIONS(2031),
    [anon_sym_QMARK_QMARK] = ACTIONS(2031),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(2029),
    [anon_sym_is] = ACTIONS(2029),
    [anon_sym_DASH_GT] = ACTIONS(2031),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_with] = ACTIONS(2029),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [306] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6916),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7061),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6243),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4369),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7437),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9284),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(306),
    [sym_preproc_endregion] = STATE(306),
    [sym_preproc_line] = STATE(306),
    [sym_preproc_pragma] = STATE(306),
    [sym_preproc_nullable] = STATE(306),
    [sym_preproc_error] = STATE(306),
    [sym_preproc_warning] = STATE(306),
    [sym_preproc_define] = STATE(306),
    [sym_preproc_undef] = STATE(306),
    [aux_sym_class_declaration_repeat1] = STATE(3839),
    [aux_sym_lambda_expression_repeat1] = STATE(4267),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1963),
    [anon_sym_ref] = ACTIONS(1965),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_LT] = ACTIONS(1229),
    [anon_sym_GT] = ACTIONS(1229),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1229),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1967),
    [anon_sym_TILDE] = ACTIONS(1969),
    [anon_sym_PLUS_PLUS] = ACTIONS(1969),
    [anon_sym_DASH_DASH] = ACTIONS(1969),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1967),
    [anon_sym_DASH] = ACTIONS(1967),
    [anon_sym_STAR] = ACTIONS(1971),
    [anon_sym_SLASH] = ACTIONS(1229),
    [anon_sym_PERCENT] = ACTIONS(1227),
    [anon_sym_CARET] = ACTIONS(1969),
    [anon_sym_PIPE] = ACTIONS(1229),
    [anon_sym_AMP] = ACTIONS(1967),
    [anon_sym_LT_LT] = ACTIONS(1227),
    [anon_sym_GT_GT] = ACTIONS(1229),
    [anon_sym_GT_GT_GT] = ACTIONS(1227),
    [anon_sym_EQ_EQ] = ACTIONS(1227),
    [anon_sym_BANG_EQ] = ACTIONS(1227),
    [anon_sym_GT_EQ] = ACTIONS(1227),
    [anon_sym_LT_EQ] = ACTIONS(1227),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_DOT] = ACTIONS(1229),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_EQ_GT] = ACTIONS(1227),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1229),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1973),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1975),
    [anon_sym_DOT_DOT] = ACTIONS(1977),
    [anon_sym_AMP_AMP] = ACTIONS(1227),
    [anon_sym_PIPE_PIPE] = ACTIONS(1227),
    [anon_sym_QMARK_QMARK] = ACTIONS(1227),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1229),
    [anon_sym_is] = ACTIONS(1229),
    [anon_sym_DASH_GT] = ACTIONS(1227),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_with] = ACTIONS(1229),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [307] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7139),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6521),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(307),
    [sym_preproc_endregion] = STATE(307),
    [sym_preproc_line] = STATE(307),
    [sym_preproc_pragma] = STATE(307),
    [sym_preproc_nullable] = STATE(307),
    [sym_preproc_error] = STATE(307),
    [sym_preproc_warning] = STATE(307),
    [sym_preproc_define] = STATE(307),
    [sym_preproc_undef] = STATE(307),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_COLON] = ACTIONS(1157),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2011),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_LT] = ACTIONS(1171),
    [anon_sym_GT] = ACTIONS(1171),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1171),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2013),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_SLASH] = ACTIONS(1171),
    [anon_sym_PERCENT] = ACTIONS(1157),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_PIPE] = ACTIONS(1171),
    [anon_sym_AMP] = ACTIONS(2013),
    [anon_sym_LT_LT] = ACTIONS(1157),
    [anon_sym_GT_GT] = ACTIONS(1171),
    [anon_sym_GT_GT_GT] = ACTIONS(1157),
    [anon_sym_EQ_EQ] = ACTIONS(1157),
    [anon_sym_BANG_EQ] = ACTIONS(1157),
    [anon_sym_GT_EQ] = ACTIONS(1157),
    [anon_sym_LT_EQ] = ACTIONS(1157),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(1171),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1171),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_AMP_AMP] = ACTIONS(1157),
    [anon_sym_PIPE_PIPE] = ACTIONS(1157),
    [anon_sym_QMARK_QMARK] = ACTIONS(1157),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1171),
    [anon_sym_is] = ACTIONS(1171),
    [anon_sym_DASH_GT] = ACTIONS(1157),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_with] = ACTIONS(1171),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [308] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6956),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4338),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9482),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(308),
    [sym_preproc_endregion] = STATE(308),
    [sym_preproc_line] = STATE(308),
    [sym_preproc_pragma] = STATE(308),
    [sym_preproc_nullable] = STATE(308),
    [sym_preproc_error] = STATE(308),
    [sym_preproc_warning] = STATE(308),
    [sym_preproc_define] = STATE(308),
    [sym_preproc_undef] = STATE(308),
    [aux_sym_class_declaration_repeat1] = STATE(3853),
    [aux_sym_lambda_expression_repeat1] = STATE(4299),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(2035),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1497),
    [anon_sym_ref] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_LT] = ACTIONS(2037),
    [anon_sym_GT] = ACTIONS(2037),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(2037),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_SLASH] = ACTIONS(2037),
    [anon_sym_PERCENT] = ACTIONS(2035),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_PIPE] = ACTIONS(2037),
    [anon_sym_AMP] = ACTIONS(79),
    [anon_sym_LT_LT] = ACTIONS(2035),
    [anon_sym_GT_GT] = ACTIONS(2037),
    [anon_sym_GT_GT_GT] = ACTIONS(2035),
    [anon_sym_EQ_EQ] = ACTIONS(2035),
    [anon_sym_BANG_EQ] = ACTIONS(2035),
    [anon_sym_GT_EQ] = ACTIONS(2035),
    [anon_sym_LT_EQ] = ACTIONS(2035),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(2037),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(2037),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1505),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1507),
    [anon_sym_DOT_DOT] = ACTIONS(1509),
    [anon_sym_AMP_AMP] = ACTIONS(2035),
    [anon_sym_PIPE_PIPE] = ACTIONS(2035),
    [anon_sym_QMARK_QMARK] = ACTIONS(2035),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(2037),
    [anon_sym_is] = ACTIONS(2037),
    [anon_sym_DASH_GT] = ACTIONS(2035),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_with] = ACTIONS(2037),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [309] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2798),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(5930),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_pattern] = STATE(8333),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6158),
    [sym_property_pattern_clause] = STATE(6724),
    [sym_subpattern] = STATE(8577),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(5471),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4216),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5060),
    [sym_postfix_unary_expression] = STATE(5061),
    [sym_prefix_unary_expression] = STATE(5061),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5060),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5061),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5060),
    [sym_member_access_expression] = STATE(3797),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5061),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9065),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(5060),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5060),
    [sym_typeof_expression] = STATE(5060),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3797),
    [sym_literal] = STATE(5060),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(309),
    [sym_preproc_endregion] = STATE(309),
    [sym_preproc_line] = STATE(309),
    [sym_preproc_pragma] = STATE(309),
    [sym_preproc_nullable] = STATE(309),
    [sym_preproc_error] = STATE(309),
    [sym_preproc_warning] = STATE(309),
    [sym_preproc_define] = STATE(309),
    [sym_preproc_undef] = STATE(309),
    [aux_sym_class_declaration_repeat1] = STATE(3874),
    [aux_sym_lambda_expression_repeat1] = STATE(4311),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_COMMA] = ACTIONS(2039),
    [anon_sym_LPAREN] = ACTIONS(1231),
    [anon_sym_ref] = ACTIONS(2041),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_RBRACE] = ACTIONS(2043),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_LT] = ACTIONS(1077),
    [anon_sym_GT] = ACTIONS(1077),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1117),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(1121),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_AMP] = ACTIONS(1117),
    [anon_sym_GT_EQ] = ACTIONS(1087),
    [anon_sym_LT_EQ] = ACTIONS(1087),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(1089),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1091),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1129),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1131),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(1135),
    [anon_sym_not] = ACTIONS(1101),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [310] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2802),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(5754),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_pattern] = STATE(8333),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6158),
    [sym_property_pattern_clause] = STATE(6724),
    [sym_subpattern] = STATE(8577),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6690),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5302),
    [sym_postfix_unary_expression] = STATE(5343),
    [sym_prefix_unary_expression] = STATE(5343),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5302),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5343),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5302),
    [sym_member_access_expression] = STATE(3862),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5343),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(5302),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5302),
    [sym_typeof_expression] = STATE(5302),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3862),
    [sym_literal] = STATE(5302),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(310),
    [sym_preproc_endregion] = STATE(310),
    [sym_preproc_line] = STATE(310),
    [sym_preproc_pragma] = STATE(310),
    [sym_preproc_nullable] = STATE(310),
    [sym_preproc_error] = STATE(310),
    [sym_preproc_warning] = STATE(310),
    [sym_preproc_define] = STATE(310),
    [sym_preproc_undef] = STATE(310),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_COMMA] = ACTIONS(2045),
    [anon_sym_LPAREN] = ACTIONS(1231),
    [anon_sym_ref] = ACTIONS(2047),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_RBRACE] = ACTIONS(2049),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_LT] = ACTIONS(1077),
    [anon_sym_GT] = ACTIONS(1077),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1117),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_AMP] = ACTIONS(1117),
    [anon_sym_GT_EQ] = ACTIONS(1087),
    [anon_sym_LT_EQ] = ACTIONS(1087),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(1089),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1091),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_not] = ACTIONS(1101),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [311] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6759),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2844),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6163),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_pattern] = STATE(8123),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6721),
    [sym_property_pattern_clause] = STATE(6770),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6727),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5060),
    [sym_postfix_unary_expression] = STATE(5061),
    [sym_prefix_unary_expression] = STATE(5061),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5060),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5061),
    [sym_switch_expression] = STATE(3765),
    [sym_switch_expression_arm] = STATE(8535),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5060),
    [sym_member_access_expression] = STATE(3797),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5061),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(5060),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5060),
    [sym_typeof_expression] = STATE(5060),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3797),
    [sym_literal] = STATE(5060),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(311),
    [sym_preproc_endregion] = STATE(311),
    [sym_preproc_line] = STATE(311),
    [sym_preproc_pragma] = STATE(311),
    [sym_preproc_nullable] = STATE(311),
    [sym_preproc_error] = STATE(311),
    [sym_preproc_warning] = STATE(311),
    [sym_preproc_define] = STATE(311),
    [sym_preproc_undef] = STATE(311),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_COMMA] = ACTIONS(2051),
    [anon_sym_LPAREN] = ACTIONS(1949),
    [anon_sym_ref] = ACTIONS(1951),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_RBRACE] = ACTIONS(2053),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(1955),
    [anon_sym_GT] = ACTIONS(1955),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1581),
    [anon_sym_TILDE] = ACTIONS(1581),
    [anon_sym_PLUS_PLUS] = ACTIONS(1581),
    [anon_sym_DASH_DASH] = ACTIONS(1581),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1579),
    [anon_sym_DASH] = ACTIONS(1579),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1581),
    [anon_sym_AMP] = ACTIONS(1581),
    [anon_sym_GT_EQ] = ACTIONS(1957),
    [anon_sym_LT_EQ] = ACTIONS(1957),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(1089),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1959),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(1961),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [312] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7163),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6685),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4473),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9905),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(312),
    [sym_preproc_endregion] = STATE(312),
    [sym_preproc_line] = STATE(312),
    [sym_preproc_pragma] = STATE(312),
    [sym_preproc_nullable] = STATE(312),
    [sym_preproc_error] = STATE(312),
    [sym_preproc_warning] = STATE(312),
    [sym_preproc_define] = STATE(312),
    [sym_preproc_undef] = STATE(312),
    [aux_sym_class_declaration_repeat1] = STATE(3878),
    [aux_sym_lambda_expression_repeat1] = STATE(4331),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2055),
    [anon_sym_ref] = ACTIONS(2057),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(1171),
    [anon_sym_GT] = ACTIONS(1171),
    [anon_sym_in] = ACTIONS(1171),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1171),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2059),
    [anon_sym_TILDE] = ACTIONS(2061),
    [anon_sym_PLUS_PLUS] = ACTIONS(2061),
    [anon_sym_DASH_DASH] = ACTIONS(2061),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2059),
    [anon_sym_DASH] = ACTIONS(2059),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_SLASH] = ACTIONS(1171),
    [anon_sym_PERCENT] = ACTIONS(1157),
    [anon_sym_CARET] = ACTIONS(2061),
    [anon_sym_PIPE] = ACTIONS(1171),
    [anon_sym_AMP] = ACTIONS(2059),
    [anon_sym_LT_LT] = ACTIONS(1157),
    [anon_sym_GT_GT] = ACTIONS(1171),
    [anon_sym_GT_GT_GT] = ACTIONS(1157),
    [anon_sym_EQ_EQ] = ACTIONS(1157),
    [anon_sym_BANG_EQ] = ACTIONS(1157),
    [anon_sym_GT_EQ] = ACTIONS(1157),
    [anon_sym_LT_EQ] = ACTIONS(1157),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(1171),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1171),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2063),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2065),
    [anon_sym_DOT_DOT] = ACTIONS(2067),
    [anon_sym_AMP_AMP] = ACTIONS(1157),
    [anon_sym_PIPE_PIPE] = ACTIONS(1157),
    [anon_sym_QMARK_QMARK] = ACTIONS(1157),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1171),
    [anon_sym_is] = ACTIONS(1171),
    [anon_sym_DASH_GT] = ACTIONS(1157),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_with] = ACTIONS(1171),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [313] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7163),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6601),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4473),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9905),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(313),
    [sym_preproc_endregion] = STATE(313),
    [sym_preproc_line] = STATE(313),
    [sym_preproc_pragma] = STATE(313),
    [sym_preproc_nullable] = STATE(313),
    [sym_preproc_error] = STATE(313),
    [sym_preproc_warning] = STATE(313),
    [sym_preproc_define] = STATE(313),
    [sym_preproc_undef] = STATE(313),
    [aux_sym_class_declaration_repeat1] = STATE(3878),
    [aux_sym_lambda_expression_repeat1] = STATE(4331),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2055),
    [anon_sym_ref] = ACTIONS(2057),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(1229),
    [anon_sym_GT] = ACTIONS(1229),
    [anon_sym_in] = ACTIONS(1229),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1229),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2059),
    [anon_sym_TILDE] = ACTIONS(2061),
    [anon_sym_PLUS_PLUS] = ACTIONS(2061),
    [anon_sym_DASH_DASH] = ACTIONS(2061),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2059),
    [anon_sym_DASH] = ACTIONS(2059),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_SLASH] = ACTIONS(1229),
    [anon_sym_PERCENT] = ACTIONS(1227),
    [anon_sym_CARET] = ACTIONS(2061),
    [anon_sym_PIPE] = ACTIONS(1229),
    [anon_sym_AMP] = ACTIONS(2059),
    [anon_sym_LT_LT] = ACTIONS(1227),
    [anon_sym_GT_GT] = ACTIONS(1229),
    [anon_sym_GT_GT_GT] = ACTIONS(1227),
    [anon_sym_EQ_EQ] = ACTIONS(1227),
    [anon_sym_BANG_EQ] = ACTIONS(1227),
    [anon_sym_GT_EQ] = ACTIONS(1227),
    [anon_sym_LT_EQ] = ACTIONS(1227),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(1229),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1229),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2063),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2065),
    [anon_sym_DOT_DOT] = ACTIONS(2067),
    [anon_sym_AMP_AMP] = ACTIONS(1227),
    [anon_sym_PIPE_PIPE] = ACTIONS(1227),
    [anon_sym_QMARK_QMARK] = ACTIONS(1227),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1229),
    [anon_sym_is] = ACTIONS(1229),
    [anon_sym_DASH_GT] = ACTIONS(1227),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_with] = ACTIONS(1229),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [314] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6956),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6430),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9482),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(314),
    [sym_preproc_endregion] = STATE(314),
    [sym_preproc_line] = STATE(314),
    [sym_preproc_pragma] = STATE(314),
    [sym_preproc_nullable] = STATE(314),
    [sym_preproc_error] = STATE(314),
    [sym_preproc_warning] = STATE(314),
    [sym_preproc_define] = STATE(314),
    [sym_preproc_undef] = STATE(314),
    [aux_sym_class_declaration_repeat1] = STATE(3853),
    [aux_sym_lambda_expression_repeat1] = STATE(4299),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(2069),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2027),
    [anon_sym_ref] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_LT] = ACTIONS(2029),
    [anon_sym_GT] = ACTIONS(2029),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(2029),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_SLASH] = ACTIONS(2029),
    [anon_sym_PERCENT] = ACTIONS(2031),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_PIPE] = ACTIONS(2029),
    [anon_sym_AMP] = ACTIONS(79),
    [anon_sym_LT_LT] = ACTIONS(2031),
    [anon_sym_GT_GT] = ACTIONS(2029),
    [anon_sym_GT_GT_GT] = ACTIONS(2031),
    [anon_sym_EQ_EQ] = ACTIONS(2031),
    [anon_sym_BANG_EQ] = ACTIONS(2031),
    [anon_sym_GT_EQ] = ACTIONS(2031),
    [anon_sym_LT_EQ] = ACTIONS(2031),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(2029),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(2029),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1505),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1507),
    [anon_sym_DOT_DOT] = ACTIONS(1509),
    [anon_sym_AMP_AMP] = ACTIONS(2031),
    [anon_sym_PIPE_PIPE] = ACTIONS(2031),
    [anon_sym_QMARK_QMARK] = ACTIONS(2031),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(2029),
    [anon_sym_is] = ACTIONS(2029),
    [anon_sym_DASH_GT] = ACTIONS(2031),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_with] = ACTIONS(2029),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [315] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6759),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2844),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6163),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_pattern] = STATE(8123),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6721),
    [sym_property_pattern_clause] = STATE(6770),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6727),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5060),
    [sym_postfix_unary_expression] = STATE(5061),
    [sym_prefix_unary_expression] = STATE(5061),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5060),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5061),
    [sym_switch_expression] = STATE(3765),
    [sym_switch_expression_arm] = STATE(8416),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5060),
    [sym_member_access_expression] = STATE(3797),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5061),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(5060),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5060),
    [sym_typeof_expression] = STATE(5060),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3797),
    [sym_literal] = STATE(5060),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(315),
    [sym_preproc_endregion] = STATE(315),
    [sym_preproc_line] = STATE(315),
    [sym_preproc_pragma] = STATE(315),
    [sym_preproc_nullable] = STATE(315),
    [sym_preproc_error] = STATE(315),
    [sym_preproc_warning] = STATE(315),
    [sym_preproc_define] = STATE(315),
    [sym_preproc_undef] = STATE(315),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_COMMA] = ACTIONS(2071),
    [anon_sym_LPAREN] = ACTIONS(1949),
    [anon_sym_ref] = ACTIONS(1951),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_RBRACE] = ACTIONS(2073),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(1955),
    [anon_sym_GT] = ACTIONS(1955),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1581),
    [anon_sym_TILDE] = ACTIONS(1581),
    [anon_sym_PLUS_PLUS] = ACTIONS(1581),
    [anon_sym_DASH_DASH] = ACTIONS(1581),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1579),
    [anon_sym_DASH] = ACTIONS(1579),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1581),
    [anon_sym_AMP] = ACTIONS(1581),
    [anon_sym_GT_EQ] = ACTIONS(1957),
    [anon_sym_LT_EQ] = ACTIONS(1957),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(1089),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1959),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(1961),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [316] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2798),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(5930),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_pattern] = STATE(8333),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6158),
    [sym_property_pattern_clause] = STATE(6724),
    [sym_subpattern] = STATE(8585),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(5471),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4216),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5060),
    [sym_postfix_unary_expression] = STATE(5061),
    [sym_prefix_unary_expression] = STATE(5061),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5060),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5061),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5060),
    [sym_member_access_expression] = STATE(3797),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5061),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9065),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(5060),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5060),
    [sym_typeof_expression] = STATE(5060),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3797),
    [sym_literal] = STATE(5060),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(316),
    [sym_preproc_endregion] = STATE(316),
    [sym_preproc_line] = STATE(316),
    [sym_preproc_pragma] = STATE(316),
    [sym_preproc_nullable] = STATE(316),
    [sym_preproc_error] = STATE(316),
    [sym_preproc_warning] = STATE(316),
    [sym_preproc_define] = STATE(316),
    [sym_preproc_undef] = STATE(316),
    [aux_sym_class_declaration_repeat1] = STATE(3874),
    [aux_sym_lambda_expression_repeat1] = STATE(4311),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_COMMA] = ACTIONS(2075),
    [anon_sym_LPAREN] = ACTIONS(1231),
    [anon_sym_ref] = ACTIONS(2041),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_RBRACE] = ACTIONS(2077),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_LT] = ACTIONS(1077),
    [anon_sym_GT] = ACTIONS(1077),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1117),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(1121),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_AMP] = ACTIONS(1117),
    [anon_sym_GT_EQ] = ACTIONS(1087),
    [anon_sym_LT_EQ] = ACTIONS(1087),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(1089),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1091),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1129),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1131),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(1135),
    [anon_sym_not] = ACTIONS(1101),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [317] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6956),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6382),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9482),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(317),
    [sym_preproc_endregion] = STATE(317),
    [sym_preproc_line] = STATE(317),
    [sym_preproc_pragma] = STATE(317),
    [sym_preproc_nullable] = STATE(317),
    [sym_preproc_error] = STATE(317),
    [sym_preproc_warning] = STATE(317),
    [sym_preproc_define] = STATE(317),
    [sym_preproc_undef] = STATE(317),
    [aux_sym_class_declaration_repeat1] = STATE(3853),
    [aux_sym_lambda_expression_repeat1] = STATE(4299),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(2079),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2027),
    [anon_sym_ref] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_LT] = ACTIONS(2029),
    [anon_sym_GT] = ACTIONS(2029),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(2029),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_SLASH] = ACTIONS(2029),
    [anon_sym_PERCENT] = ACTIONS(2031),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_PIPE] = ACTIONS(2029),
    [anon_sym_AMP] = ACTIONS(79),
    [anon_sym_LT_LT] = ACTIONS(2031),
    [anon_sym_GT_GT] = ACTIONS(2029),
    [anon_sym_GT_GT_GT] = ACTIONS(2031),
    [anon_sym_EQ_EQ] = ACTIONS(2031),
    [anon_sym_BANG_EQ] = ACTIONS(2031),
    [anon_sym_GT_EQ] = ACTIONS(2031),
    [anon_sym_LT_EQ] = ACTIONS(2031),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(2029),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(2029),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1505),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1507),
    [anon_sym_DOT_DOT] = ACTIONS(1509),
    [anon_sym_AMP_AMP] = ACTIONS(2031),
    [anon_sym_PIPE_PIPE] = ACTIONS(2031),
    [anon_sym_QMARK_QMARK] = ACTIONS(2031),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(2029),
    [anon_sym_is] = ACTIONS(2029),
    [anon_sym_DASH_GT] = ACTIONS(2031),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_with] = ACTIONS(2029),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [318] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6925),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2932),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6992),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4553),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3702),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7420),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9634),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(318),
    [sym_preproc_endregion] = STATE(318),
    [sym_preproc_line] = STATE(318),
    [sym_preproc_pragma] = STATE(318),
    [sym_preproc_nullable] = STATE(318),
    [sym_preproc_error] = STATE(318),
    [sym_preproc_warning] = STATE(318),
    [sym_preproc_define] = STATE(318),
    [sym_preproc_undef] = STATE(318),
    [aux_sym_class_declaration_repeat1] = STATE(3819),
    [aux_sym_lambda_expression_repeat1] = STATE(4232),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_COMMA] = ACTIONS(1157),
    [anon_sym_LPAREN] = ACTIONS(1995),
    [anon_sym_ref] = ACTIONS(1997),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1771),
    [anon_sym_LT] = ACTIONS(1171),
    [anon_sym_GT] = ACTIONS(1171),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1171),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1999),
    [anon_sym_TILDE] = ACTIONS(2001),
    [anon_sym_PLUS_PLUS] = ACTIONS(2001),
    [anon_sym_DASH_DASH] = ACTIONS(2001),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1999),
    [anon_sym_DASH] = ACTIONS(1999),
    [anon_sym_STAR] = ACTIONS(1777),
    [anon_sym_SLASH] = ACTIONS(1171),
    [anon_sym_PERCENT] = ACTIONS(1157),
    [anon_sym_CARET] = ACTIONS(2001),
    [anon_sym_PIPE] = ACTIONS(1171),
    [anon_sym_AMP] = ACTIONS(1999),
    [anon_sym_LT_LT] = ACTIONS(1157),
    [anon_sym_GT_GT] = ACTIONS(1171),
    [anon_sym_GT_GT_GT] = ACTIONS(1157),
    [anon_sym_EQ_EQ] = ACTIONS(1157),
    [anon_sym_BANG_EQ] = ACTIONS(1157),
    [anon_sym_GT_EQ] = ACTIONS(1157),
    [anon_sym_LT_EQ] = ACTIONS(1157),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_DOT] = ACTIONS(1171),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1171),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(2003),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2005),
    [anon_sym_DOT_DOT] = ACTIONS(2007),
    [anon_sym_AMP_AMP] = ACTIONS(1157),
    [anon_sym_PIPE_PIPE] = ACTIONS(1157),
    [anon_sym_QMARK_QMARK] = ACTIONS(1157),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1171),
    [anon_sym_is] = ACTIONS(1171),
    [anon_sym_DASH_GT] = ACTIONS(1157),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_with] = ACTIONS(1171),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [319] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2802),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(5754),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_pattern] = STATE(8333),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6158),
    [sym_property_pattern_clause] = STATE(6724),
    [sym_subpattern] = STATE(8585),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6690),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5302),
    [sym_postfix_unary_expression] = STATE(5343),
    [sym_prefix_unary_expression] = STATE(5343),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5302),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5343),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5302),
    [sym_member_access_expression] = STATE(3862),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5343),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(5302),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5302),
    [sym_typeof_expression] = STATE(5302),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3862),
    [sym_literal] = STATE(5302),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(319),
    [sym_preproc_endregion] = STATE(319),
    [sym_preproc_line] = STATE(319),
    [sym_preproc_pragma] = STATE(319),
    [sym_preproc_nullable] = STATE(319),
    [sym_preproc_error] = STATE(319),
    [sym_preproc_warning] = STATE(319),
    [sym_preproc_define] = STATE(319),
    [sym_preproc_undef] = STATE(319),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_COMMA] = ACTIONS(2081),
    [anon_sym_LPAREN] = ACTIONS(1231),
    [anon_sym_ref] = ACTIONS(2047),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_RBRACE] = ACTIONS(2083),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_LT] = ACTIONS(1077),
    [anon_sym_GT] = ACTIONS(1077),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1117),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_AMP] = ACTIONS(1117),
    [anon_sym_GT_EQ] = ACTIONS(1087),
    [anon_sym_LT_EQ] = ACTIONS(1087),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(1089),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1091),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_not] = ACTIONS(1101),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [320] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6759),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2844),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6163),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_pattern] = STATE(8123),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6721),
    [sym_property_pattern_clause] = STATE(6770),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6727),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5060),
    [sym_postfix_unary_expression] = STATE(5061),
    [sym_prefix_unary_expression] = STATE(5061),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5060),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5061),
    [sym_switch_expression] = STATE(3765),
    [sym_switch_expression_arm] = STATE(8580),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5060),
    [sym_member_access_expression] = STATE(3797),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5061),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(5060),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5060),
    [sym_typeof_expression] = STATE(5060),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3797),
    [sym_literal] = STATE(5060),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(320),
    [sym_preproc_endregion] = STATE(320),
    [sym_preproc_line] = STATE(320),
    [sym_preproc_pragma] = STATE(320),
    [sym_preproc_nullable] = STATE(320),
    [sym_preproc_error] = STATE(320),
    [sym_preproc_warning] = STATE(320),
    [sym_preproc_define] = STATE(320),
    [sym_preproc_undef] = STATE(320),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_COMMA] = ACTIONS(2085),
    [anon_sym_LPAREN] = ACTIONS(1949),
    [anon_sym_ref] = ACTIONS(1951),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_RBRACE] = ACTIONS(2087),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(1955),
    [anon_sym_GT] = ACTIONS(1955),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1581),
    [anon_sym_TILDE] = ACTIONS(1581),
    [anon_sym_PLUS_PLUS] = ACTIONS(1581),
    [anon_sym_DASH_DASH] = ACTIONS(1581),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1579),
    [anon_sym_DASH] = ACTIONS(1579),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1581),
    [anon_sym_AMP] = ACTIONS(1581),
    [anon_sym_GT_EQ] = ACTIONS(1957),
    [anon_sym_LT_EQ] = ACTIONS(1957),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(1089),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1959),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(1961),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [321] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6911),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2930),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7031),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4939),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3742),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7420),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9374),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(321),
    [sym_preproc_endregion] = STATE(321),
    [sym_preproc_line] = STATE(321),
    [sym_preproc_pragma] = STATE(321),
    [sym_preproc_nullable] = STATE(321),
    [sym_preproc_error] = STATE(321),
    [sym_preproc_warning] = STATE(321),
    [sym_preproc_define] = STATE(321),
    [sym_preproc_undef] = STATE(321),
    [aux_sym_class_declaration_repeat1] = STATE(3861),
    [aux_sym_lambda_expression_repeat1] = STATE(4169),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_COMMA] = ACTIONS(1157),
    [anon_sym_LPAREN] = ACTIONS(2089),
    [anon_sym_ref] = ACTIONS(2091),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1695),
    [anon_sym_LT] = ACTIONS(1171),
    [anon_sym_GT] = ACTIONS(1171),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1171),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(2093),
    [anon_sym_TILDE] = ACTIONS(2095),
    [anon_sym_PLUS_PLUS] = ACTIONS(2095),
    [anon_sym_DASH_DASH] = ACTIONS(2095),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(2093),
    [anon_sym_DASH] = ACTIONS(2093),
    [anon_sym_STAR] = ACTIONS(1705),
    [anon_sym_SLASH] = ACTIONS(1171),
    [anon_sym_PERCENT] = ACTIONS(1157),
    [anon_sym_CARET] = ACTIONS(2095),
    [anon_sym_PIPE] = ACTIONS(1171),
    [anon_sym_AMP] = ACTIONS(2093),
    [anon_sym_LT_LT] = ACTIONS(1157),
    [anon_sym_GT_GT] = ACTIONS(1171),
    [anon_sym_GT_GT_GT] = ACTIONS(1157),
    [anon_sym_EQ_EQ] = ACTIONS(1157),
    [anon_sym_BANG_EQ] = ACTIONS(1157),
    [anon_sym_GT_EQ] = ACTIONS(1157),
    [anon_sym_LT_EQ] = ACTIONS(1157),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_DOT] = ACTIONS(1171),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1171),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(2097),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2099),
    [anon_sym_DOT_DOT] = ACTIONS(2101),
    [anon_sym_AMP_AMP] = ACTIONS(1157),
    [anon_sym_PIPE_PIPE] = ACTIONS(1157),
    [anon_sym_QMARK_QMARK] = ACTIONS(1157),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1171),
    [anon_sym_is] = ACTIONS(1171),
    [anon_sym_DASH_GT] = ACTIONS(1157),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_with] = ACTIONS(1171),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [322] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2798),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(5930),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_pattern] = STATE(8333),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6158),
    [sym_property_pattern_clause] = STATE(6724),
    [sym_subpattern] = STATE(8577),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(5471),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4216),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5060),
    [sym_postfix_unary_expression] = STATE(5061),
    [sym_prefix_unary_expression] = STATE(5061),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5060),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5061),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5060),
    [sym_member_access_expression] = STATE(3797),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5061),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9065),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(5060),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5060),
    [sym_typeof_expression] = STATE(5060),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3797),
    [sym_literal] = STATE(5060),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(322),
    [sym_preproc_endregion] = STATE(322),
    [sym_preproc_line] = STATE(322),
    [sym_preproc_pragma] = STATE(322),
    [sym_preproc_nullable] = STATE(322),
    [sym_preproc_error] = STATE(322),
    [sym_preproc_warning] = STATE(322),
    [sym_preproc_define] = STATE(322),
    [sym_preproc_undef] = STATE(322),
    [aux_sym_class_declaration_repeat1] = STATE(3874),
    [aux_sym_lambda_expression_repeat1] = STATE(4311),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_COMMA] = ACTIONS(2103),
    [anon_sym_LPAREN] = ACTIONS(1231),
    [anon_sym_ref] = ACTIONS(2041),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_RBRACE] = ACTIONS(2105),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_LT] = ACTIONS(1077),
    [anon_sym_GT] = ACTIONS(1077),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1117),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(1121),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_AMP] = ACTIONS(1117),
    [anon_sym_GT_EQ] = ACTIONS(1087),
    [anon_sym_LT_EQ] = ACTIONS(1087),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(1089),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1091),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1129),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1131),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(1135),
    [anon_sym_not] = ACTIONS(1101),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [323] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6911),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2930),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7031),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4884),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3742),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7420),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9374),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(323),
    [sym_preproc_endregion] = STATE(323),
    [sym_preproc_line] = STATE(323),
    [sym_preproc_pragma] = STATE(323),
    [sym_preproc_nullable] = STATE(323),
    [sym_preproc_error] = STATE(323),
    [sym_preproc_warning] = STATE(323),
    [sym_preproc_define] = STATE(323),
    [sym_preproc_undef] = STATE(323),
    [aux_sym_class_declaration_repeat1] = STATE(3861),
    [aux_sym_lambda_expression_repeat1] = STATE(4169),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_COMMA] = ACTIONS(1227),
    [anon_sym_LPAREN] = ACTIONS(2089),
    [anon_sym_ref] = ACTIONS(2091),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1695),
    [anon_sym_LT] = ACTIONS(1229),
    [anon_sym_GT] = ACTIONS(1229),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1229),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(2093),
    [anon_sym_TILDE] = ACTIONS(2095),
    [anon_sym_PLUS_PLUS] = ACTIONS(2095),
    [anon_sym_DASH_DASH] = ACTIONS(2095),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(2093),
    [anon_sym_DASH] = ACTIONS(2093),
    [anon_sym_STAR] = ACTIONS(1705),
    [anon_sym_SLASH] = ACTIONS(1229),
    [anon_sym_PERCENT] = ACTIONS(1227),
    [anon_sym_CARET] = ACTIONS(2095),
    [anon_sym_PIPE] = ACTIONS(1229),
    [anon_sym_AMP] = ACTIONS(2093),
    [anon_sym_LT_LT] = ACTIONS(1227),
    [anon_sym_GT_GT] = ACTIONS(1229),
    [anon_sym_GT_GT_GT] = ACTIONS(1227),
    [anon_sym_EQ_EQ] = ACTIONS(1227),
    [anon_sym_BANG_EQ] = ACTIONS(1227),
    [anon_sym_GT_EQ] = ACTIONS(1227),
    [anon_sym_LT_EQ] = ACTIONS(1227),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_DOT] = ACTIONS(1229),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1229),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(2097),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2099),
    [anon_sym_DOT_DOT] = ACTIONS(2101),
    [anon_sym_AMP_AMP] = ACTIONS(1227),
    [anon_sym_PIPE_PIPE] = ACTIONS(1227),
    [anon_sym_QMARK_QMARK] = ACTIONS(1227),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1229),
    [anon_sym_is] = ACTIONS(1229),
    [anon_sym_DASH_GT] = ACTIONS(1227),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_with] = ACTIONS(1229),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [324] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2798),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(5930),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_pattern] = STATE(8333),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6158),
    [sym_property_pattern_clause] = STATE(6724),
    [sym_subpattern] = STATE(8577),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(5471),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4216),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5060),
    [sym_postfix_unary_expression] = STATE(5061),
    [sym_prefix_unary_expression] = STATE(5061),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5060),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5061),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5060),
    [sym_member_access_expression] = STATE(3797),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5061),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9065),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(5060),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5060),
    [sym_typeof_expression] = STATE(5060),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3797),
    [sym_literal] = STATE(5060),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(324),
    [sym_preproc_endregion] = STATE(324),
    [sym_preproc_line] = STATE(324),
    [sym_preproc_pragma] = STATE(324),
    [sym_preproc_nullable] = STATE(324),
    [sym_preproc_error] = STATE(324),
    [sym_preproc_warning] = STATE(324),
    [sym_preproc_define] = STATE(324),
    [sym_preproc_undef] = STATE(324),
    [aux_sym_class_declaration_repeat1] = STATE(3874),
    [aux_sym_lambda_expression_repeat1] = STATE(4311),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_COMMA] = ACTIONS(2107),
    [anon_sym_LPAREN] = ACTIONS(1231),
    [anon_sym_ref] = ACTIONS(2041),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_RBRACE] = ACTIONS(2109),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_LT] = ACTIONS(1077),
    [anon_sym_GT] = ACTIONS(1077),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1117),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(1121),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_AMP] = ACTIONS(1117),
    [anon_sym_GT_EQ] = ACTIONS(1087),
    [anon_sym_LT_EQ] = ACTIONS(1087),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(1089),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1091),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1129),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1131),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(1135),
    [anon_sym_not] = ACTIONS(1101),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [325] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6948),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2940),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6999),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5103),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3857),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7444),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9574),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(325),
    [sym_preproc_endregion] = STATE(325),
    [sym_preproc_line] = STATE(325),
    [sym_preproc_pragma] = STATE(325),
    [sym_preproc_nullable] = STATE(325),
    [sym_preproc_error] = STATE(325),
    [sym_preproc_warning] = STATE(325),
    [sym_preproc_define] = STATE(325),
    [sym_preproc_undef] = STATE(325),
    [aux_sym_class_declaration_repeat1] = STATE(3854),
    [aux_sym_lambda_expression_repeat1] = STATE(4136),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2111),
    [anon_sym_ref] = ACTIONS(2113),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1897),
    [anon_sym_LT] = ACTIONS(1229),
    [anon_sym_GT] = ACTIONS(1229),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1229),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2115),
    [anon_sym_TILDE] = ACTIONS(2117),
    [anon_sym_PLUS_PLUS] = ACTIONS(2117),
    [anon_sym_DASH_DASH] = ACTIONS(2117),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2115),
    [anon_sym_DASH] = ACTIONS(2115),
    [anon_sym_STAR] = ACTIONS(1903),
    [anon_sym_SLASH] = ACTIONS(1229),
    [anon_sym_PERCENT] = ACTIONS(1227),
    [anon_sym_CARET] = ACTIONS(2117),
    [anon_sym_PIPE] = ACTIONS(1229),
    [anon_sym_AMP] = ACTIONS(2115),
    [anon_sym_LT_LT] = ACTIONS(1227),
    [anon_sym_GT_GT] = ACTIONS(1229),
    [anon_sym_GT_GT_GT] = ACTIONS(1227),
    [anon_sym_EQ_EQ] = ACTIONS(1227),
    [anon_sym_BANG_EQ] = ACTIONS(1227),
    [anon_sym_GT_EQ] = ACTIONS(1227),
    [anon_sym_LT_EQ] = ACTIONS(1227),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(1229),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1229),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2119),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2121),
    [anon_sym_DOT_DOT] = ACTIONS(2123),
    [anon_sym_AMP_AMP] = ACTIONS(1227),
    [anon_sym_PIPE_PIPE] = ACTIONS(1227),
    [anon_sym_QMARK_QMARK] = ACTIONS(1227),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1229),
    [anon_sym_is] = ACTIONS(1229),
    [anon_sym_DASH_GT] = ACTIONS(1227),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_with] = ACTIONS(1229),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [326] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6759),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2844),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6163),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_pattern] = STATE(8123),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6721),
    [sym_property_pattern_clause] = STATE(6770),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6727),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5060),
    [sym_postfix_unary_expression] = STATE(5061),
    [sym_prefix_unary_expression] = STATE(5061),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5060),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5061),
    [sym_switch_expression] = STATE(3765),
    [sym_switch_expression_arm] = STATE(8935),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5060),
    [sym_member_access_expression] = STATE(3797),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5061),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(5060),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5060),
    [sym_typeof_expression] = STATE(5060),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3797),
    [sym_literal] = STATE(5060),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(326),
    [sym_preproc_endregion] = STATE(326),
    [sym_preproc_line] = STATE(326),
    [sym_preproc_pragma] = STATE(326),
    [sym_preproc_nullable] = STATE(326),
    [sym_preproc_error] = STATE(326),
    [sym_preproc_warning] = STATE(326),
    [sym_preproc_define] = STATE(326),
    [sym_preproc_undef] = STATE(326),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1949),
    [anon_sym_ref] = ACTIONS(1951),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_RBRACE] = ACTIONS(2125),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(1955),
    [anon_sym_GT] = ACTIONS(1955),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1581),
    [anon_sym_TILDE] = ACTIONS(1581),
    [anon_sym_PLUS_PLUS] = ACTIONS(1581),
    [anon_sym_DASH_DASH] = ACTIONS(1581),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1579),
    [anon_sym_DASH] = ACTIONS(1579),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1581),
    [anon_sym_AMP] = ACTIONS(1581),
    [anon_sym_GT_EQ] = ACTIONS(1957),
    [anon_sym_LT_EQ] = ACTIONS(1957),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(1089),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1959),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(1961),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [327] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6932),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2977),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6996),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6298),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4378),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7430),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9693),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(327),
    [sym_preproc_endregion] = STATE(327),
    [sym_preproc_line] = STATE(327),
    [sym_preproc_pragma] = STATE(327),
    [sym_preproc_nullable] = STATE(327),
    [sym_preproc_error] = STATE(327),
    [sym_preproc_warning] = STATE(327),
    [sym_preproc_define] = STATE(327),
    [sym_preproc_undef] = STATE(327),
    [aux_sym_class_declaration_repeat1] = STATE(3820),
    [aux_sym_lambda_expression_repeat1] = STATE(4234),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2127),
    [anon_sym_ref] = ACTIONS(2129),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2131),
    [anon_sym_LT] = ACTIONS(1171),
    [anon_sym_GT] = ACTIONS(1171),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1171),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2133),
    [anon_sym_TILDE] = ACTIONS(2135),
    [anon_sym_PLUS_PLUS] = ACTIONS(2135),
    [anon_sym_DASH_DASH] = ACTIONS(2135),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2133),
    [anon_sym_DASH] = ACTIONS(2133),
    [anon_sym_STAR] = ACTIONS(2137),
    [anon_sym_SLASH] = ACTIONS(1171),
    [anon_sym_PERCENT] = ACTIONS(1157),
    [anon_sym_CARET] = ACTIONS(2135),
    [anon_sym_PIPE] = ACTIONS(1171),
    [anon_sym_AMP] = ACTIONS(2133),
    [anon_sym_LT_LT] = ACTIONS(1157),
    [anon_sym_GT_GT] = ACTIONS(1171),
    [anon_sym_GT_GT_GT] = ACTIONS(1157),
    [anon_sym_EQ_EQ] = ACTIONS(1157),
    [anon_sym_BANG_EQ] = ACTIONS(1157),
    [anon_sym_GT_EQ] = ACTIONS(1157),
    [anon_sym_LT_EQ] = ACTIONS(1157),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_DOT] = ACTIONS(1171),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1171),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2139),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2141),
    [anon_sym_DOT_DOT] = ACTIONS(2143),
    [anon_sym_AMP_AMP] = ACTIONS(1157),
    [anon_sym_PIPE_PIPE] = ACTIONS(1157),
    [anon_sym_QMARK_QMARK] = ACTIONS(1157),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1171),
    [anon_sym_is] = ACTIONS(1171),
    [anon_sym_DASH_GT] = ACTIONS(1157),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_with] = ACTIONS(1171),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [328] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6932),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2977),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6996),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6295),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4378),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7430),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9693),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(328),
    [sym_preproc_endregion] = STATE(328),
    [sym_preproc_line] = STATE(328),
    [sym_preproc_pragma] = STATE(328),
    [sym_preproc_nullable] = STATE(328),
    [sym_preproc_error] = STATE(328),
    [sym_preproc_warning] = STATE(328),
    [sym_preproc_define] = STATE(328),
    [sym_preproc_undef] = STATE(328),
    [aux_sym_class_declaration_repeat1] = STATE(3820),
    [aux_sym_lambda_expression_repeat1] = STATE(4234),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2127),
    [anon_sym_ref] = ACTIONS(2129),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2131),
    [anon_sym_LT] = ACTIONS(1229),
    [anon_sym_GT] = ACTIONS(1229),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1229),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2133),
    [anon_sym_TILDE] = ACTIONS(2135),
    [anon_sym_PLUS_PLUS] = ACTIONS(2135),
    [anon_sym_DASH_DASH] = ACTIONS(2135),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2133),
    [anon_sym_DASH] = ACTIONS(2133),
    [anon_sym_STAR] = ACTIONS(2137),
    [anon_sym_SLASH] = ACTIONS(1229),
    [anon_sym_PERCENT] = ACTIONS(1227),
    [anon_sym_CARET] = ACTIONS(2135),
    [anon_sym_PIPE] = ACTIONS(1229),
    [anon_sym_AMP] = ACTIONS(2133),
    [anon_sym_LT_LT] = ACTIONS(1227),
    [anon_sym_GT_GT] = ACTIONS(1229),
    [anon_sym_GT_GT_GT] = ACTIONS(1227),
    [anon_sym_EQ_EQ] = ACTIONS(1227),
    [anon_sym_BANG_EQ] = ACTIONS(1227),
    [anon_sym_GT_EQ] = ACTIONS(1227),
    [anon_sym_LT_EQ] = ACTIONS(1227),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_DOT] = ACTIONS(1229),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1229),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2139),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2141),
    [anon_sym_DOT_DOT] = ACTIONS(2143),
    [anon_sym_AMP_AMP] = ACTIONS(1227),
    [anon_sym_PIPE_PIPE] = ACTIONS(1227),
    [anon_sym_QMARK_QMARK] = ACTIONS(1227),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1229),
    [anon_sym_is] = ACTIONS(1229),
    [anon_sym_DASH_GT] = ACTIONS(1227),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_with] = ACTIONS(1229),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [329] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2802),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(5754),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_pattern] = STATE(8333),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6158),
    [sym_property_pattern_clause] = STATE(6724),
    [sym_subpattern] = STATE(8548),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6690),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5302),
    [sym_postfix_unary_expression] = STATE(5343),
    [sym_prefix_unary_expression] = STATE(5343),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5302),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5343),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5302),
    [sym_member_access_expression] = STATE(3862),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5343),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(5302),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5302),
    [sym_typeof_expression] = STATE(5302),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3862),
    [sym_literal] = STATE(5302),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(329),
    [sym_preproc_endregion] = STATE(329),
    [sym_preproc_line] = STATE(329),
    [sym_preproc_pragma] = STATE(329),
    [sym_preproc_nullable] = STATE(329),
    [sym_preproc_error] = STATE(329),
    [sym_preproc_warning] = STATE(329),
    [sym_preproc_define] = STATE(329),
    [sym_preproc_undef] = STATE(329),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1231),
    [anon_sym_ref] = ACTIONS(2047),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_RBRACE] = ACTIONS(2145),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_LT] = ACTIONS(1077),
    [anon_sym_GT] = ACTIONS(1077),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1117),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_AMP] = ACTIONS(1117),
    [anon_sym_GT_EQ] = ACTIONS(1087),
    [anon_sym_LT_EQ] = ACTIONS(1087),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(1089),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1091),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_not] = ACTIONS(1101),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [330] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6759),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2844),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6163),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_pattern] = STATE(8123),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6721),
    [sym_property_pattern_clause] = STATE(6770),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6727),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5060),
    [sym_postfix_unary_expression] = STATE(5061),
    [sym_prefix_unary_expression] = STATE(5061),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5060),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5061),
    [sym_switch_expression] = STATE(3765),
    [sym_switch_expression_arm] = STATE(8935),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5060),
    [sym_member_access_expression] = STATE(3797),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5061),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(5060),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5060),
    [sym_typeof_expression] = STATE(5060),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3797),
    [sym_literal] = STATE(5060),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(330),
    [sym_preproc_endregion] = STATE(330),
    [sym_preproc_line] = STATE(330),
    [sym_preproc_pragma] = STATE(330),
    [sym_preproc_nullable] = STATE(330),
    [sym_preproc_error] = STATE(330),
    [sym_preproc_warning] = STATE(330),
    [sym_preproc_define] = STATE(330),
    [sym_preproc_undef] = STATE(330),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1949),
    [anon_sym_ref] = ACTIONS(1951),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_RBRACE] = ACTIONS(2147),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(1955),
    [anon_sym_GT] = ACTIONS(1955),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1581),
    [anon_sym_TILDE] = ACTIONS(1581),
    [anon_sym_PLUS_PLUS] = ACTIONS(1581),
    [anon_sym_DASH_DASH] = ACTIONS(1581),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1579),
    [anon_sym_DASH] = ACTIONS(1579),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1581),
    [anon_sym_AMP] = ACTIONS(1581),
    [anon_sym_GT_EQ] = ACTIONS(1957),
    [anon_sym_LT_EQ] = ACTIONS(1957),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(1089),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1959),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(1961),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [331] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6759),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2844),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6163),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_pattern] = STATE(8123),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6721),
    [sym_property_pattern_clause] = STATE(6770),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6727),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5060),
    [sym_postfix_unary_expression] = STATE(5061),
    [sym_prefix_unary_expression] = STATE(5061),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5060),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5061),
    [sym_switch_expression] = STATE(3765),
    [sym_switch_expression_arm] = STATE(8935),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5060),
    [sym_member_access_expression] = STATE(3797),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5061),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(5060),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5060),
    [sym_typeof_expression] = STATE(5060),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3797),
    [sym_literal] = STATE(5060),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(331),
    [sym_preproc_endregion] = STATE(331),
    [sym_preproc_line] = STATE(331),
    [sym_preproc_pragma] = STATE(331),
    [sym_preproc_nullable] = STATE(331),
    [sym_preproc_error] = STATE(331),
    [sym_preproc_warning] = STATE(331),
    [sym_preproc_define] = STATE(331),
    [sym_preproc_undef] = STATE(331),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1949),
    [anon_sym_ref] = ACTIONS(1951),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_RBRACE] = ACTIONS(2149),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(1955),
    [anon_sym_GT] = ACTIONS(1955),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1581),
    [anon_sym_TILDE] = ACTIONS(1581),
    [anon_sym_PLUS_PLUS] = ACTIONS(1581),
    [anon_sym_DASH_DASH] = ACTIONS(1581),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1579),
    [anon_sym_DASH] = ACTIONS(1579),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1581),
    [anon_sym_AMP] = ACTIONS(1581),
    [anon_sym_GT_EQ] = ACTIONS(1957),
    [anon_sym_LT_EQ] = ACTIONS(1957),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(1089),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1959),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(1961),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [332] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6914),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2960),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7049),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6154),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4399),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7440),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9013),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(332),
    [sym_preproc_endregion] = STATE(332),
    [sym_preproc_line] = STATE(332),
    [sym_preproc_pragma] = STATE(332),
    [sym_preproc_nullable] = STATE(332),
    [sym_preproc_error] = STATE(332),
    [sym_preproc_warning] = STATE(332),
    [sym_preproc_define] = STATE(332),
    [sym_preproc_undef] = STATE(332),
    [aux_sym_class_declaration_repeat1] = STATE(3833),
    [aux_sym_lambda_expression_repeat1] = STATE(4261),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2151),
    [anon_sym_ref] = ACTIONS(2153),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2155),
    [anon_sym_LT] = ACTIONS(1171),
    [anon_sym_GT] = ACTIONS(1171),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1171),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2157),
    [anon_sym_TILDE] = ACTIONS(2159),
    [anon_sym_PLUS_PLUS] = ACTIONS(2159),
    [anon_sym_DASH_DASH] = ACTIONS(2159),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2157),
    [anon_sym_DASH] = ACTIONS(2157),
    [anon_sym_STAR] = ACTIONS(2161),
    [anon_sym_SLASH] = ACTIONS(1171),
    [anon_sym_PERCENT] = ACTIONS(1157),
    [anon_sym_CARET] = ACTIONS(2159),
    [anon_sym_PIPE] = ACTIONS(1171),
    [anon_sym_AMP] = ACTIONS(2157),
    [anon_sym_LT_LT] = ACTIONS(1157),
    [anon_sym_GT_GT] = ACTIONS(1171),
    [anon_sym_GT_GT_GT] = ACTIONS(1157),
    [anon_sym_EQ_EQ] = ACTIONS(1157),
    [anon_sym_BANG_EQ] = ACTIONS(1157),
    [anon_sym_GT_EQ] = ACTIONS(1157),
    [anon_sym_LT_EQ] = ACTIONS(1157),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_DOT] = ACTIONS(1171),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1171),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2163),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2165),
    [anon_sym_DOT_DOT] = ACTIONS(2167),
    [anon_sym_AMP_AMP] = ACTIONS(1157),
    [anon_sym_PIPE_PIPE] = ACTIONS(1157),
    [anon_sym_QMARK_QMARK] = ACTIONS(1157),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1171),
    [anon_sym_is] = ACTIONS(1171),
    [anon_sym_DASH_GT] = ACTIONS(1157),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_with] = ACTIONS(1171),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [333] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6914),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2960),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7049),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6183),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4399),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7440),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9013),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(333),
    [sym_preproc_endregion] = STATE(333),
    [sym_preproc_line] = STATE(333),
    [sym_preproc_pragma] = STATE(333),
    [sym_preproc_nullable] = STATE(333),
    [sym_preproc_error] = STATE(333),
    [sym_preproc_warning] = STATE(333),
    [sym_preproc_define] = STATE(333),
    [sym_preproc_undef] = STATE(333),
    [aux_sym_class_declaration_repeat1] = STATE(3833),
    [aux_sym_lambda_expression_repeat1] = STATE(4261),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2151),
    [anon_sym_ref] = ACTIONS(2153),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2155),
    [anon_sym_LT] = ACTIONS(1229),
    [anon_sym_GT] = ACTIONS(1229),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1229),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2157),
    [anon_sym_TILDE] = ACTIONS(2159),
    [anon_sym_PLUS_PLUS] = ACTIONS(2159),
    [anon_sym_DASH_DASH] = ACTIONS(2159),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2157),
    [anon_sym_DASH] = ACTIONS(2157),
    [anon_sym_STAR] = ACTIONS(2161),
    [anon_sym_SLASH] = ACTIONS(1229),
    [anon_sym_PERCENT] = ACTIONS(1227),
    [anon_sym_CARET] = ACTIONS(2159),
    [anon_sym_PIPE] = ACTIONS(1229),
    [anon_sym_AMP] = ACTIONS(2157),
    [anon_sym_LT_LT] = ACTIONS(1227),
    [anon_sym_GT_GT] = ACTIONS(1229),
    [anon_sym_GT_GT_GT] = ACTIONS(1227),
    [anon_sym_EQ_EQ] = ACTIONS(1227),
    [anon_sym_BANG_EQ] = ACTIONS(1227),
    [anon_sym_GT_EQ] = ACTIONS(1227),
    [anon_sym_LT_EQ] = ACTIONS(1227),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_DOT] = ACTIONS(1229),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1229),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2163),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2165),
    [anon_sym_DOT_DOT] = ACTIONS(2167),
    [anon_sym_AMP_AMP] = ACTIONS(1227),
    [anon_sym_PIPE_PIPE] = ACTIONS(1227),
    [anon_sym_QMARK_QMARK] = ACTIONS(1227),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1229),
    [anon_sym_is] = ACTIONS(1229),
    [anon_sym_DASH_GT] = ACTIONS(1227),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_with] = ACTIONS(1229),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [334] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6943),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2986),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7151),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6548),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4518),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7441),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9110),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(334),
    [sym_preproc_endregion] = STATE(334),
    [sym_preproc_line] = STATE(334),
    [sym_preproc_pragma] = STATE(334),
    [sym_preproc_nullable] = STATE(334),
    [sym_preproc_error] = STATE(334),
    [sym_preproc_warning] = STATE(334),
    [sym_preproc_define] = STATE(334),
    [sym_preproc_undef] = STATE(334),
    [aux_sym_class_declaration_repeat1] = STATE(3875),
    [aux_sym_lambda_expression_repeat1] = STATE(4315),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2169),
    [anon_sym_ref] = ACTIONS(2171),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2173),
    [anon_sym_LT] = ACTIONS(1171),
    [anon_sym_GT] = ACTIONS(1171),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1171),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2175),
    [anon_sym_TILDE] = ACTIONS(2177),
    [anon_sym_PLUS_PLUS] = ACTIONS(2177),
    [anon_sym_DASH_DASH] = ACTIONS(2177),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2175),
    [anon_sym_DASH] = ACTIONS(2175),
    [anon_sym_STAR] = ACTIONS(2179),
    [anon_sym_SLASH] = ACTIONS(1171),
    [anon_sym_PERCENT] = ACTIONS(1157),
    [anon_sym_CARET] = ACTIONS(2177),
    [anon_sym_PIPE] = ACTIONS(1171),
    [anon_sym_AMP] = ACTIONS(2175),
    [anon_sym_LT_LT] = ACTIONS(1157),
    [anon_sym_GT_GT] = ACTIONS(1171),
    [anon_sym_GT_GT_GT] = ACTIONS(1157),
    [anon_sym_EQ_EQ] = ACTIONS(1157),
    [anon_sym_BANG_EQ] = ACTIONS(1157),
    [anon_sym_GT_EQ] = ACTIONS(1157),
    [anon_sym_LT_EQ] = ACTIONS(1157),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(1171),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1171),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2181),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2183),
    [anon_sym_DOT_DOT] = ACTIONS(2185),
    [anon_sym_AMP_AMP] = ACTIONS(1157),
    [anon_sym_PIPE_PIPE] = ACTIONS(1157),
    [anon_sym_QMARK_QMARK] = ACTIONS(1157),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1171),
    [anon_sym_is] = ACTIONS(1171),
    [anon_sym_DASH_GT] = ACTIONS(1157),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_with] = ACTIONS(1171),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [335] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2802),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(5754),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_pattern] = STATE(8333),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6158),
    [sym_property_pattern_clause] = STATE(6724),
    [sym_subpattern] = STATE(8548),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6690),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5302),
    [sym_postfix_unary_expression] = STATE(5343),
    [sym_prefix_unary_expression] = STATE(5343),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5302),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5343),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5302),
    [sym_member_access_expression] = STATE(3862),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5343),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(5302),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5302),
    [sym_typeof_expression] = STATE(5302),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3862),
    [sym_literal] = STATE(5302),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(335),
    [sym_preproc_endregion] = STATE(335),
    [sym_preproc_line] = STATE(335),
    [sym_preproc_pragma] = STATE(335),
    [sym_preproc_nullable] = STATE(335),
    [sym_preproc_error] = STATE(335),
    [sym_preproc_warning] = STATE(335),
    [sym_preproc_define] = STATE(335),
    [sym_preproc_undef] = STATE(335),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1231),
    [anon_sym_ref] = ACTIONS(2047),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_RBRACE] = ACTIONS(2187),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_LT] = ACTIONS(1077),
    [anon_sym_GT] = ACTIONS(1077),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1117),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_AMP] = ACTIONS(1117),
    [anon_sym_GT_EQ] = ACTIONS(1087),
    [anon_sym_LT_EQ] = ACTIONS(1087),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(1089),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1091),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_not] = ACTIONS(1101),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [336] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6920),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2942),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7143),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6675),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4489),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7426),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9002),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(336),
    [sym_preproc_endregion] = STATE(336),
    [sym_preproc_line] = STATE(336),
    [sym_preproc_pragma] = STATE(336),
    [sym_preproc_nullable] = STATE(336),
    [sym_preproc_error] = STATE(336),
    [sym_preproc_warning] = STATE(336),
    [sym_preproc_define] = STATE(336),
    [sym_preproc_undef] = STATE(336),
    [aux_sym_class_declaration_repeat1] = STATE(3809),
    [aux_sym_lambda_expression_repeat1] = STATE(4308),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2189),
    [anon_sym_ref] = ACTIONS(2191),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2193),
    [anon_sym_LT] = ACTIONS(1229),
    [anon_sym_GT] = ACTIONS(1229),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1229),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2195),
    [anon_sym_TILDE] = ACTIONS(2197),
    [anon_sym_PLUS_PLUS] = ACTIONS(2197),
    [anon_sym_DASH_DASH] = ACTIONS(2197),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2195),
    [anon_sym_DASH] = ACTIONS(2195),
    [anon_sym_STAR] = ACTIONS(2199),
    [anon_sym_SLASH] = ACTIONS(1229),
    [anon_sym_PERCENT] = ACTIONS(1227),
    [anon_sym_CARET] = ACTIONS(2197),
    [anon_sym_PIPE] = ACTIONS(1229),
    [anon_sym_AMP] = ACTIONS(2195),
    [anon_sym_LT_LT] = ACTIONS(1227),
    [anon_sym_GT_GT] = ACTIONS(1229),
    [anon_sym_GT_GT_GT] = ACTIONS(1227),
    [anon_sym_EQ_EQ] = ACTIONS(1227),
    [anon_sym_BANG_EQ] = ACTIONS(1227),
    [anon_sym_GT_EQ] = ACTIONS(1227),
    [anon_sym_LT_EQ] = ACTIONS(1227),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(1229),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1229),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2201),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2203),
    [anon_sym_DOT_DOT] = ACTIONS(2205),
    [anon_sym_AMP_AMP] = ACTIONS(1227),
    [anon_sym_PIPE_PIPE] = ACTIONS(1227),
    [anon_sym_QMARK_QMARK] = ACTIONS(1227),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1229),
    [anon_sym_is] = ACTIONS(1229),
    [anon_sym_DASH_GT] = ACTIONS(1227),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_with] = ACTIONS(1229),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [337] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2802),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(5754),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_pattern] = STATE(8333),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6158),
    [sym_property_pattern_clause] = STATE(6724),
    [sym_subpattern] = STATE(8548),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6690),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5302),
    [sym_postfix_unary_expression] = STATE(5343),
    [sym_prefix_unary_expression] = STATE(5343),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5302),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5343),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5302),
    [sym_member_access_expression] = STATE(3862),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5343),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(5302),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5302),
    [sym_typeof_expression] = STATE(5302),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3862),
    [sym_literal] = STATE(5302),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(337),
    [sym_preproc_endregion] = STATE(337),
    [sym_preproc_line] = STATE(337),
    [sym_preproc_pragma] = STATE(337),
    [sym_preproc_nullable] = STATE(337),
    [sym_preproc_error] = STATE(337),
    [sym_preproc_warning] = STATE(337),
    [sym_preproc_define] = STATE(337),
    [sym_preproc_undef] = STATE(337),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1231),
    [anon_sym_ref] = ACTIONS(2047),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_RBRACE] = ACTIONS(2207),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_LT] = ACTIONS(1077),
    [anon_sym_GT] = ACTIONS(1077),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1117),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_AMP] = ACTIONS(1117),
    [anon_sym_GT_EQ] = ACTIONS(1087),
    [anon_sym_LT_EQ] = ACTIONS(1087),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(1089),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1091),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_not] = ACTIONS(1101),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [338] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6759),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2844),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6163),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_pattern] = STATE(8123),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6721),
    [sym_property_pattern_clause] = STATE(6770),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6727),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5060),
    [sym_postfix_unary_expression] = STATE(5061),
    [sym_prefix_unary_expression] = STATE(5061),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5060),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5061),
    [sym_switch_expression] = STATE(3765),
    [sym_switch_expression_arm] = STATE(8935),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5060),
    [sym_member_access_expression] = STATE(3797),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5061),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(5060),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5060),
    [sym_typeof_expression] = STATE(5060),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3797),
    [sym_literal] = STATE(5060),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(338),
    [sym_preproc_endregion] = STATE(338),
    [sym_preproc_line] = STATE(338),
    [sym_preproc_pragma] = STATE(338),
    [sym_preproc_nullable] = STATE(338),
    [sym_preproc_error] = STATE(338),
    [sym_preproc_warning] = STATE(338),
    [sym_preproc_define] = STATE(338),
    [sym_preproc_undef] = STATE(338),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1949),
    [anon_sym_ref] = ACTIONS(1951),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_RBRACE] = ACTIONS(2209),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(1955),
    [anon_sym_GT] = ACTIONS(1955),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1581),
    [anon_sym_TILDE] = ACTIONS(1581),
    [anon_sym_PLUS_PLUS] = ACTIONS(1581),
    [anon_sym_DASH_DASH] = ACTIONS(1581),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1579),
    [anon_sym_DASH] = ACTIONS(1579),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1581),
    [anon_sym_AMP] = ACTIONS(1581),
    [anon_sym_GT_EQ] = ACTIONS(1957),
    [anon_sym_LT_EQ] = ACTIONS(1957),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(1089),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1959),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(1961),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [339] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6759),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2844),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6163),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_pattern] = STATE(8123),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6721),
    [sym_property_pattern_clause] = STATE(6770),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6727),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5060),
    [sym_postfix_unary_expression] = STATE(5061),
    [sym_prefix_unary_expression] = STATE(5061),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5060),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5061),
    [sym_switch_expression] = STATE(3765),
    [sym_switch_expression_arm] = STATE(8935),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5060),
    [sym_member_access_expression] = STATE(3797),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5061),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(5060),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5060),
    [sym_typeof_expression] = STATE(5060),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3797),
    [sym_literal] = STATE(5060),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(339),
    [sym_preproc_endregion] = STATE(339),
    [sym_preproc_line] = STATE(339),
    [sym_preproc_pragma] = STATE(339),
    [sym_preproc_nullable] = STATE(339),
    [sym_preproc_error] = STATE(339),
    [sym_preproc_warning] = STATE(339),
    [sym_preproc_define] = STATE(339),
    [sym_preproc_undef] = STATE(339),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1949),
    [anon_sym_ref] = ACTIONS(1951),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_RBRACE] = ACTIONS(2211),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(1955),
    [anon_sym_GT] = ACTIONS(1955),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1581),
    [anon_sym_TILDE] = ACTIONS(1581),
    [anon_sym_PLUS_PLUS] = ACTIONS(1581),
    [anon_sym_DASH_DASH] = ACTIONS(1581),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1579),
    [anon_sym_DASH] = ACTIONS(1579),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1581),
    [anon_sym_AMP] = ACTIONS(1581),
    [anon_sym_GT_EQ] = ACTIONS(1957),
    [anon_sym_LT_EQ] = ACTIONS(1957),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(1089),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1959),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(1961),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [340] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6926),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2950),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7053),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6177),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4458),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7431),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9158),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(340),
    [sym_preproc_endregion] = STATE(340),
    [sym_preproc_line] = STATE(340),
    [sym_preproc_pragma] = STATE(340),
    [sym_preproc_nullable] = STATE(340),
    [sym_preproc_error] = STATE(340),
    [sym_preproc_warning] = STATE(340),
    [sym_preproc_define] = STATE(340),
    [sym_preproc_undef] = STATE(340),
    [aux_sym_class_declaration_repeat1] = STATE(3835),
    [aux_sym_lambda_expression_repeat1] = STATE(4263),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2213),
    [anon_sym_ref] = ACTIONS(2215),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2217),
    [anon_sym_LT] = ACTIONS(1171),
    [anon_sym_GT] = ACTIONS(1171),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1171),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2219),
    [anon_sym_TILDE] = ACTIONS(2221),
    [anon_sym_PLUS_PLUS] = ACTIONS(2221),
    [anon_sym_DASH_DASH] = ACTIONS(2221),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2219),
    [anon_sym_DASH] = ACTIONS(2219),
    [anon_sym_STAR] = ACTIONS(2223),
    [anon_sym_SLASH] = ACTIONS(1171),
    [anon_sym_PERCENT] = ACTIONS(1157),
    [anon_sym_CARET] = ACTIONS(2221),
    [anon_sym_PIPE] = ACTIONS(1171),
    [anon_sym_AMP] = ACTIONS(2219),
    [anon_sym_LT_LT] = ACTIONS(1157),
    [anon_sym_GT_GT] = ACTIONS(1171),
    [anon_sym_GT_GT_GT] = ACTIONS(1157),
    [anon_sym_EQ_EQ] = ACTIONS(1157),
    [anon_sym_BANG_EQ] = ACTIONS(1157),
    [anon_sym_GT_EQ] = ACTIONS(1157),
    [anon_sym_LT_EQ] = ACTIONS(1157),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_DOT] = ACTIONS(1171),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1171),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2225),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2227),
    [anon_sym_DOT_DOT] = ACTIONS(2229),
    [anon_sym_AMP_AMP] = ACTIONS(1157),
    [anon_sym_PIPE_PIPE] = ACTIONS(1157),
    [anon_sym_QMARK_QMARK] = ACTIONS(1157),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1171),
    [anon_sym_is] = ACTIONS(1171),
    [anon_sym_DASH_GT] = ACTIONS(1157),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_with] = ACTIONS(1171),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [341] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6926),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2950),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7053),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6265),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4458),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7431),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9158),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(341),
    [sym_preproc_endregion] = STATE(341),
    [sym_preproc_line] = STATE(341),
    [sym_preproc_pragma] = STATE(341),
    [sym_preproc_nullable] = STATE(341),
    [sym_preproc_error] = STATE(341),
    [sym_preproc_warning] = STATE(341),
    [sym_preproc_define] = STATE(341),
    [sym_preproc_undef] = STATE(341),
    [aux_sym_class_declaration_repeat1] = STATE(3835),
    [aux_sym_lambda_expression_repeat1] = STATE(4263),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2213),
    [anon_sym_ref] = ACTIONS(2215),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2217),
    [anon_sym_LT] = ACTIONS(1229),
    [anon_sym_GT] = ACTIONS(1229),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1229),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2219),
    [anon_sym_TILDE] = ACTIONS(2221),
    [anon_sym_PLUS_PLUS] = ACTIONS(2221),
    [anon_sym_DASH_DASH] = ACTIONS(2221),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2219),
    [anon_sym_DASH] = ACTIONS(2219),
    [anon_sym_STAR] = ACTIONS(2223),
    [anon_sym_SLASH] = ACTIONS(1229),
    [anon_sym_PERCENT] = ACTIONS(1227),
    [anon_sym_CARET] = ACTIONS(2221),
    [anon_sym_PIPE] = ACTIONS(1229),
    [anon_sym_AMP] = ACTIONS(2219),
    [anon_sym_LT_LT] = ACTIONS(1227),
    [anon_sym_GT_GT] = ACTIONS(1229),
    [anon_sym_GT_GT_GT] = ACTIONS(1227),
    [anon_sym_EQ_EQ] = ACTIONS(1227),
    [anon_sym_BANG_EQ] = ACTIONS(1227),
    [anon_sym_GT_EQ] = ACTIONS(1227),
    [anon_sym_LT_EQ] = ACTIONS(1227),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_DOT] = ACTIONS(1229),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1229),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2225),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2227),
    [anon_sym_DOT_DOT] = ACTIONS(2229),
    [anon_sym_AMP_AMP] = ACTIONS(1227),
    [anon_sym_PIPE_PIPE] = ACTIONS(1227),
    [anon_sym_QMARK_QMARK] = ACTIONS(1227),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1229),
    [anon_sym_is] = ACTIONS(1229),
    [anon_sym_DASH_GT] = ACTIONS(1227),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_with] = ACTIONS(1229),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [342] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6922),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2984),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7155),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6555),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4541),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7435),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9148),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(342),
    [sym_preproc_endregion] = STATE(342),
    [sym_preproc_line] = STATE(342),
    [sym_preproc_pragma] = STATE(342),
    [sym_preproc_nullable] = STATE(342),
    [sym_preproc_error] = STATE(342),
    [sym_preproc_warning] = STATE(342),
    [sym_preproc_define] = STATE(342),
    [sym_preproc_undef] = STATE(342),
    [aux_sym_class_declaration_repeat1] = STATE(3876),
    [aux_sym_lambda_expression_repeat1] = STATE(4317),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2231),
    [anon_sym_ref] = ACTIONS(2233),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2235),
    [anon_sym_LT] = ACTIONS(1171),
    [anon_sym_GT] = ACTIONS(1171),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1171),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2237),
    [anon_sym_TILDE] = ACTIONS(2239),
    [anon_sym_PLUS_PLUS] = ACTIONS(2239),
    [anon_sym_DASH_DASH] = ACTIONS(2239),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2237),
    [anon_sym_DASH] = ACTIONS(2237),
    [anon_sym_STAR] = ACTIONS(2241),
    [anon_sym_SLASH] = ACTIONS(1171),
    [anon_sym_PERCENT] = ACTIONS(1157),
    [anon_sym_CARET] = ACTIONS(2239),
    [anon_sym_PIPE] = ACTIONS(1171),
    [anon_sym_AMP] = ACTIONS(2237),
    [anon_sym_LT_LT] = ACTIONS(1157),
    [anon_sym_GT_GT] = ACTIONS(1171),
    [anon_sym_GT_GT_GT] = ACTIONS(1157),
    [anon_sym_EQ_EQ] = ACTIONS(1157),
    [anon_sym_BANG_EQ] = ACTIONS(1157),
    [anon_sym_GT_EQ] = ACTIONS(1157),
    [anon_sym_LT_EQ] = ACTIONS(1157),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(1171),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1171),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2243),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2245),
    [anon_sym_DOT_DOT] = ACTIONS(2247),
    [anon_sym_AMP_AMP] = ACTIONS(1157),
    [anon_sym_PIPE_PIPE] = ACTIONS(1157),
    [anon_sym_QMARK_QMARK] = ACTIONS(1157),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1171),
    [anon_sym_is] = ACTIONS(1171),
    [anon_sym_DASH_GT] = ACTIONS(1157),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_with] = ACTIONS(1171),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [343] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6759),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2844),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6163),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_pattern] = STATE(8123),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6721),
    [sym_property_pattern_clause] = STATE(6770),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6727),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5060),
    [sym_postfix_unary_expression] = STATE(5061),
    [sym_prefix_unary_expression] = STATE(5061),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5060),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5061),
    [sym_switch_expression] = STATE(3765),
    [sym_switch_expression_arm] = STATE(8935),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5060),
    [sym_member_access_expression] = STATE(3797),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5061),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(5060),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5060),
    [sym_typeof_expression] = STATE(5060),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3797),
    [sym_literal] = STATE(5060),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(343),
    [sym_preproc_endregion] = STATE(343),
    [sym_preproc_line] = STATE(343),
    [sym_preproc_pragma] = STATE(343),
    [sym_preproc_nullable] = STATE(343),
    [sym_preproc_error] = STATE(343),
    [sym_preproc_warning] = STATE(343),
    [sym_preproc_define] = STATE(343),
    [sym_preproc_undef] = STATE(343),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1949),
    [anon_sym_ref] = ACTIONS(1951),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_RBRACE] = ACTIONS(2249),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(1955),
    [anon_sym_GT] = ACTIONS(1955),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1581),
    [anon_sym_TILDE] = ACTIONS(1581),
    [anon_sym_PLUS_PLUS] = ACTIONS(1581),
    [anon_sym_DASH_DASH] = ACTIONS(1581),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1579),
    [anon_sym_DASH] = ACTIONS(1579),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1581),
    [anon_sym_AMP] = ACTIONS(1581),
    [anon_sym_GT_EQ] = ACTIONS(1957),
    [anon_sym_LT_EQ] = ACTIONS(1957),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(1089),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1959),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(1961),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [344] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2802),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(5754),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_pattern] = STATE(8333),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6158),
    [sym_property_pattern_clause] = STATE(6724),
    [sym_subpattern] = STATE(8548),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6690),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5302),
    [sym_postfix_unary_expression] = STATE(5343),
    [sym_prefix_unary_expression] = STATE(5343),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5302),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5343),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5302),
    [sym_member_access_expression] = STATE(3862),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5343),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(5302),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5302),
    [sym_typeof_expression] = STATE(5302),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3862),
    [sym_literal] = STATE(5302),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(344),
    [sym_preproc_endregion] = STATE(344),
    [sym_preproc_line] = STATE(344),
    [sym_preproc_pragma] = STATE(344),
    [sym_preproc_nullable] = STATE(344),
    [sym_preproc_error] = STATE(344),
    [sym_preproc_warning] = STATE(344),
    [sym_preproc_define] = STATE(344),
    [sym_preproc_undef] = STATE(344),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1231),
    [anon_sym_ref] = ACTIONS(2047),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_RBRACE] = ACTIONS(2251),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_LT] = ACTIONS(1077),
    [anon_sym_GT] = ACTIONS(1077),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1117),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_AMP] = ACTIONS(1117),
    [anon_sym_GT_EQ] = ACTIONS(1087),
    [anon_sym_LT_EQ] = ACTIONS(1087),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(1089),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1091),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_not] = ACTIONS(1101),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [345] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6943),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2986),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7151),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6510),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4518),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7441),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9110),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(345),
    [sym_preproc_endregion] = STATE(345),
    [sym_preproc_line] = STATE(345),
    [sym_preproc_pragma] = STATE(345),
    [sym_preproc_nullable] = STATE(345),
    [sym_preproc_error] = STATE(345),
    [sym_preproc_warning] = STATE(345),
    [sym_preproc_define] = STATE(345),
    [sym_preproc_undef] = STATE(345),
    [aux_sym_class_declaration_repeat1] = STATE(3875),
    [aux_sym_lambda_expression_repeat1] = STATE(4315),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2169),
    [anon_sym_ref] = ACTIONS(2171),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2173),
    [anon_sym_LT] = ACTIONS(1229),
    [anon_sym_GT] = ACTIONS(1229),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1229),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2175),
    [anon_sym_TILDE] = ACTIONS(2177),
    [anon_sym_PLUS_PLUS] = ACTIONS(2177),
    [anon_sym_DASH_DASH] = ACTIONS(2177),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2175),
    [anon_sym_DASH] = ACTIONS(2175),
    [anon_sym_STAR] = ACTIONS(2179),
    [anon_sym_SLASH] = ACTIONS(1229),
    [anon_sym_PERCENT] = ACTIONS(1227),
    [anon_sym_CARET] = ACTIONS(2177),
    [anon_sym_PIPE] = ACTIONS(1229),
    [anon_sym_AMP] = ACTIONS(2175),
    [anon_sym_LT_LT] = ACTIONS(1227),
    [anon_sym_GT_GT] = ACTIONS(1229),
    [anon_sym_GT_GT_GT] = ACTIONS(1227),
    [anon_sym_EQ_EQ] = ACTIONS(1227),
    [anon_sym_BANG_EQ] = ACTIONS(1227),
    [anon_sym_GT_EQ] = ACTIONS(1227),
    [anon_sym_LT_EQ] = ACTIONS(1227),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(1229),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1229),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2181),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2183),
    [anon_sym_DOT_DOT] = ACTIONS(2185),
    [anon_sym_AMP_AMP] = ACTIONS(1227),
    [anon_sym_PIPE_PIPE] = ACTIONS(1227),
    [anon_sym_QMARK_QMARK] = ACTIONS(1227),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1229),
    [anon_sym_is] = ACTIONS(1229),
    [anon_sym_DASH_GT] = ACTIONS(1227),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_with] = ACTIONS(1229),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [346] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6759),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2844),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6163),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_pattern] = STATE(8123),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6721),
    [sym_property_pattern_clause] = STATE(6770),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6727),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5060),
    [sym_postfix_unary_expression] = STATE(5061),
    [sym_prefix_unary_expression] = STATE(5061),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5060),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5061),
    [sym_switch_expression] = STATE(3765),
    [sym_switch_expression_arm] = STATE(8935),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5060),
    [sym_member_access_expression] = STATE(3797),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5061),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(5060),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5060),
    [sym_typeof_expression] = STATE(5060),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3797),
    [sym_literal] = STATE(5060),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(346),
    [sym_preproc_endregion] = STATE(346),
    [sym_preproc_line] = STATE(346),
    [sym_preproc_pragma] = STATE(346),
    [sym_preproc_nullable] = STATE(346),
    [sym_preproc_error] = STATE(346),
    [sym_preproc_warning] = STATE(346),
    [sym_preproc_define] = STATE(346),
    [sym_preproc_undef] = STATE(346),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1949),
    [anon_sym_ref] = ACTIONS(1951),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_RBRACE] = ACTIONS(2253),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(1955),
    [anon_sym_GT] = ACTIONS(1955),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1581),
    [anon_sym_TILDE] = ACTIONS(1581),
    [anon_sym_PLUS_PLUS] = ACTIONS(1581),
    [anon_sym_DASH_DASH] = ACTIONS(1581),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1579),
    [anon_sym_DASH] = ACTIONS(1579),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1581),
    [anon_sym_AMP] = ACTIONS(1581),
    [anon_sym_GT_EQ] = ACTIONS(1957),
    [anon_sym_LT_EQ] = ACTIONS(1957),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(1089),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1959),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(1961),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [347] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6759),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2844),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6163),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_pattern] = STATE(8123),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6721),
    [sym_property_pattern_clause] = STATE(6770),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6727),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5060),
    [sym_postfix_unary_expression] = STATE(5061),
    [sym_prefix_unary_expression] = STATE(5061),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5060),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5061),
    [sym_switch_expression] = STATE(3765),
    [sym_switch_expression_arm] = STATE(8935),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5060),
    [sym_member_access_expression] = STATE(3797),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5061),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(5060),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5060),
    [sym_typeof_expression] = STATE(5060),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3797),
    [sym_literal] = STATE(5060),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(347),
    [sym_preproc_endregion] = STATE(347),
    [sym_preproc_line] = STATE(347),
    [sym_preproc_pragma] = STATE(347),
    [sym_preproc_nullable] = STATE(347),
    [sym_preproc_error] = STATE(347),
    [sym_preproc_warning] = STATE(347),
    [sym_preproc_define] = STATE(347),
    [sym_preproc_undef] = STATE(347),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1949),
    [anon_sym_ref] = ACTIONS(1951),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_RBRACE] = ACTIONS(2255),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(1955),
    [anon_sym_GT] = ACTIONS(1955),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1581),
    [anon_sym_TILDE] = ACTIONS(1581),
    [anon_sym_PLUS_PLUS] = ACTIONS(1581),
    [anon_sym_DASH_DASH] = ACTIONS(1581),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1579),
    [anon_sym_DASH] = ACTIONS(1579),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1581),
    [anon_sym_AMP] = ACTIONS(1581),
    [anon_sym_GT_EQ] = ACTIONS(1957),
    [anon_sym_LT_EQ] = ACTIONS(1957),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(1089),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1959),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(1961),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [348] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6759),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2844),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6163),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_pattern] = STATE(8123),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6721),
    [sym_property_pattern_clause] = STATE(6770),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6727),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5060),
    [sym_postfix_unary_expression] = STATE(5061),
    [sym_prefix_unary_expression] = STATE(5061),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5060),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5061),
    [sym_switch_expression] = STATE(3765),
    [sym_switch_expression_arm] = STATE(8935),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5060),
    [sym_member_access_expression] = STATE(3797),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5061),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(5060),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5060),
    [sym_typeof_expression] = STATE(5060),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3797),
    [sym_literal] = STATE(5060),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(348),
    [sym_preproc_endregion] = STATE(348),
    [sym_preproc_line] = STATE(348),
    [sym_preproc_pragma] = STATE(348),
    [sym_preproc_nullable] = STATE(348),
    [sym_preproc_error] = STATE(348),
    [sym_preproc_warning] = STATE(348),
    [sym_preproc_define] = STATE(348),
    [sym_preproc_undef] = STATE(348),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1949),
    [anon_sym_ref] = ACTIONS(1951),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_RBRACE] = ACTIONS(2257),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(1955),
    [anon_sym_GT] = ACTIONS(1955),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1581),
    [anon_sym_TILDE] = ACTIONS(1581),
    [anon_sym_PLUS_PLUS] = ACTIONS(1581),
    [anon_sym_DASH_DASH] = ACTIONS(1581),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1579),
    [anon_sym_DASH] = ACTIONS(1579),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1581),
    [anon_sym_AMP] = ACTIONS(1581),
    [anon_sym_GT_EQ] = ACTIONS(1957),
    [anon_sym_LT_EQ] = ACTIONS(1957),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(1089),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1959),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(1961),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [349] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6922),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2984),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7155),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6607),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4541),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7435),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9148),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(349),
    [sym_preproc_endregion] = STATE(349),
    [sym_preproc_line] = STATE(349),
    [sym_preproc_pragma] = STATE(349),
    [sym_preproc_nullable] = STATE(349),
    [sym_preproc_error] = STATE(349),
    [sym_preproc_warning] = STATE(349),
    [sym_preproc_define] = STATE(349),
    [sym_preproc_undef] = STATE(349),
    [aux_sym_class_declaration_repeat1] = STATE(3876),
    [aux_sym_lambda_expression_repeat1] = STATE(4317),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2231),
    [anon_sym_ref] = ACTIONS(2233),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2235),
    [anon_sym_LT] = ACTIONS(1229),
    [anon_sym_GT] = ACTIONS(1229),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1229),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2237),
    [anon_sym_TILDE] = ACTIONS(2239),
    [anon_sym_PLUS_PLUS] = ACTIONS(2239),
    [anon_sym_DASH_DASH] = ACTIONS(2239),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2237),
    [anon_sym_DASH] = ACTIONS(2237),
    [anon_sym_STAR] = ACTIONS(2241),
    [anon_sym_SLASH] = ACTIONS(1229),
    [anon_sym_PERCENT] = ACTIONS(1227),
    [anon_sym_CARET] = ACTIONS(2239),
    [anon_sym_PIPE] = ACTIONS(1229),
    [anon_sym_AMP] = ACTIONS(2237),
    [anon_sym_LT_LT] = ACTIONS(1227),
    [anon_sym_GT_GT] = ACTIONS(1229),
    [anon_sym_GT_GT_GT] = ACTIONS(1227),
    [anon_sym_EQ_EQ] = ACTIONS(1227),
    [anon_sym_BANG_EQ] = ACTIONS(1227),
    [anon_sym_GT_EQ] = ACTIONS(1227),
    [anon_sym_LT_EQ] = ACTIONS(1227),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(1229),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1229),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2243),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2245),
    [anon_sym_DOT_DOT] = ACTIONS(2247),
    [anon_sym_AMP_AMP] = ACTIONS(1227),
    [anon_sym_PIPE_PIPE] = ACTIONS(1227),
    [anon_sym_QMARK_QMARK] = ACTIONS(1227),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1229),
    [anon_sym_is] = ACTIONS(1229),
    [anon_sym_DASH_GT] = ACTIONS(1227),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_with] = ACTIONS(1229),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [350] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6955),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2975),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6988),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5048),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3800),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7425),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9573),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(350),
    [sym_preproc_endregion] = STATE(350),
    [sym_preproc_line] = STATE(350),
    [sym_preproc_pragma] = STATE(350),
    [sym_preproc_nullable] = STATE(350),
    [sym_preproc_error] = STATE(350),
    [sym_preproc_warning] = STATE(350),
    [sym_preproc_define] = STATE(350),
    [sym_preproc_undef] = STATE(350),
    [aux_sym_class_declaration_repeat1] = STATE(3818),
    [aux_sym_lambda_expression_repeat1] = STATE(4229),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2259),
    [anon_sym_ref] = ACTIONS(2261),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1933),
    [anon_sym_LT] = ACTIONS(1171),
    [anon_sym_GT] = ACTIONS(1171),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1171),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2263),
    [anon_sym_TILDE] = ACTIONS(2265),
    [anon_sym_PLUS_PLUS] = ACTIONS(2265),
    [anon_sym_DASH_DASH] = ACTIONS(2265),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2263),
    [anon_sym_DASH] = ACTIONS(2263),
    [anon_sym_STAR] = ACTIONS(1939),
    [anon_sym_SLASH] = ACTIONS(1171),
    [anon_sym_PERCENT] = ACTIONS(1157),
    [anon_sym_CARET] = ACTIONS(2265),
    [anon_sym_PIPE] = ACTIONS(1171),
    [anon_sym_AMP] = ACTIONS(2263),
    [anon_sym_LT_LT] = ACTIONS(1157),
    [anon_sym_GT_GT] = ACTIONS(1171),
    [anon_sym_GT_GT_GT] = ACTIONS(1157),
    [anon_sym_EQ_EQ] = ACTIONS(1157),
    [anon_sym_BANG_EQ] = ACTIONS(1157),
    [anon_sym_GT_EQ] = ACTIONS(1157),
    [anon_sym_LT_EQ] = ACTIONS(1157),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_DOT] = ACTIONS(1171),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1171),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2267),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2269),
    [anon_sym_DOT_DOT] = ACTIONS(2271),
    [anon_sym_AMP_AMP] = ACTIONS(1157),
    [anon_sym_PIPE_PIPE] = ACTIONS(1157),
    [anon_sym_QMARK_QMARK] = ACTIONS(1157),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1171),
    [anon_sym_is] = ACTIONS(1171),
    [anon_sym_DASH_GT] = ACTIONS(1157),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_with] = ACTIONS(1171),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [351] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6955),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2975),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6988),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5011),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3800),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7425),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9573),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(351),
    [sym_preproc_endregion] = STATE(351),
    [sym_preproc_line] = STATE(351),
    [sym_preproc_pragma] = STATE(351),
    [sym_preproc_nullable] = STATE(351),
    [sym_preproc_error] = STATE(351),
    [sym_preproc_warning] = STATE(351),
    [sym_preproc_define] = STATE(351),
    [sym_preproc_undef] = STATE(351),
    [aux_sym_class_declaration_repeat1] = STATE(3818),
    [aux_sym_lambda_expression_repeat1] = STATE(4229),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2259),
    [anon_sym_ref] = ACTIONS(2261),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1933),
    [anon_sym_LT] = ACTIONS(1229),
    [anon_sym_GT] = ACTIONS(1229),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1229),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2263),
    [anon_sym_TILDE] = ACTIONS(2265),
    [anon_sym_PLUS_PLUS] = ACTIONS(2265),
    [anon_sym_DASH_DASH] = ACTIONS(2265),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2263),
    [anon_sym_DASH] = ACTIONS(2263),
    [anon_sym_STAR] = ACTIONS(1939),
    [anon_sym_SLASH] = ACTIONS(1229),
    [anon_sym_PERCENT] = ACTIONS(1227),
    [anon_sym_CARET] = ACTIONS(2265),
    [anon_sym_PIPE] = ACTIONS(1229),
    [anon_sym_AMP] = ACTIONS(2263),
    [anon_sym_LT_LT] = ACTIONS(1227),
    [anon_sym_GT_GT] = ACTIONS(1229),
    [anon_sym_GT_GT_GT] = ACTIONS(1227),
    [anon_sym_EQ_EQ] = ACTIONS(1227),
    [anon_sym_BANG_EQ] = ACTIONS(1227),
    [anon_sym_GT_EQ] = ACTIONS(1227),
    [anon_sym_LT_EQ] = ACTIONS(1227),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_DOT] = ACTIONS(1229),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1229),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2267),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2269),
    [anon_sym_DOT_DOT] = ACTIONS(2271),
    [anon_sym_AMP_AMP] = ACTIONS(1227),
    [anon_sym_PIPE_PIPE] = ACTIONS(1227),
    [anon_sym_QMARK_QMARK] = ACTIONS(1227),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1229),
    [anon_sym_is] = ACTIONS(1229),
    [anon_sym_DASH_GT] = ACTIONS(1227),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_with] = ACTIONS(1229),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [352] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6759),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2844),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6163),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_pattern] = STATE(8123),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6721),
    [sym_property_pattern_clause] = STATE(6770),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6727),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5060),
    [sym_postfix_unary_expression] = STATE(5061),
    [sym_prefix_unary_expression] = STATE(5061),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5060),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5061),
    [sym_switch_expression] = STATE(3765),
    [sym_switch_expression_arm] = STATE(8935),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5060),
    [sym_member_access_expression] = STATE(3797),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5061),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(5060),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5060),
    [sym_typeof_expression] = STATE(5060),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3797),
    [sym_literal] = STATE(5060),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(352),
    [sym_preproc_endregion] = STATE(352),
    [sym_preproc_line] = STATE(352),
    [sym_preproc_pragma] = STATE(352),
    [sym_preproc_nullable] = STATE(352),
    [sym_preproc_error] = STATE(352),
    [sym_preproc_warning] = STATE(352),
    [sym_preproc_define] = STATE(352),
    [sym_preproc_undef] = STATE(352),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1949),
    [anon_sym_ref] = ACTIONS(1951),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_RBRACE] = ACTIONS(2273),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(1955),
    [anon_sym_GT] = ACTIONS(1955),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1581),
    [anon_sym_TILDE] = ACTIONS(1581),
    [anon_sym_PLUS_PLUS] = ACTIONS(1581),
    [anon_sym_DASH_DASH] = ACTIONS(1581),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1579),
    [anon_sym_DASH] = ACTIONS(1579),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1581),
    [anon_sym_AMP] = ACTIONS(1581),
    [anon_sym_GT_EQ] = ACTIONS(1957),
    [anon_sym_LT_EQ] = ACTIONS(1957),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(1089),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1959),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(1961),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [353] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6948),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2940),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6999),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5066),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3857),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7444),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9574),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(353),
    [sym_preproc_endregion] = STATE(353),
    [sym_preproc_line] = STATE(353),
    [sym_preproc_pragma] = STATE(353),
    [sym_preproc_nullable] = STATE(353),
    [sym_preproc_error] = STATE(353),
    [sym_preproc_warning] = STATE(353),
    [sym_preproc_define] = STATE(353),
    [sym_preproc_undef] = STATE(353),
    [aux_sym_class_declaration_repeat1] = STATE(3854),
    [aux_sym_lambda_expression_repeat1] = STATE(4136),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2111),
    [anon_sym_ref] = ACTIONS(2113),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1897),
    [anon_sym_LT] = ACTIONS(1171),
    [anon_sym_GT] = ACTIONS(1171),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1171),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2115),
    [anon_sym_TILDE] = ACTIONS(2117),
    [anon_sym_PLUS_PLUS] = ACTIONS(2117),
    [anon_sym_DASH_DASH] = ACTIONS(2117),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2115),
    [anon_sym_DASH] = ACTIONS(2115),
    [anon_sym_STAR] = ACTIONS(1903),
    [anon_sym_SLASH] = ACTIONS(1171),
    [anon_sym_PERCENT] = ACTIONS(1157),
    [anon_sym_CARET] = ACTIONS(2117),
    [anon_sym_PIPE] = ACTIONS(1171),
    [anon_sym_AMP] = ACTIONS(2115),
    [anon_sym_LT_LT] = ACTIONS(1157),
    [anon_sym_GT_GT] = ACTIONS(1171),
    [anon_sym_GT_GT_GT] = ACTIONS(1157),
    [anon_sym_EQ_EQ] = ACTIONS(1157),
    [anon_sym_BANG_EQ] = ACTIONS(1157),
    [anon_sym_GT_EQ] = ACTIONS(1157),
    [anon_sym_LT_EQ] = ACTIONS(1157),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(1171),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1171),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2119),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2121),
    [anon_sym_DOT_DOT] = ACTIONS(2123),
    [anon_sym_AMP_AMP] = ACTIONS(1157),
    [anon_sym_PIPE_PIPE] = ACTIONS(1157),
    [anon_sym_QMARK_QMARK] = ACTIONS(1157),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1171),
    [anon_sym_is] = ACTIONS(1171),
    [anon_sym_DASH_GT] = ACTIONS(1157),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_with] = ACTIONS(1171),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [354] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6920),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2942),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7143),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6532),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4489),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7426),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9002),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(354),
    [sym_preproc_endregion] = STATE(354),
    [sym_preproc_line] = STATE(354),
    [sym_preproc_pragma] = STATE(354),
    [sym_preproc_nullable] = STATE(354),
    [sym_preproc_error] = STATE(354),
    [sym_preproc_warning] = STATE(354),
    [sym_preproc_define] = STATE(354),
    [sym_preproc_undef] = STATE(354),
    [aux_sym_class_declaration_repeat1] = STATE(3809),
    [aux_sym_lambda_expression_repeat1] = STATE(4308),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2189),
    [anon_sym_ref] = ACTIONS(2191),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2193),
    [anon_sym_LT] = ACTIONS(1171),
    [anon_sym_GT] = ACTIONS(1171),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_QMARK] = ACTIONS(1171),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2195),
    [anon_sym_TILDE] = ACTIONS(2197),
    [anon_sym_PLUS_PLUS] = ACTIONS(2197),
    [anon_sym_DASH_DASH] = ACTIONS(2197),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2195),
    [anon_sym_DASH] = ACTIONS(2195),
    [anon_sym_STAR] = ACTIONS(2199),
    [anon_sym_SLASH] = ACTIONS(1171),
    [anon_sym_PERCENT] = ACTIONS(1157),
    [anon_sym_CARET] = ACTIONS(2197),
    [anon_sym_PIPE] = ACTIONS(1171),
    [anon_sym_AMP] = ACTIONS(2195),
    [anon_sym_LT_LT] = ACTIONS(1157),
    [anon_sym_GT_GT] = ACTIONS(1171),
    [anon_sym_GT_GT_GT] = ACTIONS(1157),
    [anon_sym_EQ_EQ] = ACTIONS(1157),
    [anon_sym_BANG_EQ] = ACTIONS(1157),
    [anon_sym_GT_EQ] = ACTIONS(1157),
    [anon_sym_LT_EQ] = ACTIONS(1157),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(1171),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_switch] = ACTIONS(1171),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2201),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2203),
    [anon_sym_DOT_DOT] = ACTIONS(2205),
    [anon_sym_AMP_AMP] = ACTIONS(1157),
    [anon_sym_PIPE_PIPE] = ACTIONS(1157),
    [anon_sym_QMARK_QMARK] = ACTIONS(1157),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_as] = ACTIONS(1171),
    [anon_sym_is] = ACTIONS(1171),
    [anon_sym_DASH_GT] = ACTIONS(1157),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_with] = ACTIONS(1171),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [355] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6759),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2844),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6163),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_pattern] = STATE(8123),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6721),
    [sym_property_pattern_clause] = STATE(6770),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6727),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5060),
    [sym_postfix_unary_expression] = STATE(5061),
    [sym_prefix_unary_expression] = STATE(5061),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5060),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5061),
    [sym_switch_expression] = STATE(3765),
    [sym_switch_expression_arm] = STATE(8935),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5060),
    [sym_member_access_expression] = STATE(3797),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5061),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(5060),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5060),
    [sym_typeof_expression] = STATE(5060),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3797),
    [sym_literal] = STATE(5060),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(355),
    [sym_preproc_endregion] = STATE(355),
    [sym_preproc_line] = STATE(355),
    [sym_preproc_pragma] = STATE(355),
    [sym_preproc_nullable] = STATE(355),
    [sym_preproc_error] = STATE(355),
    [sym_preproc_warning] = STATE(355),
    [sym_preproc_define] = STATE(355),
    [sym_preproc_undef] = STATE(355),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1949),
    [anon_sym_ref] = ACTIONS(1951),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_RBRACE] = ACTIONS(2275),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(1955),
    [anon_sym_GT] = ACTIONS(1955),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1581),
    [anon_sym_TILDE] = ACTIONS(1581),
    [anon_sym_PLUS_PLUS] = ACTIONS(1581),
    [anon_sym_DASH_DASH] = ACTIONS(1581),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1579),
    [anon_sym_DASH] = ACTIONS(1579),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1581),
    [anon_sym_AMP] = ACTIONS(1581),
    [anon_sym_GT_EQ] = ACTIONS(1957),
    [anon_sym_LT_EQ] = ACTIONS(1957),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(1089),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1959),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(1961),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [356] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6759),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2844),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6163),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_pattern] = STATE(8123),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6721),
    [sym_property_pattern_clause] = STATE(6770),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6727),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5060),
    [sym_postfix_unary_expression] = STATE(5061),
    [sym_prefix_unary_expression] = STATE(5061),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5060),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5061),
    [sym_switch_expression] = STATE(3765),
    [sym_switch_expression_arm] = STATE(8935),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5060),
    [sym_member_access_expression] = STATE(3797),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5061),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(5060),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5060),
    [sym_typeof_expression] = STATE(5060),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3797),
    [sym_literal] = STATE(5060),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(356),
    [sym_preproc_endregion] = STATE(356),
    [sym_preproc_line] = STATE(356),
    [sym_preproc_pragma] = STATE(356),
    [sym_preproc_nullable] = STATE(356),
    [sym_preproc_error] = STATE(356),
    [sym_preproc_warning] = STATE(356),
    [sym_preproc_define] = STATE(356),
    [sym_preproc_undef] = STATE(356),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1949),
    [anon_sym_ref] = ACTIONS(1951),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_RBRACE] = ACTIONS(2277),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(1955),
    [anon_sym_GT] = ACTIONS(1955),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1581),
    [anon_sym_TILDE] = ACTIONS(1581),
    [anon_sym_PLUS_PLUS] = ACTIONS(1581),
    [anon_sym_DASH_DASH] = ACTIONS(1581),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1579),
    [anon_sym_DASH] = ACTIONS(1579),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1581),
    [anon_sym_AMP] = ACTIONS(1581),
    [anon_sym_GT_EQ] = ACTIONS(1957),
    [anon_sym_LT_EQ] = ACTIONS(1957),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(1089),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1959),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(1961),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [357] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2802),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(5351),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_pattern] = STATE(8325),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6158),
    [sym_property_pattern_clause] = STATE(6724),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6719),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5302),
    [sym_postfix_unary_expression] = STATE(5343),
    [sym_prefix_unary_expression] = STATE(5343),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5302),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5343),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5302),
    [sym_member_access_expression] = STATE(3862),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5343),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(5302),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5302),
    [sym_typeof_expression] = STATE(5302),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3862),
    [sym_literal] = STATE(5302),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(357),
    [sym_preproc_endregion] = STATE(357),
    [sym_preproc_line] = STATE(357),
    [sym_preproc_pragma] = STATE(357),
    [sym_preproc_nullable] = STATE(357),
    [sym_preproc_error] = STATE(357),
    [sym_preproc_warning] = STATE(357),
    [sym_preproc_define] = STATE(357),
    [sym_preproc_undef] = STATE(357),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_RBRACK] = ACTIONS(2279),
    [anon_sym_LPAREN] = ACTIONS(1067),
    [anon_sym_ref] = ACTIONS(2281),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(1077),
    [anon_sym_GT] = ACTIONS(1077),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1083),
    [anon_sym_PLUS_PLUS] = ACTIONS(1083),
    [anon_sym_DASH_DASH] = ACTIONS(1083),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1085),
    [anon_sym_DASH] = ACTIONS(1085),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1083),
    [anon_sym_AMP] = ACTIONS(1083),
    [anon_sym_GT_EQ] = ACTIONS(1087),
    [anon_sym_LT_EQ] = ACTIONS(1087),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(1089),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1091),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(2283),
    [anon_sym_not] = ACTIONS(1101),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [358] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2802),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(5351),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_pattern] = STATE(8325),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6158),
    [sym_property_pattern_clause] = STATE(6724),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6719),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5302),
    [sym_postfix_unary_expression] = STATE(5343),
    [sym_prefix_unary_expression] = STATE(5343),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5302),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5343),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5302),
    [sym_member_access_expression] = STATE(3862),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5343),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(5302),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5302),
    [sym_typeof_expression] = STATE(5302),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3862),
    [sym_literal] = STATE(5302),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(358),
    [sym_preproc_endregion] = STATE(358),
    [sym_preproc_line] = STATE(358),
    [sym_preproc_pragma] = STATE(358),
    [sym_preproc_nullable] = STATE(358),
    [sym_preproc_error] = STATE(358),
    [sym_preproc_warning] = STATE(358),
    [sym_preproc_define] = STATE(358),
    [sym_preproc_undef] = STATE(358),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_RBRACK] = ACTIONS(2285),
    [anon_sym_LPAREN] = ACTIONS(1067),
    [anon_sym_ref] = ACTIONS(2281),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(1077),
    [anon_sym_GT] = ACTIONS(1077),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1083),
    [anon_sym_PLUS_PLUS] = ACTIONS(1083),
    [anon_sym_DASH_DASH] = ACTIONS(1083),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1085),
    [anon_sym_DASH] = ACTIONS(1085),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1083),
    [anon_sym_AMP] = ACTIONS(1083),
    [anon_sym_GT_EQ] = ACTIONS(1087),
    [anon_sym_LT_EQ] = ACTIONS(1087),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(1089),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1091),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(2283),
    [anon_sym_not] = ACTIONS(1101),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [359] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2802),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(5351),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_pattern] = STATE(8325),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6158),
    [sym_property_pattern_clause] = STATE(6724),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6719),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5302),
    [sym_postfix_unary_expression] = STATE(5343),
    [sym_prefix_unary_expression] = STATE(5343),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5302),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5343),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5302),
    [sym_member_access_expression] = STATE(3862),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5343),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(5302),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5302),
    [sym_typeof_expression] = STATE(5302),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3862),
    [sym_literal] = STATE(5302),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(359),
    [sym_preproc_endregion] = STATE(359),
    [sym_preproc_line] = STATE(359),
    [sym_preproc_pragma] = STATE(359),
    [sym_preproc_nullable] = STATE(359),
    [sym_preproc_error] = STATE(359),
    [sym_preproc_warning] = STATE(359),
    [sym_preproc_define] = STATE(359),
    [sym_preproc_undef] = STATE(359),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_RBRACK] = ACTIONS(2287),
    [anon_sym_LPAREN] = ACTIONS(1067),
    [anon_sym_ref] = ACTIONS(2281),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(1077),
    [anon_sym_GT] = ACTIONS(1077),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1083),
    [anon_sym_PLUS_PLUS] = ACTIONS(1083),
    [anon_sym_DASH_DASH] = ACTIONS(1083),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1085),
    [anon_sym_DASH] = ACTIONS(1085),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1083),
    [anon_sym_AMP] = ACTIONS(1083),
    [anon_sym_GT_EQ] = ACTIONS(1087),
    [anon_sym_LT_EQ] = ACTIONS(1087),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(1089),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1091),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(2283),
    [anon_sym_not] = ACTIONS(1101),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [360] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6759),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2844),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6163),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_pattern] = STATE(8123),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6721),
    [sym_property_pattern_clause] = STATE(6770),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6727),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5060),
    [sym_postfix_unary_expression] = STATE(5061),
    [sym_prefix_unary_expression] = STATE(5061),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5060),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5061),
    [sym_switch_expression] = STATE(3765),
    [sym_switch_expression_arm] = STATE(8935),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5060),
    [sym_member_access_expression] = STATE(3797),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5061),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(5060),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5060),
    [sym_typeof_expression] = STATE(5060),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3797),
    [sym_literal] = STATE(5060),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(360),
    [sym_preproc_endregion] = STATE(360),
    [sym_preproc_line] = STATE(360),
    [sym_preproc_pragma] = STATE(360),
    [sym_preproc_nullable] = STATE(360),
    [sym_preproc_error] = STATE(360),
    [sym_preproc_warning] = STATE(360),
    [sym_preproc_define] = STATE(360),
    [sym_preproc_undef] = STATE(360),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1949),
    [anon_sym_ref] = ACTIONS(1951),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(1955),
    [anon_sym_GT] = ACTIONS(1955),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1581),
    [anon_sym_TILDE] = ACTIONS(1581),
    [anon_sym_PLUS_PLUS] = ACTIONS(1581),
    [anon_sym_DASH_DASH] = ACTIONS(1581),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1579),
    [anon_sym_DASH] = ACTIONS(1579),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1581),
    [anon_sym_AMP] = ACTIONS(1581),
    [anon_sym_GT_EQ] = ACTIONS(1957),
    [anon_sym_LT_EQ] = ACTIONS(1957),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(1089),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1959),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(1961),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [361] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2802),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(5351),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_pattern] = STATE(8325),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6158),
    [sym_property_pattern_clause] = STATE(6724),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6719),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5302),
    [sym_postfix_unary_expression] = STATE(5343),
    [sym_prefix_unary_expression] = STATE(5343),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5302),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5343),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5302),
    [sym_member_access_expression] = STATE(3862),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5343),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(5302),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5302),
    [sym_typeof_expression] = STATE(5302),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3862),
    [sym_literal] = STATE(5302),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(361),
    [sym_preproc_endregion] = STATE(361),
    [sym_preproc_line] = STATE(361),
    [sym_preproc_pragma] = STATE(361),
    [sym_preproc_nullable] = STATE(361),
    [sym_preproc_error] = STATE(361),
    [sym_preproc_warning] = STATE(361),
    [sym_preproc_define] = STATE(361),
    [sym_preproc_undef] = STATE(361),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_RBRACK] = ACTIONS(2289),
    [anon_sym_LPAREN] = ACTIONS(1067),
    [anon_sym_ref] = ACTIONS(2281),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(1077),
    [anon_sym_GT] = ACTIONS(1077),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1083),
    [anon_sym_PLUS_PLUS] = ACTIONS(1083),
    [anon_sym_DASH_DASH] = ACTIONS(1083),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1085),
    [anon_sym_DASH] = ACTIONS(1085),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1083),
    [anon_sym_AMP] = ACTIONS(1083),
    [anon_sym_GT_EQ] = ACTIONS(1087),
    [anon_sym_LT_EQ] = ACTIONS(1087),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(1089),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1091),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(2283),
    [anon_sym_not] = ACTIONS(1101),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [362] = {
    [sym_attribute_list] = STATE(6699),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_variable_declaration] = STATE(9387),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6857),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4336),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9482),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(362),
    [sym_preproc_endregion] = STATE(362),
    [sym_preproc_line] = STATE(362),
    [sym_preproc_pragma] = STATE(362),
    [sym_preproc_nullable] = STATE(362),
    [sym_preproc_error] = STATE(362),
    [sym_preproc_warning] = STATE(362),
    [sym_preproc_define] = STATE(362),
    [sym_preproc_undef] = STATE(362),
    [aux_sym_class_declaration_repeat1] = STATE(3853),
    [aux_sym_class_declaration_repeat2] = STATE(3093),
    [aux_sym_lambda_expression_repeat1] = STATE(4299),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(2291),
    [anon_sym_unsafe] = ACTIONS(661),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1497),
    [anon_sym_ref] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(661),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(2293),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1505),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1507),
    [anon_sym_foreach] = ACTIONS(2295),
    [anon_sym_DOT_DOT] = ACTIONS(1509),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [363] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2802),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(5754),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_pattern] = STATE(8333),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6158),
    [sym_property_pattern_clause] = STATE(6724),
    [sym_subpattern] = STATE(8548),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6690),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5302),
    [sym_postfix_unary_expression] = STATE(5343),
    [sym_prefix_unary_expression] = STATE(5343),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5302),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5343),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5302),
    [sym_member_access_expression] = STATE(3862),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5343),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(5302),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5302),
    [sym_typeof_expression] = STATE(5302),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3862),
    [sym_literal] = STATE(5302),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(363),
    [sym_preproc_endregion] = STATE(363),
    [sym_preproc_line] = STATE(363),
    [sym_preproc_pragma] = STATE(363),
    [sym_preproc_nullable] = STATE(363),
    [sym_preproc_error] = STATE(363),
    [sym_preproc_warning] = STATE(363),
    [sym_preproc_define] = STATE(363),
    [sym_preproc_undef] = STATE(363),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1231),
    [anon_sym_ref] = ACTIONS(2047),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_LT] = ACTIONS(1077),
    [anon_sym_GT] = ACTIONS(1077),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1117),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_AMP] = ACTIONS(1117),
    [anon_sym_GT_EQ] = ACTIONS(1087),
    [anon_sym_LT_EQ] = ACTIONS(1087),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(1089),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1091),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_not] = ACTIONS(1101),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [364] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2802),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(5351),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_pattern] = STATE(8325),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6158),
    [sym_property_pattern_clause] = STATE(6724),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6719),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5302),
    [sym_postfix_unary_expression] = STATE(5343),
    [sym_prefix_unary_expression] = STATE(5343),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5302),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5343),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5302),
    [sym_member_access_expression] = STATE(3862),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5343),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(5302),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5302),
    [sym_typeof_expression] = STATE(5302),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3862),
    [sym_literal] = STATE(5302),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(364),
    [sym_preproc_endregion] = STATE(364),
    [sym_preproc_line] = STATE(364),
    [sym_preproc_pragma] = STATE(364),
    [sym_preproc_nullable] = STATE(364),
    [sym_preproc_error] = STATE(364),
    [sym_preproc_warning] = STATE(364),
    [sym_preproc_define] = STATE(364),
    [sym_preproc_undef] = STATE(364),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_RBRACK] = ACTIONS(2297),
    [anon_sym_LPAREN] = ACTIONS(1067),
    [anon_sym_ref] = ACTIONS(2281),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(1077),
    [anon_sym_GT] = ACTIONS(1077),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1083),
    [anon_sym_PLUS_PLUS] = ACTIONS(1083),
    [anon_sym_DASH_DASH] = ACTIONS(1083),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1085),
    [anon_sym_DASH] = ACTIONS(1085),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1083),
    [anon_sym_AMP] = ACTIONS(1083),
    [anon_sym_GT_EQ] = ACTIONS(1087),
    [anon_sym_LT_EQ] = ACTIONS(1087),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(1089),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1091),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(2283),
    [anon_sym_not] = ACTIONS(1101),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [365] = {
    [sym_attribute_list] = STATE(6699),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_variable_declaration] = STATE(9599),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6857),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4336),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9482),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(365),
    [sym_preproc_endregion] = STATE(365),
    [sym_preproc_line] = STATE(365),
    [sym_preproc_pragma] = STATE(365),
    [sym_preproc_nullable] = STATE(365),
    [sym_preproc_error] = STATE(365),
    [sym_preproc_warning] = STATE(365),
    [sym_preproc_define] = STATE(365),
    [sym_preproc_undef] = STATE(365),
    [aux_sym_class_declaration_repeat1] = STATE(3853),
    [aux_sym_class_declaration_repeat2] = STATE(3092),
    [aux_sym_lambda_expression_repeat1] = STATE(4299),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(2299),
    [anon_sym_unsafe] = ACTIONS(661),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1497),
    [anon_sym_ref] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(661),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(2293),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1505),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1507),
    [anon_sym_foreach] = ACTIONS(2301),
    [anon_sym_DOT_DOT] = ACTIONS(1509),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [366] = {
    [sym_attribute_list] = STATE(6699),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_variable_declaration] = STATE(9599),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6902),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4336),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4364),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9470),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(366),
    [sym_preproc_endregion] = STATE(366),
    [sym_preproc_line] = STATE(366),
    [sym_preproc_pragma] = STATE(366),
    [sym_preproc_nullable] = STATE(366),
    [sym_preproc_error] = STATE(366),
    [sym_preproc_warning] = STATE(366),
    [sym_preproc_define] = STATE(366),
    [sym_preproc_undef] = STATE(366),
    [aux_sym_class_declaration_repeat1] = STATE(3870),
    [aux_sym_class_declaration_repeat2] = STATE(3092),
    [aux_sym_lambda_expression_repeat1] = STATE(4302),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(2299),
    [anon_sym_unsafe] = ACTIONS(661),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1555),
    [anon_sym_ref] = ACTIONS(1557),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(661),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(2293),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(695),
    [anon_sym_TILDE] = ACTIONS(695),
    [anon_sym_PLUS_PLUS] = ACTIONS(695),
    [anon_sym_DASH_DASH] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(697),
    [anon_sym_DASH] = ACTIONS(697),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(695),
    [anon_sym_AMP] = ACTIONS(695),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1559),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1561),
    [anon_sym_foreach] = ACTIONS(2301),
    [anon_sym_DOT_DOT] = ACTIONS(1563),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [367] = {
    [sym_attribute_list] = STATE(6699),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_variable_declaration] = STATE(9117),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6857),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4336),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9482),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(367),
    [sym_preproc_endregion] = STATE(367),
    [sym_preproc_line] = STATE(367),
    [sym_preproc_pragma] = STATE(367),
    [sym_preproc_nullable] = STATE(367),
    [sym_preproc_error] = STATE(367),
    [sym_preproc_warning] = STATE(367),
    [sym_preproc_define] = STATE(367),
    [sym_preproc_undef] = STATE(367),
    [aux_sym_class_declaration_repeat1] = STATE(3853),
    [aux_sym_class_declaration_repeat2] = STATE(3105),
    [aux_sym_lambda_expression_repeat1] = STATE(4299),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(2303),
    [anon_sym_unsafe] = ACTIONS(661),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1497),
    [anon_sym_ref] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(661),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(2293),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1505),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1507),
    [anon_sym_foreach] = ACTIONS(2305),
    [anon_sym_DOT_DOT] = ACTIONS(1509),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [368] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2802),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(5351),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_pattern] = STATE(8325),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6158),
    [sym_property_pattern_clause] = STATE(6724),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6719),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5302),
    [sym_postfix_unary_expression] = STATE(5343),
    [sym_prefix_unary_expression] = STATE(5343),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5302),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5343),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5302),
    [sym_member_access_expression] = STATE(3862),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5343),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(5302),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5302),
    [sym_typeof_expression] = STATE(5302),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3862),
    [sym_literal] = STATE(5302),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(368),
    [sym_preproc_endregion] = STATE(368),
    [sym_preproc_line] = STATE(368),
    [sym_preproc_pragma] = STATE(368),
    [sym_preproc_nullable] = STATE(368),
    [sym_preproc_error] = STATE(368),
    [sym_preproc_warning] = STATE(368),
    [sym_preproc_define] = STATE(368),
    [sym_preproc_undef] = STATE(368),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_RBRACK] = ACTIONS(2307),
    [anon_sym_LPAREN] = ACTIONS(1067),
    [anon_sym_ref] = ACTIONS(2281),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(1077),
    [anon_sym_GT] = ACTIONS(1077),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1083),
    [anon_sym_PLUS_PLUS] = ACTIONS(1083),
    [anon_sym_DASH_DASH] = ACTIONS(1083),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1085),
    [anon_sym_DASH] = ACTIONS(1085),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1083),
    [anon_sym_AMP] = ACTIONS(1083),
    [anon_sym_GT_EQ] = ACTIONS(1087),
    [anon_sym_LT_EQ] = ACTIONS(1087),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(1089),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1091),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(2283),
    [anon_sym_not] = ACTIONS(1101),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [369] = {
    [sym_attribute_list] = STATE(6699),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym_variable_declaration] = STATE(9401),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6857),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4336),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9482),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(369),
    [sym_preproc_endregion] = STATE(369),
    [sym_preproc_line] = STATE(369),
    [sym_preproc_pragma] = STATE(369),
    [sym_preproc_nullable] = STATE(369),
    [sym_preproc_error] = STATE(369),
    [sym_preproc_warning] = STATE(369),
    [sym_preproc_define] = STATE(369),
    [sym_preproc_undef] = STATE(369),
    [aux_sym_class_declaration_repeat1] = STATE(3853),
    [aux_sym_class_declaration_repeat2] = STATE(3100),
    [aux_sym_lambda_expression_repeat1] = STATE(4299),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_using] = ACTIONS(2309),
    [anon_sym_unsafe] = ACTIONS(661),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1497),
    [anon_sym_ref] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(687),
    [anon_sym_fixed] = ACTIONS(661),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(2293),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1505),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1507),
    [anon_sym_foreach] = ACTIONS(2311),
    [anon_sym_DOT_DOT] = ACTIONS(1509),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [370] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2802),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(5351),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_pattern] = STATE(8325),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6158),
    [sym_property_pattern_clause] = STATE(6724),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6719),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5302),
    [sym_postfix_unary_expression] = STATE(5343),
    [sym_prefix_unary_expression] = STATE(5343),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5302),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5343),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5302),
    [sym_member_access_expression] = STATE(3862),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5343),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(5302),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5302),
    [sym_typeof_expression] = STATE(5302),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3862),
    [sym_literal] = STATE(5302),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(370),
    [sym_preproc_endregion] = STATE(370),
    [sym_preproc_line] = STATE(370),
    [sym_preproc_pragma] = STATE(370),
    [sym_preproc_nullable] = STATE(370),
    [sym_preproc_error] = STATE(370),
    [sym_preproc_warning] = STATE(370),
    [sym_preproc_define] = STATE(370),
    [sym_preproc_undef] = STATE(370),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_RBRACK] = ACTIONS(2313),
    [anon_sym_LPAREN] = ACTIONS(1067),
    [anon_sym_ref] = ACTIONS(2281),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(1077),
    [anon_sym_GT] = ACTIONS(1077),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1083),
    [anon_sym_PLUS_PLUS] = ACTIONS(1083),
    [anon_sym_DASH_DASH] = ACTIONS(1083),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1085),
    [anon_sym_DASH] = ACTIONS(1085),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1083),
    [anon_sym_AMP] = ACTIONS(1083),
    [anon_sym_GT_EQ] = ACTIONS(1087),
    [anon_sym_LT_EQ] = ACTIONS(1087),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(1089),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1091),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(2283),
    [anon_sym_not] = ACTIONS(1101),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [371] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2802),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(5351),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_pattern] = STATE(8325),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6158),
    [sym_property_pattern_clause] = STATE(6724),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6719),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5302),
    [sym_postfix_unary_expression] = STATE(5343),
    [sym_prefix_unary_expression] = STATE(5343),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5302),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5343),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5302),
    [sym_member_access_expression] = STATE(3862),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5343),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(5302),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5302),
    [sym_typeof_expression] = STATE(5302),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3862),
    [sym_literal] = STATE(5302),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(371),
    [sym_preproc_endregion] = STATE(371),
    [sym_preproc_line] = STATE(371),
    [sym_preproc_pragma] = STATE(371),
    [sym_preproc_nullable] = STATE(371),
    [sym_preproc_error] = STATE(371),
    [sym_preproc_warning] = STATE(371),
    [sym_preproc_define] = STATE(371),
    [sym_preproc_undef] = STATE(371),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_RBRACK] = ACTIONS(2315),
    [anon_sym_LPAREN] = ACTIONS(1067),
    [anon_sym_ref] = ACTIONS(2281),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(1077),
    [anon_sym_GT] = ACTIONS(1077),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1083),
    [anon_sym_PLUS_PLUS] = ACTIONS(1083),
    [anon_sym_DASH_DASH] = ACTIONS(1083),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1085),
    [anon_sym_DASH] = ACTIONS(1085),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1083),
    [anon_sym_AMP] = ACTIONS(1083),
    [anon_sym_GT_EQ] = ACTIONS(1087),
    [anon_sym_LT_EQ] = ACTIONS(1087),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(1089),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1091),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(2283),
    [anon_sym_not] = ACTIONS(1101),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [372] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2802),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(5754),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_pattern] = STATE(8349),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6158),
    [sym_property_pattern_clause] = STATE(6724),
    [sym_subpattern] = STATE(8548),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6410),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5302),
    [sym_postfix_unary_expression] = STATE(5343),
    [sym_prefix_unary_expression] = STATE(5343),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5302),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5343),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5302),
    [sym_member_access_expression] = STATE(3862),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5343),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(5302),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5302),
    [sym_typeof_expression] = STATE(5302),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3862),
    [sym_literal] = STATE(5302),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(372),
    [sym_preproc_endregion] = STATE(372),
    [sym_preproc_line] = STATE(372),
    [sym_preproc_pragma] = STATE(372),
    [sym_preproc_nullable] = STATE(372),
    [sym_preproc_error] = STATE(372),
    [sym_preproc_warning] = STATE(372),
    [sym_preproc_define] = STATE(372),
    [sym_preproc_undef] = STATE(372),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1231),
    [anon_sym_ref] = ACTIONS(2317),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_LT] = ACTIONS(1077),
    [anon_sym_GT] = ACTIONS(1077),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1117),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_AMP] = ACTIONS(1117),
    [anon_sym_GT_EQ] = ACTIONS(1087),
    [anon_sym_LT_EQ] = ACTIONS(1087),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2319),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1091),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_not] = ACTIONS(1137),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [373] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2802),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(5351),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_pattern] = STATE(8325),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6158),
    [sym_property_pattern_clause] = STATE(6724),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6719),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5302),
    [sym_postfix_unary_expression] = STATE(5343),
    [sym_prefix_unary_expression] = STATE(5343),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5302),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5343),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5302),
    [sym_member_access_expression] = STATE(3862),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5343),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(5302),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5302),
    [sym_typeof_expression] = STATE(5302),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3862),
    [sym_literal] = STATE(5302),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(373),
    [sym_preproc_endregion] = STATE(373),
    [sym_preproc_line] = STATE(373),
    [sym_preproc_pragma] = STATE(373),
    [sym_preproc_nullable] = STATE(373),
    [sym_preproc_error] = STATE(373),
    [sym_preproc_warning] = STATE(373),
    [sym_preproc_define] = STATE(373),
    [sym_preproc_undef] = STATE(373),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_RBRACK] = ACTIONS(2321),
    [anon_sym_LPAREN] = ACTIONS(1067),
    [anon_sym_ref] = ACTIONS(2281),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(1077),
    [anon_sym_GT] = ACTIONS(1077),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1083),
    [anon_sym_PLUS_PLUS] = ACTIONS(1083),
    [anon_sym_DASH_DASH] = ACTIONS(1083),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1085),
    [anon_sym_DASH] = ACTIONS(1085),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1083),
    [anon_sym_AMP] = ACTIONS(1083),
    [anon_sym_GT_EQ] = ACTIONS(1087),
    [anon_sym_LT_EQ] = ACTIONS(1087),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(1089),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1091),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(2283),
    [anon_sym_not] = ACTIONS(1101),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [374] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2802),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(5351),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_pattern] = STATE(8325),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6158),
    [sym_property_pattern_clause] = STATE(6724),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6719),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5302),
    [sym_postfix_unary_expression] = STATE(5343),
    [sym_prefix_unary_expression] = STATE(5343),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5302),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5343),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5302),
    [sym_member_access_expression] = STATE(3862),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5343),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(5302),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5302),
    [sym_typeof_expression] = STATE(5302),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3862),
    [sym_literal] = STATE(5302),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(374),
    [sym_preproc_endregion] = STATE(374),
    [sym_preproc_line] = STATE(374),
    [sym_preproc_pragma] = STATE(374),
    [sym_preproc_nullable] = STATE(374),
    [sym_preproc_error] = STATE(374),
    [sym_preproc_warning] = STATE(374),
    [sym_preproc_define] = STATE(374),
    [sym_preproc_undef] = STATE(374),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_RBRACK] = ACTIONS(2323),
    [anon_sym_LPAREN] = ACTIONS(1067),
    [anon_sym_ref] = ACTIONS(2281),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(1077),
    [anon_sym_GT] = ACTIONS(1077),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1083),
    [anon_sym_PLUS_PLUS] = ACTIONS(1083),
    [anon_sym_DASH_DASH] = ACTIONS(1083),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1085),
    [anon_sym_DASH] = ACTIONS(1085),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1083),
    [anon_sym_AMP] = ACTIONS(1083),
    [anon_sym_GT_EQ] = ACTIONS(1087),
    [anon_sym_LT_EQ] = ACTIONS(1087),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(1089),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1091),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(2283),
    [anon_sym_not] = ACTIONS(1101),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [375] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3000),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2756),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3038),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(4137),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(3124),
    [sym_property_pattern_clause] = STATE(3207),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6708),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(4164),
    [sym_postfix_unary_expression] = STATE(4165),
    [sym_prefix_unary_expression] = STATE(4165),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(4164),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(4165),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(4164),
    [sym_member_access_expression] = STATE(3482),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(4165),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(4164),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(4164),
    [sym_typeof_expression] = STATE(4164),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3482),
    [sym_literal] = STATE(4164),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2755),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(375),
    [sym_preproc_endregion] = STATE(375),
    [sym_preproc_line] = STATE(375),
    [sym_preproc_pragma] = STATE(375),
    [sym_preproc_nullable] = STATE(375),
    [sym_preproc_error] = STATE(375),
    [sym_preproc_warning] = STATE(375),
    [sym_preproc_define] = STATE(375),
    [sym_preproc_undef] = STATE(375),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(2325),
    [anon_sym_ref] = ACTIONS(2327),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2331),
    [anon_sym_GT] = ACTIONS(2331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1759),
    [anon_sym_TILDE] = ACTIONS(1759),
    [anon_sym_PLUS_PLUS] = ACTIONS(1759),
    [anon_sym_DASH_DASH] = ACTIONS(1759),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1757),
    [anon_sym_DASH] = ACTIONS(1757),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1759),
    [anon_sym_AMP] = ACTIONS(1759),
    [anon_sym_GT_EQ] = ACTIONS(2333),
    [anon_sym_LT_EQ] = ACTIONS(2333),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2337),
    [sym_predefined_type] = ACTIONS(2339),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2341),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [376] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3555),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2893),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3065),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(4198),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(3170),
    [sym_property_pattern_clause] = STATE(3373),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6736),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(4164),
    [sym_postfix_unary_expression] = STATE(4165),
    [sym_prefix_unary_expression] = STATE(4165),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(4164),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(4165),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(4164),
    [sym_member_access_expression] = STATE(3482),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(4165),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(4164),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(4164),
    [sym_typeof_expression] = STATE(4164),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3482),
    [sym_literal] = STATE(4164),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2755),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(376),
    [sym_preproc_endregion] = STATE(376),
    [sym_preproc_line] = STATE(376),
    [sym_preproc_pragma] = STATE(376),
    [sym_preproc_nullable] = STATE(376),
    [sym_preproc_error] = STATE(376),
    [sym_preproc_warning] = STATE(376),
    [sym_preproc_define] = STATE(376),
    [sym_preproc_undef] = STATE(376),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(2343),
    [anon_sym_ref] = ACTIONS(2327),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2345),
    [anon_sym_GT] = ACTIONS(2345),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1863),
    [anon_sym_TILDE] = ACTIONS(1863),
    [anon_sym_PLUS_PLUS] = ACTIONS(1863),
    [anon_sym_DASH_DASH] = ACTIONS(1863),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1861),
    [anon_sym_DASH] = ACTIONS(1861),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1863),
    [anon_sym_AMP] = ACTIONS(1863),
    [anon_sym_GT_EQ] = ACTIONS(2347),
    [anon_sym_LT_EQ] = ACTIONS(2347),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2349),
    [sym_predefined_type] = ACTIONS(2339),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2351),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [377] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3555),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2893),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3065),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(6331),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(3170),
    [sym_property_pattern_clause] = STATE(3373),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6736),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(4164),
    [sym_postfix_unary_expression] = STATE(4165),
    [sym_prefix_unary_expression] = STATE(4165),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(4164),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(4165),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(4164),
    [sym_member_access_expression] = STATE(3482),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(4165),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(4164),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(4164),
    [sym_typeof_expression] = STATE(4164),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3482),
    [sym_literal] = STATE(4164),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2755),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(377),
    [sym_preproc_endregion] = STATE(377),
    [sym_preproc_line] = STATE(377),
    [sym_preproc_pragma] = STATE(377),
    [sym_preproc_nullable] = STATE(377),
    [sym_preproc_error] = STATE(377),
    [sym_preproc_warning] = STATE(377),
    [sym_preproc_define] = STATE(377),
    [sym_preproc_undef] = STATE(377),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(2343),
    [anon_sym_ref] = ACTIONS(2327),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2345),
    [anon_sym_GT] = ACTIONS(2345),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1863),
    [anon_sym_TILDE] = ACTIONS(1863),
    [anon_sym_PLUS_PLUS] = ACTIONS(1863),
    [anon_sym_DASH_DASH] = ACTIONS(1863),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1861),
    [anon_sym_DASH] = ACTIONS(1861),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1863),
    [anon_sym_AMP] = ACTIONS(1863),
    [anon_sym_GT_EQ] = ACTIONS(2347),
    [anon_sym_LT_EQ] = ACTIONS(2347),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2349),
    [sym_predefined_type] = ACTIONS(2339),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2351),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [378] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3465),
    [sym_alias_qualified_name] = STATE(3486),
    [sym__simple_name] = STATE(2831),
    [sym_qualified_name] = STATE(3486),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(2976),
    [sym_implicit_type] = STATE(3330),
    [sym_array_type] = STATE(3488),
    [sym__array_base_type] = STATE(8756),
    [sym_nullable_type] = STATE(3489),
    [sym_pointer_type] = STATE(3489),
    [sym__pointer_base_type] = STATE(9221),
    [sym_function_pointer_type] = STATE(3489),
    [sym_ref_type] = STATE(3330),
    [sym_scoped_type] = STATE(3330),
    [sym_tuple_type] = STATE(3490),
    [sym_pattern] = STATE(5626),
    [sym_constant_pattern] = STATE(5744),
    [sym_parenthesized_pattern] = STATE(5744),
    [sym_var_pattern] = STATE(5744),
    [sym_type_pattern] = STATE(5744),
    [sym_list_pattern] = STATE(5744),
    [sym_recursive_pattern] = STATE(5744),
    [sym_positional_pattern_clause] = STATE(3076),
    [sym_property_pattern_clause] = STATE(3129),
    [sym_relational_pattern] = STATE(5744),
    [sym_negated_pattern] = STATE(5744),
    [sym_and_pattern] = STATE(5744),
    [sym_or_pattern] = STATE(5744),
    [sym_declaration_pattern] = STATE(5744),
    [sym_expression] = STATE(6695),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5469),
    [sym_postfix_unary_expression] = STATE(5470),
    [sym_prefix_unary_expression] = STATE(5470),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5469),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5470),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5469),
    [sym_member_access_expression] = STATE(3940),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5470),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(5469),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5469),
    [sym_typeof_expression] = STATE(5469),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3940),
    [sym_literal] = STATE(5469),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2792),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(378),
    [sym_preproc_endregion] = STATE(378),
    [sym_preproc_line] = STATE(378),
    [sym_preproc_pragma] = STATE(378),
    [sym_preproc_nullable] = STATE(378),
    [sym_preproc_error] = STATE(378),
    [sym_preproc_warning] = STATE(378),
    [sym_preproc_define] = STATE(378),
    [sym_preproc_undef] = STATE(378),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(2353),
    [anon_sym_LPAREN] = ACTIONS(2355),
    [anon_sym_ref] = ACTIONS(2357),
    [anon_sym_LBRACE] = ACTIONS(2359),
    [anon_sym_delegate] = ACTIONS(2361),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2363),
    [anon_sym_GT] = ACTIONS(2363),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1485),
    [anon_sym_TILDE] = ACTIONS(1485),
    [anon_sym_PLUS_PLUS] = ACTIONS(1485),
    [anon_sym_DASH_DASH] = ACTIONS(1485),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1483),
    [anon_sym_DASH] = ACTIONS(1483),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1485),
    [anon_sym_AMP] = ACTIONS(1485),
    [anon_sym_GT_EQ] = ACTIONS(2365),
    [anon_sym_LT_EQ] = ACTIONS(2365),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2367),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2369),
    [sym_predefined_type] = ACTIONS(2371),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(2373),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2375),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [379] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3465),
    [sym_alias_qualified_name] = STATE(3486),
    [sym__simple_name] = STATE(2831),
    [sym_qualified_name] = STATE(3486),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(2976),
    [sym_implicit_type] = STATE(3330),
    [sym_array_type] = STATE(3488),
    [sym__array_base_type] = STATE(8756),
    [sym_nullable_type] = STATE(3489),
    [sym_pointer_type] = STATE(3489),
    [sym__pointer_base_type] = STATE(9221),
    [sym_function_pointer_type] = STATE(3489),
    [sym_ref_type] = STATE(3330),
    [sym_scoped_type] = STATE(3330),
    [sym_tuple_type] = STATE(3490),
    [sym_pattern] = STATE(5432),
    [sym_constant_pattern] = STATE(5744),
    [sym_parenthesized_pattern] = STATE(5744),
    [sym_var_pattern] = STATE(5744),
    [sym_type_pattern] = STATE(5744),
    [sym_list_pattern] = STATE(5744),
    [sym_recursive_pattern] = STATE(5744),
    [sym_positional_pattern_clause] = STATE(3076),
    [sym_property_pattern_clause] = STATE(3129),
    [sym_relational_pattern] = STATE(5744),
    [sym_negated_pattern] = STATE(5744),
    [sym_and_pattern] = STATE(5744),
    [sym_or_pattern] = STATE(5744),
    [sym_declaration_pattern] = STATE(5744),
    [sym_expression] = STATE(6695),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5469),
    [sym_postfix_unary_expression] = STATE(5470),
    [sym_prefix_unary_expression] = STATE(5470),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5469),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5470),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5469),
    [sym_member_access_expression] = STATE(3940),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5470),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(5469),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5469),
    [sym_typeof_expression] = STATE(5469),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3940),
    [sym_literal] = STATE(5469),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2792),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(379),
    [sym_preproc_endregion] = STATE(379),
    [sym_preproc_line] = STATE(379),
    [sym_preproc_pragma] = STATE(379),
    [sym_preproc_nullable] = STATE(379),
    [sym_preproc_error] = STATE(379),
    [sym_preproc_warning] = STATE(379),
    [sym_preproc_define] = STATE(379),
    [sym_preproc_undef] = STATE(379),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(2353),
    [anon_sym_LPAREN] = ACTIONS(2355),
    [anon_sym_ref] = ACTIONS(2357),
    [anon_sym_LBRACE] = ACTIONS(2359),
    [anon_sym_delegate] = ACTIONS(2361),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2363),
    [anon_sym_GT] = ACTIONS(2363),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1485),
    [anon_sym_TILDE] = ACTIONS(1485),
    [anon_sym_PLUS_PLUS] = ACTIONS(1485),
    [anon_sym_DASH_DASH] = ACTIONS(1485),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1483),
    [anon_sym_DASH] = ACTIONS(1483),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1485),
    [anon_sym_AMP] = ACTIONS(1485),
    [anon_sym_GT_EQ] = ACTIONS(2365),
    [anon_sym_LT_EQ] = ACTIONS(2365),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2367),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2369),
    [sym_predefined_type] = ACTIONS(2371),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(2373),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2375),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [380] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(2999),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2761),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(2795),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(3987),
    [sym_constant_pattern] = STATE(4086),
    [sym_parenthesized_pattern] = STATE(4086),
    [sym_var_pattern] = STATE(4086),
    [sym_type_pattern] = STATE(4086),
    [sym_list_pattern] = STATE(4086),
    [sym_recursive_pattern] = STATE(4086),
    [sym_positional_pattern_clause] = STATE(2840),
    [sym_property_pattern_clause] = STATE(2874),
    [sym_relational_pattern] = STATE(4086),
    [sym_negated_pattern] = STATE(4086),
    [sym_and_pattern] = STATE(4086),
    [sym_or_pattern] = STATE(4086),
    [sym_declaration_pattern] = STATE(4086),
    [sym_expression] = STATE(6704),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3989),
    [sym_postfix_unary_expression] = STATE(3990),
    [sym_prefix_unary_expression] = STATE(3990),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3989),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3990),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3989),
    [sym_member_access_expression] = STATE(3206),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3990),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3989),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3989),
    [sym_typeof_expression] = STATE(3989),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3206),
    [sym_literal] = STATE(3989),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2755),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(380),
    [sym_preproc_endregion] = STATE(380),
    [sym_preproc_line] = STATE(380),
    [sym_preproc_pragma] = STATE(380),
    [sym_preproc_nullable] = STATE(380),
    [sym_preproc_error] = STATE(380),
    [sym_preproc_warning] = STATE(380),
    [sym_preproc_define] = STATE(380),
    [sym_preproc_undef] = STATE(380),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(2377),
    [anon_sym_LPAREN] = ACTIONS(2379),
    [anon_sym_ref] = ACTIONS(2327),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2381),
    [anon_sym_GT] = ACTIONS(2381),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1177),
    [anon_sym_TILDE] = ACTIONS(1177),
    [anon_sym_PLUS_PLUS] = ACTIONS(1177),
    [anon_sym_DASH_DASH] = ACTIONS(1177),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1175),
    [anon_sym_DASH] = ACTIONS(1175),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1177),
    [anon_sym_AMP] = ACTIONS(1177),
    [anon_sym_GT_EQ] = ACTIONS(2383),
    [anon_sym_LT_EQ] = ACTIONS(2383),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2385),
    [sym_predefined_type] = ACTIONS(2387),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(2389),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2391),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [381] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3000),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2756),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(2813),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(4137),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(2858),
    [sym_property_pattern_clause] = STATE(2881),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6719),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(4164),
    [sym_postfix_unary_expression] = STATE(4165),
    [sym_prefix_unary_expression] = STATE(4165),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(4164),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(4165),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(4164),
    [sym_member_access_expression] = STATE(3482),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(4165),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(4164),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(4164),
    [sym_typeof_expression] = STATE(4164),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3482),
    [sym_literal] = STATE(4164),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2755),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(381),
    [sym_preproc_endregion] = STATE(381),
    [sym_preproc_line] = STATE(381),
    [sym_preproc_pragma] = STATE(381),
    [sym_preproc_nullable] = STATE(381),
    [sym_preproc_error] = STATE(381),
    [sym_preproc_warning] = STATE(381),
    [sym_preproc_define] = STATE(381),
    [sym_preproc_undef] = STATE(381),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(2393),
    [anon_sym_ref] = ACTIONS(2327),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(1077),
    [anon_sym_GT] = ACTIONS(1077),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1083),
    [anon_sym_PLUS_PLUS] = ACTIONS(1083),
    [anon_sym_DASH_DASH] = ACTIONS(1083),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1085),
    [anon_sym_DASH] = ACTIONS(1085),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1083),
    [anon_sym_AMP] = ACTIONS(1083),
    [anon_sym_GT_EQ] = ACTIONS(1087),
    [anon_sym_LT_EQ] = ACTIONS(1087),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2349),
    [sym_predefined_type] = ACTIONS(2339),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2395),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [382] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3465),
    [sym_alias_qualified_name] = STATE(3486),
    [sym__simple_name] = STATE(2831),
    [sym_qualified_name] = STATE(3486),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(2976),
    [sym_implicit_type] = STATE(3330),
    [sym_array_type] = STATE(3488),
    [sym__array_base_type] = STATE(8756),
    [sym_nullable_type] = STATE(3489),
    [sym_pointer_type] = STATE(3489),
    [sym__pointer_base_type] = STATE(9221),
    [sym_function_pointer_type] = STATE(3489),
    [sym_ref_type] = STATE(3330),
    [sym_scoped_type] = STATE(3330),
    [sym_tuple_type] = STATE(3490),
    [sym_pattern] = STATE(5747),
    [sym_constant_pattern] = STATE(5744),
    [sym_parenthesized_pattern] = STATE(5744),
    [sym_var_pattern] = STATE(5744),
    [sym_type_pattern] = STATE(5744),
    [sym_list_pattern] = STATE(5744),
    [sym_recursive_pattern] = STATE(5744),
    [sym_positional_pattern_clause] = STATE(3076),
    [sym_property_pattern_clause] = STATE(3129),
    [sym_relational_pattern] = STATE(5744),
    [sym_negated_pattern] = STATE(5744),
    [sym_and_pattern] = STATE(5744),
    [sym_or_pattern] = STATE(5744),
    [sym_declaration_pattern] = STATE(5744),
    [sym_expression] = STATE(6695),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5469),
    [sym_postfix_unary_expression] = STATE(5470),
    [sym_prefix_unary_expression] = STATE(5470),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5469),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5470),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5469),
    [sym_member_access_expression] = STATE(3940),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5470),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(5469),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5469),
    [sym_typeof_expression] = STATE(5469),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3940),
    [sym_literal] = STATE(5469),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2792),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(382),
    [sym_preproc_endregion] = STATE(382),
    [sym_preproc_line] = STATE(382),
    [sym_preproc_pragma] = STATE(382),
    [sym_preproc_nullable] = STATE(382),
    [sym_preproc_error] = STATE(382),
    [sym_preproc_warning] = STATE(382),
    [sym_preproc_define] = STATE(382),
    [sym_preproc_undef] = STATE(382),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(2353),
    [anon_sym_LPAREN] = ACTIONS(2355),
    [anon_sym_ref] = ACTIONS(2357),
    [anon_sym_LBRACE] = ACTIONS(2359),
    [anon_sym_delegate] = ACTIONS(2361),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2363),
    [anon_sym_GT] = ACTIONS(2363),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1485),
    [anon_sym_TILDE] = ACTIONS(1485),
    [anon_sym_PLUS_PLUS] = ACTIONS(1485),
    [anon_sym_DASH_DASH] = ACTIONS(1485),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1483),
    [anon_sym_DASH] = ACTIONS(1483),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1485),
    [anon_sym_AMP] = ACTIONS(1485),
    [anon_sym_GT_EQ] = ACTIONS(2365),
    [anon_sym_LT_EQ] = ACTIONS(2365),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2367),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2369),
    [sym_predefined_type] = ACTIONS(2371),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(2373),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2375),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [383] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6764),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2862),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6181),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_pattern] = STATE(8348),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6721),
    [sym_property_pattern_clause] = STATE(6770),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6715),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(6241),
    [sym_postfix_unary_expression] = STATE(6242),
    [sym_prefix_unary_expression] = STATE(6242),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(6241),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(6242),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(6241),
    [sym_member_access_expression] = STATE(4249),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(6242),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(6241),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(6241),
    [sym_typeof_expression] = STATE(6241),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(4249),
    [sym_literal] = STATE(6241),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2810),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(383),
    [sym_preproc_endregion] = STATE(383),
    [sym_preproc_line] = STATE(383),
    [sym_preproc_pragma] = STATE(383),
    [sym_preproc_nullable] = STATE(383),
    [sym_preproc_error] = STATE(383),
    [sym_preproc_warning] = STATE(383),
    [sym_preproc_define] = STATE(383),
    [sym_preproc_undef] = STATE(383),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(2397),
    [anon_sym_ref] = ACTIONS(2399),
    [anon_sym_LBRACE] = ACTIONS(2401),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2403),
    [anon_sym_GT] = ACTIONS(2403),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1629),
    [anon_sym_TILDE] = ACTIONS(1629),
    [anon_sym_PLUS_PLUS] = ACTIONS(1629),
    [anon_sym_DASH_DASH] = ACTIONS(1629),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1627),
    [anon_sym_DASH] = ACTIONS(1627),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1629),
    [anon_sym_AMP] = ACTIONS(1629),
    [anon_sym_GT_EQ] = ACTIONS(2405),
    [anon_sym_LT_EQ] = ACTIONS(2405),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2407),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2409),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2411),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [384] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3536),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2859),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3036),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(4562),
    [sym_constant_pattern] = STATE(4557),
    [sym_parenthesized_pattern] = STATE(4557),
    [sym_var_pattern] = STATE(4557),
    [sym_type_pattern] = STATE(4557),
    [sym_list_pattern] = STATE(4557),
    [sym_recursive_pattern] = STATE(4557),
    [sym_positional_pattern_clause] = STATE(3127),
    [sym_property_pattern_clause] = STATE(3184),
    [sym_relational_pattern] = STATE(4557),
    [sym_negated_pattern] = STATE(4557),
    [sym_and_pattern] = STATE(4557),
    [sym_or_pattern] = STATE(4557),
    [sym_declaration_pattern] = STATE(4557),
    [sym_expression] = STATE(6744),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(4559),
    [sym_postfix_unary_expression] = STATE(4560),
    [sym_prefix_unary_expression] = STATE(4560),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(4559),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(4560),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(4559),
    [sym_member_access_expression] = STATE(3583),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(4560),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(4559),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(4559),
    [sym_typeof_expression] = STATE(4559),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3583),
    [sym_literal] = STATE(4559),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2755),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(384),
    [sym_preproc_endregion] = STATE(384),
    [sym_preproc_line] = STATE(384),
    [sym_preproc_pragma] = STATE(384),
    [sym_preproc_nullable] = STATE(384),
    [sym_preproc_error] = STATE(384),
    [sym_preproc_warning] = STATE(384),
    [sym_preproc_define] = STATE(384),
    [sym_preproc_undef] = STATE(384),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(2413),
    [anon_sym_LPAREN] = ACTIONS(2415),
    [anon_sym_ref] = ACTIONS(2327),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2417),
    [anon_sym_GT] = ACTIONS(2417),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1775),
    [anon_sym_TILDE] = ACTIONS(1775),
    [anon_sym_PLUS_PLUS] = ACTIONS(1775),
    [anon_sym_DASH_DASH] = ACTIONS(1775),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1773),
    [anon_sym_DASH] = ACTIONS(1773),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1775),
    [anon_sym_AMP] = ACTIONS(1775),
    [anon_sym_GT_EQ] = ACTIONS(2419),
    [anon_sym_LT_EQ] = ACTIONS(2419),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2421),
    [sym_predefined_type] = ACTIONS(2423),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(2425),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2427),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [385] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3541),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2876),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3037),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(4754),
    [sym_constant_pattern] = STATE(4557),
    [sym_parenthesized_pattern] = STATE(4557),
    [sym_var_pattern] = STATE(4557),
    [sym_type_pattern] = STATE(4557),
    [sym_list_pattern] = STATE(4557),
    [sym_recursive_pattern] = STATE(4557),
    [sym_positional_pattern_clause] = STATE(3128),
    [sym_property_pattern_clause] = STATE(3222),
    [sym_relational_pattern] = STATE(4557),
    [sym_negated_pattern] = STATE(4557),
    [sym_and_pattern] = STATE(4557),
    [sym_or_pattern] = STATE(4557),
    [sym_declaration_pattern] = STATE(4557),
    [sym_expression] = STATE(6747),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(4559),
    [sym_postfix_unary_expression] = STATE(4560),
    [sym_prefix_unary_expression] = STATE(4560),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(4559),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(4560),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(4559),
    [sym_member_access_expression] = STATE(3583),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(4560),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(4559),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(4559),
    [sym_typeof_expression] = STATE(4559),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3583),
    [sym_literal] = STATE(4559),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2755),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(385),
    [sym_preproc_endregion] = STATE(385),
    [sym_preproc_line] = STATE(385),
    [sym_preproc_pragma] = STATE(385),
    [sym_preproc_nullable] = STATE(385),
    [sym_preproc_error] = STATE(385),
    [sym_preproc_warning] = STATE(385),
    [sym_preproc_define] = STATE(385),
    [sym_preproc_undef] = STATE(385),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(2413),
    [anon_sym_LPAREN] = ACTIONS(2429),
    [anon_sym_ref] = ACTIONS(2327),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2431),
    [anon_sym_GT] = ACTIONS(2431),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1701),
    [anon_sym_TILDE] = ACTIONS(1701),
    [anon_sym_PLUS_PLUS] = ACTIONS(1701),
    [anon_sym_DASH_DASH] = ACTIONS(1701),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1699),
    [anon_sym_DASH] = ACTIONS(1699),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1701),
    [anon_sym_AMP] = ACTIONS(1701),
    [anon_sym_GT_EQ] = ACTIONS(2433),
    [anon_sym_LT_EQ] = ACTIONS(2433),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2421),
    [sym_predefined_type] = ACTIONS(2423),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(2425),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2435),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [386] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3549),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2915),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3083),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(6523),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(3141),
    [sym_property_pattern_clause] = STATE(3273),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6740),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(4164),
    [sym_postfix_unary_expression] = STATE(4165),
    [sym_prefix_unary_expression] = STATE(4165),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(4164),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(4165),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(4164),
    [sym_member_access_expression] = STATE(3482),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(4165),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(4164),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(4164),
    [sym_typeof_expression] = STATE(4164),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3482),
    [sym_literal] = STATE(4164),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2755),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(386),
    [sym_preproc_endregion] = STATE(386),
    [sym_preproc_line] = STATE(386),
    [sym_preproc_pragma] = STATE(386),
    [sym_preproc_nullable] = STATE(386),
    [sym_preproc_error] = STATE(386),
    [sym_preproc_warning] = STATE(386),
    [sym_preproc_define] = STATE(386),
    [sym_preproc_undef] = STATE(386),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(2437),
    [anon_sym_ref] = ACTIONS(2327),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2439),
    [anon_sym_GT] = ACTIONS(2439),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1809),
    [anon_sym_TILDE] = ACTIONS(1809),
    [anon_sym_PLUS_PLUS] = ACTIONS(1809),
    [anon_sym_DASH_DASH] = ACTIONS(1809),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1807),
    [anon_sym_DASH] = ACTIONS(1807),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1809),
    [anon_sym_AMP] = ACTIONS(1809),
    [anon_sym_GT_EQ] = ACTIONS(2441),
    [anon_sym_LT_EQ] = ACTIONS(2441),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2349),
    [sym_predefined_type] = ACTIONS(2339),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2443),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [387] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3538),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2846),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3029),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(6043),
    [sym_constant_pattern] = STATE(4086),
    [sym_parenthesized_pattern] = STATE(4086),
    [sym_var_pattern] = STATE(4086),
    [sym_type_pattern] = STATE(4086),
    [sym_list_pattern] = STATE(4086),
    [sym_recursive_pattern] = STATE(4086),
    [sym_positional_pattern_clause] = STATE(3120),
    [sym_property_pattern_clause] = STATE(3169),
    [sym_relational_pattern] = STATE(4086),
    [sym_negated_pattern] = STATE(4086),
    [sym_and_pattern] = STATE(4086),
    [sym_or_pattern] = STATE(4086),
    [sym_declaration_pattern] = STATE(4086),
    [sym_expression] = STATE(6705),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3989),
    [sym_postfix_unary_expression] = STATE(3990),
    [sym_prefix_unary_expression] = STATE(3990),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3989),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3990),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3989),
    [sym_member_access_expression] = STATE(3206),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3990),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3989),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3989),
    [sym_typeof_expression] = STATE(3989),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3206),
    [sym_literal] = STATE(3989),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2776),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(387),
    [sym_preproc_endregion] = STATE(387),
    [sym_preproc_line] = STATE(387),
    [sym_preproc_pragma] = STATE(387),
    [sym_preproc_nullable] = STATE(387),
    [sym_preproc_error] = STATE(387),
    [sym_preproc_warning] = STATE(387),
    [sym_preproc_define] = STATE(387),
    [sym_preproc_undef] = STATE(387),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(2377),
    [anon_sym_LPAREN] = ACTIONS(2445),
    [anon_sym_ref] = ACTIONS(2447),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2449),
    [anon_sym_GT] = ACTIONS(2449),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1599),
    [anon_sym_TILDE] = ACTIONS(1599),
    [anon_sym_PLUS_PLUS] = ACTIONS(1599),
    [anon_sym_DASH_DASH] = ACTIONS(1599),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1597),
    [anon_sym_DASH] = ACTIONS(1597),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1599),
    [anon_sym_AMP] = ACTIONS(1599),
    [anon_sym_GT_EQ] = ACTIONS(2451),
    [anon_sym_LT_EQ] = ACTIONS(2451),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2453),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2385),
    [sym_predefined_type] = ACTIONS(2387),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(2389),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2455),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [388] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3538),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2846),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3029),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(4029),
    [sym_constant_pattern] = STATE(4086),
    [sym_parenthesized_pattern] = STATE(4086),
    [sym_var_pattern] = STATE(4086),
    [sym_type_pattern] = STATE(4086),
    [sym_list_pattern] = STATE(4086),
    [sym_recursive_pattern] = STATE(4086),
    [sym_positional_pattern_clause] = STATE(3120),
    [sym_property_pattern_clause] = STATE(3169),
    [sym_relational_pattern] = STATE(4086),
    [sym_negated_pattern] = STATE(4086),
    [sym_and_pattern] = STATE(4086),
    [sym_or_pattern] = STATE(4086),
    [sym_declaration_pattern] = STATE(4086),
    [sym_expression] = STATE(6705),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3989),
    [sym_postfix_unary_expression] = STATE(3990),
    [sym_prefix_unary_expression] = STATE(3990),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3989),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3990),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3989),
    [sym_member_access_expression] = STATE(3206),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3990),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3989),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3989),
    [sym_typeof_expression] = STATE(3989),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3206),
    [sym_literal] = STATE(3989),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2776),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(388),
    [sym_preproc_endregion] = STATE(388),
    [sym_preproc_line] = STATE(388),
    [sym_preproc_pragma] = STATE(388),
    [sym_preproc_nullable] = STATE(388),
    [sym_preproc_error] = STATE(388),
    [sym_preproc_warning] = STATE(388),
    [sym_preproc_define] = STATE(388),
    [sym_preproc_undef] = STATE(388),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(2377),
    [anon_sym_LPAREN] = ACTIONS(2445),
    [anon_sym_ref] = ACTIONS(2447),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2449),
    [anon_sym_GT] = ACTIONS(2449),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1599),
    [anon_sym_TILDE] = ACTIONS(1599),
    [anon_sym_PLUS_PLUS] = ACTIONS(1599),
    [anon_sym_DASH_DASH] = ACTIONS(1599),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1597),
    [anon_sym_DASH] = ACTIONS(1597),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1599),
    [anon_sym_AMP] = ACTIONS(1599),
    [anon_sym_GT_EQ] = ACTIONS(2451),
    [anon_sym_LT_EQ] = ACTIONS(2451),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2453),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2385),
    [sym_predefined_type] = ACTIONS(2387),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(2389),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2455),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [389] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3538),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2846),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3029),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(6022),
    [sym_constant_pattern] = STATE(4086),
    [sym_parenthesized_pattern] = STATE(4086),
    [sym_var_pattern] = STATE(4086),
    [sym_type_pattern] = STATE(4086),
    [sym_list_pattern] = STATE(4086),
    [sym_recursive_pattern] = STATE(4086),
    [sym_positional_pattern_clause] = STATE(3120),
    [sym_property_pattern_clause] = STATE(3169),
    [sym_relational_pattern] = STATE(4086),
    [sym_negated_pattern] = STATE(4086),
    [sym_and_pattern] = STATE(4086),
    [sym_or_pattern] = STATE(4086),
    [sym_declaration_pattern] = STATE(4086),
    [sym_expression] = STATE(6705),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3989),
    [sym_postfix_unary_expression] = STATE(3990),
    [sym_prefix_unary_expression] = STATE(3990),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3989),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3990),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3989),
    [sym_member_access_expression] = STATE(3206),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3990),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3989),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3989),
    [sym_typeof_expression] = STATE(3989),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3206),
    [sym_literal] = STATE(3989),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2776),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(389),
    [sym_preproc_endregion] = STATE(389),
    [sym_preproc_line] = STATE(389),
    [sym_preproc_pragma] = STATE(389),
    [sym_preproc_nullable] = STATE(389),
    [sym_preproc_error] = STATE(389),
    [sym_preproc_warning] = STATE(389),
    [sym_preproc_define] = STATE(389),
    [sym_preproc_undef] = STATE(389),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(2377),
    [anon_sym_LPAREN] = ACTIONS(2445),
    [anon_sym_ref] = ACTIONS(2447),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2449),
    [anon_sym_GT] = ACTIONS(2449),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1599),
    [anon_sym_TILDE] = ACTIONS(1599),
    [anon_sym_PLUS_PLUS] = ACTIONS(1599),
    [anon_sym_DASH_DASH] = ACTIONS(1599),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1597),
    [anon_sym_DASH] = ACTIONS(1597),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1599),
    [anon_sym_AMP] = ACTIONS(1599),
    [anon_sym_GT_EQ] = ACTIONS(2451),
    [anon_sym_LT_EQ] = ACTIONS(2451),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2453),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2385),
    [sym_predefined_type] = ACTIONS(2387),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(2389),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2455),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [390] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3000),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2756),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(2809),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(5581),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(2858),
    [sym_property_pattern_clause] = STATE(2881),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6706),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(4164),
    [sym_postfix_unary_expression] = STATE(4165),
    [sym_prefix_unary_expression] = STATE(4165),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(4164),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(4165),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(4164),
    [sym_member_access_expression] = STATE(3482),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(4165),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(4164),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(4164),
    [sym_typeof_expression] = STATE(4164),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3482),
    [sym_literal] = STATE(4164),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2755),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(390),
    [sym_preproc_endregion] = STATE(390),
    [sym_preproc_line] = STATE(390),
    [sym_preproc_pragma] = STATE(390),
    [sym_preproc_nullable] = STATE(390),
    [sym_preproc_error] = STATE(390),
    [sym_preproc_warning] = STATE(390),
    [sym_preproc_define] = STATE(390),
    [sym_preproc_undef] = STATE(390),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(2457),
    [anon_sym_ref] = ACTIONS(2327),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2459),
    [anon_sym_GT] = ACTIONS(2459),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1379),
    [anon_sym_TILDE] = ACTIONS(1379),
    [anon_sym_PLUS_PLUS] = ACTIONS(1379),
    [anon_sym_DASH_DASH] = ACTIONS(1379),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1377),
    [anon_sym_DASH] = ACTIONS(1377),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1379),
    [anon_sym_AMP] = ACTIONS(1379),
    [anon_sym_GT_EQ] = ACTIONS(2461),
    [anon_sym_LT_EQ] = ACTIONS(2461),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2349),
    [sym_predefined_type] = ACTIONS(2339),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2463),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [391] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3535),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2846),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3039),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(3987),
    [sym_constant_pattern] = STATE(4086),
    [sym_parenthesized_pattern] = STATE(4086),
    [sym_var_pattern] = STATE(4086),
    [sym_type_pattern] = STATE(4086),
    [sym_list_pattern] = STATE(4086),
    [sym_recursive_pattern] = STATE(4086),
    [sym_positional_pattern_clause] = STATE(3120),
    [sym_property_pattern_clause] = STATE(3169),
    [sym_relational_pattern] = STATE(4086),
    [sym_negated_pattern] = STATE(4086),
    [sym_and_pattern] = STATE(4086),
    [sym_or_pattern] = STATE(4086),
    [sym_declaration_pattern] = STATE(4086),
    [sym_expression] = STATE(6700),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3989),
    [sym_postfix_unary_expression] = STATE(3990),
    [sym_prefix_unary_expression] = STATE(3990),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3989),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3990),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3989),
    [sym_member_access_expression] = STATE(3206),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3990),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3989),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3989),
    [sym_typeof_expression] = STATE(3989),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3206),
    [sym_literal] = STATE(3989),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2835),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(391),
    [sym_preproc_endregion] = STATE(391),
    [sym_preproc_line] = STATE(391),
    [sym_preproc_pragma] = STATE(391),
    [sym_preproc_nullable] = STATE(391),
    [sym_preproc_error] = STATE(391),
    [sym_preproc_warning] = STATE(391),
    [sym_preproc_define] = STATE(391),
    [sym_preproc_undef] = STATE(391),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(2377),
    [anon_sym_LPAREN] = ACTIONS(2465),
    [anon_sym_ref] = ACTIONS(2467),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2469),
    [anon_sym_GT] = ACTIONS(2469),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1791),
    [anon_sym_TILDE] = ACTIONS(1791),
    [anon_sym_PLUS_PLUS] = ACTIONS(1791),
    [anon_sym_DASH_DASH] = ACTIONS(1791),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1789),
    [anon_sym_DASH] = ACTIONS(1789),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1791),
    [anon_sym_AMP] = ACTIONS(1791),
    [anon_sym_GT_EQ] = ACTIONS(2471),
    [anon_sym_LT_EQ] = ACTIONS(2471),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2473),
    [sym_predefined_type] = ACTIONS(2387),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(2389),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2475),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [392] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3543),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2882),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3090),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(5083),
    [sym_constant_pattern] = STATE(5032),
    [sym_parenthesized_pattern] = STATE(5032),
    [sym_var_pattern] = STATE(5032),
    [sym_type_pattern] = STATE(5032),
    [sym_list_pattern] = STATE(5032),
    [sym_recursive_pattern] = STATE(5032),
    [sym_positional_pattern_clause] = STATE(3157),
    [sym_property_pattern_clause] = STATE(3428),
    [sym_relational_pattern] = STATE(5032),
    [sym_negated_pattern] = STATE(5032),
    [sym_and_pattern] = STATE(5032),
    [sym_or_pattern] = STATE(5032),
    [sym_declaration_pattern] = STATE(5032),
    [sym_expression] = STATE(6692),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(4990),
    [sym_postfix_unary_expression] = STATE(5037),
    [sym_prefix_unary_expression] = STATE(5037),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(4990),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5037),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(4990),
    [sym_member_access_expression] = STATE(3739),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5037),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(4990),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(4990),
    [sym_typeof_expression] = STATE(4990),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3739),
    [sym_literal] = STATE(4990),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2755),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(392),
    [sym_preproc_endregion] = STATE(392),
    [sym_preproc_line] = STATE(392),
    [sym_preproc_pragma] = STATE(392),
    [sym_preproc_nullable] = STATE(392),
    [sym_preproc_error] = STATE(392),
    [sym_preproc_warning] = STATE(392),
    [sym_preproc_define] = STATE(392),
    [sym_preproc_undef] = STATE(392),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(2477),
    [anon_sym_LPAREN] = ACTIONS(2479),
    [anon_sym_ref] = ACTIONS(2327),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2481),
    [anon_sym_GT] = ACTIONS(2481),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1901),
    [anon_sym_TILDE] = ACTIONS(1901),
    [anon_sym_PLUS_PLUS] = ACTIONS(1901),
    [anon_sym_DASH_DASH] = ACTIONS(1901),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1899),
    [anon_sym_DASH] = ACTIONS(1899),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1901),
    [anon_sym_AMP] = ACTIONS(1901),
    [anon_sym_GT_EQ] = ACTIONS(2483),
    [anon_sym_LT_EQ] = ACTIONS(2483),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2485),
    [sym_predefined_type] = ACTIONS(2487),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(2489),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2491),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [393] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3000),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2756),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3043),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(6314),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(2858),
    [sym_property_pattern_clause] = STATE(2881),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6697),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(4164),
    [sym_postfix_unary_expression] = STATE(4165),
    [sym_prefix_unary_expression] = STATE(4165),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(4164),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(4165),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(4164),
    [sym_member_access_expression] = STATE(3482),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(4165),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(4164),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(4164),
    [sym_typeof_expression] = STATE(4164),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3482),
    [sym_literal] = STATE(4164),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2835),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(393),
    [sym_preproc_endregion] = STATE(393),
    [sym_preproc_line] = STATE(393),
    [sym_preproc_pragma] = STATE(393),
    [sym_preproc_nullable] = STATE(393),
    [sym_preproc_error] = STATE(393),
    [sym_preproc_warning] = STATE(393),
    [sym_preproc_define] = STATE(393),
    [sym_preproc_undef] = STATE(393),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(2493),
    [anon_sym_ref] = ACTIONS(2467),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2495),
    [anon_sym_GT] = ACTIONS(2495),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1675),
    [anon_sym_TILDE] = ACTIONS(1675),
    [anon_sym_PLUS_PLUS] = ACTIONS(1675),
    [anon_sym_DASH_DASH] = ACTIONS(1675),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1675),
    [anon_sym_AMP] = ACTIONS(1675),
    [anon_sym_GT_EQ] = ACTIONS(2497),
    [anon_sym_LT_EQ] = ACTIONS(2497),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2499),
    [sym_predefined_type] = ACTIONS(2339),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2501),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [394] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3211),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2756),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(2813),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(4137),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(2858),
    [sym_property_pattern_clause] = STATE(2881),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6722),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(4164),
    [sym_postfix_unary_expression] = STATE(4165),
    [sym_prefix_unary_expression] = STATE(4165),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(4164),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(4165),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(4164),
    [sym_member_access_expression] = STATE(3482),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(4165),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(4164),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(4164),
    [sym_typeof_expression] = STATE(4164),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3482),
    [sym_literal] = STATE(4164),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2776),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(394),
    [sym_preproc_endregion] = STATE(394),
    [sym_preproc_line] = STATE(394),
    [sym_preproc_pragma] = STATE(394),
    [sym_preproc_nullable] = STATE(394),
    [sym_preproc_error] = STATE(394),
    [sym_preproc_warning] = STATE(394),
    [sym_preproc_define] = STATE(394),
    [sym_preproc_undef] = STATE(394),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(2503),
    [anon_sym_ref] = ACTIONS(2447),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2505),
    [anon_sym_GT] = ACTIONS(2505),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1117),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_AMP] = ACTIONS(1117),
    [anon_sym_GT_EQ] = ACTIONS(2507),
    [anon_sym_LT_EQ] = ACTIONS(2507),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2453),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2349),
    [sym_predefined_type] = ACTIONS(2339),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2509),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [395] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3543),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2882),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3090),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(5026),
    [sym_constant_pattern] = STATE(5032),
    [sym_parenthesized_pattern] = STATE(5032),
    [sym_var_pattern] = STATE(5032),
    [sym_type_pattern] = STATE(5032),
    [sym_list_pattern] = STATE(5032),
    [sym_recursive_pattern] = STATE(5032),
    [sym_positional_pattern_clause] = STATE(3157),
    [sym_property_pattern_clause] = STATE(3428),
    [sym_relational_pattern] = STATE(5032),
    [sym_negated_pattern] = STATE(5032),
    [sym_and_pattern] = STATE(5032),
    [sym_or_pattern] = STATE(5032),
    [sym_declaration_pattern] = STATE(5032),
    [sym_expression] = STATE(6692),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(4990),
    [sym_postfix_unary_expression] = STATE(5037),
    [sym_prefix_unary_expression] = STATE(5037),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(4990),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5037),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(4990),
    [sym_member_access_expression] = STATE(3739),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5037),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(4990),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(4990),
    [sym_typeof_expression] = STATE(4990),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3739),
    [sym_literal] = STATE(4990),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2755),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(395),
    [sym_preproc_endregion] = STATE(395),
    [sym_preproc_line] = STATE(395),
    [sym_preproc_pragma] = STATE(395),
    [sym_preproc_nullable] = STATE(395),
    [sym_preproc_error] = STATE(395),
    [sym_preproc_warning] = STATE(395),
    [sym_preproc_define] = STATE(395),
    [sym_preproc_undef] = STATE(395),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(2477),
    [anon_sym_LPAREN] = ACTIONS(2479),
    [anon_sym_ref] = ACTIONS(2327),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2481),
    [anon_sym_GT] = ACTIONS(2481),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1901),
    [anon_sym_TILDE] = ACTIONS(1901),
    [anon_sym_PLUS_PLUS] = ACTIONS(1901),
    [anon_sym_DASH_DASH] = ACTIONS(1901),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1899),
    [anon_sym_DASH] = ACTIONS(1899),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1901),
    [anon_sym_AMP] = ACTIONS(1901),
    [anon_sym_GT_EQ] = ACTIONS(2483),
    [anon_sym_LT_EQ] = ACTIONS(2483),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2485),
    [sym_predefined_type] = ACTIONS(2487),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(2489),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2491),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [396] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3559),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2901),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3059),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(6552),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(3156),
    [sym_property_pattern_clause] = STATE(3380),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6741),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(4164),
    [sym_postfix_unary_expression] = STATE(4165),
    [sym_prefix_unary_expression] = STATE(4165),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(4164),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(4165),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(4164),
    [sym_member_access_expression] = STATE(3482),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(4165),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(4164),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(4164),
    [sym_typeof_expression] = STATE(4164),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3482),
    [sym_literal] = STATE(4164),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2755),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(396),
    [sym_preproc_endregion] = STATE(396),
    [sym_preproc_line] = STATE(396),
    [sym_preproc_pragma] = STATE(396),
    [sym_preproc_nullable] = STATE(396),
    [sym_preproc_error] = STATE(396),
    [sym_preproc_warning] = STATE(396),
    [sym_preproc_define] = STATE(396),
    [sym_preproc_undef] = STATE(396),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(2511),
    [anon_sym_ref] = ACTIONS(2327),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2513),
    [anon_sym_GT] = ACTIONS(2513),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1883),
    [anon_sym_TILDE] = ACTIONS(1883),
    [anon_sym_PLUS_PLUS] = ACTIONS(1883),
    [anon_sym_DASH_DASH] = ACTIONS(1883),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1881),
    [anon_sym_DASH] = ACTIONS(1881),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1883),
    [anon_sym_AMP] = ACTIONS(1883),
    [anon_sym_GT_EQ] = ACTIONS(2515),
    [anon_sym_LT_EQ] = ACTIONS(2515),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2349),
    [sym_predefined_type] = ACTIONS(2339),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2517),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [397] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3559),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2901),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3059),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(4198),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(3156),
    [sym_property_pattern_clause] = STATE(3380),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6741),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(4164),
    [sym_postfix_unary_expression] = STATE(4165),
    [sym_prefix_unary_expression] = STATE(4165),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(4164),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(4165),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(4164),
    [sym_member_access_expression] = STATE(3482),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(4165),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(4164),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(4164),
    [sym_typeof_expression] = STATE(4164),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3482),
    [sym_literal] = STATE(4164),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2755),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(397),
    [sym_preproc_endregion] = STATE(397),
    [sym_preproc_line] = STATE(397),
    [sym_preproc_pragma] = STATE(397),
    [sym_preproc_nullable] = STATE(397),
    [sym_preproc_error] = STATE(397),
    [sym_preproc_warning] = STATE(397),
    [sym_preproc_define] = STATE(397),
    [sym_preproc_undef] = STATE(397),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(2511),
    [anon_sym_ref] = ACTIONS(2327),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2513),
    [anon_sym_GT] = ACTIONS(2513),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1883),
    [anon_sym_TILDE] = ACTIONS(1883),
    [anon_sym_PLUS_PLUS] = ACTIONS(1883),
    [anon_sym_DASH_DASH] = ACTIONS(1883),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1881),
    [anon_sym_DASH] = ACTIONS(1881),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1883),
    [anon_sym_AMP] = ACTIONS(1883),
    [anon_sym_GT_EQ] = ACTIONS(2515),
    [anon_sym_LT_EQ] = ACTIONS(2515),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2349),
    [sym_predefined_type] = ACTIONS(2339),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2517),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [398] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3559),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2901),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3059),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(6424),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(3156),
    [sym_property_pattern_clause] = STATE(3380),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6741),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(4164),
    [sym_postfix_unary_expression] = STATE(4165),
    [sym_prefix_unary_expression] = STATE(4165),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(4164),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(4165),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(4164),
    [sym_member_access_expression] = STATE(3482),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(4165),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(4164),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(4164),
    [sym_typeof_expression] = STATE(4164),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3482),
    [sym_literal] = STATE(4164),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2755),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(398),
    [sym_preproc_endregion] = STATE(398),
    [sym_preproc_line] = STATE(398),
    [sym_preproc_pragma] = STATE(398),
    [sym_preproc_nullable] = STATE(398),
    [sym_preproc_error] = STATE(398),
    [sym_preproc_warning] = STATE(398),
    [sym_preproc_define] = STATE(398),
    [sym_preproc_undef] = STATE(398),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(2511),
    [anon_sym_ref] = ACTIONS(2327),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2513),
    [anon_sym_GT] = ACTIONS(2513),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1883),
    [anon_sym_TILDE] = ACTIONS(1883),
    [anon_sym_PLUS_PLUS] = ACTIONS(1883),
    [anon_sym_DASH_DASH] = ACTIONS(1883),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1881),
    [anon_sym_DASH] = ACTIONS(1881),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1883),
    [anon_sym_AMP] = ACTIONS(1883),
    [anon_sym_GT_EQ] = ACTIONS(2515),
    [anon_sym_LT_EQ] = ACTIONS(2515),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2349),
    [sym_predefined_type] = ACTIONS(2339),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2517),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [399] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3543),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2882),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3058),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(4995),
    [sym_constant_pattern] = STATE(5032),
    [sym_parenthesized_pattern] = STATE(5032),
    [sym_var_pattern] = STATE(5032),
    [sym_type_pattern] = STATE(5032),
    [sym_list_pattern] = STATE(5032),
    [sym_recursive_pattern] = STATE(5032),
    [sym_positional_pattern_clause] = STATE(3157),
    [sym_property_pattern_clause] = STATE(3428),
    [sym_relational_pattern] = STATE(5032),
    [sym_negated_pattern] = STATE(5032),
    [sym_and_pattern] = STATE(5032),
    [sym_or_pattern] = STATE(5032),
    [sym_declaration_pattern] = STATE(5032),
    [sym_expression] = STATE(6692),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(4990),
    [sym_postfix_unary_expression] = STATE(5037),
    [sym_prefix_unary_expression] = STATE(5037),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(4990),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5037),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(4990),
    [sym_member_access_expression] = STATE(3739),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5037),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(4990),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(4990),
    [sym_typeof_expression] = STATE(4990),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3739),
    [sym_literal] = STATE(4990),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2755),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(399),
    [sym_preproc_endregion] = STATE(399),
    [sym_preproc_line] = STATE(399),
    [sym_preproc_pragma] = STATE(399),
    [sym_preproc_nullable] = STATE(399),
    [sym_preproc_error] = STATE(399),
    [sym_preproc_warning] = STATE(399),
    [sym_preproc_define] = STATE(399),
    [sym_preproc_undef] = STATE(399),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(2477),
    [anon_sym_LPAREN] = ACTIONS(2479),
    [anon_sym_ref] = ACTIONS(2327),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2481),
    [anon_sym_GT] = ACTIONS(2481),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1901),
    [anon_sym_TILDE] = ACTIONS(1901),
    [anon_sym_PLUS_PLUS] = ACTIONS(1901),
    [anon_sym_DASH_DASH] = ACTIONS(1901),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1899),
    [anon_sym_DASH] = ACTIONS(1899),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1901),
    [anon_sym_AMP] = ACTIONS(1901),
    [anon_sym_GT_EQ] = ACTIONS(2483),
    [anon_sym_LT_EQ] = ACTIONS(2483),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2485),
    [sym_predefined_type] = ACTIONS(2487),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(2489),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2491),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [400] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3465),
    [sym_alias_qualified_name] = STATE(3486),
    [sym__simple_name] = STATE(2831),
    [sym_qualified_name] = STATE(3486),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(2974),
    [sym_implicit_type] = STATE(3330),
    [sym_array_type] = STATE(3488),
    [sym__array_base_type] = STATE(8756),
    [sym_nullable_type] = STATE(3489),
    [sym_pointer_type] = STATE(3489),
    [sym__pointer_base_type] = STATE(9221),
    [sym_function_pointer_type] = STATE(3489),
    [sym_ref_type] = STATE(3330),
    [sym_scoped_type] = STATE(3330),
    [sym_tuple_type] = STATE(3490),
    [sym_pattern] = STATE(5625),
    [sym_constant_pattern] = STATE(5744),
    [sym_parenthesized_pattern] = STATE(5744),
    [sym_var_pattern] = STATE(5744),
    [sym_type_pattern] = STATE(5744),
    [sym_list_pattern] = STATE(5744),
    [sym_recursive_pattern] = STATE(5744),
    [sym_positional_pattern_clause] = STATE(3076),
    [sym_property_pattern_clause] = STATE(3129),
    [sym_relational_pattern] = STATE(5744),
    [sym_negated_pattern] = STATE(5744),
    [sym_and_pattern] = STATE(5744),
    [sym_or_pattern] = STATE(5744),
    [sym_declaration_pattern] = STATE(5744),
    [sym_expression] = STATE(6695),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5469),
    [sym_postfix_unary_expression] = STATE(5470),
    [sym_prefix_unary_expression] = STATE(5470),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5469),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5470),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5469),
    [sym_member_access_expression] = STATE(3940),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5470),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(5469),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5469),
    [sym_typeof_expression] = STATE(5469),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3940),
    [sym_literal] = STATE(5469),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2792),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(400),
    [sym_preproc_endregion] = STATE(400),
    [sym_preproc_line] = STATE(400),
    [sym_preproc_pragma] = STATE(400),
    [sym_preproc_nullable] = STATE(400),
    [sym_preproc_error] = STATE(400),
    [sym_preproc_warning] = STATE(400),
    [sym_preproc_define] = STATE(400),
    [sym_preproc_undef] = STATE(400),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(2353),
    [anon_sym_LPAREN] = ACTIONS(2355),
    [anon_sym_ref] = ACTIONS(2357),
    [anon_sym_LBRACE] = ACTIONS(2359),
    [anon_sym_delegate] = ACTIONS(2361),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2363),
    [anon_sym_GT] = ACTIONS(2363),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1485),
    [anon_sym_TILDE] = ACTIONS(1485),
    [anon_sym_PLUS_PLUS] = ACTIONS(1485),
    [anon_sym_DASH_DASH] = ACTIONS(1485),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1483),
    [anon_sym_DASH] = ACTIONS(1483),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1485),
    [anon_sym_AMP] = ACTIONS(1485),
    [anon_sym_GT_EQ] = ACTIONS(2365),
    [anon_sym_LT_EQ] = ACTIONS(2365),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2367),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2369),
    [sym_predefined_type] = ACTIONS(2371),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(2373),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2375),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [401] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3549),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2915),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3088),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(6528),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(3141),
    [sym_property_pattern_clause] = STATE(3273),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6740),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(4164),
    [sym_postfix_unary_expression] = STATE(4165),
    [sym_prefix_unary_expression] = STATE(4165),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(4164),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(4165),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(4164),
    [sym_member_access_expression] = STATE(3482),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(4165),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(4164),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(4164),
    [sym_typeof_expression] = STATE(4164),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3482),
    [sym_literal] = STATE(4164),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2755),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(401),
    [sym_preproc_endregion] = STATE(401),
    [sym_preproc_line] = STATE(401),
    [sym_preproc_pragma] = STATE(401),
    [sym_preproc_nullable] = STATE(401),
    [sym_preproc_error] = STATE(401),
    [sym_preproc_warning] = STATE(401),
    [sym_preproc_define] = STATE(401),
    [sym_preproc_undef] = STATE(401),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(2437),
    [anon_sym_ref] = ACTIONS(2327),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2439),
    [anon_sym_GT] = ACTIONS(2439),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1809),
    [anon_sym_TILDE] = ACTIONS(1809),
    [anon_sym_PLUS_PLUS] = ACTIONS(1809),
    [anon_sym_DASH_DASH] = ACTIONS(1809),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1807),
    [anon_sym_DASH] = ACTIONS(1807),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1809),
    [anon_sym_AMP] = ACTIONS(1809),
    [anon_sym_GT_EQ] = ACTIONS(2441),
    [anon_sym_LT_EQ] = ACTIONS(2441),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2349),
    [sym_predefined_type] = ACTIONS(2339),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2443),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [402] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3549),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2915),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3088),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(4198),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(3141),
    [sym_property_pattern_clause] = STATE(3273),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6740),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(4164),
    [sym_postfix_unary_expression] = STATE(4165),
    [sym_prefix_unary_expression] = STATE(4165),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(4164),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(4165),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(4164),
    [sym_member_access_expression] = STATE(3482),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(4165),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(4164),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(4164),
    [sym_typeof_expression] = STATE(4164),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3482),
    [sym_literal] = STATE(4164),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2755),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(402),
    [sym_preproc_endregion] = STATE(402),
    [sym_preproc_line] = STATE(402),
    [sym_preproc_pragma] = STATE(402),
    [sym_preproc_nullable] = STATE(402),
    [sym_preproc_error] = STATE(402),
    [sym_preproc_warning] = STATE(402),
    [sym_preproc_define] = STATE(402),
    [sym_preproc_undef] = STATE(402),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(2437),
    [anon_sym_ref] = ACTIONS(2327),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2439),
    [anon_sym_GT] = ACTIONS(2439),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1809),
    [anon_sym_TILDE] = ACTIONS(1809),
    [anon_sym_PLUS_PLUS] = ACTIONS(1809),
    [anon_sym_DASH_DASH] = ACTIONS(1809),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1807),
    [anon_sym_DASH] = ACTIONS(1807),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1809),
    [anon_sym_AMP] = ACTIONS(1809),
    [anon_sym_GT_EQ] = ACTIONS(2441),
    [anon_sym_LT_EQ] = ACTIONS(2441),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2349),
    [sym_predefined_type] = ACTIONS(2339),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2443),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [403] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3000),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2756),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3031),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(6474),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(3124),
    [sym_property_pattern_clause] = STATE(3207),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6708),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(4164),
    [sym_postfix_unary_expression] = STATE(4165),
    [sym_prefix_unary_expression] = STATE(4165),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(4164),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(4165),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(4164),
    [sym_member_access_expression] = STATE(3482),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(4165),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(4164),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(4164),
    [sym_typeof_expression] = STATE(4164),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3482),
    [sym_literal] = STATE(4164),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2755),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(403),
    [sym_preproc_endregion] = STATE(403),
    [sym_preproc_line] = STATE(403),
    [sym_preproc_pragma] = STATE(403),
    [sym_preproc_nullable] = STATE(403),
    [sym_preproc_error] = STATE(403),
    [sym_preproc_warning] = STATE(403),
    [sym_preproc_define] = STATE(403),
    [sym_preproc_undef] = STATE(403),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(2325),
    [anon_sym_ref] = ACTIONS(2327),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2331),
    [anon_sym_GT] = ACTIONS(2331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1759),
    [anon_sym_TILDE] = ACTIONS(1759),
    [anon_sym_PLUS_PLUS] = ACTIONS(1759),
    [anon_sym_DASH_DASH] = ACTIONS(1759),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1757),
    [anon_sym_DASH] = ACTIONS(1757),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1759),
    [anon_sym_AMP] = ACTIONS(1759),
    [anon_sym_GT_EQ] = ACTIONS(2333),
    [anon_sym_LT_EQ] = ACTIONS(2333),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2337),
    [sym_predefined_type] = ACTIONS(2339),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2341),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [404] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(2999),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2761),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3048),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(6278),
    [sym_constant_pattern] = STATE(4086),
    [sym_parenthesized_pattern] = STATE(4086),
    [sym_var_pattern] = STATE(4086),
    [sym_type_pattern] = STATE(4086),
    [sym_list_pattern] = STATE(4086),
    [sym_recursive_pattern] = STATE(4086),
    [sym_positional_pattern_clause] = STATE(2840),
    [sym_property_pattern_clause] = STATE(2874),
    [sym_relational_pattern] = STATE(4086),
    [sym_negated_pattern] = STATE(4086),
    [sym_and_pattern] = STATE(4086),
    [sym_or_pattern] = STATE(4086),
    [sym_declaration_pattern] = STATE(4086),
    [sym_expression] = STATE(6707),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3989),
    [sym_postfix_unary_expression] = STATE(3990),
    [sym_prefix_unary_expression] = STATE(3990),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3989),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3990),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3989),
    [sym_member_access_expression] = STATE(3206),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3990),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3989),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3989),
    [sym_typeof_expression] = STATE(3989),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3206),
    [sym_literal] = STATE(3989),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2835),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(404),
    [sym_preproc_endregion] = STATE(404),
    [sym_preproc_line] = STATE(404),
    [sym_preproc_pragma] = STATE(404),
    [sym_preproc_nullable] = STATE(404),
    [sym_preproc_error] = STATE(404),
    [sym_preproc_warning] = STATE(404),
    [sym_preproc_define] = STATE(404),
    [sym_preproc_undef] = STATE(404),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(2377),
    [anon_sym_LPAREN] = ACTIONS(2519),
    [anon_sym_ref] = ACTIONS(2467),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2521),
    [anon_sym_GT] = ACTIONS(2521),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1659),
    [anon_sym_TILDE] = ACTIONS(1659),
    [anon_sym_PLUS_PLUS] = ACTIONS(1659),
    [anon_sym_DASH_DASH] = ACTIONS(1659),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1657),
    [anon_sym_DASH] = ACTIONS(1657),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1659),
    [anon_sym_AMP] = ACTIONS(1659),
    [anon_sym_GT_EQ] = ACTIONS(2523),
    [anon_sym_LT_EQ] = ACTIONS(2523),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2473),
    [sym_predefined_type] = ACTIONS(2387),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(2389),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2525),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [405] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3000),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2756),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3031),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(4198),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(3124),
    [sym_property_pattern_clause] = STATE(3207),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6708),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(4164),
    [sym_postfix_unary_expression] = STATE(4165),
    [sym_prefix_unary_expression] = STATE(4165),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(4164),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(4165),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(4164),
    [sym_member_access_expression] = STATE(3482),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(4165),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(4164),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(4164),
    [sym_typeof_expression] = STATE(4164),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3482),
    [sym_literal] = STATE(4164),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2755),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(405),
    [sym_preproc_endregion] = STATE(405),
    [sym_preproc_line] = STATE(405),
    [sym_preproc_pragma] = STATE(405),
    [sym_preproc_nullable] = STATE(405),
    [sym_preproc_error] = STATE(405),
    [sym_preproc_warning] = STATE(405),
    [sym_preproc_define] = STATE(405),
    [sym_preproc_undef] = STATE(405),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(2325),
    [anon_sym_ref] = ACTIONS(2327),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2331),
    [anon_sym_GT] = ACTIONS(2331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1759),
    [anon_sym_TILDE] = ACTIONS(1759),
    [anon_sym_PLUS_PLUS] = ACTIONS(1759),
    [anon_sym_DASH_DASH] = ACTIONS(1759),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1757),
    [anon_sym_DASH] = ACTIONS(1757),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1759),
    [anon_sym_AMP] = ACTIONS(1759),
    [anon_sym_GT_EQ] = ACTIONS(2333),
    [anon_sym_LT_EQ] = ACTIONS(2333),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2337),
    [sym_predefined_type] = ACTIONS(2339),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2341),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [406] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3543),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2882),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3090),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(5052),
    [sym_constant_pattern] = STATE(5032),
    [sym_parenthesized_pattern] = STATE(5032),
    [sym_var_pattern] = STATE(5032),
    [sym_type_pattern] = STATE(5032),
    [sym_list_pattern] = STATE(5032),
    [sym_recursive_pattern] = STATE(5032),
    [sym_positional_pattern_clause] = STATE(3157),
    [sym_property_pattern_clause] = STATE(3428),
    [sym_relational_pattern] = STATE(5032),
    [sym_negated_pattern] = STATE(5032),
    [sym_and_pattern] = STATE(5032),
    [sym_or_pattern] = STATE(5032),
    [sym_declaration_pattern] = STATE(5032),
    [sym_expression] = STATE(6692),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(4990),
    [sym_postfix_unary_expression] = STATE(5037),
    [sym_prefix_unary_expression] = STATE(5037),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(4990),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5037),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(4990),
    [sym_member_access_expression] = STATE(3739),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5037),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(4990),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(4990),
    [sym_typeof_expression] = STATE(4990),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3739),
    [sym_literal] = STATE(4990),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2755),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(406),
    [sym_preproc_endregion] = STATE(406),
    [sym_preproc_line] = STATE(406),
    [sym_preproc_pragma] = STATE(406),
    [sym_preproc_nullable] = STATE(406),
    [sym_preproc_error] = STATE(406),
    [sym_preproc_warning] = STATE(406),
    [sym_preproc_define] = STATE(406),
    [sym_preproc_undef] = STATE(406),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(2477),
    [anon_sym_LPAREN] = ACTIONS(2479),
    [anon_sym_ref] = ACTIONS(2327),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2481),
    [anon_sym_GT] = ACTIONS(2481),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1901),
    [anon_sym_TILDE] = ACTIONS(1901),
    [anon_sym_PLUS_PLUS] = ACTIONS(1901),
    [anon_sym_DASH_DASH] = ACTIONS(1901),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1899),
    [anon_sym_DASH] = ACTIONS(1899),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1901),
    [anon_sym_AMP] = ACTIONS(1901),
    [anon_sym_GT_EQ] = ACTIONS(2483),
    [anon_sym_LT_EQ] = ACTIONS(2483),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2485),
    [sym_predefined_type] = ACTIONS(2487),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(2489),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2491),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [407] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3000),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2756),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3031),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(6688),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(3124),
    [sym_property_pattern_clause] = STATE(3207),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6708),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(4164),
    [sym_postfix_unary_expression] = STATE(4165),
    [sym_prefix_unary_expression] = STATE(4165),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(4164),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(4165),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(4164),
    [sym_member_access_expression] = STATE(3482),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(4165),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(4164),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(4164),
    [sym_typeof_expression] = STATE(4164),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3482),
    [sym_literal] = STATE(4164),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2755),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(407),
    [sym_preproc_endregion] = STATE(407),
    [sym_preproc_line] = STATE(407),
    [sym_preproc_pragma] = STATE(407),
    [sym_preproc_nullable] = STATE(407),
    [sym_preproc_error] = STATE(407),
    [sym_preproc_warning] = STATE(407),
    [sym_preproc_define] = STATE(407),
    [sym_preproc_undef] = STATE(407),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(2325),
    [anon_sym_ref] = ACTIONS(2327),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2331),
    [anon_sym_GT] = ACTIONS(2331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1759),
    [anon_sym_TILDE] = ACTIONS(1759),
    [anon_sym_PLUS_PLUS] = ACTIONS(1759),
    [anon_sym_DASH_DASH] = ACTIONS(1759),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1757),
    [anon_sym_DASH] = ACTIONS(1757),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1759),
    [anon_sym_AMP] = ACTIONS(1759),
    [anon_sym_GT_EQ] = ACTIONS(2333),
    [anon_sym_LT_EQ] = ACTIONS(2333),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2337),
    [sym_predefined_type] = ACTIONS(2339),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2341),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [408] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3000),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2756),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(2814),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(5504),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(2858),
    [sym_property_pattern_clause] = STATE(2881),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6706),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(4164),
    [sym_postfix_unary_expression] = STATE(4165),
    [sym_prefix_unary_expression] = STATE(4165),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(4164),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(4165),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(4164),
    [sym_member_access_expression] = STATE(3482),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(4165),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(4164),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(4164),
    [sym_typeof_expression] = STATE(4164),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3482),
    [sym_literal] = STATE(4164),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2755),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(408),
    [sym_preproc_endregion] = STATE(408),
    [sym_preproc_line] = STATE(408),
    [sym_preproc_pragma] = STATE(408),
    [sym_preproc_nullable] = STATE(408),
    [sym_preproc_error] = STATE(408),
    [sym_preproc_warning] = STATE(408),
    [sym_preproc_define] = STATE(408),
    [sym_preproc_undef] = STATE(408),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(2457),
    [anon_sym_ref] = ACTIONS(2327),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2459),
    [anon_sym_GT] = ACTIONS(2459),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1379),
    [anon_sym_TILDE] = ACTIONS(1379),
    [anon_sym_PLUS_PLUS] = ACTIONS(1379),
    [anon_sym_DASH_DASH] = ACTIONS(1379),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1377),
    [anon_sym_DASH] = ACTIONS(1377),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1379),
    [anon_sym_AMP] = ACTIONS(1379),
    [anon_sym_GT_EQ] = ACTIONS(2461),
    [anon_sym_LT_EQ] = ACTIONS(2461),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2349),
    [sym_predefined_type] = ACTIONS(2339),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2463),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [409] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3000),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2756),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(2814),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(5472),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(2858),
    [sym_property_pattern_clause] = STATE(2881),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6706),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(4164),
    [sym_postfix_unary_expression] = STATE(4165),
    [sym_prefix_unary_expression] = STATE(4165),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(4164),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(4165),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(4164),
    [sym_member_access_expression] = STATE(3482),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(4165),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(4164),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(4164),
    [sym_typeof_expression] = STATE(4164),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3482),
    [sym_literal] = STATE(4164),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2755),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(409),
    [sym_preproc_endregion] = STATE(409),
    [sym_preproc_line] = STATE(409),
    [sym_preproc_pragma] = STATE(409),
    [sym_preproc_nullable] = STATE(409),
    [sym_preproc_error] = STATE(409),
    [sym_preproc_warning] = STATE(409),
    [sym_preproc_define] = STATE(409),
    [sym_preproc_undef] = STATE(409),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(2457),
    [anon_sym_ref] = ACTIONS(2327),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2459),
    [anon_sym_GT] = ACTIONS(2459),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1379),
    [anon_sym_TILDE] = ACTIONS(1379),
    [anon_sym_PLUS_PLUS] = ACTIONS(1379),
    [anon_sym_DASH_DASH] = ACTIONS(1379),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1377),
    [anon_sym_DASH] = ACTIONS(1377),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1379),
    [anon_sym_AMP] = ACTIONS(1379),
    [anon_sym_GT_EQ] = ACTIONS(2461),
    [anon_sym_LT_EQ] = ACTIONS(2461),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2349),
    [sym_predefined_type] = ACTIONS(2339),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2463),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [410] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3549),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2915),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3088),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(6461),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(3141),
    [sym_property_pattern_clause] = STATE(3273),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6740),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(4164),
    [sym_postfix_unary_expression] = STATE(4165),
    [sym_prefix_unary_expression] = STATE(4165),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(4164),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(4165),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(4164),
    [sym_member_access_expression] = STATE(3482),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(4165),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(4164),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(4164),
    [sym_typeof_expression] = STATE(4164),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3482),
    [sym_literal] = STATE(4164),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2755),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(410),
    [sym_preproc_endregion] = STATE(410),
    [sym_preproc_line] = STATE(410),
    [sym_preproc_pragma] = STATE(410),
    [sym_preproc_nullable] = STATE(410),
    [sym_preproc_error] = STATE(410),
    [sym_preproc_warning] = STATE(410),
    [sym_preproc_define] = STATE(410),
    [sym_preproc_undef] = STATE(410),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(2437),
    [anon_sym_ref] = ACTIONS(2327),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2439),
    [anon_sym_GT] = ACTIONS(2439),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1809),
    [anon_sym_TILDE] = ACTIONS(1809),
    [anon_sym_PLUS_PLUS] = ACTIONS(1809),
    [anon_sym_DASH_DASH] = ACTIONS(1809),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1807),
    [anon_sym_DASH] = ACTIONS(1807),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1809),
    [anon_sym_AMP] = ACTIONS(1809),
    [anon_sym_GT_EQ] = ACTIONS(2441),
    [anon_sym_LT_EQ] = ACTIONS(2441),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2349),
    [sym_predefined_type] = ACTIONS(2339),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2443),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [411] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3555),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2893),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3069),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(6542),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(3170),
    [sym_property_pattern_clause] = STATE(3373),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6736),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(4164),
    [sym_postfix_unary_expression] = STATE(4165),
    [sym_prefix_unary_expression] = STATE(4165),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(4164),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(4165),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(4164),
    [sym_member_access_expression] = STATE(3482),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(4165),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(4164),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(4164),
    [sym_typeof_expression] = STATE(4164),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3482),
    [sym_literal] = STATE(4164),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2755),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(411),
    [sym_preproc_endregion] = STATE(411),
    [sym_preproc_line] = STATE(411),
    [sym_preproc_pragma] = STATE(411),
    [sym_preproc_nullable] = STATE(411),
    [sym_preproc_error] = STATE(411),
    [sym_preproc_warning] = STATE(411),
    [sym_preproc_define] = STATE(411),
    [sym_preproc_undef] = STATE(411),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(2343),
    [anon_sym_ref] = ACTIONS(2327),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2345),
    [anon_sym_GT] = ACTIONS(2345),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1863),
    [anon_sym_TILDE] = ACTIONS(1863),
    [anon_sym_PLUS_PLUS] = ACTIONS(1863),
    [anon_sym_DASH_DASH] = ACTIONS(1863),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1861),
    [anon_sym_DASH] = ACTIONS(1861),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1863),
    [anon_sym_AMP] = ACTIONS(1863),
    [anon_sym_GT_EQ] = ACTIONS(2347),
    [anon_sym_LT_EQ] = ACTIONS(2347),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2349),
    [sym_predefined_type] = ACTIONS(2339),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2351),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [412] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3541),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2876),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3053),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(4927),
    [sym_constant_pattern] = STATE(4557),
    [sym_parenthesized_pattern] = STATE(4557),
    [sym_var_pattern] = STATE(4557),
    [sym_type_pattern] = STATE(4557),
    [sym_list_pattern] = STATE(4557),
    [sym_recursive_pattern] = STATE(4557),
    [sym_positional_pattern_clause] = STATE(3128),
    [sym_property_pattern_clause] = STATE(3222),
    [sym_relational_pattern] = STATE(4557),
    [sym_negated_pattern] = STATE(4557),
    [sym_and_pattern] = STATE(4557),
    [sym_or_pattern] = STATE(4557),
    [sym_declaration_pattern] = STATE(4557),
    [sym_expression] = STATE(6747),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(4559),
    [sym_postfix_unary_expression] = STATE(4560),
    [sym_prefix_unary_expression] = STATE(4560),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(4559),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(4560),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(4559),
    [sym_member_access_expression] = STATE(3583),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(4560),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(4559),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(4559),
    [sym_typeof_expression] = STATE(4559),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3583),
    [sym_literal] = STATE(4559),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2755),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(412),
    [sym_preproc_endregion] = STATE(412),
    [sym_preproc_line] = STATE(412),
    [sym_preproc_pragma] = STATE(412),
    [sym_preproc_nullable] = STATE(412),
    [sym_preproc_error] = STATE(412),
    [sym_preproc_warning] = STATE(412),
    [sym_preproc_define] = STATE(412),
    [sym_preproc_undef] = STATE(412),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(2413),
    [anon_sym_LPAREN] = ACTIONS(2429),
    [anon_sym_ref] = ACTIONS(2327),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2431),
    [anon_sym_GT] = ACTIONS(2431),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1701),
    [anon_sym_TILDE] = ACTIONS(1701),
    [anon_sym_PLUS_PLUS] = ACTIONS(1701),
    [anon_sym_DASH_DASH] = ACTIONS(1701),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1699),
    [anon_sym_DASH] = ACTIONS(1699),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1701),
    [anon_sym_AMP] = ACTIONS(1701),
    [anon_sym_GT_EQ] = ACTIONS(2433),
    [anon_sym_LT_EQ] = ACTIONS(2433),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2421),
    [sym_predefined_type] = ACTIONS(2423),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(2425),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2435),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [413] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3537),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2852),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3047),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(6199),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(3103),
    [sym_property_pattern_clause] = STATE(3159),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6715),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(4164),
    [sym_postfix_unary_expression] = STATE(4165),
    [sym_prefix_unary_expression] = STATE(4165),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(4164),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(4165),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(4164),
    [sym_member_access_expression] = STATE(3482),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(4165),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(4164),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(4164),
    [sym_typeof_expression] = STATE(4164),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3482),
    [sym_literal] = STATE(4164),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2776),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(413),
    [sym_preproc_endregion] = STATE(413),
    [sym_preproc_line] = STATE(413),
    [sym_preproc_pragma] = STATE(413),
    [sym_preproc_nullable] = STATE(413),
    [sym_preproc_error] = STATE(413),
    [sym_preproc_warning] = STATE(413),
    [sym_preproc_define] = STATE(413),
    [sym_preproc_undef] = STATE(413),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(2527),
    [anon_sym_ref] = ACTIONS(2447),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2403),
    [anon_sym_GT] = ACTIONS(2403),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1629),
    [anon_sym_TILDE] = ACTIONS(1629),
    [anon_sym_PLUS_PLUS] = ACTIONS(1629),
    [anon_sym_DASH_DASH] = ACTIONS(1629),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1627),
    [anon_sym_DASH] = ACTIONS(1627),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1629),
    [anon_sym_AMP] = ACTIONS(1629),
    [anon_sym_GT_EQ] = ACTIONS(2405),
    [anon_sym_LT_EQ] = ACTIONS(2405),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2453),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2349),
    [sym_predefined_type] = ACTIONS(2339),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2529),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [414] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3537),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2852),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3047),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(4198),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(3103),
    [sym_property_pattern_clause] = STATE(3159),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6715),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(4164),
    [sym_postfix_unary_expression] = STATE(4165),
    [sym_prefix_unary_expression] = STATE(4165),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(4164),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(4165),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(4164),
    [sym_member_access_expression] = STATE(3482),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(4165),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(4164),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(4164),
    [sym_typeof_expression] = STATE(4164),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3482),
    [sym_literal] = STATE(4164),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2776),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(414),
    [sym_preproc_endregion] = STATE(414),
    [sym_preproc_line] = STATE(414),
    [sym_preproc_pragma] = STATE(414),
    [sym_preproc_nullable] = STATE(414),
    [sym_preproc_error] = STATE(414),
    [sym_preproc_warning] = STATE(414),
    [sym_preproc_define] = STATE(414),
    [sym_preproc_undef] = STATE(414),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(2527),
    [anon_sym_ref] = ACTIONS(2447),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2403),
    [anon_sym_GT] = ACTIONS(2403),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1629),
    [anon_sym_TILDE] = ACTIONS(1629),
    [anon_sym_PLUS_PLUS] = ACTIONS(1629),
    [anon_sym_DASH_DASH] = ACTIONS(1629),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1627),
    [anon_sym_DASH] = ACTIONS(1627),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1629),
    [anon_sym_AMP] = ACTIONS(1629),
    [anon_sym_GT_EQ] = ACTIONS(2405),
    [anon_sym_LT_EQ] = ACTIONS(2405),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2453),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2349),
    [sym_predefined_type] = ACTIONS(2339),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2529),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [415] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3537),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2852),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3047),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(6157),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(3103),
    [sym_property_pattern_clause] = STATE(3159),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6715),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(4164),
    [sym_postfix_unary_expression] = STATE(4165),
    [sym_prefix_unary_expression] = STATE(4165),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(4164),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(4165),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(4164),
    [sym_member_access_expression] = STATE(3482),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(4165),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(4164),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(4164),
    [sym_typeof_expression] = STATE(4164),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3482),
    [sym_literal] = STATE(4164),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2776),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(415),
    [sym_preproc_endregion] = STATE(415),
    [sym_preproc_line] = STATE(415),
    [sym_preproc_pragma] = STATE(415),
    [sym_preproc_nullable] = STATE(415),
    [sym_preproc_error] = STATE(415),
    [sym_preproc_warning] = STATE(415),
    [sym_preproc_define] = STATE(415),
    [sym_preproc_undef] = STATE(415),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(2527),
    [anon_sym_ref] = ACTIONS(2447),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2403),
    [anon_sym_GT] = ACTIONS(2403),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1629),
    [anon_sym_TILDE] = ACTIONS(1629),
    [anon_sym_PLUS_PLUS] = ACTIONS(1629),
    [anon_sym_DASH_DASH] = ACTIONS(1629),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1627),
    [anon_sym_DASH] = ACTIONS(1627),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1629),
    [anon_sym_AMP] = ACTIONS(1629),
    [anon_sym_GT_EQ] = ACTIONS(2405),
    [anon_sym_LT_EQ] = ACTIONS(2405),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2453),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2349),
    [sym_predefined_type] = ACTIONS(2339),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2529),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [416] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3223),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2761),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(2795),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(3987),
    [sym_constant_pattern] = STATE(4086),
    [sym_parenthesized_pattern] = STATE(4086),
    [sym_var_pattern] = STATE(4086),
    [sym_type_pattern] = STATE(4086),
    [sym_list_pattern] = STATE(4086),
    [sym_recursive_pattern] = STATE(4086),
    [sym_positional_pattern_clause] = STATE(2840),
    [sym_property_pattern_clause] = STATE(2874),
    [sym_relational_pattern] = STATE(4086),
    [sym_negated_pattern] = STATE(4086),
    [sym_and_pattern] = STATE(4086),
    [sym_or_pattern] = STATE(4086),
    [sym_declaration_pattern] = STATE(4086),
    [sym_expression] = STATE(6729),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3989),
    [sym_postfix_unary_expression] = STATE(3990),
    [sym_prefix_unary_expression] = STATE(3990),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3989),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3990),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3989),
    [sym_member_access_expression] = STATE(3206),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3990),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3989),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3989),
    [sym_typeof_expression] = STATE(3989),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3206),
    [sym_literal] = STATE(3989),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2776),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(416),
    [sym_preproc_endregion] = STATE(416),
    [sym_preproc_line] = STATE(416),
    [sym_preproc_pragma] = STATE(416),
    [sym_preproc_nullable] = STATE(416),
    [sym_preproc_error] = STATE(416),
    [sym_preproc_warning] = STATE(416),
    [sym_preproc_define] = STATE(416),
    [sym_preproc_undef] = STATE(416),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(2377),
    [anon_sym_LPAREN] = ACTIONS(2531),
    [anon_sym_ref] = ACTIONS(2447),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2533),
    [anon_sym_GT] = ACTIONS(2533),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1363),
    [anon_sym_TILDE] = ACTIONS(1363),
    [anon_sym_PLUS_PLUS] = ACTIONS(1363),
    [anon_sym_DASH_DASH] = ACTIONS(1363),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1361),
    [anon_sym_DASH] = ACTIONS(1361),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1363),
    [anon_sym_AMP] = ACTIONS(1363),
    [anon_sym_GT_EQ] = ACTIONS(2535),
    [anon_sym_LT_EQ] = ACTIONS(2535),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2453),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2385),
    [sym_predefined_type] = ACTIONS(2387),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(2389),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2537),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [417] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3545),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2917),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3079),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(5000),
    [sym_constant_pattern] = STATE(5032),
    [sym_parenthesized_pattern] = STATE(5032),
    [sym_var_pattern] = STATE(5032),
    [sym_type_pattern] = STATE(5032),
    [sym_list_pattern] = STATE(5032),
    [sym_recursive_pattern] = STATE(5032),
    [sym_positional_pattern_clause] = STATE(3143),
    [sym_property_pattern_clause] = STATE(3360),
    [sym_relational_pattern] = STATE(5032),
    [sym_negated_pattern] = STATE(5032),
    [sym_and_pattern] = STATE(5032),
    [sym_or_pattern] = STATE(5032),
    [sym_declaration_pattern] = STATE(5032),
    [sym_expression] = STATE(6735),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(4990),
    [sym_postfix_unary_expression] = STATE(5037),
    [sym_prefix_unary_expression] = STATE(5037),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(4990),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5037),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(4990),
    [sym_member_access_expression] = STATE(3739),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5037),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(4990),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(4990),
    [sym_typeof_expression] = STATE(4990),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3739),
    [sym_literal] = STATE(4990),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2755),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(417),
    [sym_preproc_endregion] = STATE(417),
    [sym_preproc_line] = STATE(417),
    [sym_preproc_pragma] = STATE(417),
    [sym_preproc_nullable] = STATE(417),
    [sym_preproc_error] = STATE(417),
    [sym_preproc_warning] = STATE(417),
    [sym_preproc_define] = STATE(417),
    [sym_preproc_undef] = STATE(417),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(2477),
    [anon_sym_LPAREN] = ACTIONS(2539),
    [anon_sym_ref] = ACTIONS(2327),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2541),
    [anon_sym_GT] = ACTIONS(2541),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1937),
    [anon_sym_TILDE] = ACTIONS(1937),
    [anon_sym_PLUS_PLUS] = ACTIONS(1937),
    [anon_sym_DASH_DASH] = ACTIONS(1937),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1935),
    [anon_sym_DASH] = ACTIONS(1935),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1937),
    [anon_sym_AMP] = ACTIONS(1937),
    [anon_sym_GT_EQ] = ACTIONS(2543),
    [anon_sym_LT_EQ] = ACTIONS(2543),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2545),
    [sym_predefined_type] = ACTIONS(2487),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(2489),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2547),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [418] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3536),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2859),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3032),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(4699),
    [sym_constant_pattern] = STATE(4557),
    [sym_parenthesized_pattern] = STATE(4557),
    [sym_var_pattern] = STATE(4557),
    [sym_type_pattern] = STATE(4557),
    [sym_list_pattern] = STATE(4557),
    [sym_recursive_pattern] = STATE(4557),
    [sym_positional_pattern_clause] = STATE(3127),
    [sym_property_pattern_clause] = STATE(3184),
    [sym_relational_pattern] = STATE(4557),
    [sym_negated_pattern] = STATE(4557),
    [sym_and_pattern] = STATE(4557),
    [sym_or_pattern] = STATE(4557),
    [sym_declaration_pattern] = STATE(4557),
    [sym_expression] = STATE(6744),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(4559),
    [sym_postfix_unary_expression] = STATE(4560),
    [sym_prefix_unary_expression] = STATE(4560),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(4559),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(4560),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(4559),
    [sym_member_access_expression] = STATE(3583),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(4560),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(4559),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(4559),
    [sym_typeof_expression] = STATE(4559),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3583),
    [sym_literal] = STATE(4559),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2755),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(418),
    [sym_preproc_endregion] = STATE(418),
    [sym_preproc_line] = STATE(418),
    [sym_preproc_pragma] = STATE(418),
    [sym_preproc_nullable] = STATE(418),
    [sym_preproc_error] = STATE(418),
    [sym_preproc_warning] = STATE(418),
    [sym_preproc_define] = STATE(418),
    [sym_preproc_undef] = STATE(418),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(2413),
    [anon_sym_LPAREN] = ACTIONS(2415),
    [anon_sym_ref] = ACTIONS(2327),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2417),
    [anon_sym_GT] = ACTIONS(2417),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1775),
    [anon_sym_TILDE] = ACTIONS(1775),
    [anon_sym_PLUS_PLUS] = ACTIONS(1775),
    [anon_sym_DASH_DASH] = ACTIONS(1775),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1773),
    [anon_sym_DASH] = ACTIONS(1773),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1775),
    [anon_sym_AMP] = ACTIONS(1775),
    [anon_sym_GT_EQ] = ACTIONS(2419),
    [anon_sym_LT_EQ] = ACTIONS(2419),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2421),
    [sym_predefined_type] = ACTIONS(2423),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(2425),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2427),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [419] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3465),
    [sym_alias_qualified_name] = STATE(3486),
    [sym__simple_name] = STATE(2831),
    [sym_qualified_name] = STATE(3486),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(2959),
    [sym_implicit_type] = STATE(3330),
    [sym_array_type] = STATE(3488),
    [sym__array_base_type] = STATE(8756),
    [sym_nullable_type] = STATE(3489),
    [sym_pointer_type] = STATE(3489),
    [sym__pointer_base_type] = STATE(9221),
    [sym_function_pointer_type] = STATE(3489),
    [sym_ref_type] = STATE(3330),
    [sym_scoped_type] = STATE(3330),
    [sym_tuple_type] = STATE(3490),
    [sym_pattern] = STATE(5509),
    [sym_constant_pattern] = STATE(5744),
    [sym_parenthesized_pattern] = STATE(5744),
    [sym_var_pattern] = STATE(5744),
    [sym_type_pattern] = STATE(5744),
    [sym_list_pattern] = STATE(5744),
    [sym_recursive_pattern] = STATE(5744),
    [sym_positional_pattern_clause] = STATE(3076),
    [sym_property_pattern_clause] = STATE(3129),
    [sym_relational_pattern] = STATE(5744),
    [sym_negated_pattern] = STATE(5744),
    [sym_and_pattern] = STATE(5744),
    [sym_or_pattern] = STATE(5744),
    [sym_declaration_pattern] = STATE(5744),
    [sym_expression] = STATE(6695),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5469),
    [sym_postfix_unary_expression] = STATE(5470),
    [sym_prefix_unary_expression] = STATE(5470),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5469),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5470),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5469),
    [sym_member_access_expression] = STATE(3940),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5470),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(5469),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5469),
    [sym_typeof_expression] = STATE(5469),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3940),
    [sym_literal] = STATE(5469),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2792),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(419),
    [sym_preproc_endregion] = STATE(419),
    [sym_preproc_line] = STATE(419),
    [sym_preproc_pragma] = STATE(419),
    [sym_preproc_nullable] = STATE(419),
    [sym_preproc_error] = STATE(419),
    [sym_preproc_warning] = STATE(419),
    [sym_preproc_define] = STATE(419),
    [sym_preproc_undef] = STATE(419),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(2353),
    [anon_sym_LPAREN] = ACTIONS(2355),
    [anon_sym_ref] = ACTIONS(2357),
    [anon_sym_LBRACE] = ACTIONS(2359),
    [anon_sym_delegate] = ACTIONS(2361),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2363),
    [anon_sym_GT] = ACTIONS(2363),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1485),
    [anon_sym_TILDE] = ACTIONS(1485),
    [anon_sym_PLUS_PLUS] = ACTIONS(1485),
    [anon_sym_DASH_DASH] = ACTIONS(1485),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1483),
    [anon_sym_DASH] = ACTIONS(1483),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1485),
    [anon_sym_AMP] = ACTIONS(1485),
    [anon_sym_GT_EQ] = ACTIONS(2365),
    [anon_sym_LT_EQ] = ACTIONS(2365),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2367),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2369),
    [sym_predefined_type] = ACTIONS(2371),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(2373),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2375),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [420] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3223),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2761),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(2805),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(5298),
    [sym_constant_pattern] = STATE(4086),
    [sym_parenthesized_pattern] = STATE(4086),
    [sym_var_pattern] = STATE(4086),
    [sym_type_pattern] = STATE(4086),
    [sym_list_pattern] = STATE(4086),
    [sym_recursive_pattern] = STATE(4086),
    [sym_positional_pattern_clause] = STATE(2840),
    [sym_property_pattern_clause] = STATE(2874),
    [sym_relational_pattern] = STATE(4086),
    [sym_negated_pattern] = STATE(4086),
    [sym_and_pattern] = STATE(4086),
    [sym_or_pattern] = STATE(4086),
    [sym_declaration_pattern] = STATE(4086),
    [sym_expression] = STATE(6729),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3989),
    [sym_postfix_unary_expression] = STATE(3990),
    [sym_prefix_unary_expression] = STATE(3990),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3989),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3990),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3989),
    [sym_member_access_expression] = STATE(3206),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3990),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3989),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3989),
    [sym_typeof_expression] = STATE(3989),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3206),
    [sym_literal] = STATE(3989),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2776),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(420),
    [sym_preproc_endregion] = STATE(420),
    [sym_preproc_line] = STATE(420),
    [sym_preproc_pragma] = STATE(420),
    [sym_preproc_nullable] = STATE(420),
    [sym_preproc_error] = STATE(420),
    [sym_preproc_warning] = STATE(420),
    [sym_preproc_define] = STATE(420),
    [sym_preproc_undef] = STATE(420),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(2377),
    [anon_sym_LPAREN] = ACTIONS(2531),
    [anon_sym_ref] = ACTIONS(2447),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2533),
    [anon_sym_GT] = ACTIONS(2533),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1363),
    [anon_sym_TILDE] = ACTIONS(1363),
    [anon_sym_PLUS_PLUS] = ACTIONS(1363),
    [anon_sym_DASH_DASH] = ACTIONS(1363),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1361),
    [anon_sym_DASH] = ACTIONS(1361),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1363),
    [anon_sym_AMP] = ACTIONS(1363),
    [anon_sym_GT_EQ] = ACTIONS(2535),
    [anon_sym_LT_EQ] = ACTIONS(2535),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2453),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2385),
    [sym_predefined_type] = ACTIONS(2387),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(2389),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2537),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [421] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3541),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2876),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3053),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(4613),
    [sym_constant_pattern] = STATE(4557),
    [sym_parenthesized_pattern] = STATE(4557),
    [sym_var_pattern] = STATE(4557),
    [sym_type_pattern] = STATE(4557),
    [sym_list_pattern] = STATE(4557),
    [sym_recursive_pattern] = STATE(4557),
    [sym_positional_pattern_clause] = STATE(3128),
    [sym_property_pattern_clause] = STATE(3222),
    [sym_relational_pattern] = STATE(4557),
    [sym_negated_pattern] = STATE(4557),
    [sym_and_pattern] = STATE(4557),
    [sym_or_pattern] = STATE(4557),
    [sym_declaration_pattern] = STATE(4557),
    [sym_expression] = STATE(6747),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(4559),
    [sym_postfix_unary_expression] = STATE(4560),
    [sym_prefix_unary_expression] = STATE(4560),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(4559),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(4560),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(4559),
    [sym_member_access_expression] = STATE(3583),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(4560),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(4559),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(4559),
    [sym_typeof_expression] = STATE(4559),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3583),
    [sym_literal] = STATE(4559),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2755),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(421),
    [sym_preproc_endregion] = STATE(421),
    [sym_preproc_line] = STATE(421),
    [sym_preproc_pragma] = STATE(421),
    [sym_preproc_nullable] = STATE(421),
    [sym_preproc_error] = STATE(421),
    [sym_preproc_warning] = STATE(421),
    [sym_preproc_define] = STATE(421),
    [sym_preproc_undef] = STATE(421),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(2413),
    [anon_sym_LPAREN] = ACTIONS(2429),
    [anon_sym_ref] = ACTIONS(2327),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2431),
    [anon_sym_GT] = ACTIONS(2431),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1701),
    [anon_sym_TILDE] = ACTIONS(1701),
    [anon_sym_PLUS_PLUS] = ACTIONS(1701),
    [anon_sym_DASH_DASH] = ACTIONS(1701),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1699),
    [anon_sym_DASH] = ACTIONS(1699),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1701),
    [anon_sym_AMP] = ACTIONS(1701),
    [anon_sym_GT_EQ] = ACTIONS(2433),
    [anon_sym_LT_EQ] = ACTIONS(2433),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2421),
    [sym_predefined_type] = ACTIONS(2423),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(2425),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2435),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [422] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3541),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2876),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3053),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(4925),
    [sym_constant_pattern] = STATE(4557),
    [sym_parenthesized_pattern] = STATE(4557),
    [sym_var_pattern] = STATE(4557),
    [sym_type_pattern] = STATE(4557),
    [sym_list_pattern] = STATE(4557),
    [sym_recursive_pattern] = STATE(4557),
    [sym_positional_pattern_clause] = STATE(3128),
    [sym_property_pattern_clause] = STATE(3222),
    [sym_relational_pattern] = STATE(4557),
    [sym_negated_pattern] = STATE(4557),
    [sym_and_pattern] = STATE(4557),
    [sym_or_pattern] = STATE(4557),
    [sym_declaration_pattern] = STATE(4557),
    [sym_expression] = STATE(6747),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(4559),
    [sym_postfix_unary_expression] = STATE(4560),
    [sym_prefix_unary_expression] = STATE(4560),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(4559),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(4560),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(4559),
    [sym_member_access_expression] = STATE(3583),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(4560),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(4559),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(4559),
    [sym_typeof_expression] = STATE(4559),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3583),
    [sym_literal] = STATE(4559),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2755),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(422),
    [sym_preproc_endregion] = STATE(422),
    [sym_preproc_line] = STATE(422),
    [sym_preproc_pragma] = STATE(422),
    [sym_preproc_nullable] = STATE(422),
    [sym_preproc_error] = STATE(422),
    [sym_preproc_warning] = STATE(422),
    [sym_preproc_define] = STATE(422),
    [sym_preproc_undef] = STATE(422),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(2413),
    [anon_sym_LPAREN] = ACTIONS(2429),
    [anon_sym_ref] = ACTIONS(2327),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2431),
    [anon_sym_GT] = ACTIONS(2431),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1701),
    [anon_sym_TILDE] = ACTIONS(1701),
    [anon_sym_PLUS_PLUS] = ACTIONS(1701),
    [anon_sym_DASH_DASH] = ACTIONS(1701),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1699),
    [anon_sym_DASH] = ACTIONS(1699),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1701),
    [anon_sym_AMP] = ACTIONS(1701),
    [anon_sym_GT_EQ] = ACTIONS(2433),
    [anon_sym_LT_EQ] = ACTIONS(2433),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2421),
    [sym_predefined_type] = ACTIONS(2423),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(2425),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2435),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [423] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3548),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2918),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3072),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(6196),
    [sym_constant_pattern] = STATE(4086),
    [sym_parenthesized_pattern] = STATE(4086),
    [sym_var_pattern] = STATE(4086),
    [sym_type_pattern] = STATE(4086),
    [sym_list_pattern] = STATE(4086),
    [sym_recursive_pattern] = STATE(4086),
    [sym_positional_pattern_clause] = STATE(3148),
    [sym_property_pattern_clause] = STATE(3407),
    [sym_relational_pattern] = STATE(4086),
    [sym_negated_pattern] = STATE(4086),
    [sym_and_pattern] = STATE(4086),
    [sym_or_pattern] = STATE(4086),
    [sym_declaration_pattern] = STATE(4086),
    [sym_expression] = STATE(6694),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3989),
    [sym_postfix_unary_expression] = STATE(3990),
    [sym_prefix_unary_expression] = STATE(3990),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3989),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3990),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3989),
    [sym_member_access_expression] = STATE(3206),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3990),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3989),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3989),
    [sym_typeof_expression] = STATE(3989),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3206),
    [sym_literal] = STATE(3989),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2755),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(423),
    [sym_preproc_endregion] = STATE(423),
    [sym_preproc_line] = STATE(423),
    [sym_preproc_pragma] = STATE(423),
    [sym_preproc_nullable] = STATE(423),
    [sym_preproc_error] = STATE(423),
    [sym_preproc_warning] = STATE(423),
    [sym_preproc_define] = STATE(423),
    [sym_preproc_undef] = STATE(423),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(2377),
    [anon_sym_LPAREN] = ACTIONS(2549),
    [anon_sym_ref] = ACTIONS(2327),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2551),
    [anon_sym_GT] = ACTIONS(2551),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1919),
    [anon_sym_TILDE] = ACTIONS(1919),
    [anon_sym_PLUS_PLUS] = ACTIONS(1919),
    [anon_sym_DASH_DASH] = ACTIONS(1919),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1917),
    [anon_sym_DASH] = ACTIONS(1917),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1919),
    [anon_sym_AMP] = ACTIONS(1919),
    [anon_sym_GT_EQ] = ACTIONS(2553),
    [anon_sym_LT_EQ] = ACTIONS(2553),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2385),
    [sym_predefined_type] = ACTIONS(2387),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(2389),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2555),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [424] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3554),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2908),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3077),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(6304),
    [sym_constant_pattern] = STATE(4086),
    [sym_parenthesized_pattern] = STATE(4086),
    [sym_var_pattern] = STATE(4086),
    [sym_type_pattern] = STATE(4086),
    [sym_list_pattern] = STATE(4086),
    [sym_recursive_pattern] = STATE(4086),
    [sym_positional_pattern_clause] = STATE(3151),
    [sym_property_pattern_clause] = STATE(3422),
    [sym_relational_pattern] = STATE(4086),
    [sym_negated_pattern] = STATE(4086),
    [sym_and_pattern] = STATE(4086),
    [sym_or_pattern] = STATE(4086),
    [sym_declaration_pattern] = STATE(4086),
    [sym_expression] = STATE(6701),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3989),
    [sym_postfix_unary_expression] = STATE(3990),
    [sym_prefix_unary_expression] = STATE(3990),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3989),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3990),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3989),
    [sym_member_access_expression] = STATE(3206),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3990),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3989),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3989),
    [sym_typeof_expression] = STATE(3989),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3206),
    [sym_literal] = STATE(3989),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2755),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(424),
    [sym_preproc_endregion] = STATE(424),
    [sym_preproc_line] = STATE(424),
    [sym_preproc_pragma] = STATE(424),
    [sym_preproc_nullable] = STATE(424),
    [sym_preproc_error] = STATE(424),
    [sym_preproc_warning] = STATE(424),
    [sym_preproc_define] = STATE(424),
    [sym_preproc_undef] = STATE(424),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(2377),
    [anon_sym_LPAREN] = ACTIONS(2557),
    [anon_sym_ref] = ACTIONS(2327),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2559),
    [anon_sym_GT] = ACTIONS(2559),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1827),
    [anon_sym_TILDE] = ACTIONS(1827),
    [anon_sym_PLUS_PLUS] = ACTIONS(1827),
    [anon_sym_DASH_DASH] = ACTIONS(1827),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1825),
    [anon_sym_DASH] = ACTIONS(1825),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1827),
    [anon_sym_AMP] = ACTIONS(1827),
    [anon_sym_GT_EQ] = ACTIONS(2561),
    [anon_sym_LT_EQ] = ACTIONS(2561),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2385),
    [sym_predefined_type] = ACTIONS(2387),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(2389),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2563),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [425] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3559),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2901),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3074),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(6550),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(3156),
    [sym_property_pattern_clause] = STATE(3380),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6741),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(4164),
    [sym_postfix_unary_expression] = STATE(4165),
    [sym_prefix_unary_expression] = STATE(4165),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(4164),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(4165),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(4164),
    [sym_member_access_expression] = STATE(3482),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(4165),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(4164),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(4164),
    [sym_typeof_expression] = STATE(4164),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3482),
    [sym_literal] = STATE(4164),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2755),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(425),
    [sym_preproc_endregion] = STATE(425),
    [sym_preproc_line] = STATE(425),
    [sym_preproc_pragma] = STATE(425),
    [sym_preproc_nullable] = STATE(425),
    [sym_preproc_error] = STATE(425),
    [sym_preproc_warning] = STATE(425),
    [sym_preproc_define] = STATE(425),
    [sym_preproc_undef] = STATE(425),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(2511),
    [anon_sym_ref] = ACTIONS(2327),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2513),
    [anon_sym_GT] = ACTIONS(2513),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1883),
    [anon_sym_TILDE] = ACTIONS(1883),
    [anon_sym_PLUS_PLUS] = ACTIONS(1883),
    [anon_sym_DASH_DASH] = ACTIONS(1883),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1881),
    [anon_sym_DASH] = ACTIONS(1881),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1883),
    [anon_sym_AMP] = ACTIONS(1883),
    [anon_sym_GT_EQ] = ACTIONS(2515),
    [anon_sym_LT_EQ] = ACTIONS(2515),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2349),
    [sym_predefined_type] = ACTIONS(2339),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2517),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [426] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2802),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(5351),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_pattern] = STATE(4198),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6158),
    [sym_property_pattern_clause] = STATE(6724),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6719),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5302),
    [sym_postfix_unary_expression] = STATE(5343),
    [sym_prefix_unary_expression] = STATE(5343),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5302),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5343),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5302),
    [sym_member_access_expression] = STATE(3862),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5343),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(5302),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5302),
    [sym_typeof_expression] = STATE(5302),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3862),
    [sym_literal] = STATE(5302),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(426),
    [sym_preproc_endregion] = STATE(426),
    [sym_preproc_line] = STATE(426),
    [sym_preproc_pragma] = STATE(426),
    [sym_preproc_nullable] = STATE(426),
    [sym_preproc_error] = STATE(426),
    [sym_preproc_warning] = STATE(426),
    [sym_preproc_define] = STATE(426),
    [sym_preproc_undef] = STATE(426),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1067),
    [anon_sym_ref] = ACTIONS(2281),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(1077),
    [anon_sym_GT] = ACTIONS(1077),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1083),
    [anon_sym_PLUS_PLUS] = ACTIONS(1083),
    [anon_sym_DASH_DASH] = ACTIONS(1083),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1085),
    [anon_sym_DASH] = ACTIONS(1085),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1083),
    [anon_sym_AMP] = ACTIONS(1083),
    [anon_sym_GT_EQ] = ACTIONS(1087),
    [anon_sym_LT_EQ] = ACTIONS(1087),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(1089),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1091),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(1101),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [427] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3554),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2908),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3070),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(6237),
    [sym_constant_pattern] = STATE(4086),
    [sym_parenthesized_pattern] = STATE(4086),
    [sym_var_pattern] = STATE(4086),
    [sym_type_pattern] = STATE(4086),
    [sym_list_pattern] = STATE(4086),
    [sym_recursive_pattern] = STATE(4086),
    [sym_positional_pattern_clause] = STATE(3151),
    [sym_property_pattern_clause] = STATE(3422),
    [sym_relational_pattern] = STATE(4086),
    [sym_negated_pattern] = STATE(4086),
    [sym_and_pattern] = STATE(4086),
    [sym_or_pattern] = STATE(4086),
    [sym_declaration_pattern] = STATE(4086),
    [sym_expression] = STATE(6701),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3989),
    [sym_postfix_unary_expression] = STATE(3990),
    [sym_prefix_unary_expression] = STATE(3990),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3989),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3990),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3989),
    [sym_member_access_expression] = STATE(3206),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3990),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3989),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3989),
    [sym_typeof_expression] = STATE(3989),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3206),
    [sym_literal] = STATE(3989),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2755),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(427),
    [sym_preproc_endregion] = STATE(427),
    [sym_preproc_line] = STATE(427),
    [sym_preproc_pragma] = STATE(427),
    [sym_preproc_nullable] = STATE(427),
    [sym_preproc_error] = STATE(427),
    [sym_preproc_warning] = STATE(427),
    [sym_preproc_define] = STATE(427),
    [sym_preproc_undef] = STATE(427),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(2377),
    [anon_sym_LPAREN] = ACTIONS(2557),
    [anon_sym_ref] = ACTIONS(2327),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2559),
    [anon_sym_GT] = ACTIONS(2559),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1827),
    [anon_sym_TILDE] = ACTIONS(1827),
    [anon_sym_PLUS_PLUS] = ACTIONS(1827),
    [anon_sym_DASH_DASH] = ACTIONS(1827),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1825),
    [anon_sym_DASH] = ACTIONS(1825),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1827),
    [anon_sym_AMP] = ACTIONS(1827),
    [anon_sym_GT_EQ] = ACTIONS(2561),
    [anon_sym_LT_EQ] = ACTIONS(2561),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2385),
    [sym_predefined_type] = ACTIONS(2387),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(2389),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2563),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [428] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3223),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2761),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(2800),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(5402),
    [sym_constant_pattern] = STATE(4086),
    [sym_parenthesized_pattern] = STATE(4086),
    [sym_var_pattern] = STATE(4086),
    [sym_type_pattern] = STATE(4086),
    [sym_list_pattern] = STATE(4086),
    [sym_recursive_pattern] = STATE(4086),
    [sym_positional_pattern_clause] = STATE(2840),
    [sym_property_pattern_clause] = STATE(2874),
    [sym_relational_pattern] = STATE(4086),
    [sym_negated_pattern] = STATE(4086),
    [sym_and_pattern] = STATE(4086),
    [sym_or_pattern] = STATE(4086),
    [sym_declaration_pattern] = STATE(4086),
    [sym_expression] = STATE(6729),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3989),
    [sym_postfix_unary_expression] = STATE(3990),
    [sym_prefix_unary_expression] = STATE(3990),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3989),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3990),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3989),
    [sym_member_access_expression] = STATE(3206),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3990),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3989),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3989),
    [sym_typeof_expression] = STATE(3989),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3206),
    [sym_literal] = STATE(3989),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2776),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(428),
    [sym_preproc_endregion] = STATE(428),
    [sym_preproc_line] = STATE(428),
    [sym_preproc_pragma] = STATE(428),
    [sym_preproc_nullable] = STATE(428),
    [sym_preproc_error] = STATE(428),
    [sym_preproc_warning] = STATE(428),
    [sym_preproc_define] = STATE(428),
    [sym_preproc_undef] = STATE(428),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(2377),
    [anon_sym_LPAREN] = ACTIONS(2531),
    [anon_sym_ref] = ACTIONS(2447),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2533),
    [anon_sym_GT] = ACTIONS(2533),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1363),
    [anon_sym_TILDE] = ACTIONS(1363),
    [anon_sym_PLUS_PLUS] = ACTIONS(1363),
    [anon_sym_DASH_DASH] = ACTIONS(1363),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1361),
    [anon_sym_DASH] = ACTIONS(1361),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1363),
    [anon_sym_AMP] = ACTIONS(1363),
    [anon_sym_GT_EQ] = ACTIONS(2535),
    [anon_sym_LT_EQ] = ACTIONS(2535),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2453),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2385),
    [sym_predefined_type] = ACTIONS(2387),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(2389),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2537),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [429] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3541),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2876),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3045),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(4699),
    [sym_constant_pattern] = STATE(4557),
    [sym_parenthesized_pattern] = STATE(4557),
    [sym_var_pattern] = STATE(4557),
    [sym_type_pattern] = STATE(4557),
    [sym_list_pattern] = STATE(4557),
    [sym_recursive_pattern] = STATE(4557),
    [sym_positional_pattern_clause] = STATE(3128),
    [sym_property_pattern_clause] = STATE(3222),
    [sym_relational_pattern] = STATE(4557),
    [sym_negated_pattern] = STATE(4557),
    [sym_and_pattern] = STATE(4557),
    [sym_or_pattern] = STATE(4557),
    [sym_declaration_pattern] = STATE(4557),
    [sym_expression] = STATE(6747),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(4559),
    [sym_postfix_unary_expression] = STATE(4560),
    [sym_prefix_unary_expression] = STATE(4560),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(4559),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(4560),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(4559),
    [sym_member_access_expression] = STATE(3583),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(4560),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(4559),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(4559),
    [sym_typeof_expression] = STATE(4559),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3583),
    [sym_literal] = STATE(4559),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2755),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(429),
    [sym_preproc_endregion] = STATE(429),
    [sym_preproc_line] = STATE(429),
    [sym_preproc_pragma] = STATE(429),
    [sym_preproc_nullable] = STATE(429),
    [sym_preproc_error] = STATE(429),
    [sym_preproc_warning] = STATE(429),
    [sym_preproc_define] = STATE(429),
    [sym_preproc_undef] = STATE(429),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(2413),
    [anon_sym_LPAREN] = ACTIONS(2429),
    [anon_sym_ref] = ACTIONS(2327),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2431),
    [anon_sym_GT] = ACTIONS(2431),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1701),
    [anon_sym_TILDE] = ACTIONS(1701),
    [anon_sym_PLUS_PLUS] = ACTIONS(1701),
    [anon_sym_DASH_DASH] = ACTIONS(1701),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1699),
    [anon_sym_DASH] = ACTIONS(1699),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1701),
    [anon_sym_AMP] = ACTIONS(1701),
    [anon_sym_GT_EQ] = ACTIONS(2433),
    [anon_sym_LT_EQ] = ACTIONS(2433),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2421),
    [sym_predefined_type] = ACTIONS(2423),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(2425),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2435),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [430] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(2999),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2761),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(2805),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(4946),
    [sym_constant_pattern] = STATE(4086),
    [sym_parenthesized_pattern] = STATE(4086),
    [sym_var_pattern] = STATE(4086),
    [sym_type_pattern] = STATE(4086),
    [sym_list_pattern] = STATE(4086),
    [sym_recursive_pattern] = STATE(4086),
    [sym_positional_pattern_clause] = STATE(2840),
    [sym_property_pattern_clause] = STATE(2874),
    [sym_relational_pattern] = STATE(4086),
    [sym_negated_pattern] = STATE(4086),
    [sym_and_pattern] = STATE(4086),
    [sym_or_pattern] = STATE(4086),
    [sym_declaration_pattern] = STATE(4086),
    [sym_expression] = STATE(6704),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3989),
    [sym_postfix_unary_expression] = STATE(3990),
    [sym_prefix_unary_expression] = STATE(3990),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3989),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3990),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3989),
    [sym_member_access_expression] = STATE(3206),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3990),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3989),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3989),
    [sym_typeof_expression] = STATE(3989),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3206),
    [sym_literal] = STATE(3989),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2755),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(430),
    [sym_preproc_endregion] = STATE(430),
    [sym_preproc_line] = STATE(430),
    [sym_preproc_pragma] = STATE(430),
    [sym_preproc_nullable] = STATE(430),
    [sym_preproc_error] = STATE(430),
    [sym_preproc_warning] = STATE(430),
    [sym_preproc_define] = STATE(430),
    [sym_preproc_undef] = STATE(430),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(2377),
    [anon_sym_LPAREN] = ACTIONS(2379),
    [anon_sym_ref] = ACTIONS(2327),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2381),
    [anon_sym_GT] = ACTIONS(2381),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1177),
    [anon_sym_TILDE] = ACTIONS(1177),
    [anon_sym_PLUS_PLUS] = ACTIONS(1177),
    [anon_sym_DASH_DASH] = ACTIONS(1177),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1175),
    [anon_sym_DASH] = ACTIONS(1175),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1177),
    [anon_sym_AMP] = ACTIONS(1177),
    [anon_sym_GT_EQ] = ACTIONS(2383),
    [anon_sym_LT_EQ] = ACTIONS(2383),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2385),
    [sym_predefined_type] = ACTIONS(2387),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(2389),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2391),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [431] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(2999),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2761),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(2805),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(4029),
    [sym_constant_pattern] = STATE(4086),
    [sym_parenthesized_pattern] = STATE(4086),
    [sym_var_pattern] = STATE(4086),
    [sym_type_pattern] = STATE(4086),
    [sym_list_pattern] = STATE(4086),
    [sym_recursive_pattern] = STATE(4086),
    [sym_positional_pattern_clause] = STATE(2840),
    [sym_property_pattern_clause] = STATE(2874),
    [sym_relational_pattern] = STATE(4086),
    [sym_negated_pattern] = STATE(4086),
    [sym_and_pattern] = STATE(4086),
    [sym_or_pattern] = STATE(4086),
    [sym_declaration_pattern] = STATE(4086),
    [sym_expression] = STATE(6704),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3989),
    [sym_postfix_unary_expression] = STATE(3990),
    [sym_prefix_unary_expression] = STATE(3990),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3989),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3990),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3989),
    [sym_member_access_expression] = STATE(3206),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3990),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3989),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3989),
    [sym_typeof_expression] = STATE(3989),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3206),
    [sym_literal] = STATE(3989),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2755),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(431),
    [sym_preproc_endregion] = STATE(431),
    [sym_preproc_line] = STATE(431),
    [sym_preproc_pragma] = STATE(431),
    [sym_preproc_nullable] = STATE(431),
    [sym_preproc_error] = STATE(431),
    [sym_preproc_warning] = STATE(431),
    [sym_preproc_define] = STATE(431),
    [sym_preproc_undef] = STATE(431),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(2377),
    [anon_sym_LPAREN] = ACTIONS(2379),
    [anon_sym_ref] = ACTIONS(2327),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2381),
    [anon_sym_GT] = ACTIONS(2381),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1177),
    [anon_sym_TILDE] = ACTIONS(1177),
    [anon_sym_PLUS_PLUS] = ACTIONS(1177),
    [anon_sym_DASH_DASH] = ACTIONS(1177),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1175),
    [anon_sym_DASH] = ACTIONS(1175),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1177),
    [anon_sym_AMP] = ACTIONS(1177),
    [anon_sym_GT_EQ] = ACTIONS(2383),
    [anon_sym_LT_EQ] = ACTIONS(2383),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2385),
    [sym_predefined_type] = ACTIONS(2387),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(2389),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2391),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [432] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(2999),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2761),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(2805),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(4926),
    [sym_constant_pattern] = STATE(4086),
    [sym_parenthesized_pattern] = STATE(4086),
    [sym_var_pattern] = STATE(4086),
    [sym_type_pattern] = STATE(4086),
    [sym_list_pattern] = STATE(4086),
    [sym_recursive_pattern] = STATE(4086),
    [sym_positional_pattern_clause] = STATE(2840),
    [sym_property_pattern_clause] = STATE(2874),
    [sym_relational_pattern] = STATE(4086),
    [sym_negated_pattern] = STATE(4086),
    [sym_and_pattern] = STATE(4086),
    [sym_or_pattern] = STATE(4086),
    [sym_declaration_pattern] = STATE(4086),
    [sym_expression] = STATE(6704),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3989),
    [sym_postfix_unary_expression] = STATE(3990),
    [sym_prefix_unary_expression] = STATE(3990),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3989),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3990),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3989),
    [sym_member_access_expression] = STATE(3206),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3990),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3989),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3989),
    [sym_typeof_expression] = STATE(3989),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3206),
    [sym_literal] = STATE(3989),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2755),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(432),
    [sym_preproc_endregion] = STATE(432),
    [sym_preproc_line] = STATE(432),
    [sym_preproc_pragma] = STATE(432),
    [sym_preproc_nullable] = STATE(432),
    [sym_preproc_error] = STATE(432),
    [sym_preproc_warning] = STATE(432),
    [sym_preproc_define] = STATE(432),
    [sym_preproc_undef] = STATE(432),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(2377),
    [anon_sym_LPAREN] = ACTIONS(2379),
    [anon_sym_ref] = ACTIONS(2327),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2381),
    [anon_sym_GT] = ACTIONS(2381),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1177),
    [anon_sym_TILDE] = ACTIONS(1177),
    [anon_sym_PLUS_PLUS] = ACTIONS(1177),
    [anon_sym_DASH_DASH] = ACTIONS(1177),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1175),
    [anon_sym_DASH] = ACTIONS(1175),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1177),
    [anon_sym_AMP] = ACTIONS(1177),
    [anon_sym_GT_EQ] = ACTIONS(2383),
    [anon_sym_LT_EQ] = ACTIONS(2383),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2385),
    [sym_predefined_type] = ACTIONS(2387),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(2389),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2391),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [433] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3554),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2908),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3077),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(4029),
    [sym_constant_pattern] = STATE(4086),
    [sym_parenthesized_pattern] = STATE(4086),
    [sym_var_pattern] = STATE(4086),
    [sym_type_pattern] = STATE(4086),
    [sym_list_pattern] = STATE(4086),
    [sym_recursive_pattern] = STATE(4086),
    [sym_positional_pattern_clause] = STATE(3151),
    [sym_property_pattern_clause] = STATE(3422),
    [sym_relational_pattern] = STATE(4086),
    [sym_negated_pattern] = STATE(4086),
    [sym_and_pattern] = STATE(4086),
    [sym_or_pattern] = STATE(4086),
    [sym_declaration_pattern] = STATE(4086),
    [sym_expression] = STATE(6701),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3989),
    [sym_postfix_unary_expression] = STATE(3990),
    [sym_prefix_unary_expression] = STATE(3990),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3989),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3990),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3989),
    [sym_member_access_expression] = STATE(3206),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3990),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3989),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3989),
    [sym_typeof_expression] = STATE(3989),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3206),
    [sym_literal] = STATE(3989),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2755),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(433),
    [sym_preproc_endregion] = STATE(433),
    [sym_preproc_line] = STATE(433),
    [sym_preproc_pragma] = STATE(433),
    [sym_preproc_nullable] = STATE(433),
    [sym_preproc_error] = STATE(433),
    [sym_preproc_warning] = STATE(433),
    [sym_preproc_define] = STATE(433),
    [sym_preproc_undef] = STATE(433),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(2377),
    [anon_sym_LPAREN] = ACTIONS(2557),
    [anon_sym_ref] = ACTIONS(2327),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2559),
    [anon_sym_GT] = ACTIONS(2559),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1827),
    [anon_sym_TILDE] = ACTIONS(1827),
    [anon_sym_PLUS_PLUS] = ACTIONS(1827),
    [anon_sym_DASH_DASH] = ACTIONS(1827),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1825),
    [anon_sym_DASH] = ACTIONS(1825),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1827),
    [anon_sym_AMP] = ACTIONS(1827),
    [anon_sym_GT_EQ] = ACTIONS(2561),
    [anon_sym_LT_EQ] = ACTIONS(2561),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2385),
    [sym_predefined_type] = ACTIONS(2387),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(2389),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2563),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [434] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3537),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2852),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3055),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(4137),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(3103),
    [sym_property_pattern_clause] = STATE(3159),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6715),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(4164),
    [sym_postfix_unary_expression] = STATE(4165),
    [sym_prefix_unary_expression] = STATE(4165),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(4164),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(4165),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(4164),
    [sym_member_access_expression] = STATE(3482),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(4165),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(4164),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(4164),
    [sym_typeof_expression] = STATE(4164),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3482),
    [sym_literal] = STATE(4164),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2776),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(434),
    [sym_preproc_endregion] = STATE(434),
    [sym_preproc_line] = STATE(434),
    [sym_preproc_pragma] = STATE(434),
    [sym_preproc_nullable] = STATE(434),
    [sym_preproc_error] = STATE(434),
    [sym_preproc_warning] = STATE(434),
    [sym_preproc_define] = STATE(434),
    [sym_preproc_undef] = STATE(434),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(2527),
    [anon_sym_ref] = ACTIONS(2447),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2403),
    [anon_sym_GT] = ACTIONS(2403),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1629),
    [anon_sym_TILDE] = ACTIONS(1629),
    [anon_sym_PLUS_PLUS] = ACTIONS(1629),
    [anon_sym_DASH_DASH] = ACTIONS(1629),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1627),
    [anon_sym_DASH] = ACTIONS(1627),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1629),
    [anon_sym_AMP] = ACTIONS(1629),
    [anon_sym_GT_EQ] = ACTIONS(2405),
    [anon_sym_LT_EQ] = ACTIONS(2405),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2453),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2349),
    [sym_predefined_type] = ACTIONS(2339),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2529),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [435] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3485),
    [sym_alias_qualified_name] = STATE(3486),
    [sym__simple_name] = STATE(2830),
    [sym_qualified_name] = STATE(3486),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(2985),
    [sym_implicit_type] = STATE(3330),
    [sym_array_type] = STATE(3488),
    [sym__array_base_type] = STATE(8756),
    [sym_nullable_type] = STATE(3489),
    [sym_pointer_type] = STATE(3489),
    [sym__pointer_base_type] = STATE(9221),
    [sym_function_pointer_type] = STATE(3489),
    [sym_ref_type] = STATE(3330),
    [sym_scoped_type] = STATE(3330),
    [sym_tuple_type] = STATE(3490),
    [sym_pattern] = STATE(6093),
    [sym_constant_pattern] = STATE(5744),
    [sym_parenthesized_pattern] = STATE(5744),
    [sym_var_pattern] = STATE(5744),
    [sym_type_pattern] = STATE(5744),
    [sym_list_pattern] = STATE(5744),
    [sym_recursive_pattern] = STATE(5744),
    [sym_positional_pattern_clause] = STATE(3084),
    [sym_property_pattern_clause] = STATE(3132),
    [sym_relational_pattern] = STATE(5744),
    [sym_negated_pattern] = STATE(5744),
    [sym_and_pattern] = STATE(5744),
    [sym_or_pattern] = STATE(5744),
    [sym_declaration_pattern] = STATE(5744),
    [sym_expression] = STATE(6709),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5469),
    [sym_postfix_unary_expression] = STATE(5470),
    [sym_prefix_unary_expression] = STATE(5470),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5469),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5470),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5469),
    [sym_member_access_expression] = STATE(3940),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5470),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(5469),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5469),
    [sym_typeof_expression] = STATE(5469),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3940),
    [sym_literal] = STATE(5469),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2792),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(435),
    [sym_preproc_endregion] = STATE(435),
    [sym_preproc_line] = STATE(435),
    [sym_preproc_pragma] = STATE(435),
    [sym_preproc_nullable] = STATE(435),
    [sym_preproc_error] = STATE(435),
    [sym_preproc_warning] = STATE(435),
    [sym_preproc_define] = STATE(435),
    [sym_preproc_undef] = STATE(435),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(2353),
    [anon_sym_LPAREN] = ACTIONS(2565),
    [anon_sym_ref] = ACTIONS(2357),
    [anon_sym_LBRACE] = ACTIONS(2359),
    [anon_sym_delegate] = ACTIONS(2361),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2567),
    [anon_sym_GT] = ACTIONS(2567),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1421),
    [anon_sym_TILDE] = ACTIONS(1421),
    [anon_sym_PLUS_PLUS] = ACTIONS(1421),
    [anon_sym_DASH_DASH] = ACTIONS(1421),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1419),
    [anon_sym_DASH] = ACTIONS(1419),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1421),
    [anon_sym_AMP] = ACTIONS(1421),
    [anon_sym_GT_EQ] = ACTIONS(2569),
    [anon_sym_LT_EQ] = ACTIONS(2569),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2367),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2369),
    [sym_predefined_type] = ACTIONS(2371),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(2373),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2571),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [436] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3552),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2911),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3067),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(6198),
    [sym_constant_pattern] = STATE(4086),
    [sym_parenthesized_pattern] = STATE(4086),
    [sym_var_pattern] = STATE(4086),
    [sym_type_pattern] = STATE(4086),
    [sym_list_pattern] = STATE(4086),
    [sym_recursive_pattern] = STATE(4086),
    [sym_positional_pattern_clause] = STATE(3163),
    [sym_property_pattern_clause] = STATE(3429),
    [sym_relational_pattern] = STATE(4086),
    [sym_negated_pattern] = STATE(4086),
    [sym_and_pattern] = STATE(4086),
    [sym_or_pattern] = STATE(4086),
    [sym_declaration_pattern] = STATE(4086),
    [sym_expression] = STATE(6703),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3989),
    [sym_postfix_unary_expression] = STATE(3990),
    [sym_prefix_unary_expression] = STATE(3990),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3989),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3990),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3989),
    [sym_member_access_expression] = STATE(3206),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3990),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3989),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3989),
    [sym_typeof_expression] = STATE(3989),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3206),
    [sym_literal] = STATE(3989),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2755),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(436),
    [sym_preproc_endregion] = STATE(436),
    [sym_preproc_line] = STATE(436),
    [sym_preproc_pragma] = STATE(436),
    [sym_preproc_nullable] = STATE(436),
    [sym_preproc_error] = STATE(436),
    [sym_preproc_warning] = STATE(436),
    [sym_preproc_define] = STATE(436),
    [sym_preproc_undef] = STATE(436),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(2377),
    [anon_sym_LPAREN] = ACTIONS(2573),
    [anon_sym_ref] = ACTIONS(2327),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2575),
    [anon_sym_GT] = ACTIONS(2575),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1845),
    [anon_sym_TILDE] = ACTIONS(1845),
    [anon_sym_PLUS_PLUS] = ACTIONS(1845),
    [anon_sym_DASH_DASH] = ACTIONS(1845),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1843),
    [anon_sym_DASH] = ACTIONS(1843),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1845),
    [anon_sym_AMP] = ACTIONS(1845),
    [anon_sym_GT_EQ] = ACTIONS(2577),
    [anon_sym_LT_EQ] = ACTIONS(2577),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2385),
    [sym_predefined_type] = ACTIONS(2387),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(2389),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2579),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [437] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3000),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2756),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3043),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(4198),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(2858),
    [sym_property_pattern_clause] = STATE(2881),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6697),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(4164),
    [sym_postfix_unary_expression] = STATE(4165),
    [sym_prefix_unary_expression] = STATE(4165),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(4164),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(4165),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(4164),
    [sym_member_access_expression] = STATE(3482),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(4165),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(4164),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(4164),
    [sym_typeof_expression] = STATE(4164),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3482),
    [sym_literal] = STATE(4164),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2835),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(437),
    [sym_preproc_endregion] = STATE(437),
    [sym_preproc_line] = STATE(437),
    [sym_preproc_pragma] = STATE(437),
    [sym_preproc_nullable] = STATE(437),
    [sym_preproc_error] = STATE(437),
    [sym_preproc_warning] = STATE(437),
    [sym_preproc_define] = STATE(437),
    [sym_preproc_undef] = STATE(437),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(2493),
    [anon_sym_ref] = ACTIONS(2467),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2495),
    [anon_sym_GT] = ACTIONS(2495),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1675),
    [anon_sym_TILDE] = ACTIONS(1675),
    [anon_sym_PLUS_PLUS] = ACTIONS(1675),
    [anon_sym_DASH_DASH] = ACTIONS(1675),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1675),
    [anon_sym_AMP] = ACTIONS(1675),
    [anon_sym_GT_EQ] = ACTIONS(2497),
    [anon_sym_LT_EQ] = ACTIONS(2497),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2499),
    [sym_predefined_type] = ACTIONS(2339),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2501),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [438] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3485),
    [sym_alias_qualified_name] = STATE(3486),
    [sym__simple_name] = STATE(2830),
    [sym_qualified_name] = STATE(3486),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(2964),
    [sym_implicit_type] = STATE(3330),
    [sym_array_type] = STATE(3488),
    [sym__array_base_type] = STATE(8756),
    [sym_nullable_type] = STATE(3489),
    [sym_pointer_type] = STATE(3489),
    [sym__pointer_base_type] = STATE(9221),
    [sym_function_pointer_type] = STATE(3489),
    [sym_ref_type] = STATE(3330),
    [sym_scoped_type] = STATE(3330),
    [sym_tuple_type] = STATE(3490),
    [sym_pattern] = STATE(5509),
    [sym_constant_pattern] = STATE(5744),
    [sym_parenthesized_pattern] = STATE(5744),
    [sym_var_pattern] = STATE(5744),
    [sym_type_pattern] = STATE(5744),
    [sym_list_pattern] = STATE(5744),
    [sym_recursive_pattern] = STATE(5744),
    [sym_positional_pattern_clause] = STATE(3084),
    [sym_property_pattern_clause] = STATE(3132),
    [sym_relational_pattern] = STATE(5744),
    [sym_negated_pattern] = STATE(5744),
    [sym_and_pattern] = STATE(5744),
    [sym_or_pattern] = STATE(5744),
    [sym_declaration_pattern] = STATE(5744),
    [sym_expression] = STATE(6709),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5469),
    [sym_postfix_unary_expression] = STATE(5470),
    [sym_prefix_unary_expression] = STATE(5470),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5469),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5470),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5469),
    [sym_member_access_expression] = STATE(3940),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5470),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(5469),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5469),
    [sym_typeof_expression] = STATE(5469),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3940),
    [sym_literal] = STATE(5469),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2792),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(438),
    [sym_preproc_endregion] = STATE(438),
    [sym_preproc_line] = STATE(438),
    [sym_preproc_pragma] = STATE(438),
    [sym_preproc_nullable] = STATE(438),
    [sym_preproc_error] = STATE(438),
    [sym_preproc_warning] = STATE(438),
    [sym_preproc_define] = STATE(438),
    [sym_preproc_undef] = STATE(438),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(2353),
    [anon_sym_LPAREN] = ACTIONS(2565),
    [anon_sym_ref] = ACTIONS(2357),
    [anon_sym_LBRACE] = ACTIONS(2359),
    [anon_sym_delegate] = ACTIONS(2361),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2567),
    [anon_sym_GT] = ACTIONS(2567),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1421),
    [anon_sym_TILDE] = ACTIONS(1421),
    [anon_sym_PLUS_PLUS] = ACTIONS(1421),
    [anon_sym_DASH_DASH] = ACTIONS(1421),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1419),
    [anon_sym_DASH] = ACTIONS(1419),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1421),
    [anon_sym_AMP] = ACTIONS(1421),
    [anon_sym_GT_EQ] = ACTIONS(2569),
    [anon_sym_LT_EQ] = ACTIONS(2569),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2367),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2369),
    [sym_predefined_type] = ACTIONS(2371),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(2373),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2571),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [439] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3485),
    [sym_alias_qualified_name] = STATE(3486),
    [sym__simple_name] = STATE(2830),
    [sym_qualified_name] = STATE(3486),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(2985),
    [sym_implicit_type] = STATE(3330),
    [sym_array_type] = STATE(3488),
    [sym__array_base_type] = STATE(8756),
    [sym_nullable_type] = STATE(3489),
    [sym_pointer_type] = STATE(3489),
    [sym__pointer_base_type] = STATE(9221),
    [sym_function_pointer_type] = STATE(3489),
    [sym_ref_type] = STATE(3330),
    [sym_scoped_type] = STATE(3330),
    [sym_tuple_type] = STATE(3490),
    [sym_pattern] = STATE(5432),
    [sym_constant_pattern] = STATE(5744),
    [sym_parenthesized_pattern] = STATE(5744),
    [sym_var_pattern] = STATE(5744),
    [sym_type_pattern] = STATE(5744),
    [sym_list_pattern] = STATE(5744),
    [sym_recursive_pattern] = STATE(5744),
    [sym_positional_pattern_clause] = STATE(3084),
    [sym_property_pattern_clause] = STATE(3132),
    [sym_relational_pattern] = STATE(5744),
    [sym_negated_pattern] = STATE(5744),
    [sym_and_pattern] = STATE(5744),
    [sym_or_pattern] = STATE(5744),
    [sym_declaration_pattern] = STATE(5744),
    [sym_expression] = STATE(6709),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5469),
    [sym_postfix_unary_expression] = STATE(5470),
    [sym_prefix_unary_expression] = STATE(5470),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5469),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5470),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5469),
    [sym_member_access_expression] = STATE(3940),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5470),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(5469),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5469),
    [sym_typeof_expression] = STATE(5469),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3940),
    [sym_literal] = STATE(5469),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2792),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(439),
    [sym_preproc_endregion] = STATE(439),
    [sym_preproc_line] = STATE(439),
    [sym_preproc_pragma] = STATE(439),
    [sym_preproc_nullable] = STATE(439),
    [sym_preproc_error] = STATE(439),
    [sym_preproc_warning] = STATE(439),
    [sym_preproc_define] = STATE(439),
    [sym_preproc_undef] = STATE(439),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(2353),
    [anon_sym_LPAREN] = ACTIONS(2565),
    [anon_sym_ref] = ACTIONS(2357),
    [anon_sym_LBRACE] = ACTIONS(2359),
    [anon_sym_delegate] = ACTIONS(2361),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2567),
    [anon_sym_GT] = ACTIONS(2567),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1421),
    [anon_sym_TILDE] = ACTIONS(1421),
    [anon_sym_PLUS_PLUS] = ACTIONS(1421),
    [anon_sym_DASH_DASH] = ACTIONS(1421),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1419),
    [anon_sym_DASH] = ACTIONS(1419),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1421),
    [anon_sym_AMP] = ACTIONS(1421),
    [anon_sym_GT_EQ] = ACTIONS(2569),
    [anon_sym_LT_EQ] = ACTIONS(2569),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2367),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2369),
    [sym_predefined_type] = ACTIONS(2371),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(2373),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2571),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [440] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3485),
    [sym_alias_qualified_name] = STATE(3486),
    [sym__simple_name] = STATE(2830),
    [sym_qualified_name] = STATE(3486),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(2985),
    [sym_implicit_type] = STATE(3330),
    [sym_array_type] = STATE(3488),
    [sym__array_base_type] = STATE(8756),
    [sym_nullable_type] = STATE(3489),
    [sym_pointer_type] = STATE(3489),
    [sym__pointer_base_type] = STATE(9221),
    [sym_function_pointer_type] = STATE(3489),
    [sym_ref_type] = STATE(3330),
    [sym_scoped_type] = STATE(3330),
    [sym_tuple_type] = STATE(3490),
    [sym_pattern] = STATE(6027),
    [sym_constant_pattern] = STATE(5744),
    [sym_parenthesized_pattern] = STATE(5744),
    [sym_var_pattern] = STATE(5744),
    [sym_type_pattern] = STATE(5744),
    [sym_list_pattern] = STATE(5744),
    [sym_recursive_pattern] = STATE(5744),
    [sym_positional_pattern_clause] = STATE(3084),
    [sym_property_pattern_clause] = STATE(3132),
    [sym_relational_pattern] = STATE(5744),
    [sym_negated_pattern] = STATE(5744),
    [sym_and_pattern] = STATE(5744),
    [sym_or_pattern] = STATE(5744),
    [sym_declaration_pattern] = STATE(5744),
    [sym_expression] = STATE(6709),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5469),
    [sym_postfix_unary_expression] = STATE(5470),
    [sym_prefix_unary_expression] = STATE(5470),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5469),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5470),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5469),
    [sym_member_access_expression] = STATE(3940),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5470),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(5469),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5469),
    [sym_typeof_expression] = STATE(5469),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3940),
    [sym_literal] = STATE(5469),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2792),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(440),
    [sym_preproc_endregion] = STATE(440),
    [sym_preproc_line] = STATE(440),
    [sym_preproc_pragma] = STATE(440),
    [sym_preproc_nullable] = STATE(440),
    [sym_preproc_error] = STATE(440),
    [sym_preproc_warning] = STATE(440),
    [sym_preproc_define] = STATE(440),
    [sym_preproc_undef] = STATE(440),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(2353),
    [anon_sym_LPAREN] = ACTIONS(2565),
    [anon_sym_ref] = ACTIONS(2357),
    [anon_sym_LBRACE] = ACTIONS(2359),
    [anon_sym_delegate] = ACTIONS(2361),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2567),
    [anon_sym_GT] = ACTIONS(2567),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1421),
    [anon_sym_TILDE] = ACTIONS(1421),
    [anon_sym_PLUS_PLUS] = ACTIONS(1421),
    [anon_sym_DASH_DASH] = ACTIONS(1421),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1419),
    [anon_sym_DASH] = ACTIONS(1419),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1421),
    [anon_sym_AMP] = ACTIONS(1421),
    [anon_sym_GT_EQ] = ACTIONS(2569),
    [anon_sym_LT_EQ] = ACTIONS(2569),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2367),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2369),
    [sym_predefined_type] = ACTIONS(2371),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(2373),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2571),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [441] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3000),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2756),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3043),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(6581),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(2858),
    [sym_property_pattern_clause] = STATE(2881),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6697),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(4164),
    [sym_postfix_unary_expression] = STATE(4165),
    [sym_prefix_unary_expression] = STATE(4165),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(4164),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(4165),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(4164),
    [sym_member_access_expression] = STATE(3482),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(4165),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(4164),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(4164),
    [sym_typeof_expression] = STATE(4164),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3482),
    [sym_literal] = STATE(4164),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2835),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(441),
    [sym_preproc_endregion] = STATE(441),
    [sym_preproc_line] = STATE(441),
    [sym_preproc_pragma] = STATE(441),
    [sym_preproc_nullable] = STATE(441),
    [sym_preproc_error] = STATE(441),
    [sym_preproc_warning] = STATE(441),
    [sym_preproc_define] = STATE(441),
    [sym_preproc_undef] = STATE(441),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(2493),
    [anon_sym_ref] = ACTIONS(2467),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2495),
    [anon_sym_GT] = ACTIONS(2495),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1675),
    [anon_sym_TILDE] = ACTIONS(1675),
    [anon_sym_PLUS_PLUS] = ACTIONS(1675),
    [anon_sym_DASH_DASH] = ACTIONS(1675),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1675),
    [anon_sym_AMP] = ACTIONS(1675),
    [anon_sym_GT_EQ] = ACTIONS(2497),
    [anon_sym_LT_EQ] = ACTIONS(2497),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2499),
    [sym_predefined_type] = ACTIONS(2339),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2501),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [442] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3540),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2852),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3044),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(6164),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(3103),
    [sym_property_pattern_clause] = STATE(3159),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6727),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(4164),
    [sym_postfix_unary_expression] = STATE(4165),
    [sym_prefix_unary_expression] = STATE(4165),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(4164),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(4165),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(4164),
    [sym_member_access_expression] = STATE(3482),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(4165),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(4164),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(4164),
    [sym_typeof_expression] = STATE(4164),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3482),
    [sym_literal] = STATE(4164),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2835),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(442),
    [sym_preproc_endregion] = STATE(442),
    [sym_preproc_line] = STATE(442),
    [sym_preproc_pragma] = STATE(442),
    [sym_preproc_nullable] = STATE(442),
    [sym_preproc_error] = STATE(442),
    [sym_preproc_warning] = STATE(442),
    [sym_preproc_define] = STATE(442),
    [sym_preproc_undef] = STATE(442),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(2581),
    [anon_sym_ref] = ACTIONS(2467),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(1955),
    [anon_sym_GT] = ACTIONS(1955),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1581),
    [anon_sym_TILDE] = ACTIONS(1581),
    [anon_sym_PLUS_PLUS] = ACTIONS(1581),
    [anon_sym_DASH_DASH] = ACTIONS(1581),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1579),
    [anon_sym_DASH] = ACTIONS(1579),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1581),
    [anon_sym_AMP] = ACTIONS(1581),
    [anon_sym_GT_EQ] = ACTIONS(1957),
    [anon_sym_LT_EQ] = ACTIONS(1957),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2499),
    [sym_predefined_type] = ACTIONS(2339),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2583),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [443] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3538),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2846),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3035),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(3987),
    [sym_constant_pattern] = STATE(4086),
    [sym_parenthesized_pattern] = STATE(4086),
    [sym_var_pattern] = STATE(4086),
    [sym_type_pattern] = STATE(4086),
    [sym_list_pattern] = STATE(4086),
    [sym_recursive_pattern] = STATE(4086),
    [sym_positional_pattern_clause] = STATE(3120),
    [sym_property_pattern_clause] = STATE(3169),
    [sym_relational_pattern] = STATE(4086),
    [sym_negated_pattern] = STATE(4086),
    [sym_and_pattern] = STATE(4086),
    [sym_or_pattern] = STATE(4086),
    [sym_declaration_pattern] = STATE(4086),
    [sym_expression] = STATE(6705),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3989),
    [sym_postfix_unary_expression] = STATE(3990),
    [sym_prefix_unary_expression] = STATE(3990),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3989),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3990),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3989),
    [sym_member_access_expression] = STATE(3206),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3990),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3989),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3989),
    [sym_typeof_expression] = STATE(3989),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3206),
    [sym_literal] = STATE(3989),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2776),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(443),
    [sym_preproc_endregion] = STATE(443),
    [sym_preproc_line] = STATE(443),
    [sym_preproc_pragma] = STATE(443),
    [sym_preproc_nullable] = STATE(443),
    [sym_preproc_error] = STATE(443),
    [sym_preproc_warning] = STATE(443),
    [sym_preproc_define] = STATE(443),
    [sym_preproc_undef] = STATE(443),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(2377),
    [anon_sym_LPAREN] = ACTIONS(2445),
    [anon_sym_ref] = ACTIONS(2447),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2449),
    [anon_sym_GT] = ACTIONS(2449),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1599),
    [anon_sym_TILDE] = ACTIONS(1599),
    [anon_sym_PLUS_PLUS] = ACTIONS(1599),
    [anon_sym_DASH_DASH] = ACTIONS(1599),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1597),
    [anon_sym_DASH] = ACTIONS(1597),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1599),
    [anon_sym_AMP] = ACTIONS(1599),
    [anon_sym_GT_EQ] = ACTIONS(2451),
    [anon_sym_LT_EQ] = ACTIONS(2451),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2453),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2385),
    [sym_predefined_type] = ACTIONS(2387),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(2389),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2455),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [444] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3211),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2756),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(2813),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(4137),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(2858),
    [sym_property_pattern_clause] = STATE(2881),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6732),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(4164),
    [sym_postfix_unary_expression] = STATE(4165),
    [sym_prefix_unary_expression] = STATE(4165),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(4164),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(4165),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(4164),
    [sym_member_access_expression] = STATE(3482),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(4165),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(4164),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(4164),
    [sym_typeof_expression] = STATE(4164),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3482),
    [sym_literal] = STATE(4164),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2776),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(444),
    [sym_preproc_endregion] = STATE(444),
    [sym_preproc_line] = STATE(444),
    [sym_preproc_pragma] = STATE(444),
    [sym_preproc_nullable] = STATE(444),
    [sym_preproc_error] = STATE(444),
    [sym_preproc_warning] = STATE(444),
    [sym_preproc_define] = STATE(444),
    [sym_preproc_undef] = STATE(444),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(2585),
    [anon_sym_ref] = ACTIONS(2447),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2587),
    [anon_sym_GT] = ACTIONS(2587),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1545),
    [anon_sym_TILDE] = ACTIONS(1545),
    [anon_sym_PLUS_PLUS] = ACTIONS(1545),
    [anon_sym_DASH_DASH] = ACTIONS(1545),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1543),
    [anon_sym_DASH] = ACTIONS(1543),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1545),
    [anon_sym_AMP] = ACTIONS(1545),
    [anon_sym_GT_EQ] = ACTIONS(2589),
    [anon_sym_LT_EQ] = ACTIONS(2589),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2453),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2349),
    [sym_predefined_type] = ACTIONS(2339),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2591),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [445] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3540),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2852),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3044),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(4198),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(3103),
    [sym_property_pattern_clause] = STATE(3159),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6727),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(4164),
    [sym_postfix_unary_expression] = STATE(4165),
    [sym_prefix_unary_expression] = STATE(4165),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(4164),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(4165),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(4164),
    [sym_member_access_expression] = STATE(3482),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(4165),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(4164),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(4164),
    [sym_typeof_expression] = STATE(4164),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3482),
    [sym_literal] = STATE(4164),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2835),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(445),
    [sym_preproc_endregion] = STATE(445),
    [sym_preproc_line] = STATE(445),
    [sym_preproc_pragma] = STATE(445),
    [sym_preproc_nullable] = STATE(445),
    [sym_preproc_error] = STATE(445),
    [sym_preproc_warning] = STATE(445),
    [sym_preproc_define] = STATE(445),
    [sym_preproc_undef] = STATE(445),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(2581),
    [anon_sym_ref] = ACTIONS(2467),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(1955),
    [anon_sym_GT] = ACTIONS(1955),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1581),
    [anon_sym_TILDE] = ACTIONS(1581),
    [anon_sym_PLUS_PLUS] = ACTIONS(1581),
    [anon_sym_DASH_DASH] = ACTIONS(1581),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1579),
    [anon_sym_DASH] = ACTIONS(1579),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1581),
    [anon_sym_AMP] = ACTIONS(1581),
    [anon_sym_GT_EQ] = ACTIONS(1957),
    [anon_sym_LT_EQ] = ACTIONS(1957),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2499),
    [sym_predefined_type] = ACTIONS(2339),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2583),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [446] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3555),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2893),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3065),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(6544),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(3170),
    [sym_property_pattern_clause] = STATE(3373),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6736),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(4164),
    [sym_postfix_unary_expression] = STATE(4165),
    [sym_prefix_unary_expression] = STATE(4165),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(4164),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(4165),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(4164),
    [sym_member_access_expression] = STATE(3482),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(4165),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(4164),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(4164),
    [sym_typeof_expression] = STATE(4164),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3482),
    [sym_literal] = STATE(4164),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2755),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(446),
    [sym_preproc_endregion] = STATE(446),
    [sym_preproc_line] = STATE(446),
    [sym_preproc_pragma] = STATE(446),
    [sym_preproc_nullable] = STATE(446),
    [sym_preproc_error] = STATE(446),
    [sym_preproc_warning] = STATE(446),
    [sym_preproc_define] = STATE(446),
    [sym_preproc_undef] = STATE(446),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(2343),
    [anon_sym_ref] = ACTIONS(2327),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2345),
    [anon_sym_GT] = ACTIONS(2345),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1863),
    [anon_sym_TILDE] = ACTIONS(1863),
    [anon_sym_PLUS_PLUS] = ACTIONS(1863),
    [anon_sym_DASH_DASH] = ACTIONS(1863),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1861),
    [anon_sym_DASH] = ACTIONS(1861),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1863),
    [anon_sym_AMP] = ACTIONS(1863),
    [anon_sym_GT_EQ] = ACTIONS(2347),
    [anon_sym_LT_EQ] = ACTIONS(2347),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2349),
    [sym_predefined_type] = ACTIONS(2339),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2351),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [447] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3000),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2756),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3052),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(6391),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(2858),
    [sym_property_pattern_clause] = STATE(2881),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6697),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(4164),
    [sym_postfix_unary_expression] = STATE(4165),
    [sym_prefix_unary_expression] = STATE(4165),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(4164),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(4165),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(4164),
    [sym_member_access_expression] = STATE(3482),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(4165),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(4164),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(4164),
    [sym_typeof_expression] = STATE(4164),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3482),
    [sym_literal] = STATE(4164),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2835),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(447),
    [sym_preproc_endregion] = STATE(447),
    [sym_preproc_line] = STATE(447),
    [sym_preproc_pragma] = STATE(447),
    [sym_preproc_nullable] = STATE(447),
    [sym_preproc_error] = STATE(447),
    [sym_preproc_warning] = STATE(447),
    [sym_preproc_define] = STATE(447),
    [sym_preproc_undef] = STATE(447),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(2493),
    [anon_sym_ref] = ACTIONS(2467),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2495),
    [anon_sym_GT] = ACTIONS(2495),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1675),
    [anon_sym_TILDE] = ACTIONS(1675),
    [anon_sym_PLUS_PLUS] = ACTIONS(1675),
    [anon_sym_DASH_DASH] = ACTIONS(1675),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1675),
    [anon_sym_AMP] = ACTIONS(1675),
    [anon_sym_GT_EQ] = ACTIONS(2497),
    [anon_sym_LT_EQ] = ACTIONS(2497),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2499),
    [sym_predefined_type] = ACTIONS(2339),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2501),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [448] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3540),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2852),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3044),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(6251),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(3103),
    [sym_property_pattern_clause] = STATE(3159),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6727),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(4164),
    [sym_postfix_unary_expression] = STATE(4165),
    [sym_prefix_unary_expression] = STATE(4165),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(4164),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(4165),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(4164),
    [sym_member_access_expression] = STATE(3482),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(4165),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(4164),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(4164),
    [sym_typeof_expression] = STATE(4164),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3482),
    [sym_literal] = STATE(4164),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2835),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(448),
    [sym_preproc_endregion] = STATE(448),
    [sym_preproc_line] = STATE(448),
    [sym_preproc_pragma] = STATE(448),
    [sym_preproc_nullable] = STATE(448),
    [sym_preproc_error] = STATE(448),
    [sym_preproc_warning] = STATE(448),
    [sym_preproc_define] = STATE(448),
    [sym_preproc_undef] = STATE(448),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(2581),
    [anon_sym_ref] = ACTIONS(2467),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(1955),
    [anon_sym_GT] = ACTIONS(1955),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1581),
    [anon_sym_TILDE] = ACTIONS(1581),
    [anon_sym_PLUS_PLUS] = ACTIONS(1581),
    [anon_sym_DASH_DASH] = ACTIONS(1581),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1579),
    [anon_sym_DASH] = ACTIONS(1579),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1581),
    [anon_sym_AMP] = ACTIONS(1581),
    [anon_sym_GT_EQ] = ACTIONS(1957),
    [anon_sym_LT_EQ] = ACTIONS(1957),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2499),
    [sym_predefined_type] = ACTIONS(2339),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2583),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [449] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3548),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2918),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3078),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(3987),
    [sym_constant_pattern] = STATE(4086),
    [sym_parenthesized_pattern] = STATE(4086),
    [sym_var_pattern] = STATE(4086),
    [sym_type_pattern] = STATE(4086),
    [sym_list_pattern] = STATE(4086),
    [sym_recursive_pattern] = STATE(4086),
    [sym_positional_pattern_clause] = STATE(3148),
    [sym_property_pattern_clause] = STATE(3407),
    [sym_relational_pattern] = STATE(4086),
    [sym_negated_pattern] = STATE(4086),
    [sym_and_pattern] = STATE(4086),
    [sym_or_pattern] = STATE(4086),
    [sym_declaration_pattern] = STATE(4086),
    [sym_expression] = STATE(6694),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3989),
    [sym_postfix_unary_expression] = STATE(3990),
    [sym_prefix_unary_expression] = STATE(3990),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3989),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3990),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3989),
    [sym_member_access_expression] = STATE(3206),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3990),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3989),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3989),
    [sym_typeof_expression] = STATE(3989),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3206),
    [sym_literal] = STATE(3989),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2755),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(449),
    [sym_preproc_endregion] = STATE(449),
    [sym_preproc_line] = STATE(449),
    [sym_preproc_pragma] = STATE(449),
    [sym_preproc_nullable] = STATE(449),
    [sym_preproc_error] = STATE(449),
    [sym_preproc_warning] = STATE(449),
    [sym_preproc_define] = STATE(449),
    [sym_preproc_undef] = STATE(449),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(2377),
    [anon_sym_LPAREN] = ACTIONS(2549),
    [anon_sym_ref] = ACTIONS(2327),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2551),
    [anon_sym_GT] = ACTIONS(2551),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1919),
    [anon_sym_TILDE] = ACTIONS(1919),
    [anon_sym_PLUS_PLUS] = ACTIONS(1919),
    [anon_sym_DASH_DASH] = ACTIONS(1919),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1917),
    [anon_sym_DASH] = ACTIONS(1917),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1919),
    [anon_sym_AMP] = ACTIONS(1919),
    [anon_sym_GT_EQ] = ACTIONS(2553),
    [anon_sym_LT_EQ] = ACTIONS(2553),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2385),
    [sym_predefined_type] = ACTIONS(2387),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(2389),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2555),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [450] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3549),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2915),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3063),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(4137),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(3141),
    [sym_property_pattern_clause] = STATE(3273),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6740),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(4164),
    [sym_postfix_unary_expression] = STATE(4165),
    [sym_prefix_unary_expression] = STATE(4165),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(4164),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(4165),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(4164),
    [sym_member_access_expression] = STATE(3482),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(4165),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(4164),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(4164),
    [sym_typeof_expression] = STATE(4164),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3482),
    [sym_literal] = STATE(4164),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2755),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(450),
    [sym_preproc_endregion] = STATE(450),
    [sym_preproc_line] = STATE(450),
    [sym_preproc_pragma] = STATE(450),
    [sym_preproc_nullable] = STATE(450),
    [sym_preproc_error] = STATE(450),
    [sym_preproc_warning] = STATE(450),
    [sym_preproc_define] = STATE(450),
    [sym_preproc_undef] = STATE(450),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(2437),
    [anon_sym_ref] = ACTIONS(2327),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2439),
    [anon_sym_GT] = ACTIONS(2439),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1809),
    [anon_sym_TILDE] = ACTIONS(1809),
    [anon_sym_PLUS_PLUS] = ACTIONS(1809),
    [anon_sym_DASH_DASH] = ACTIONS(1809),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1807),
    [anon_sym_DASH] = ACTIONS(1807),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1809),
    [anon_sym_AMP] = ACTIONS(1809),
    [anon_sym_GT_EQ] = ACTIONS(2441),
    [anon_sym_LT_EQ] = ACTIONS(2441),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2349),
    [sym_predefined_type] = ACTIONS(2339),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2443),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [451] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3545),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2917),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3073),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(4992),
    [sym_constant_pattern] = STATE(5032),
    [sym_parenthesized_pattern] = STATE(5032),
    [sym_var_pattern] = STATE(5032),
    [sym_type_pattern] = STATE(5032),
    [sym_list_pattern] = STATE(5032),
    [sym_recursive_pattern] = STATE(5032),
    [sym_positional_pattern_clause] = STATE(3143),
    [sym_property_pattern_clause] = STATE(3360),
    [sym_relational_pattern] = STATE(5032),
    [sym_negated_pattern] = STATE(5032),
    [sym_and_pattern] = STATE(5032),
    [sym_or_pattern] = STATE(5032),
    [sym_declaration_pattern] = STATE(5032),
    [sym_expression] = STATE(6735),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(4990),
    [sym_postfix_unary_expression] = STATE(5037),
    [sym_prefix_unary_expression] = STATE(5037),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(4990),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5037),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(4990),
    [sym_member_access_expression] = STATE(3739),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5037),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(4990),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(4990),
    [sym_typeof_expression] = STATE(4990),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3739),
    [sym_literal] = STATE(4990),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2755),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(451),
    [sym_preproc_endregion] = STATE(451),
    [sym_preproc_line] = STATE(451),
    [sym_preproc_pragma] = STATE(451),
    [sym_preproc_nullable] = STATE(451),
    [sym_preproc_error] = STATE(451),
    [sym_preproc_warning] = STATE(451),
    [sym_preproc_define] = STATE(451),
    [sym_preproc_undef] = STATE(451),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(2477),
    [anon_sym_LPAREN] = ACTIONS(2539),
    [anon_sym_ref] = ACTIONS(2327),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2541),
    [anon_sym_GT] = ACTIONS(2541),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1937),
    [anon_sym_TILDE] = ACTIONS(1937),
    [anon_sym_PLUS_PLUS] = ACTIONS(1937),
    [anon_sym_DASH_DASH] = ACTIONS(1937),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1935),
    [anon_sym_DASH] = ACTIONS(1935),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1937),
    [anon_sym_AMP] = ACTIONS(1937),
    [anon_sym_GT_EQ] = ACTIONS(2543),
    [anon_sym_LT_EQ] = ACTIONS(2543),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2545),
    [sym_predefined_type] = ACTIONS(2487),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(2489),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2547),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [452] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3554),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2908),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3089),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(3987),
    [sym_constant_pattern] = STATE(4086),
    [sym_parenthesized_pattern] = STATE(4086),
    [sym_var_pattern] = STATE(4086),
    [sym_type_pattern] = STATE(4086),
    [sym_list_pattern] = STATE(4086),
    [sym_recursive_pattern] = STATE(4086),
    [sym_positional_pattern_clause] = STATE(3151),
    [sym_property_pattern_clause] = STATE(3422),
    [sym_relational_pattern] = STATE(4086),
    [sym_negated_pattern] = STATE(4086),
    [sym_and_pattern] = STATE(4086),
    [sym_or_pattern] = STATE(4086),
    [sym_declaration_pattern] = STATE(4086),
    [sym_expression] = STATE(6701),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3989),
    [sym_postfix_unary_expression] = STATE(3990),
    [sym_prefix_unary_expression] = STATE(3990),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3989),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3990),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3989),
    [sym_member_access_expression] = STATE(3206),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3990),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3989),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3989),
    [sym_typeof_expression] = STATE(3989),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3206),
    [sym_literal] = STATE(3989),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2755),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(452),
    [sym_preproc_endregion] = STATE(452),
    [sym_preproc_line] = STATE(452),
    [sym_preproc_pragma] = STATE(452),
    [sym_preproc_nullable] = STATE(452),
    [sym_preproc_error] = STATE(452),
    [sym_preproc_warning] = STATE(452),
    [sym_preproc_define] = STATE(452),
    [sym_preproc_undef] = STATE(452),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(2377),
    [anon_sym_LPAREN] = ACTIONS(2557),
    [anon_sym_ref] = ACTIONS(2327),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2559),
    [anon_sym_GT] = ACTIONS(2559),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1827),
    [anon_sym_TILDE] = ACTIONS(1827),
    [anon_sym_PLUS_PLUS] = ACTIONS(1827),
    [anon_sym_DASH_DASH] = ACTIONS(1827),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1825),
    [anon_sym_DASH] = ACTIONS(1825),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1827),
    [anon_sym_AMP] = ACTIONS(1827),
    [anon_sym_GT_EQ] = ACTIONS(2561),
    [anon_sym_LT_EQ] = ACTIONS(2561),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2385),
    [sym_predefined_type] = ACTIONS(2387),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(2389),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2563),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [453] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3555),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2893),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3062),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(4137),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(3170),
    [sym_property_pattern_clause] = STATE(3373),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6736),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(4164),
    [sym_postfix_unary_expression] = STATE(4165),
    [sym_prefix_unary_expression] = STATE(4165),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(4164),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(4165),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(4164),
    [sym_member_access_expression] = STATE(3482),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(4165),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(4164),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(4164),
    [sym_typeof_expression] = STATE(4164),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3482),
    [sym_literal] = STATE(4164),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2755),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(453),
    [sym_preproc_endregion] = STATE(453),
    [sym_preproc_line] = STATE(453),
    [sym_preproc_pragma] = STATE(453),
    [sym_preproc_nullable] = STATE(453),
    [sym_preproc_error] = STATE(453),
    [sym_preproc_warning] = STATE(453),
    [sym_preproc_define] = STATE(453),
    [sym_preproc_undef] = STATE(453),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(2343),
    [anon_sym_ref] = ACTIONS(2327),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2345),
    [anon_sym_GT] = ACTIONS(2345),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1863),
    [anon_sym_TILDE] = ACTIONS(1863),
    [anon_sym_PLUS_PLUS] = ACTIONS(1863),
    [anon_sym_DASH_DASH] = ACTIONS(1863),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1861),
    [anon_sym_DASH] = ACTIONS(1861),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1863),
    [anon_sym_AMP] = ACTIONS(1863),
    [anon_sym_GT_EQ] = ACTIONS(2347),
    [anon_sym_LT_EQ] = ACTIONS(2347),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2349),
    [sym_predefined_type] = ACTIONS(2339),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2351),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [454] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3545),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2917),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3073),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(5026),
    [sym_constant_pattern] = STATE(5032),
    [sym_parenthesized_pattern] = STATE(5032),
    [sym_var_pattern] = STATE(5032),
    [sym_type_pattern] = STATE(5032),
    [sym_list_pattern] = STATE(5032),
    [sym_recursive_pattern] = STATE(5032),
    [sym_positional_pattern_clause] = STATE(3143),
    [sym_property_pattern_clause] = STATE(3360),
    [sym_relational_pattern] = STATE(5032),
    [sym_negated_pattern] = STATE(5032),
    [sym_and_pattern] = STATE(5032),
    [sym_or_pattern] = STATE(5032),
    [sym_declaration_pattern] = STATE(5032),
    [sym_expression] = STATE(6735),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(4990),
    [sym_postfix_unary_expression] = STATE(5037),
    [sym_prefix_unary_expression] = STATE(5037),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(4990),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5037),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(4990),
    [sym_member_access_expression] = STATE(3739),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5037),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(4990),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(4990),
    [sym_typeof_expression] = STATE(4990),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3739),
    [sym_literal] = STATE(4990),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2755),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(454),
    [sym_preproc_endregion] = STATE(454),
    [sym_preproc_line] = STATE(454),
    [sym_preproc_pragma] = STATE(454),
    [sym_preproc_nullable] = STATE(454),
    [sym_preproc_error] = STATE(454),
    [sym_preproc_warning] = STATE(454),
    [sym_preproc_define] = STATE(454),
    [sym_preproc_undef] = STATE(454),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(2477),
    [anon_sym_LPAREN] = ACTIONS(2539),
    [anon_sym_ref] = ACTIONS(2327),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2541),
    [anon_sym_GT] = ACTIONS(2541),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1937),
    [anon_sym_TILDE] = ACTIONS(1937),
    [anon_sym_PLUS_PLUS] = ACTIONS(1937),
    [anon_sym_DASH_DASH] = ACTIONS(1937),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1935),
    [anon_sym_DASH] = ACTIONS(1935),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1937),
    [anon_sym_AMP] = ACTIONS(1937),
    [anon_sym_GT_EQ] = ACTIONS(2543),
    [anon_sym_LT_EQ] = ACTIONS(2543),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2545),
    [sym_predefined_type] = ACTIONS(2487),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(2489),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2547),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [455] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3552),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2911),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3060),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(3987),
    [sym_constant_pattern] = STATE(4086),
    [sym_parenthesized_pattern] = STATE(4086),
    [sym_var_pattern] = STATE(4086),
    [sym_type_pattern] = STATE(4086),
    [sym_list_pattern] = STATE(4086),
    [sym_recursive_pattern] = STATE(4086),
    [sym_positional_pattern_clause] = STATE(3163),
    [sym_property_pattern_clause] = STATE(3429),
    [sym_relational_pattern] = STATE(4086),
    [sym_negated_pattern] = STATE(4086),
    [sym_and_pattern] = STATE(4086),
    [sym_or_pattern] = STATE(4086),
    [sym_declaration_pattern] = STATE(4086),
    [sym_expression] = STATE(6703),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3989),
    [sym_postfix_unary_expression] = STATE(3990),
    [sym_prefix_unary_expression] = STATE(3990),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3989),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3990),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3989),
    [sym_member_access_expression] = STATE(3206),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3990),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3989),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3989),
    [sym_typeof_expression] = STATE(3989),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3206),
    [sym_literal] = STATE(3989),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2755),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(455),
    [sym_preproc_endregion] = STATE(455),
    [sym_preproc_line] = STATE(455),
    [sym_preproc_pragma] = STATE(455),
    [sym_preproc_nullable] = STATE(455),
    [sym_preproc_error] = STATE(455),
    [sym_preproc_warning] = STATE(455),
    [sym_preproc_define] = STATE(455),
    [sym_preproc_undef] = STATE(455),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(2377),
    [anon_sym_LPAREN] = ACTIONS(2573),
    [anon_sym_ref] = ACTIONS(2327),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2575),
    [anon_sym_GT] = ACTIONS(2575),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1845),
    [anon_sym_TILDE] = ACTIONS(1845),
    [anon_sym_PLUS_PLUS] = ACTIONS(1845),
    [anon_sym_DASH_DASH] = ACTIONS(1845),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1843),
    [anon_sym_DASH] = ACTIONS(1843),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1845),
    [anon_sym_AMP] = ACTIONS(1845),
    [anon_sym_GT_EQ] = ACTIONS(2577),
    [anon_sym_LT_EQ] = ACTIONS(2577),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2385),
    [sym_predefined_type] = ACTIONS(2387),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(2389),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2579),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [456] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3559),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2901),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3068),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(4137),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(3156),
    [sym_property_pattern_clause] = STATE(3380),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6741),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(4164),
    [sym_postfix_unary_expression] = STATE(4165),
    [sym_prefix_unary_expression] = STATE(4165),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(4164),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(4165),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(4164),
    [sym_member_access_expression] = STATE(3482),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(4165),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(4164),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(4164),
    [sym_typeof_expression] = STATE(4164),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3482),
    [sym_literal] = STATE(4164),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2755),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(456),
    [sym_preproc_endregion] = STATE(456),
    [sym_preproc_line] = STATE(456),
    [sym_preproc_pragma] = STATE(456),
    [sym_preproc_nullable] = STATE(456),
    [sym_preproc_error] = STATE(456),
    [sym_preproc_warning] = STATE(456),
    [sym_preproc_define] = STATE(456),
    [sym_preproc_undef] = STATE(456),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(2511),
    [anon_sym_ref] = ACTIONS(2327),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2513),
    [anon_sym_GT] = ACTIONS(2513),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1883),
    [anon_sym_TILDE] = ACTIONS(1883),
    [anon_sym_PLUS_PLUS] = ACTIONS(1883),
    [anon_sym_DASH_DASH] = ACTIONS(1883),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1881),
    [anon_sym_DASH] = ACTIONS(1881),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1883),
    [anon_sym_AMP] = ACTIONS(1883),
    [anon_sym_GT_EQ] = ACTIONS(2515),
    [anon_sym_LT_EQ] = ACTIONS(2515),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2349),
    [sym_predefined_type] = ACTIONS(2339),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2517),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [457] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3545),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2917),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3073),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(5010),
    [sym_constant_pattern] = STATE(5032),
    [sym_parenthesized_pattern] = STATE(5032),
    [sym_var_pattern] = STATE(5032),
    [sym_type_pattern] = STATE(5032),
    [sym_list_pattern] = STATE(5032),
    [sym_recursive_pattern] = STATE(5032),
    [sym_positional_pattern_clause] = STATE(3143),
    [sym_property_pattern_clause] = STATE(3360),
    [sym_relational_pattern] = STATE(5032),
    [sym_negated_pattern] = STATE(5032),
    [sym_and_pattern] = STATE(5032),
    [sym_or_pattern] = STATE(5032),
    [sym_declaration_pattern] = STATE(5032),
    [sym_expression] = STATE(6735),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(4990),
    [sym_postfix_unary_expression] = STATE(5037),
    [sym_prefix_unary_expression] = STATE(5037),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(4990),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5037),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(4990),
    [sym_member_access_expression] = STATE(3739),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5037),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(4990),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(4990),
    [sym_typeof_expression] = STATE(4990),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3739),
    [sym_literal] = STATE(4990),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2755),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(457),
    [sym_preproc_endregion] = STATE(457),
    [sym_preproc_line] = STATE(457),
    [sym_preproc_pragma] = STATE(457),
    [sym_preproc_nullable] = STATE(457),
    [sym_preproc_error] = STATE(457),
    [sym_preproc_warning] = STATE(457),
    [sym_preproc_define] = STATE(457),
    [sym_preproc_undef] = STATE(457),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(2477),
    [anon_sym_LPAREN] = ACTIONS(2539),
    [anon_sym_ref] = ACTIONS(2327),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2541),
    [anon_sym_GT] = ACTIONS(2541),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1937),
    [anon_sym_TILDE] = ACTIONS(1937),
    [anon_sym_PLUS_PLUS] = ACTIONS(1937),
    [anon_sym_DASH_DASH] = ACTIONS(1937),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1935),
    [anon_sym_DASH] = ACTIONS(1935),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1937),
    [anon_sym_AMP] = ACTIONS(1937),
    [anon_sym_GT_EQ] = ACTIONS(2543),
    [anon_sym_LT_EQ] = ACTIONS(2543),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2545),
    [sym_predefined_type] = ACTIONS(2487),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(2489),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2547),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [458] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3000),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2756),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3057),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(4137),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(2858),
    [sym_property_pattern_clause] = STATE(2881),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6697),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(4164),
    [sym_postfix_unary_expression] = STATE(4165),
    [sym_prefix_unary_expression] = STATE(4165),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(4164),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(4165),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(4164),
    [sym_member_access_expression] = STATE(3482),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(4165),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(4164),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(4164),
    [sym_typeof_expression] = STATE(4164),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3482),
    [sym_literal] = STATE(4164),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2835),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(458),
    [sym_preproc_endregion] = STATE(458),
    [sym_preproc_line] = STATE(458),
    [sym_preproc_pragma] = STATE(458),
    [sym_preproc_nullable] = STATE(458),
    [sym_preproc_error] = STATE(458),
    [sym_preproc_warning] = STATE(458),
    [sym_preproc_define] = STATE(458),
    [sym_preproc_undef] = STATE(458),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(2493),
    [anon_sym_ref] = ACTIONS(2467),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2495),
    [anon_sym_GT] = ACTIONS(2495),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1675),
    [anon_sym_TILDE] = ACTIONS(1675),
    [anon_sym_PLUS_PLUS] = ACTIONS(1675),
    [anon_sym_DASH_DASH] = ACTIONS(1675),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1675),
    [anon_sym_AMP] = ACTIONS(1675),
    [anon_sym_GT_EQ] = ACTIONS(2497),
    [anon_sym_LT_EQ] = ACTIONS(2497),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2499),
    [sym_predefined_type] = ACTIONS(2339),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2501),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [459] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(2999),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2761),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3041),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(6168),
    [sym_constant_pattern] = STATE(4086),
    [sym_parenthesized_pattern] = STATE(4086),
    [sym_var_pattern] = STATE(4086),
    [sym_type_pattern] = STATE(4086),
    [sym_list_pattern] = STATE(4086),
    [sym_recursive_pattern] = STATE(4086),
    [sym_positional_pattern_clause] = STATE(2840),
    [sym_property_pattern_clause] = STATE(2874),
    [sym_relational_pattern] = STATE(4086),
    [sym_negated_pattern] = STATE(4086),
    [sym_and_pattern] = STATE(4086),
    [sym_or_pattern] = STATE(4086),
    [sym_declaration_pattern] = STATE(4086),
    [sym_expression] = STATE(6707),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3989),
    [sym_postfix_unary_expression] = STATE(3990),
    [sym_prefix_unary_expression] = STATE(3990),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3989),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3990),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3989),
    [sym_member_access_expression] = STATE(3206),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3990),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3989),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3989),
    [sym_typeof_expression] = STATE(3989),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3206),
    [sym_literal] = STATE(3989),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2835),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(459),
    [sym_preproc_endregion] = STATE(459),
    [sym_preproc_line] = STATE(459),
    [sym_preproc_pragma] = STATE(459),
    [sym_preproc_nullable] = STATE(459),
    [sym_preproc_error] = STATE(459),
    [sym_preproc_warning] = STATE(459),
    [sym_preproc_define] = STATE(459),
    [sym_preproc_undef] = STATE(459),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(2377),
    [anon_sym_LPAREN] = ACTIONS(2519),
    [anon_sym_ref] = ACTIONS(2467),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2521),
    [anon_sym_GT] = ACTIONS(2521),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1659),
    [anon_sym_TILDE] = ACTIONS(1659),
    [anon_sym_PLUS_PLUS] = ACTIONS(1659),
    [anon_sym_DASH_DASH] = ACTIONS(1659),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1657),
    [anon_sym_DASH] = ACTIONS(1657),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1659),
    [anon_sym_AMP] = ACTIONS(1659),
    [anon_sym_GT_EQ] = ACTIONS(2523),
    [anon_sym_LT_EQ] = ACTIONS(2523),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2473),
    [sym_predefined_type] = ACTIONS(2387),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(2389),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2525),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [460] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3000),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2756),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(2809),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(5409),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(2858),
    [sym_property_pattern_clause] = STATE(2881),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6719),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(4164),
    [sym_postfix_unary_expression] = STATE(4165),
    [sym_prefix_unary_expression] = STATE(4165),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(4164),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(4165),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(4164),
    [sym_member_access_expression] = STATE(3482),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(4165),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(4164),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(4164),
    [sym_typeof_expression] = STATE(4164),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3482),
    [sym_literal] = STATE(4164),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2755),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(460),
    [sym_preproc_endregion] = STATE(460),
    [sym_preproc_line] = STATE(460),
    [sym_preproc_pragma] = STATE(460),
    [sym_preproc_nullable] = STATE(460),
    [sym_preproc_error] = STATE(460),
    [sym_preproc_warning] = STATE(460),
    [sym_preproc_define] = STATE(460),
    [sym_preproc_undef] = STATE(460),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(2393),
    [anon_sym_ref] = ACTIONS(2327),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(1077),
    [anon_sym_GT] = ACTIONS(1077),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1083),
    [anon_sym_PLUS_PLUS] = ACTIONS(1083),
    [anon_sym_DASH_DASH] = ACTIONS(1083),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1085),
    [anon_sym_DASH] = ACTIONS(1085),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1083),
    [anon_sym_AMP] = ACTIONS(1083),
    [anon_sym_GT_EQ] = ACTIONS(1087),
    [anon_sym_LT_EQ] = ACTIONS(1087),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2349),
    [sym_predefined_type] = ACTIONS(2339),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2395),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [461] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3535),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2846),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3042),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(6019),
    [sym_constant_pattern] = STATE(4086),
    [sym_parenthesized_pattern] = STATE(4086),
    [sym_var_pattern] = STATE(4086),
    [sym_type_pattern] = STATE(4086),
    [sym_list_pattern] = STATE(4086),
    [sym_recursive_pattern] = STATE(4086),
    [sym_positional_pattern_clause] = STATE(3120),
    [sym_property_pattern_clause] = STATE(3169),
    [sym_relational_pattern] = STATE(4086),
    [sym_negated_pattern] = STATE(4086),
    [sym_and_pattern] = STATE(4086),
    [sym_or_pattern] = STATE(4086),
    [sym_declaration_pattern] = STATE(4086),
    [sym_expression] = STATE(6700),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3989),
    [sym_postfix_unary_expression] = STATE(3990),
    [sym_prefix_unary_expression] = STATE(3990),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3989),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3990),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3989),
    [sym_member_access_expression] = STATE(3206),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3990),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3989),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3989),
    [sym_typeof_expression] = STATE(3989),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3206),
    [sym_literal] = STATE(3989),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2835),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(461),
    [sym_preproc_endregion] = STATE(461),
    [sym_preproc_line] = STATE(461),
    [sym_preproc_pragma] = STATE(461),
    [sym_preproc_nullable] = STATE(461),
    [sym_preproc_error] = STATE(461),
    [sym_preproc_warning] = STATE(461),
    [sym_preproc_define] = STATE(461),
    [sym_preproc_undef] = STATE(461),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(2377),
    [anon_sym_LPAREN] = ACTIONS(2465),
    [anon_sym_ref] = ACTIONS(2467),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2469),
    [anon_sym_GT] = ACTIONS(2469),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1791),
    [anon_sym_TILDE] = ACTIONS(1791),
    [anon_sym_PLUS_PLUS] = ACTIONS(1791),
    [anon_sym_DASH_DASH] = ACTIONS(1791),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1789),
    [anon_sym_DASH] = ACTIONS(1789),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1791),
    [anon_sym_AMP] = ACTIONS(1791),
    [anon_sym_GT_EQ] = ACTIONS(2471),
    [anon_sym_LT_EQ] = ACTIONS(2471),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2473),
    [sym_predefined_type] = ACTIONS(2387),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(2389),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2475),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [462] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(2999),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2761),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3051),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(3987),
    [sym_constant_pattern] = STATE(4086),
    [sym_parenthesized_pattern] = STATE(4086),
    [sym_var_pattern] = STATE(4086),
    [sym_type_pattern] = STATE(4086),
    [sym_list_pattern] = STATE(4086),
    [sym_recursive_pattern] = STATE(4086),
    [sym_positional_pattern_clause] = STATE(2840),
    [sym_property_pattern_clause] = STATE(2874),
    [sym_relational_pattern] = STATE(4086),
    [sym_negated_pattern] = STATE(4086),
    [sym_and_pattern] = STATE(4086),
    [sym_or_pattern] = STATE(4086),
    [sym_declaration_pattern] = STATE(4086),
    [sym_expression] = STATE(6707),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3989),
    [sym_postfix_unary_expression] = STATE(3990),
    [sym_prefix_unary_expression] = STATE(3990),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3989),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3990),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3989),
    [sym_member_access_expression] = STATE(3206),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3990),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3989),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3989),
    [sym_typeof_expression] = STATE(3989),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3206),
    [sym_literal] = STATE(3989),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2835),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(462),
    [sym_preproc_endregion] = STATE(462),
    [sym_preproc_line] = STATE(462),
    [sym_preproc_pragma] = STATE(462),
    [sym_preproc_nullable] = STATE(462),
    [sym_preproc_error] = STATE(462),
    [sym_preproc_warning] = STATE(462),
    [sym_preproc_define] = STATE(462),
    [sym_preproc_undef] = STATE(462),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(2377),
    [anon_sym_LPAREN] = ACTIONS(2519),
    [anon_sym_ref] = ACTIONS(2467),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2521),
    [anon_sym_GT] = ACTIONS(2521),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1659),
    [anon_sym_TILDE] = ACTIONS(1659),
    [anon_sym_PLUS_PLUS] = ACTIONS(1659),
    [anon_sym_DASH_DASH] = ACTIONS(1659),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1657),
    [anon_sym_DASH] = ACTIONS(1657),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1659),
    [anon_sym_AMP] = ACTIONS(1659),
    [anon_sym_GT_EQ] = ACTIONS(2523),
    [anon_sym_LT_EQ] = ACTIONS(2523),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2473),
    [sym_predefined_type] = ACTIONS(2387),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(2389),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2525),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [463] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(2999),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2761),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3041),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(4029),
    [sym_constant_pattern] = STATE(4086),
    [sym_parenthesized_pattern] = STATE(4086),
    [sym_var_pattern] = STATE(4086),
    [sym_type_pattern] = STATE(4086),
    [sym_list_pattern] = STATE(4086),
    [sym_recursive_pattern] = STATE(4086),
    [sym_positional_pattern_clause] = STATE(2840),
    [sym_property_pattern_clause] = STATE(2874),
    [sym_relational_pattern] = STATE(4086),
    [sym_negated_pattern] = STATE(4086),
    [sym_and_pattern] = STATE(4086),
    [sym_or_pattern] = STATE(4086),
    [sym_declaration_pattern] = STATE(4086),
    [sym_expression] = STATE(6707),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3989),
    [sym_postfix_unary_expression] = STATE(3990),
    [sym_prefix_unary_expression] = STATE(3990),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3989),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3990),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3989),
    [sym_member_access_expression] = STATE(3206),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3990),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3989),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3989),
    [sym_typeof_expression] = STATE(3989),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3206),
    [sym_literal] = STATE(3989),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2835),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(463),
    [sym_preproc_endregion] = STATE(463),
    [sym_preproc_line] = STATE(463),
    [sym_preproc_pragma] = STATE(463),
    [sym_preproc_nullable] = STATE(463),
    [sym_preproc_error] = STATE(463),
    [sym_preproc_warning] = STATE(463),
    [sym_preproc_define] = STATE(463),
    [sym_preproc_undef] = STATE(463),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(2377),
    [anon_sym_LPAREN] = ACTIONS(2519),
    [anon_sym_ref] = ACTIONS(2467),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2521),
    [anon_sym_GT] = ACTIONS(2521),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1659),
    [anon_sym_TILDE] = ACTIONS(1659),
    [anon_sym_PLUS_PLUS] = ACTIONS(1659),
    [anon_sym_DASH_DASH] = ACTIONS(1659),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1657),
    [anon_sym_DASH] = ACTIONS(1657),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1659),
    [anon_sym_AMP] = ACTIONS(1659),
    [anon_sym_GT_EQ] = ACTIONS(2523),
    [anon_sym_LT_EQ] = ACTIONS(2523),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2473),
    [sym_predefined_type] = ACTIONS(2387),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(2389),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2525),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [464] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2802),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(5351),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_pattern] = STATE(8350),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6158),
    [sym_property_pattern_clause] = STATE(6724),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6719),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5302),
    [sym_postfix_unary_expression] = STATE(5343),
    [sym_prefix_unary_expression] = STATE(5343),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5302),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5343),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5302),
    [sym_member_access_expression] = STATE(3862),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5343),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(5302),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5302),
    [sym_typeof_expression] = STATE(5302),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3862),
    [sym_literal] = STATE(5302),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(464),
    [sym_preproc_endregion] = STATE(464),
    [sym_preproc_line] = STATE(464),
    [sym_preproc_pragma] = STATE(464),
    [sym_preproc_nullable] = STATE(464),
    [sym_preproc_error] = STATE(464),
    [sym_preproc_warning] = STATE(464),
    [sym_preproc_define] = STATE(464),
    [sym_preproc_undef] = STATE(464),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1067),
    [anon_sym_ref] = ACTIONS(2593),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(1077),
    [anon_sym_GT] = ACTIONS(1077),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1083),
    [anon_sym_PLUS_PLUS] = ACTIONS(1083),
    [anon_sym_DASH_DASH] = ACTIONS(1083),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1085),
    [anon_sym_DASH] = ACTIONS(1085),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1083),
    [anon_sym_AMP] = ACTIONS(1083),
    [anon_sym_GT_EQ] = ACTIONS(1087),
    [anon_sym_LT_EQ] = ACTIONS(1087),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2319),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1091),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(1137),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [465] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6759),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2844),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6163),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_pattern] = STATE(8335),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6721),
    [sym_property_pattern_clause] = STATE(6770),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6727),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5060),
    [sym_postfix_unary_expression] = STATE(5061),
    [sym_prefix_unary_expression] = STATE(5061),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5060),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5061),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5060),
    [sym_member_access_expression] = STATE(3797),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5061),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(5060),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5060),
    [sym_typeof_expression] = STATE(5060),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3797),
    [sym_literal] = STATE(5060),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(465),
    [sym_preproc_endregion] = STATE(465),
    [sym_preproc_line] = STATE(465),
    [sym_preproc_pragma] = STATE(465),
    [sym_preproc_nullable] = STATE(465),
    [sym_preproc_error] = STATE(465),
    [sym_preproc_warning] = STATE(465),
    [sym_preproc_define] = STATE(465),
    [sym_preproc_undef] = STATE(465),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1949),
    [anon_sym_ref] = ACTIONS(1951),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(1955),
    [anon_sym_GT] = ACTIONS(1955),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1581),
    [anon_sym_TILDE] = ACTIONS(1581),
    [anon_sym_PLUS_PLUS] = ACTIONS(1581),
    [anon_sym_DASH_DASH] = ACTIONS(1581),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1579),
    [anon_sym_DASH] = ACTIONS(1579),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1581),
    [anon_sym_AMP] = ACTIONS(1581),
    [anon_sym_GT_EQ] = ACTIONS(1957),
    [anon_sym_LT_EQ] = ACTIONS(1957),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(1089),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1959),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(1961),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [466] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2802),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(5351),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_pattern] = STATE(8237),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6158),
    [sym_property_pattern_clause] = STATE(6724),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6719),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5302),
    [sym_postfix_unary_expression] = STATE(5343),
    [sym_prefix_unary_expression] = STATE(5343),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5302),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5343),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5302),
    [sym_member_access_expression] = STATE(3862),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5343),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(5302),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5302),
    [sym_typeof_expression] = STATE(5302),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3862),
    [sym_literal] = STATE(5302),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(466),
    [sym_preproc_endregion] = STATE(466),
    [sym_preproc_line] = STATE(466),
    [sym_preproc_pragma] = STATE(466),
    [sym_preproc_nullable] = STATE(466),
    [sym_preproc_error] = STATE(466),
    [sym_preproc_warning] = STATE(466),
    [sym_preproc_define] = STATE(466),
    [sym_preproc_undef] = STATE(466),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1067),
    [anon_sym_ref] = ACTIONS(2281),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(1077),
    [anon_sym_GT] = ACTIONS(1077),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1083),
    [anon_sym_PLUS_PLUS] = ACTIONS(1083),
    [anon_sym_DASH_DASH] = ACTIONS(1083),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1085),
    [anon_sym_DASH] = ACTIONS(1085),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1083),
    [anon_sym_AMP] = ACTIONS(1083),
    [anon_sym_GT_EQ] = ACTIONS(1087),
    [anon_sym_LT_EQ] = ACTIONS(1087),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(1089),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1091),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(1101),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [467] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2802),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(5351),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_pattern] = STATE(8259),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6158),
    [sym_property_pattern_clause] = STATE(6724),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6719),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5302),
    [sym_postfix_unary_expression] = STATE(5343),
    [sym_prefix_unary_expression] = STATE(5343),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5302),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5343),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5302),
    [sym_member_access_expression] = STATE(3862),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5343),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(5302),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5302),
    [sym_typeof_expression] = STATE(5302),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3862),
    [sym_literal] = STATE(5302),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(467),
    [sym_preproc_endregion] = STATE(467),
    [sym_preproc_line] = STATE(467),
    [sym_preproc_pragma] = STATE(467),
    [sym_preproc_nullable] = STATE(467),
    [sym_preproc_error] = STATE(467),
    [sym_preproc_warning] = STATE(467),
    [sym_preproc_define] = STATE(467),
    [sym_preproc_undef] = STATE(467),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1067),
    [anon_sym_ref] = ACTIONS(2593),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(1077),
    [anon_sym_GT] = ACTIONS(1077),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1083),
    [anon_sym_PLUS_PLUS] = ACTIONS(1083),
    [anon_sym_DASH_DASH] = ACTIONS(1083),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1085),
    [anon_sym_DASH] = ACTIONS(1085),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1083),
    [anon_sym_AMP] = ACTIONS(1083),
    [anon_sym_GT_EQ] = ACTIONS(1087),
    [anon_sym_LT_EQ] = ACTIONS(1087),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2319),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1091),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(1137),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [468] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2802),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(5351),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_pattern] = STATE(4198),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6158),
    [sym_property_pattern_clause] = STATE(6724),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6719),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5302),
    [sym_postfix_unary_expression] = STATE(5343),
    [sym_prefix_unary_expression] = STATE(5343),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5302),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5343),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5302),
    [sym_member_access_expression] = STATE(3862),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5343),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(5302),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5302),
    [sym_typeof_expression] = STATE(5302),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3862),
    [sym_literal] = STATE(5302),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(468),
    [sym_preproc_endregion] = STATE(468),
    [sym_preproc_line] = STATE(468),
    [sym_preproc_pragma] = STATE(468),
    [sym_preproc_nullable] = STATE(468),
    [sym_preproc_error] = STATE(468),
    [sym_preproc_warning] = STATE(468),
    [sym_preproc_define] = STATE(468),
    [sym_preproc_undef] = STATE(468),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1067),
    [anon_sym_ref] = ACTIONS(2593),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(1077),
    [anon_sym_GT] = ACTIONS(1077),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1083),
    [anon_sym_PLUS_PLUS] = ACTIONS(1083),
    [anon_sym_DASH_DASH] = ACTIONS(1083),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1085),
    [anon_sym_DASH] = ACTIONS(1085),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1083),
    [anon_sym_AMP] = ACTIONS(1083),
    [anon_sym_GT_EQ] = ACTIONS(1087),
    [anon_sym_LT_EQ] = ACTIONS(1087),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2319),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1091),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(1137),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [469] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2802),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(5351),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_pattern] = STATE(8356),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6158),
    [sym_property_pattern_clause] = STATE(6724),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6719),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5302),
    [sym_postfix_unary_expression] = STATE(5343),
    [sym_prefix_unary_expression] = STATE(5343),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5302),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5343),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5302),
    [sym_member_access_expression] = STATE(3862),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5343),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(5302),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5302),
    [sym_typeof_expression] = STATE(5302),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3862),
    [sym_literal] = STATE(5302),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(469),
    [sym_preproc_endregion] = STATE(469),
    [sym_preproc_line] = STATE(469),
    [sym_preproc_pragma] = STATE(469),
    [sym_preproc_nullable] = STATE(469),
    [sym_preproc_error] = STATE(469),
    [sym_preproc_warning] = STATE(469),
    [sym_preproc_define] = STATE(469),
    [sym_preproc_undef] = STATE(469),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1067),
    [anon_sym_ref] = ACTIONS(2593),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(1077),
    [anon_sym_GT] = ACTIONS(1077),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1083),
    [anon_sym_PLUS_PLUS] = ACTIONS(1083),
    [anon_sym_DASH_DASH] = ACTIONS(1083),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1085),
    [anon_sym_DASH] = ACTIONS(1085),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1083),
    [anon_sym_AMP] = ACTIONS(1083),
    [anon_sym_GT_EQ] = ACTIONS(1087),
    [anon_sym_LT_EQ] = ACTIONS(1087),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2319),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1091),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(1137),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [470] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3535),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2846),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3042),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(4029),
    [sym_constant_pattern] = STATE(4086),
    [sym_parenthesized_pattern] = STATE(4086),
    [sym_var_pattern] = STATE(4086),
    [sym_type_pattern] = STATE(4086),
    [sym_list_pattern] = STATE(4086),
    [sym_recursive_pattern] = STATE(4086),
    [sym_positional_pattern_clause] = STATE(3120),
    [sym_property_pattern_clause] = STATE(3169),
    [sym_relational_pattern] = STATE(4086),
    [sym_negated_pattern] = STATE(4086),
    [sym_and_pattern] = STATE(4086),
    [sym_or_pattern] = STATE(4086),
    [sym_declaration_pattern] = STATE(4086),
    [sym_expression] = STATE(6700),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3989),
    [sym_postfix_unary_expression] = STATE(3990),
    [sym_prefix_unary_expression] = STATE(3990),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3989),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3990),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3989),
    [sym_member_access_expression] = STATE(3206),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3990),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3989),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3989),
    [sym_typeof_expression] = STATE(3989),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3206),
    [sym_literal] = STATE(3989),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2835),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(470),
    [sym_preproc_endregion] = STATE(470),
    [sym_preproc_line] = STATE(470),
    [sym_preproc_pragma] = STATE(470),
    [sym_preproc_nullable] = STATE(470),
    [sym_preproc_error] = STATE(470),
    [sym_preproc_warning] = STATE(470),
    [sym_preproc_define] = STATE(470),
    [sym_preproc_undef] = STATE(470),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(2377),
    [anon_sym_LPAREN] = ACTIONS(2465),
    [anon_sym_ref] = ACTIONS(2467),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2469),
    [anon_sym_GT] = ACTIONS(2469),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1791),
    [anon_sym_TILDE] = ACTIONS(1791),
    [anon_sym_PLUS_PLUS] = ACTIONS(1791),
    [anon_sym_DASH_DASH] = ACTIONS(1791),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1789),
    [anon_sym_DASH] = ACTIONS(1789),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1791),
    [anon_sym_AMP] = ACTIONS(1791),
    [anon_sym_GT_EQ] = ACTIONS(2471),
    [anon_sym_LT_EQ] = ACTIONS(2471),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2473),
    [sym_predefined_type] = ACTIONS(2387),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(2389),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2475),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [471] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2802),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(5351),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_pattern] = STATE(7987),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6158),
    [sym_property_pattern_clause] = STATE(6724),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6719),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5302),
    [sym_postfix_unary_expression] = STATE(5343),
    [sym_prefix_unary_expression] = STATE(5343),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5302),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5343),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5302),
    [sym_member_access_expression] = STATE(3862),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5343),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(5302),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5302),
    [sym_typeof_expression] = STATE(5302),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3862),
    [sym_literal] = STATE(5302),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(471),
    [sym_preproc_endregion] = STATE(471),
    [sym_preproc_line] = STATE(471),
    [sym_preproc_pragma] = STATE(471),
    [sym_preproc_nullable] = STATE(471),
    [sym_preproc_error] = STATE(471),
    [sym_preproc_warning] = STATE(471),
    [sym_preproc_define] = STATE(471),
    [sym_preproc_undef] = STATE(471),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1067),
    [anon_sym_ref] = ACTIONS(2281),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(1077),
    [anon_sym_GT] = ACTIONS(1077),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1083),
    [anon_sym_PLUS_PLUS] = ACTIONS(1083),
    [anon_sym_DASH_DASH] = ACTIONS(1083),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1085),
    [anon_sym_DASH] = ACTIONS(1085),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1083),
    [anon_sym_AMP] = ACTIONS(1083),
    [anon_sym_GT_EQ] = ACTIONS(1087),
    [anon_sym_LT_EQ] = ACTIONS(1087),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(1089),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1091),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(1101),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [472] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6759),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2844),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6163),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_pattern] = STATE(4198),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6721),
    [sym_property_pattern_clause] = STATE(6770),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6727),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5060),
    [sym_postfix_unary_expression] = STATE(5061),
    [sym_prefix_unary_expression] = STATE(5061),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5060),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5061),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5060),
    [sym_member_access_expression] = STATE(3797),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5061),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(5060),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5060),
    [sym_typeof_expression] = STATE(5060),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3797),
    [sym_literal] = STATE(5060),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(472),
    [sym_preproc_endregion] = STATE(472),
    [sym_preproc_line] = STATE(472),
    [sym_preproc_pragma] = STATE(472),
    [sym_preproc_nullable] = STATE(472),
    [sym_preproc_error] = STATE(472),
    [sym_preproc_warning] = STATE(472),
    [sym_preproc_define] = STATE(472),
    [sym_preproc_undef] = STATE(472),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1949),
    [anon_sym_ref] = ACTIONS(1951),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(1955),
    [anon_sym_GT] = ACTIONS(1955),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1581),
    [anon_sym_TILDE] = ACTIONS(1581),
    [anon_sym_PLUS_PLUS] = ACTIONS(1581),
    [anon_sym_DASH_DASH] = ACTIONS(1581),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1579),
    [anon_sym_DASH] = ACTIONS(1579),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1581),
    [anon_sym_AMP] = ACTIONS(1581),
    [anon_sym_GT_EQ] = ACTIONS(1957),
    [anon_sym_LT_EQ] = ACTIONS(1957),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(1089),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1959),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(1961),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [473] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3211),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2756),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(2809),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(5720),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(2858),
    [sym_property_pattern_clause] = STATE(2881),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6722),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(4164),
    [sym_postfix_unary_expression] = STATE(4165),
    [sym_prefix_unary_expression] = STATE(4165),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(4164),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(4165),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(4164),
    [sym_member_access_expression] = STATE(3482),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(4165),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(4164),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(4164),
    [sym_typeof_expression] = STATE(4164),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3482),
    [sym_literal] = STATE(4164),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2776),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(473),
    [sym_preproc_endregion] = STATE(473),
    [sym_preproc_line] = STATE(473),
    [sym_preproc_pragma] = STATE(473),
    [sym_preproc_nullable] = STATE(473),
    [sym_preproc_error] = STATE(473),
    [sym_preproc_warning] = STATE(473),
    [sym_preproc_define] = STATE(473),
    [sym_preproc_undef] = STATE(473),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(2503),
    [anon_sym_ref] = ACTIONS(2447),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2505),
    [anon_sym_GT] = ACTIONS(2505),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1117),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_AMP] = ACTIONS(1117),
    [anon_sym_GT_EQ] = ACTIONS(2507),
    [anon_sym_LT_EQ] = ACTIONS(2507),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2453),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2349),
    [sym_predefined_type] = ACTIONS(2339),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2509),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [474] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3535),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2846),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3042),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(5793),
    [sym_constant_pattern] = STATE(4086),
    [sym_parenthesized_pattern] = STATE(4086),
    [sym_var_pattern] = STATE(4086),
    [sym_type_pattern] = STATE(4086),
    [sym_list_pattern] = STATE(4086),
    [sym_recursive_pattern] = STATE(4086),
    [sym_positional_pattern_clause] = STATE(3120),
    [sym_property_pattern_clause] = STATE(3169),
    [sym_relational_pattern] = STATE(4086),
    [sym_negated_pattern] = STATE(4086),
    [sym_and_pattern] = STATE(4086),
    [sym_or_pattern] = STATE(4086),
    [sym_declaration_pattern] = STATE(4086),
    [sym_expression] = STATE(6700),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3989),
    [sym_postfix_unary_expression] = STATE(3990),
    [sym_prefix_unary_expression] = STATE(3990),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3989),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3990),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3989),
    [sym_member_access_expression] = STATE(3206),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3990),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3989),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3989),
    [sym_typeof_expression] = STATE(3989),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3206),
    [sym_literal] = STATE(3989),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2835),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(474),
    [sym_preproc_endregion] = STATE(474),
    [sym_preproc_line] = STATE(474),
    [sym_preproc_pragma] = STATE(474),
    [sym_preproc_nullable] = STATE(474),
    [sym_preproc_error] = STATE(474),
    [sym_preproc_warning] = STATE(474),
    [sym_preproc_define] = STATE(474),
    [sym_preproc_undef] = STATE(474),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(2377),
    [anon_sym_LPAREN] = ACTIONS(2465),
    [anon_sym_ref] = ACTIONS(2467),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2469),
    [anon_sym_GT] = ACTIONS(2469),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1791),
    [anon_sym_TILDE] = ACTIONS(1791),
    [anon_sym_PLUS_PLUS] = ACTIONS(1791),
    [anon_sym_DASH_DASH] = ACTIONS(1791),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1789),
    [anon_sym_DASH] = ACTIONS(1789),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1791),
    [anon_sym_AMP] = ACTIONS(1791),
    [anon_sym_GT_EQ] = ACTIONS(2471),
    [anon_sym_LT_EQ] = ACTIONS(2471),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2473),
    [sym_predefined_type] = ACTIONS(2387),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(2389),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2475),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [475] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3548),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2918),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3082),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(6238),
    [sym_constant_pattern] = STATE(4086),
    [sym_parenthesized_pattern] = STATE(4086),
    [sym_var_pattern] = STATE(4086),
    [sym_type_pattern] = STATE(4086),
    [sym_list_pattern] = STATE(4086),
    [sym_recursive_pattern] = STATE(4086),
    [sym_positional_pattern_clause] = STATE(3148),
    [sym_property_pattern_clause] = STATE(3407),
    [sym_relational_pattern] = STATE(4086),
    [sym_negated_pattern] = STATE(4086),
    [sym_and_pattern] = STATE(4086),
    [sym_or_pattern] = STATE(4086),
    [sym_declaration_pattern] = STATE(4086),
    [sym_expression] = STATE(6694),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3989),
    [sym_postfix_unary_expression] = STATE(3990),
    [sym_prefix_unary_expression] = STATE(3990),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3989),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3990),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3989),
    [sym_member_access_expression] = STATE(3206),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3990),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3989),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3989),
    [sym_typeof_expression] = STATE(3989),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3206),
    [sym_literal] = STATE(3989),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2755),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(475),
    [sym_preproc_endregion] = STATE(475),
    [sym_preproc_line] = STATE(475),
    [sym_preproc_pragma] = STATE(475),
    [sym_preproc_nullable] = STATE(475),
    [sym_preproc_error] = STATE(475),
    [sym_preproc_warning] = STATE(475),
    [sym_preproc_define] = STATE(475),
    [sym_preproc_undef] = STATE(475),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(2377),
    [anon_sym_LPAREN] = ACTIONS(2549),
    [anon_sym_ref] = ACTIONS(2327),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2551),
    [anon_sym_GT] = ACTIONS(2551),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1919),
    [anon_sym_TILDE] = ACTIONS(1919),
    [anon_sym_PLUS_PLUS] = ACTIONS(1919),
    [anon_sym_DASH_DASH] = ACTIONS(1919),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1917),
    [anon_sym_DASH] = ACTIONS(1917),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1919),
    [anon_sym_AMP] = ACTIONS(1919),
    [anon_sym_GT_EQ] = ACTIONS(2553),
    [anon_sym_LT_EQ] = ACTIONS(2553),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2385),
    [sym_predefined_type] = ACTIONS(2387),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(2389),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2555),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [476] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3552),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2911),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3064),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(6159),
    [sym_constant_pattern] = STATE(4086),
    [sym_parenthesized_pattern] = STATE(4086),
    [sym_var_pattern] = STATE(4086),
    [sym_type_pattern] = STATE(4086),
    [sym_list_pattern] = STATE(4086),
    [sym_recursive_pattern] = STATE(4086),
    [sym_positional_pattern_clause] = STATE(3163),
    [sym_property_pattern_clause] = STATE(3429),
    [sym_relational_pattern] = STATE(4086),
    [sym_negated_pattern] = STATE(4086),
    [sym_and_pattern] = STATE(4086),
    [sym_or_pattern] = STATE(4086),
    [sym_declaration_pattern] = STATE(4086),
    [sym_expression] = STATE(6703),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3989),
    [sym_postfix_unary_expression] = STATE(3990),
    [sym_prefix_unary_expression] = STATE(3990),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3989),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3990),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3989),
    [sym_member_access_expression] = STATE(3206),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3990),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3989),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3989),
    [sym_typeof_expression] = STATE(3989),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3206),
    [sym_literal] = STATE(3989),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2755),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(476),
    [sym_preproc_endregion] = STATE(476),
    [sym_preproc_line] = STATE(476),
    [sym_preproc_pragma] = STATE(476),
    [sym_preproc_nullable] = STATE(476),
    [sym_preproc_error] = STATE(476),
    [sym_preproc_warning] = STATE(476),
    [sym_preproc_define] = STATE(476),
    [sym_preproc_undef] = STATE(476),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(2377),
    [anon_sym_LPAREN] = ACTIONS(2573),
    [anon_sym_ref] = ACTIONS(2327),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2575),
    [anon_sym_GT] = ACTIONS(2575),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1845),
    [anon_sym_TILDE] = ACTIONS(1845),
    [anon_sym_PLUS_PLUS] = ACTIONS(1845),
    [anon_sym_DASH_DASH] = ACTIONS(1845),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1843),
    [anon_sym_DASH] = ACTIONS(1843),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1845),
    [anon_sym_AMP] = ACTIONS(1845),
    [anon_sym_GT_EQ] = ACTIONS(2577),
    [anon_sym_LT_EQ] = ACTIONS(2577),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2385),
    [sym_predefined_type] = ACTIONS(2387),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(2389),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2579),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [477] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3211),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2756),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(2814),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(5721),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(2858),
    [sym_property_pattern_clause] = STATE(2881),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6722),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(4164),
    [sym_postfix_unary_expression] = STATE(4165),
    [sym_prefix_unary_expression] = STATE(4165),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(4164),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(4165),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(4164),
    [sym_member_access_expression] = STATE(3482),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(4165),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(4164),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(4164),
    [sym_typeof_expression] = STATE(4164),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3482),
    [sym_literal] = STATE(4164),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2776),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(477),
    [sym_preproc_endregion] = STATE(477),
    [sym_preproc_line] = STATE(477),
    [sym_preproc_pragma] = STATE(477),
    [sym_preproc_nullable] = STATE(477),
    [sym_preproc_error] = STATE(477),
    [sym_preproc_warning] = STATE(477),
    [sym_preproc_define] = STATE(477),
    [sym_preproc_undef] = STATE(477),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(2503),
    [anon_sym_ref] = ACTIONS(2447),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2505),
    [anon_sym_GT] = ACTIONS(2505),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1117),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_AMP] = ACTIONS(1117),
    [anon_sym_GT_EQ] = ACTIONS(2507),
    [anon_sym_LT_EQ] = ACTIONS(2507),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2453),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2349),
    [sym_predefined_type] = ACTIONS(2339),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2509),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [478] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3211),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2756),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(2814),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(4198),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(2858),
    [sym_property_pattern_clause] = STATE(2881),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6722),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(4164),
    [sym_postfix_unary_expression] = STATE(4165),
    [sym_prefix_unary_expression] = STATE(4165),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(4164),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(4165),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(4164),
    [sym_member_access_expression] = STATE(3482),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(4165),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(4164),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(4164),
    [sym_typeof_expression] = STATE(4164),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3482),
    [sym_literal] = STATE(4164),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2776),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(478),
    [sym_preproc_endregion] = STATE(478),
    [sym_preproc_line] = STATE(478),
    [sym_preproc_pragma] = STATE(478),
    [sym_preproc_nullable] = STATE(478),
    [sym_preproc_error] = STATE(478),
    [sym_preproc_warning] = STATE(478),
    [sym_preproc_define] = STATE(478),
    [sym_preproc_undef] = STATE(478),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(2503),
    [anon_sym_ref] = ACTIONS(2447),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2505),
    [anon_sym_GT] = ACTIONS(2505),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1117),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_AMP] = ACTIONS(1117),
    [anon_sym_GT_EQ] = ACTIONS(2507),
    [anon_sym_LT_EQ] = ACTIONS(2507),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2453),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2349),
    [sym_predefined_type] = ACTIONS(2339),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2509),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [479] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3211),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2756),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(2814),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(5650),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(2858),
    [sym_property_pattern_clause] = STATE(2881),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6722),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(4164),
    [sym_postfix_unary_expression] = STATE(4165),
    [sym_prefix_unary_expression] = STATE(4165),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(4164),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(4165),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(4164),
    [sym_member_access_expression] = STATE(3482),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(4165),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(4164),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(4164),
    [sym_typeof_expression] = STATE(4164),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3482),
    [sym_literal] = STATE(4164),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2776),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(479),
    [sym_preproc_endregion] = STATE(479),
    [sym_preproc_line] = STATE(479),
    [sym_preproc_pragma] = STATE(479),
    [sym_preproc_nullable] = STATE(479),
    [sym_preproc_error] = STATE(479),
    [sym_preproc_warning] = STATE(479),
    [sym_preproc_define] = STATE(479),
    [sym_preproc_undef] = STATE(479),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(2503),
    [anon_sym_ref] = ACTIONS(2447),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2505),
    [anon_sym_GT] = ACTIONS(2505),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1117),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_AMP] = ACTIONS(1117),
    [anon_sym_GT_EQ] = ACTIONS(2507),
    [anon_sym_LT_EQ] = ACTIONS(2507),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2453),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2349),
    [sym_predefined_type] = ACTIONS(2339),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2509),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [480] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3552),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2911),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3064),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(4029),
    [sym_constant_pattern] = STATE(4086),
    [sym_parenthesized_pattern] = STATE(4086),
    [sym_var_pattern] = STATE(4086),
    [sym_type_pattern] = STATE(4086),
    [sym_list_pattern] = STATE(4086),
    [sym_recursive_pattern] = STATE(4086),
    [sym_positional_pattern_clause] = STATE(3163),
    [sym_property_pattern_clause] = STATE(3429),
    [sym_relational_pattern] = STATE(4086),
    [sym_negated_pattern] = STATE(4086),
    [sym_and_pattern] = STATE(4086),
    [sym_or_pattern] = STATE(4086),
    [sym_declaration_pattern] = STATE(4086),
    [sym_expression] = STATE(6703),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3989),
    [sym_postfix_unary_expression] = STATE(3990),
    [sym_prefix_unary_expression] = STATE(3990),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3989),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3990),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3989),
    [sym_member_access_expression] = STATE(3206),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3990),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3989),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3989),
    [sym_typeof_expression] = STATE(3989),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3206),
    [sym_literal] = STATE(3989),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2755),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(480),
    [sym_preproc_endregion] = STATE(480),
    [sym_preproc_line] = STATE(480),
    [sym_preproc_pragma] = STATE(480),
    [sym_preproc_nullable] = STATE(480),
    [sym_preproc_error] = STATE(480),
    [sym_preproc_warning] = STATE(480),
    [sym_preproc_define] = STATE(480),
    [sym_preproc_undef] = STATE(480),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(2377),
    [anon_sym_LPAREN] = ACTIONS(2573),
    [anon_sym_ref] = ACTIONS(2327),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2575),
    [anon_sym_GT] = ACTIONS(2575),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1845),
    [anon_sym_TILDE] = ACTIONS(1845),
    [anon_sym_PLUS_PLUS] = ACTIONS(1845),
    [anon_sym_DASH_DASH] = ACTIONS(1845),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1843),
    [anon_sym_DASH] = ACTIONS(1843),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1845),
    [anon_sym_AMP] = ACTIONS(1845),
    [anon_sym_GT_EQ] = ACTIONS(2577),
    [anon_sym_LT_EQ] = ACTIONS(2577),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2385),
    [sym_predefined_type] = ACTIONS(2387),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(2389),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2579),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [481] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3548),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2918),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3082),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(4029),
    [sym_constant_pattern] = STATE(4086),
    [sym_parenthesized_pattern] = STATE(4086),
    [sym_var_pattern] = STATE(4086),
    [sym_type_pattern] = STATE(4086),
    [sym_list_pattern] = STATE(4086),
    [sym_recursive_pattern] = STATE(4086),
    [sym_positional_pattern_clause] = STATE(3148),
    [sym_property_pattern_clause] = STATE(3407),
    [sym_relational_pattern] = STATE(4086),
    [sym_negated_pattern] = STATE(4086),
    [sym_and_pattern] = STATE(4086),
    [sym_or_pattern] = STATE(4086),
    [sym_declaration_pattern] = STATE(4086),
    [sym_expression] = STATE(6694),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3989),
    [sym_postfix_unary_expression] = STATE(3990),
    [sym_prefix_unary_expression] = STATE(3990),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3989),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3990),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3989),
    [sym_member_access_expression] = STATE(3206),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3990),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3989),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3989),
    [sym_typeof_expression] = STATE(3989),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3206),
    [sym_literal] = STATE(3989),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2755),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(481),
    [sym_preproc_endregion] = STATE(481),
    [sym_preproc_line] = STATE(481),
    [sym_preproc_pragma] = STATE(481),
    [sym_preproc_nullable] = STATE(481),
    [sym_preproc_error] = STATE(481),
    [sym_preproc_warning] = STATE(481),
    [sym_preproc_define] = STATE(481),
    [sym_preproc_undef] = STATE(481),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(2377),
    [anon_sym_LPAREN] = ACTIONS(2549),
    [anon_sym_ref] = ACTIONS(2327),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2551),
    [anon_sym_GT] = ACTIONS(2551),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1919),
    [anon_sym_TILDE] = ACTIONS(1919),
    [anon_sym_PLUS_PLUS] = ACTIONS(1919),
    [anon_sym_DASH_DASH] = ACTIONS(1919),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1917),
    [anon_sym_DASH] = ACTIONS(1917),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1919),
    [anon_sym_AMP] = ACTIONS(1919),
    [anon_sym_GT_EQ] = ACTIONS(2553),
    [anon_sym_LT_EQ] = ACTIONS(2553),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2385),
    [sym_predefined_type] = ACTIONS(2387),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(2389),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2555),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [482] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3000),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2756),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3028),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(6469),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(3124),
    [sym_property_pattern_clause] = STATE(3207),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6708),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(4164),
    [sym_postfix_unary_expression] = STATE(4165),
    [sym_prefix_unary_expression] = STATE(4165),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(4164),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(4165),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(4164),
    [sym_member_access_expression] = STATE(3482),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(4165),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(4164),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(4164),
    [sym_typeof_expression] = STATE(4164),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3482),
    [sym_literal] = STATE(4164),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2755),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(482),
    [sym_preproc_endregion] = STATE(482),
    [sym_preproc_line] = STATE(482),
    [sym_preproc_pragma] = STATE(482),
    [sym_preproc_nullable] = STATE(482),
    [sym_preproc_error] = STATE(482),
    [sym_preproc_warning] = STATE(482),
    [sym_preproc_define] = STATE(482),
    [sym_preproc_undef] = STATE(482),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(2325),
    [anon_sym_ref] = ACTIONS(2327),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2331),
    [anon_sym_GT] = ACTIONS(2331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1759),
    [anon_sym_TILDE] = ACTIONS(1759),
    [anon_sym_PLUS_PLUS] = ACTIONS(1759),
    [anon_sym_DASH_DASH] = ACTIONS(1759),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1757),
    [anon_sym_DASH] = ACTIONS(1757),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1759),
    [anon_sym_AMP] = ACTIONS(1759),
    [anon_sym_GT_EQ] = ACTIONS(2333),
    [anon_sym_LT_EQ] = ACTIONS(2333),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2337),
    [sym_predefined_type] = ACTIONS(2339),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2341),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [483] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3548),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2918),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3082),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(6184),
    [sym_constant_pattern] = STATE(4086),
    [sym_parenthesized_pattern] = STATE(4086),
    [sym_var_pattern] = STATE(4086),
    [sym_type_pattern] = STATE(4086),
    [sym_list_pattern] = STATE(4086),
    [sym_recursive_pattern] = STATE(4086),
    [sym_positional_pattern_clause] = STATE(3148),
    [sym_property_pattern_clause] = STATE(3407),
    [sym_relational_pattern] = STATE(4086),
    [sym_negated_pattern] = STATE(4086),
    [sym_and_pattern] = STATE(4086),
    [sym_or_pattern] = STATE(4086),
    [sym_declaration_pattern] = STATE(4086),
    [sym_expression] = STATE(6694),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3989),
    [sym_postfix_unary_expression] = STATE(3990),
    [sym_prefix_unary_expression] = STATE(3990),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3989),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3990),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3989),
    [sym_member_access_expression] = STATE(3206),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3990),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3989),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3989),
    [sym_typeof_expression] = STATE(3989),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3206),
    [sym_literal] = STATE(3989),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2755),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(483),
    [sym_preproc_endregion] = STATE(483),
    [sym_preproc_line] = STATE(483),
    [sym_preproc_pragma] = STATE(483),
    [sym_preproc_nullable] = STATE(483),
    [sym_preproc_error] = STATE(483),
    [sym_preproc_warning] = STATE(483),
    [sym_preproc_define] = STATE(483),
    [sym_preproc_undef] = STATE(483),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(2377),
    [anon_sym_LPAREN] = ACTIONS(2549),
    [anon_sym_ref] = ACTIONS(2327),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2551),
    [anon_sym_GT] = ACTIONS(2551),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1919),
    [anon_sym_TILDE] = ACTIONS(1919),
    [anon_sym_PLUS_PLUS] = ACTIONS(1919),
    [anon_sym_DASH_DASH] = ACTIONS(1919),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1917),
    [anon_sym_DASH] = ACTIONS(1917),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1919),
    [anon_sym_AMP] = ACTIONS(1919),
    [anon_sym_GT_EQ] = ACTIONS(2553),
    [anon_sym_LT_EQ] = ACTIONS(2553),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2385),
    [sym_predefined_type] = ACTIONS(2387),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(2389),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2555),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [484] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3552),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2911),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3064),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(6197),
    [sym_constant_pattern] = STATE(4086),
    [sym_parenthesized_pattern] = STATE(4086),
    [sym_var_pattern] = STATE(4086),
    [sym_type_pattern] = STATE(4086),
    [sym_list_pattern] = STATE(4086),
    [sym_recursive_pattern] = STATE(4086),
    [sym_positional_pattern_clause] = STATE(3163),
    [sym_property_pattern_clause] = STATE(3429),
    [sym_relational_pattern] = STATE(4086),
    [sym_negated_pattern] = STATE(4086),
    [sym_and_pattern] = STATE(4086),
    [sym_or_pattern] = STATE(4086),
    [sym_declaration_pattern] = STATE(4086),
    [sym_expression] = STATE(6703),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3989),
    [sym_postfix_unary_expression] = STATE(3990),
    [sym_prefix_unary_expression] = STATE(3990),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3989),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3990),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3989),
    [sym_member_access_expression] = STATE(3206),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3990),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3989),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3989),
    [sym_typeof_expression] = STATE(3989),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3206),
    [sym_literal] = STATE(3989),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2755),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(484),
    [sym_preproc_endregion] = STATE(484),
    [sym_preproc_line] = STATE(484),
    [sym_preproc_pragma] = STATE(484),
    [sym_preproc_nullable] = STATE(484),
    [sym_preproc_error] = STATE(484),
    [sym_preproc_warning] = STATE(484),
    [sym_preproc_define] = STATE(484),
    [sym_preproc_undef] = STATE(484),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(2377),
    [anon_sym_LPAREN] = ACTIONS(2573),
    [anon_sym_ref] = ACTIONS(2327),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2575),
    [anon_sym_GT] = ACTIONS(2575),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1845),
    [anon_sym_TILDE] = ACTIONS(1845),
    [anon_sym_PLUS_PLUS] = ACTIONS(1845),
    [anon_sym_DASH_DASH] = ACTIONS(1845),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1843),
    [anon_sym_DASH] = ACTIONS(1843),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1845),
    [anon_sym_AMP] = ACTIONS(1845),
    [anon_sym_GT_EQ] = ACTIONS(2577),
    [anon_sym_LT_EQ] = ACTIONS(2577),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2385),
    [sym_predefined_type] = ACTIONS(2387),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(2389),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2579),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [485] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(2999),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2761),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3041),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(6230),
    [sym_constant_pattern] = STATE(4086),
    [sym_parenthesized_pattern] = STATE(4086),
    [sym_var_pattern] = STATE(4086),
    [sym_type_pattern] = STATE(4086),
    [sym_list_pattern] = STATE(4086),
    [sym_recursive_pattern] = STATE(4086),
    [sym_positional_pattern_clause] = STATE(2840),
    [sym_property_pattern_clause] = STATE(2874),
    [sym_relational_pattern] = STATE(4086),
    [sym_negated_pattern] = STATE(4086),
    [sym_and_pattern] = STATE(4086),
    [sym_or_pattern] = STATE(4086),
    [sym_declaration_pattern] = STATE(4086),
    [sym_expression] = STATE(6707),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3989),
    [sym_postfix_unary_expression] = STATE(3990),
    [sym_prefix_unary_expression] = STATE(3990),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3989),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3990),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3989),
    [sym_member_access_expression] = STATE(3206),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3990),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3989),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3989),
    [sym_typeof_expression] = STATE(3989),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3206),
    [sym_literal] = STATE(3989),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2835),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(485),
    [sym_preproc_endregion] = STATE(485),
    [sym_preproc_line] = STATE(485),
    [sym_preproc_pragma] = STATE(485),
    [sym_preproc_nullable] = STATE(485),
    [sym_preproc_error] = STATE(485),
    [sym_preproc_warning] = STATE(485),
    [sym_preproc_define] = STATE(485),
    [sym_preproc_undef] = STATE(485),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(2377),
    [anon_sym_LPAREN] = ACTIONS(2519),
    [anon_sym_ref] = ACTIONS(2467),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2521),
    [anon_sym_GT] = ACTIONS(2521),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1659),
    [anon_sym_TILDE] = ACTIONS(1659),
    [anon_sym_PLUS_PLUS] = ACTIONS(1659),
    [anon_sym_DASH_DASH] = ACTIONS(1659),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1657),
    [anon_sym_DASH] = ACTIONS(1657),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1659),
    [anon_sym_AMP] = ACTIONS(1659),
    [anon_sym_GT_EQ] = ACTIONS(2523),
    [anon_sym_LT_EQ] = ACTIONS(2523),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2473),
    [sym_predefined_type] = ACTIONS(2387),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(2389),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2525),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [486] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6759),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2844),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6163),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_pattern] = STATE(8383),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6721),
    [sym_property_pattern_clause] = STATE(6770),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6727),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5060),
    [sym_postfix_unary_expression] = STATE(5061),
    [sym_prefix_unary_expression] = STATE(5061),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5060),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5061),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5060),
    [sym_member_access_expression] = STATE(3797),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5061),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(5060),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5060),
    [sym_typeof_expression] = STATE(5060),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3797),
    [sym_literal] = STATE(5060),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(486),
    [sym_preproc_endregion] = STATE(486),
    [sym_preproc_line] = STATE(486),
    [sym_preproc_pragma] = STATE(486),
    [sym_preproc_nullable] = STATE(486),
    [sym_preproc_error] = STATE(486),
    [sym_preproc_warning] = STATE(486),
    [sym_preproc_define] = STATE(486),
    [sym_preproc_undef] = STATE(486),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1949),
    [anon_sym_ref] = ACTIONS(1951),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(1955),
    [anon_sym_GT] = ACTIONS(1955),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1581),
    [anon_sym_TILDE] = ACTIONS(1581),
    [anon_sym_PLUS_PLUS] = ACTIONS(1581),
    [anon_sym_DASH_DASH] = ACTIONS(1581),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1579),
    [anon_sym_DASH] = ACTIONS(1579),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1581),
    [anon_sym_AMP] = ACTIONS(1581),
    [anon_sym_GT_EQ] = ACTIONS(1957),
    [anon_sym_LT_EQ] = ACTIONS(1957),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(1089),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1959),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(1961),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [487] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3554),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2908),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3077),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(6312),
    [sym_constant_pattern] = STATE(4086),
    [sym_parenthesized_pattern] = STATE(4086),
    [sym_var_pattern] = STATE(4086),
    [sym_type_pattern] = STATE(4086),
    [sym_list_pattern] = STATE(4086),
    [sym_recursive_pattern] = STATE(4086),
    [sym_positional_pattern_clause] = STATE(3151),
    [sym_property_pattern_clause] = STATE(3422),
    [sym_relational_pattern] = STATE(4086),
    [sym_negated_pattern] = STATE(4086),
    [sym_and_pattern] = STATE(4086),
    [sym_or_pattern] = STATE(4086),
    [sym_declaration_pattern] = STATE(4086),
    [sym_expression] = STATE(6701),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3989),
    [sym_postfix_unary_expression] = STATE(3990),
    [sym_prefix_unary_expression] = STATE(3990),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3989),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3990),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3989),
    [sym_member_access_expression] = STATE(3206),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3990),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3989),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3989),
    [sym_typeof_expression] = STATE(3989),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3206),
    [sym_literal] = STATE(3989),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2755),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(487),
    [sym_preproc_endregion] = STATE(487),
    [sym_preproc_line] = STATE(487),
    [sym_preproc_pragma] = STATE(487),
    [sym_preproc_nullable] = STATE(487),
    [sym_preproc_error] = STATE(487),
    [sym_preproc_warning] = STATE(487),
    [sym_preproc_define] = STATE(487),
    [sym_preproc_undef] = STATE(487),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(2377),
    [anon_sym_LPAREN] = ACTIONS(2557),
    [anon_sym_ref] = ACTIONS(2327),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2559),
    [anon_sym_GT] = ACTIONS(2559),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1827),
    [anon_sym_TILDE] = ACTIONS(1827),
    [anon_sym_PLUS_PLUS] = ACTIONS(1827),
    [anon_sym_DASH_DASH] = ACTIONS(1827),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1825),
    [anon_sym_DASH] = ACTIONS(1825),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1827),
    [anon_sym_AMP] = ACTIONS(1827),
    [anon_sym_GT_EQ] = ACTIONS(2561),
    [anon_sym_LT_EQ] = ACTIONS(2561),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2385),
    [sym_predefined_type] = ACTIONS(2387),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(2389),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2563),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [488] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2802),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(5351),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_pattern] = STATE(8325),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6158),
    [sym_property_pattern_clause] = STATE(6724),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6719),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5302),
    [sym_postfix_unary_expression] = STATE(5343),
    [sym_prefix_unary_expression] = STATE(5343),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5302),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5343),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5302),
    [sym_member_access_expression] = STATE(3862),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5343),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(5302),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5302),
    [sym_typeof_expression] = STATE(5302),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3862),
    [sym_literal] = STATE(5302),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(488),
    [sym_preproc_endregion] = STATE(488),
    [sym_preproc_line] = STATE(488),
    [sym_preproc_pragma] = STATE(488),
    [sym_preproc_nullable] = STATE(488),
    [sym_preproc_error] = STATE(488),
    [sym_preproc_warning] = STATE(488),
    [sym_preproc_define] = STATE(488),
    [sym_preproc_undef] = STATE(488),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1067),
    [anon_sym_ref] = ACTIONS(2281),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(1077),
    [anon_sym_GT] = ACTIONS(1077),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1083),
    [anon_sym_PLUS_PLUS] = ACTIONS(1083),
    [anon_sym_DASH_DASH] = ACTIONS(1083),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1085),
    [anon_sym_DASH] = ACTIONS(1085),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1083),
    [anon_sym_AMP] = ACTIONS(1083),
    [anon_sym_GT_EQ] = ACTIONS(1087),
    [anon_sym_LT_EQ] = ACTIONS(1087),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(1089),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1091),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(2283),
    [anon_sym_not] = ACTIONS(1101),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [489] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6764),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2844),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6133),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_pattern] = STATE(8224),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6721),
    [sym_property_pattern_clause] = STATE(6770),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6566),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(6146),
    [sym_postfix_unary_expression] = STATE(6147),
    [sym_prefix_unary_expression] = STATE(6147),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(6146),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(6147),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(6146),
    [sym_member_access_expression] = STATE(4179),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(6147),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(6146),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(6146),
    [sym_typeof_expression] = STATE(6146),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(4179),
    [sym_literal] = STATE(6146),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2810),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(489),
    [sym_preproc_endregion] = STATE(489),
    [sym_preproc_line] = STATE(489),
    [sym_preproc_pragma] = STATE(489),
    [sym_preproc_nullable] = STATE(489),
    [sym_preproc_error] = STATE(489),
    [sym_preproc_warning] = STATE(489),
    [sym_preproc_define] = STATE(489),
    [sym_preproc_undef] = STATE(489),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(2397),
    [anon_sym_ref] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(2401),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_LT] = ACTIONS(2403),
    [anon_sym_GT] = ACTIONS(2403),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1629),
    [anon_sym_TILDE] = ACTIONS(1629),
    [anon_sym_PLUS_PLUS] = ACTIONS(1629),
    [anon_sym_DASH_DASH] = ACTIONS(1629),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1627),
    [anon_sym_DASH] = ACTIONS(1627),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(1629),
    [anon_sym_AMP] = ACTIONS(1629),
    [anon_sym_GT_EQ] = ACTIONS(2405),
    [anon_sym_LT_EQ] = ACTIONS(2405),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2407),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2409),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_not] = ACTIONS(2411),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [490] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3536),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2859),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3040),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(4563),
    [sym_constant_pattern] = STATE(4557),
    [sym_parenthesized_pattern] = STATE(4557),
    [sym_var_pattern] = STATE(4557),
    [sym_type_pattern] = STATE(4557),
    [sym_list_pattern] = STATE(4557),
    [sym_recursive_pattern] = STATE(4557),
    [sym_positional_pattern_clause] = STATE(3127),
    [sym_property_pattern_clause] = STATE(3184),
    [sym_relational_pattern] = STATE(4557),
    [sym_negated_pattern] = STATE(4557),
    [sym_and_pattern] = STATE(4557),
    [sym_or_pattern] = STATE(4557),
    [sym_declaration_pattern] = STATE(4557),
    [sym_expression] = STATE(6744),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(4559),
    [sym_postfix_unary_expression] = STATE(4560),
    [sym_prefix_unary_expression] = STATE(4560),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(4559),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(4560),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(4559),
    [sym_member_access_expression] = STATE(3583),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(4560),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(4559),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(4559),
    [sym_typeof_expression] = STATE(4559),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3583),
    [sym_literal] = STATE(4559),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2755),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(490),
    [sym_preproc_endregion] = STATE(490),
    [sym_preproc_line] = STATE(490),
    [sym_preproc_pragma] = STATE(490),
    [sym_preproc_nullable] = STATE(490),
    [sym_preproc_error] = STATE(490),
    [sym_preproc_warning] = STATE(490),
    [sym_preproc_define] = STATE(490),
    [sym_preproc_undef] = STATE(490),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(2413),
    [anon_sym_LPAREN] = ACTIONS(2415),
    [anon_sym_ref] = ACTIONS(2327),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2417),
    [anon_sym_GT] = ACTIONS(2417),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1775),
    [anon_sym_TILDE] = ACTIONS(1775),
    [anon_sym_PLUS_PLUS] = ACTIONS(1775),
    [anon_sym_DASH_DASH] = ACTIONS(1775),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1773),
    [anon_sym_DASH] = ACTIONS(1773),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1775),
    [anon_sym_AMP] = ACTIONS(1775),
    [anon_sym_GT_EQ] = ACTIONS(2419),
    [anon_sym_LT_EQ] = ACTIONS(2419),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2421),
    [sym_predefined_type] = ACTIONS(2423),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(2425),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2427),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [491] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3000),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2756),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(2814),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(5258),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(2858),
    [sym_property_pattern_clause] = STATE(2881),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6719),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(4164),
    [sym_postfix_unary_expression] = STATE(4165),
    [sym_prefix_unary_expression] = STATE(4165),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(4164),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(4165),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(4164),
    [sym_member_access_expression] = STATE(3482),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(4165),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(4164),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(4164),
    [sym_typeof_expression] = STATE(4164),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3482),
    [sym_literal] = STATE(4164),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2755),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(491),
    [sym_preproc_endregion] = STATE(491),
    [sym_preproc_line] = STATE(491),
    [sym_preproc_pragma] = STATE(491),
    [sym_preproc_nullable] = STATE(491),
    [sym_preproc_error] = STATE(491),
    [sym_preproc_warning] = STATE(491),
    [sym_preproc_define] = STATE(491),
    [sym_preproc_undef] = STATE(491),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(2393),
    [anon_sym_ref] = ACTIONS(2327),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(1077),
    [anon_sym_GT] = ACTIONS(1077),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1083),
    [anon_sym_PLUS_PLUS] = ACTIONS(1083),
    [anon_sym_DASH_DASH] = ACTIONS(1083),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1085),
    [anon_sym_DASH] = ACTIONS(1085),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1083),
    [anon_sym_AMP] = ACTIONS(1083),
    [anon_sym_GT_EQ] = ACTIONS(1087),
    [anon_sym_LT_EQ] = ACTIONS(1087),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2349),
    [sym_predefined_type] = ACTIONS(2339),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2395),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [492] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3536),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2859),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3040),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(4613),
    [sym_constant_pattern] = STATE(4557),
    [sym_parenthesized_pattern] = STATE(4557),
    [sym_var_pattern] = STATE(4557),
    [sym_type_pattern] = STATE(4557),
    [sym_list_pattern] = STATE(4557),
    [sym_recursive_pattern] = STATE(4557),
    [sym_positional_pattern_clause] = STATE(3127),
    [sym_property_pattern_clause] = STATE(3184),
    [sym_relational_pattern] = STATE(4557),
    [sym_negated_pattern] = STATE(4557),
    [sym_and_pattern] = STATE(4557),
    [sym_or_pattern] = STATE(4557),
    [sym_declaration_pattern] = STATE(4557),
    [sym_expression] = STATE(6744),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(4559),
    [sym_postfix_unary_expression] = STATE(4560),
    [sym_prefix_unary_expression] = STATE(4560),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(4559),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(4560),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(4559),
    [sym_member_access_expression] = STATE(3583),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(4560),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(4559),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(4559),
    [sym_typeof_expression] = STATE(4559),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3583),
    [sym_literal] = STATE(4559),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2755),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(492),
    [sym_preproc_endregion] = STATE(492),
    [sym_preproc_line] = STATE(492),
    [sym_preproc_pragma] = STATE(492),
    [sym_preproc_nullable] = STATE(492),
    [sym_preproc_error] = STATE(492),
    [sym_preproc_warning] = STATE(492),
    [sym_preproc_define] = STATE(492),
    [sym_preproc_undef] = STATE(492),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(2413),
    [anon_sym_LPAREN] = ACTIONS(2415),
    [anon_sym_ref] = ACTIONS(2327),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2417),
    [anon_sym_GT] = ACTIONS(2417),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1775),
    [anon_sym_TILDE] = ACTIONS(1775),
    [anon_sym_PLUS_PLUS] = ACTIONS(1775),
    [anon_sym_DASH_DASH] = ACTIONS(1775),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1773),
    [anon_sym_DASH] = ACTIONS(1773),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1775),
    [anon_sym_AMP] = ACTIONS(1775),
    [anon_sym_GT_EQ] = ACTIONS(2419),
    [anon_sym_LT_EQ] = ACTIONS(2419),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2421),
    [sym_predefined_type] = ACTIONS(2423),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(2425),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2427),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [493] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3000),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2756),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(2813),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(4137),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(2858),
    [sym_property_pattern_clause] = STATE(2881),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6706),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(4164),
    [sym_postfix_unary_expression] = STATE(4165),
    [sym_prefix_unary_expression] = STATE(4165),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(4164),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(4165),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(4164),
    [sym_member_access_expression] = STATE(3482),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(4165),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(4164),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(4164),
    [sym_typeof_expression] = STATE(4164),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3482),
    [sym_literal] = STATE(4164),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2755),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(493),
    [sym_preproc_endregion] = STATE(493),
    [sym_preproc_line] = STATE(493),
    [sym_preproc_pragma] = STATE(493),
    [sym_preproc_nullable] = STATE(493),
    [sym_preproc_error] = STATE(493),
    [sym_preproc_warning] = STATE(493),
    [sym_preproc_define] = STATE(493),
    [sym_preproc_undef] = STATE(493),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(2457),
    [anon_sym_ref] = ACTIONS(2327),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2459),
    [anon_sym_GT] = ACTIONS(2459),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1379),
    [anon_sym_TILDE] = ACTIONS(1379),
    [anon_sym_PLUS_PLUS] = ACTIONS(1379),
    [anon_sym_DASH_DASH] = ACTIONS(1379),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1377),
    [anon_sym_DASH] = ACTIONS(1377),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1379),
    [anon_sym_AMP] = ACTIONS(1379),
    [anon_sym_GT_EQ] = ACTIONS(2461),
    [anon_sym_LT_EQ] = ACTIONS(2461),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2349),
    [sym_predefined_type] = ACTIONS(2339),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2463),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [494] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3543),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2882),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3061),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(5059),
    [sym_constant_pattern] = STATE(5032),
    [sym_parenthesized_pattern] = STATE(5032),
    [sym_var_pattern] = STATE(5032),
    [sym_type_pattern] = STATE(5032),
    [sym_list_pattern] = STATE(5032),
    [sym_recursive_pattern] = STATE(5032),
    [sym_positional_pattern_clause] = STATE(3157),
    [sym_property_pattern_clause] = STATE(3428),
    [sym_relational_pattern] = STATE(5032),
    [sym_negated_pattern] = STATE(5032),
    [sym_and_pattern] = STATE(5032),
    [sym_or_pattern] = STATE(5032),
    [sym_declaration_pattern] = STATE(5032),
    [sym_expression] = STATE(6692),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(4990),
    [sym_postfix_unary_expression] = STATE(5037),
    [sym_prefix_unary_expression] = STATE(5037),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(4990),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5037),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(4990),
    [sym_member_access_expression] = STATE(3739),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5037),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(4990),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(4990),
    [sym_typeof_expression] = STATE(4990),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3739),
    [sym_literal] = STATE(4990),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2755),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(494),
    [sym_preproc_endregion] = STATE(494),
    [sym_preproc_line] = STATE(494),
    [sym_preproc_pragma] = STATE(494),
    [sym_preproc_nullable] = STATE(494),
    [sym_preproc_error] = STATE(494),
    [sym_preproc_warning] = STATE(494),
    [sym_preproc_define] = STATE(494),
    [sym_preproc_undef] = STATE(494),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(2477),
    [anon_sym_LPAREN] = ACTIONS(2479),
    [anon_sym_ref] = ACTIONS(2327),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2481),
    [anon_sym_GT] = ACTIONS(2481),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1901),
    [anon_sym_TILDE] = ACTIONS(1901),
    [anon_sym_PLUS_PLUS] = ACTIONS(1901),
    [anon_sym_DASH_DASH] = ACTIONS(1901),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1899),
    [anon_sym_DASH] = ACTIONS(1899),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1901),
    [anon_sym_AMP] = ACTIONS(1901),
    [anon_sym_GT_EQ] = ACTIONS(2483),
    [anon_sym_LT_EQ] = ACTIONS(2483),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2485),
    [sym_predefined_type] = ACTIONS(2487),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(2489),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2491),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [495] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3000),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2756),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(2814),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(4198),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(2858),
    [sym_property_pattern_clause] = STATE(2881),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6706),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(4164),
    [sym_postfix_unary_expression] = STATE(4165),
    [sym_prefix_unary_expression] = STATE(4165),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(4164),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(4165),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(4164),
    [sym_member_access_expression] = STATE(3482),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(4165),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(4164),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(4164),
    [sym_typeof_expression] = STATE(4164),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3482),
    [sym_literal] = STATE(4164),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2755),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(495),
    [sym_preproc_endregion] = STATE(495),
    [sym_preproc_line] = STATE(495),
    [sym_preproc_pragma] = STATE(495),
    [sym_preproc_nullable] = STATE(495),
    [sym_preproc_error] = STATE(495),
    [sym_preproc_warning] = STATE(495),
    [sym_preproc_define] = STATE(495),
    [sym_preproc_undef] = STATE(495),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(2457),
    [anon_sym_ref] = ACTIONS(2327),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2459),
    [anon_sym_GT] = ACTIONS(2459),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1379),
    [anon_sym_TILDE] = ACTIONS(1379),
    [anon_sym_PLUS_PLUS] = ACTIONS(1379),
    [anon_sym_DASH_DASH] = ACTIONS(1379),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1377),
    [anon_sym_DASH] = ACTIONS(1377),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1379),
    [anon_sym_AMP] = ACTIONS(1379),
    [anon_sym_GT_EQ] = ACTIONS(2461),
    [anon_sym_LT_EQ] = ACTIONS(2461),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2349),
    [sym_predefined_type] = ACTIONS(2339),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2463),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [496] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3536),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2859),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3040),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(4720),
    [sym_constant_pattern] = STATE(4557),
    [sym_parenthesized_pattern] = STATE(4557),
    [sym_var_pattern] = STATE(4557),
    [sym_type_pattern] = STATE(4557),
    [sym_list_pattern] = STATE(4557),
    [sym_recursive_pattern] = STATE(4557),
    [sym_positional_pattern_clause] = STATE(3127),
    [sym_property_pattern_clause] = STATE(3184),
    [sym_relational_pattern] = STATE(4557),
    [sym_negated_pattern] = STATE(4557),
    [sym_and_pattern] = STATE(4557),
    [sym_or_pattern] = STATE(4557),
    [sym_declaration_pattern] = STATE(4557),
    [sym_expression] = STATE(6744),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(4559),
    [sym_postfix_unary_expression] = STATE(4560),
    [sym_prefix_unary_expression] = STATE(4560),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(4559),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(4560),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(4559),
    [sym_member_access_expression] = STATE(3583),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(4560),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(4559),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(4559),
    [sym_typeof_expression] = STATE(4559),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3583),
    [sym_literal] = STATE(4559),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2755),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(496),
    [sym_preproc_endregion] = STATE(496),
    [sym_preproc_line] = STATE(496),
    [sym_preproc_pragma] = STATE(496),
    [sym_preproc_nullable] = STATE(496),
    [sym_preproc_error] = STATE(496),
    [sym_preproc_warning] = STATE(496),
    [sym_preproc_define] = STATE(496),
    [sym_preproc_undef] = STATE(496),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(2413),
    [anon_sym_LPAREN] = ACTIONS(2415),
    [anon_sym_ref] = ACTIONS(2327),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2417),
    [anon_sym_GT] = ACTIONS(2417),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1775),
    [anon_sym_TILDE] = ACTIONS(1775),
    [anon_sym_PLUS_PLUS] = ACTIONS(1775),
    [anon_sym_DASH_DASH] = ACTIONS(1775),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1773),
    [anon_sym_DASH] = ACTIONS(1773),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1775),
    [anon_sym_AMP] = ACTIONS(1775),
    [anon_sym_GT_EQ] = ACTIONS(2419),
    [anon_sym_LT_EQ] = ACTIONS(2419),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2421),
    [sym_predefined_type] = ACTIONS(2423),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(2425),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2427),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [497] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3223),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2761),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(2805),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(4029),
    [sym_constant_pattern] = STATE(4086),
    [sym_parenthesized_pattern] = STATE(4086),
    [sym_var_pattern] = STATE(4086),
    [sym_type_pattern] = STATE(4086),
    [sym_list_pattern] = STATE(4086),
    [sym_recursive_pattern] = STATE(4086),
    [sym_positional_pattern_clause] = STATE(2840),
    [sym_property_pattern_clause] = STATE(2874),
    [sym_relational_pattern] = STATE(4086),
    [sym_negated_pattern] = STATE(4086),
    [sym_and_pattern] = STATE(4086),
    [sym_or_pattern] = STATE(4086),
    [sym_declaration_pattern] = STATE(4086),
    [sym_expression] = STATE(6729),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3989),
    [sym_postfix_unary_expression] = STATE(3990),
    [sym_prefix_unary_expression] = STATE(3990),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3989),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3990),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3989),
    [sym_member_access_expression] = STATE(3206),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3990),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3989),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3989),
    [sym_typeof_expression] = STATE(3989),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3206),
    [sym_literal] = STATE(3989),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2776),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(497),
    [sym_preproc_endregion] = STATE(497),
    [sym_preproc_line] = STATE(497),
    [sym_preproc_pragma] = STATE(497),
    [sym_preproc_nullable] = STATE(497),
    [sym_preproc_error] = STATE(497),
    [sym_preproc_warning] = STATE(497),
    [sym_preproc_define] = STATE(497),
    [sym_preproc_undef] = STATE(497),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(2377),
    [anon_sym_LPAREN] = ACTIONS(2531),
    [anon_sym_ref] = ACTIONS(2447),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2533),
    [anon_sym_GT] = ACTIONS(2533),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1363),
    [anon_sym_TILDE] = ACTIONS(1363),
    [anon_sym_PLUS_PLUS] = ACTIONS(1363),
    [anon_sym_DASH_DASH] = ACTIONS(1363),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1361),
    [anon_sym_DASH] = ACTIONS(1361),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1363),
    [anon_sym_AMP] = ACTIONS(1363),
    [anon_sym_GT_EQ] = ACTIONS(2535),
    [anon_sym_LT_EQ] = ACTIONS(2535),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2453),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2385),
    [sym_predefined_type] = ACTIONS(2387),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(2389),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2537),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [498] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3540),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2852),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3034),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(4137),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(3103),
    [sym_property_pattern_clause] = STATE(3159),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6727),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(4164),
    [sym_postfix_unary_expression] = STATE(4165),
    [sym_prefix_unary_expression] = STATE(4165),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(4164),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(4165),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(4164),
    [sym_member_access_expression] = STATE(3482),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(4165),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(4164),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(4164),
    [sym_typeof_expression] = STATE(4164),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3482),
    [sym_literal] = STATE(4164),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2835),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(498),
    [sym_preproc_endregion] = STATE(498),
    [sym_preproc_line] = STATE(498),
    [sym_preproc_pragma] = STATE(498),
    [sym_preproc_nullable] = STATE(498),
    [sym_preproc_error] = STATE(498),
    [sym_preproc_warning] = STATE(498),
    [sym_preproc_define] = STATE(498),
    [sym_preproc_undef] = STATE(498),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(2581),
    [anon_sym_ref] = ACTIONS(2467),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(1955),
    [anon_sym_GT] = ACTIONS(1955),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1581),
    [anon_sym_TILDE] = ACTIONS(1581),
    [anon_sym_PLUS_PLUS] = ACTIONS(1581),
    [anon_sym_DASH_DASH] = ACTIONS(1581),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1579),
    [anon_sym_DASH] = ACTIONS(1579),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1581),
    [anon_sym_AMP] = ACTIONS(1581),
    [anon_sym_GT_EQ] = ACTIONS(1957),
    [anon_sym_LT_EQ] = ACTIONS(1957),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2499),
    [sym_predefined_type] = ACTIONS(2339),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2583),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [499] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3211),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2756),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(2809),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(6488),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(2858),
    [sym_property_pattern_clause] = STATE(2881),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6732),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(4164),
    [sym_postfix_unary_expression] = STATE(4165),
    [sym_prefix_unary_expression] = STATE(4165),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(4164),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(4165),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(4164),
    [sym_member_access_expression] = STATE(3482),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(4165),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(4164),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(4164),
    [sym_typeof_expression] = STATE(4164),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3482),
    [sym_literal] = STATE(4164),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2776),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(499),
    [sym_preproc_endregion] = STATE(499),
    [sym_preproc_line] = STATE(499),
    [sym_preproc_pragma] = STATE(499),
    [sym_preproc_nullable] = STATE(499),
    [sym_preproc_error] = STATE(499),
    [sym_preproc_warning] = STATE(499),
    [sym_preproc_define] = STATE(499),
    [sym_preproc_undef] = STATE(499),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(2585),
    [anon_sym_ref] = ACTIONS(2447),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2587),
    [anon_sym_GT] = ACTIONS(2587),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1545),
    [anon_sym_TILDE] = ACTIONS(1545),
    [anon_sym_PLUS_PLUS] = ACTIONS(1545),
    [anon_sym_DASH_DASH] = ACTIONS(1545),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1543),
    [anon_sym_DASH] = ACTIONS(1543),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1545),
    [anon_sym_AMP] = ACTIONS(1545),
    [anon_sym_GT_EQ] = ACTIONS(2589),
    [anon_sym_LT_EQ] = ACTIONS(2589),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2453),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2349),
    [sym_predefined_type] = ACTIONS(2339),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2591),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [500] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3223),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2761),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(2805),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(5371),
    [sym_constant_pattern] = STATE(4086),
    [sym_parenthesized_pattern] = STATE(4086),
    [sym_var_pattern] = STATE(4086),
    [sym_type_pattern] = STATE(4086),
    [sym_list_pattern] = STATE(4086),
    [sym_recursive_pattern] = STATE(4086),
    [sym_positional_pattern_clause] = STATE(2840),
    [sym_property_pattern_clause] = STATE(2874),
    [sym_relational_pattern] = STATE(4086),
    [sym_negated_pattern] = STATE(4086),
    [sym_and_pattern] = STATE(4086),
    [sym_or_pattern] = STATE(4086),
    [sym_declaration_pattern] = STATE(4086),
    [sym_expression] = STATE(6729),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3989),
    [sym_postfix_unary_expression] = STATE(3990),
    [sym_prefix_unary_expression] = STATE(3990),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3989),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3990),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3989),
    [sym_member_access_expression] = STATE(3206),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3990),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3989),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3989),
    [sym_typeof_expression] = STATE(3989),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3206),
    [sym_literal] = STATE(3989),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2776),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(500),
    [sym_preproc_endregion] = STATE(500),
    [sym_preproc_line] = STATE(500),
    [sym_preproc_pragma] = STATE(500),
    [sym_preproc_nullable] = STATE(500),
    [sym_preproc_error] = STATE(500),
    [sym_preproc_warning] = STATE(500),
    [sym_preproc_define] = STATE(500),
    [sym_preproc_undef] = STATE(500),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(2377),
    [anon_sym_LPAREN] = ACTIONS(2531),
    [anon_sym_ref] = ACTIONS(2447),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2533),
    [anon_sym_GT] = ACTIONS(2533),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1363),
    [anon_sym_TILDE] = ACTIONS(1363),
    [anon_sym_PLUS_PLUS] = ACTIONS(1363),
    [anon_sym_DASH_DASH] = ACTIONS(1363),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1361),
    [anon_sym_DASH] = ACTIONS(1361),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1363),
    [anon_sym_AMP] = ACTIONS(1363),
    [anon_sym_GT_EQ] = ACTIONS(2535),
    [anon_sym_LT_EQ] = ACTIONS(2535),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2453),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2385),
    [sym_predefined_type] = ACTIONS(2387),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(2389),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2537),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [501] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(2999),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2761),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(2800),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(4855),
    [sym_constant_pattern] = STATE(4086),
    [sym_parenthesized_pattern] = STATE(4086),
    [sym_var_pattern] = STATE(4086),
    [sym_type_pattern] = STATE(4086),
    [sym_list_pattern] = STATE(4086),
    [sym_recursive_pattern] = STATE(4086),
    [sym_positional_pattern_clause] = STATE(2840),
    [sym_property_pattern_clause] = STATE(2874),
    [sym_relational_pattern] = STATE(4086),
    [sym_negated_pattern] = STATE(4086),
    [sym_and_pattern] = STATE(4086),
    [sym_or_pattern] = STATE(4086),
    [sym_declaration_pattern] = STATE(4086),
    [sym_expression] = STATE(6704),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3989),
    [sym_postfix_unary_expression] = STATE(3990),
    [sym_prefix_unary_expression] = STATE(3990),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3989),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3990),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3989),
    [sym_member_access_expression] = STATE(3206),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3990),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3989),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3989),
    [sym_typeof_expression] = STATE(3989),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3206),
    [sym_literal] = STATE(3989),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2755),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(501),
    [sym_preproc_endregion] = STATE(501),
    [sym_preproc_line] = STATE(501),
    [sym_preproc_pragma] = STATE(501),
    [sym_preproc_nullable] = STATE(501),
    [sym_preproc_error] = STATE(501),
    [sym_preproc_warning] = STATE(501),
    [sym_preproc_define] = STATE(501),
    [sym_preproc_undef] = STATE(501),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(2377),
    [anon_sym_LPAREN] = ACTIONS(2379),
    [anon_sym_ref] = ACTIONS(2327),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2381),
    [anon_sym_GT] = ACTIONS(2381),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1177),
    [anon_sym_TILDE] = ACTIONS(1177),
    [anon_sym_PLUS_PLUS] = ACTIONS(1177),
    [anon_sym_DASH_DASH] = ACTIONS(1177),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1175),
    [anon_sym_DASH] = ACTIONS(1175),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1177),
    [anon_sym_AMP] = ACTIONS(1177),
    [anon_sym_GT_EQ] = ACTIONS(2383),
    [anon_sym_LT_EQ] = ACTIONS(2383),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2385),
    [sym_predefined_type] = ACTIONS(2387),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(2389),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2391),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [502] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3485),
    [sym_alias_qualified_name] = STATE(3486),
    [sym__simple_name] = STATE(2830),
    [sym_qualified_name] = STATE(3486),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(2980),
    [sym_implicit_type] = STATE(3330),
    [sym_array_type] = STATE(3488),
    [sym__array_base_type] = STATE(8756),
    [sym_nullable_type] = STATE(3489),
    [sym_pointer_type] = STATE(3489),
    [sym__pointer_base_type] = STATE(9221),
    [sym_function_pointer_type] = STATE(3489),
    [sym_ref_type] = STATE(3330),
    [sym_scoped_type] = STATE(3330),
    [sym_tuple_type] = STATE(3490),
    [sym_pattern] = STATE(6075),
    [sym_constant_pattern] = STATE(5744),
    [sym_parenthesized_pattern] = STATE(5744),
    [sym_var_pattern] = STATE(5744),
    [sym_type_pattern] = STATE(5744),
    [sym_list_pattern] = STATE(5744),
    [sym_recursive_pattern] = STATE(5744),
    [sym_positional_pattern_clause] = STATE(3084),
    [sym_property_pattern_clause] = STATE(3132),
    [sym_relational_pattern] = STATE(5744),
    [sym_negated_pattern] = STATE(5744),
    [sym_and_pattern] = STATE(5744),
    [sym_or_pattern] = STATE(5744),
    [sym_declaration_pattern] = STATE(5744),
    [sym_expression] = STATE(6709),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5469),
    [sym_postfix_unary_expression] = STATE(5470),
    [sym_prefix_unary_expression] = STATE(5470),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5469),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5470),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5469),
    [sym_member_access_expression] = STATE(3940),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5470),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(5469),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5469),
    [sym_typeof_expression] = STATE(5469),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3940),
    [sym_literal] = STATE(5469),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2792),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(502),
    [sym_preproc_endregion] = STATE(502),
    [sym_preproc_line] = STATE(502),
    [sym_preproc_pragma] = STATE(502),
    [sym_preproc_nullable] = STATE(502),
    [sym_preproc_error] = STATE(502),
    [sym_preproc_warning] = STATE(502),
    [sym_preproc_define] = STATE(502),
    [sym_preproc_undef] = STATE(502),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(2353),
    [anon_sym_LPAREN] = ACTIONS(2565),
    [anon_sym_ref] = ACTIONS(2357),
    [anon_sym_LBRACE] = ACTIONS(2359),
    [anon_sym_delegate] = ACTIONS(2361),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2567),
    [anon_sym_GT] = ACTIONS(2567),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1421),
    [anon_sym_TILDE] = ACTIONS(1421),
    [anon_sym_PLUS_PLUS] = ACTIONS(1421),
    [anon_sym_DASH_DASH] = ACTIONS(1421),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1419),
    [anon_sym_DASH] = ACTIONS(1419),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1421),
    [anon_sym_AMP] = ACTIONS(1421),
    [anon_sym_GT_EQ] = ACTIONS(2569),
    [anon_sym_LT_EQ] = ACTIONS(2569),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2367),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2369),
    [sym_predefined_type] = ACTIONS(2371),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(2373),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2571),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [503] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3211),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2756),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(2814),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(6494),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(2858),
    [sym_property_pattern_clause] = STATE(2881),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6732),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(4164),
    [sym_postfix_unary_expression] = STATE(4165),
    [sym_prefix_unary_expression] = STATE(4165),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(4164),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(4165),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(4164),
    [sym_member_access_expression] = STATE(3482),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(4165),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(4164),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(4164),
    [sym_typeof_expression] = STATE(4164),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3482),
    [sym_literal] = STATE(4164),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2776),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(503),
    [sym_preproc_endregion] = STATE(503),
    [sym_preproc_line] = STATE(503),
    [sym_preproc_pragma] = STATE(503),
    [sym_preproc_nullable] = STATE(503),
    [sym_preproc_error] = STATE(503),
    [sym_preproc_warning] = STATE(503),
    [sym_preproc_define] = STATE(503),
    [sym_preproc_undef] = STATE(503),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(2585),
    [anon_sym_ref] = ACTIONS(2447),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2587),
    [anon_sym_GT] = ACTIONS(2587),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1545),
    [anon_sym_TILDE] = ACTIONS(1545),
    [anon_sym_PLUS_PLUS] = ACTIONS(1545),
    [anon_sym_DASH_DASH] = ACTIONS(1545),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1543),
    [anon_sym_DASH] = ACTIONS(1543),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1545),
    [anon_sym_AMP] = ACTIONS(1545),
    [anon_sym_GT_EQ] = ACTIONS(2589),
    [anon_sym_LT_EQ] = ACTIONS(2589),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2453),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2349),
    [sym_predefined_type] = ACTIONS(2339),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2591),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [504] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2802),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(5351),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_pattern] = STATE(8326),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6158),
    [sym_property_pattern_clause] = STATE(6724),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6719),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(5302),
    [sym_postfix_unary_expression] = STATE(5343),
    [sym_prefix_unary_expression] = STATE(5343),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(5302),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5343),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(5302),
    [sym_member_access_expression] = STATE(3862),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5343),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(5302),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(5302),
    [sym_typeof_expression] = STATE(5302),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3862),
    [sym_literal] = STATE(5302),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(504),
    [sym_preproc_endregion] = STATE(504),
    [sym_preproc_line] = STATE(504),
    [sym_preproc_pragma] = STATE(504),
    [sym_preproc_nullable] = STATE(504),
    [sym_preproc_error] = STATE(504),
    [sym_preproc_warning] = STATE(504),
    [sym_preproc_define] = STATE(504),
    [sym_preproc_undef] = STATE(504),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(1067),
    [anon_sym_ref] = ACTIONS(2281),
    [anon_sym_LBRACE] = ACTIONS(1073),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(1077),
    [anon_sym_GT] = ACTIONS(1077),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1083),
    [anon_sym_PLUS_PLUS] = ACTIONS(1083),
    [anon_sym_DASH_DASH] = ACTIONS(1083),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1085),
    [anon_sym_DASH] = ACTIONS(1085),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1083),
    [anon_sym_AMP] = ACTIONS(1083),
    [anon_sym_GT_EQ] = ACTIONS(1087),
    [anon_sym_LT_EQ] = ACTIONS(1087),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(1089),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1091),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(1101),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [505] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3000),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2756),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(2814),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(5264),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(2858),
    [sym_property_pattern_clause] = STATE(2881),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6719),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(4164),
    [sym_postfix_unary_expression] = STATE(4165),
    [sym_prefix_unary_expression] = STATE(4165),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(4164),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(4165),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(4164),
    [sym_member_access_expression] = STATE(3482),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(4165),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(4164),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(4164),
    [sym_typeof_expression] = STATE(4164),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3482),
    [sym_literal] = STATE(4164),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2755),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(505),
    [sym_preproc_endregion] = STATE(505),
    [sym_preproc_line] = STATE(505),
    [sym_preproc_pragma] = STATE(505),
    [sym_preproc_nullable] = STATE(505),
    [sym_preproc_error] = STATE(505),
    [sym_preproc_warning] = STATE(505),
    [sym_preproc_define] = STATE(505),
    [sym_preproc_undef] = STATE(505),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(2393),
    [anon_sym_ref] = ACTIONS(2327),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(1077),
    [anon_sym_GT] = ACTIONS(1077),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1083),
    [anon_sym_PLUS_PLUS] = ACTIONS(1083),
    [anon_sym_DASH_DASH] = ACTIONS(1083),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1085),
    [anon_sym_DASH] = ACTIONS(1085),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1083),
    [anon_sym_AMP] = ACTIONS(1083),
    [anon_sym_GT_EQ] = ACTIONS(1087),
    [anon_sym_LT_EQ] = ACTIONS(1087),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2349),
    [sym_predefined_type] = ACTIONS(2339),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2395),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [506] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6764),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2862),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6181),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_pattern] = STATE(8288),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6721),
    [sym_property_pattern_clause] = STATE(6770),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6715),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(6241),
    [sym_postfix_unary_expression] = STATE(6242),
    [sym_prefix_unary_expression] = STATE(6242),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(6241),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(6242),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(6241),
    [sym_member_access_expression] = STATE(4249),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(6242),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(6241),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(6241),
    [sym_typeof_expression] = STATE(6241),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(4249),
    [sym_literal] = STATE(6241),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2810),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(506),
    [sym_preproc_endregion] = STATE(506),
    [sym_preproc_line] = STATE(506),
    [sym_preproc_pragma] = STATE(506),
    [sym_preproc_nullable] = STATE(506),
    [sym_preproc_error] = STATE(506),
    [sym_preproc_warning] = STATE(506),
    [sym_preproc_define] = STATE(506),
    [sym_preproc_undef] = STATE(506),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(2397),
    [anon_sym_ref] = ACTIONS(2399),
    [anon_sym_LBRACE] = ACTIONS(2401),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2403),
    [anon_sym_GT] = ACTIONS(2403),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1629),
    [anon_sym_TILDE] = ACTIONS(1629),
    [anon_sym_PLUS_PLUS] = ACTIONS(1629),
    [anon_sym_DASH_DASH] = ACTIONS(1629),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1627),
    [anon_sym_DASH] = ACTIONS(1627),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1629),
    [anon_sym_AMP] = ACTIONS(1629),
    [anon_sym_GT_EQ] = ACTIONS(2405),
    [anon_sym_LT_EQ] = ACTIONS(2405),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2407),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2409),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2411),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [507] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3211),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2756),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(2814),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(4198),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(2858),
    [sym_property_pattern_clause] = STATE(2881),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6732),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(4164),
    [sym_postfix_unary_expression] = STATE(4165),
    [sym_prefix_unary_expression] = STATE(4165),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(4164),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(4165),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(4164),
    [sym_member_access_expression] = STATE(3482),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(4165),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(4164),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(4164),
    [sym_typeof_expression] = STATE(4164),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3482),
    [sym_literal] = STATE(4164),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2776),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(507),
    [sym_preproc_endregion] = STATE(507),
    [sym_preproc_line] = STATE(507),
    [sym_preproc_pragma] = STATE(507),
    [sym_preproc_nullable] = STATE(507),
    [sym_preproc_error] = STATE(507),
    [sym_preproc_warning] = STATE(507),
    [sym_preproc_define] = STATE(507),
    [sym_preproc_undef] = STATE(507),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(2585),
    [anon_sym_ref] = ACTIONS(2447),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2587),
    [anon_sym_GT] = ACTIONS(2587),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1545),
    [anon_sym_TILDE] = ACTIONS(1545),
    [anon_sym_PLUS_PLUS] = ACTIONS(1545),
    [anon_sym_DASH_DASH] = ACTIONS(1545),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1543),
    [anon_sym_DASH] = ACTIONS(1543),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1545),
    [anon_sym_AMP] = ACTIONS(1545),
    [anon_sym_GT_EQ] = ACTIONS(2589),
    [anon_sym_LT_EQ] = ACTIONS(2589),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2453),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2349),
    [sym_predefined_type] = ACTIONS(2339),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2591),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [508] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3211),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2756),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(2814),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(6467),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(2858),
    [sym_property_pattern_clause] = STATE(2881),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6732),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(4164),
    [sym_postfix_unary_expression] = STATE(4165),
    [sym_prefix_unary_expression] = STATE(4165),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(4164),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(4165),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(4164),
    [sym_member_access_expression] = STATE(3482),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(4165),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(4164),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(4164),
    [sym_typeof_expression] = STATE(4164),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3482),
    [sym_literal] = STATE(4164),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2776),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(508),
    [sym_preproc_endregion] = STATE(508),
    [sym_preproc_line] = STATE(508),
    [sym_preproc_pragma] = STATE(508),
    [sym_preproc_nullable] = STATE(508),
    [sym_preproc_error] = STATE(508),
    [sym_preproc_warning] = STATE(508),
    [sym_preproc_define] = STATE(508),
    [sym_preproc_undef] = STATE(508),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(2585),
    [anon_sym_ref] = ACTIONS(2447),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2587),
    [anon_sym_GT] = ACTIONS(2587),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1545),
    [anon_sym_TILDE] = ACTIONS(1545),
    [anon_sym_PLUS_PLUS] = ACTIONS(1545),
    [anon_sym_DASH_DASH] = ACTIONS(1545),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1543),
    [anon_sym_DASH] = ACTIONS(1543),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1545),
    [anon_sym_AMP] = ACTIONS(1545),
    [anon_sym_GT_EQ] = ACTIONS(2589),
    [anon_sym_LT_EQ] = ACTIONS(2589),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2453),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2349),
    [sym_predefined_type] = ACTIONS(2339),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2591),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [509] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6764),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2862),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6181),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_pattern] = STATE(4198),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(6721),
    [sym_property_pattern_clause] = STATE(6770),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6715),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(6241),
    [sym_postfix_unary_expression] = STATE(6242),
    [sym_prefix_unary_expression] = STATE(6242),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(6241),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(6242),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(6241),
    [sym_member_access_expression] = STATE(4249),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(6242),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(6241),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(6241),
    [sym_typeof_expression] = STATE(6241),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(4249),
    [sym_literal] = STATE(6241),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2810),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(509),
    [sym_preproc_endregion] = STATE(509),
    [sym_preproc_line] = STATE(509),
    [sym_preproc_pragma] = STATE(509),
    [sym_preproc_nullable] = STATE(509),
    [sym_preproc_error] = STATE(509),
    [sym_preproc_warning] = STATE(509),
    [sym_preproc_define] = STATE(509),
    [sym_preproc_undef] = STATE(509),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(2397),
    [anon_sym_ref] = ACTIONS(2399),
    [anon_sym_LBRACE] = ACTIONS(2401),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2403),
    [anon_sym_GT] = ACTIONS(2403),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1629),
    [anon_sym_TILDE] = ACTIONS(1629),
    [anon_sym_PLUS_PLUS] = ACTIONS(1629),
    [anon_sym_DASH_DASH] = ACTIONS(1629),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1627),
    [anon_sym_DASH] = ACTIONS(1627),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1629),
    [anon_sym_AMP] = ACTIONS(1629),
    [anon_sym_GT_EQ] = ACTIONS(2405),
    [anon_sym_LT_EQ] = ACTIONS(2405),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2407),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2409),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2411),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [510] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3000),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2756),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(2814),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(4198),
    [sym_constant_pattern] = STATE(4157),
    [sym_parenthesized_pattern] = STATE(4157),
    [sym_var_pattern] = STATE(4157),
    [sym_type_pattern] = STATE(4157),
    [sym_list_pattern] = STATE(4157),
    [sym_recursive_pattern] = STATE(4157),
    [sym_positional_pattern_clause] = STATE(2858),
    [sym_property_pattern_clause] = STATE(2881),
    [sym_relational_pattern] = STATE(4157),
    [sym_negated_pattern] = STATE(4157),
    [sym_and_pattern] = STATE(4157),
    [sym_or_pattern] = STATE(4157),
    [sym_declaration_pattern] = STATE(4157),
    [sym_expression] = STATE(6719),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(4164),
    [sym_postfix_unary_expression] = STATE(4165),
    [sym_prefix_unary_expression] = STATE(4165),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(4164),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(4165),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(4164),
    [sym_member_access_expression] = STATE(3482),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(4165),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(4164),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(4164),
    [sym_typeof_expression] = STATE(4164),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3482),
    [sym_literal] = STATE(4164),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2755),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(510),
    [sym_preproc_endregion] = STATE(510),
    [sym_preproc_line] = STATE(510),
    [sym_preproc_pragma] = STATE(510),
    [sym_preproc_nullable] = STATE(510),
    [sym_preproc_error] = STATE(510),
    [sym_preproc_warning] = STATE(510),
    [sym_preproc_define] = STATE(510),
    [sym_preproc_undef] = STATE(510),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1063),
    [anon_sym_LPAREN] = ACTIONS(2393),
    [anon_sym_ref] = ACTIONS(2327),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(1077),
    [anon_sym_GT] = ACTIONS(1077),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1083),
    [anon_sym_PLUS_PLUS] = ACTIONS(1083),
    [anon_sym_DASH_DASH] = ACTIONS(1083),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1085),
    [anon_sym_DASH] = ACTIONS(1085),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1083),
    [anon_sym_AMP] = ACTIONS(1083),
    [anon_sym_GT_EQ] = ACTIONS(1087),
    [anon_sym_LT_EQ] = ACTIONS(1087),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2349),
    [sym_predefined_type] = ACTIONS(2339),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(1097),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2395),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [511] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3545),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2917),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(3087),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_pattern] = STATE(4995),
    [sym_constant_pattern] = STATE(5032),
    [sym_parenthesized_pattern] = STATE(5032),
    [sym_var_pattern] = STATE(5032),
    [sym_type_pattern] = STATE(5032),
    [sym_list_pattern] = STATE(5032),
    [sym_recursive_pattern] = STATE(5032),
    [sym_positional_pattern_clause] = STATE(3143),
    [sym_property_pattern_clause] = STATE(3360),
    [sym_relational_pattern] = STATE(5032),
    [sym_negated_pattern] = STATE(5032),
    [sym_and_pattern] = STATE(5032),
    [sym_or_pattern] = STATE(5032),
    [sym_declaration_pattern] = STATE(5032),
    [sym_expression] = STATE(6735),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(4990),
    [sym_postfix_unary_expression] = STATE(5037),
    [sym_prefix_unary_expression] = STATE(5037),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(4990),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(5037),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(4990),
    [sym_member_access_expression] = STATE(3739),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(5037),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(4990),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(4990),
    [sym_typeof_expression] = STATE(4990),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3739),
    [sym_literal] = STATE(4990),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2755),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(511),
    [sym_preproc_endregion] = STATE(511),
    [sym_preproc_line] = STATE(511),
    [sym_preproc_pragma] = STATE(511),
    [sym_preproc_nullable] = STATE(511),
    [sym_preproc_error] = STATE(511),
    [sym_preproc_warning] = STATE(511),
    [sym_preproc_define] = STATE(511),
    [sym_preproc_undef] = STATE(511),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(2477),
    [anon_sym_LPAREN] = ACTIONS(2539),
    [anon_sym_ref] = ACTIONS(2327),
    [anon_sym_LBRACE] = ACTIONS(2329),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_LT] = ACTIONS(2541),
    [anon_sym_GT] = ACTIONS(2541),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1937),
    [anon_sym_TILDE] = ACTIONS(1937),
    [anon_sym_PLUS_PLUS] = ACTIONS(1937),
    [anon_sym_DASH_DASH] = ACTIONS(1937),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1935),
    [anon_sym_DASH] = ACTIONS(1935),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1937),
    [anon_sym_AMP] = ACTIONS(1937),
    [anon_sym_GT_EQ] = ACTIONS(2543),
    [anon_sym_LT_EQ] = ACTIONS(2543),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2545),
    [sym_predefined_type] = ACTIONS(2487),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [sym_discard] = ACTIONS(2489),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_not] = ACTIONS(2547),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [512] = {
    [sym_attribute] = STATE(8445),
    [sym_attribute_list] = STATE(6699),
    [sym_attribute_target_specifier] = STATE(6817),
    [sym_parameter_list] = STATE(9685),
    [sym_argument] = STATE(8466),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6785),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6964),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2779),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(512),
    [sym_preproc_endregion] = STATE(512),
    [sym_preproc_line] = STATE(512),
    [sym_preproc_pragma] = STATE(512),
    [sym_preproc_nullable] = STATE(512),
    [sym_preproc_error] = STATE(512),
    [sym_preproc_warning] = STATE(512),
    [sym_preproc_define] = STATE(512),
    [sym_preproc_undef] = STATE(512),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_assembly] = ACTIONS(2597),
    [anon_sym_module] = ACTIONS(2597),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_field] = ACTIONS(1069),
    [anon_sym_event] = ACTIONS(1069),
    [anon_sym_method] = ACTIONS(1069),
    [anon_sym_param] = ACTIONS(1069),
    [anon_sym_property] = ACTIONS(1069),
    [anon_sym_return] = ACTIONS(1069),
    [anon_sym_type] = ACTIONS(1069),
    [anon_sym_ref] = ACTIONS(2599),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_in] = ACTIONS(1079),
    [anon_sym_out] = ACTIONS(1079),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [513] = {
    [sym_attribute] = STATE(8445),
    [sym_attribute_list] = STATE(6699),
    [sym_attribute_target_specifier] = STATE(6817),
    [sym_parameter_list] = STATE(9685),
    [sym_argument] = STATE(8466),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6785),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6964),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2779),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(513),
    [sym_preproc_endregion] = STATE(513),
    [sym_preproc_line] = STATE(513),
    [sym_preproc_pragma] = STATE(513),
    [sym_preproc_nullable] = STATE(513),
    [sym_preproc_error] = STATE(513),
    [sym_preproc_warning] = STATE(513),
    [sym_preproc_define] = STATE(513),
    [sym_preproc_undef] = STATE(513),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_assembly] = ACTIONS(2601),
    [anon_sym_module] = ACTIONS(2601),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_field] = ACTIONS(1069),
    [anon_sym_event] = ACTIONS(1069),
    [anon_sym_method] = ACTIONS(1069),
    [anon_sym_param] = ACTIONS(1069),
    [anon_sym_property] = ACTIONS(1069),
    [anon_sym_return] = ACTIONS(1069),
    [anon_sym_type] = ACTIONS(1069),
    [anon_sym_ref] = ACTIONS(2599),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_in] = ACTIONS(1079),
    [anon_sym_out] = ACTIONS(1079),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [514] = {
    [sym_attribute] = STATE(8640),
    [sym_attribute_list] = STATE(6699),
    [sym_attribute_target_specifier] = STATE(6811),
    [sym_parameter_list] = STATE(9685),
    [sym_argument] = STATE(8688),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6785),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6964),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2779),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(514),
    [sym_preproc_endregion] = STATE(514),
    [sym_preproc_line] = STATE(514),
    [sym_preproc_pragma] = STATE(514),
    [sym_preproc_nullable] = STATE(514),
    [sym_preproc_error] = STATE(514),
    [sym_preproc_warning] = STATE(514),
    [sym_preproc_define] = STATE(514),
    [sym_preproc_undef] = STATE(514),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_field] = ACTIONS(1069),
    [anon_sym_event] = ACTIONS(1069),
    [anon_sym_method] = ACTIONS(1069),
    [anon_sym_param] = ACTIONS(1069),
    [anon_sym_property] = ACTIONS(1069),
    [anon_sym_return] = ACTIONS(1069),
    [anon_sym_type] = ACTIONS(1069),
    [anon_sym_ref] = ACTIONS(2599),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_in] = ACTIONS(1079),
    [anon_sym_out] = ACTIONS(1079),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [515] = {
    [sym_attribute] = STATE(8640),
    [sym_attribute_list] = STATE(6699),
    [sym_attribute_target_specifier] = STATE(6811),
    [sym_parameter_list] = STATE(9685),
    [sym_argument] = STATE(8583),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6785),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6964),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2779),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(515),
    [sym_preproc_endregion] = STATE(515),
    [sym_preproc_line] = STATE(515),
    [sym_preproc_pragma] = STATE(515),
    [sym_preproc_nullable] = STATE(515),
    [sym_preproc_error] = STATE(515),
    [sym_preproc_warning] = STATE(515),
    [sym_preproc_define] = STATE(515),
    [sym_preproc_undef] = STATE(515),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_field] = ACTIONS(1069),
    [anon_sym_event] = ACTIONS(1069),
    [anon_sym_method] = ACTIONS(1069),
    [anon_sym_param] = ACTIONS(1069),
    [anon_sym_property] = ACTIONS(1069),
    [anon_sym_return] = ACTIONS(1069),
    [anon_sym_type] = ACTIONS(1069),
    [anon_sym_ref] = ACTIONS(2599),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_in] = ACTIONS(1079),
    [anon_sym_out] = ACTIONS(1079),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [516] = {
    [sym_attribute] = STATE(8640),
    [sym_attribute_list] = STATE(6699),
    [sym_attribute_target_specifier] = STATE(6811),
    [sym_parameter_list] = STATE(9685),
    [sym_argument] = STATE(8466),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6785),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6964),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2779),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(516),
    [sym_preproc_endregion] = STATE(516),
    [sym_preproc_line] = STATE(516),
    [sym_preproc_pragma] = STATE(516),
    [sym_preproc_nullable] = STATE(516),
    [sym_preproc_error] = STATE(516),
    [sym_preproc_warning] = STATE(516),
    [sym_preproc_define] = STATE(516),
    [sym_preproc_undef] = STATE(516),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_field] = ACTIONS(1069),
    [anon_sym_event] = ACTIONS(1069),
    [anon_sym_method] = ACTIONS(1069),
    [anon_sym_param] = ACTIONS(1069),
    [anon_sym_property] = ACTIONS(1069),
    [anon_sym_return] = ACTIONS(1069),
    [anon_sym_type] = ACTIONS(1069),
    [anon_sym_ref] = ACTIONS(2599),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_in] = ACTIONS(1079),
    [anon_sym_out] = ACTIONS(1079),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [517] = {
    [sym_attribute] = STATE(8640),
    [sym_attribute_list] = STATE(6699),
    [sym_attribute_target_specifier] = STATE(6811),
    [sym_parameter_list] = STATE(9685),
    [sym_argument] = STATE(8641),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6785),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6964),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2779),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(517),
    [sym_preproc_endregion] = STATE(517),
    [sym_preproc_line] = STATE(517),
    [sym_preproc_pragma] = STATE(517),
    [sym_preproc_nullable] = STATE(517),
    [sym_preproc_error] = STATE(517),
    [sym_preproc_warning] = STATE(517),
    [sym_preproc_define] = STATE(517),
    [sym_preproc_undef] = STATE(517),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_field] = ACTIONS(1069),
    [anon_sym_event] = ACTIONS(1069),
    [anon_sym_method] = ACTIONS(1069),
    [anon_sym_param] = ACTIONS(1069),
    [anon_sym_property] = ACTIONS(1069),
    [anon_sym_return] = ACTIONS(1069),
    [anon_sym_type] = ACTIONS(1069),
    [anon_sym_ref] = ACTIONS(2599),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_in] = ACTIONS(1079),
    [anon_sym_out] = ACTIONS(1079),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [518] = {
    [sym_attribute] = STATE(8640),
    [sym_attribute_list] = STATE(6699),
    [sym_attribute_target_specifier] = STATE(6811),
    [sym_parameter_list] = STATE(9685),
    [sym_argument] = STATE(8518),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6785),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6964),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2779),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(518),
    [sym_preproc_endregion] = STATE(518),
    [sym_preproc_line] = STATE(518),
    [sym_preproc_pragma] = STATE(518),
    [sym_preproc_nullable] = STATE(518),
    [sym_preproc_error] = STATE(518),
    [sym_preproc_warning] = STATE(518),
    [sym_preproc_define] = STATE(518),
    [sym_preproc_undef] = STATE(518),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_field] = ACTIONS(1069),
    [anon_sym_event] = ACTIONS(1069),
    [anon_sym_method] = ACTIONS(1069),
    [anon_sym_param] = ACTIONS(1069),
    [anon_sym_property] = ACTIONS(1069),
    [anon_sym_return] = ACTIONS(1069),
    [anon_sym_type] = ACTIONS(1069),
    [anon_sym_ref] = ACTIONS(2599),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_in] = ACTIONS(1079),
    [anon_sym_out] = ACTIONS(1079),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [519] = {
    [sym_attribute] = STATE(8582),
    [sym_attribute_list] = STATE(6699),
    [sym_attribute_target_specifier] = STATE(6827),
    [sym_parameter_list] = STATE(9685),
    [sym_argument] = STATE(8466),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6785),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6964),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2779),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(519),
    [sym_preproc_endregion] = STATE(519),
    [sym_preproc_line] = STATE(519),
    [sym_preproc_pragma] = STATE(519),
    [sym_preproc_nullable] = STATE(519),
    [sym_preproc_error] = STATE(519),
    [sym_preproc_warning] = STATE(519),
    [sym_preproc_define] = STATE(519),
    [sym_preproc_undef] = STATE(519),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_field] = ACTIONS(1069),
    [anon_sym_event] = ACTIONS(1069),
    [anon_sym_method] = ACTIONS(1069),
    [anon_sym_param] = ACTIONS(1069),
    [anon_sym_property] = ACTIONS(1069),
    [anon_sym_return] = ACTIONS(1069),
    [anon_sym_type] = ACTIONS(1069),
    [anon_sym_ref] = ACTIONS(2599),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_in] = ACTIONS(1079),
    [anon_sym_out] = ACTIONS(1079),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [520] = {
    [sym_attribute] = STATE(8640),
    [sym_attribute_list] = STATE(6699),
    [sym_attribute_target_specifier] = STATE(6811),
    [sym_parameter_list] = STATE(9685),
    [sym_argument] = STATE(8484),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6785),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6964),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2779),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(520),
    [sym_preproc_endregion] = STATE(520),
    [sym_preproc_line] = STATE(520),
    [sym_preproc_pragma] = STATE(520),
    [sym_preproc_nullable] = STATE(520),
    [sym_preproc_error] = STATE(520),
    [sym_preproc_warning] = STATE(520),
    [sym_preproc_define] = STATE(520),
    [sym_preproc_undef] = STATE(520),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_field] = ACTIONS(1069),
    [anon_sym_event] = ACTIONS(1069),
    [anon_sym_method] = ACTIONS(1069),
    [anon_sym_param] = ACTIONS(1069),
    [anon_sym_property] = ACTIONS(1069),
    [anon_sym_return] = ACTIONS(1069),
    [anon_sym_type] = ACTIONS(1069),
    [anon_sym_ref] = ACTIONS(2599),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_in] = ACTIONS(1079),
    [anon_sym_out] = ACTIONS(1079),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [521] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8749),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6853),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8977),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(6351),
    [sym_lvalue_expression] = STATE(4365),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(521),
    [sym_preproc_endregion] = STATE(521),
    [sym_preproc_line] = STATE(521),
    [sym_preproc_pragma] = STATE(521),
    [sym_preproc_nullable] = STATE(521),
    [sym_preproc_error] = STATE(521),
    [sym_preproc_warning] = STATE(521),
    [sym_preproc_define] = STATE(521),
    [sym_preproc_undef] = STATE(521),
    [aux_sym_class_declaration_repeat1] = STATE(3575),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2603),
    [anon_sym_ref] = ACTIONS(2605),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2607),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [522] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8790),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6840),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8812),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(6534),
    [sym_lvalue_expression] = STATE(4366),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(522),
    [sym_preproc_endregion] = STATE(522),
    [sym_preproc_line] = STATE(522),
    [sym_preproc_pragma] = STATE(522),
    [sym_preproc_nullable] = STATE(522),
    [sym_preproc_error] = STATE(522),
    [sym_preproc_warning] = STATE(522),
    [sym_preproc_define] = STATE(522),
    [sym_preproc_undef] = STATE(522),
    [aux_sym_class_declaration_repeat1] = STATE(3575),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2603),
    [anon_sym_ref] = ACTIONS(2605),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2607),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [523] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8790),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6866),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8977),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(6534),
    [sym_lvalue_expression] = STATE(4366),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(523),
    [sym_preproc_endregion] = STATE(523),
    [sym_preproc_line] = STATE(523),
    [sym_preproc_pragma] = STATE(523),
    [sym_preproc_nullable] = STATE(523),
    [sym_preproc_error] = STATE(523),
    [sym_preproc_warning] = STATE(523),
    [sym_preproc_define] = STATE(523),
    [sym_preproc_undef] = STATE(523),
    [aux_sym_class_declaration_repeat1] = STATE(3575),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2603),
    [anon_sym_ref] = ACTIONS(2605),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2607),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [524] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8790),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6840),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8977),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(6534),
    [sym_lvalue_expression] = STATE(4366),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(524),
    [sym_preproc_endregion] = STATE(524),
    [sym_preproc_line] = STATE(524),
    [sym_preproc_pragma] = STATE(524),
    [sym_preproc_nullable] = STATE(524),
    [sym_preproc_error] = STATE(524),
    [sym_preproc_warning] = STATE(524),
    [sym_preproc_define] = STATE(524),
    [sym_preproc_undef] = STATE(524),
    [aux_sym_class_declaration_repeat1] = STATE(3575),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2603),
    [anon_sym_ref] = ACTIONS(2605),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2607),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [525] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8749),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6842),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8977),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(6351),
    [sym_lvalue_expression] = STATE(4366),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(525),
    [sym_preproc_endregion] = STATE(525),
    [sym_preproc_line] = STATE(525),
    [sym_preproc_pragma] = STATE(525),
    [sym_preproc_nullable] = STATE(525),
    [sym_preproc_error] = STATE(525),
    [sym_preproc_warning] = STATE(525),
    [sym_preproc_define] = STATE(525),
    [sym_preproc_undef] = STATE(525),
    [aux_sym_class_declaration_repeat1] = STATE(3575),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2603),
    [anon_sym_ref] = ACTIONS(2605),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2607),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [526] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8790),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6905),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8977),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(6534),
    [sym_lvalue_expression] = STATE(4366),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(526),
    [sym_preproc_endregion] = STATE(526),
    [sym_preproc_line] = STATE(526),
    [sym_preproc_pragma] = STATE(526),
    [sym_preproc_nullable] = STATE(526),
    [sym_preproc_error] = STATE(526),
    [sym_preproc_warning] = STATE(526),
    [sym_preproc_define] = STATE(526),
    [sym_preproc_undef] = STATE(526),
    [aux_sym_class_declaration_repeat1] = STATE(3575),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2603),
    [anon_sym_ref] = ACTIONS(2605),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2607),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [527] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8749),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6869),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8977),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(6351),
    [sym_lvalue_expression] = STATE(4365),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(527),
    [sym_preproc_endregion] = STATE(527),
    [sym_preproc_line] = STATE(527),
    [sym_preproc_pragma] = STATE(527),
    [sym_preproc_nullable] = STATE(527),
    [sym_preproc_error] = STATE(527),
    [sym_preproc_warning] = STATE(527),
    [sym_preproc_define] = STATE(527),
    [sym_preproc_undef] = STATE(527),
    [aux_sym_class_declaration_repeat1] = STATE(3575),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2603),
    [anon_sym_ref] = ACTIONS(2605),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2607),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [528] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8776),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6845),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8977),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(6500),
    [sym_lvalue_expression] = STATE(4436),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(528),
    [sym_preproc_endregion] = STATE(528),
    [sym_preproc_line] = STATE(528),
    [sym_preproc_pragma] = STATE(528),
    [sym_preproc_nullable] = STATE(528),
    [sym_preproc_error] = STATE(528),
    [sym_preproc_warning] = STATE(528),
    [sym_preproc_define] = STATE(528),
    [sym_preproc_undef] = STATE(528),
    [aux_sym_class_declaration_repeat1] = STATE(3575),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2603),
    [anon_sym_ref] = ACTIONS(2605),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2607),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [529] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8790),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6841),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8977),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(6534),
    [sym_lvalue_expression] = STATE(4384),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(529),
    [sym_preproc_endregion] = STATE(529),
    [sym_preproc_line] = STATE(529),
    [sym_preproc_pragma] = STATE(529),
    [sym_preproc_nullable] = STATE(529),
    [sym_preproc_error] = STATE(529),
    [sym_preproc_warning] = STATE(529),
    [sym_preproc_define] = STATE(529),
    [sym_preproc_undef] = STATE(529),
    [aux_sym_class_declaration_repeat1] = STATE(3575),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2603),
    [anon_sym_ref] = ACTIONS(2605),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2607),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [530] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8754),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6840),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8977),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(6534),
    [sym_lvalue_expression] = STATE(4457),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(530),
    [sym_preproc_endregion] = STATE(530),
    [sym_preproc_line] = STATE(530),
    [sym_preproc_pragma] = STATE(530),
    [sym_preproc_nullable] = STATE(530),
    [sym_preproc_error] = STATE(530),
    [sym_preproc_warning] = STATE(530),
    [sym_preproc_define] = STATE(530),
    [sym_preproc_undef] = STATE(530),
    [aux_sym_class_declaration_repeat1] = STATE(3575),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2603),
    [anon_sym_ref] = ACTIONS(2605),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2607),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [531] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8749),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6840),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8977),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(6534),
    [sym_lvalue_expression] = STATE(4365),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(531),
    [sym_preproc_endregion] = STATE(531),
    [sym_preproc_line] = STATE(531),
    [sym_preproc_pragma] = STATE(531),
    [sym_preproc_nullable] = STATE(531),
    [sym_preproc_error] = STATE(531),
    [sym_preproc_warning] = STATE(531),
    [sym_preproc_define] = STATE(531),
    [sym_preproc_undef] = STATE(531),
    [aux_sym_class_declaration_repeat1] = STATE(3575),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2603),
    [anon_sym_ref] = ACTIONS(2605),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2607),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [532] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8776),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6840),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8977),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(6534),
    [sym_lvalue_expression] = STATE(4436),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(532),
    [sym_preproc_endregion] = STATE(532),
    [sym_preproc_line] = STATE(532),
    [sym_preproc_pragma] = STATE(532),
    [sym_preproc_nullable] = STATE(532),
    [sym_preproc_error] = STATE(532),
    [sym_preproc_warning] = STATE(532),
    [sym_preproc_define] = STATE(532),
    [sym_preproc_undef] = STATE(532),
    [aux_sym_class_declaration_repeat1] = STATE(3575),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2603),
    [anon_sym_ref] = ACTIONS(2605),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2607),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [533] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8790),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6882),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8977),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(6534),
    [sym_lvalue_expression] = STATE(4384),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(533),
    [sym_preproc_endregion] = STATE(533),
    [sym_preproc_line] = STATE(533),
    [sym_preproc_pragma] = STATE(533),
    [sym_preproc_nullable] = STATE(533),
    [sym_preproc_error] = STATE(533),
    [sym_preproc_warning] = STATE(533),
    [sym_preproc_define] = STATE(533),
    [sym_preproc_undef] = STATE(533),
    [aux_sym_class_declaration_repeat1] = STATE(3575),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2603),
    [anon_sym_ref] = ACTIONS(2605),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2607),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [534] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8749),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6876),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8977),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(6351),
    [sym_lvalue_expression] = STATE(4365),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(534),
    [sym_preproc_endregion] = STATE(534),
    [sym_preproc_line] = STATE(534),
    [sym_preproc_pragma] = STATE(534),
    [sym_preproc_nullable] = STATE(534),
    [sym_preproc_error] = STATE(534),
    [sym_preproc_warning] = STATE(534),
    [sym_preproc_define] = STATE(534),
    [sym_preproc_undef] = STATE(534),
    [aux_sym_class_declaration_repeat1] = STATE(3575),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2603),
    [anon_sym_ref] = ACTIONS(2605),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2607),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [535] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8790),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6830),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8977),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(6534),
    [sym_lvalue_expression] = STATE(4384),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(535),
    [sym_preproc_endregion] = STATE(535),
    [sym_preproc_line] = STATE(535),
    [sym_preproc_pragma] = STATE(535),
    [sym_preproc_nullable] = STATE(535),
    [sym_preproc_error] = STATE(535),
    [sym_preproc_warning] = STATE(535),
    [sym_preproc_define] = STATE(535),
    [sym_preproc_undef] = STATE(535),
    [aux_sym_class_declaration_repeat1] = STATE(3575),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2603),
    [anon_sym_ref] = ACTIONS(2605),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2607),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [536] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8790),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6903),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8977),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(6534),
    [sym_lvalue_expression] = STATE(4384),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(536),
    [sym_preproc_endregion] = STATE(536),
    [sym_preproc_line] = STATE(536),
    [sym_preproc_pragma] = STATE(536),
    [sym_preproc_nullable] = STATE(536),
    [sym_preproc_error] = STATE(536),
    [sym_preproc_warning] = STATE(536),
    [sym_preproc_define] = STATE(536),
    [sym_preproc_undef] = STATE(536),
    [aux_sym_class_declaration_repeat1] = STATE(3575),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2603),
    [anon_sym_ref] = ACTIONS(2605),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2607),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [537] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8790),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6840),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8977),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(6534),
    [sym_lvalue_expression] = STATE(4384),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(537),
    [sym_preproc_endregion] = STATE(537),
    [sym_preproc_line] = STATE(537),
    [sym_preproc_pragma] = STATE(537),
    [sym_preproc_nullable] = STATE(537),
    [sym_preproc_error] = STATE(537),
    [sym_preproc_warning] = STATE(537),
    [sym_preproc_define] = STATE(537),
    [sym_preproc_undef] = STATE(537),
    [aux_sym_class_declaration_repeat1] = STATE(3575),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2603),
    [anon_sym_ref] = ACTIONS(2605),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2607),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [538] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8749),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6848),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8977),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(6351),
    [sym_lvalue_expression] = STATE(4365),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(538),
    [sym_preproc_endregion] = STATE(538),
    [sym_preproc_line] = STATE(538),
    [sym_preproc_pragma] = STATE(538),
    [sym_preproc_nullable] = STATE(538),
    [sym_preproc_error] = STATE(538),
    [sym_preproc_warning] = STATE(538),
    [sym_preproc_define] = STATE(538),
    [sym_preproc_undef] = STATE(538),
    [aux_sym_class_declaration_repeat1] = STATE(3575),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2603),
    [anon_sym_ref] = ACTIONS(2605),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2607),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [539] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8754),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6895),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8977),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(6583),
    [sym_lvalue_expression] = STATE(4457),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(539),
    [sym_preproc_endregion] = STATE(539),
    [sym_preproc_line] = STATE(539),
    [sym_preproc_pragma] = STATE(539),
    [sym_preproc_nullable] = STATE(539),
    [sym_preproc_error] = STATE(539),
    [sym_preproc_warning] = STATE(539),
    [sym_preproc_define] = STATE(539),
    [sym_preproc_undef] = STATE(539),
    [aux_sym_class_declaration_repeat1] = STATE(3575),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2603),
    [anon_sym_ref] = ACTIONS(2605),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2607),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [540] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8749),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6872),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8977),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(6351),
    [sym_lvalue_expression] = STATE(4365),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(540),
    [sym_preproc_endregion] = STATE(540),
    [sym_preproc_line] = STATE(540),
    [sym_preproc_pragma] = STATE(540),
    [sym_preproc_nullable] = STATE(540),
    [sym_preproc_error] = STATE(540),
    [sym_preproc_warning] = STATE(540),
    [sym_preproc_define] = STATE(540),
    [sym_preproc_undef] = STATE(540),
    [aux_sym_class_declaration_repeat1] = STATE(3575),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2603),
    [anon_sym_ref] = ACTIONS(2605),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2607),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [541] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8776),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6838),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8977),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(6500),
    [sym_lvalue_expression] = STATE(4436),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(541),
    [sym_preproc_endregion] = STATE(541),
    [sym_preproc_line] = STATE(541),
    [sym_preproc_pragma] = STATE(541),
    [sym_preproc_nullable] = STATE(541),
    [sym_preproc_error] = STATE(541),
    [sym_preproc_warning] = STATE(541),
    [sym_preproc_define] = STATE(541),
    [sym_preproc_undef] = STATE(541),
    [aux_sym_class_declaration_repeat1] = STATE(3575),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2603),
    [anon_sym_ref] = ACTIONS(2605),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2607),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [542] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8790),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6881),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8977),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(6534),
    [sym_lvalue_expression] = STATE(4384),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(542),
    [sym_preproc_endregion] = STATE(542),
    [sym_preproc_line] = STATE(542),
    [sym_preproc_pragma] = STATE(542),
    [sym_preproc_nullable] = STATE(542),
    [sym_preproc_error] = STATE(542),
    [sym_preproc_warning] = STATE(542),
    [sym_preproc_define] = STATE(542),
    [sym_preproc_undef] = STATE(542),
    [aux_sym_class_declaration_repeat1] = STATE(3575),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2603),
    [anon_sym_ref] = ACTIONS(2605),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2607),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [543] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8790),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6878),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8977),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(6534),
    [sym_lvalue_expression] = STATE(4384),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(543),
    [sym_preproc_endregion] = STATE(543),
    [sym_preproc_line] = STATE(543),
    [sym_preproc_pragma] = STATE(543),
    [sym_preproc_nullable] = STATE(543),
    [sym_preproc_error] = STATE(543),
    [sym_preproc_warning] = STATE(543),
    [sym_preproc_define] = STATE(543),
    [sym_preproc_undef] = STATE(543),
    [aux_sym_class_declaration_repeat1] = STATE(3575),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2603),
    [anon_sym_ref] = ACTIONS(2605),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2607),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [544] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8790),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6846),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8977),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(6534),
    [sym_lvalue_expression] = STATE(4384),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(544),
    [sym_preproc_endregion] = STATE(544),
    [sym_preproc_line] = STATE(544),
    [sym_preproc_pragma] = STATE(544),
    [sym_preproc_nullable] = STATE(544),
    [sym_preproc_error] = STATE(544),
    [sym_preproc_warning] = STATE(544),
    [sym_preproc_define] = STATE(544),
    [sym_preproc_undef] = STATE(544),
    [aux_sym_class_declaration_repeat1] = STATE(3575),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2603),
    [anon_sym_ref] = ACTIONS(2605),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2607),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [545] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8982),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6867),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8977),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(6390),
    [sym_lvalue_expression] = STATE(4386),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(545),
    [sym_preproc_endregion] = STATE(545),
    [sym_preproc_line] = STATE(545),
    [sym_preproc_pragma] = STATE(545),
    [sym_preproc_nullable] = STATE(545),
    [sym_preproc_error] = STATE(545),
    [sym_preproc_warning] = STATE(545),
    [sym_preproc_define] = STATE(545),
    [sym_preproc_undef] = STATE(545),
    [aux_sym_class_declaration_repeat1] = STATE(3575),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2603),
    [anon_sym_ref] = ACTIONS(2605),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2607),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [546] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8749),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6888),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8977),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(6351),
    [sym_lvalue_expression] = STATE(4366),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(546),
    [sym_preproc_endregion] = STATE(546),
    [sym_preproc_line] = STATE(546),
    [sym_preproc_pragma] = STATE(546),
    [sym_preproc_nullable] = STATE(546),
    [sym_preproc_error] = STATE(546),
    [sym_preproc_warning] = STATE(546),
    [sym_preproc_define] = STATE(546),
    [sym_preproc_undef] = STATE(546),
    [aux_sym_class_declaration_repeat1] = STATE(3575),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2603),
    [anon_sym_ref] = ACTIONS(2605),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2607),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [547] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8754),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6861),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8977),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(6583),
    [sym_lvalue_expression] = STATE(4457),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(547),
    [sym_preproc_endregion] = STATE(547),
    [sym_preproc_line] = STATE(547),
    [sym_preproc_pragma] = STATE(547),
    [sym_preproc_nullable] = STATE(547),
    [sym_preproc_error] = STATE(547),
    [sym_preproc_warning] = STATE(547),
    [sym_preproc_define] = STATE(547),
    [sym_preproc_undef] = STATE(547),
    [aux_sym_class_declaration_repeat1] = STATE(3575),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2603),
    [anon_sym_ref] = ACTIONS(2605),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2607),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [548] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8790),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6874),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8977),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(6534),
    [sym_lvalue_expression] = STATE(4384),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(548),
    [sym_preproc_endregion] = STATE(548),
    [sym_preproc_line] = STATE(548),
    [sym_preproc_pragma] = STATE(548),
    [sym_preproc_nullable] = STATE(548),
    [sym_preproc_error] = STATE(548),
    [sym_preproc_warning] = STATE(548),
    [sym_preproc_define] = STATE(548),
    [sym_preproc_undef] = STATE(548),
    [aux_sym_class_declaration_repeat1] = STATE(3575),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2603),
    [anon_sym_ref] = ACTIONS(2605),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2607),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [549] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8776),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6858),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8977),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(6500),
    [sym_lvalue_expression] = STATE(4436),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(549),
    [sym_preproc_endregion] = STATE(549),
    [sym_preproc_line] = STATE(549),
    [sym_preproc_pragma] = STATE(549),
    [sym_preproc_nullable] = STATE(549),
    [sym_preproc_error] = STATE(549),
    [sym_preproc_warning] = STATE(549),
    [sym_preproc_define] = STATE(549),
    [sym_preproc_undef] = STATE(549),
    [aux_sym_class_declaration_repeat1] = STATE(3575),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2603),
    [anon_sym_ref] = ACTIONS(2605),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2607),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [550] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8982),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6877),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8977),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(6390),
    [sym_lvalue_expression] = STATE(4386),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(550),
    [sym_preproc_endregion] = STATE(550),
    [sym_preproc_line] = STATE(550),
    [sym_preproc_pragma] = STATE(550),
    [sym_preproc_nullable] = STATE(550),
    [sym_preproc_error] = STATE(550),
    [sym_preproc_warning] = STATE(550),
    [sym_preproc_define] = STATE(550),
    [sym_preproc_undef] = STATE(550),
    [aux_sym_class_declaration_repeat1] = STATE(3575),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2603),
    [anon_sym_ref] = ACTIONS(2605),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2607),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [551] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8982),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6886),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8977),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(6390),
    [sym_lvalue_expression] = STATE(4386),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(551),
    [sym_preproc_endregion] = STATE(551),
    [sym_preproc_line] = STATE(551),
    [sym_preproc_pragma] = STATE(551),
    [sym_preproc_nullable] = STATE(551),
    [sym_preproc_error] = STATE(551),
    [sym_preproc_warning] = STATE(551),
    [sym_preproc_define] = STATE(551),
    [sym_preproc_undef] = STATE(551),
    [aux_sym_class_declaration_repeat1] = STATE(3575),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2603),
    [anon_sym_ref] = ACTIONS(2605),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2607),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [552] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8982),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6840),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8977),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(6534),
    [sym_lvalue_expression] = STATE(4386),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(552),
    [sym_preproc_endregion] = STATE(552),
    [sym_preproc_line] = STATE(552),
    [sym_preproc_pragma] = STATE(552),
    [sym_preproc_nullable] = STATE(552),
    [sym_preproc_error] = STATE(552),
    [sym_preproc_warning] = STATE(552),
    [sym_preproc_define] = STATE(552),
    [sym_preproc_undef] = STATE(552),
    [aux_sym_class_declaration_repeat1] = STATE(3575),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2603),
    [anon_sym_ref] = ACTIONS(2605),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2607),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [553] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8749),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6893),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8977),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(6351),
    [sym_lvalue_expression] = STATE(4365),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(553),
    [sym_preproc_endregion] = STATE(553),
    [sym_preproc_line] = STATE(553),
    [sym_preproc_pragma] = STATE(553),
    [sym_preproc_nullable] = STATE(553),
    [sym_preproc_error] = STATE(553),
    [sym_preproc_warning] = STATE(553),
    [sym_preproc_define] = STATE(553),
    [sym_preproc_undef] = STATE(553),
    [aux_sym_class_declaration_repeat1] = STATE(3575),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2603),
    [anon_sym_ref] = ACTIONS(2605),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2607),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [554] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8749),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6899),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8977),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(6351),
    [sym_lvalue_expression] = STATE(4365),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(554),
    [sym_preproc_endregion] = STATE(554),
    [sym_preproc_line] = STATE(554),
    [sym_preproc_pragma] = STATE(554),
    [sym_preproc_nullable] = STATE(554),
    [sym_preproc_error] = STATE(554),
    [sym_preproc_warning] = STATE(554),
    [sym_preproc_define] = STATE(554),
    [sym_preproc_undef] = STATE(554),
    [aux_sym_class_declaration_repeat1] = STATE(3575),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2603),
    [anon_sym_ref] = ACTIONS(2605),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2607),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [555] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8982),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6906),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8977),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(6390),
    [sym_lvalue_expression] = STATE(4386),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(555),
    [sym_preproc_endregion] = STATE(555),
    [sym_preproc_line] = STATE(555),
    [sym_preproc_pragma] = STATE(555),
    [sym_preproc_nullable] = STATE(555),
    [sym_preproc_error] = STATE(555),
    [sym_preproc_warning] = STATE(555),
    [sym_preproc_define] = STATE(555),
    [sym_preproc_undef] = STATE(555),
    [aux_sym_class_declaration_repeat1] = STATE(3575),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2603),
    [anon_sym_ref] = ACTIONS(2605),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2607),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [556] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8790),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6873),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8977),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(6534),
    [sym_lvalue_expression] = STATE(4384),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(556),
    [sym_preproc_endregion] = STATE(556),
    [sym_preproc_line] = STATE(556),
    [sym_preproc_pragma] = STATE(556),
    [sym_preproc_nullable] = STATE(556),
    [sym_preproc_error] = STATE(556),
    [sym_preproc_warning] = STATE(556),
    [sym_preproc_define] = STATE(556),
    [sym_preproc_undef] = STATE(556),
    [aux_sym_class_declaration_repeat1] = STATE(3575),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2603),
    [anon_sym_ref] = ACTIONS(2605),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2607),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [557] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8790),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6896),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8977),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(6534),
    [sym_lvalue_expression] = STATE(4384),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(557),
    [sym_preproc_endregion] = STATE(557),
    [sym_preproc_line] = STATE(557),
    [sym_preproc_pragma] = STATE(557),
    [sym_preproc_nullable] = STATE(557),
    [sym_preproc_error] = STATE(557),
    [sym_preproc_warning] = STATE(557),
    [sym_preproc_define] = STATE(557),
    [sym_preproc_undef] = STATE(557),
    [aux_sym_class_declaration_repeat1] = STATE(3575),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2603),
    [anon_sym_ref] = ACTIONS(2605),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2607),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [558] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8754),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6892),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8977),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(6583),
    [sym_lvalue_expression] = STATE(4457),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(558),
    [sym_preproc_endregion] = STATE(558),
    [sym_preproc_line] = STATE(558),
    [sym_preproc_pragma] = STATE(558),
    [sym_preproc_nullable] = STATE(558),
    [sym_preproc_error] = STATE(558),
    [sym_preproc_warning] = STATE(558),
    [sym_preproc_define] = STATE(558),
    [sym_preproc_undef] = STATE(558),
    [aux_sym_class_declaration_repeat1] = STATE(3575),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2603),
    [anon_sym_ref] = ACTIONS(2605),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2607),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [559] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8982),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6907),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8977),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(6390),
    [sym_lvalue_expression] = STATE(4386),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(559),
    [sym_preproc_endregion] = STATE(559),
    [sym_preproc_line] = STATE(559),
    [sym_preproc_pragma] = STATE(559),
    [sym_preproc_nullable] = STATE(559),
    [sym_preproc_error] = STATE(559),
    [sym_preproc_warning] = STATE(559),
    [sym_preproc_define] = STATE(559),
    [sym_preproc_undef] = STATE(559),
    [aux_sym_class_declaration_repeat1] = STATE(3575),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2603),
    [anon_sym_ref] = ACTIONS(2605),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2607),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [560] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8776),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6898),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8977),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(6500),
    [sym_lvalue_expression] = STATE(4436),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(560),
    [sym_preproc_endregion] = STATE(560),
    [sym_preproc_line] = STATE(560),
    [sym_preproc_pragma] = STATE(560),
    [sym_preproc_nullable] = STATE(560),
    [sym_preproc_error] = STATE(560),
    [sym_preproc_warning] = STATE(560),
    [sym_preproc_define] = STATE(560),
    [sym_preproc_undef] = STATE(560),
    [aux_sym_class_declaration_repeat1] = STATE(3575),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2603),
    [anon_sym_ref] = ACTIONS(2605),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2607),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [561] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8790),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6860),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8977),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(6534),
    [sym_lvalue_expression] = STATE(4384),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(561),
    [sym_preproc_endregion] = STATE(561),
    [sym_preproc_line] = STATE(561),
    [sym_preproc_pragma] = STATE(561),
    [sym_preproc_nullable] = STATE(561),
    [sym_preproc_error] = STATE(561),
    [sym_preproc_warning] = STATE(561),
    [sym_preproc_define] = STATE(561),
    [sym_preproc_undef] = STATE(561),
    [aux_sym_class_declaration_repeat1] = STATE(3575),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2603),
    [anon_sym_ref] = ACTIONS(2605),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2607),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [562] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8982),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6863),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8977),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(6390),
    [sym_lvalue_expression] = STATE(4386),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(562),
    [sym_preproc_endregion] = STATE(562),
    [sym_preproc_line] = STATE(562),
    [sym_preproc_pragma] = STATE(562),
    [sym_preproc_nullable] = STATE(562),
    [sym_preproc_error] = STATE(562),
    [sym_preproc_warning] = STATE(562),
    [sym_preproc_define] = STATE(562),
    [sym_preproc_undef] = STATE(562),
    [aux_sym_class_declaration_repeat1] = STATE(3575),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2603),
    [anon_sym_ref] = ACTIONS(2605),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2607),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [563] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8982),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6887),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8977),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(6390),
    [sym_lvalue_expression] = STATE(4386),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(563),
    [sym_preproc_endregion] = STATE(563),
    [sym_preproc_line] = STATE(563),
    [sym_preproc_pragma] = STATE(563),
    [sym_preproc_nullable] = STATE(563),
    [sym_preproc_error] = STATE(563),
    [sym_preproc_warning] = STATE(563),
    [sym_preproc_define] = STATE(563),
    [sym_preproc_undef] = STATE(563),
    [aux_sym_class_declaration_repeat1] = STATE(3575),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2603),
    [anon_sym_ref] = ACTIONS(2605),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2607),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [564] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8982),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6908),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8977),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(6390),
    [sym_lvalue_expression] = STATE(4386),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(564),
    [sym_preproc_endregion] = STATE(564),
    [sym_preproc_line] = STATE(564),
    [sym_preproc_pragma] = STATE(564),
    [sym_preproc_nullable] = STATE(564),
    [sym_preproc_error] = STATE(564),
    [sym_preproc_warning] = STATE(564),
    [sym_preproc_define] = STATE(564),
    [sym_preproc_undef] = STATE(564),
    [aux_sym_class_declaration_repeat1] = STATE(3575),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2603),
    [anon_sym_ref] = ACTIONS(2605),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2607),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [565] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8790),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6837),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8977),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(6534),
    [sym_lvalue_expression] = STATE(4366),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(565),
    [sym_preproc_endregion] = STATE(565),
    [sym_preproc_line] = STATE(565),
    [sym_preproc_pragma] = STATE(565),
    [sym_preproc_nullable] = STATE(565),
    [sym_preproc_error] = STATE(565),
    [sym_preproc_warning] = STATE(565),
    [sym_preproc_define] = STATE(565),
    [sym_preproc_undef] = STATE(565),
    [aux_sym_class_declaration_repeat1] = STATE(3575),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2603),
    [anon_sym_ref] = ACTIONS(2605),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2607),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [566] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8749),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6856),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8977),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(6351),
    [sym_lvalue_expression] = STATE(4365),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(566),
    [sym_preproc_endregion] = STATE(566),
    [sym_preproc_line] = STATE(566),
    [sym_preproc_pragma] = STATE(566),
    [sym_preproc_nullable] = STATE(566),
    [sym_preproc_error] = STATE(566),
    [sym_preproc_warning] = STATE(566),
    [sym_preproc_define] = STATE(566),
    [sym_preproc_undef] = STATE(566),
    [aux_sym_class_declaration_repeat1] = STATE(3575),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2603),
    [anon_sym_ref] = ACTIONS(2605),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2607),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [567] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8790),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6832),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8977),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(6534),
    [sym_lvalue_expression] = STATE(4366),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(567),
    [sym_preproc_endregion] = STATE(567),
    [sym_preproc_line] = STATE(567),
    [sym_preproc_pragma] = STATE(567),
    [sym_preproc_nullable] = STATE(567),
    [sym_preproc_error] = STATE(567),
    [sym_preproc_warning] = STATE(567),
    [sym_preproc_define] = STATE(567),
    [sym_preproc_undef] = STATE(567),
    [aux_sym_class_declaration_repeat1] = STATE(3575),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2603),
    [anon_sym_ref] = ACTIONS(2605),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2607),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [568] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8790),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6909),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8977),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(6534),
    [sym_lvalue_expression] = STATE(4366),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(568),
    [sym_preproc_endregion] = STATE(568),
    [sym_preproc_line] = STATE(568),
    [sym_preproc_pragma] = STATE(568),
    [sym_preproc_nullable] = STATE(568),
    [sym_preproc_error] = STATE(568),
    [sym_preproc_warning] = STATE(568),
    [sym_preproc_define] = STATE(568),
    [sym_preproc_undef] = STATE(568),
    [aux_sym_class_declaration_repeat1] = STATE(3575),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2603),
    [anon_sym_ref] = ACTIONS(2605),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2607),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [569] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8790),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6900),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8977),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(6534),
    [sym_lvalue_expression] = STATE(4366),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(569),
    [sym_preproc_endregion] = STATE(569),
    [sym_preproc_line] = STATE(569),
    [sym_preproc_pragma] = STATE(569),
    [sym_preproc_nullable] = STATE(569),
    [sym_preproc_error] = STATE(569),
    [sym_preproc_warning] = STATE(569),
    [sym_preproc_define] = STATE(569),
    [sym_preproc_undef] = STATE(569),
    [aux_sym_class_declaration_repeat1] = STATE(3575),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2603),
    [anon_sym_ref] = ACTIONS(2605),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2607),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [570] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8790),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6891),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8977),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(6534),
    [sym_lvalue_expression] = STATE(4366),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(570),
    [sym_preproc_endregion] = STATE(570),
    [sym_preproc_line] = STATE(570),
    [sym_preproc_pragma] = STATE(570),
    [sym_preproc_nullable] = STATE(570),
    [sym_preproc_error] = STATE(570),
    [sym_preproc_warning] = STATE(570),
    [sym_preproc_define] = STATE(570),
    [sym_preproc_undef] = STATE(570),
    [aux_sym_class_declaration_repeat1] = STATE(3575),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2603),
    [anon_sym_ref] = ACTIONS(2605),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2607),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [571] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8790),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6840),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8759),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(6534),
    [sym_lvalue_expression] = STATE(4366),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(571),
    [sym_preproc_endregion] = STATE(571),
    [sym_preproc_line] = STATE(571),
    [sym_preproc_pragma] = STATE(571),
    [sym_preproc_nullable] = STATE(571),
    [sym_preproc_error] = STATE(571),
    [sym_preproc_warning] = STATE(571),
    [sym_preproc_define] = STATE(571),
    [sym_preproc_undef] = STATE(571),
    [aux_sym_class_declaration_repeat1] = STATE(3575),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2603),
    [anon_sym_ref] = ACTIONS(2605),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2607),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [572] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8749),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6840),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8977),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(6534),
    [sym_lvalue_expression] = STATE(4366),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(572),
    [sym_preproc_endregion] = STATE(572),
    [sym_preproc_line] = STATE(572),
    [sym_preproc_pragma] = STATE(572),
    [sym_preproc_nullable] = STATE(572),
    [sym_preproc_error] = STATE(572),
    [sym_preproc_warning] = STATE(572),
    [sym_preproc_define] = STATE(572),
    [sym_preproc_undef] = STATE(572),
    [aux_sym_class_declaration_repeat1] = STATE(3575),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2603),
    [anon_sym_ref] = ACTIONS(2605),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2607),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [573] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8790),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6884),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8977),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(6534),
    [sym_lvalue_expression] = STATE(4366),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(573),
    [sym_preproc_endregion] = STATE(573),
    [sym_preproc_line] = STATE(573),
    [sym_preproc_pragma] = STATE(573),
    [sym_preproc_nullable] = STATE(573),
    [sym_preproc_error] = STATE(573),
    [sym_preproc_warning] = STATE(573),
    [sym_preproc_define] = STATE(573),
    [sym_preproc_undef] = STATE(573),
    [aux_sym_class_declaration_repeat1] = STATE(3575),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2603),
    [anon_sym_ref] = ACTIONS(2605),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2607),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [574] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8790),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6859),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8977),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(6534),
    [sym_lvalue_expression] = STATE(4366),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(574),
    [sym_preproc_endregion] = STATE(574),
    [sym_preproc_line] = STATE(574),
    [sym_preproc_pragma] = STATE(574),
    [sym_preproc_nullable] = STATE(574),
    [sym_preproc_error] = STATE(574),
    [sym_preproc_warning] = STATE(574),
    [sym_preproc_define] = STATE(574),
    [sym_preproc_undef] = STATE(574),
    [aux_sym_class_declaration_repeat1] = STATE(3575),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2603),
    [anon_sym_ref] = ACTIONS(2605),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2607),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [575] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8790),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6883),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8977),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(6534),
    [sym_lvalue_expression] = STATE(4366),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(575),
    [sym_preproc_endregion] = STATE(575),
    [sym_preproc_line] = STATE(575),
    [sym_preproc_pragma] = STATE(575),
    [sym_preproc_nullable] = STATE(575),
    [sym_preproc_error] = STATE(575),
    [sym_preproc_warning] = STATE(575),
    [sym_preproc_define] = STATE(575),
    [sym_preproc_undef] = STATE(575),
    [aux_sym_class_declaration_repeat1] = STATE(3575),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2603),
    [anon_sym_ref] = ACTIONS(2605),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2607),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [576] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8790),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6829),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8977),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(6534),
    [sym_lvalue_expression] = STATE(4366),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(576),
    [sym_preproc_endregion] = STATE(576),
    [sym_preproc_line] = STATE(576),
    [sym_preproc_pragma] = STATE(576),
    [sym_preproc_nullable] = STATE(576),
    [sym_preproc_error] = STATE(576),
    [sym_preproc_warning] = STATE(576),
    [sym_preproc_define] = STATE(576),
    [sym_preproc_undef] = STATE(576),
    [aux_sym_class_declaration_repeat1] = STATE(3575),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2603),
    [anon_sym_ref] = ACTIONS(2605),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2607),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [577] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_argument] = STATE(8754),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6871),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8977),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(6583),
    [sym_lvalue_expression] = STATE(4457),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2780),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(577),
    [sym_preproc_endregion] = STATE(577),
    [sym_preproc_line] = STATE(577),
    [sym_preproc_pragma] = STATE(577),
    [sym_preproc_nullable] = STATE(577),
    [sym_preproc_error] = STATE(577),
    [sym_preproc_warning] = STATE(577),
    [sym_preproc_define] = STATE(577),
    [sym_preproc_undef] = STATE(577),
    [aux_sym_class_declaration_repeat1] = STATE(3575),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2603),
    [anon_sym_ref] = ACTIONS(2605),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_in] = ACTIONS(1115),
    [anon_sym_out] = ACTIONS(1115),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(1123),
    [anon_sym_scoped] = ACTIONS(1125),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2607),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [578] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_argument] = STATE(8625),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6730),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2801),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6924),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8759),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2779),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(578),
    [sym_preproc_endregion] = STATE(578),
    [sym_preproc_line] = STATE(578),
    [sym_preproc_pragma] = STATE(578),
    [sym_preproc_nullable] = STATE(578),
    [sym_preproc_error] = STATE(578),
    [sym_preproc_warning] = STATE(578),
    [sym_preproc_define] = STATE(578),
    [sym_preproc_undef] = STATE(578),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2609),
    [anon_sym_ref] = ACTIONS(2611),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_in] = ACTIONS(1079),
    [anon_sym_out] = ACTIONS(1079),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(1089),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2613),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [579] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_argument] = STATE(8474),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6730),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2801),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6924),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8869),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2779),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(579),
    [sym_preproc_endregion] = STATE(579),
    [sym_preproc_line] = STATE(579),
    [sym_preproc_pragma] = STATE(579),
    [sym_preproc_nullable] = STATE(579),
    [sym_preproc_error] = STATE(579),
    [sym_preproc_warning] = STATE(579),
    [sym_preproc_define] = STATE(579),
    [sym_preproc_undef] = STATE(579),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2615),
    [anon_sym_ref] = ACTIONS(2611),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_in] = ACTIONS(1079),
    [anon_sym_out] = ACTIONS(1079),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(1089),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2613),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [580] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_argument] = STATE(8520),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6730),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2801),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6924),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8848),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2779),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(580),
    [sym_preproc_endregion] = STATE(580),
    [sym_preproc_line] = STATE(580),
    [sym_preproc_pragma] = STATE(580),
    [sym_preproc_nullable] = STATE(580),
    [sym_preproc_error] = STATE(580),
    [sym_preproc_warning] = STATE(580),
    [sym_preproc_define] = STATE(580),
    [sym_preproc_undef] = STATE(580),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2617),
    [anon_sym_ref] = ACTIONS(2611),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_in] = ACTIONS(1079),
    [anon_sym_out] = ACTIONS(1079),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(1089),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2613),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [581] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_argument] = STATE(8390),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6730),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2801),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6924),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8869),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2779),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(581),
    [sym_preproc_endregion] = STATE(581),
    [sym_preproc_line] = STATE(581),
    [sym_preproc_pragma] = STATE(581),
    [sym_preproc_nullable] = STATE(581),
    [sym_preproc_error] = STATE(581),
    [sym_preproc_warning] = STATE(581),
    [sym_preproc_define] = STATE(581),
    [sym_preproc_undef] = STATE(581),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2619),
    [anon_sym_ref] = ACTIONS(2611),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_in] = ACTIONS(1079),
    [anon_sym_out] = ACTIONS(1079),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(1089),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2613),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [582] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_argument] = STATE(8390),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6730),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2801),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6924),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8770),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2779),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(582),
    [sym_preproc_endregion] = STATE(582),
    [sym_preproc_line] = STATE(582),
    [sym_preproc_pragma] = STATE(582),
    [sym_preproc_nullable] = STATE(582),
    [sym_preproc_error] = STATE(582),
    [sym_preproc_warning] = STATE(582),
    [sym_preproc_define] = STATE(582),
    [sym_preproc_undef] = STATE(582),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2619),
    [anon_sym_ref] = ACTIONS(2611),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_in] = ACTIONS(1079),
    [anon_sym_out] = ACTIONS(1079),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(1089),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2613),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [583] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_argument] = STATE(8474),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6730),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2801),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6924),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8778),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2779),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(583),
    [sym_preproc_endregion] = STATE(583),
    [sym_preproc_line] = STATE(583),
    [sym_preproc_pragma] = STATE(583),
    [sym_preproc_nullable] = STATE(583),
    [sym_preproc_error] = STATE(583),
    [sym_preproc_warning] = STATE(583),
    [sym_preproc_define] = STATE(583),
    [sym_preproc_undef] = STATE(583),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2615),
    [anon_sym_ref] = ACTIONS(2611),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_in] = ACTIONS(1079),
    [anon_sym_out] = ACTIONS(1079),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(1089),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2613),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [584] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_argument] = STATE(8607),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6730),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2801),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6924),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8986),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2779),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(584),
    [sym_preproc_endregion] = STATE(584),
    [sym_preproc_line] = STATE(584),
    [sym_preproc_pragma] = STATE(584),
    [sym_preproc_nullable] = STATE(584),
    [sym_preproc_error] = STATE(584),
    [sym_preproc_warning] = STATE(584),
    [sym_preproc_define] = STATE(584),
    [sym_preproc_undef] = STATE(584),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2621),
    [anon_sym_ref] = ACTIONS(2611),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_in] = ACTIONS(1079),
    [anon_sym_out] = ACTIONS(1079),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(1089),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2613),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [585] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_argument] = STATE(8467),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6964),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2779),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(585),
    [sym_preproc_endregion] = STATE(585),
    [sym_preproc_line] = STATE(585),
    [sym_preproc_pragma] = STATE(585),
    [sym_preproc_nullable] = STATE(585),
    [sym_preproc_error] = STATE(585),
    [sym_preproc_warning] = STATE(585),
    [sym_preproc_define] = STATE(585),
    [sym_preproc_undef] = STATE(585),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_RBRACK] = ACTIONS(2623),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(2599),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_in] = ACTIONS(1079),
    [anon_sym_out] = ACTIONS(1079),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [586] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_argument] = STATE(8467),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6964),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2779),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(586),
    [sym_preproc_endregion] = STATE(586),
    [sym_preproc_line] = STATE(586),
    [sym_preproc_pragma] = STATE(586),
    [sym_preproc_nullable] = STATE(586),
    [sym_preproc_error] = STATE(586),
    [sym_preproc_warning] = STATE(586),
    [sym_preproc_define] = STATE(586),
    [sym_preproc_undef] = STATE(586),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_RBRACK] = ACTIONS(2625),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(2599),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_in] = ACTIONS(1079),
    [anon_sym_out] = ACTIONS(1079),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [587] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7105),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5261),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_else_in_expression] = STATE(9783),
    [sym_preproc_elif_in_expression] = STATE(9783),
    [sym_preproc_region] = STATE(587),
    [sym_preproc_endregion] = STATE(587),
    [sym_preproc_line] = STATE(587),
    [sym_preproc_pragma] = STATE(587),
    [sym_preproc_nullable] = STATE(587),
    [sym_preproc_error] = STATE(587),
    [sym_preproc_warning] = STATE(587),
    [sym_preproc_define] = STATE(587),
    [sym_preproc_undef] = STATE(587),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_if_token3] = ACTIONS(2627),
    [aux_sym_preproc_else_token1] = ACTIONS(2629),
    [aux_sym_preproc_elif_token1] = ACTIONS(2631),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [588] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_argument] = STATE(8467),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6964),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2779),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(588),
    [sym_preproc_endregion] = STATE(588),
    [sym_preproc_line] = STATE(588),
    [sym_preproc_pragma] = STATE(588),
    [sym_preproc_nullable] = STATE(588),
    [sym_preproc_error] = STATE(588),
    [sym_preproc_warning] = STATE(588),
    [sym_preproc_define] = STATE(588),
    [sym_preproc_undef] = STATE(588),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_RBRACK] = ACTIONS(2633),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(2599),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_in] = ACTIONS(1079),
    [anon_sym_out] = ACTIONS(1079),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [589] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_argument] = STATE(8474),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6964),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2779),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(589),
    [sym_preproc_endregion] = STATE(589),
    [sym_preproc_line] = STATE(589),
    [sym_preproc_pragma] = STATE(589),
    [sym_preproc_nullable] = STATE(589),
    [sym_preproc_error] = STATE(589),
    [sym_preproc_warning] = STATE(589),
    [sym_preproc_define] = STATE(589),
    [sym_preproc_undef] = STATE(589),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2615),
    [anon_sym_ref] = ACTIONS(2635),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_in] = ACTIONS(1079),
    [anon_sym_out] = ACTIONS(1079),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [590] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_argument] = STATE(8467),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6964),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2779),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(590),
    [sym_preproc_endregion] = STATE(590),
    [sym_preproc_line] = STATE(590),
    [sym_preproc_pragma] = STATE(590),
    [sym_preproc_nullable] = STATE(590),
    [sym_preproc_error] = STATE(590),
    [sym_preproc_warning] = STATE(590),
    [sym_preproc_define] = STATE(590),
    [sym_preproc_undef] = STATE(590),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_RBRACK] = ACTIONS(2637),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(2599),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_in] = ACTIONS(1079),
    [anon_sym_out] = ACTIONS(1079),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [591] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_argument] = STATE(8520),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6964),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2779),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(591),
    [sym_preproc_endregion] = STATE(591),
    [sym_preproc_line] = STATE(591),
    [sym_preproc_pragma] = STATE(591),
    [sym_preproc_nullable] = STATE(591),
    [sym_preproc_error] = STATE(591),
    [sym_preproc_warning] = STATE(591),
    [sym_preproc_define] = STATE(591),
    [sym_preproc_undef] = STATE(591),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2617),
    [anon_sym_ref] = ACTIONS(2635),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_in] = ACTIONS(1079),
    [anon_sym_out] = ACTIONS(1079),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [592] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_argument] = STATE(8467),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6964),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2779),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(592),
    [sym_preproc_endregion] = STATE(592),
    [sym_preproc_line] = STATE(592),
    [sym_preproc_pragma] = STATE(592),
    [sym_preproc_nullable] = STATE(592),
    [sym_preproc_error] = STATE(592),
    [sym_preproc_warning] = STATE(592),
    [sym_preproc_define] = STATE(592),
    [sym_preproc_undef] = STATE(592),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_RBRACK] = ACTIONS(2639),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(2599),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_in] = ACTIONS(1079),
    [anon_sym_out] = ACTIONS(1079),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [593] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_argument] = STATE(8467),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6964),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2779),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(593),
    [sym_preproc_endregion] = STATE(593),
    [sym_preproc_line] = STATE(593),
    [sym_preproc_pragma] = STATE(593),
    [sym_preproc_nullable] = STATE(593),
    [sym_preproc_error] = STATE(593),
    [sym_preproc_warning] = STATE(593),
    [sym_preproc_define] = STATE(593),
    [sym_preproc_undef] = STATE(593),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_RBRACK] = ACTIONS(2641),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(2599),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_in] = ACTIONS(1079),
    [anon_sym_out] = ACTIONS(1079),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [594] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7105),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5244),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_else_in_expression] = STATE(9272),
    [sym_preproc_elif_in_expression] = STATE(9272),
    [sym_preproc_region] = STATE(594),
    [sym_preproc_endregion] = STATE(594),
    [sym_preproc_line] = STATE(594),
    [sym_preproc_pragma] = STATE(594),
    [sym_preproc_nullable] = STATE(594),
    [sym_preproc_error] = STATE(594),
    [sym_preproc_warning] = STATE(594),
    [sym_preproc_define] = STATE(594),
    [sym_preproc_undef] = STATE(594),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_if_token3] = ACTIONS(2643),
    [aux_sym_preproc_else_token1] = ACTIONS(2629),
    [aux_sym_preproc_elif_token1] = ACTIONS(2631),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [595] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_argument] = STATE(8467),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6964),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2779),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(595),
    [sym_preproc_endregion] = STATE(595),
    [sym_preproc_line] = STATE(595),
    [sym_preproc_pragma] = STATE(595),
    [sym_preproc_nullable] = STATE(595),
    [sym_preproc_error] = STATE(595),
    [sym_preproc_warning] = STATE(595),
    [sym_preproc_define] = STATE(595),
    [sym_preproc_undef] = STATE(595),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_RBRACK] = ACTIONS(2645),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(2599),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_in] = ACTIONS(1079),
    [anon_sym_out] = ACTIONS(1079),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [596] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7105),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5362),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_else_in_expression] = STATE(9353),
    [sym_preproc_elif_in_expression] = STATE(9353),
    [sym_preproc_region] = STATE(596),
    [sym_preproc_endregion] = STATE(596),
    [sym_preproc_line] = STATE(596),
    [sym_preproc_pragma] = STATE(596),
    [sym_preproc_nullable] = STATE(596),
    [sym_preproc_error] = STATE(596),
    [sym_preproc_warning] = STATE(596),
    [sym_preproc_define] = STATE(596),
    [sym_preproc_undef] = STATE(596),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_if_token3] = ACTIONS(2647),
    [aux_sym_preproc_else_token1] = ACTIONS(2629),
    [aux_sym_preproc_elif_token1] = ACTIONS(2631),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [597] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_argument] = STATE(8467),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6964),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2779),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(597),
    [sym_preproc_endregion] = STATE(597),
    [sym_preproc_line] = STATE(597),
    [sym_preproc_pragma] = STATE(597),
    [sym_preproc_nullable] = STATE(597),
    [sym_preproc_error] = STATE(597),
    [sym_preproc_warning] = STATE(597),
    [sym_preproc_define] = STATE(597),
    [sym_preproc_undef] = STATE(597),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_RBRACK] = ACTIONS(2649),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(2599),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_in] = ACTIONS(1079),
    [anon_sym_out] = ACTIONS(1079),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [598] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_argument] = STATE(8467),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6964),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2779),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(598),
    [sym_preproc_endregion] = STATE(598),
    [sym_preproc_line] = STATE(598),
    [sym_preproc_pragma] = STATE(598),
    [sym_preproc_nullable] = STATE(598),
    [sym_preproc_error] = STATE(598),
    [sym_preproc_warning] = STATE(598),
    [sym_preproc_define] = STATE(598),
    [sym_preproc_undef] = STATE(598),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_RBRACK] = ACTIONS(2651),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(2599),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_in] = ACTIONS(1079),
    [anon_sym_out] = ACTIONS(1079),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [599] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7105),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5368),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_else_in_expression] = STATE(9141),
    [sym_preproc_elif_in_expression] = STATE(9141),
    [sym_preproc_region] = STATE(599),
    [sym_preproc_endregion] = STATE(599),
    [sym_preproc_line] = STATE(599),
    [sym_preproc_pragma] = STATE(599),
    [sym_preproc_nullable] = STATE(599),
    [sym_preproc_error] = STATE(599),
    [sym_preproc_warning] = STATE(599),
    [sym_preproc_define] = STATE(599),
    [sym_preproc_undef] = STATE(599),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_if_token3] = ACTIONS(2653),
    [aux_sym_preproc_else_token1] = ACTIONS(2629),
    [aux_sym_preproc_elif_token1] = ACTIONS(2631),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [600] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_argument] = STATE(8467),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6964),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2779),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(600),
    [sym_preproc_endregion] = STATE(600),
    [sym_preproc_line] = STATE(600),
    [sym_preproc_pragma] = STATE(600),
    [sym_preproc_nullable] = STATE(600),
    [sym_preproc_error] = STATE(600),
    [sym_preproc_warning] = STATE(600),
    [sym_preproc_define] = STATE(600),
    [sym_preproc_undef] = STATE(600),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_RBRACK] = ACTIONS(2655),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(2599),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_in] = ACTIONS(1079),
    [anon_sym_out] = ACTIONS(1079),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [601] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_argument] = STATE(8607),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6964),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2779),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(601),
    [sym_preproc_endregion] = STATE(601),
    [sym_preproc_line] = STATE(601),
    [sym_preproc_pragma] = STATE(601),
    [sym_preproc_nullable] = STATE(601),
    [sym_preproc_error] = STATE(601),
    [sym_preproc_warning] = STATE(601),
    [sym_preproc_define] = STATE(601),
    [sym_preproc_undef] = STATE(601),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2621),
    [anon_sym_ref] = ACTIONS(2635),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_in] = ACTIONS(1079),
    [anon_sym_out] = ACTIONS(1079),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [602] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_argument] = STATE(8390),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6964),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2779),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(602),
    [sym_preproc_endregion] = STATE(602),
    [sym_preproc_line] = STATE(602),
    [sym_preproc_pragma] = STATE(602),
    [sym_preproc_nullable] = STATE(602),
    [sym_preproc_error] = STATE(602),
    [sym_preproc_warning] = STATE(602),
    [sym_preproc_define] = STATE(602),
    [sym_preproc_undef] = STATE(602),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2619),
    [anon_sym_ref] = ACTIONS(2635),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_in] = ACTIONS(1079),
    [anon_sym_out] = ACTIONS(1079),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [603] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_argument] = STATE(8467),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6964),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2779),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(603),
    [sym_preproc_endregion] = STATE(603),
    [sym_preproc_line] = STATE(603),
    [sym_preproc_pragma] = STATE(603),
    [sym_preproc_nullable] = STATE(603),
    [sym_preproc_error] = STATE(603),
    [sym_preproc_warning] = STATE(603),
    [sym_preproc_define] = STATE(603),
    [sym_preproc_undef] = STATE(603),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_RBRACK] = ACTIONS(2657),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(2599),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_in] = ACTIONS(1079),
    [anon_sym_out] = ACTIONS(1079),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [604] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7105),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5308),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_else_in_expression] = STATE(9435),
    [sym_preproc_elif_in_expression] = STATE(9435),
    [sym_preproc_region] = STATE(604),
    [sym_preproc_endregion] = STATE(604),
    [sym_preproc_line] = STATE(604),
    [sym_preproc_pragma] = STATE(604),
    [sym_preproc_nullable] = STATE(604),
    [sym_preproc_error] = STATE(604),
    [sym_preproc_warning] = STATE(604),
    [sym_preproc_define] = STATE(604),
    [sym_preproc_undef] = STATE(604),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_if_token3] = ACTIONS(2659),
    [aux_sym_preproc_else_token1] = ACTIONS(2629),
    [aux_sym_preproc_elif_token1] = ACTIONS(2631),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [605] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7105),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5277),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_else_in_expression] = STATE(9149),
    [sym_preproc_elif_in_expression] = STATE(9149),
    [sym_preproc_region] = STATE(605),
    [sym_preproc_endregion] = STATE(605),
    [sym_preproc_line] = STATE(605),
    [sym_preproc_pragma] = STATE(605),
    [sym_preproc_nullable] = STATE(605),
    [sym_preproc_error] = STATE(605),
    [sym_preproc_warning] = STATE(605),
    [sym_preproc_define] = STATE(605),
    [sym_preproc_undef] = STATE(605),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_if_token3] = ACTIONS(2661),
    [aux_sym_preproc_else_token1] = ACTIONS(2629),
    [aux_sym_preproc_elif_token1] = ACTIONS(2631),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [606] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7105),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5400),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_else_in_expression] = STATE(9475),
    [sym_preproc_elif_in_expression] = STATE(9475),
    [sym_preproc_region] = STATE(606),
    [sym_preproc_endregion] = STATE(606),
    [sym_preproc_line] = STATE(606),
    [sym_preproc_pragma] = STATE(606),
    [sym_preproc_nullable] = STATE(606),
    [sym_preproc_error] = STATE(606),
    [sym_preproc_warning] = STATE(606),
    [sym_preproc_define] = STATE(606),
    [sym_preproc_undef] = STATE(606),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_if_token3] = ACTIONS(2663),
    [aux_sym_preproc_else_token1] = ACTIONS(2629),
    [aux_sym_preproc_elif_token1] = ACTIONS(2631),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [607] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_argument] = STATE(8467),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6964),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2779),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(607),
    [sym_preproc_endregion] = STATE(607),
    [sym_preproc_line] = STATE(607),
    [sym_preproc_pragma] = STATE(607),
    [sym_preproc_nullable] = STATE(607),
    [sym_preproc_error] = STATE(607),
    [sym_preproc_warning] = STATE(607),
    [sym_preproc_define] = STATE(607),
    [sym_preproc_undef] = STATE(607),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_RBRACK] = ACTIONS(2665),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(2599),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_in] = ACTIONS(1079),
    [anon_sym_out] = ACTIONS(1079),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [608] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_argument] = STATE(8625),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6964),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2779),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(608),
    [sym_preproc_endregion] = STATE(608),
    [sym_preproc_line] = STATE(608),
    [sym_preproc_pragma] = STATE(608),
    [sym_preproc_nullable] = STATE(608),
    [sym_preproc_error] = STATE(608),
    [sym_preproc_warning] = STATE(608),
    [sym_preproc_define] = STATE(608),
    [sym_preproc_undef] = STATE(608),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2609),
    [anon_sym_ref] = ACTIONS(2635),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_in] = ACTIONS(1079),
    [anon_sym_out] = ACTIONS(1079),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [609] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_argument] = STATE(8688),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6964),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2779),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(609),
    [sym_preproc_endregion] = STATE(609),
    [sym_preproc_line] = STATE(609),
    [sym_preproc_pragma] = STATE(609),
    [sym_preproc_nullable] = STATE(609),
    [sym_preproc_error] = STATE(609),
    [sym_preproc_warning] = STATE(609),
    [sym_preproc_define] = STATE(609),
    [sym_preproc_undef] = STATE(609),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(2599),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_in] = ACTIONS(1079),
    [anon_sym_out] = ACTIONS(1079),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [610] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6725),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2838),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6762),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5916),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4216),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9065),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8686),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(610),
    [sym_preproc_endregion] = STATE(610),
    [sym_preproc_line] = STATE(610),
    [sym_preproc_pragma] = STATE(610),
    [sym_preproc_nullable] = STATE(610),
    [sym_preproc_error] = STATE(610),
    [sym_preproc_warning] = STATE(610),
    [sym_preproc_define] = STATE(610),
    [sym_preproc_undef] = STATE(610),
    [aux_sym_class_declaration_repeat1] = STATE(3874),
    [aux_sym_lambda_expression_repeat1] = STATE(4311),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1531),
    [anon_sym_ref] = ACTIONS(2667),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_readonly] = ACTIONS(2669),
    [anon_sym_in] = ACTIONS(2669),
    [anon_sym_out] = ACTIONS(2669),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1537),
    [anon_sym_TILDE] = ACTIONS(1537),
    [anon_sym_PLUS_PLUS] = ACTIONS(1537),
    [anon_sym_DASH_DASH] = ACTIONS(1537),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1535),
    [anon_sym_DASH] = ACTIONS(1535),
    [anon_sym_STAR] = ACTIONS(1121),
    [anon_sym_CARET] = ACTIONS(1537),
    [anon_sym_AMP] = ACTIONS(1537),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2319),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2607),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1129),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1131),
    [anon_sym_DOT_DOT] = ACTIONS(1135),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [611] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6964),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6066),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8686),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(611),
    [sym_preproc_endregion] = STATE(611),
    [sym_preproc_line] = STATE(611),
    [sym_preproc_pragma] = STATE(611),
    [sym_preproc_nullable] = STATE(611),
    [sym_preproc_error] = STATE(611),
    [sym_preproc_warning] = STATE(611),
    [sym_preproc_define] = STATE(611),
    [sym_preproc_undef] = STATE(611),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(2669),
    [anon_sym_in] = ACTIONS(2669),
    [anon_sym_out] = ACTIONS(2669),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [612] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6698),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6063),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8686),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(612),
    [sym_preproc_endregion] = STATE(612),
    [sym_preproc_line] = STATE(612),
    [sym_preproc_pragma] = STATE(612),
    [sym_preproc_nullable] = STATE(612),
    [sym_preproc_error] = STATE(612),
    [sym_preproc_warning] = STATE(612),
    [sym_preproc_define] = STATE(612),
    [sym_preproc_undef] = STATE(612),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(2671),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(2669),
    [anon_sym_in] = ACTIONS(2669),
    [anon_sym_out] = ACTIONS(2669),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2319),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2607),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [613] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_argument] = STATE(8467),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6964),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2779),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(613),
    [sym_preproc_endregion] = STATE(613),
    [sym_preproc_line] = STATE(613),
    [sym_preproc_pragma] = STATE(613),
    [sym_preproc_nullable] = STATE(613),
    [sym_preproc_error] = STATE(613),
    [sym_preproc_warning] = STATE(613),
    [sym_preproc_define] = STATE(613),
    [sym_preproc_undef] = STATE(613),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(2599),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_in] = ACTIONS(1079),
    [anon_sym_out] = ACTIONS(1079),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [614] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_argument] = STATE(8467),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6964),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2779),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(614),
    [sym_preproc_endregion] = STATE(614),
    [sym_preproc_line] = STATE(614),
    [sym_preproc_pragma] = STATE(614),
    [sym_preproc_nullable] = STATE(614),
    [sym_preproc_error] = STATE(614),
    [sym_preproc_warning] = STATE(614),
    [sym_preproc_define] = STATE(614),
    [sym_preproc_undef] = STATE(614),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(2635),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_in] = ACTIONS(1079),
    [anon_sym_out] = ACTIONS(1079),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [615] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_argument] = STATE(8790),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6964),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6210),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2779),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(615),
    [sym_preproc_endregion] = STATE(615),
    [sym_preproc_line] = STATE(615),
    [sym_preproc_pragma] = STATE(615),
    [sym_preproc_nullable] = STATE(615),
    [sym_preproc_error] = STATE(615),
    [sym_preproc_warning] = STATE(615),
    [sym_preproc_define] = STATE(615),
    [sym_preproc_undef] = STATE(615),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(2599),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_in] = ACTIONS(1079),
    [anon_sym_out] = ACTIONS(1079),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [616] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_argument] = STATE(8641),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6964),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2779),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(616),
    [sym_preproc_endregion] = STATE(616),
    [sym_preproc_line] = STATE(616),
    [sym_preproc_pragma] = STATE(616),
    [sym_preproc_nullable] = STATE(616),
    [sym_preproc_error] = STATE(616),
    [sym_preproc_warning] = STATE(616),
    [sym_preproc_define] = STATE(616),
    [sym_preproc_undef] = STATE(616),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(2599),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_in] = ACTIONS(1079),
    [anon_sym_out] = ACTIONS(1079),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [617] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_argument] = STATE(8790),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6964),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6296),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2779),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(617),
    [sym_preproc_endregion] = STATE(617),
    [sym_preproc_line] = STATE(617),
    [sym_preproc_pragma] = STATE(617),
    [sym_preproc_nullable] = STATE(617),
    [sym_preproc_error] = STATE(617),
    [sym_preproc_warning] = STATE(617),
    [sym_preproc_define] = STATE(617),
    [sym_preproc_undef] = STATE(617),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(2599),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_in] = ACTIONS(1079),
    [anon_sym_out] = ACTIONS(1079),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [618] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_argument] = STATE(8484),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6964),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2779),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(618),
    [sym_preproc_endregion] = STATE(618),
    [sym_preproc_line] = STATE(618),
    [sym_preproc_pragma] = STATE(618),
    [sym_preproc_nullable] = STATE(618),
    [sym_preproc_error] = STATE(618),
    [sym_preproc_warning] = STATE(618),
    [sym_preproc_define] = STATE(618),
    [sym_preproc_undef] = STATE(618),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(2599),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_in] = ACTIONS(1079),
    [anon_sym_out] = ACTIONS(1079),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [619] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_argument] = STATE(8790),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6964),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6226),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2779),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(619),
    [sym_preproc_endregion] = STATE(619),
    [sym_preproc_line] = STATE(619),
    [sym_preproc_pragma] = STATE(619),
    [sym_preproc_nullable] = STATE(619),
    [sym_preproc_error] = STATE(619),
    [sym_preproc_warning] = STATE(619),
    [sym_preproc_define] = STATE(619),
    [sym_preproc_undef] = STATE(619),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(2599),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_in] = ACTIONS(1079),
    [anon_sym_out] = ACTIONS(1079),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [620] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_argument] = STATE(8518),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6964),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2779),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(620),
    [sym_preproc_endregion] = STATE(620),
    [sym_preproc_line] = STATE(620),
    [sym_preproc_pragma] = STATE(620),
    [sym_preproc_nullable] = STATE(620),
    [sym_preproc_error] = STATE(620),
    [sym_preproc_warning] = STATE(620),
    [sym_preproc_define] = STATE(620),
    [sym_preproc_undef] = STATE(620),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(2599),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_in] = ACTIONS(1079),
    [anon_sym_out] = ACTIONS(1079),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [621] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_argument] = STATE(8790),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6964),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6287),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2779),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(621),
    [sym_preproc_endregion] = STATE(621),
    [sym_preproc_line] = STATE(621),
    [sym_preproc_pragma] = STATE(621),
    [sym_preproc_nullable] = STATE(621),
    [sym_preproc_error] = STATE(621),
    [sym_preproc_warning] = STATE(621),
    [sym_preproc_define] = STATE(621),
    [sym_preproc_undef] = STATE(621),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(2599),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_in] = ACTIONS(1079),
    [anon_sym_out] = ACTIONS(1079),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [622] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_argument] = STATE(8583),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6964),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2779),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(622),
    [sym_preproc_endregion] = STATE(622),
    [sym_preproc_line] = STATE(622),
    [sym_preproc_pragma] = STATE(622),
    [sym_preproc_nullable] = STATE(622),
    [sym_preproc_error] = STATE(622),
    [sym_preproc_warning] = STATE(622),
    [sym_preproc_define] = STATE(622),
    [sym_preproc_undef] = STATE(622),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(2599),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_in] = ACTIONS(1079),
    [anon_sym_out] = ACTIONS(1079),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [623] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_argument] = STATE(8466),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6964),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6035),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8488),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2779),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(623),
    [sym_preproc_endregion] = STATE(623),
    [sym_preproc_line] = STATE(623),
    [sym_preproc_pragma] = STATE(623),
    [sym_preproc_nullable] = STATE(623),
    [sym_preproc_error] = STATE(623),
    [sym_preproc_warning] = STATE(623),
    [sym_preproc_define] = STATE(623),
    [sym_preproc_undef] = STATE(623),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(2599),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_in] = ACTIONS(1079),
    [anon_sym_out] = ACTIONS(1079),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [624] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6223),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym__anonymous_object_member_declarator] = STATE(8608),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2867),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(624),
    [sym_preproc_endregion] = STATE(624),
    [sym_preproc_line] = STATE(624),
    [sym_preproc_pragma] = STATE(624),
    [sym_preproc_nullable] = STATE(624),
    [sym_preproc_error] = STATE(624),
    [sym_preproc_warning] = STATE(624),
    [sym_preproc_define] = STATE(624),
    [sym_preproc_undef] = STATE(624),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_COMMA] = ACTIONS(2673),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_RBRACE] = ACTIONS(2675),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [625] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5919),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(625),
    [sym_preproc_endregion] = STATE(625),
    [sym_preproc_line] = STATE(625),
    [sym_preproc_pragma] = STATE(625),
    [sym_preproc_nullable] = STATE(625),
    [sym_preproc_error] = STATE(625),
    [sym_preproc_warning] = STATE(625),
    [sym_preproc_define] = STATE(625),
    [sym_preproc_undef] = STATE(625),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_array_rank_specifier_repeat1] = STATE(8405),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_COMMA] = ACTIONS(2677),
    [anon_sym_RBRACK] = ACTIONS(2679),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [626] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6964),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6036),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8490),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(626),
    [sym_preproc_endregion] = STATE(626),
    [sym_preproc_line] = STATE(626),
    [sym_preproc_pragma] = STATE(626),
    [sym_preproc_nullable] = STATE(626),
    [sym_preproc_error] = STATE(626),
    [sym_preproc_warning] = STATE(626),
    [sym_preproc_define] = STATE(626),
    [sym_preproc_undef] = STATE(626),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(2681),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_in] = ACTIONS(2683),
    [anon_sym_out] = ACTIONS(2683),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [627] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6223),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym__anonymous_object_member_declarator] = STATE(8494),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2867),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(627),
    [sym_preproc_endregion] = STATE(627),
    [sym_preproc_line] = STATE(627),
    [sym_preproc_pragma] = STATE(627),
    [sym_preproc_nullable] = STATE(627),
    [sym_preproc_error] = STATE(627),
    [sym_preproc_warning] = STATE(627),
    [sym_preproc_define] = STATE(627),
    [sym_preproc_undef] = STATE(627),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_COMMA] = ACTIONS(2685),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_RBRACE] = ACTIONS(2687),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [628] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6028),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(628),
    [sym_preproc_endregion] = STATE(628),
    [sym_preproc_line] = STATE(628),
    [sym_preproc_pragma] = STATE(628),
    [sym_preproc_nullable] = STATE(628),
    [sym_preproc_error] = STATE(628),
    [sym_preproc_warning] = STATE(628),
    [sym_preproc_define] = STATE(628),
    [sym_preproc_undef] = STATE(628),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_array_rank_specifier_repeat1] = STATE(8431),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_COMMA] = ACTIONS(2677),
    [anon_sym_RBRACK] = ACTIONS(2689),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [629] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5921),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(629),
    [sym_preproc_endregion] = STATE(629),
    [sym_preproc_line] = STATE(629),
    [sym_preproc_pragma] = STATE(629),
    [sym_preproc_nullable] = STATE(629),
    [sym_preproc_error] = STATE(629),
    [sym_preproc_warning] = STATE(629),
    [sym_preproc_define] = STATE(629),
    [sym_preproc_undef] = STATE(629),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_array_rank_specifier_repeat1] = STATE(8626),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_COMMA] = ACTIONS(2677),
    [anon_sym_RBRACK] = ACTIONS(2691),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [630] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5794),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(630),
    [sym_preproc_endregion] = STATE(630),
    [sym_preproc_line] = STATE(630),
    [sym_preproc_pragma] = STATE(630),
    [sym_preproc_nullable] = STATE(630),
    [sym_preproc_error] = STATE(630),
    [sym_preproc_warning] = STATE(630),
    [sym_preproc_define] = STATE(630),
    [sym_preproc_undef] = STATE(630),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_array_rank_specifier_repeat1] = STATE(8458),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_COMMA] = ACTIONS(2677),
    [anon_sym_RBRACK] = ACTIONS(2693),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [631] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6728),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2789),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6662),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6519),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(631),
    [sym_preproc_endregion] = STATE(631),
    [sym_preproc_line] = STATE(631),
    [sym_preproc_pragma] = STATE(631),
    [sym_preproc_nullable] = STATE(631),
    [sym_preproc_error] = STATE(631),
    [sym_preproc_warning] = STATE(631),
    [sym_preproc_define] = STATE(631),
    [sym_preproc_undef] = STATE(631),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(2669),
    [anon_sym_alias] = ACTIONS(2669),
    [anon_sym_global] = ACTIONS(2669),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_ref] = ACTIONS(2669),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(2669),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(2669),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_readonly] = ACTIONS(2669),
    [anon_sym_in] = ACTIONS(2669),
    [anon_sym_out] = ACTIONS(2669),
    [anon_sym_where] = ACTIONS(2669),
    [anon_sym_notnull] = ACTIONS(2669),
    [anon_sym_unmanaged] = ACTIONS(2669),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(2669),
    [anon_sym_scoped] = ACTIONS(2669),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2669),
    [sym_predefined_type] = ACTIONS(2669),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(2669),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(2669),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(2669),
    [anon_sym_into] = ACTIONS(2669),
    [anon_sym_join] = ACTIONS(2669),
    [anon_sym_on] = ACTIONS(2669),
    [anon_sym_equals] = ACTIONS(2669),
    [anon_sym_let] = ACTIONS(2669),
    [anon_sym_orderby] = ACTIONS(2669),
    [anon_sym_ascending] = ACTIONS(2669),
    [anon_sym_descending] = ACTIONS(2669),
    [anon_sym_group] = ACTIONS(2669),
    [anon_sym_by] = ACTIONS(2669),
    [anon_sym_select] = ACTIONS(2669),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [632] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6223),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym__anonymous_object_member_declarator] = STATE(8563),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2867),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(632),
    [sym_preproc_endregion] = STATE(632),
    [sym_preproc_line] = STATE(632),
    [sym_preproc_pragma] = STATE(632),
    [sym_preproc_nullable] = STATE(632),
    [sym_preproc_error] = STATE(632),
    [sym_preproc_warning] = STATE(632),
    [sym_preproc_define] = STATE(632),
    [sym_preproc_undef] = STATE(632),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_COMMA] = ACTIONS(2697),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_RBRACE] = ACTIONS(2699),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [633] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5872),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(633),
    [sym_preproc_endregion] = STATE(633),
    [sym_preproc_line] = STATE(633),
    [sym_preproc_pragma] = STATE(633),
    [sym_preproc_nullable] = STATE(633),
    [sym_preproc_error] = STATE(633),
    [sym_preproc_warning] = STATE(633),
    [sym_preproc_define] = STATE(633),
    [sym_preproc_undef] = STATE(633),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_array_rank_specifier_repeat1] = STATE(8528),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_COMMA] = ACTIONS(2677),
    [anon_sym_RBRACK] = ACTIONS(2701),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [634] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6223),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym__anonymous_object_member_declarator] = STATE(8522),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2867),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(634),
    [sym_preproc_endregion] = STATE(634),
    [sym_preproc_line] = STATE(634),
    [sym_preproc_pragma] = STATE(634),
    [sym_preproc_nullable] = STATE(634),
    [sym_preproc_error] = STATE(634),
    [sym_preproc_warning] = STATE(634),
    [sym_preproc_define] = STATE(634),
    [sym_preproc_undef] = STATE(634),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_COMMA] = ACTIONS(2703),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_RBRACE] = ACTIONS(2705),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [635] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6223),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym__anonymous_object_member_declarator] = STATE(8627),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2867),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(635),
    [sym_preproc_endregion] = STATE(635),
    [sym_preproc_line] = STATE(635),
    [sym_preproc_pragma] = STATE(635),
    [sym_preproc_nullable] = STATE(635),
    [sym_preproc_error] = STATE(635),
    [sym_preproc_warning] = STATE(635),
    [sym_preproc_define] = STATE(635),
    [sym_preproc_undef] = STATE(635),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_COMMA] = ACTIONS(2707),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_RBRACE] = ACTIONS(2709),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [636] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6085),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(636),
    [sym_preproc_endregion] = STATE(636),
    [sym_preproc_line] = STATE(636),
    [sym_preproc_pragma] = STATE(636),
    [sym_preproc_nullable] = STATE(636),
    [sym_preproc_error] = STATE(636),
    [sym_preproc_warning] = STATE(636),
    [sym_preproc_define] = STATE(636),
    [sym_preproc_undef] = STATE(636),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_array_rank_specifier_repeat1] = STATE(8631),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_COMMA] = ACTIONS(2677),
    [anon_sym_RBRACK] = ACTIONS(2711),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [637] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6223),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym__anonymous_object_member_declarator] = STATE(8702),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2867),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(637),
    [sym_preproc_endregion] = STATE(637),
    [sym_preproc_line] = STATE(637),
    [sym_preproc_pragma] = STATE(637),
    [sym_preproc_nullable] = STATE(637),
    [sym_preproc_error] = STATE(637),
    [sym_preproc_warning] = STATE(637),
    [sym_preproc_define] = STATE(637),
    [sym_preproc_undef] = STATE(637),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_COMMA] = ACTIONS(2713),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_RBRACE] = ACTIONS(2715),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [638] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5982),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(638),
    [sym_preproc_endregion] = STATE(638),
    [sym_preproc_line] = STATE(638),
    [sym_preproc_pragma] = STATE(638),
    [sym_preproc_nullable] = STATE(638),
    [sym_preproc_error] = STATE(638),
    [sym_preproc_warning] = STATE(638),
    [sym_preproc_define] = STATE(638),
    [sym_preproc_undef] = STATE(638),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_array_rank_specifier_repeat1] = STATE(8402),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_COMMA] = ACTIONS(2677),
    [anon_sym_RBRACK] = ACTIONS(2717),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [639] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5826),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(639),
    [sym_preproc_endregion] = STATE(639),
    [sym_preproc_line] = STATE(639),
    [sym_preproc_pragma] = STATE(639),
    [sym_preproc_nullable] = STATE(639),
    [sym_preproc_error] = STATE(639),
    [sym_preproc_warning] = STATE(639),
    [sym_preproc_define] = STATE(639),
    [sym_preproc_undef] = STATE(639),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_array_rank_specifier_repeat1] = STATE(8385),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_COMMA] = ACTIONS(2677),
    [anon_sym_RBRACK] = ACTIONS(2719),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [640] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3026),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7139),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6533),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_member_binding_expression] = STATE(3770),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(640),
    [sym_preproc_endregion] = STATE(640),
    [sym_preproc_line] = STATE(640),
    [sym_preproc_pragma] = STATE(640),
    [sym_preproc_nullable] = STATE(640),
    [sym_preproc_error] = STATE(640),
    [sym_preproc_warning] = STATE(640),
    [sym_preproc_define] = STATE(640),
    [sym_preproc_undef] = STATE(640),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2011),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(2721),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [641] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6223),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym__anonymous_object_member_declarator] = STATE(8895),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2867),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(641),
    [sym_preproc_endregion] = STATE(641),
    [sym_preproc_line] = STATE(641),
    [sym_preproc_pragma] = STATE(641),
    [sym_preproc_nullable] = STATE(641),
    [sym_preproc_error] = STATE(641),
    [sym_preproc_warning] = STATE(641),
    [sym_preproc_define] = STATE(641),
    [sym_preproc_undef] = STATE(641),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_RBRACE] = ACTIONS(2723),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [642] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_using_variable_declaration] = STATE(9403),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6221),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2789),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6865),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8977),
    [sym_expression] = STATE(6539),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(642),
    [sym_preproc_endregion] = STATE(642),
    [sym_preproc_line] = STATE(642),
    [sym_preproc_pragma] = STATE(642),
    [sym_preproc_nullable] = STATE(642),
    [sym_preproc_error] = STATE(642),
    [sym_preproc_warning] = STATE(642),
    [sym_preproc_define] = STATE(642),
    [sym_preproc_undef] = STATE(642),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(2725),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(1089),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2727),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [643] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_using_variable_declaration] = STATE(9317),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6221),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2789),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6865),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8977),
    [sym_expression] = STATE(6388),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(643),
    [sym_preproc_endregion] = STATE(643),
    [sym_preproc_line] = STATE(643),
    [sym_preproc_pragma] = STATE(643),
    [sym_preproc_nullable] = STATE(643),
    [sym_preproc_error] = STATE(643),
    [sym_preproc_warning] = STATE(643),
    [sym_preproc_define] = STATE(643),
    [sym_preproc_undef] = STATE(643),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(2725),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(1089),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2727),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [644] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6223),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym__anonymous_object_member_declarator] = STATE(8895),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2867),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(644),
    [sym_preproc_endregion] = STATE(644),
    [sym_preproc_line] = STATE(644),
    [sym_preproc_pragma] = STATE(644),
    [sym_preproc_nullable] = STATE(644),
    [sym_preproc_error] = STATE(644),
    [sym_preproc_warning] = STATE(644),
    [sym_preproc_define] = STATE(644),
    [sym_preproc_undef] = STATE(644),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_RBRACE] = ACTIONS(2729),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [645] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3018),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7139),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6367),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_member_binding_expression] = STATE(3693),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(645),
    [sym_preproc_endregion] = STATE(645),
    [sym_preproc_line] = STATE(645),
    [sym_preproc_pragma] = STATE(645),
    [sym_preproc_nullable] = STATE(645),
    [sym_preproc_error] = STATE(645),
    [sym_preproc_warning] = STATE(645),
    [sym_preproc_define] = STATE(645),
    [sym_preproc_undef] = STATE(645),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2011),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(2731),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [646] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3267),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7139),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6460),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_member_binding_expression] = STATE(4121),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(646),
    [sym_preproc_endregion] = STATE(646),
    [sym_preproc_line] = STATE(646),
    [sym_preproc_pragma] = STATE(646),
    [sym_preproc_nullable] = STATE(646),
    [sym_preproc_error] = STATE(646),
    [sym_preproc_warning] = STATE(646),
    [sym_preproc_define] = STATE(646),
    [sym_preproc_undef] = STATE(646),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2011),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(2733),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [647] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3220),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7139),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6375),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_member_binding_expression] = STATE(4074),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(647),
    [sym_preproc_endregion] = STATE(647),
    [sym_preproc_line] = STATE(647),
    [sym_preproc_pragma] = STATE(647),
    [sym_preproc_nullable] = STATE(647),
    [sym_preproc_error] = STATE(647),
    [sym_preproc_warning] = STATE(647),
    [sym_preproc_define] = STATE(647),
    [sym_preproc_undef] = STATE(647),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2011),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(2735),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [648] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6730),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2801),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6698),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6063),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8686),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(648),
    [sym_preproc_endregion] = STATE(648),
    [sym_preproc_line] = STATE(648),
    [sym_preproc_pragma] = STATE(648),
    [sym_preproc_nullable] = STATE(648),
    [sym_preproc_error] = STATE(648),
    [sym_preproc_warning] = STATE(648),
    [sym_preproc_define] = STATE(648),
    [sym_preproc_undef] = STATE(648),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(2737),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(2739),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(1089),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2727),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [649] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3018),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7139),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6368),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_member_binding_expression] = STATE(3693),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(649),
    [sym_preproc_endregion] = STATE(649),
    [sym_preproc_line] = STATE(649),
    [sym_preproc_pragma] = STATE(649),
    [sym_preproc_nullable] = STATE(649),
    [sym_preproc_error] = STATE(649),
    [sym_preproc_warning] = STATE(649),
    [sym_preproc_define] = STATE(649),
    [sym_preproc_undef] = STATE(649),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2011),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(2731),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [650] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3267),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7139),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6363),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_member_binding_expression] = STATE(4121),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(650),
    [sym_preproc_endregion] = STATE(650),
    [sym_preproc_line] = STATE(650),
    [sym_preproc_pragma] = STATE(650),
    [sym_preproc_nullable] = STATE(650),
    [sym_preproc_error] = STATE(650),
    [sym_preproc_warning] = STATE(650),
    [sym_preproc_define] = STATE(650),
    [sym_preproc_undef] = STATE(650),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2011),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(2741),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [651] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3220),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7139),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6378),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_member_binding_expression] = STATE(4074),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(651),
    [sym_preproc_endregion] = STATE(651),
    [sym_preproc_line] = STATE(651),
    [sym_preproc_pragma] = STATE(651),
    [sym_preproc_nullable] = STATE(651),
    [sym_preproc_error] = STATE(651),
    [sym_preproc_warning] = STATE(651),
    [sym_preproc_define] = STATE(651),
    [sym_preproc_undef] = STATE(651),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2011),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(2735),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [652] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6201),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(652),
    [sym_preproc_endregion] = STATE(652),
    [sym_preproc_line] = STATE(652),
    [sym_preproc_pragma] = STATE(652),
    [sym_preproc_nullable] = STATE(652),
    [sym_preproc_error] = STATE(652),
    [sym_preproc_warning] = STATE(652),
    [sym_preproc_define] = STATE(652),
    [sym_preproc_undef] = STATE(652),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_COMMA] = ACTIONS(2743),
    [anon_sym_RBRACK] = ACTIONS(2743),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [653] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3018),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7139),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6370),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_member_binding_expression] = STATE(3693),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(653),
    [sym_preproc_endregion] = STATE(653),
    [sym_preproc_line] = STATE(653),
    [sym_preproc_pragma] = STATE(653),
    [sym_preproc_nullable] = STATE(653),
    [sym_preproc_error] = STATE(653),
    [sym_preproc_warning] = STATE(653),
    [sym_preproc_define] = STATE(653),
    [sym_preproc_undef] = STATE(653),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2011),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(2731),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [654] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3267),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7139),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6371),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_member_binding_expression] = STATE(4121),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(654),
    [sym_preproc_endregion] = STATE(654),
    [sym_preproc_line] = STATE(654),
    [sym_preproc_pragma] = STATE(654),
    [sym_preproc_nullable] = STATE(654),
    [sym_preproc_error] = STATE(654),
    [sym_preproc_warning] = STATE(654),
    [sym_preproc_define] = STATE(654),
    [sym_preproc_undef] = STATE(654),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2011),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(2741),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [655] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3220),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7139),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6381),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_member_binding_expression] = STATE(4074),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(655),
    [sym_preproc_endregion] = STATE(655),
    [sym_preproc_line] = STATE(655),
    [sym_preproc_pragma] = STATE(655),
    [sym_preproc_nullable] = STATE(655),
    [sym_preproc_error] = STATE(655),
    [sym_preproc_warning] = STATE(655),
    [sym_preproc_define] = STATE(655),
    [sym_preproc_undef] = STATE(655),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2011),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(2735),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [656] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5839),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(656),
    [sym_preproc_endregion] = STATE(656),
    [sym_preproc_line] = STATE(656),
    [sym_preproc_pragma] = STATE(656),
    [sym_preproc_nullable] = STATE(656),
    [sym_preproc_error] = STATE(656),
    [sym_preproc_warning] = STATE(656),
    [sym_preproc_define] = STATE(656),
    [sym_preproc_undef] = STATE(656),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_COMMA] = ACTIONS(673),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_RBRACE] = ACTIONS(2745),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [657] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3026),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7139),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6578),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_member_binding_expression] = STATE(3770),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(657),
    [sym_preproc_endregion] = STATE(657),
    [sym_preproc_line] = STATE(657),
    [sym_preproc_pragma] = STATE(657),
    [sym_preproc_nullable] = STATE(657),
    [sym_preproc_error] = STATE(657),
    [sym_preproc_warning] = STATE(657),
    [sym_preproc_define] = STATE(657),
    [sym_preproc_undef] = STATE(657),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2011),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(2721),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [658] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3267),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7139),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6372),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_member_binding_expression] = STATE(4121),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(658),
    [sym_preproc_endregion] = STATE(658),
    [sym_preproc_line] = STATE(658),
    [sym_preproc_pragma] = STATE(658),
    [sym_preproc_nullable] = STATE(658),
    [sym_preproc_error] = STATE(658),
    [sym_preproc_warning] = STATE(658),
    [sym_preproc_define] = STATE(658),
    [sym_preproc_undef] = STATE(658),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2011),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(2741),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [659] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3801),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7139),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6502),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_member_binding_expression] = STATE(3693),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(659),
    [sym_preproc_endregion] = STATE(659),
    [sym_preproc_line] = STATE(659),
    [sym_preproc_pragma] = STATE(659),
    [sym_preproc_nullable] = STATE(659),
    [sym_preproc_error] = STATE(659),
    [sym_preproc_warning] = STATE(659),
    [sym_preproc_define] = STATE(659),
    [sym_preproc_undef] = STATE(659),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2011),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(2731),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [660] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3267),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7139),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6374),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_member_binding_expression] = STATE(4121),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(660),
    [sym_preproc_endregion] = STATE(660),
    [sym_preproc_line] = STATE(660),
    [sym_preproc_pragma] = STATE(660),
    [sym_preproc_nullable] = STATE(660),
    [sym_preproc_error] = STATE(660),
    [sym_preproc_warning] = STATE(660),
    [sym_preproc_define] = STATE(660),
    [sym_preproc_undef] = STATE(660),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2011),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(2741),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [661] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6223),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym__anonymous_object_member_declarator] = STATE(8895),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2867),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(661),
    [sym_preproc_endregion] = STATE(661),
    [sym_preproc_line] = STATE(661),
    [sym_preproc_pragma] = STATE(661),
    [sym_preproc_nullable] = STATE(661),
    [sym_preproc_error] = STATE(661),
    [sym_preproc_warning] = STATE(661),
    [sym_preproc_define] = STATE(661),
    [sym_preproc_undef] = STATE(661),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_RBRACE] = ACTIONS(2747),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [662] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6223),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym__anonymous_object_member_declarator] = STATE(8895),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2867),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(662),
    [sym_preproc_endregion] = STATE(662),
    [sym_preproc_line] = STATE(662),
    [sym_preproc_pragma] = STATE(662),
    [sym_preproc_nullable] = STATE(662),
    [sym_preproc_error] = STATE(662),
    [sym_preproc_warning] = STATE(662),
    [sym_preproc_define] = STATE(662),
    [sym_preproc_undef] = STATE(662),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_RBRACE] = ACTIONS(2749),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [663] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6956),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6530),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9482),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(663),
    [sym_preproc_endregion] = STATE(663),
    [sym_preproc_line] = STATE(663),
    [sym_preproc_pragma] = STATE(663),
    [sym_preproc_nullable] = STATE(663),
    [sym_preproc_error] = STATE(663),
    [sym_preproc_warning] = STATE(663),
    [sym_preproc_define] = STATE(663),
    [sym_preproc_undef] = STATE(663),
    [aux_sym_class_declaration_repeat1] = STATE(3853),
    [aux_sym_lambda_expression_repeat1] = STATE(4299),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(2751),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1497),
    [anon_sym_ref] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_case] = ACTIONS(2753),
    [anon_sym_default] = ACTIONS(2755),
    [anon_sym_throw] = ACTIONS(1505),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1507),
    [anon_sym_DOT_DOT] = ACTIONS(1509),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [664] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3801),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7139),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6522),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_member_binding_expression] = STATE(3770),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(664),
    [sym_preproc_endregion] = STATE(664),
    [sym_preproc_line] = STATE(664),
    [sym_preproc_pragma] = STATE(664),
    [sym_preproc_nullable] = STATE(664),
    [sym_preproc_error] = STATE(664),
    [sym_preproc_warning] = STATE(664),
    [sym_preproc_define] = STATE(664),
    [sym_preproc_undef] = STATE(664),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2011),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(2757),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [665] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3801),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7139),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6317),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_member_binding_expression] = STATE(4121),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(665),
    [sym_preproc_endregion] = STATE(665),
    [sym_preproc_line] = STATE(665),
    [sym_preproc_pragma] = STATE(665),
    [sym_preproc_nullable] = STATE(665),
    [sym_preproc_error] = STATE(665),
    [sym_preproc_warning] = STATE(665),
    [sym_preproc_define] = STATE(665),
    [sym_preproc_undef] = STATE(665),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2011),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(2741),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [666] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6223),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym__anonymous_object_member_declarator] = STATE(8895),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2867),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(666),
    [sym_preproc_endregion] = STATE(666),
    [sym_preproc_line] = STATE(666),
    [sym_preproc_pragma] = STATE(666),
    [sym_preproc_nullable] = STATE(666),
    [sym_preproc_error] = STATE(666),
    [sym_preproc_warning] = STATE(666),
    [sym_preproc_define] = STATE(666),
    [sym_preproc_undef] = STATE(666),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_RBRACE] = ACTIONS(2759),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [667] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6223),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym__anonymous_object_member_declarator] = STATE(8895),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2867),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(667),
    [sym_preproc_endregion] = STATE(667),
    [sym_preproc_line] = STATE(667),
    [sym_preproc_pragma] = STATE(667),
    [sym_preproc_nullable] = STATE(667),
    [sym_preproc_error] = STATE(667),
    [sym_preproc_warning] = STATE(667),
    [sym_preproc_define] = STATE(667),
    [sym_preproc_undef] = STATE(667),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_RBRACE] = ACTIONS(2761),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [668] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6117),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(668),
    [sym_preproc_endregion] = STATE(668),
    [sym_preproc_line] = STATE(668),
    [sym_preproc_pragma] = STATE(668),
    [sym_preproc_nullable] = STATE(668),
    [sym_preproc_error] = STATE(668),
    [sym_preproc_warning] = STATE(668),
    [sym_preproc_define] = STATE(668),
    [sym_preproc_undef] = STATE(668),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_COMMA] = ACTIONS(743),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_RBRACE] = ACTIONS(2763),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [669] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5870),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(669),
    [sym_preproc_endregion] = STATE(669),
    [sym_preproc_line] = STATE(669),
    [sym_preproc_pragma] = STATE(669),
    [sym_preproc_nullable] = STATE(669),
    [sym_preproc_error] = STATE(669),
    [sym_preproc_warning] = STATE(669),
    [sym_preproc_define] = STATE(669),
    [sym_preproc_undef] = STATE(669),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_COMMA] = ACTIONS(949),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_RBRACE] = ACTIONS(2765),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [670] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3220),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7139),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6362),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_member_binding_expression] = STATE(4074),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(670),
    [sym_preproc_endregion] = STATE(670),
    [sym_preproc_line] = STATE(670),
    [sym_preproc_pragma] = STATE(670),
    [sym_preproc_nullable] = STATE(670),
    [sym_preproc_error] = STATE(670),
    [sym_preproc_warning] = STATE(670),
    [sym_preproc_define] = STATE(670),
    [sym_preproc_undef] = STATE(670),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2011),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(2735),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [671] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6698),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5866),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8472),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(671),
    [sym_preproc_endregion] = STATE(671),
    [sym_preproc_line] = STATE(671),
    [sym_preproc_pragma] = STATE(671),
    [sym_preproc_nullable] = STATE(671),
    [sym_preproc_error] = STATE(671),
    [sym_preproc_warning] = STATE(671),
    [sym_preproc_define] = STATE(671),
    [sym_preproc_undef] = STATE(671),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(2767),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [672] = {
    [sym_attribute_argument] = STATE(8476),
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6165),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2843),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(672),
    [sym_preproc_endregion] = STATE(672),
    [sym_preproc_line] = STATE(672),
    [sym_preproc_pragma] = STATE(672),
    [sym_preproc_nullable] = STATE(672),
    [sym_preproc_error] = STATE(672),
    [sym_preproc_warning] = STATE(672),
    [sym_preproc_define] = STATE(672),
    [sym_preproc_undef] = STATE(672),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2769),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [673] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3801),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7139),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6366),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_member_binding_expression] = STATE(4074),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(673),
    [sym_preproc_endregion] = STATE(673),
    [sym_preproc_line] = STATE(673),
    [sym_preproc_pragma] = STATE(673),
    [sym_preproc_nullable] = STATE(673),
    [sym_preproc_error] = STATE(673),
    [sym_preproc_warning] = STATE(673),
    [sym_preproc_define] = STATE(673),
    [sym_preproc_undef] = STATE(673),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2011),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(2735),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [674] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_variable_declaration] = STATE(9135),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6902),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6000),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4364),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9470),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(674),
    [sym_preproc_endregion] = STATE(674),
    [sym_preproc_line] = STATE(674),
    [sym_preproc_pragma] = STATE(674),
    [sym_preproc_nullable] = STATE(674),
    [sym_preproc_error] = STATE(674),
    [sym_preproc_warning] = STATE(674),
    [sym_preproc_define] = STATE(674),
    [sym_preproc_undef] = STATE(674),
    [aux_sym_class_declaration_repeat1] = STATE(3870),
    [aux_sym_lambda_expression_repeat1] = STATE(4302),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(2771),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1555),
    [anon_sym_ref] = ACTIONS(1557),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(695),
    [anon_sym_TILDE] = ACTIONS(695),
    [anon_sym_PLUS_PLUS] = ACTIONS(695),
    [anon_sym_DASH_DASH] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(697),
    [anon_sym_DASH] = ACTIONS(697),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(695),
    [anon_sym_AMP] = ACTIONS(695),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1559),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1561),
    [anon_sym_DOT_DOT] = ACTIONS(1563),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [675] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6223),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym__anonymous_object_member_declarator] = STATE(8895),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2867),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(675),
    [sym_preproc_endregion] = STATE(675),
    [sym_preproc_line] = STATE(675),
    [sym_preproc_pragma] = STATE(675),
    [sym_preproc_nullable] = STATE(675),
    [sym_preproc_error] = STATE(675),
    [sym_preproc_warning] = STATE(675),
    [sym_preproc_define] = STATE(675),
    [sym_preproc_undef] = STATE(675),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_RBRACE] = ACTIONS(2773),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [676] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6223),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym__anonymous_object_member_declarator] = STATE(8895),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2867),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(676),
    [sym_preproc_endregion] = STATE(676),
    [sym_preproc_line] = STATE(676),
    [sym_preproc_pragma] = STATE(676),
    [sym_preproc_nullable] = STATE(676),
    [sym_preproc_error] = STATE(676),
    [sym_preproc_warning] = STATE(676),
    [sym_preproc_define] = STATE(676),
    [sym_preproc_undef] = STATE(676),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_RBRACE] = ACTIONS(2775),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [677] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6956),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6587),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9482),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(677),
    [sym_preproc_endregion] = STATE(677),
    [sym_preproc_line] = STATE(677),
    [sym_preproc_pragma] = STATE(677),
    [sym_preproc_nullable] = STATE(677),
    [sym_preproc_error] = STATE(677),
    [sym_preproc_warning] = STATE(677),
    [sym_preproc_define] = STATE(677),
    [sym_preproc_undef] = STATE(677),
    [aux_sym_class_declaration_repeat1] = STATE(3853),
    [aux_sym_lambda_expression_repeat1] = STATE(4299),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(2777),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1497),
    [anon_sym_ref] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_case] = ACTIONS(2779),
    [anon_sym_default] = ACTIONS(2781),
    [anon_sym_throw] = ACTIONS(1505),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1507),
    [anon_sym_DOT_DOT] = ACTIONS(1509),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [678] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6077),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(678),
    [sym_preproc_endregion] = STATE(678),
    [sym_preproc_line] = STATE(678),
    [sym_preproc_pragma] = STATE(678),
    [sym_preproc_nullable] = STATE(678),
    [sym_preproc_error] = STATE(678),
    [sym_preproc_warning] = STATE(678),
    [sym_preproc_define] = STATE(678),
    [sym_preproc_undef] = STATE(678),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_COMMA] = ACTIONS(943),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_RBRACE] = ACTIONS(2783),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [679] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_using_variable_declaration] = STATE(9647),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6221),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2789),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6865),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8977),
    [sym_expression] = STATE(6452),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(679),
    [sym_preproc_endregion] = STATE(679),
    [sym_preproc_line] = STATE(679),
    [sym_preproc_pragma] = STATE(679),
    [sym_preproc_nullable] = STATE(679),
    [sym_preproc_error] = STATE(679),
    [sym_preproc_warning] = STATE(679),
    [sym_preproc_define] = STATE(679),
    [sym_preproc_undef] = STATE(679),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(2725),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(1089),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2727),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [680] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5980),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(680),
    [sym_preproc_endregion] = STATE(680),
    [sym_preproc_line] = STATE(680),
    [sym_preproc_pragma] = STATE(680),
    [sym_preproc_nullable] = STATE(680),
    [sym_preproc_error] = STATE(680),
    [sym_preproc_warning] = STATE(680),
    [sym_preproc_define] = STATE(680),
    [sym_preproc_undef] = STATE(680),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_COMMA] = ACTIONS(953),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_RBRACE] = ACTIONS(2785),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [681] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6223),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym__anonymous_object_member_declarator] = STATE(8895),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2867),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(681),
    [sym_preproc_endregion] = STATE(681),
    [sym_preproc_line] = STATE(681),
    [sym_preproc_pragma] = STATE(681),
    [sym_preproc_nullable] = STATE(681),
    [sym_preproc_error] = STATE(681),
    [sym_preproc_warning] = STATE(681),
    [sym_preproc_define] = STATE(681),
    [sym_preproc_undef] = STATE(681),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_RBRACE] = ACTIONS(2787),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [682] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_using_variable_declaration] = STATE(9130),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6221),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2789),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6865),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8977),
    [sym_expression] = STATE(6365),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(682),
    [sym_preproc_endregion] = STATE(682),
    [sym_preproc_line] = STATE(682),
    [sym_preproc_pragma] = STATE(682),
    [sym_preproc_nullable] = STATE(682),
    [sym_preproc_error] = STATE(682),
    [sym_preproc_warning] = STATE(682),
    [sym_preproc_define] = STATE(682),
    [sym_preproc_undef] = STATE(682),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(2725),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(1089),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2727),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [683] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3026),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7139),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6386),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_member_binding_expression] = STATE(3770),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(683),
    [sym_preproc_endregion] = STATE(683),
    [sym_preproc_line] = STATE(683),
    [sym_preproc_pragma] = STATE(683),
    [sym_preproc_nullable] = STATE(683),
    [sym_preproc_error] = STATE(683),
    [sym_preproc_warning] = STATE(683),
    [sym_preproc_define] = STATE(683),
    [sym_preproc_undef] = STATE(683),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2011),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(2721),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [684] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_using_variable_declaration] = STATE(9331),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6221),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2789),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6865),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8977),
    [sym_expression] = STATE(6415),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(684),
    [sym_preproc_endregion] = STATE(684),
    [sym_preproc_line] = STATE(684),
    [sym_preproc_pragma] = STATE(684),
    [sym_preproc_nullable] = STATE(684),
    [sym_preproc_error] = STATE(684),
    [sym_preproc_warning] = STATE(684),
    [sym_preproc_define] = STATE(684),
    [sym_preproc_undef] = STATE(684),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(2725),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(1089),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2727),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [685] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6956),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6359),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9482),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(685),
    [sym_preproc_endregion] = STATE(685),
    [sym_preproc_line] = STATE(685),
    [sym_preproc_pragma] = STATE(685),
    [sym_preproc_nullable] = STATE(685),
    [sym_preproc_error] = STATE(685),
    [sym_preproc_warning] = STATE(685),
    [sym_preproc_define] = STATE(685),
    [sym_preproc_undef] = STATE(685),
    [aux_sym_class_declaration_repeat1] = STATE(3853),
    [aux_sym_lambda_expression_repeat1] = STATE(4299),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(2789),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1497),
    [anon_sym_ref] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_case] = ACTIONS(2791),
    [anon_sym_default] = ACTIONS(2793),
    [anon_sym_throw] = ACTIONS(1505),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1507),
    [anon_sym_DOT_DOT] = ACTIONS(1509),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [686] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6698),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6063),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8686),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(686),
    [sym_preproc_endregion] = STATE(686),
    [sym_preproc_line] = STATE(686),
    [sym_preproc_pragma] = STATE(686),
    [sym_preproc_nullable] = STATE(686),
    [sym_preproc_error] = STATE(686),
    [sym_preproc_warning] = STATE(686),
    [sym_preproc_define] = STATE(686),
    [sym_preproc_undef] = STATE(686),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(2767),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [687] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6698),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6129),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8686),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(687),
    [sym_preproc_endregion] = STATE(687),
    [sym_preproc_line] = STATE(687),
    [sym_preproc_pragma] = STATE(687),
    [sym_preproc_nullable] = STATE(687),
    [sym_preproc_error] = STATE(687),
    [sym_preproc_warning] = STATE(687),
    [sym_preproc_define] = STATE(687),
    [sym_preproc_undef] = STATE(687),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(2767),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [688] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6956),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6529),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9482),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(688),
    [sym_preproc_endregion] = STATE(688),
    [sym_preproc_line] = STATE(688),
    [sym_preproc_pragma] = STATE(688),
    [sym_preproc_nullable] = STATE(688),
    [sym_preproc_error] = STATE(688),
    [sym_preproc_warning] = STATE(688),
    [sym_preproc_define] = STATE(688),
    [sym_preproc_undef] = STATE(688),
    [aux_sym_class_declaration_repeat1] = STATE(3853),
    [aux_sym_lambda_expression_repeat1] = STATE(4299),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(2795),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1497),
    [anon_sym_ref] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_case] = ACTIONS(2797),
    [anon_sym_default] = ACTIONS(2799),
    [anon_sym_throw] = ACTIONS(1505),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1507),
    [anon_sym_DOT_DOT] = ACTIONS(1509),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [689] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3267),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7139),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6665),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_member_binding_expression] = STATE(4121),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(689),
    [sym_preproc_endregion] = STATE(689),
    [sym_preproc_line] = STATE(689),
    [sym_preproc_pragma] = STATE(689),
    [sym_preproc_nullable] = STATE(689),
    [sym_preproc_error] = STATE(689),
    [sym_preproc_warning] = STATE(689),
    [sym_preproc_define] = STATE(689),
    [sym_preproc_undef] = STATE(689),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2011),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(2741),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [690] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5905),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(690),
    [sym_preproc_endregion] = STATE(690),
    [sym_preproc_line] = STATE(690),
    [sym_preproc_pragma] = STATE(690),
    [sym_preproc_nullable] = STATE(690),
    [sym_preproc_error] = STATE(690),
    [sym_preproc_warning] = STATE(690),
    [sym_preproc_define] = STATE(690),
    [sym_preproc_undef] = STATE(690),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_COMMA] = ACTIONS(939),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_RBRACE] = ACTIONS(2801),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [691] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6223),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym__anonymous_object_member_declarator] = STATE(8895),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2867),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(691),
    [sym_preproc_endregion] = STATE(691),
    [sym_preproc_line] = STATE(691),
    [sym_preproc_pragma] = STATE(691),
    [sym_preproc_nullable] = STATE(691),
    [sym_preproc_error] = STATE(691),
    [sym_preproc_warning] = STATE(691),
    [sym_preproc_define] = STATE(691),
    [sym_preproc_undef] = STATE(691),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_RBRACE] = ACTIONS(2803),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [692] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3553),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7139),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6350),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_member_binding_expression] = STATE(4624),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(692),
    [sym_preproc_endregion] = STATE(692),
    [sym_preproc_line] = STATE(692),
    [sym_preproc_pragma] = STATE(692),
    [sym_preproc_nullable] = STATE(692),
    [sym_preproc_error] = STATE(692),
    [sym_preproc_warning] = STATE(692),
    [sym_preproc_define] = STATE(692),
    [sym_preproc_undef] = STATE(692),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2011),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(2805),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [693] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3018),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7139),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6348),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_member_binding_expression] = STATE(3693),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(693),
    [sym_preproc_endregion] = STATE(693),
    [sym_preproc_line] = STATE(693),
    [sym_preproc_pragma] = STATE(693),
    [sym_preproc_nullable] = STATE(693),
    [sym_preproc_error] = STATE(693),
    [sym_preproc_warning] = STATE(693),
    [sym_preproc_define] = STATE(693),
    [sym_preproc_undef] = STATE(693),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2011),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(2807),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [694] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3944),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7139),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6427),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_member_binding_expression] = STATE(5558),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(694),
    [sym_preproc_endregion] = STATE(694),
    [sym_preproc_line] = STATE(694),
    [sym_preproc_pragma] = STATE(694),
    [sym_preproc_nullable] = STATE(694),
    [sym_preproc_error] = STATE(694),
    [sym_preproc_warning] = STATE(694),
    [sym_preproc_define] = STATE(694),
    [sym_preproc_undef] = STATE(694),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2011),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(2809),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [695] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6730),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2801),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6698),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6129),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8686),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(695),
    [sym_preproc_endregion] = STATE(695),
    [sym_preproc_line] = STATE(695),
    [sym_preproc_pragma] = STATE(695),
    [sym_preproc_nullable] = STATE(695),
    [sym_preproc_error] = STATE(695),
    [sym_preproc_warning] = STATE(695),
    [sym_preproc_define] = STATE(695),
    [sym_preproc_undef] = STATE(695),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(2737),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(2739),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(1089),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2727),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [696] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_variable_declaration] = STATE(9512),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6902),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6081),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4364),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9470),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(696),
    [sym_preproc_endregion] = STATE(696),
    [sym_preproc_line] = STATE(696),
    [sym_preproc_pragma] = STATE(696),
    [sym_preproc_nullable] = STATE(696),
    [sym_preproc_error] = STATE(696),
    [sym_preproc_warning] = STATE(696),
    [sym_preproc_define] = STATE(696),
    [sym_preproc_undef] = STATE(696),
    [aux_sym_class_declaration_repeat1] = STATE(3870),
    [aux_sym_lambda_expression_repeat1] = STATE(4302),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(2811),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1555),
    [anon_sym_ref] = ACTIONS(1557),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(695),
    [anon_sym_TILDE] = ACTIONS(695),
    [anon_sym_PLUS_PLUS] = ACTIONS(695),
    [anon_sym_DASH_DASH] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(697),
    [anon_sym_DASH] = ACTIONS(697),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(695),
    [anon_sym_AMP] = ACTIONS(695),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1559),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1561),
    [anon_sym_DOT_DOT] = ACTIONS(1563),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [697] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3944),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7139),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6358),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_member_binding_expression] = STATE(5558),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(697),
    [sym_preproc_endregion] = STATE(697),
    [sym_preproc_line] = STATE(697),
    [sym_preproc_pragma] = STATE(697),
    [sym_preproc_nullable] = STATE(697),
    [sym_preproc_error] = STATE(697),
    [sym_preproc_warning] = STATE(697),
    [sym_preproc_define] = STATE(697),
    [sym_preproc_undef] = STATE(697),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2011),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(2809),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [698] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3026),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7139),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6394),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_member_binding_expression] = STATE(3770),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(698),
    [sym_preproc_endregion] = STATE(698),
    [sym_preproc_line] = STATE(698),
    [sym_preproc_pragma] = STATE(698),
    [sym_preproc_nullable] = STATE(698),
    [sym_preproc_error] = STATE(698),
    [sym_preproc_warning] = STATE(698),
    [sym_preproc_define] = STATE(698),
    [sym_preproc_undef] = STATE(698),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2011),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(2721),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [699] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3267),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7139),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6416),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_member_binding_expression] = STATE(4121),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(699),
    [sym_preproc_endregion] = STATE(699),
    [sym_preproc_line] = STATE(699),
    [sym_preproc_pragma] = STATE(699),
    [sym_preproc_nullable] = STATE(699),
    [sym_preproc_error] = STATE(699),
    [sym_preproc_warning] = STATE(699),
    [sym_preproc_define] = STATE(699),
    [sym_preproc_undef] = STATE(699),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2011),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(2741),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [700] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3801),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7139),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6541),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_member_binding_expression] = STATE(3770),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(700),
    [sym_preproc_endregion] = STATE(700),
    [sym_preproc_line] = STATE(700),
    [sym_preproc_pragma] = STATE(700),
    [sym_preproc_nullable] = STATE(700),
    [sym_preproc_error] = STATE(700),
    [sym_preproc_warning] = STATE(700),
    [sym_preproc_define] = STATE(700),
    [sym_preproc_undef] = STATE(700),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2011),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(2757),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [701] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3553),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7139),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6450),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_member_binding_expression] = STATE(4624),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(701),
    [sym_preproc_endregion] = STATE(701),
    [sym_preproc_line] = STATE(701),
    [sym_preproc_pragma] = STATE(701),
    [sym_preproc_nullable] = STATE(701),
    [sym_preproc_error] = STATE(701),
    [sym_preproc_warning] = STATE(701),
    [sym_preproc_define] = STATE(701),
    [sym_preproc_undef] = STATE(701),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2011),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(2805),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [702] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3944),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7139),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6458),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_member_binding_expression] = STATE(5558),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(702),
    [sym_preproc_endregion] = STATE(702),
    [sym_preproc_line] = STATE(702),
    [sym_preproc_pragma] = STATE(702),
    [sym_preproc_nullable] = STATE(702),
    [sym_preproc_error] = STATE(702),
    [sym_preproc_warning] = STATE(702),
    [sym_preproc_define] = STATE(702),
    [sym_preproc_undef] = STATE(702),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2011),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(2809),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [703] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3018),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7139),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6632),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_member_binding_expression] = STATE(3693),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(703),
    [sym_preproc_endregion] = STATE(703),
    [sym_preproc_line] = STATE(703),
    [sym_preproc_pragma] = STATE(703),
    [sym_preproc_nullable] = STATE(703),
    [sym_preproc_error] = STATE(703),
    [sym_preproc_warning] = STATE(703),
    [sym_preproc_define] = STATE(703),
    [sym_preproc_undef] = STATE(703),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2011),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(2807),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [704] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3801),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7139),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6360),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_member_binding_expression] = STATE(4121),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(704),
    [sym_preproc_endregion] = STATE(704),
    [sym_preproc_line] = STATE(704),
    [sym_preproc_pragma] = STATE(704),
    [sym_preproc_nullable] = STATE(704),
    [sym_preproc_error] = STATE(704),
    [sym_preproc_warning] = STATE(704),
    [sym_preproc_define] = STATE(704),
    [sym_preproc_undef] = STATE(704),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2011),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(2741),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [705] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3220),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7139),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6364),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_member_binding_expression] = STATE(4074),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(705),
    [sym_preproc_endregion] = STATE(705),
    [sym_preproc_line] = STATE(705),
    [sym_preproc_pragma] = STATE(705),
    [sym_preproc_nullable] = STATE(705),
    [sym_preproc_error] = STATE(705),
    [sym_preproc_warning] = STATE(705),
    [sym_preproc_define] = STATE(705),
    [sym_preproc_undef] = STATE(705),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2011),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(2735),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [706] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_variable_declaration] = STATE(9701),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6902),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6095),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4364),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9470),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(706),
    [sym_preproc_endregion] = STATE(706),
    [sym_preproc_line] = STATE(706),
    [sym_preproc_pragma] = STATE(706),
    [sym_preproc_nullable] = STATE(706),
    [sym_preproc_error] = STATE(706),
    [sym_preproc_warning] = STATE(706),
    [sym_preproc_define] = STATE(706),
    [sym_preproc_undef] = STATE(706),
    [aux_sym_class_declaration_repeat1] = STATE(3870),
    [aux_sym_lambda_expression_repeat1] = STATE(4302),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(2813),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1555),
    [anon_sym_ref] = ACTIONS(1557),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(695),
    [anon_sym_TILDE] = ACTIONS(695),
    [anon_sym_PLUS_PLUS] = ACTIONS(695),
    [anon_sym_DASH_DASH] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(697),
    [anon_sym_DASH] = ACTIONS(697),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(695),
    [anon_sym_AMP] = ACTIONS(695),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1559),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1561),
    [anon_sym_DOT_DOT] = ACTIONS(1563),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [707] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3801),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7139),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6369),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_member_binding_expression] = STATE(4074),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(707),
    [sym_preproc_endregion] = STATE(707),
    [sym_preproc_line] = STATE(707),
    [sym_preproc_pragma] = STATE(707),
    [sym_preproc_nullable] = STATE(707),
    [sym_preproc_error] = STATE(707),
    [sym_preproc_warning] = STATE(707),
    [sym_preproc_define] = STATE(707),
    [sym_preproc_undef] = STATE(707),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2011),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(2735),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [708] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3026),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7139),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6468),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_member_binding_expression] = STATE(3770),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(708),
    [sym_preproc_endregion] = STATE(708),
    [sym_preproc_line] = STATE(708),
    [sym_preproc_pragma] = STATE(708),
    [sym_preproc_nullable] = STATE(708),
    [sym_preproc_error] = STATE(708),
    [sym_preproc_warning] = STATE(708),
    [sym_preproc_define] = STATE(708),
    [sym_preproc_undef] = STATE(708),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2011),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(2721),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [709] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_using_variable_declaration] = STATE(9045),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6221),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2789),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6865),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8977),
    [sym_expression] = STATE(6454),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(709),
    [sym_preproc_endregion] = STATE(709),
    [sym_preproc_line] = STATE(709),
    [sym_preproc_pragma] = STATE(709),
    [sym_preproc_nullable] = STATE(709),
    [sym_preproc_error] = STATE(709),
    [sym_preproc_warning] = STATE(709),
    [sym_preproc_define] = STATE(709),
    [sym_preproc_undef] = STATE(709),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(2725),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(1089),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2727),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [710] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6223),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym__anonymous_object_member_declarator] = STATE(8895),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2867),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(710),
    [sym_preproc_endregion] = STATE(710),
    [sym_preproc_line] = STATE(710),
    [sym_preproc_pragma] = STATE(710),
    [sym_preproc_nullable] = STATE(710),
    [sym_preproc_error] = STATE(710),
    [sym_preproc_warning] = STATE(710),
    [sym_preproc_define] = STATE(710),
    [sym_preproc_undef] = STATE(710),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_RBRACE] = ACTIONS(2815),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [711] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_variable_declaration] = STATE(9761),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6902),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6096),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4364),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9470),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(711),
    [sym_preproc_endregion] = STATE(711),
    [sym_preproc_line] = STATE(711),
    [sym_preproc_pragma] = STATE(711),
    [sym_preproc_nullable] = STATE(711),
    [sym_preproc_error] = STATE(711),
    [sym_preproc_warning] = STATE(711),
    [sym_preproc_define] = STATE(711),
    [sym_preproc_undef] = STATE(711),
    [aux_sym_class_declaration_repeat1] = STATE(3870),
    [aux_sym_lambda_expression_repeat1] = STATE(4302),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(2817),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1555),
    [anon_sym_ref] = ACTIONS(1557),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(695),
    [anon_sym_TILDE] = ACTIONS(695),
    [anon_sym_PLUS_PLUS] = ACTIONS(695),
    [anon_sym_DASH_DASH] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(697),
    [anon_sym_DASH] = ACTIONS(697),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(695),
    [anon_sym_AMP] = ACTIONS(695),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1559),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1561),
    [anon_sym_DOT_DOT] = ACTIONS(1563),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [712] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6223),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym__anonymous_object_member_declarator] = STATE(8895),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2867),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(712),
    [sym_preproc_endregion] = STATE(712),
    [sym_preproc_line] = STATE(712),
    [sym_preproc_pragma] = STATE(712),
    [sym_preproc_nullable] = STATE(712),
    [sym_preproc_error] = STATE(712),
    [sym_preproc_warning] = STATE(712),
    [sym_preproc_define] = STATE(712),
    [sym_preproc_undef] = STATE(712),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_RBRACE] = ACTIONS(2819),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [713] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3026),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7139),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6487),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_member_binding_expression] = STATE(3770),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(713),
    [sym_preproc_endregion] = STATE(713),
    [sym_preproc_line] = STATE(713),
    [sym_preproc_pragma] = STATE(713),
    [sym_preproc_nullable] = STATE(713),
    [sym_preproc_error] = STATE(713),
    [sym_preproc_warning] = STATE(713),
    [sym_preproc_define] = STATE(713),
    [sym_preproc_undef] = STATE(713),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2011),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(2721),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [714] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_using_variable_declaration] = STATE(9520),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6221),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2789),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6865),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8977),
    [sym_expression] = STATE(6602),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(714),
    [sym_preproc_endregion] = STATE(714),
    [sym_preproc_line] = STATE(714),
    [sym_preproc_pragma] = STATE(714),
    [sym_preproc_nullable] = STATE(714),
    [sym_preproc_error] = STATE(714),
    [sym_preproc_warning] = STATE(714),
    [sym_preproc_define] = STATE(714),
    [sym_preproc_undef] = STATE(714),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(2725),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(1089),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2727),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [715] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3026),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7139),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6687),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_member_binding_expression] = STATE(3770),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(715),
    [sym_preproc_endregion] = STATE(715),
    [sym_preproc_line] = STATE(715),
    [sym_preproc_pragma] = STATE(715),
    [sym_preproc_nullable] = STATE(715),
    [sym_preproc_error] = STATE(715),
    [sym_preproc_warning] = STATE(715),
    [sym_preproc_define] = STATE(715),
    [sym_preproc_undef] = STATE(715),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2011),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(2721),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [716] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3026),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7139),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6445),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_member_binding_expression] = STATE(3770),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(716),
    [sym_preproc_endregion] = STATE(716),
    [sym_preproc_line] = STATE(716),
    [sym_preproc_pragma] = STATE(716),
    [sym_preproc_nullable] = STATE(716),
    [sym_preproc_error] = STATE(716),
    [sym_preproc_warning] = STATE(716),
    [sym_preproc_define] = STATE(716),
    [sym_preproc_undef] = STATE(716),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2011),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(2721),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [717] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3026),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7139),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6549),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_member_binding_expression] = STATE(3770),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(717),
    [sym_preproc_endregion] = STATE(717),
    [sym_preproc_line] = STATE(717),
    [sym_preproc_pragma] = STATE(717),
    [sym_preproc_nullable] = STATE(717),
    [sym_preproc_error] = STATE(717),
    [sym_preproc_warning] = STATE(717),
    [sym_preproc_define] = STATE(717),
    [sym_preproc_undef] = STATE(717),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2011),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(2721),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [718] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_using_variable_declaration] = STATE(9755),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6221),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2789),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6865),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8977),
    [sym_expression] = STATE(6649),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(718),
    [sym_preproc_endregion] = STATE(718),
    [sym_preproc_line] = STATE(718),
    [sym_preproc_pragma] = STATE(718),
    [sym_preproc_nullable] = STATE(718),
    [sym_preproc_error] = STATE(718),
    [sym_preproc_warning] = STATE(718),
    [sym_preproc_define] = STATE(718),
    [sym_preproc_undef] = STATE(718),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(2725),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(1089),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2727),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [719] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3026),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7139),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6556),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_member_binding_expression] = STATE(3770),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(719),
    [sym_preproc_endregion] = STATE(719),
    [sym_preproc_line] = STATE(719),
    [sym_preproc_pragma] = STATE(719),
    [sym_preproc_nullable] = STATE(719),
    [sym_preproc_error] = STATE(719),
    [sym_preproc_warning] = STATE(719),
    [sym_preproc_define] = STATE(719),
    [sym_preproc_undef] = STATE(719),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2011),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(2721),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [720] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3553),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7139),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6462),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_member_binding_expression] = STATE(4624),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(720),
    [sym_preproc_endregion] = STATE(720),
    [sym_preproc_line] = STATE(720),
    [sym_preproc_pragma] = STATE(720),
    [sym_preproc_nullable] = STATE(720),
    [sym_preproc_error] = STATE(720),
    [sym_preproc_warning] = STATE(720),
    [sym_preproc_define] = STATE(720),
    [sym_preproc_undef] = STATE(720),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2011),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(2805),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [721] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3026),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7139),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6562),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_member_binding_expression] = STATE(3770),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(721),
    [sym_preproc_endregion] = STATE(721),
    [sym_preproc_line] = STATE(721),
    [sym_preproc_pragma] = STATE(721),
    [sym_preproc_nullable] = STATE(721),
    [sym_preproc_error] = STATE(721),
    [sym_preproc_warning] = STATE(721),
    [sym_preproc_define] = STATE(721),
    [sym_preproc_undef] = STATE(721),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2011),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(2721),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [722] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3018),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7139),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6341),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_member_binding_expression] = STATE(3693),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(722),
    [sym_preproc_endregion] = STATE(722),
    [sym_preproc_line] = STATE(722),
    [sym_preproc_pragma] = STATE(722),
    [sym_preproc_nullable] = STATE(722),
    [sym_preproc_error] = STATE(722),
    [sym_preproc_warning] = STATE(722),
    [sym_preproc_define] = STATE(722),
    [sym_preproc_undef] = STATE(722),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2011),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(2731),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [723] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3018),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7139),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6354),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_member_binding_expression] = STATE(3693),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(723),
    [sym_preproc_endregion] = STATE(723),
    [sym_preproc_line] = STATE(723),
    [sym_preproc_pragma] = STATE(723),
    [sym_preproc_nullable] = STATE(723),
    [sym_preproc_error] = STATE(723),
    [sym_preproc_warning] = STATE(723),
    [sym_preproc_define] = STATE(723),
    [sym_preproc_undef] = STATE(723),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2011),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(2731),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [724] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3944),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7139),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6463),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_member_binding_expression] = STATE(5558),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(724),
    [sym_preproc_endregion] = STATE(724),
    [sym_preproc_line] = STATE(724),
    [sym_preproc_pragma] = STATE(724),
    [sym_preproc_nullable] = STATE(724),
    [sym_preproc_error] = STATE(724),
    [sym_preproc_warning] = STATE(724),
    [sym_preproc_define] = STATE(724),
    [sym_preproc_undef] = STATE(724),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2011),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(2809),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [725] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3267),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7139),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6588),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_member_binding_expression] = STATE(4121),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(725),
    [sym_preproc_endregion] = STATE(725),
    [sym_preproc_line] = STATE(725),
    [sym_preproc_pragma] = STATE(725),
    [sym_preproc_nullable] = STATE(725),
    [sym_preproc_error] = STATE(725),
    [sym_preproc_warning] = STATE(725),
    [sym_preproc_define] = STATE(725),
    [sym_preproc_undef] = STATE(725),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2011),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(2741),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [726] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3801),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7139),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6361),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_member_binding_expression] = STATE(4121),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(726),
    [sym_preproc_endregion] = STATE(726),
    [sym_preproc_line] = STATE(726),
    [sym_preproc_pragma] = STATE(726),
    [sym_preproc_nullable] = STATE(726),
    [sym_preproc_error] = STATE(726),
    [sym_preproc_warning] = STATE(726),
    [sym_preproc_define] = STATE(726),
    [sym_preproc_undef] = STATE(726),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2011),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(2741),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [727] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(2855),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6045),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(727),
    [sym_preproc_endregion] = STATE(727),
    [sym_preproc_line] = STATE(727),
    [sym_preproc_pragma] = STATE(727),
    [sym_preproc_nullable] = STATE(727),
    [sym_preproc_error] = STATE(727),
    [sym_preproc_warning] = STATE(727),
    [sym_preproc_define] = STATE(727),
    [sym_preproc_undef] = STATE(727),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_struct] = ACTIONS(2821),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(2767),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [728] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(2855),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6045),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(728),
    [sym_preproc_endregion] = STATE(728),
    [sym_preproc_line] = STATE(728),
    [sym_preproc_pragma] = STATE(728),
    [sym_preproc_nullable] = STATE(728),
    [sym_preproc_error] = STATE(728),
    [sym_preproc_warning] = STATE(728),
    [sym_preproc_define] = STATE(728),
    [sym_preproc_undef] = STATE(728),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_struct] = ACTIONS(2823),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(2767),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [729] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3220),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7139),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6373),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_member_binding_expression] = STATE(4074),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(729),
    [sym_preproc_endregion] = STATE(729),
    [sym_preproc_line] = STATE(729),
    [sym_preproc_pragma] = STATE(729),
    [sym_preproc_nullable] = STATE(729),
    [sym_preproc_error] = STATE(729),
    [sym_preproc_warning] = STATE(729),
    [sym_preproc_define] = STATE(729),
    [sym_preproc_undef] = STATE(729),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2011),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(2735),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [730] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3553),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7139),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6623),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_member_binding_expression] = STATE(4624),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(730),
    [sym_preproc_endregion] = STATE(730),
    [sym_preproc_line] = STATE(730),
    [sym_preproc_pragma] = STATE(730),
    [sym_preproc_nullable] = STATE(730),
    [sym_preproc_error] = STATE(730),
    [sym_preproc_warning] = STATE(730),
    [sym_preproc_define] = STATE(730),
    [sym_preproc_undef] = STATE(730),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2011),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_DOT] = ACTIONS(2805),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [731] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7160),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6560),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4487),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7422),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9176),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(731),
    [sym_preproc_endregion] = STATE(731),
    [sym_preproc_line] = STATE(731),
    [sym_preproc_pragma] = STATE(731),
    [sym_preproc_nullable] = STATE(731),
    [sym_preproc_error] = STATE(731),
    [sym_preproc_warning] = STATE(731),
    [sym_preproc_define] = STATE(731),
    [sym_preproc_undef] = STATE(731),
    [aux_sym_class_declaration_repeat1] = STATE(3877),
    [aux_sym_lambda_expression_repeat1] = STATE(4320),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1979),
    [anon_sym_ref] = ACTIONS(1981),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(2767),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1985),
    [anon_sym_TILDE] = ACTIONS(1985),
    [anon_sym_PLUS_PLUS] = ACTIONS(1985),
    [anon_sym_DASH_DASH] = ACTIONS(1985),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1983),
    [anon_sym_DASH] = ACTIONS(1983),
    [anon_sym_STAR] = ACTIONS(1987),
    [anon_sym_CARET] = ACTIONS(1985),
    [anon_sym_AMP] = ACTIONS(1985),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1989),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1991),
    [anon_sym_DOT_DOT] = ACTIONS(1993),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [732] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3714),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6926),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2950),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7053),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6271),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4458),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7431),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9158),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(732),
    [sym_preproc_endregion] = STATE(732),
    [sym_preproc_line] = STATE(732),
    [sym_preproc_pragma] = STATE(732),
    [sym_preproc_nullable] = STATE(732),
    [sym_preproc_error] = STATE(732),
    [sym_preproc_warning] = STATE(732),
    [sym_preproc_define] = STATE(732),
    [sym_preproc_undef] = STATE(732),
    [aux_sym_class_declaration_repeat1] = STATE(3835),
    [aux_sym_lambda_expression_repeat1] = STATE(4263),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2213),
    [anon_sym_ref] = ACTIONS(2215),
    [anon_sym_LBRACE] = ACTIONS(2825),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2217),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2221),
    [anon_sym_TILDE] = ACTIONS(2221),
    [anon_sym_PLUS_PLUS] = ACTIONS(2221),
    [anon_sym_DASH_DASH] = ACTIONS(2221),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2219),
    [anon_sym_DASH] = ACTIONS(2219),
    [anon_sym_STAR] = ACTIONS(2223),
    [anon_sym_CARET] = ACTIONS(2221),
    [anon_sym_AMP] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2225),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2227),
    [anon_sym_DOT_DOT] = ACTIONS(2229),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [733] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3641),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6926),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2950),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7053),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6274),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4458),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7431),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9158),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(733),
    [sym_preproc_endregion] = STATE(733),
    [sym_preproc_line] = STATE(733),
    [sym_preproc_pragma] = STATE(733),
    [sym_preproc_nullable] = STATE(733),
    [sym_preproc_error] = STATE(733),
    [sym_preproc_warning] = STATE(733),
    [sym_preproc_define] = STATE(733),
    [sym_preproc_undef] = STATE(733),
    [aux_sym_class_declaration_repeat1] = STATE(3835),
    [aux_sym_lambda_expression_repeat1] = STATE(4263),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2213),
    [anon_sym_ref] = ACTIONS(2215),
    [anon_sym_LBRACE] = ACTIONS(2825),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2217),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2221),
    [anon_sym_TILDE] = ACTIONS(2221),
    [anon_sym_PLUS_PLUS] = ACTIONS(2221),
    [anon_sym_DASH_DASH] = ACTIONS(2221),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2219),
    [anon_sym_DASH] = ACTIONS(2219),
    [anon_sym_STAR] = ACTIONS(2223),
    [anon_sym_CARET] = ACTIONS(2221),
    [anon_sym_AMP] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2225),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2227),
    [anon_sym_DOT_DOT] = ACTIONS(2229),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [734] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3689),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6926),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2950),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7053),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6276),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4458),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7431),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9158),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(734),
    [sym_preproc_endregion] = STATE(734),
    [sym_preproc_line] = STATE(734),
    [sym_preproc_pragma] = STATE(734),
    [sym_preproc_nullable] = STATE(734),
    [sym_preproc_error] = STATE(734),
    [sym_preproc_warning] = STATE(734),
    [sym_preproc_define] = STATE(734),
    [sym_preproc_undef] = STATE(734),
    [aux_sym_class_declaration_repeat1] = STATE(3835),
    [aux_sym_lambda_expression_repeat1] = STATE(4263),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2213),
    [anon_sym_ref] = ACTIONS(2215),
    [anon_sym_LBRACE] = ACTIONS(2825),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2217),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2221),
    [anon_sym_TILDE] = ACTIONS(2221),
    [anon_sym_PLUS_PLUS] = ACTIONS(2221),
    [anon_sym_DASH_DASH] = ACTIONS(2221),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2219),
    [anon_sym_DASH] = ACTIONS(2219),
    [anon_sym_STAR] = ACTIONS(2223),
    [anon_sym_CARET] = ACTIONS(2221),
    [anon_sym_AMP] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2225),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2227),
    [anon_sym_DOT_DOT] = ACTIONS(2229),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [735] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3692),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6926),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2950),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7053),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6283),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4458),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7431),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9158),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(735),
    [sym_preproc_endregion] = STATE(735),
    [sym_preproc_line] = STATE(735),
    [sym_preproc_pragma] = STATE(735),
    [sym_preproc_nullable] = STATE(735),
    [sym_preproc_error] = STATE(735),
    [sym_preproc_warning] = STATE(735),
    [sym_preproc_define] = STATE(735),
    [sym_preproc_undef] = STATE(735),
    [aux_sym_class_declaration_repeat1] = STATE(3835),
    [aux_sym_lambda_expression_repeat1] = STATE(4263),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2213),
    [anon_sym_ref] = ACTIONS(2215),
    [anon_sym_LBRACE] = ACTIONS(2825),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2217),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2221),
    [anon_sym_TILDE] = ACTIONS(2221),
    [anon_sym_PLUS_PLUS] = ACTIONS(2221),
    [anon_sym_DASH_DASH] = ACTIONS(2221),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2219),
    [anon_sym_DASH] = ACTIONS(2219),
    [anon_sym_STAR] = ACTIONS(2223),
    [anon_sym_CARET] = ACTIONS(2221),
    [anon_sym_AMP] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2225),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2227),
    [anon_sym_DOT_DOT] = ACTIONS(2229),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [736] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3708),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6926),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2950),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7053),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6289),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4458),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7431),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9158),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(736),
    [sym_preproc_endregion] = STATE(736),
    [sym_preproc_line] = STATE(736),
    [sym_preproc_pragma] = STATE(736),
    [sym_preproc_nullable] = STATE(736),
    [sym_preproc_error] = STATE(736),
    [sym_preproc_warning] = STATE(736),
    [sym_preproc_define] = STATE(736),
    [sym_preproc_undef] = STATE(736),
    [aux_sym_class_declaration_repeat1] = STATE(3835),
    [aux_sym_lambda_expression_repeat1] = STATE(4263),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2213),
    [anon_sym_ref] = ACTIONS(2215),
    [anon_sym_LBRACE] = ACTIONS(2825),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2217),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2221),
    [anon_sym_TILDE] = ACTIONS(2221),
    [anon_sym_PLUS_PLUS] = ACTIONS(2221),
    [anon_sym_DASH_DASH] = ACTIONS(2221),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2219),
    [anon_sym_DASH] = ACTIONS(2219),
    [anon_sym_STAR] = ACTIONS(2223),
    [anon_sym_CARET] = ACTIONS(2221),
    [anon_sym_AMP] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2225),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2227),
    [anon_sym_DOT_DOT] = ACTIONS(2229),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [737] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5974),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(737),
    [sym_preproc_endregion] = STATE(737),
    [sym_preproc_line] = STATE(737),
    [sym_preproc_pragma] = STATE(737),
    [sym_preproc_nullable] = STATE(737),
    [sym_preproc_error] = STATE(737),
    [sym_preproc_warning] = STATE(737),
    [sym_preproc_define] = STATE(737),
    [sym_preproc_undef] = STATE(737),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2827),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [738] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6926),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2950),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7054),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6176),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4458),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7431),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9158),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(738),
    [sym_preproc_endregion] = STATE(738),
    [sym_preproc_line] = STATE(738),
    [sym_preproc_pragma] = STATE(738),
    [sym_preproc_nullable] = STATE(738),
    [sym_preproc_error] = STATE(738),
    [sym_preproc_warning] = STATE(738),
    [sym_preproc_define] = STATE(738),
    [sym_preproc_undef] = STATE(738),
    [aux_sym_class_declaration_repeat1] = STATE(3835),
    [aux_sym_lambda_expression_repeat1] = STATE(4263),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2213),
    [anon_sym_ref] = ACTIONS(2215),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2217),
    [anon_sym_readonly] = ACTIONS(2767),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2221),
    [anon_sym_TILDE] = ACTIONS(2221),
    [anon_sym_PLUS_PLUS] = ACTIONS(2221),
    [anon_sym_DASH_DASH] = ACTIONS(2221),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2219),
    [anon_sym_DASH] = ACTIONS(2219),
    [anon_sym_STAR] = ACTIONS(2223),
    [anon_sym_CARET] = ACTIONS(2221),
    [anon_sym_AMP] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2225),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2227),
    [anon_sym_DOT_DOT] = ACTIONS(2229),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [739] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6030),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(739),
    [sym_preproc_endregion] = STATE(739),
    [sym_preproc_line] = STATE(739),
    [sym_preproc_pragma] = STATE(739),
    [sym_preproc_nullable] = STATE(739),
    [sym_preproc_error] = STATE(739),
    [sym_preproc_warning] = STATE(739),
    [sym_preproc_define] = STATE(739),
    [sym_preproc_undef] = STATE(739),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2829),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [740] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4152),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7014),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6008),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4335),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7428),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9866),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(740),
    [sym_preproc_endregion] = STATE(740),
    [sym_preproc_line] = STATE(740),
    [sym_preproc_pragma] = STATE(740),
    [sym_preproc_nullable] = STATE(740),
    [sym_preproc_error] = STATE(740),
    [sym_preproc_warning] = STATE(740),
    [sym_preproc_define] = STATE(740),
    [sym_preproc_undef] = STATE(740),
    [aux_sym_class_declaration_repeat1] = STATE(3824),
    [aux_sym_lambda_expression_repeat1] = STATE(4242),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1539),
    [anon_sym_ref] = ACTIONS(1541),
    [anon_sym_LBRACE] = ACTIONS(2831),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1545),
    [anon_sym_TILDE] = ACTIONS(1545),
    [anon_sym_PLUS_PLUS] = ACTIONS(1545),
    [anon_sym_DASH_DASH] = ACTIONS(1545),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1543),
    [anon_sym_DASH] = ACTIONS(1543),
    [anon_sym_STAR] = ACTIONS(1547),
    [anon_sym_CARET] = ACTIONS(1545),
    [anon_sym_AMP] = ACTIONS(1545),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1549),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1551),
    [anon_sym_DOT_DOT] = ACTIONS(1553),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [741] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4119),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7014),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6009),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4335),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7428),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9866),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(741),
    [sym_preproc_endregion] = STATE(741),
    [sym_preproc_line] = STATE(741),
    [sym_preproc_pragma] = STATE(741),
    [sym_preproc_nullable] = STATE(741),
    [sym_preproc_error] = STATE(741),
    [sym_preproc_warning] = STATE(741),
    [sym_preproc_define] = STATE(741),
    [sym_preproc_undef] = STATE(741),
    [aux_sym_class_declaration_repeat1] = STATE(3824),
    [aux_sym_lambda_expression_repeat1] = STATE(4242),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1539),
    [anon_sym_ref] = ACTIONS(1541),
    [anon_sym_LBRACE] = ACTIONS(2831),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1545),
    [anon_sym_TILDE] = ACTIONS(1545),
    [anon_sym_PLUS_PLUS] = ACTIONS(1545),
    [anon_sym_DASH_DASH] = ACTIONS(1545),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1543),
    [anon_sym_DASH] = ACTIONS(1543),
    [anon_sym_STAR] = ACTIONS(1547),
    [anon_sym_CARET] = ACTIONS(1545),
    [anon_sym_AMP] = ACTIONS(1545),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1549),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1551),
    [anon_sym_DOT_DOT] = ACTIONS(1553),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [742] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4218),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7014),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6010),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4335),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7428),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9866),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(742),
    [sym_preproc_endregion] = STATE(742),
    [sym_preproc_line] = STATE(742),
    [sym_preproc_pragma] = STATE(742),
    [sym_preproc_nullable] = STATE(742),
    [sym_preproc_error] = STATE(742),
    [sym_preproc_warning] = STATE(742),
    [sym_preproc_define] = STATE(742),
    [sym_preproc_undef] = STATE(742),
    [aux_sym_class_declaration_repeat1] = STATE(3824),
    [aux_sym_lambda_expression_repeat1] = STATE(4242),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1539),
    [anon_sym_ref] = ACTIONS(1541),
    [anon_sym_LBRACE] = ACTIONS(2831),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1545),
    [anon_sym_TILDE] = ACTIONS(1545),
    [anon_sym_PLUS_PLUS] = ACTIONS(1545),
    [anon_sym_DASH_DASH] = ACTIONS(1545),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1543),
    [anon_sym_DASH] = ACTIONS(1543),
    [anon_sym_STAR] = ACTIONS(1547),
    [anon_sym_CARET] = ACTIONS(1545),
    [anon_sym_AMP] = ACTIONS(1545),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1549),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1551),
    [anon_sym_DOT_DOT] = ACTIONS(1553),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [743] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4101),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7014),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6012),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4335),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7428),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9866),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(743),
    [sym_preproc_endregion] = STATE(743),
    [sym_preproc_line] = STATE(743),
    [sym_preproc_pragma] = STATE(743),
    [sym_preproc_nullable] = STATE(743),
    [sym_preproc_error] = STATE(743),
    [sym_preproc_warning] = STATE(743),
    [sym_preproc_define] = STATE(743),
    [sym_preproc_undef] = STATE(743),
    [aux_sym_class_declaration_repeat1] = STATE(3824),
    [aux_sym_lambda_expression_repeat1] = STATE(4242),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1539),
    [anon_sym_ref] = ACTIONS(1541),
    [anon_sym_LBRACE] = ACTIONS(2831),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1545),
    [anon_sym_TILDE] = ACTIONS(1545),
    [anon_sym_PLUS_PLUS] = ACTIONS(1545),
    [anon_sym_DASH_DASH] = ACTIONS(1545),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1543),
    [anon_sym_DASH] = ACTIONS(1543),
    [anon_sym_STAR] = ACTIONS(1547),
    [anon_sym_CARET] = ACTIONS(1545),
    [anon_sym_AMP] = ACTIONS(1545),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1549),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1551),
    [anon_sym_DOT_DOT] = ACTIONS(1553),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [744] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4102),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7014),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6013),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4335),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7428),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9866),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(744),
    [sym_preproc_endregion] = STATE(744),
    [sym_preproc_line] = STATE(744),
    [sym_preproc_pragma] = STATE(744),
    [sym_preproc_nullable] = STATE(744),
    [sym_preproc_error] = STATE(744),
    [sym_preproc_warning] = STATE(744),
    [sym_preproc_define] = STATE(744),
    [sym_preproc_undef] = STATE(744),
    [aux_sym_class_declaration_repeat1] = STATE(3824),
    [aux_sym_lambda_expression_repeat1] = STATE(4242),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1539),
    [anon_sym_ref] = ACTIONS(1541),
    [anon_sym_LBRACE] = ACTIONS(2831),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1545),
    [anon_sym_TILDE] = ACTIONS(1545),
    [anon_sym_PLUS_PLUS] = ACTIONS(1545),
    [anon_sym_DASH_DASH] = ACTIONS(1545),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1543),
    [anon_sym_DASH] = ACTIONS(1543),
    [anon_sym_STAR] = ACTIONS(1547),
    [anon_sym_CARET] = ACTIONS(1545),
    [anon_sym_AMP] = ACTIONS(1545),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1549),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1551),
    [anon_sym_DOT_DOT] = ACTIONS(1553),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [745] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4111),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7014),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6014),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4335),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7428),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9866),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(745),
    [sym_preproc_endregion] = STATE(745),
    [sym_preproc_line] = STATE(745),
    [sym_preproc_pragma] = STATE(745),
    [sym_preproc_nullable] = STATE(745),
    [sym_preproc_error] = STATE(745),
    [sym_preproc_warning] = STATE(745),
    [sym_preproc_define] = STATE(745),
    [sym_preproc_undef] = STATE(745),
    [aux_sym_class_declaration_repeat1] = STATE(3824),
    [aux_sym_lambda_expression_repeat1] = STATE(4242),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1539),
    [anon_sym_ref] = ACTIONS(1541),
    [anon_sym_LBRACE] = ACTIONS(2831),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1545),
    [anon_sym_TILDE] = ACTIONS(1545),
    [anon_sym_PLUS_PLUS] = ACTIONS(1545),
    [anon_sym_DASH_DASH] = ACTIONS(1545),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1543),
    [anon_sym_DASH] = ACTIONS(1543),
    [anon_sym_STAR] = ACTIONS(1547),
    [anon_sym_CARET] = ACTIONS(1545),
    [anon_sym_AMP] = ACTIONS(1545),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1549),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1551),
    [anon_sym_DOT_DOT] = ACTIONS(1553),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [746] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6731),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5652),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(746),
    [sym_preproc_endregion] = STATE(746),
    [sym_preproc_line] = STATE(746),
    [sym_preproc_pragma] = STATE(746),
    [sym_preproc_nullable] = STATE(746),
    [sym_preproc_error] = STATE(746),
    [sym_preproc_warning] = STATE(746),
    [sym_preproc_define] = STATE(746),
    [sym_preproc_undef] = STATE(746),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(2671),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(2833),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2319),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2607),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [747] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3692),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6916),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7128),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4934),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3752),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7413),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9092),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(747),
    [sym_preproc_endregion] = STATE(747),
    [sym_preproc_line] = STATE(747),
    [sym_preproc_pragma] = STATE(747),
    [sym_preproc_nullable] = STATE(747),
    [sym_preproc_error] = STATE(747),
    [sym_preproc_warning] = STATE(747),
    [sym_preproc_define] = STATE(747),
    [sym_preproc_undef] = STATE(747),
    [aux_sym_class_declaration_repeat1] = STATE(3845),
    [aux_sym_lambda_expression_repeat1] = STATE(4181),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1241),
    [anon_sym_ref] = ACTIONS(1243),
    [anon_sym_LBRACE] = ACTIONS(2825),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1255),
    [anon_sym_TILDE] = ACTIONS(1255),
    [anon_sym_PLUS_PLUS] = ACTIONS(1255),
    [anon_sym_DASH_DASH] = ACTIONS(1255),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1253),
    [anon_sym_DASH] = ACTIONS(1253),
    [anon_sym_STAR] = ACTIONS(1259),
    [anon_sym_CARET] = ACTIONS(1255),
    [anon_sym_AMP] = ACTIONS(1255),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1269),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1271),
    [anon_sym_DOT_DOT] = ACTIONS(1273),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [748] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3991),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6910),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2960),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7091),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5666),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4208),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7438),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9067),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(748),
    [sym_preproc_endregion] = STATE(748),
    [sym_preproc_line] = STATE(748),
    [sym_preproc_pragma] = STATE(748),
    [sym_preproc_nullable] = STATE(748),
    [sym_preproc_error] = STATE(748),
    [sym_preproc_warning] = STATE(748),
    [sym_preproc_define] = STATE(748),
    [sym_preproc_undef] = STATE(748),
    [aux_sym_class_declaration_repeat1] = STATE(3847),
    [aux_sym_lambda_expression_repeat1] = STATE(4280),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1819),
    [anon_sym_ref] = ACTIONS(1821),
    [anon_sym_LBRACE] = ACTIONS(2835),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1823),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1827),
    [anon_sym_TILDE] = ACTIONS(1827),
    [anon_sym_PLUS_PLUS] = ACTIONS(1827),
    [anon_sym_DASH_DASH] = ACTIONS(1827),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1825),
    [anon_sym_DASH] = ACTIONS(1825),
    [anon_sym_STAR] = ACTIONS(1829),
    [anon_sym_CARET] = ACTIONS(1827),
    [anon_sym_AMP] = ACTIONS(1827),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1831),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1833),
    [anon_sym_DOT_DOT] = ACTIONS(1835),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [749] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4028),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6910),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2960),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7091),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5667),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4208),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7438),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9067),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(749),
    [sym_preproc_endregion] = STATE(749),
    [sym_preproc_line] = STATE(749),
    [sym_preproc_pragma] = STATE(749),
    [sym_preproc_nullable] = STATE(749),
    [sym_preproc_error] = STATE(749),
    [sym_preproc_warning] = STATE(749),
    [sym_preproc_define] = STATE(749),
    [sym_preproc_undef] = STATE(749),
    [aux_sym_class_declaration_repeat1] = STATE(3847),
    [aux_sym_lambda_expression_repeat1] = STATE(4280),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1819),
    [anon_sym_ref] = ACTIONS(1821),
    [anon_sym_LBRACE] = ACTIONS(2835),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1823),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1827),
    [anon_sym_TILDE] = ACTIONS(1827),
    [anon_sym_PLUS_PLUS] = ACTIONS(1827),
    [anon_sym_DASH_DASH] = ACTIONS(1827),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1825),
    [anon_sym_DASH] = ACTIONS(1825),
    [anon_sym_STAR] = ACTIONS(1829),
    [anon_sym_CARET] = ACTIONS(1827),
    [anon_sym_AMP] = ACTIONS(1827),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1831),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1833),
    [anon_sym_DOT_DOT] = ACTIONS(1835),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [750] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3764),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7105),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5956),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(750),
    [sym_preproc_endregion] = STATE(750),
    [sym_preproc_line] = STATE(750),
    [sym_preproc_pragma] = STATE(750),
    [sym_preproc_nullable] = STATE(750),
    [sym_preproc_error] = STATE(750),
    [sym_preproc_warning] = STATE(750),
    [sym_preproc_define] = STATE(750),
    [sym_preproc_undef] = STATE(750),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [751] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4030),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6910),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2960),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7091),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5668),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4208),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7438),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9067),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(751),
    [sym_preproc_endregion] = STATE(751),
    [sym_preproc_line] = STATE(751),
    [sym_preproc_pragma] = STATE(751),
    [sym_preproc_nullable] = STATE(751),
    [sym_preproc_error] = STATE(751),
    [sym_preproc_warning] = STATE(751),
    [sym_preproc_define] = STATE(751),
    [sym_preproc_undef] = STATE(751),
    [aux_sym_class_declaration_repeat1] = STATE(3847),
    [aux_sym_lambda_expression_repeat1] = STATE(4280),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1819),
    [anon_sym_ref] = ACTIONS(1821),
    [anon_sym_LBRACE] = ACTIONS(2835),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1823),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1827),
    [anon_sym_TILDE] = ACTIONS(1827),
    [anon_sym_PLUS_PLUS] = ACTIONS(1827),
    [anon_sym_DASH_DASH] = ACTIONS(1827),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1825),
    [anon_sym_DASH] = ACTIONS(1825),
    [anon_sym_STAR] = ACTIONS(1829),
    [anon_sym_CARET] = ACTIONS(1827),
    [anon_sym_AMP] = ACTIONS(1827),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1831),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1833),
    [anon_sym_DOT_DOT] = ACTIONS(1835),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [752] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3219),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2760),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(2855),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_expression] = STATE(6045),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2776),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(752),
    [sym_preproc_endregion] = STATE(752),
    [sym_preproc_line] = STATE(752),
    [sym_preproc_pragma] = STATE(752),
    [sym_preproc_nullable] = STATE(752),
    [sym_preproc_error] = STATE(752),
    [sym_preproc_warning] = STATE(752),
    [sym_preproc_define] = STATE(752),
    [sym_preproc_undef] = STATE(752),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2839),
    [anon_sym_ref] = ACTIONS(2447),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(2841),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2453),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2843),
    [sym_predefined_type] = ACTIONS(2339),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [753] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6031),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(753),
    [sym_preproc_endregion] = STATE(753),
    [sym_preproc_line] = STATE(753),
    [sym_preproc_pragma] = STATE(753),
    [sym_preproc_nullable] = STATE(753),
    [sym_preproc_error] = STATE(753),
    [sym_preproc_warning] = STATE(753),
    [sym_preproc_define] = STATE(753),
    [sym_preproc_undef] = STATE(753),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2845),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [754] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4005),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6910),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2960),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7091),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5670),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4208),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7438),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9067),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(754),
    [sym_preproc_endregion] = STATE(754),
    [sym_preproc_line] = STATE(754),
    [sym_preproc_pragma] = STATE(754),
    [sym_preproc_nullable] = STATE(754),
    [sym_preproc_error] = STATE(754),
    [sym_preproc_warning] = STATE(754),
    [sym_preproc_define] = STATE(754),
    [sym_preproc_undef] = STATE(754),
    [aux_sym_class_declaration_repeat1] = STATE(3847),
    [aux_sym_lambda_expression_repeat1] = STATE(4280),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1819),
    [anon_sym_ref] = ACTIONS(1821),
    [anon_sym_LBRACE] = ACTIONS(2835),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1823),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1827),
    [anon_sym_TILDE] = ACTIONS(1827),
    [anon_sym_PLUS_PLUS] = ACTIONS(1827),
    [anon_sym_DASH_DASH] = ACTIONS(1827),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1825),
    [anon_sym_DASH] = ACTIONS(1825),
    [anon_sym_STAR] = ACTIONS(1829),
    [anon_sym_CARET] = ACTIONS(1827),
    [anon_sym_AMP] = ACTIONS(1827),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1831),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1833),
    [anon_sym_DOT_DOT] = ACTIONS(1835),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [755] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4021),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6910),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2960),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7091),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5671),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4208),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7438),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9067),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(755),
    [sym_preproc_endregion] = STATE(755),
    [sym_preproc_line] = STATE(755),
    [sym_preproc_pragma] = STATE(755),
    [sym_preproc_nullable] = STATE(755),
    [sym_preproc_error] = STATE(755),
    [sym_preproc_warning] = STATE(755),
    [sym_preproc_define] = STATE(755),
    [sym_preproc_undef] = STATE(755),
    [aux_sym_class_declaration_repeat1] = STATE(3847),
    [aux_sym_lambda_expression_repeat1] = STATE(4280),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1819),
    [anon_sym_ref] = ACTIONS(1821),
    [anon_sym_LBRACE] = ACTIONS(2835),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1823),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1827),
    [anon_sym_TILDE] = ACTIONS(1827),
    [anon_sym_PLUS_PLUS] = ACTIONS(1827),
    [anon_sym_DASH_DASH] = ACTIONS(1827),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1825),
    [anon_sym_DASH] = ACTIONS(1825),
    [anon_sym_STAR] = ACTIONS(1829),
    [anon_sym_CARET] = ACTIONS(1827),
    [anon_sym_AMP] = ACTIONS(1827),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1831),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1833),
    [anon_sym_DOT_DOT] = ACTIONS(1835),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [756] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4060),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6910),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2960),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7091),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5672),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4208),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7438),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9067),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(756),
    [sym_preproc_endregion] = STATE(756),
    [sym_preproc_line] = STATE(756),
    [sym_preproc_pragma] = STATE(756),
    [sym_preproc_nullable] = STATE(756),
    [sym_preproc_error] = STATE(756),
    [sym_preproc_warning] = STATE(756),
    [sym_preproc_define] = STATE(756),
    [sym_preproc_undef] = STATE(756),
    [aux_sym_class_declaration_repeat1] = STATE(3847),
    [aux_sym_lambda_expression_repeat1] = STATE(4280),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1819),
    [anon_sym_ref] = ACTIONS(1821),
    [anon_sym_LBRACE] = ACTIONS(2835),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1823),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1827),
    [anon_sym_TILDE] = ACTIONS(1827),
    [anon_sym_PLUS_PLUS] = ACTIONS(1827),
    [anon_sym_DASH_DASH] = ACTIONS(1827),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1825),
    [anon_sym_DASH] = ACTIONS(1825),
    [anon_sym_STAR] = ACTIONS(1829),
    [anon_sym_CARET] = ACTIONS(1827),
    [anon_sym_AMP] = ACTIONS(1827),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1831),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1833),
    [anon_sym_DOT_DOT] = ACTIONS(1835),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [757] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7015),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6015),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4335),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7428),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9866),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(757),
    [sym_preproc_endregion] = STATE(757),
    [sym_preproc_line] = STATE(757),
    [sym_preproc_pragma] = STATE(757),
    [sym_preproc_nullable] = STATE(757),
    [sym_preproc_error] = STATE(757),
    [sym_preproc_warning] = STATE(757),
    [sym_preproc_define] = STATE(757),
    [sym_preproc_undef] = STATE(757),
    [aux_sym_class_declaration_repeat1] = STATE(3824),
    [aux_sym_lambda_expression_repeat1] = STATE(4242),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1539),
    [anon_sym_ref] = ACTIONS(1541),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_readonly] = ACTIONS(2767),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1545),
    [anon_sym_TILDE] = ACTIONS(1545),
    [anon_sym_PLUS_PLUS] = ACTIONS(1545),
    [anon_sym_DASH_DASH] = ACTIONS(1545),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1543),
    [anon_sym_DASH] = ACTIONS(1543),
    [anon_sym_STAR] = ACTIONS(1547),
    [anon_sym_CARET] = ACTIONS(1545),
    [anon_sym_AMP] = ACTIONS(1545),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1549),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1551),
    [anon_sym_DOT_DOT] = ACTIONS(1553),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [758] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6910),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2960),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7092),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5673),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4208),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7438),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9067),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(758),
    [sym_preproc_endregion] = STATE(758),
    [sym_preproc_line] = STATE(758),
    [sym_preproc_pragma] = STATE(758),
    [sym_preproc_nullable] = STATE(758),
    [sym_preproc_error] = STATE(758),
    [sym_preproc_warning] = STATE(758),
    [sym_preproc_define] = STATE(758),
    [sym_preproc_undef] = STATE(758),
    [aux_sym_class_declaration_repeat1] = STATE(3847),
    [aux_sym_lambda_expression_repeat1] = STATE(4280),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1819),
    [anon_sym_ref] = ACTIONS(1821),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1823),
    [anon_sym_readonly] = ACTIONS(2767),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1827),
    [anon_sym_TILDE] = ACTIONS(1827),
    [anon_sym_PLUS_PLUS] = ACTIONS(1827),
    [anon_sym_DASH_DASH] = ACTIONS(1827),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1825),
    [anon_sym_DASH] = ACTIONS(1825),
    [anon_sym_STAR] = ACTIONS(1829),
    [anon_sym_CARET] = ACTIONS(1827),
    [anon_sym_AMP] = ACTIONS(1827),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1831),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1833),
    [anon_sym_DOT_DOT] = ACTIONS(1835),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [759] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3708),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6916),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7128),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4893),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3752),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7413),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9092),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(759),
    [sym_preproc_endregion] = STATE(759),
    [sym_preproc_line] = STATE(759),
    [sym_preproc_pragma] = STATE(759),
    [sym_preproc_nullable] = STATE(759),
    [sym_preproc_error] = STATE(759),
    [sym_preproc_warning] = STATE(759),
    [sym_preproc_define] = STATE(759),
    [sym_preproc_undef] = STATE(759),
    [aux_sym_class_declaration_repeat1] = STATE(3845),
    [aux_sym_lambda_expression_repeat1] = STATE(4181),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1241),
    [anon_sym_ref] = ACTIONS(1243),
    [anon_sym_LBRACE] = ACTIONS(2825),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1255),
    [anon_sym_TILDE] = ACTIONS(1255),
    [anon_sym_PLUS_PLUS] = ACTIONS(1255),
    [anon_sym_DASH_DASH] = ACTIONS(1255),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1253),
    [anon_sym_DASH] = ACTIONS(1253),
    [anon_sym_STAR] = ACTIONS(1259),
    [anon_sym_CARET] = ACTIONS(1255),
    [anon_sym_AMP] = ACTIONS(1255),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1269),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1271),
    [anon_sym_DOT_DOT] = ACTIONS(1273),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [760] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4643),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6925),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2932),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6992),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4588),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3702),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7420),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9634),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(760),
    [sym_preproc_endregion] = STATE(760),
    [sym_preproc_line] = STATE(760),
    [sym_preproc_pragma] = STATE(760),
    [sym_preproc_nullable] = STATE(760),
    [sym_preproc_error] = STATE(760),
    [sym_preproc_warning] = STATE(760),
    [sym_preproc_define] = STATE(760),
    [sym_preproc_undef] = STATE(760),
    [aux_sym_class_declaration_repeat1] = STATE(3819),
    [aux_sym_lambda_expression_repeat1] = STATE(4232),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1995),
    [anon_sym_ref] = ACTIONS(1997),
    [anon_sym_LBRACE] = ACTIONS(2847),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1771),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(2001),
    [anon_sym_TILDE] = ACTIONS(2001),
    [anon_sym_PLUS_PLUS] = ACTIONS(2001),
    [anon_sym_DASH_DASH] = ACTIONS(2001),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1999),
    [anon_sym_DASH] = ACTIONS(1999),
    [anon_sym_STAR] = ACTIONS(1777),
    [anon_sym_CARET] = ACTIONS(2001),
    [anon_sym_AMP] = ACTIONS(2001),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(2003),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2005),
    [anon_sym_DOT_DOT] = ACTIONS(2007),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [761] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4708),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6925),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2932),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6992),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4589),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3702),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7420),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9634),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(761),
    [sym_preproc_endregion] = STATE(761),
    [sym_preproc_line] = STATE(761),
    [sym_preproc_pragma] = STATE(761),
    [sym_preproc_nullable] = STATE(761),
    [sym_preproc_error] = STATE(761),
    [sym_preproc_warning] = STATE(761),
    [sym_preproc_define] = STATE(761),
    [sym_preproc_undef] = STATE(761),
    [aux_sym_class_declaration_repeat1] = STATE(3819),
    [aux_sym_lambda_expression_repeat1] = STATE(4232),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1995),
    [anon_sym_ref] = ACTIONS(1997),
    [anon_sym_LBRACE] = ACTIONS(2847),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1771),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(2001),
    [anon_sym_TILDE] = ACTIONS(2001),
    [anon_sym_PLUS_PLUS] = ACTIONS(2001),
    [anon_sym_DASH_DASH] = ACTIONS(2001),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1999),
    [anon_sym_DASH] = ACTIONS(1999),
    [anon_sym_STAR] = ACTIONS(1777),
    [anon_sym_CARET] = ACTIONS(2001),
    [anon_sym_AMP] = ACTIONS(2001),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(2003),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2005),
    [anon_sym_DOT_DOT] = ACTIONS(2007),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [762] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6743),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5726),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4216),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9065),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(762),
    [sym_preproc_endregion] = STATE(762),
    [sym_preproc_line] = STATE(762),
    [sym_preproc_pragma] = STATE(762),
    [sym_preproc_nullable] = STATE(762),
    [sym_preproc_error] = STATE(762),
    [sym_preproc_warning] = STATE(762),
    [sym_preproc_define] = STATE(762),
    [sym_preproc_undef] = STATE(762),
    [aux_sym_class_declaration_repeat1] = STATE(3874),
    [aux_sym_lambda_expression_repeat1] = STATE(4311),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1531),
    [anon_sym_ref] = ACTIONS(1533),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_readonly] = ACTIONS(2767),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1537),
    [anon_sym_TILDE] = ACTIONS(1537),
    [anon_sym_PLUS_PLUS] = ACTIONS(1537),
    [anon_sym_DASH_DASH] = ACTIONS(1537),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1535),
    [anon_sym_DASH] = ACTIONS(1535),
    [anon_sym_STAR] = ACTIONS(1121),
    [anon_sym_CARET] = ACTIONS(1537),
    [anon_sym_AMP] = ACTIONS(1537),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1129),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1131),
    [anon_sym_DOT_DOT] = ACTIONS(1135),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [763] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4719),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6925),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2932),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6992),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4598),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3702),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7420),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9634),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(763),
    [sym_preproc_endregion] = STATE(763),
    [sym_preproc_line] = STATE(763),
    [sym_preproc_pragma] = STATE(763),
    [sym_preproc_nullable] = STATE(763),
    [sym_preproc_error] = STATE(763),
    [sym_preproc_warning] = STATE(763),
    [sym_preproc_define] = STATE(763),
    [sym_preproc_undef] = STATE(763),
    [aux_sym_class_declaration_repeat1] = STATE(3819),
    [aux_sym_lambda_expression_repeat1] = STATE(4232),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1995),
    [anon_sym_ref] = ACTIONS(1997),
    [anon_sym_LBRACE] = ACTIONS(2847),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1771),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(2001),
    [anon_sym_TILDE] = ACTIONS(2001),
    [anon_sym_PLUS_PLUS] = ACTIONS(2001),
    [anon_sym_DASH_DASH] = ACTIONS(2001),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1999),
    [anon_sym_DASH] = ACTIONS(1999),
    [anon_sym_STAR] = ACTIONS(1777),
    [anon_sym_CARET] = ACTIONS(2001),
    [anon_sym_AMP] = ACTIONS(2001),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(2003),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2005),
    [anon_sym_DOT_DOT] = ACTIONS(2007),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [764] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6913),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2905),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6980),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5458),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4178),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7433),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9183),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(764),
    [sym_preproc_endregion] = STATE(764),
    [sym_preproc_line] = STATE(764),
    [sym_preproc_pragma] = STATE(764),
    [sym_preproc_nullable] = STATE(764),
    [sym_preproc_error] = STATE(764),
    [sym_preproc_warning] = STATE(764),
    [sym_preproc_define] = STATE(764),
    [sym_preproc_undef] = STATE(764),
    [aux_sym_class_declaration_repeat1] = STATE(3816),
    [aux_sym_lambda_expression_repeat1] = STATE(4225),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1573),
    [anon_sym_ref] = ACTIONS(1575),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1577),
    [anon_sym_readonly] = ACTIONS(2767),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1581),
    [anon_sym_TILDE] = ACTIONS(1581),
    [anon_sym_PLUS_PLUS] = ACTIONS(1581),
    [anon_sym_DASH_DASH] = ACTIONS(1581),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1579),
    [anon_sym_DASH] = ACTIONS(1579),
    [anon_sym_STAR] = ACTIONS(1583),
    [anon_sym_CARET] = ACTIONS(1581),
    [anon_sym_AMP] = ACTIONS(1581),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1585),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1587),
    [anon_sym_DOT_DOT] = ACTIONS(1589),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [765] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6950),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7045),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5137),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3868),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7432),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9127),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(765),
    [sym_preproc_endregion] = STATE(765),
    [sym_preproc_line] = STATE(765),
    [sym_preproc_pragma] = STATE(765),
    [sym_preproc_nullable] = STATE(765),
    [sym_preproc_error] = STATE(765),
    [sym_preproc_warning] = STATE(765),
    [sym_preproc_define] = STATE(765),
    [sym_preproc_undef] = STATE(765),
    [aux_sym_class_declaration_repeat1] = STATE(3832),
    [aux_sym_lambda_expression_repeat1] = STATE(4259),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1357),
    [anon_sym_ref] = ACTIONS(1359),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_readonly] = ACTIONS(2767),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1363),
    [anon_sym_TILDE] = ACTIONS(1363),
    [anon_sym_PLUS_PLUS] = ACTIONS(1363),
    [anon_sym_DASH_DASH] = ACTIONS(1363),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1361),
    [anon_sym_DASH] = ACTIONS(1361),
    [anon_sym_STAR] = ACTIONS(1365),
    [anon_sym_CARET] = ACTIONS(1363),
    [anon_sym_AMP] = ACTIONS(1363),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1367),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1369),
    [anon_sym_DOT_DOT] = ACTIONS(1371),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [766] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4677),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6925),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2932),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6992),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4600),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3702),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7420),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9634),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(766),
    [sym_preproc_endregion] = STATE(766),
    [sym_preproc_line] = STATE(766),
    [sym_preproc_pragma] = STATE(766),
    [sym_preproc_nullable] = STATE(766),
    [sym_preproc_error] = STATE(766),
    [sym_preproc_warning] = STATE(766),
    [sym_preproc_define] = STATE(766),
    [sym_preproc_undef] = STATE(766),
    [aux_sym_class_declaration_repeat1] = STATE(3819),
    [aux_sym_lambda_expression_repeat1] = STATE(4232),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1995),
    [anon_sym_ref] = ACTIONS(1997),
    [anon_sym_LBRACE] = ACTIONS(2847),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1771),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(2001),
    [anon_sym_TILDE] = ACTIONS(2001),
    [anon_sym_PLUS_PLUS] = ACTIONS(2001),
    [anon_sym_DASH_DASH] = ACTIONS(2001),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1999),
    [anon_sym_DASH] = ACTIONS(1999),
    [anon_sym_STAR] = ACTIONS(1777),
    [anon_sym_CARET] = ACTIONS(2001),
    [anon_sym_AMP] = ACTIONS(2001),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(2003),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2005),
    [anon_sym_DOT_DOT] = ACTIONS(2007),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [767] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4671),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6925),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2932),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6992),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4546),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3702),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7420),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9634),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(767),
    [sym_preproc_endregion] = STATE(767),
    [sym_preproc_line] = STATE(767),
    [sym_preproc_pragma] = STATE(767),
    [sym_preproc_nullable] = STATE(767),
    [sym_preproc_error] = STATE(767),
    [sym_preproc_warning] = STATE(767),
    [sym_preproc_define] = STATE(767),
    [sym_preproc_undef] = STATE(767),
    [aux_sym_class_declaration_repeat1] = STATE(3819),
    [aux_sym_lambda_expression_repeat1] = STATE(4232),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1995),
    [anon_sym_ref] = ACTIONS(1997),
    [anon_sym_LBRACE] = ACTIONS(2847),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1771),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(2001),
    [anon_sym_TILDE] = ACTIONS(2001),
    [anon_sym_PLUS_PLUS] = ACTIONS(2001),
    [anon_sym_DASH_DASH] = ACTIONS(2001),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1999),
    [anon_sym_DASH] = ACTIONS(1999),
    [anon_sym_STAR] = ACTIONS(1777),
    [anon_sym_CARET] = ACTIONS(2001),
    [anon_sym_AMP] = ACTIONS(2001),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(2003),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2005),
    [anon_sym_DOT_DOT] = ACTIONS(2007),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [768] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3763),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7147),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5522),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4216),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9065),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(768),
    [sym_preproc_endregion] = STATE(768),
    [sym_preproc_line] = STATE(768),
    [sym_preproc_pragma] = STATE(768),
    [sym_preproc_nullable] = STATE(768),
    [sym_preproc_error] = STATE(768),
    [sym_preproc_warning] = STATE(768),
    [sym_preproc_define] = STATE(768),
    [sym_preproc_undef] = STATE(768),
    [aux_sym_class_declaration_repeat1] = STATE(3874),
    [aux_sym_lambda_expression_repeat1] = STATE(4311),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1531),
    [anon_sym_ref] = ACTIONS(1533),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1537),
    [anon_sym_TILDE] = ACTIONS(1537),
    [anon_sym_PLUS_PLUS] = ACTIONS(1537),
    [anon_sym_DASH_DASH] = ACTIONS(1537),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1535),
    [anon_sym_DASH] = ACTIONS(1535),
    [anon_sym_STAR] = ACTIONS(1121),
    [anon_sym_CARET] = ACTIONS(1537),
    [anon_sym_AMP] = ACTIONS(1537),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1129),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1131),
    [anon_sym_DOT_DOT] = ACTIONS(1135),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [769] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3764),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7147),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5523),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4216),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9065),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(769),
    [sym_preproc_endregion] = STATE(769),
    [sym_preproc_line] = STATE(769),
    [sym_preproc_pragma] = STATE(769),
    [sym_preproc_nullable] = STATE(769),
    [sym_preproc_error] = STATE(769),
    [sym_preproc_warning] = STATE(769),
    [sym_preproc_define] = STATE(769),
    [sym_preproc_undef] = STATE(769),
    [aux_sym_class_declaration_repeat1] = STATE(3874),
    [aux_sym_lambda_expression_repeat1] = STATE(4311),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1531),
    [anon_sym_ref] = ACTIONS(1533),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1537),
    [anon_sym_TILDE] = ACTIONS(1537),
    [anon_sym_PLUS_PLUS] = ACTIONS(1537),
    [anon_sym_DASH_DASH] = ACTIONS(1537),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1535),
    [anon_sym_DASH] = ACTIONS(1535),
    [anon_sym_STAR] = ACTIONS(1121),
    [anon_sym_CARET] = ACTIONS(1537),
    [anon_sym_AMP] = ACTIONS(1537),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1129),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1131),
    [anon_sym_DOT_DOT] = ACTIONS(1135),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [770] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4676),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6925),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2932),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6992),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4601),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3702),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7420),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9634),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(770),
    [sym_preproc_endregion] = STATE(770),
    [sym_preproc_line] = STATE(770),
    [sym_preproc_pragma] = STATE(770),
    [sym_preproc_nullable] = STATE(770),
    [sym_preproc_error] = STATE(770),
    [sym_preproc_warning] = STATE(770),
    [sym_preproc_define] = STATE(770),
    [sym_preproc_undef] = STATE(770),
    [aux_sym_class_declaration_repeat1] = STATE(3819),
    [aux_sym_lambda_expression_repeat1] = STATE(4232),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1995),
    [anon_sym_ref] = ACTIONS(1997),
    [anon_sym_LBRACE] = ACTIONS(2847),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1771),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(2001),
    [anon_sym_TILDE] = ACTIONS(2001),
    [anon_sym_PLUS_PLUS] = ACTIONS(2001),
    [anon_sym_DASH_DASH] = ACTIONS(2001),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1999),
    [anon_sym_DASH] = ACTIONS(1999),
    [anon_sym_STAR] = ACTIONS(1777),
    [anon_sym_CARET] = ACTIONS(2001),
    [anon_sym_AMP] = ACTIONS(2001),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(2003),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2005),
    [anon_sym_DOT_DOT] = ACTIONS(2007),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [771] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6032),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(771),
    [sym_preproc_endregion] = STATE(771),
    [sym_preproc_line] = STATE(771),
    [sym_preproc_pragma] = STATE(771),
    [sym_preproc_nullable] = STATE(771),
    [sym_preproc_error] = STATE(771),
    [sym_preproc_warning] = STATE(771),
    [sym_preproc_define] = STATE(771),
    [sym_preproc_undef] = STATE(771),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2849),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [772] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3780),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7147),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5524),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4216),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9065),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(772),
    [sym_preproc_endregion] = STATE(772),
    [sym_preproc_line] = STATE(772),
    [sym_preproc_pragma] = STATE(772),
    [sym_preproc_nullable] = STATE(772),
    [sym_preproc_error] = STATE(772),
    [sym_preproc_warning] = STATE(772),
    [sym_preproc_define] = STATE(772),
    [sym_preproc_undef] = STATE(772),
    [aux_sym_class_declaration_repeat1] = STATE(3874),
    [aux_sym_lambda_expression_repeat1] = STATE(4311),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1531),
    [anon_sym_ref] = ACTIONS(1533),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1537),
    [anon_sym_TILDE] = ACTIONS(1537),
    [anon_sym_PLUS_PLUS] = ACTIONS(1537),
    [anon_sym_DASH_DASH] = ACTIONS(1537),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1535),
    [anon_sym_DASH] = ACTIONS(1535),
    [anon_sym_STAR] = ACTIONS(1121),
    [anon_sym_CARET] = ACTIONS(1537),
    [anon_sym_AMP] = ACTIONS(1537),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1129),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1131),
    [anon_sym_DOT_DOT] = ACTIONS(1135),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [773] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5992),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(773),
    [sym_preproc_endregion] = STATE(773),
    [sym_preproc_line] = STATE(773),
    [sym_preproc_pragma] = STATE(773),
    [sym_preproc_nullable] = STATE(773),
    [sym_preproc_error] = STATE(773),
    [sym_preproc_warning] = STATE(773),
    [sym_preproc_define] = STATE(773),
    [sym_preproc_undef] = STATE(773),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2851),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [774] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5993),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(774),
    [sym_preproc_endregion] = STATE(774),
    [sym_preproc_line] = STATE(774),
    [sym_preproc_pragma] = STATE(774),
    [sym_preproc_nullable] = STATE(774),
    [sym_preproc_error] = STATE(774),
    [sym_preproc_warning] = STATE(774),
    [sym_preproc_define] = STATE(774),
    [sym_preproc_undef] = STATE(774),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2853),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [775] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3735),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7147),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5526),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4216),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9065),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(775),
    [sym_preproc_endregion] = STATE(775),
    [sym_preproc_line] = STATE(775),
    [sym_preproc_pragma] = STATE(775),
    [sym_preproc_nullable] = STATE(775),
    [sym_preproc_error] = STATE(775),
    [sym_preproc_warning] = STATE(775),
    [sym_preproc_define] = STATE(775),
    [sym_preproc_undef] = STATE(775),
    [aux_sym_class_declaration_repeat1] = STATE(3874),
    [aux_sym_lambda_expression_repeat1] = STATE(4311),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1531),
    [anon_sym_ref] = ACTIONS(1533),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1537),
    [anon_sym_TILDE] = ACTIONS(1537),
    [anon_sym_PLUS_PLUS] = ACTIONS(1537),
    [anon_sym_DASH_DASH] = ACTIONS(1537),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1535),
    [anon_sym_DASH] = ACTIONS(1535),
    [anon_sym_STAR] = ACTIONS(1121),
    [anon_sym_CARET] = ACTIONS(1537),
    [anon_sym_AMP] = ACTIONS(1537),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1129),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1131),
    [anon_sym_DOT_DOT] = ACTIONS(1135),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [776] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3741),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7147),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5527),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4216),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9065),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(776),
    [sym_preproc_endregion] = STATE(776),
    [sym_preproc_line] = STATE(776),
    [sym_preproc_pragma] = STATE(776),
    [sym_preproc_nullable] = STATE(776),
    [sym_preproc_error] = STATE(776),
    [sym_preproc_warning] = STATE(776),
    [sym_preproc_define] = STATE(776),
    [sym_preproc_undef] = STATE(776),
    [aux_sym_class_declaration_repeat1] = STATE(3874),
    [aux_sym_lambda_expression_repeat1] = STATE(4311),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1531),
    [anon_sym_ref] = ACTIONS(1533),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1537),
    [anon_sym_TILDE] = ACTIONS(1537),
    [anon_sym_PLUS_PLUS] = ACTIONS(1537),
    [anon_sym_DASH_DASH] = ACTIONS(1537),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1535),
    [anon_sym_DASH] = ACTIONS(1535),
    [anon_sym_STAR] = ACTIONS(1121),
    [anon_sym_CARET] = ACTIONS(1537),
    [anon_sym_AMP] = ACTIONS(1537),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1129),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1131),
    [anon_sym_DOT_DOT] = ACTIONS(1135),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [777] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3754),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7147),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5528),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4216),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9065),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(777),
    [sym_preproc_endregion] = STATE(777),
    [sym_preproc_line] = STATE(777),
    [sym_preproc_pragma] = STATE(777),
    [sym_preproc_nullable] = STATE(777),
    [sym_preproc_error] = STATE(777),
    [sym_preproc_warning] = STATE(777),
    [sym_preproc_define] = STATE(777),
    [sym_preproc_undef] = STATE(777),
    [aux_sym_class_declaration_repeat1] = STATE(3874),
    [aux_sym_lambda_expression_repeat1] = STATE(4311),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1531),
    [anon_sym_ref] = ACTIONS(1533),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1537),
    [anon_sym_TILDE] = ACTIONS(1537),
    [anon_sym_PLUS_PLUS] = ACTIONS(1537),
    [anon_sym_DASH_DASH] = ACTIONS(1537),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1535),
    [anon_sym_DASH] = ACTIONS(1535),
    [anon_sym_STAR] = ACTIONS(1121),
    [anon_sym_CARET] = ACTIONS(1537),
    [anon_sym_AMP] = ACTIONS(1537),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1129),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1131),
    [anon_sym_DOT_DOT] = ACTIONS(1135),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [778] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6221),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2789),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(2855),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6045),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(778),
    [sym_preproc_endregion] = STATE(778),
    [sym_preproc_line] = STATE(778),
    [sym_preproc_pragma] = STATE(778),
    [sym_preproc_nullable] = STATE(778),
    [sym_preproc_error] = STATE(778),
    [sym_preproc_warning] = STATE(778),
    [sym_preproc_define] = STATE(778),
    [sym_preproc_undef] = STATE(778),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_ref] = ACTIONS(2281),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(2739),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(1089),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2727),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [779] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3637),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6918),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6973),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5306),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4069),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7443),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9676),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(779),
    [sym_preproc_endregion] = STATE(779),
    [sym_preproc_line] = STATE(779),
    [sym_preproc_pragma] = STATE(779),
    [sym_preproc_nullable] = STATE(779),
    [sym_preproc_error] = STATE(779),
    [sym_preproc_warning] = STATE(779),
    [sym_preproc_define] = STATE(779),
    [sym_preproc_undef] = STATE(779),
    [aux_sym_class_declaration_repeat1] = STATE(3815),
    [aux_sym_lambda_expression_repeat1] = STATE(4217),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1515),
    [anon_sym_ref] = ACTIONS(1517),
    [anon_sym_LBRACE] = ACTIONS(2825),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1521),
    [anon_sym_TILDE] = ACTIONS(1521),
    [anon_sym_PLUS_PLUS] = ACTIONS(1521),
    [anon_sym_DASH_DASH] = ACTIONS(1521),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1519),
    [anon_sym_DASH] = ACTIONS(1519),
    [anon_sym_STAR] = ACTIONS(1523),
    [anon_sym_CARET] = ACTIONS(1521),
    [anon_sym_AMP] = ACTIONS(1521),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1525),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1527),
    [anon_sym_DOT_DOT] = ACTIONS(1529),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [780] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3714),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6918),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6973),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5397),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4069),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7443),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9676),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(780),
    [sym_preproc_endregion] = STATE(780),
    [sym_preproc_line] = STATE(780),
    [sym_preproc_pragma] = STATE(780),
    [sym_preproc_nullable] = STATE(780),
    [sym_preproc_error] = STATE(780),
    [sym_preproc_warning] = STATE(780),
    [sym_preproc_define] = STATE(780),
    [sym_preproc_undef] = STATE(780),
    [aux_sym_class_declaration_repeat1] = STATE(3815),
    [aux_sym_lambda_expression_repeat1] = STATE(4217),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1515),
    [anon_sym_ref] = ACTIONS(1517),
    [anon_sym_LBRACE] = ACTIONS(2825),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1521),
    [anon_sym_TILDE] = ACTIONS(1521),
    [anon_sym_PLUS_PLUS] = ACTIONS(1521),
    [anon_sym_DASH_DASH] = ACTIONS(1521),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1519),
    [anon_sym_DASH] = ACTIONS(1519),
    [anon_sym_STAR] = ACTIONS(1523),
    [anon_sym_CARET] = ACTIONS(1521),
    [anon_sym_AMP] = ACTIONS(1521),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1525),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1527),
    [anon_sym_DOT_DOT] = ACTIONS(1529),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [781] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3641),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6918),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6973),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5246),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4069),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7443),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9676),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(781),
    [sym_preproc_endregion] = STATE(781),
    [sym_preproc_line] = STATE(781),
    [sym_preproc_pragma] = STATE(781),
    [sym_preproc_nullable] = STATE(781),
    [sym_preproc_error] = STATE(781),
    [sym_preproc_warning] = STATE(781),
    [sym_preproc_define] = STATE(781),
    [sym_preproc_undef] = STATE(781),
    [aux_sym_class_declaration_repeat1] = STATE(3815),
    [aux_sym_lambda_expression_repeat1] = STATE(4217),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1515),
    [anon_sym_ref] = ACTIONS(1517),
    [anon_sym_LBRACE] = ACTIONS(2825),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1521),
    [anon_sym_TILDE] = ACTIONS(1521),
    [anon_sym_PLUS_PLUS] = ACTIONS(1521),
    [anon_sym_DASH_DASH] = ACTIONS(1521),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1519),
    [anon_sym_DASH] = ACTIONS(1519),
    [anon_sym_STAR] = ACTIONS(1523),
    [anon_sym_CARET] = ACTIONS(1521),
    [anon_sym_AMP] = ACTIONS(1521),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1525),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1527),
    [anon_sym_DOT_DOT] = ACTIONS(1529),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [782] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3637),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6916),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7061),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6245),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4369),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7437),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9284),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(782),
    [sym_preproc_endregion] = STATE(782),
    [sym_preproc_line] = STATE(782),
    [sym_preproc_pragma] = STATE(782),
    [sym_preproc_nullable] = STATE(782),
    [sym_preproc_error] = STATE(782),
    [sym_preproc_warning] = STATE(782),
    [sym_preproc_define] = STATE(782),
    [sym_preproc_undef] = STATE(782),
    [aux_sym_class_declaration_repeat1] = STATE(3839),
    [aux_sym_lambda_expression_repeat1] = STATE(4267),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1963),
    [anon_sym_ref] = ACTIONS(1965),
    [anon_sym_LBRACE] = ACTIONS(2825),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1969),
    [anon_sym_TILDE] = ACTIONS(1969),
    [anon_sym_PLUS_PLUS] = ACTIONS(1969),
    [anon_sym_DASH_DASH] = ACTIONS(1969),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1967),
    [anon_sym_DASH] = ACTIONS(1967),
    [anon_sym_STAR] = ACTIONS(1971),
    [anon_sym_CARET] = ACTIONS(1969),
    [anon_sym_AMP] = ACTIONS(1969),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1973),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1975),
    [anon_sym_DOT_DOT] = ACTIONS(1977),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [783] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3714),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6916),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7061),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6246),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4369),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7437),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9284),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(783),
    [sym_preproc_endregion] = STATE(783),
    [sym_preproc_line] = STATE(783),
    [sym_preproc_pragma] = STATE(783),
    [sym_preproc_nullable] = STATE(783),
    [sym_preproc_error] = STATE(783),
    [sym_preproc_warning] = STATE(783),
    [sym_preproc_define] = STATE(783),
    [sym_preproc_undef] = STATE(783),
    [aux_sym_class_declaration_repeat1] = STATE(3839),
    [aux_sym_lambda_expression_repeat1] = STATE(4267),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1963),
    [anon_sym_ref] = ACTIONS(1965),
    [anon_sym_LBRACE] = ACTIONS(2825),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1969),
    [anon_sym_TILDE] = ACTIONS(1969),
    [anon_sym_PLUS_PLUS] = ACTIONS(1969),
    [anon_sym_DASH_DASH] = ACTIONS(1969),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1967),
    [anon_sym_DASH] = ACTIONS(1967),
    [anon_sym_STAR] = ACTIONS(1971),
    [anon_sym_CARET] = ACTIONS(1969),
    [anon_sym_AMP] = ACTIONS(1969),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1973),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1975),
    [anon_sym_DOT_DOT] = ACTIONS(1977),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [784] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3641),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6916),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7061),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6249),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4369),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7437),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9284),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(784),
    [sym_preproc_endregion] = STATE(784),
    [sym_preproc_line] = STATE(784),
    [sym_preproc_pragma] = STATE(784),
    [sym_preproc_nullable] = STATE(784),
    [sym_preproc_error] = STATE(784),
    [sym_preproc_warning] = STATE(784),
    [sym_preproc_define] = STATE(784),
    [sym_preproc_undef] = STATE(784),
    [aux_sym_class_declaration_repeat1] = STATE(3839),
    [aux_sym_lambda_expression_repeat1] = STATE(4267),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1963),
    [anon_sym_ref] = ACTIONS(1965),
    [anon_sym_LBRACE] = ACTIONS(2825),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1969),
    [anon_sym_TILDE] = ACTIONS(1969),
    [anon_sym_PLUS_PLUS] = ACTIONS(1969),
    [anon_sym_DASH_DASH] = ACTIONS(1969),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1967),
    [anon_sym_DASH] = ACTIONS(1967),
    [anon_sym_STAR] = ACTIONS(1971),
    [anon_sym_CARET] = ACTIONS(1969),
    [anon_sym_AMP] = ACTIONS(1969),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1973),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1975),
    [anon_sym_DOT_DOT] = ACTIONS(1977),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [785] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3689),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6916),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7061),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6252),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4369),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7437),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9284),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(785),
    [sym_preproc_endregion] = STATE(785),
    [sym_preproc_line] = STATE(785),
    [sym_preproc_pragma] = STATE(785),
    [sym_preproc_nullable] = STATE(785),
    [sym_preproc_error] = STATE(785),
    [sym_preproc_warning] = STATE(785),
    [sym_preproc_define] = STATE(785),
    [sym_preproc_undef] = STATE(785),
    [aux_sym_class_declaration_repeat1] = STATE(3839),
    [aux_sym_lambda_expression_repeat1] = STATE(4267),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1963),
    [anon_sym_ref] = ACTIONS(1965),
    [anon_sym_LBRACE] = ACTIONS(2825),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1969),
    [anon_sym_TILDE] = ACTIONS(1969),
    [anon_sym_PLUS_PLUS] = ACTIONS(1969),
    [anon_sym_DASH_DASH] = ACTIONS(1969),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1967),
    [anon_sym_DASH] = ACTIONS(1967),
    [anon_sym_STAR] = ACTIONS(1971),
    [anon_sym_CARET] = ACTIONS(1969),
    [anon_sym_AMP] = ACTIONS(1969),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1973),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1975),
    [anon_sym_DOT_DOT] = ACTIONS(1977),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [786] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3692),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6916),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7061),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6253),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4369),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7437),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9284),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(786),
    [sym_preproc_endregion] = STATE(786),
    [sym_preproc_line] = STATE(786),
    [sym_preproc_pragma] = STATE(786),
    [sym_preproc_nullable] = STATE(786),
    [sym_preproc_error] = STATE(786),
    [sym_preproc_warning] = STATE(786),
    [sym_preproc_define] = STATE(786),
    [sym_preproc_undef] = STATE(786),
    [aux_sym_class_declaration_repeat1] = STATE(3839),
    [aux_sym_lambda_expression_repeat1] = STATE(4267),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1963),
    [anon_sym_ref] = ACTIONS(1965),
    [anon_sym_LBRACE] = ACTIONS(2825),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1969),
    [anon_sym_TILDE] = ACTIONS(1969),
    [anon_sym_PLUS_PLUS] = ACTIONS(1969),
    [anon_sym_DASH_DASH] = ACTIONS(1969),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1967),
    [anon_sym_DASH] = ACTIONS(1967),
    [anon_sym_STAR] = ACTIONS(1971),
    [anon_sym_CARET] = ACTIONS(1969),
    [anon_sym_AMP] = ACTIONS(1969),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1973),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1975),
    [anon_sym_DOT_DOT] = ACTIONS(1977),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [787] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3708),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6916),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7061),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6258),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4369),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7437),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9284),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(787),
    [sym_preproc_endregion] = STATE(787),
    [sym_preproc_line] = STATE(787),
    [sym_preproc_pragma] = STATE(787),
    [sym_preproc_nullable] = STATE(787),
    [sym_preproc_error] = STATE(787),
    [sym_preproc_warning] = STATE(787),
    [sym_preproc_define] = STATE(787),
    [sym_preproc_undef] = STATE(787),
    [aux_sym_class_declaration_repeat1] = STATE(3839),
    [aux_sym_lambda_expression_repeat1] = STATE(4267),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1963),
    [anon_sym_ref] = ACTIONS(1965),
    [anon_sym_LBRACE] = ACTIONS(2825),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1969),
    [anon_sym_TILDE] = ACTIONS(1969),
    [anon_sym_PLUS_PLUS] = ACTIONS(1969),
    [anon_sym_DASH_DASH] = ACTIONS(1969),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1967),
    [anon_sym_DASH] = ACTIONS(1967),
    [anon_sym_STAR] = ACTIONS(1971),
    [anon_sym_CARET] = ACTIONS(1969),
    [anon_sym_AMP] = ACTIONS(1969),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1973),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1975),
    [anon_sym_DOT_DOT] = ACTIONS(1977),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [788] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3689),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6918),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6973),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5263),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4069),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7443),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9676),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(788),
    [sym_preproc_endregion] = STATE(788),
    [sym_preproc_line] = STATE(788),
    [sym_preproc_pragma] = STATE(788),
    [sym_preproc_nullable] = STATE(788),
    [sym_preproc_error] = STATE(788),
    [sym_preproc_warning] = STATE(788),
    [sym_preproc_define] = STATE(788),
    [sym_preproc_undef] = STATE(788),
    [aux_sym_class_declaration_repeat1] = STATE(3815),
    [aux_sym_lambda_expression_repeat1] = STATE(4217),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1515),
    [anon_sym_ref] = ACTIONS(1517),
    [anon_sym_LBRACE] = ACTIONS(2825),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1521),
    [anon_sym_TILDE] = ACTIONS(1521),
    [anon_sym_PLUS_PLUS] = ACTIONS(1521),
    [anon_sym_DASH_DASH] = ACTIONS(1521),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1519),
    [anon_sym_DASH] = ACTIONS(1519),
    [anon_sym_STAR] = ACTIONS(1523),
    [anon_sym_CARET] = ACTIONS(1521),
    [anon_sym_AMP] = ACTIONS(1521),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1525),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1527),
    [anon_sym_DOT_DOT] = ACTIONS(1529),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [789] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6916),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7062),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6239),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4369),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7437),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9284),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(789),
    [sym_preproc_endregion] = STATE(789),
    [sym_preproc_line] = STATE(789),
    [sym_preproc_pragma] = STATE(789),
    [sym_preproc_nullable] = STATE(789),
    [sym_preproc_error] = STATE(789),
    [sym_preproc_warning] = STATE(789),
    [sym_preproc_define] = STATE(789),
    [sym_preproc_undef] = STATE(789),
    [aux_sym_class_declaration_repeat1] = STATE(3839),
    [aux_sym_lambda_expression_repeat1] = STATE(4267),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1963),
    [anon_sym_ref] = ACTIONS(1965),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_readonly] = ACTIONS(2767),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1969),
    [anon_sym_TILDE] = ACTIONS(1969),
    [anon_sym_PLUS_PLUS] = ACTIONS(1969),
    [anon_sym_DASH_DASH] = ACTIONS(1969),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1967),
    [anon_sym_DASH] = ACTIONS(1967),
    [anon_sym_STAR] = ACTIONS(1971),
    [anon_sym_CARET] = ACTIONS(1969),
    [anon_sym_AMP] = ACTIONS(1969),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1973),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1975),
    [anon_sym_DOT_DOT] = ACTIONS(1977),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [790] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3692),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6918),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6973),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5281),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4069),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7443),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9676),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(790),
    [sym_preproc_endregion] = STATE(790),
    [sym_preproc_line] = STATE(790),
    [sym_preproc_pragma] = STATE(790),
    [sym_preproc_nullable] = STATE(790),
    [sym_preproc_error] = STATE(790),
    [sym_preproc_warning] = STATE(790),
    [sym_preproc_define] = STATE(790),
    [sym_preproc_undef] = STATE(790),
    [aux_sym_class_declaration_repeat1] = STATE(3815),
    [aux_sym_lambda_expression_repeat1] = STATE(4217),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1515),
    [anon_sym_ref] = ACTIONS(1517),
    [anon_sym_LBRACE] = ACTIONS(2825),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1521),
    [anon_sym_TILDE] = ACTIONS(1521),
    [anon_sym_PLUS_PLUS] = ACTIONS(1521),
    [anon_sym_DASH_DASH] = ACTIONS(1521),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1519),
    [anon_sym_DASH] = ACTIONS(1519),
    [anon_sym_STAR] = ACTIONS(1523),
    [anon_sym_CARET] = ACTIONS(1521),
    [anon_sym_AMP] = ACTIONS(1521),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1525),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1527),
    [anon_sym_DOT_DOT] = ACTIONS(1529),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [791] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4152),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6920),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2942),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7032),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6089),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4337),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7427),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9283),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(791),
    [sym_preproc_endregion] = STATE(791),
    [sym_preproc_line] = STATE(791),
    [sym_preproc_pragma] = STATE(791),
    [sym_preproc_nullable] = STATE(791),
    [sym_preproc_error] = STATE(791),
    [sym_preproc_warning] = STATE(791),
    [sym_preproc_define] = STATE(791),
    [sym_preproc_undef] = STATE(791),
    [aux_sym_class_declaration_repeat1] = STATE(3829),
    [aux_sym_lambda_expression_repeat1] = STATE(4252),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1801),
    [anon_sym_ref] = ACTIONS(1803),
    [anon_sym_LBRACE] = ACTIONS(2831),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1805),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1809),
    [anon_sym_TILDE] = ACTIONS(1809),
    [anon_sym_PLUS_PLUS] = ACTIONS(1809),
    [anon_sym_DASH_DASH] = ACTIONS(1809),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1807),
    [anon_sym_DASH] = ACTIONS(1807),
    [anon_sym_STAR] = ACTIONS(1811),
    [anon_sym_CARET] = ACTIONS(1809),
    [anon_sym_AMP] = ACTIONS(1809),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1813),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1815),
    [anon_sym_DOT_DOT] = ACTIONS(1817),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [792] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4119),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6920),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2942),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7032),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6090),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4337),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7427),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9283),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(792),
    [sym_preproc_endregion] = STATE(792),
    [sym_preproc_line] = STATE(792),
    [sym_preproc_pragma] = STATE(792),
    [sym_preproc_nullable] = STATE(792),
    [sym_preproc_error] = STATE(792),
    [sym_preproc_warning] = STATE(792),
    [sym_preproc_define] = STATE(792),
    [sym_preproc_undef] = STATE(792),
    [aux_sym_class_declaration_repeat1] = STATE(3829),
    [aux_sym_lambda_expression_repeat1] = STATE(4252),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1801),
    [anon_sym_ref] = ACTIONS(1803),
    [anon_sym_LBRACE] = ACTIONS(2831),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1805),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1809),
    [anon_sym_TILDE] = ACTIONS(1809),
    [anon_sym_PLUS_PLUS] = ACTIONS(1809),
    [anon_sym_DASH_DASH] = ACTIONS(1809),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1807),
    [anon_sym_DASH] = ACTIONS(1807),
    [anon_sym_STAR] = ACTIONS(1811),
    [anon_sym_CARET] = ACTIONS(1809),
    [anon_sym_AMP] = ACTIONS(1809),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1813),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1815),
    [anon_sym_DOT_DOT] = ACTIONS(1817),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [793] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4218),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6920),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2942),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7032),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6091),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4337),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7427),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9283),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(793),
    [sym_preproc_endregion] = STATE(793),
    [sym_preproc_line] = STATE(793),
    [sym_preproc_pragma] = STATE(793),
    [sym_preproc_nullable] = STATE(793),
    [sym_preproc_error] = STATE(793),
    [sym_preproc_warning] = STATE(793),
    [sym_preproc_define] = STATE(793),
    [sym_preproc_undef] = STATE(793),
    [aux_sym_class_declaration_repeat1] = STATE(3829),
    [aux_sym_lambda_expression_repeat1] = STATE(4252),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1801),
    [anon_sym_ref] = ACTIONS(1803),
    [anon_sym_LBRACE] = ACTIONS(2831),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1805),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1809),
    [anon_sym_TILDE] = ACTIONS(1809),
    [anon_sym_PLUS_PLUS] = ACTIONS(1809),
    [anon_sym_DASH_DASH] = ACTIONS(1809),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1807),
    [anon_sym_DASH] = ACTIONS(1807),
    [anon_sym_STAR] = ACTIONS(1811),
    [anon_sym_CARET] = ACTIONS(1809),
    [anon_sym_AMP] = ACTIONS(1809),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1813),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1815),
    [anon_sym_DOT_DOT] = ACTIONS(1817),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [794] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4101),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6920),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2942),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7032),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6094),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4337),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7427),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9283),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(794),
    [sym_preproc_endregion] = STATE(794),
    [sym_preproc_line] = STATE(794),
    [sym_preproc_pragma] = STATE(794),
    [sym_preproc_nullable] = STATE(794),
    [sym_preproc_error] = STATE(794),
    [sym_preproc_warning] = STATE(794),
    [sym_preproc_define] = STATE(794),
    [sym_preproc_undef] = STATE(794),
    [aux_sym_class_declaration_repeat1] = STATE(3829),
    [aux_sym_lambda_expression_repeat1] = STATE(4252),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1801),
    [anon_sym_ref] = ACTIONS(1803),
    [anon_sym_LBRACE] = ACTIONS(2831),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1805),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1809),
    [anon_sym_TILDE] = ACTIONS(1809),
    [anon_sym_PLUS_PLUS] = ACTIONS(1809),
    [anon_sym_DASH_DASH] = ACTIONS(1809),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1807),
    [anon_sym_DASH] = ACTIONS(1807),
    [anon_sym_STAR] = ACTIONS(1811),
    [anon_sym_CARET] = ACTIONS(1809),
    [anon_sym_AMP] = ACTIONS(1809),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1813),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1815),
    [anon_sym_DOT_DOT] = ACTIONS(1817),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [795] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4102),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6920),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2942),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7032),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6097),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4337),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7427),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9283),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(795),
    [sym_preproc_endregion] = STATE(795),
    [sym_preproc_line] = STATE(795),
    [sym_preproc_pragma] = STATE(795),
    [sym_preproc_nullable] = STATE(795),
    [sym_preproc_error] = STATE(795),
    [sym_preproc_warning] = STATE(795),
    [sym_preproc_define] = STATE(795),
    [sym_preproc_undef] = STATE(795),
    [aux_sym_class_declaration_repeat1] = STATE(3829),
    [aux_sym_lambda_expression_repeat1] = STATE(4252),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1801),
    [anon_sym_ref] = ACTIONS(1803),
    [anon_sym_LBRACE] = ACTIONS(2831),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1805),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1809),
    [anon_sym_TILDE] = ACTIONS(1809),
    [anon_sym_PLUS_PLUS] = ACTIONS(1809),
    [anon_sym_DASH_DASH] = ACTIONS(1809),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1807),
    [anon_sym_DASH] = ACTIONS(1807),
    [anon_sym_STAR] = ACTIONS(1811),
    [anon_sym_CARET] = ACTIONS(1809),
    [anon_sym_AMP] = ACTIONS(1809),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1813),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1815),
    [anon_sym_DOT_DOT] = ACTIONS(1817),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [796] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4111),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6920),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2942),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7032),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6098),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4337),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7427),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9283),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(796),
    [sym_preproc_endregion] = STATE(796),
    [sym_preproc_line] = STATE(796),
    [sym_preproc_pragma] = STATE(796),
    [sym_preproc_nullable] = STATE(796),
    [sym_preproc_error] = STATE(796),
    [sym_preproc_warning] = STATE(796),
    [sym_preproc_define] = STATE(796),
    [sym_preproc_undef] = STATE(796),
    [aux_sym_class_declaration_repeat1] = STATE(3829),
    [aux_sym_lambda_expression_repeat1] = STATE(4252),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1801),
    [anon_sym_ref] = ACTIONS(1803),
    [anon_sym_LBRACE] = ACTIONS(2831),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1805),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1809),
    [anon_sym_TILDE] = ACTIONS(1809),
    [anon_sym_PLUS_PLUS] = ACTIONS(1809),
    [anon_sym_DASH_DASH] = ACTIONS(1809),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1807),
    [anon_sym_DASH] = ACTIONS(1807),
    [anon_sym_STAR] = ACTIONS(1811),
    [anon_sym_CARET] = ACTIONS(1809),
    [anon_sym_AMP] = ACTIONS(1809),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1813),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1815),
    [anon_sym_DOT_DOT] = ACTIONS(1817),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [797] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3708),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6918),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6973),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5282),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4069),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7443),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9676),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(797),
    [sym_preproc_endregion] = STATE(797),
    [sym_preproc_line] = STATE(797),
    [sym_preproc_pragma] = STATE(797),
    [sym_preproc_nullable] = STATE(797),
    [sym_preproc_error] = STATE(797),
    [sym_preproc_warning] = STATE(797),
    [sym_preproc_define] = STATE(797),
    [sym_preproc_undef] = STATE(797),
    [aux_sym_class_declaration_repeat1] = STATE(3815),
    [aux_sym_lambda_expression_repeat1] = STATE(4217),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1515),
    [anon_sym_ref] = ACTIONS(1517),
    [anon_sym_LBRACE] = ACTIONS(2825),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1521),
    [anon_sym_TILDE] = ACTIONS(1521),
    [anon_sym_PLUS_PLUS] = ACTIONS(1521),
    [anon_sym_DASH_DASH] = ACTIONS(1521),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1519),
    [anon_sym_DASH] = ACTIONS(1519),
    [anon_sym_STAR] = ACTIONS(1523),
    [anon_sym_CARET] = ACTIONS(1521),
    [anon_sym_AMP] = ACTIONS(1521),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1525),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1527),
    [anon_sym_DOT_DOT] = ACTIONS(1529),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [798] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6221),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2789),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(2855),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6045),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(798),
    [sym_preproc_endregion] = STATE(798),
    [sym_preproc_line] = STATE(798),
    [sym_preproc_pragma] = STATE(798),
    [sym_preproc_nullable] = STATE(798),
    [sym_preproc_error] = STATE(798),
    [sym_preproc_warning] = STATE(798),
    [sym_preproc_define] = STATE(798),
    [sym_preproc_undef] = STATE(798),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_ref] = ACTIONS(1951),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(2739),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(1089),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2855),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [799] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3991),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6933),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2950),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7095),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5695),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4215),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7446),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9108),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(799),
    [sym_preproc_endregion] = STATE(799),
    [sym_preproc_line] = STATE(799),
    [sym_preproc_pragma] = STATE(799),
    [sym_preproc_nullable] = STATE(799),
    [sym_preproc_error] = STATE(799),
    [sym_preproc_warning] = STATE(799),
    [sym_preproc_define] = STATE(799),
    [sym_preproc_undef] = STATE(799),
    [aux_sym_class_declaration_repeat1] = STATE(3848),
    [aux_sym_lambda_expression_repeat1] = STATE(4282),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1837),
    [anon_sym_ref] = ACTIONS(1839),
    [anon_sym_LBRACE] = ACTIONS(2835),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1841),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1845),
    [anon_sym_TILDE] = ACTIONS(1845),
    [anon_sym_PLUS_PLUS] = ACTIONS(1845),
    [anon_sym_DASH_DASH] = ACTIONS(1845),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1843),
    [anon_sym_DASH] = ACTIONS(1843),
    [anon_sym_STAR] = ACTIONS(1847),
    [anon_sym_CARET] = ACTIONS(1845),
    [anon_sym_AMP] = ACTIONS(1845),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1849),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1851),
    [anon_sym_DOT_DOT] = ACTIONS(1853),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [800] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4028),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6933),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2950),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7095),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5696),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4215),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7446),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9108),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(800),
    [sym_preproc_endregion] = STATE(800),
    [sym_preproc_line] = STATE(800),
    [sym_preproc_pragma] = STATE(800),
    [sym_preproc_nullable] = STATE(800),
    [sym_preproc_error] = STATE(800),
    [sym_preproc_warning] = STATE(800),
    [sym_preproc_define] = STATE(800),
    [sym_preproc_undef] = STATE(800),
    [aux_sym_class_declaration_repeat1] = STATE(3848),
    [aux_sym_lambda_expression_repeat1] = STATE(4282),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1837),
    [anon_sym_ref] = ACTIONS(1839),
    [anon_sym_LBRACE] = ACTIONS(2835),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1841),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1845),
    [anon_sym_TILDE] = ACTIONS(1845),
    [anon_sym_PLUS_PLUS] = ACTIONS(1845),
    [anon_sym_DASH_DASH] = ACTIONS(1845),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1843),
    [anon_sym_DASH] = ACTIONS(1843),
    [anon_sym_STAR] = ACTIONS(1847),
    [anon_sym_CARET] = ACTIONS(1845),
    [anon_sym_AMP] = ACTIONS(1845),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1849),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1851),
    [anon_sym_DOT_DOT] = ACTIONS(1853),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [801] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4030),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6933),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2950),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7095),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5697),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4215),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7446),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9108),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(801),
    [sym_preproc_endregion] = STATE(801),
    [sym_preproc_line] = STATE(801),
    [sym_preproc_pragma] = STATE(801),
    [sym_preproc_nullable] = STATE(801),
    [sym_preproc_error] = STATE(801),
    [sym_preproc_warning] = STATE(801),
    [sym_preproc_define] = STATE(801),
    [sym_preproc_undef] = STATE(801),
    [aux_sym_class_declaration_repeat1] = STATE(3848),
    [aux_sym_lambda_expression_repeat1] = STATE(4282),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1837),
    [anon_sym_ref] = ACTIONS(1839),
    [anon_sym_LBRACE] = ACTIONS(2835),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1841),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1845),
    [anon_sym_TILDE] = ACTIONS(1845),
    [anon_sym_PLUS_PLUS] = ACTIONS(1845),
    [anon_sym_DASH_DASH] = ACTIONS(1845),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1843),
    [anon_sym_DASH] = ACTIONS(1843),
    [anon_sym_STAR] = ACTIONS(1847),
    [anon_sym_CARET] = ACTIONS(1845),
    [anon_sym_AMP] = ACTIONS(1845),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1849),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1851),
    [anon_sym_DOT_DOT] = ACTIONS(1853),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [802] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4005),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6933),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2950),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7095),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5699),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4215),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7446),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9108),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(802),
    [sym_preproc_endregion] = STATE(802),
    [sym_preproc_line] = STATE(802),
    [sym_preproc_pragma] = STATE(802),
    [sym_preproc_nullable] = STATE(802),
    [sym_preproc_error] = STATE(802),
    [sym_preproc_warning] = STATE(802),
    [sym_preproc_define] = STATE(802),
    [sym_preproc_undef] = STATE(802),
    [aux_sym_class_declaration_repeat1] = STATE(3848),
    [aux_sym_lambda_expression_repeat1] = STATE(4282),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1837),
    [anon_sym_ref] = ACTIONS(1839),
    [anon_sym_LBRACE] = ACTIONS(2835),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1841),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1845),
    [anon_sym_TILDE] = ACTIONS(1845),
    [anon_sym_PLUS_PLUS] = ACTIONS(1845),
    [anon_sym_DASH_DASH] = ACTIONS(1845),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1843),
    [anon_sym_DASH] = ACTIONS(1843),
    [anon_sym_STAR] = ACTIONS(1847),
    [anon_sym_CARET] = ACTIONS(1845),
    [anon_sym_AMP] = ACTIONS(1845),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1849),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1851),
    [anon_sym_DOT_DOT] = ACTIONS(1853),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [803] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4021),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6933),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2950),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7095),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5700),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4215),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7446),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9108),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(803),
    [sym_preproc_endregion] = STATE(803),
    [sym_preproc_line] = STATE(803),
    [sym_preproc_pragma] = STATE(803),
    [sym_preproc_nullable] = STATE(803),
    [sym_preproc_error] = STATE(803),
    [sym_preproc_warning] = STATE(803),
    [sym_preproc_define] = STATE(803),
    [sym_preproc_undef] = STATE(803),
    [aux_sym_class_declaration_repeat1] = STATE(3848),
    [aux_sym_lambda_expression_repeat1] = STATE(4282),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1837),
    [anon_sym_ref] = ACTIONS(1839),
    [anon_sym_LBRACE] = ACTIONS(2835),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1841),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1845),
    [anon_sym_TILDE] = ACTIONS(1845),
    [anon_sym_PLUS_PLUS] = ACTIONS(1845),
    [anon_sym_DASH_DASH] = ACTIONS(1845),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1843),
    [anon_sym_DASH] = ACTIONS(1843),
    [anon_sym_STAR] = ACTIONS(1847),
    [anon_sym_CARET] = ACTIONS(1845),
    [anon_sym_AMP] = ACTIONS(1845),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1849),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1851),
    [anon_sym_DOT_DOT] = ACTIONS(1853),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [804] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4060),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6933),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2950),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7095),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5701),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4215),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7446),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9108),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(804),
    [sym_preproc_endregion] = STATE(804),
    [sym_preproc_line] = STATE(804),
    [sym_preproc_pragma] = STATE(804),
    [sym_preproc_nullable] = STATE(804),
    [sym_preproc_error] = STATE(804),
    [sym_preproc_warning] = STATE(804),
    [sym_preproc_define] = STATE(804),
    [sym_preproc_undef] = STATE(804),
    [aux_sym_class_declaration_repeat1] = STATE(3848),
    [aux_sym_lambda_expression_repeat1] = STATE(4282),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1837),
    [anon_sym_ref] = ACTIONS(1839),
    [anon_sym_LBRACE] = ACTIONS(2835),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1841),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1845),
    [anon_sym_TILDE] = ACTIONS(1845),
    [anon_sym_PLUS_PLUS] = ACTIONS(1845),
    [anon_sym_DASH_DASH] = ACTIONS(1845),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1843),
    [anon_sym_DASH] = ACTIONS(1843),
    [anon_sym_STAR] = ACTIONS(1847),
    [anon_sym_CARET] = ACTIONS(1845),
    [anon_sym_AMP] = ACTIONS(1845),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1849),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1851),
    [anon_sym_DOT_DOT] = ACTIONS(1853),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [805] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6920),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2942),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7033),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6099),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4337),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7427),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9283),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(805),
    [sym_preproc_endregion] = STATE(805),
    [sym_preproc_line] = STATE(805),
    [sym_preproc_pragma] = STATE(805),
    [sym_preproc_nullable] = STATE(805),
    [sym_preproc_error] = STATE(805),
    [sym_preproc_warning] = STATE(805),
    [sym_preproc_define] = STATE(805),
    [sym_preproc_undef] = STATE(805),
    [aux_sym_class_declaration_repeat1] = STATE(3829),
    [aux_sym_lambda_expression_repeat1] = STATE(4252),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1801),
    [anon_sym_ref] = ACTIONS(1803),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1805),
    [anon_sym_readonly] = ACTIONS(2767),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1809),
    [anon_sym_TILDE] = ACTIONS(1809),
    [anon_sym_PLUS_PLUS] = ACTIONS(1809),
    [anon_sym_DASH_DASH] = ACTIONS(1809),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1807),
    [anon_sym_DASH] = ACTIONS(1807),
    [anon_sym_STAR] = ACTIONS(1811),
    [anon_sym_CARET] = ACTIONS(1809),
    [anon_sym_AMP] = ACTIONS(1809),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1813),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1815),
    [anon_sym_DOT_DOT] = ACTIONS(1817),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [806] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6933),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2950),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7096),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5702),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4215),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7446),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9108),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(806),
    [sym_preproc_endregion] = STATE(806),
    [sym_preproc_line] = STATE(806),
    [sym_preproc_pragma] = STATE(806),
    [sym_preproc_nullable] = STATE(806),
    [sym_preproc_error] = STATE(806),
    [sym_preproc_warning] = STATE(806),
    [sym_preproc_define] = STATE(806),
    [sym_preproc_undef] = STATE(806),
    [aux_sym_class_declaration_repeat1] = STATE(3848),
    [aux_sym_lambda_expression_repeat1] = STATE(4282),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1837),
    [anon_sym_ref] = ACTIONS(1839),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1841),
    [anon_sym_readonly] = ACTIONS(2767),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1845),
    [anon_sym_TILDE] = ACTIONS(1845),
    [anon_sym_PLUS_PLUS] = ACTIONS(1845),
    [anon_sym_DASH_DASH] = ACTIONS(1845),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1843),
    [anon_sym_DASH] = ACTIONS(1843),
    [anon_sym_STAR] = ACTIONS(1847),
    [anon_sym_CARET] = ACTIONS(1845),
    [anon_sym_AMP] = ACTIONS(1845),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1849),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1851),
    [anon_sym_DOT_DOT] = ACTIONS(1853),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [807] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6925),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2932),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6993),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4552),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3702),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7420),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9634),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(807),
    [sym_preproc_endregion] = STATE(807),
    [sym_preproc_line] = STATE(807),
    [sym_preproc_pragma] = STATE(807),
    [sym_preproc_nullable] = STATE(807),
    [sym_preproc_error] = STATE(807),
    [sym_preproc_warning] = STATE(807),
    [sym_preproc_define] = STATE(807),
    [sym_preproc_undef] = STATE(807),
    [aux_sym_class_declaration_repeat1] = STATE(3819),
    [aux_sym_lambda_expression_repeat1] = STATE(4232),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1995),
    [anon_sym_ref] = ACTIONS(1997),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1771),
    [anon_sym_readonly] = ACTIONS(2767),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(2001),
    [anon_sym_TILDE] = ACTIONS(2001),
    [anon_sym_PLUS_PLUS] = ACTIONS(2001),
    [anon_sym_DASH_DASH] = ACTIONS(2001),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1999),
    [anon_sym_DASH] = ACTIONS(1999),
    [anon_sym_STAR] = ACTIONS(1777),
    [anon_sym_CARET] = ACTIONS(2001),
    [anon_sym_AMP] = ACTIONS(2001),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(2003),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2005),
    [anon_sym_DOT_DOT] = ACTIONS(2007),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [808] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7106),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5600),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9482),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(808),
    [sym_preproc_endregion] = STATE(808),
    [sym_preproc_line] = STATE(808),
    [sym_preproc_pragma] = STATE(808),
    [sym_preproc_nullable] = STATE(808),
    [sym_preproc_error] = STATE(808),
    [sym_preproc_warning] = STATE(808),
    [sym_preproc_define] = STATE(808),
    [sym_preproc_undef] = STATE(808),
    [aux_sym_class_declaration_repeat1] = STATE(3853),
    [aux_sym_lambda_expression_repeat1] = STATE(4299),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1497),
    [anon_sym_ref] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_readonly] = ACTIONS(2767),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1505),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1507),
    [anon_sym_DOT_DOT] = ACTIONS(1509),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [809] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3764),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6948),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2940),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6999),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5071),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3857),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7444),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9574),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(809),
    [sym_preproc_endregion] = STATE(809),
    [sym_preproc_line] = STATE(809),
    [sym_preproc_pragma] = STATE(809),
    [sym_preproc_nullable] = STATE(809),
    [sym_preproc_error] = STATE(809),
    [sym_preproc_warning] = STATE(809),
    [sym_preproc_define] = STATE(809),
    [sym_preproc_undef] = STATE(809),
    [aux_sym_class_declaration_repeat1] = STATE(3854),
    [aux_sym_lambda_expression_repeat1] = STATE(4136),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2111),
    [anon_sym_ref] = ACTIONS(2113),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1897),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2117),
    [anon_sym_TILDE] = ACTIONS(2117),
    [anon_sym_PLUS_PLUS] = ACTIONS(2117),
    [anon_sym_DASH_DASH] = ACTIONS(2117),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2115),
    [anon_sym_DASH] = ACTIONS(2115),
    [anon_sym_STAR] = ACTIONS(1903),
    [anon_sym_CARET] = ACTIONS(2117),
    [anon_sym_AMP] = ACTIONS(2117),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2119),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2121),
    [anon_sym_DOT_DOT] = ACTIONS(2123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [810] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6943),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2986),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7152),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6547),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4518),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7441),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9110),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(810),
    [sym_preproc_endregion] = STATE(810),
    [sym_preproc_line] = STATE(810),
    [sym_preproc_pragma] = STATE(810),
    [sym_preproc_nullable] = STATE(810),
    [sym_preproc_error] = STATE(810),
    [sym_preproc_warning] = STATE(810),
    [sym_preproc_define] = STATE(810),
    [sym_preproc_undef] = STATE(810),
    [aux_sym_class_declaration_repeat1] = STATE(3875),
    [aux_sym_lambda_expression_repeat1] = STATE(4315),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2169),
    [anon_sym_ref] = ACTIONS(2171),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2173),
    [anon_sym_readonly] = ACTIONS(2767),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2177),
    [anon_sym_TILDE] = ACTIONS(2177),
    [anon_sym_PLUS_PLUS] = ACTIONS(2177),
    [anon_sym_DASH_DASH] = ACTIONS(2177),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2175),
    [anon_sym_DASH] = ACTIONS(2175),
    [anon_sym_STAR] = ACTIONS(2179),
    [anon_sym_CARET] = ACTIONS(2177),
    [anon_sym_AMP] = ACTIONS(2177),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2181),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2183),
    [anon_sym_DOT_DOT] = ACTIONS(2185),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [811] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(5561),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6937),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2861),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7001),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5683),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4149),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7445),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9763),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(811),
    [sym_preproc_endregion] = STATE(811),
    [sym_preproc_line] = STATE(811),
    [sym_preproc_pragma] = STATE(811),
    [sym_preproc_nullable] = STATE(811),
    [sym_preproc_error] = STATE(811),
    [sym_preproc_warning] = STATE(811),
    [sym_preproc_define] = STATE(811),
    [sym_preproc_undef] = STATE(811),
    [aux_sym_class_declaration_repeat1] = STATE(3821),
    [aux_sym_lambda_expression_repeat1] = STATE(4236),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1609),
    [anon_sym_ref] = ACTIONS(1611),
    [anon_sym_LBRACE] = ACTIONS(2857),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1481),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1615),
    [anon_sym_TILDE] = ACTIONS(1615),
    [anon_sym_PLUS_PLUS] = ACTIONS(1615),
    [anon_sym_DASH_DASH] = ACTIONS(1615),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1613),
    [anon_sym_DASH] = ACTIONS(1613),
    [anon_sym_STAR] = ACTIONS(1487),
    [anon_sym_CARET] = ACTIONS(1615),
    [anon_sym_AMP] = ACTIONS(1615),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1617),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1619),
    [anon_sym_DOT_DOT] = ACTIONS(1621),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [812] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6956),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6514),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9482),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(812),
    [sym_preproc_endregion] = STATE(812),
    [sym_preproc_line] = STATE(812),
    [sym_preproc_pragma] = STATE(812),
    [sym_preproc_nullable] = STATE(812),
    [sym_preproc_error] = STATE(812),
    [sym_preproc_warning] = STATE(812),
    [sym_preproc_define] = STATE(812),
    [sym_preproc_undef] = STATE(812),
    [aux_sym_class_declaration_repeat1] = STATE(3853),
    [aux_sym_lambda_expression_repeat1] = STATE(4299),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(2859),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1497),
    [anon_sym_ref] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1505),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1507),
    [anon_sym_DOT_DOT] = ACTIONS(1509),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [813] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6963),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5186),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3931),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9818),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(813),
    [sym_preproc_endregion] = STATE(813),
    [sym_preproc_line] = STATE(813),
    [sym_preproc_pragma] = STATE(813),
    [sym_preproc_nullable] = STATE(813),
    [sym_preproc_error] = STATE(813),
    [sym_preproc_warning] = STATE(813),
    [sym_preproc_define] = STATE(813),
    [sym_preproc_undef] = STATE(813),
    [aux_sym_class_declaration_repeat1] = STATE(3811),
    [aux_sym_lambda_expression_repeat1] = STATE(4201),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1373),
    [anon_sym_ref] = ACTIONS(1375),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_readonly] = ACTIONS(2767),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1379),
    [anon_sym_TILDE] = ACTIONS(1379),
    [anon_sym_PLUS_PLUS] = ACTIONS(1379),
    [anon_sym_DASH_DASH] = ACTIONS(1379),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1377),
    [anon_sym_DASH] = ACTIONS(1377),
    [anon_sym_STAR] = ACTIONS(1381),
    [anon_sym_CARET] = ACTIONS(1379),
    [anon_sym_AMP] = ACTIONS(1379),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1383),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1385),
    [anon_sym_DOT_DOT] = ACTIONS(1387),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [814] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(5577),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6937),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2861),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7001),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5685),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4149),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7445),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9763),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(814),
    [sym_preproc_endregion] = STATE(814),
    [sym_preproc_line] = STATE(814),
    [sym_preproc_pragma] = STATE(814),
    [sym_preproc_nullable] = STATE(814),
    [sym_preproc_error] = STATE(814),
    [sym_preproc_warning] = STATE(814),
    [sym_preproc_define] = STATE(814),
    [sym_preproc_undef] = STATE(814),
    [aux_sym_class_declaration_repeat1] = STATE(3821),
    [aux_sym_lambda_expression_repeat1] = STATE(4236),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1609),
    [anon_sym_ref] = ACTIONS(1611),
    [anon_sym_LBRACE] = ACTIONS(2857),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1481),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1615),
    [anon_sym_TILDE] = ACTIONS(1615),
    [anon_sym_PLUS_PLUS] = ACTIONS(1615),
    [anon_sym_DASH_DASH] = ACTIONS(1615),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1613),
    [anon_sym_DASH] = ACTIONS(1613),
    [anon_sym_STAR] = ACTIONS(1487),
    [anon_sym_CARET] = ACTIONS(1615),
    [anon_sym_AMP] = ACTIONS(1615),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1617),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1619),
    [anon_sym_DOT_DOT] = ACTIONS(1621),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [815] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(5582),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6937),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2861),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7001),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5703),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4149),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7445),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9763),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(815),
    [sym_preproc_endregion] = STATE(815),
    [sym_preproc_line] = STATE(815),
    [sym_preproc_pragma] = STATE(815),
    [sym_preproc_nullable] = STATE(815),
    [sym_preproc_error] = STATE(815),
    [sym_preproc_warning] = STATE(815),
    [sym_preproc_define] = STATE(815),
    [sym_preproc_undef] = STATE(815),
    [aux_sym_class_declaration_repeat1] = STATE(3821),
    [aux_sym_lambda_expression_repeat1] = STATE(4236),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1609),
    [anon_sym_ref] = ACTIONS(1611),
    [anon_sym_LBRACE] = ACTIONS(2857),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1481),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1615),
    [anon_sym_TILDE] = ACTIONS(1615),
    [anon_sym_PLUS_PLUS] = ACTIONS(1615),
    [anon_sym_DASH_DASH] = ACTIONS(1615),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1613),
    [anon_sym_DASH] = ACTIONS(1613),
    [anon_sym_STAR] = ACTIONS(1487),
    [anon_sym_CARET] = ACTIONS(1615),
    [anon_sym_AMP] = ACTIONS(1615),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1617),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1619),
    [anon_sym_DOT_DOT] = ACTIONS(1621),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [816] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3763),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6943),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2986),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7151),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6515),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4518),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7441),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9110),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(816),
    [sym_preproc_endregion] = STATE(816),
    [sym_preproc_line] = STATE(816),
    [sym_preproc_pragma] = STATE(816),
    [sym_preproc_nullable] = STATE(816),
    [sym_preproc_error] = STATE(816),
    [sym_preproc_warning] = STATE(816),
    [sym_preproc_define] = STATE(816),
    [sym_preproc_undef] = STATE(816),
    [aux_sym_class_declaration_repeat1] = STATE(3875),
    [aux_sym_lambda_expression_repeat1] = STATE(4315),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2169),
    [anon_sym_ref] = ACTIONS(2171),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2173),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2177),
    [anon_sym_TILDE] = ACTIONS(2177),
    [anon_sym_PLUS_PLUS] = ACTIONS(2177),
    [anon_sym_DASH_DASH] = ACTIONS(2177),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2175),
    [anon_sym_DASH] = ACTIONS(2175),
    [anon_sym_STAR] = ACTIONS(2179),
    [anon_sym_CARET] = ACTIONS(2177),
    [anon_sym_AMP] = ACTIONS(2177),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2181),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2183),
    [anon_sym_DOT_DOT] = ACTIONS(2185),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [817] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3764),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6943),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2986),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7151),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6516),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4518),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7441),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9110),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(817),
    [sym_preproc_endregion] = STATE(817),
    [sym_preproc_line] = STATE(817),
    [sym_preproc_pragma] = STATE(817),
    [sym_preproc_nullable] = STATE(817),
    [sym_preproc_error] = STATE(817),
    [sym_preproc_warning] = STATE(817),
    [sym_preproc_define] = STATE(817),
    [sym_preproc_undef] = STATE(817),
    [aux_sym_class_declaration_repeat1] = STATE(3875),
    [aux_sym_lambda_expression_repeat1] = STATE(4315),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2169),
    [anon_sym_ref] = ACTIONS(2171),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2173),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2177),
    [anon_sym_TILDE] = ACTIONS(2177),
    [anon_sym_PLUS_PLUS] = ACTIONS(2177),
    [anon_sym_DASH_DASH] = ACTIONS(2177),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2175),
    [anon_sym_DASH] = ACTIONS(2175),
    [anon_sym_STAR] = ACTIONS(2179),
    [anon_sym_CARET] = ACTIONS(2177),
    [anon_sym_AMP] = ACTIONS(2177),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2181),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2183),
    [anon_sym_DOT_DOT] = ACTIONS(2185),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [818] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(5615),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6937),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2861),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7001),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5706),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4149),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7445),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9763),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(818),
    [sym_preproc_endregion] = STATE(818),
    [sym_preproc_line] = STATE(818),
    [sym_preproc_pragma] = STATE(818),
    [sym_preproc_nullable] = STATE(818),
    [sym_preproc_error] = STATE(818),
    [sym_preproc_warning] = STATE(818),
    [sym_preproc_define] = STATE(818),
    [sym_preproc_undef] = STATE(818),
    [aux_sym_class_declaration_repeat1] = STATE(3821),
    [aux_sym_lambda_expression_repeat1] = STATE(4236),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1609),
    [anon_sym_ref] = ACTIONS(1611),
    [anon_sym_LBRACE] = ACTIONS(2857),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1481),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1615),
    [anon_sym_TILDE] = ACTIONS(1615),
    [anon_sym_PLUS_PLUS] = ACTIONS(1615),
    [anon_sym_DASH_DASH] = ACTIONS(1615),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1613),
    [anon_sym_DASH] = ACTIONS(1613),
    [anon_sym_STAR] = ACTIONS(1487),
    [anon_sym_CARET] = ACTIONS(1615),
    [anon_sym_AMP] = ACTIONS(1615),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1617),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1619),
    [anon_sym_DOT_DOT] = ACTIONS(1621),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [819] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(5618),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6937),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2861),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7001),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5707),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4149),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7445),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9763),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(819),
    [sym_preproc_endregion] = STATE(819),
    [sym_preproc_line] = STATE(819),
    [sym_preproc_pragma] = STATE(819),
    [sym_preproc_nullable] = STATE(819),
    [sym_preproc_error] = STATE(819),
    [sym_preproc_warning] = STATE(819),
    [sym_preproc_define] = STATE(819),
    [sym_preproc_undef] = STATE(819),
    [aux_sym_class_declaration_repeat1] = STATE(3821),
    [aux_sym_lambda_expression_repeat1] = STATE(4236),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1609),
    [anon_sym_ref] = ACTIONS(1611),
    [anon_sym_LBRACE] = ACTIONS(2857),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1481),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1615),
    [anon_sym_TILDE] = ACTIONS(1615),
    [anon_sym_PLUS_PLUS] = ACTIONS(1615),
    [anon_sym_DASH_DASH] = ACTIONS(1615),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1613),
    [anon_sym_DASH] = ACTIONS(1613),
    [anon_sym_STAR] = ACTIONS(1487),
    [anon_sym_CARET] = ACTIONS(1615),
    [anon_sym_AMP] = ACTIONS(1615),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1617),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1619),
    [anon_sym_DOT_DOT] = ACTIONS(1621),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [820] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3780),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6943),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2986),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7151),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6518),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4518),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7441),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9110),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(820),
    [sym_preproc_endregion] = STATE(820),
    [sym_preproc_line] = STATE(820),
    [sym_preproc_pragma] = STATE(820),
    [sym_preproc_nullable] = STATE(820),
    [sym_preproc_error] = STATE(820),
    [sym_preproc_warning] = STATE(820),
    [sym_preproc_define] = STATE(820),
    [sym_preproc_undef] = STATE(820),
    [aux_sym_class_declaration_repeat1] = STATE(3875),
    [aux_sym_lambda_expression_repeat1] = STATE(4315),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2169),
    [anon_sym_ref] = ACTIONS(2171),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2173),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2177),
    [anon_sym_TILDE] = ACTIONS(2177),
    [anon_sym_PLUS_PLUS] = ACTIONS(2177),
    [anon_sym_DASH_DASH] = ACTIONS(2177),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2175),
    [anon_sym_DASH] = ACTIONS(2175),
    [anon_sym_STAR] = ACTIONS(2179),
    [anon_sym_CARET] = ACTIONS(2177),
    [anon_sym_AMP] = ACTIONS(2177),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2181),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2183),
    [anon_sym_DOT_DOT] = ACTIONS(2185),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [821] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(5639),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6937),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2861),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7001),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5708),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4149),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7445),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9763),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(821),
    [sym_preproc_endregion] = STATE(821),
    [sym_preproc_line] = STATE(821),
    [sym_preproc_pragma] = STATE(821),
    [sym_preproc_nullable] = STATE(821),
    [sym_preproc_error] = STATE(821),
    [sym_preproc_warning] = STATE(821),
    [sym_preproc_define] = STATE(821),
    [sym_preproc_undef] = STATE(821),
    [aux_sym_class_declaration_repeat1] = STATE(3821),
    [aux_sym_lambda_expression_repeat1] = STATE(4236),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1609),
    [anon_sym_ref] = ACTIONS(1611),
    [anon_sym_LBRACE] = ACTIONS(2857),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1481),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1615),
    [anon_sym_TILDE] = ACTIONS(1615),
    [anon_sym_PLUS_PLUS] = ACTIONS(1615),
    [anon_sym_DASH_DASH] = ACTIONS(1615),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1613),
    [anon_sym_DASH] = ACTIONS(1613),
    [anon_sym_STAR] = ACTIONS(1487),
    [anon_sym_CARET] = ACTIONS(1615),
    [anon_sym_AMP] = ACTIONS(1615),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1617),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1619),
    [anon_sym_DOT_DOT] = ACTIONS(1621),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [822] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6956),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6443),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9482),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(822),
    [sym_preproc_endregion] = STATE(822),
    [sym_preproc_line] = STATE(822),
    [sym_preproc_pragma] = STATE(822),
    [sym_preproc_nullable] = STATE(822),
    [sym_preproc_error] = STATE(822),
    [sym_preproc_warning] = STATE(822),
    [sym_preproc_define] = STATE(822),
    [sym_preproc_undef] = STATE(822),
    [aux_sym_class_declaration_repeat1] = STATE(3853),
    [aux_sym_lambda_expression_repeat1] = STATE(4299),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(2861),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1497),
    [anon_sym_ref] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1505),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1507),
    [anon_sym_DOT_DOT] = ACTIONS(1509),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [823] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3735),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6943),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2986),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7151),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6525),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4518),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7441),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9110),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(823),
    [sym_preproc_endregion] = STATE(823),
    [sym_preproc_line] = STATE(823),
    [sym_preproc_pragma] = STATE(823),
    [sym_preproc_nullable] = STATE(823),
    [sym_preproc_error] = STATE(823),
    [sym_preproc_warning] = STATE(823),
    [sym_preproc_define] = STATE(823),
    [sym_preproc_undef] = STATE(823),
    [aux_sym_class_declaration_repeat1] = STATE(3875),
    [aux_sym_lambda_expression_repeat1] = STATE(4315),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2169),
    [anon_sym_ref] = ACTIONS(2171),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2173),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2177),
    [anon_sym_TILDE] = ACTIONS(2177),
    [anon_sym_PLUS_PLUS] = ACTIONS(2177),
    [anon_sym_DASH_DASH] = ACTIONS(2177),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2175),
    [anon_sym_DASH] = ACTIONS(2175),
    [anon_sym_STAR] = ACTIONS(2179),
    [anon_sym_CARET] = ACTIONS(2177),
    [anon_sym_AMP] = ACTIONS(2177),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2181),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2183),
    [anon_sym_DOT_DOT] = ACTIONS(2185),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [824] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3741),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6943),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2986),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7151),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6526),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4518),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7441),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9110),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(824),
    [sym_preproc_endregion] = STATE(824),
    [sym_preproc_line] = STATE(824),
    [sym_preproc_pragma] = STATE(824),
    [sym_preproc_nullable] = STATE(824),
    [sym_preproc_error] = STATE(824),
    [sym_preproc_warning] = STATE(824),
    [sym_preproc_define] = STATE(824),
    [sym_preproc_undef] = STATE(824),
    [aux_sym_class_declaration_repeat1] = STATE(3875),
    [aux_sym_lambda_expression_repeat1] = STATE(4315),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2169),
    [anon_sym_ref] = ACTIONS(2171),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2173),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2177),
    [anon_sym_TILDE] = ACTIONS(2177),
    [anon_sym_PLUS_PLUS] = ACTIONS(2177),
    [anon_sym_DASH_DASH] = ACTIONS(2177),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2175),
    [anon_sym_DASH] = ACTIONS(2175),
    [anon_sym_STAR] = ACTIONS(2179),
    [anon_sym_CARET] = ACTIONS(2177),
    [anon_sym_AMP] = ACTIONS(2177),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2181),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2183),
    [anon_sym_DOT_DOT] = ACTIONS(2185),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [825] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3754),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6943),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2986),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7151),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6527),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4518),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7441),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9110),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(825),
    [sym_preproc_endregion] = STATE(825),
    [sym_preproc_line] = STATE(825),
    [sym_preproc_pragma] = STATE(825),
    [sym_preproc_nullable] = STATE(825),
    [sym_preproc_error] = STATE(825),
    [sym_preproc_warning] = STATE(825),
    [sym_preproc_define] = STATE(825),
    [sym_preproc_undef] = STATE(825),
    [aux_sym_class_declaration_repeat1] = STATE(3875),
    [aux_sym_lambda_expression_repeat1] = STATE(4315),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2169),
    [anon_sym_ref] = ACTIONS(2171),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2173),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2177),
    [anon_sym_TILDE] = ACTIONS(2177),
    [anon_sym_PLUS_PLUS] = ACTIONS(2177),
    [anon_sym_DASH_DASH] = ACTIONS(2177),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2175),
    [anon_sym_DASH] = ACTIONS(2175),
    [anon_sym_STAR] = ACTIONS(2179),
    [anon_sym_CARET] = ACTIONS(2177),
    [anon_sym_AMP] = ACTIONS(2177),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2181),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2183),
    [anon_sym_DOT_DOT] = ACTIONS(2185),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [826] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6725),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2838),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6743),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5726),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4216),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9065),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(826),
    [sym_preproc_endregion] = STATE(826),
    [sym_preproc_line] = STATE(826),
    [sym_preproc_pragma] = STATE(826),
    [sym_preproc_nullable] = STATE(826),
    [sym_preproc_error] = STATE(826),
    [sym_preproc_warning] = STATE(826),
    [sym_preproc_define] = STATE(826),
    [sym_preproc_undef] = STATE(826),
    [aux_sym_class_declaration_repeat1] = STATE(3874),
    [aux_sym_lambda_expression_repeat1] = STATE(4311),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1531),
    [anon_sym_ref] = ACTIONS(2667),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_readonly] = ACTIONS(2833),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1537),
    [anon_sym_TILDE] = ACTIONS(1537),
    [anon_sym_PLUS_PLUS] = ACTIONS(1537),
    [anon_sym_DASH_DASH] = ACTIONS(1537),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1535),
    [anon_sym_DASH] = ACTIONS(1535),
    [anon_sym_STAR] = ACTIONS(1121),
    [anon_sym_CARET] = ACTIONS(1537),
    [anon_sym_AMP] = ACTIONS(1537),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2319),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2607),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1129),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1131),
    [anon_sym_DOT_DOT] = ACTIONS(1135),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [827] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6918),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6974),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5287),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4069),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7443),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9676),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(827),
    [sym_preproc_endregion] = STATE(827),
    [sym_preproc_line] = STATE(827),
    [sym_preproc_pragma] = STATE(827),
    [sym_preproc_nullable] = STATE(827),
    [sym_preproc_error] = STATE(827),
    [sym_preproc_warning] = STATE(827),
    [sym_preproc_define] = STATE(827),
    [sym_preproc_undef] = STATE(827),
    [aux_sym_class_declaration_repeat1] = STATE(3815),
    [aux_sym_lambda_expression_repeat1] = STATE(4217),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1515),
    [anon_sym_ref] = ACTIONS(1517),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_readonly] = ACTIONS(2767),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1521),
    [anon_sym_TILDE] = ACTIONS(1521),
    [anon_sym_PLUS_PLUS] = ACTIONS(1521),
    [anon_sym_DASH_DASH] = ACTIONS(1521),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1519),
    [anon_sym_DASH] = ACTIONS(1519),
    [anon_sym_STAR] = ACTIONS(1523),
    [anon_sym_CARET] = ACTIONS(1521),
    [anon_sym_AMP] = ACTIONS(1521),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1525),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1527),
    [anon_sym_DOT_DOT] = ACTIONS(1529),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [828] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3780),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7105),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5824),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(828),
    [sym_preproc_endregion] = STATE(828),
    [sym_preproc_line] = STATE(828),
    [sym_preproc_pragma] = STATE(828),
    [sym_preproc_nullable] = STATE(828),
    [sym_preproc_error] = STATE(828),
    [sym_preproc_warning] = STATE(828),
    [sym_preproc_define] = STATE(828),
    [sym_preproc_undef] = STATE(828),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [829] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4152),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6967),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5082),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3813),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9209),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(829),
    [sym_preproc_endregion] = STATE(829),
    [sym_preproc_line] = STATE(829),
    [sym_preproc_pragma] = STATE(829),
    [sym_preproc_nullable] = STATE(829),
    [sym_preproc_error] = STATE(829),
    [sym_preproc_warning] = STATE(829),
    [sym_preproc_define] = STATE(829),
    [sym_preproc_undef] = STATE(829),
    [aux_sym_class_declaration_repeat1] = STATE(3814),
    [aux_sym_lambda_expression_repeat1] = STATE(4209),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1323),
    [anon_sym_ref] = ACTIONS(1325),
    [anon_sym_LBRACE] = ACTIONS(2831),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1083),
    [anon_sym_PLUS_PLUS] = ACTIONS(1083),
    [anon_sym_DASH_DASH] = ACTIONS(1083),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1085),
    [anon_sym_DASH] = ACTIONS(1085),
    [anon_sym_STAR] = ACTIONS(1335),
    [anon_sym_CARET] = ACTIONS(1083),
    [anon_sym_AMP] = ACTIONS(1083),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1341),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1343),
    [anon_sym_DOT_DOT] = ACTIONS(1345),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [830] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4152),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6943),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2986),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7065),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5813),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4342),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7419),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9334),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(830),
    [sym_preproc_endregion] = STATE(830),
    [sym_preproc_line] = STATE(830),
    [sym_preproc_pragma] = STATE(830),
    [sym_preproc_nullable] = STATE(830),
    [sym_preproc_error] = STATE(830),
    [sym_preproc_warning] = STATE(830),
    [sym_preproc_define] = STATE(830),
    [sym_preproc_undef] = STATE(830),
    [aux_sym_class_declaration_repeat1] = STATE(3840),
    [aux_sym_lambda_expression_repeat1] = STATE(4269),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1855),
    [anon_sym_ref] = ACTIONS(1857),
    [anon_sym_LBRACE] = ACTIONS(2831),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1859),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1863),
    [anon_sym_TILDE] = ACTIONS(1863),
    [anon_sym_PLUS_PLUS] = ACTIONS(1863),
    [anon_sym_DASH_DASH] = ACTIONS(1863),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1861),
    [anon_sym_DASH] = ACTIONS(1861),
    [anon_sym_STAR] = ACTIONS(1865),
    [anon_sym_CARET] = ACTIONS(1863),
    [anon_sym_AMP] = ACTIONS(1863),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1867),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1869),
    [anon_sym_DOT_DOT] = ACTIONS(1871),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [831] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4119),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6943),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2986),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7065),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5814),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4342),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7419),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9334),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(831),
    [sym_preproc_endregion] = STATE(831),
    [sym_preproc_line] = STATE(831),
    [sym_preproc_pragma] = STATE(831),
    [sym_preproc_nullable] = STATE(831),
    [sym_preproc_error] = STATE(831),
    [sym_preproc_warning] = STATE(831),
    [sym_preproc_define] = STATE(831),
    [sym_preproc_undef] = STATE(831),
    [aux_sym_class_declaration_repeat1] = STATE(3840),
    [aux_sym_lambda_expression_repeat1] = STATE(4269),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1855),
    [anon_sym_ref] = ACTIONS(1857),
    [anon_sym_LBRACE] = ACTIONS(2831),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1859),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1863),
    [anon_sym_TILDE] = ACTIONS(1863),
    [anon_sym_PLUS_PLUS] = ACTIONS(1863),
    [anon_sym_DASH_DASH] = ACTIONS(1863),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1861),
    [anon_sym_DASH] = ACTIONS(1861),
    [anon_sym_STAR] = ACTIONS(1865),
    [anon_sym_CARET] = ACTIONS(1863),
    [anon_sym_AMP] = ACTIONS(1863),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1867),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1869),
    [anon_sym_DOT_DOT] = ACTIONS(1871),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [832] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4218),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6943),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2986),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7065),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5815),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4342),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7419),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9334),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(832),
    [sym_preproc_endregion] = STATE(832),
    [sym_preproc_line] = STATE(832),
    [sym_preproc_pragma] = STATE(832),
    [sym_preproc_nullable] = STATE(832),
    [sym_preproc_error] = STATE(832),
    [sym_preproc_warning] = STATE(832),
    [sym_preproc_define] = STATE(832),
    [sym_preproc_undef] = STATE(832),
    [aux_sym_class_declaration_repeat1] = STATE(3840),
    [aux_sym_lambda_expression_repeat1] = STATE(4269),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1855),
    [anon_sym_ref] = ACTIONS(1857),
    [anon_sym_LBRACE] = ACTIONS(2831),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1859),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1863),
    [anon_sym_TILDE] = ACTIONS(1863),
    [anon_sym_PLUS_PLUS] = ACTIONS(1863),
    [anon_sym_DASH_DASH] = ACTIONS(1863),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1861),
    [anon_sym_DASH] = ACTIONS(1861),
    [anon_sym_STAR] = ACTIONS(1865),
    [anon_sym_CARET] = ACTIONS(1863),
    [anon_sym_AMP] = ACTIONS(1863),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1867),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1869),
    [anon_sym_DOT_DOT] = ACTIONS(1871),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [833] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4101),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6943),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2986),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7065),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5817),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4342),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7419),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9334),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(833),
    [sym_preproc_endregion] = STATE(833),
    [sym_preproc_line] = STATE(833),
    [sym_preproc_pragma] = STATE(833),
    [sym_preproc_nullable] = STATE(833),
    [sym_preproc_error] = STATE(833),
    [sym_preproc_warning] = STATE(833),
    [sym_preproc_define] = STATE(833),
    [sym_preproc_undef] = STATE(833),
    [aux_sym_class_declaration_repeat1] = STATE(3840),
    [aux_sym_lambda_expression_repeat1] = STATE(4269),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1855),
    [anon_sym_ref] = ACTIONS(1857),
    [anon_sym_LBRACE] = ACTIONS(2831),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1859),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1863),
    [anon_sym_TILDE] = ACTIONS(1863),
    [anon_sym_PLUS_PLUS] = ACTIONS(1863),
    [anon_sym_DASH_DASH] = ACTIONS(1863),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1861),
    [anon_sym_DASH] = ACTIONS(1861),
    [anon_sym_STAR] = ACTIONS(1865),
    [anon_sym_CARET] = ACTIONS(1863),
    [anon_sym_AMP] = ACTIONS(1863),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1867),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1869),
    [anon_sym_DOT_DOT] = ACTIONS(1871),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [834] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4102),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6943),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2986),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7065),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5818),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4342),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7419),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9334),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(834),
    [sym_preproc_endregion] = STATE(834),
    [sym_preproc_line] = STATE(834),
    [sym_preproc_pragma] = STATE(834),
    [sym_preproc_nullable] = STATE(834),
    [sym_preproc_error] = STATE(834),
    [sym_preproc_warning] = STATE(834),
    [sym_preproc_define] = STATE(834),
    [sym_preproc_undef] = STATE(834),
    [aux_sym_class_declaration_repeat1] = STATE(3840),
    [aux_sym_lambda_expression_repeat1] = STATE(4269),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1855),
    [anon_sym_ref] = ACTIONS(1857),
    [anon_sym_LBRACE] = ACTIONS(2831),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1859),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1863),
    [anon_sym_TILDE] = ACTIONS(1863),
    [anon_sym_PLUS_PLUS] = ACTIONS(1863),
    [anon_sym_DASH_DASH] = ACTIONS(1863),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1861),
    [anon_sym_DASH] = ACTIONS(1861),
    [anon_sym_STAR] = ACTIONS(1865),
    [anon_sym_CARET] = ACTIONS(1863),
    [anon_sym_AMP] = ACTIONS(1863),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1867),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1869),
    [anon_sym_DOT_DOT] = ACTIONS(1871),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [835] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4111),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6943),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2986),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7065),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5819),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4342),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7419),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9334),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(835),
    [sym_preproc_endregion] = STATE(835),
    [sym_preproc_line] = STATE(835),
    [sym_preproc_pragma] = STATE(835),
    [sym_preproc_nullable] = STATE(835),
    [sym_preproc_error] = STATE(835),
    [sym_preproc_warning] = STATE(835),
    [sym_preproc_define] = STATE(835),
    [sym_preproc_undef] = STATE(835),
    [aux_sym_class_declaration_repeat1] = STATE(3840),
    [aux_sym_lambda_expression_repeat1] = STATE(4269),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1855),
    [anon_sym_ref] = ACTIONS(1857),
    [anon_sym_LBRACE] = ACTIONS(2831),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1859),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1863),
    [anon_sym_TILDE] = ACTIONS(1863),
    [anon_sym_PLUS_PLUS] = ACTIONS(1863),
    [anon_sym_DASH_DASH] = ACTIONS(1863),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1861),
    [anon_sym_DASH] = ACTIONS(1861),
    [anon_sym_STAR] = ACTIONS(1865),
    [anon_sym_CARET] = ACTIONS(1863),
    [anon_sym_AMP] = ACTIONS(1863),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1867),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1869),
    [anon_sym_DOT_DOT] = ACTIONS(1871),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [836] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4119),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6967),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5085),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3813),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9209),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(836),
    [sym_preproc_endregion] = STATE(836),
    [sym_preproc_line] = STATE(836),
    [sym_preproc_pragma] = STATE(836),
    [sym_preproc_nullable] = STATE(836),
    [sym_preproc_error] = STATE(836),
    [sym_preproc_warning] = STATE(836),
    [sym_preproc_define] = STATE(836),
    [sym_preproc_undef] = STATE(836),
    [aux_sym_class_declaration_repeat1] = STATE(3814),
    [aux_sym_lambda_expression_repeat1] = STATE(4209),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1323),
    [anon_sym_ref] = ACTIONS(1325),
    [anon_sym_LBRACE] = ACTIONS(2831),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1083),
    [anon_sym_PLUS_PLUS] = ACTIONS(1083),
    [anon_sym_DASH_DASH] = ACTIONS(1083),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1085),
    [anon_sym_DASH] = ACTIONS(1085),
    [anon_sym_STAR] = ACTIONS(1335),
    [anon_sym_CARET] = ACTIONS(1083),
    [anon_sym_AMP] = ACTIONS(1083),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1341),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1343),
    [anon_sym_DOT_DOT] = ACTIONS(1345),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [837] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4218),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6913),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2905),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6979),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5452),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4178),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7433),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9183),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(837),
    [sym_preproc_endregion] = STATE(837),
    [sym_preproc_line] = STATE(837),
    [sym_preproc_pragma] = STATE(837),
    [sym_preproc_nullable] = STATE(837),
    [sym_preproc_error] = STATE(837),
    [sym_preproc_warning] = STATE(837),
    [sym_preproc_define] = STATE(837),
    [sym_preproc_undef] = STATE(837),
    [aux_sym_class_declaration_repeat1] = STATE(3816),
    [aux_sym_lambda_expression_repeat1] = STATE(4225),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1573),
    [anon_sym_ref] = ACTIONS(1575),
    [anon_sym_LBRACE] = ACTIONS(2831),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1577),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1581),
    [anon_sym_TILDE] = ACTIONS(1581),
    [anon_sym_PLUS_PLUS] = ACTIONS(1581),
    [anon_sym_DASH_DASH] = ACTIONS(1581),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1579),
    [anon_sym_DASH] = ACTIONS(1579),
    [anon_sym_STAR] = ACTIONS(1583),
    [anon_sym_CARET] = ACTIONS(1581),
    [anon_sym_AMP] = ACTIONS(1581),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1585),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1587),
    [anon_sym_DOT_DOT] = ACTIONS(1589),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [838] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3991),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6915),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7099),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5742),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4224),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7442),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9174),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(838),
    [sym_preproc_endregion] = STATE(838),
    [sym_preproc_line] = STATE(838),
    [sym_preproc_pragma] = STATE(838),
    [sym_preproc_nullable] = STATE(838),
    [sym_preproc_error] = STATE(838),
    [sym_preproc_warning] = STATE(838),
    [sym_preproc_define] = STATE(838),
    [sym_preproc_undef] = STATE(838),
    [aux_sym_class_declaration_repeat1] = STATE(3849),
    [aux_sym_lambda_expression_repeat1] = STATE(4284),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1653),
    [anon_sym_ref] = ACTIONS(1655),
    [anon_sym_LBRACE] = ACTIONS(2835),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1659),
    [anon_sym_TILDE] = ACTIONS(1659),
    [anon_sym_PLUS_PLUS] = ACTIONS(1659),
    [anon_sym_DASH_DASH] = ACTIONS(1659),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1657),
    [anon_sym_DASH] = ACTIONS(1657),
    [anon_sym_STAR] = ACTIONS(1661),
    [anon_sym_CARET] = ACTIONS(1659),
    [anon_sym_AMP] = ACTIONS(1659),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1663),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1665),
    [anon_sym_DOT_DOT] = ACTIONS(1667),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [839] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4028),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6915),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7099),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5743),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4224),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7442),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9174),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(839),
    [sym_preproc_endregion] = STATE(839),
    [sym_preproc_line] = STATE(839),
    [sym_preproc_pragma] = STATE(839),
    [sym_preproc_nullable] = STATE(839),
    [sym_preproc_error] = STATE(839),
    [sym_preproc_warning] = STATE(839),
    [sym_preproc_define] = STATE(839),
    [sym_preproc_undef] = STATE(839),
    [aux_sym_class_declaration_repeat1] = STATE(3849),
    [aux_sym_lambda_expression_repeat1] = STATE(4284),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1653),
    [anon_sym_ref] = ACTIONS(1655),
    [anon_sym_LBRACE] = ACTIONS(2835),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1659),
    [anon_sym_TILDE] = ACTIONS(1659),
    [anon_sym_PLUS_PLUS] = ACTIONS(1659),
    [anon_sym_DASH_DASH] = ACTIONS(1659),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1657),
    [anon_sym_DASH] = ACTIONS(1657),
    [anon_sym_STAR] = ACTIONS(1661),
    [anon_sym_CARET] = ACTIONS(1659),
    [anon_sym_AMP] = ACTIONS(1659),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1663),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1665),
    [anon_sym_DOT_DOT] = ACTIONS(1667),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [840] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4030),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6915),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7099),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5745),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4224),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7442),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9174),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(840),
    [sym_preproc_endregion] = STATE(840),
    [sym_preproc_line] = STATE(840),
    [sym_preproc_pragma] = STATE(840),
    [sym_preproc_nullable] = STATE(840),
    [sym_preproc_error] = STATE(840),
    [sym_preproc_warning] = STATE(840),
    [sym_preproc_define] = STATE(840),
    [sym_preproc_undef] = STATE(840),
    [aux_sym_class_declaration_repeat1] = STATE(3849),
    [aux_sym_lambda_expression_repeat1] = STATE(4284),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1653),
    [anon_sym_ref] = ACTIONS(1655),
    [anon_sym_LBRACE] = ACTIONS(2835),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1659),
    [anon_sym_TILDE] = ACTIONS(1659),
    [anon_sym_PLUS_PLUS] = ACTIONS(1659),
    [anon_sym_DASH_DASH] = ACTIONS(1659),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1657),
    [anon_sym_DASH] = ACTIONS(1657),
    [anon_sym_STAR] = ACTIONS(1661),
    [anon_sym_CARET] = ACTIONS(1659),
    [anon_sym_AMP] = ACTIONS(1659),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1663),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1665),
    [anon_sym_DOT_DOT] = ACTIONS(1667),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [841] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4005),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6915),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7099),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5748),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4224),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7442),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9174),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(841),
    [sym_preproc_endregion] = STATE(841),
    [sym_preproc_line] = STATE(841),
    [sym_preproc_pragma] = STATE(841),
    [sym_preproc_nullable] = STATE(841),
    [sym_preproc_error] = STATE(841),
    [sym_preproc_warning] = STATE(841),
    [sym_preproc_define] = STATE(841),
    [sym_preproc_undef] = STATE(841),
    [aux_sym_class_declaration_repeat1] = STATE(3849),
    [aux_sym_lambda_expression_repeat1] = STATE(4284),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1653),
    [anon_sym_ref] = ACTIONS(1655),
    [anon_sym_LBRACE] = ACTIONS(2835),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1659),
    [anon_sym_TILDE] = ACTIONS(1659),
    [anon_sym_PLUS_PLUS] = ACTIONS(1659),
    [anon_sym_DASH_DASH] = ACTIONS(1659),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1657),
    [anon_sym_DASH] = ACTIONS(1657),
    [anon_sym_STAR] = ACTIONS(1661),
    [anon_sym_CARET] = ACTIONS(1659),
    [anon_sym_AMP] = ACTIONS(1659),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1663),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1665),
    [anon_sym_DOT_DOT] = ACTIONS(1667),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [842] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4021),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6915),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7099),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5749),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4224),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7442),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9174),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(842),
    [sym_preproc_endregion] = STATE(842),
    [sym_preproc_line] = STATE(842),
    [sym_preproc_pragma] = STATE(842),
    [sym_preproc_nullable] = STATE(842),
    [sym_preproc_error] = STATE(842),
    [sym_preproc_warning] = STATE(842),
    [sym_preproc_define] = STATE(842),
    [sym_preproc_undef] = STATE(842),
    [aux_sym_class_declaration_repeat1] = STATE(3849),
    [aux_sym_lambda_expression_repeat1] = STATE(4284),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1653),
    [anon_sym_ref] = ACTIONS(1655),
    [anon_sym_LBRACE] = ACTIONS(2835),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1659),
    [anon_sym_TILDE] = ACTIONS(1659),
    [anon_sym_PLUS_PLUS] = ACTIONS(1659),
    [anon_sym_DASH_DASH] = ACTIONS(1659),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1657),
    [anon_sym_DASH] = ACTIONS(1657),
    [anon_sym_STAR] = ACTIONS(1661),
    [anon_sym_CARET] = ACTIONS(1659),
    [anon_sym_AMP] = ACTIONS(1659),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1663),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1665),
    [anon_sym_DOT_DOT] = ACTIONS(1667),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [843] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4060),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6915),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7099),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5750),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4224),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7442),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9174),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(843),
    [sym_preproc_endregion] = STATE(843),
    [sym_preproc_line] = STATE(843),
    [sym_preproc_pragma] = STATE(843),
    [sym_preproc_nullable] = STATE(843),
    [sym_preproc_error] = STATE(843),
    [sym_preproc_warning] = STATE(843),
    [sym_preproc_define] = STATE(843),
    [sym_preproc_undef] = STATE(843),
    [aux_sym_class_declaration_repeat1] = STATE(3849),
    [aux_sym_lambda_expression_repeat1] = STATE(4284),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1653),
    [anon_sym_ref] = ACTIONS(1655),
    [anon_sym_LBRACE] = ACTIONS(2835),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1659),
    [anon_sym_TILDE] = ACTIONS(1659),
    [anon_sym_PLUS_PLUS] = ACTIONS(1659),
    [anon_sym_DASH_DASH] = ACTIONS(1659),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1657),
    [anon_sym_DASH] = ACTIONS(1657),
    [anon_sym_STAR] = ACTIONS(1661),
    [anon_sym_CARET] = ACTIONS(1659),
    [anon_sym_AMP] = ACTIONS(1659),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1663),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1665),
    [anon_sym_DOT_DOT] = ACTIONS(1667),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [844] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6943),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2986),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7066),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5820),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4342),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7419),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9334),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(844),
    [sym_preproc_endregion] = STATE(844),
    [sym_preproc_line] = STATE(844),
    [sym_preproc_pragma] = STATE(844),
    [sym_preproc_nullable] = STATE(844),
    [sym_preproc_error] = STATE(844),
    [sym_preproc_warning] = STATE(844),
    [sym_preproc_define] = STATE(844),
    [sym_preproc_undef] = STATE(844),
    [aux_sym_class_declaration_repeat1] = STATE(3840),
    [aux_sym_lambda_expression_repeat1] = STATE(4269),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1855),
    [anon_sym_ref] = ACTIONS(1857),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1859),
    [anon_sym_readonly] = ACTIONS(2767),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1863),
    [anon_sym_TILDE] = ACTIONS(1863),
    [anon_sym_PLUS_PLUS] = ACTIONS(1863),
    [anon_sym_DASH_DASH] = ACTIONS(1863),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1861),
    [anon_sym_DASH] = ACTIONS(1861),
    [anon_sym_STAR] = ACTIONS(1865),
    [anon_sym_CARET] = ACTIONS(1863),
    [anon_sym_AMP] = ACTIONS(1863),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1867),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1869),
    [anon_sym_DOT_DOT] = ACTIONS(1871),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [845] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6915),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7100),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5627),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4224),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7442),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9174),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(845),
    [sym_preproc_endregion] = STATE(845),
    [sym_preproc_line] = STATE(845),
    [sym_preproc_pragma] = STATE(845),
    [sym_preproc_nullable] = STATE(845),
    [sym_preproc_error] = STATE(845),
    [sym_preproc_warning] = STATE(845),
    [sym_preproc_define] = STATE(845),
    [sym_preproc_undef] = STATE(845),
    [aux_sym_class_declaration_repeat1] = STATE(3849),
    [aux_sym_lambda_expression_repeat1] = STATE(4284),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1653),
    [anon_sym_ref] = ACTIONS(1655),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_readonly] = ACTIONS(2767),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1659),
    [anon_sym_TILDE] = ACTIONS(1659),
    [anon_sym_PLUS_PLUS] = ACTIONS(1659),
    [anon_sym_DASH_DASH] = ACTIONS(1659),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1657),
    [anon_sym_DASH] = ACTIONS(1657),
    [anon_sym_STAR] = ACTIONS(1661),
    [anon_sym_CARET] = ACTIONS(1659),
    [anon_sym_AMP] = ACTIONS(1659),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1663),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1665),
    [anon_sym_DOT_DOT] = ACTIONS(1667),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [846] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4218),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6967),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5093),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3813),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9209),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(846),
    [sym_preproc_endregion] = STATE(846),
    [sym_preproc_line] = STATE(846),
    [sym_preproc_pragma] = STATE(846),
    [sym_preproc_nullable] = STATE(846),
    [sym_preproc_error] = STATE(846),
    [sym_preproc_warning] = STATE(846),
    [sym_preproc_define] = STATE(846),
    [sym_preproc_undef] = STATE(846),
    [aux_sym_class_declaration_repeat1] = STATE(3814),
    [aux_sym_lambda_expression_repeat1] = STATE(4209),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1323),
    [anon_sym_ref] = ACTIONS(1325),
    [anon_sym_LBRACE] = ACTIONS(2831),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1083),
    [anon_sym_PLUS_PLUS] = ACTIONS(1083),
    [anon_sym_DASH_DASH] = ACTIONS(1083),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1085),
    [anon_sym_DASH] = ACTIONS(1085),
    [anon_sym_STAR] = ACTIONS(1335),
    [anon_sym_CARET] = ACTIONS(1083),
    [anon_sym_AMP] = ACTIONS(1083),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1341),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1343),
    [anon_sym_DOT_DOT] = ACTIONS(1345),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [847] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3637),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6932),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2977),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6996),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6309),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4378),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7430),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9693),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(847),
    [sym_preproc_endregion] = STATE(847),
    [sym_preproc_line] = STATE(847),
    [sym_preproc_pragma] = STATE(847),
    [sym_preproc_nullable] = STATE(847),
    [sym_preproc_error] = STATE(847),
    [sym_preproc_warning] = STATE(847),
    [sym_preproc_define] = STATE(847),
    [sym_preproc_undef] = STATE(847),
    [aux_sym_class_declaration_repeat1] = STATE(3820),
    [aux_sym_lambda_expression_repeat1] = STATE(4234),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2127),
    [anon_sym_ref] = ACTIONS(2129),
    [anon_sym_LBRACE] = ACTIONS(2825),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2131),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2135),
    [anon_sym_TILDE] = ACTIONS(2135),
    [anon_sym_PLUS_PLUS] = ACTIONS(2135),
    [anon_sym_DASH_DASH] = ACTIONS(2135),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2133),
    [anon_sym_DASH] = ACTIONS(2133),
    [anon_sym_STAR] = ACTIONS(2137),
    [anon_sym_CARET] = ACTIONS(2135),
    [anon_sym_AMP] = ACTIONS(2135),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2139),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2141),
    [anon_sym_DOT_DOT] = ACTIONS(2143),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [848] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6922),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2984),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7156),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6554),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4541),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7435),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9148),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(848),
    [sym_preproc_endregion] = STATE(848),
    [sym_preproc_line] = STATE(848),
    [sym_preproc_pragma] = STATE(848),
    [sym_preproc_nullable] = STATE(848),
    [sym_preproc_error] = STATE(848),
    [sym_preproc_warning] = STATE(848),
    [sym_preproc_define] = STATE(848),
    [sym_preproc_undef] = STATE(848),
    [aux_sym_class_declaration_repeat1] = STATE(3876),
    [aux_sym_lambda_expression_repeat1] = STATE(4317),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2231),
    [anon_sym_ref] = ACTIONS(2233),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2235),
    [anon_sym_readonly] = ACTIONS(2767),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2239),
    [anon_sym_TILDE] = ACTIONS(2239),
    [anon_sym_PLUS_PLUS] = ACTIONS(2239),
    [anon_sym_DASH_DASH] = ACTIONS(2239),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2237),
    [anon_sym_DASH] = ACTIONS(2237),
    [anon_sym_STAR] = ACTIONS(2241),
    [anon_sym_CARET] = ACTIONS(2239),
    [anon_sym_AMP] = ACTIONS(2239),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2243),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2245),
    [anon_sym_DOT_DOT] = ACTIONS(2247),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [849] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3714),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6932),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2977),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6996),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6311),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4378),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7430),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9693),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(849),
    [sym_preproc_endregion] = STATE(849),
    [sym_preproc_line] = STATE(849),
    [sym_preproc_pragma] = STATE(849),
    [sym_preproc_nullable] = STATE(849),
    [sym_preproc_error] = STATE(849),
    [sym_preproc_warning] = STATE(849),
    [sym_preproc_define] = STATE(849),
    [sym_preproc_undef] = STATE(849),
    [aux_sym_class_declaration_repeat1] = STATE(3820),
    [aux_sym_lambda_expression_repeat1] = STATE(4234),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2127),
    [anon_sym_ref] = ACTIONS(2129),
    [anon_sym_LBRACE] = ACTIONS(2825),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2131),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2135),
    [anon_sym_TILDE] = ACTIONS(2135),
    [anon_sym_PLUS_PLUS] = ACTIONS(2135),
    [anon_sym_DASH_DASH] = ACTIONS(2135),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2133),
    [anon_sym_DASH] = ACTIONS(2133),
    [anon_sym_STAR] = ACTIONS(2137),
    [anon_sym_CARET] = ACTIONS(2135),
    [anon_sym_AMP] = ACTIONS(2135),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2139),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2141),
    [anon_sym_DOT_DOT] = ACTIONS(2143),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [850] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3641),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6932),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2977),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6996),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6224),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4378),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7430),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9693),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(850),
    [sym_preproc_endregion] = STATE(850),
    [sym_preproc_line] = STATE(850),
    [sym_preproc_pragma] = STATE(850),
    [sym_preproc_nullable] = STATE(850),
    [sym_preproc_error] = STATE(850),
    [sym_preproc_warning] = STATE(850),
    [sym_preproc_define] = STATE(850),
    [sym_preproc_undef] = STATE(850),
    [aux_sym_class_declaration_repeat1] = STATE(3820),
    [aux_sym_lambda_expression_repeat1] = STATE(4234),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2127),
    [anon_sym_ref] = ACTIONS(2129),
    [anon_sym_LBRACE] = ACTIONS(2825),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2131),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2135),
    [anon_sym_TILDE] = ACTIONS(2135),
    [anon_sym_PLUS_PLUS] = ACTIONS(2135),
    [anon_sym_DASH_DASH] = ACTIONS(2135),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2133),
    [anon_sym_DASH] = ACTIONS(2133),
    [anon_sym_STAR] = ACTIONS(2137),
    [anon_sym_CARET] = ACTIONS(2135),
    [anon_sym_AMP] = ACTIONS(2135),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2139),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2141),
    [anon_sym_DOT_DOT] = ACTIONS(2143),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [851] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4101),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6967),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5096),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3813),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9209),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(851),
    [sym_preproc_endregion] = STATE(851),
    [sym_preproc_line] = STATE(851),
    [sym_preproc_pragma] = STATE(851),
    [sym_preproc_nullable] = STATE(851),
    [sym_preproc_error] = STATE(851),
    [sym_preproc_warning] = STATE(851),
    [sym_preproc_define] = STATE(851),
    [sym_preproc_undef] = STATE(851),
    [aux_sym_class_declaration_repeat1] = STATE(3814),
    [aux_sym_lambda_expression_repeat1] = STATE(4209),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1323),
    [anon_sym_ref] = ACTIONS(1325),
    [anon_sym_LBRACE] = ACTIONS(2831),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1083),
    [anon_sym_PLUS_PLUS] = ACTIONS(1083),
    [anon_sym_DASH_DASH] = ACTIONS(1083),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1085),
    [anon_sym_DASH] = ACTIONS(1085),
    [anon_sym_STAR] = ACTIONS(1335),
    [anon_sym_CARET] = ACTIONS(1083),
    [anon_sym_AMP] = ACTIONS(1083),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1341),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1343),
    [anon_sym_DOT_DOT] = ACTIONS(1345),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [852] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4102),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6967),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5098),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3813),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9209),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(852),
    [sym_preproc_endregion] = STATE(852),
    [sym_preproc_line] = STATE(852),
    [sym_preproc_pragma] = STATE(852),
    [sym_preproc_nullable] = STATE(852),
    [sym_preproc_error] = STATE(852),
    [sym_preproc_warning] = STATE(852),
    [sym_preproc_define] = STATE(852),
    [sym_preproc_undef] = STATE(852),
    [aux_sym_class_declaration_repeat1] = STATE(3814),
    [aux_sym_lambda_expression_repeat1] = STATE(4209),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1323),
    [anon_sym_ref] = ACTIONS(1325),
    [anon_sym_LBRACE] = ACTIONS(2831),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1083),
    [anon_sym_PLUS_PLUS] = ACTIONS(1083),
    [anon_sym_DASH_DASH] = ACTIONS(1083),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1085),
    [anon_sym_DASH] = ACTIONS(1085),
    [anon_sym_STAR] = ACTIONS(1335),
    [anon_sym_CARET] = ACTIONS(1083),
    [anon_sym_AMP] = ACTIONS(1083),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1341),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1343),
    [anon_sym_DOT_DOT] = ACTIONS(1345),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [853] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3763),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6922),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2984),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7155),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6611),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4541),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7435),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9148),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(853),
    [sym_preproc_endregion] = STATE(853),
    [sym_preproc_line] = STATE(853),
    [sym_preproc_pragma] = STATE(853),
    [sym_preproc_nullable] = STATE(853),
    [sym_preproc_error] = STATE(853),
    [sym_preproc_warning] = STATE(853),
    [sym_preproc_define] = STATE(853),
    [sym_preproc_undef] = STATE(853),
    [aux_sym_class_declaration_repeat1] = STATE(3876),
    [aux_sym_lambda_expression_repeat1] = STATE(4317),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2231),
    [anon_sym_ref] = ACTIONS(2233),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2235),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2239),
    [anon_sym_TILDE] = ACTIONS(2239),
    [anon_sym_PLUS_PLUS] = ACTIONS(2239),
    [anon_sym_DASH_DASH] = ACTIONS(2239),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2237),
    [anon_sym_DASH] = ACTIONS(2237),
    [anon_sym_STAR] = ACTIONS(2241),
    [anon_sym_CARET] = ACTIONS(2239),
    [anon_sym_AMP] = ACTIONS(2239),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2243),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2245),
    [anon_sym_DOT_DOT] = ACTIONS(2247),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [854] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3764),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6922),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2984),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7155),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6622),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4541),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7435),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9148),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(854),
    [sym_preproc_endregion] = STATE(854),
    [sym_preproc_line] = STATE(854),
    [sym_preproc_pragma] = STATE(854),
    [sym_preproc_nullable] = STATE(854),
    [sym_preproc_error] = STATE(854),
    [sym_preproc_warning] = STATE(854),
    [sym_preproc_define] = STATE(854),
    [sym_preproc_undef] = STATE(854),
    [aux_sym_class_declaration_repeat1] = STATE(3876),
    [aux_sym_lambda_expression_repeat1] = STATE(4317),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2231),
    [anon_sym_ref] = ACTIONS(2233),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2235),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2239),
    [anon_sym_TILDE] = ACTIONS(2239),
    [anon_sym_PLUS_PLUS] = ACTIONS(2239),
    [anon_sym_DASH_DASH] = ACTIONS(2239),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2237),
    [anon_sym_DASH] = ACTIONS(2237),
    [anon_sym_STAR] = ACTIONS(2241),
    [anon_sym_CARET] = ACTIONS(2239),
    [anon_sym_AMP] = ACTIONS(2239),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2243),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2245),
    [anon_sym_DOT_DOT] = ACTIONS(2247),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [855] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4111),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6967),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5099),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3813),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9209),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(855),
    [sym_preproc_endregion] = STATE(855),
    [sym_preproc_line] = STATE(855),
    [sym_preproc_pragma] = STATE(855),
    [sym_preproc_nullable] = STATE(855),
    [sym_preproc_error] = STATE(855),
    [sym_preproc_warning] = STATE(855),
    [sym_preproc_define] = STATE(855),
    [sym_preproc_undef] = STATE(855),
    [aux_sym_class_declaration_repeat1] = STATE(3814),
    [aux_sym_lambda_expression_repeat1] = STATE(4209),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1323),
    [anon_sym_ref] = ACTIONS(1325),
    [anon_sym_LBRACE] = ACTIONS(2831),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1083),
    [anon_sym_PLUS_PLUS] = ACTIONS(1083),
    [anon_sym_DASH_DASH] = ACTIONS(1083),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1085),
    [anon_sym_DASH] = ACTIONS(1085),
    [anon_sym_STAR] = ACTIONS(1335),
    [anon_sym_CARET] = ACTIONS(1083),
    [anon_sym_AMP] = ACTIONS(1083),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1341),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1343),
    [anon_sym_DOT_DOT] = ACTIONS(1345),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [856] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3780),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6922),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2984),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7155),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6625),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4541),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7435),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9148),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(856),
    [sym_preproc_endregion] = STATE(856),
    [sym_preproc_line] = STATE(856),
    [sym_preproc_pragma] = STATE(856),
    [sym_preproc_nullable] = STATE(856),
    [sym_preproc_error] = STATE(856),
    [sym_preproc_warning] = STATE(856),
    [sym_preproc_define] = STATE(856),
    [sym_preproc_undef] = STATE(856),
    [aux_sym_class_declaration_repeat1] = STATE(3876),
    [aux_sym_lambda_expression_repeat1] = STATE(4317),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2231),
    [anon_sym_ref] = ACTIONS(2233),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2235),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2239),
    [anon_sym_TILDE] = ACTIONS(2239),
    [anon_sym_PLUS_PLUS] = ACTIONS(2239),
    [anon_sym_DASH_DASH] = ACTIONS(2239),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2237),
    [anon_sym_DASH] = ACTIONS(2237),
    [anon_sym_STAR] = ACTIONS(2241),
    [anon_sym_CARET] = ACTIONS(2239),
    [anon_sym_AMP] = ACTIONS(2239),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2243),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2245),
    [anon_sym_DOT_DOT] = ACTIONS(2247),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [857] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3735),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6922),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2984),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7155),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6627),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4541),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7435),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9148),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(857),
    [sym_preproc_endregion] = STATE(857),
    [sym_preproc_line] = STATE(857),
    [sym_preproc_pragma] = STATE(857),
    [sym_preproc_nullable] = STATE(857),
    [sym_preproc_error] = STATE(857),
    [sym_preproc_warning] = STATE(857),
    [sym_preproc_define] = STATE(857),
    [sym_preproc_undef] = STATE(857),
    [aux_sym_class_declaration_repeat1] = STATE(3876),
    [aux_sym_lambda_expression_repeat1] = STATE(4317),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2231),
    [anon_sym_ref] = ACTIONS(2233),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2235),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2239),
    [anon_sym_TILDE] = ACTIONS(2239),
    [anon_sym_PLUS_PLUS] = ACTIONS(2239),
    [anon_sym_DASH_DASH] = ACTIONS(2239),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2237),
    [anon_sym_DASH] = ACTIONS(2237),
    [anon_sym_STAR] = ACTIONS(2241),
    [anon_sym_CARET] = ACTIONS(2239),
    [anon_sym_AMP] = ACTIONS(2239),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2243),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2245),
    [anon_sym_DOT_DOT] = ACTIONS(2247),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [858] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3741),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6922),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2984),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7155),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6629),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4541),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7435),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9148),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(858),
    [sym_preproc_endregion] = STATE(858),
    [sym_preproc_line] = STATE(858),
    [sym_preproc_pragma] = STATE(858),
    [sym_preproc_nullable] = STATE(858),
    [sym_preproc_error] = STATE(858),
    [sym_preproc_warning] = STATE(858),
    [sym_preproc_define] = STATE(858),
    [sym_preproc_undef] = STATE(858),
    [aux_sym_class_declaration_repeat1] = STATE(3876),
    [aux_sym_lambda_expression_repeat1] = STATE(4317),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2231),
    [anon_sym_ref] = ACTIONS(2233),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2235),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2239),
    [anon_sym_TILDE] = ACTIONS(2239),
    [anon_sym_PLUS_PLUS] = ACTIONS(2239),
    [anon_sym_DASH_DASH] = ACTIONS(2239),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2237),
    [anon_sym_DASH] = ACTIONS(2237),
    [anon_sym_STAR] = ACTIONS(2241),
    [anon_sym_CARET] = ACTIONS(2239),
    [anon_sym_AMP] = ACTIONS(2239),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2243),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2245),
    [anon_sym_DOT_DOT] = ACTIONS(2247),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [859] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3754),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6922),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2984),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7155),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6630),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4541),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7435),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9148),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(859),
    [sym_preproc_endregion] = STATE(859),
    [sym_preproc_line] = STATE(859),
    [sym_preproc_pragma] = STATE(859),
    [sym_preproc_nullable] = STATE(859),
    [sym_preproc_error] = STATE(859),
    [sym_preproc_warning] = STATE(859),
    [sym_preproc_define] = STATE(859),
    [sym_preproc_undef] = STATE(859),
    [aux_sym_class_declaration_repeat1] = STATE(3876),
    [aux_sym_lambda_expression_repeat1] = STATE(4317),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2231),
    [anon_sym_ref] = ACTIONS(2233),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2235),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2239),
    [anon_sym_TILDE] = ACTIONS(2239),
    [anon_sym_PLUS_PLUS] = ACTIONS(2239),
    [anon_sym_DASH_DASH] = ACTIONS(2239),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2237),
    [anon_sym_DASH] = ACTIONS(2237),
    [anon_sym_STAR] = ACTIONS(2241),
    [anon_sym_CARET] = ACTIONS(2239),
    [anon_sym_AMP] = ACTIONS(2239),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2243),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2245),
    [anon_sym_DOT_DOT] = ACTIONS(2247),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [860] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6714),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2829),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(2855),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6045),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(860),
    [sym_preproc_endregion] = STATE(860),
    [sym_preproc_line] = STATE(860),
    [sym_preproc_pragma] = STATE(860),
    [sym_preproc_nullable] = STATE(860),
    [sym_preproc_error] = STATE(860),
    [sym_preproc_warning] = STATE(860),
    [sym_preproc_define] = STATE(860),
    [sym_preproc_undef] = STATE(860),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_ref] = ACTIONS(2593),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(2833),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2319),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2607),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [861] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3689),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6932),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2977),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6996),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6156),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4378),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7430),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9693),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(861),
    [sym_preproc_endregion] = STATE(861),
    [sym_preproc_line] = STATE(861),
    [sym_preproc_pragma] = STATE(861),
    [sym_preproc_nullable] = STATE(861),
    [sym_preproc_error] = STATE(861),
    [sym_preproc_warning] = STATE(861),
    [sym_preproc_define] = STATE(861),
    [sym_preproc_undef] = STATE(861),
    [aux_sym_class_declaration_repeat1] = STATE(3820),
    [aux_sym_lambda_expression_repeat1] = STATE(4234),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2127),
    [anon_sym_ref] = ACTIONS(2129),
    [anon_sym_LBRACE] = ACTIONS(2825),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2131),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2135),
    [anon_sym_TILDE] = ACTIONS(2135),
    [anon_sym_PLUS_PLUS] = ACTIONS(2135),
    [anon_sym_DASH_DASH] = ACTIONS(2135),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2133),
    [anon_sym_DASH] = ACTIONS(2133),
    [anon_sym_STAR] = ACTIONS(2137),
    [anon_sym_CARET] = ACTIONS(2135),
    [anon_sym_AMP] = ACTIONS(2135),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2139),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2141),
    [anon_sym_DOT_DOT] = ACTIONS(2143),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [862] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6937),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2861),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7002),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5620),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4149),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7445),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9763),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(862),
    [sym_preproc_endregion] = STATE(862),
    [sym_preproc_line] = STATE(862),
    [sym_preproc_pragma] = STATE(862),
    [sym_preproc_nullable] = STATE(862),
    [sym_preproc_error] = STATE(862),
    [sym_preproc_warning] = STATE(862),
    [sym_preproc_define] = STATE(862),
    [sym_preproc_undef] = STATE(862),
    [aux_sym_class_declaration_repeat1] = STATE(3821),
    [aux_sym_lambda_expression_repeat1] = STATE(4236),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1609),
    [anon_sym_ref] = ACTIONS(1611),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1481),
    [anon_sym_readonly] = ACTIONS(2767),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1615),
    [anon_sym_TILDE] = ACTIONS(1615),
    [anon_sym_PLUS_PLUS] = ACTIONS(1615),
    [anon_sym_DASH_DASH] = ACTIONS(1615),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1613),
    [anon_sym_DASH] = ACTIONS(1613),
    [anon_sym_STAR] = ACTIONS(1487),
    [anon_sym_CARET] = ACTIONS(1615),
    [anon_sym_AMP] = ACTIONS(1615),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1617),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1619),
    [anon_sym_DOT_DOT] = ACTIONS(1621),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [863] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3692),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6932),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2977),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6996),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6132),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4378),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7430),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9693),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(863),
    [sym_preproc_endregion] = STATE(863),
    [sym_preproc_line] = STATE(863),
    [sym_preproc_pragma] = STATE(863),
    [sym_preproc_nullable] = STATE(863),
    [sym_preproc_error] = STATE(863),
    [sym_preproc_warning] = STATE(863),
    [sym_preproc_define] = STATE(863),
    [sym_preproc_undef] = STATE(863),
    [aux_sym_class_declaration_repeat1] = STATE(3820),
    [aux_sym_lambda_expression_repeat1] = STATE(4234),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2127),
    [anon_sym_ref] = ACTIONS(2129),
    [anon_sym_LBRACE] = ACTIONS(2825),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2131),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2135),
    [anon_sym_TILDE] = ACTIONS(2135),
    [anon_sym_PLUS_PLUS] = ACTIONS(2135),
    [anon_sym_DASH_DASH] = ACTIONS(2135),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2133),
    [anon_sym_DASH] = ACTIONS(2133),
    [anon_sym_STAR] = ACTIONS(2137),
    [anon_sym_CARET] = ACTIONS(2135),
    [anon_sym_AMP] = ACTIONS(2135),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2139),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2141),
    [anon_sym_DOT_DOT] = ACTIONS(2143),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [864] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4152),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6922),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2984),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7069),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5858),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4344),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7423),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9604),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(864),
    [sym_preproc_endregion] = STATE(864),
    [sym_preproc_line] = STATE(864),
    [sym_preproc_pragma] = STATE(864),
    [sym_preproc_nullable] = STATE(864),
    [sym_preproc_error] = STATE(864),
    [sym_preproc_warning] = STATE(864),
    [sym_preproc_define] = STATE(864),
    [sym_preproc_undef] = STATE(864),
    [aux_sym_class_declaration_repeat1] = STATE(3841),
    [aux_sym_lambda_expression_repeat1] = STATE(4271),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1875),
    [anon_sym_ref] = ACTIONS(1877),
    [anon_sym_LBRACE] = ACTIONS(2831),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1879),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1883),
    [anon_sym_TILDE] = ACTIONS(1883),
    [anon_sym_PLUS_PLUS] = ACTIONS(1883),
    [anon_sym_DASH_DASH] = ACTIONS(1883),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1881),
    [anon_sym_DASH] = ACTIONS(1881),
    [anon_sym_STAR] = ACTIONS(1885),
    [anon_sym_CARET] = ACTIONS(1883),
    [anon_sym_AMP] = ACTIONS(1883),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1887),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1889),
    [anon_sym_DOT_DOT] = ACTIONS(1891),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [865] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4119),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6922),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2984),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7069),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5859),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4344),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7423),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9604),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(865),
    [sym_preproc_endregion] = STATE(865),
    [sym_preproc_line] = STATE(865),
    [sym_preproc_pragma] = STATE(865),
    [sym_preproc_nullable] = STATE(865),
    [sym_preproc_error] = STATE(865),
    [sym_preproc_warning] = STATE(865),
    [sym_preproc_define] = STATE(865),
    [sym_preproc_undef] = STATE(865),
    [aux_sym_class_declaration_repeat1] = STATE(3841),
    [aux_sym_lambda_expression_repeat1] = STATE(4271),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1875),
    [anon_sym_ref] = ACTIONS(1877),
    [anon_sym_LBRACE] = ACTIONS(2831),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1879),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1883),
    [anon_sym_TILDE] = ACTIONS(1883),
    [anon_sym_PLUS_PLUS] = ACTIONS(1883),
    [anon_sym_DASH_DASH] = ACTIONS(1883),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1881),
    [anon_sym_DASH] = ACTIONS(1881),
    [anon_sym_STAR] = ACTIONS(1885),
    [anon_sym_CARET] = ACTIONS(1883),
    [anon_sym_AMP] = ACTIONS(1883),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1887),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1889),
    [anon_sym_DOT_DOT] = ACTIONS(1891),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [866] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4218),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6922),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2984),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7069),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5860),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4344),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7423),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9604),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(866),
    [sym_preproc_endregion] = STATE(866),
    [sym_preproc_line] = STATE(866),
    [sym_preproc_pragma] = STATE(866),
    [sym_preproc_nullable] = STATE(866),
    [sym_preproc_error] = STATE(866),
    [sym_preproc_warning] = STATE(866),
    [sym_preproc_define] = STATE(866),
    [sym_preproc_undef] = STATE(866),
    [aux_sym_class_declaration_repeat1] = STATE(3841),
    [aux_sym_lambda_expression_repeat1] = STATE(4271),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1875),
    [anon_sym_ref] = ACTIONS(1877),
    [anon_sym_LBRACE] = ACTIONS(2831),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1879),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1883),
    [anon_sym_TILDE] = ACTIONS(1883),
    [anon_sym_PLUS_PLUS] = ACTIONS(1883),
    [anon_sym_DASH_DASH] = ACTIONS(1883),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1881),
    [anon_sym_DASH] = ACTIONS(1881),
    [anon_sym_STAR] = ACTIONS(1885),
    [anon_sym_CARET] = ACTIONS(1883),
    [anon_sym_AMP] = ACTIONS(1883),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1887),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1889),
    [anon_sym_DOT_DOT] = ACTIONS(1891),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [867] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4101),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6922),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2984),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7069),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5862),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4344),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7423),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9604),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(867),
    [sym_preproc_endregion] = STATE(867),
    [sym_preproc_line] = STATE(867),
    [sym_preproc_pragma] = STATE(867),
    [sym_preproc_nullable] = STATE(867),
    [sym_preproc_error] = STATE(867),
    [sym_preproc_warning] = STATE(867),
    [sym_preproc_define] = STATE(867),
    [sym_preproc_undef] = STATE(867),
    [aux_sym_class_declaration_repeat1] = STATE(3841),
    [aux_sym_lambda_expression_repeat1] = STATE(4271),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1875),
    [anon_sym_ref] = ACTIONS(1877),
    [anon_sym_LBRACE] = ACTIONS(2831),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1879),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1883),
    [anon_sym_TILDE] = ACTIONS(1883),
    [anon_sym_PLUS_PLUS] = ACTIONS(1883),
    [anon_sym_DASH_DASH] = ACTIONS(1883),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1881),
    [anon_sym_DASH] = ACTIONS(1881),
    [anon_sym_STAR] = ACTIONS(1885),
    [anon_sym_CARET] = ACTIONS(1883),
    [anon_sym_AMP] = ACTIONS(1883),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1887),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1889),
    [anon_sym_DOT_DOT] = ACTIONS(1891),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [868] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4102),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6922),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2984),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7069),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5863),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4344),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7423),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9604),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(868),
    [sym_preproc_endregion] = STATE(868),
    [sym_preproc_line] = STATE(868),
    [sym_preproc_pragma] = STATE(868),
    [sym_preproc_nullable] = STATE(868),
    [sym_preproc_error] = STATE(868),
    [sym_preproc_warning] = STATE(868),
    [sym_preproc_define] = STATE(868),
    [sym_preproc_undef] = STATE(868),
    [aux_sym_class_declaration_repeat1] = STATE(3841),
    [aux_sym_lambda_expression_repeat1] = STATE(4271),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1875),
    [anon_sym_ref] = ACTIONS(1877),
    [anon_sym_LBRACE] = ACTIONS(2831),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1879),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1883),
    [anon_sym_TILDE] = ACTIONS(1883),
    [anon_sym_PLUS_PLUS] = ACTIONS(1883),
    [anon_sym_DASH_DASH] = ACTIONS(1883),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1881),
    [anon_sym_DASH] = ACTIONS(1881),
    [anon_sym_STAR] = ACTIONS(1885),
    [anon_sym_CARET] = ACTIONS(1883),
    [anon_sym_AMP] = ACTIONS(1883),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1887),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1889),
    [anon_sym_DOT_DOT] = ACTIONS(1891),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [869] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4111),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6922),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2984),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7069),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5864),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4344),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7423),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9604),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(869),
    [sym_preproc_endregion] = STATE(869),
    [sym_preproc_line] = STATE(869),
    [sym_preproc_pragma] = STATE(869),
    [sym_preproc_nullable] = STATE(869),
    [sym_preproc_error] = STATE(869),
    [sym_preproc_warning] = STATE(869),
    [sym_preproc_define] = STATE(869),
    [sym_preproc_undef] = STATE(869),
    [aux_sym_class_declaration_repeat1] = STATE(3841),
    [aux_sym_lambda_expression_repeat1] = STATE(4271),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1875),
    [anon_sym_ref] = ACTIONS(1877),
    [anon_sym_LBRACE] = ACTIONS(2831),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1879),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1883),
    [anon_sym_TILDE] = ACTIONS(1883),
    [anon_sym_PLUS_PLUS] = ACTIONS(1883),
    [anon_sym_DASH_DASH] = ACTIONS(1883),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1881),
    [anon_sym_DASH] = ACTIONS(1881),
    [anon_sym_STAR] = ACTIONS(1885),
    [anon_sym_CARET] = ACTIONS(1883),
    [anon_sym_AMP] = ACTIONS(1883),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1887),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1889),
    [anon_sym_DOT_DOT] = ACTIONS(1891),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [870] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6922),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2984),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7070),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5865),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4344),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7423),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9604),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(870),
    [sym_preproc_endregion] = STATE(870),
    [sym_preproc_line] = STATE(870),
    [sym_preproc_pragma] = STATE(870),
    [sym_preproc_nullable] = STATE(870),
    [sym_preproc_error] = STATE(870),
    [sym_preproc_warning] = STATE(870),
    [sym_preproc_define] = STATE(870),
    [sym_preproc_undef] = STATE(870),
    [aux_sym_class_declaration_repeat1] = STATE(3841),
    [aux_sym_lambda_expression_repeat1] = STATE(4271),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1875),
    [anon_sym_ref] = ACTIONS(1877),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1879),
    [anon_sym_readonly] = ACTIONS(2767),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1883),
    [anon_sym_TILDE] = ACTIONS(1883),
    [anon_sym_PLUS_PLUS] = ACTIONS(1883),
    [anon_sym_DASH_DASH] = ACTIONS(1883),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1881),
    [anon_sym_DASH] = ACTIONS(1881),
    [anon_sym_STAR] = ACTIONS(1885),
    [anon_sym_CARET] = ACTIONS(1883),
    [anon_sym_AMP] = ACTIONS(1883),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1887),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1889),
    [anon_sym_DOT_DOT] = ACTIONS(1891),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [871] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3991),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6912),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2912),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7040),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5297),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3963),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7448),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9641),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(871),
    [sym_preproc_endregion] = STATE(871),
    [sym_preproc_line] = STATE(871),
    [sym_preproc_pragma] = STATE(871),
    [sym_preproc_nullable] = STATE(871),
    [sym_preproc_error] = STATE(871),
    [sym_preproc_warning] = STATE(871),
    [sym_preproc_define] = STATE(871),
    [sym_preproc_undef] = STATE(871),
    [aux_sym_class_declaration_repeat1] = STATE(3831),
    [aux_sym_lambda_expression_repeat1] = STATE(4257),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1785),
    [anon_sym_ref] = ACTIONS(1787),
    [anon_sym_LBRACE] = ACTIONS(2835),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1595),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1791),
    [anon_sym_TILDE] = ACTIONS(1791),
    [anon_sym_PLUS_PLUS] = ACTIONS(1791),
    [anon_sym_DASH_DASH] = ACTIONS(1791),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1789),
    [anon_sym_DASH] = ACTIONS(1789),
    [anon_sym_STAR] = ACTIONS(1793),
    [anon_sym_CARET] = ACTIONS(1791),
    [anon_sym_AMP] = ACTIONS(1791),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1795),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1797),
    [anon_sym_DOT_DOT] = ACTIONS(1799),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [872] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4028),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6912),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2912),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7040),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5380),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3963),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7448),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9641),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(872),
    [sym_preproc_endregion] = STATE(872),
    [sym_preproc_line] = STATE(872),
    [sym_preproc_pragma] = STATE(872),
    [sym_preproc_nullable] = STATE(872),
    [sym_preproc_error] = STATE(872),
    [sym_preproc_warning] = STATE(872),
    [sym_preproc_define] = STATE(872),
    [sym_preproc_undef] = STATE(872),
    [aux_sym_class_declaration_repeat1] = STATE(3831),
    [aux_sym_lambda_expression_repeat1] = STATE(4257),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1785),
    [anon_sym_ref] = ACTIONS(1787),
    [anon_sym_LBRACE] = ACTIONS(2835),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1595),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1791),
    [anon_sym_TILDE] = ACTIONS(1791),
    [anon_sym_PLUS_PLUS] = ACTIONS(1791),
    [anon_sym_DASH_DASH] = ACTIONS(1791),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1789),
    [anon_sym_DASH] = ACTIONS(1789),
    [anon_sym_STAR] = ACTIONS(1793),
    [anon_sym_CARET] = ACTIONS(1791),
    [anon_sym_AMP] = ACTIONS(1791),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1795),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1797),
    [anon_sym_DOT_DOT] = ACTIONS(1799),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [873] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4152),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6913),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2905),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6979),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5450),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4178),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7433),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9183),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(873),
    [sym_preproc_endregion] = STATE(873),
    [sym_preproc_line] = STATE(873),
    [sym_preproc_pragma] = STATE(873),
    [sym_preproc_nullable] = STATE(873),
    [sym_preproc_error] = STATE(873),
    [sym_preproc_warning] = STATE(873),
    [sym_preproc_define] = STATE(873),
    [sym_preproc_undef] = STATE(873),
    [aux_sym_class_declaration_repeat1] = STATE(3816),
    [aux_sym_lambda_expression_repeat1] = STATE(4225),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1573),
    [anon_sym_ref] = ACTIONS(1575),
    [anon_sym_LBRACE] = ACTIONS(2831),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1577),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1581),
    [anon_sym_TILDE] = ACTIONS(1581),
    [anon_sym_PLUS_PLUS] = ACTIONS(1581),
    [anon_sym_DASH_DASH] = ACTIONS(1581),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1579),
    [anon_sym_DASH] = ACTIONS(1579),
    [anon_sym_STAR] = ACTIONS(1583),
    [anon_sym_CARET] = ACTIONS(1581),
    [anon_sym_AMP] = ACTIONS(1581),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1585),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1587),
    [anon_sym_DOT_DOT] = ACTIONS(1589),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [874] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6964),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5867),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8472),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(874),
    [sym_preproc_endregion] = STATE(874),
    [sym_preproc_line] = STATE(874),
    [sym_preproc_pragma] = STATE(874),
    [sym_preproc_nullable] = STATE(874),
    [sym_preproc_error] = STATE(874),
    [sym_preproc_warning] = STATE(874),
    [sym_preproc_define] = STATE(874),
    [sym_preproc_undef] = STATE(874),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [875] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3708),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6932),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2977),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6996),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6134),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4378),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7430),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9693),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(875),
    [sym_preproc_endregion] = STATE(875),
    [sym_preproc_line] = STATE(875),
    [sym_preproc_pragma] = STATE(875),
    [sym_preproc_nullable] = STATE(875),
    [sym_preproc_error] = STATE(875),
    [sym_preproc_warning] = STATE(875),
    [sym_preproc_define] = STATE(875),
    [sym_preproc_undef] = STATE(875),
    [aux_sym_class_declaration_repeat1] = STATE(3820),
    [aux_sym_lambda_expression_repeat1] = STATE(4234),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2127),
    [anon_sym_ref] = ACTIONS(2129),
    [anon_sym_LBRACE] = ACTIONS(2825),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2131),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2135),
    [anon_sym_TILDE] = ACTIONS(2135),
    [anon_sym_PLUS_PLUS] = ACTIONS(2135),
    [anon_sym_DASH_DASH] = ACTIONS(2135),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2133),
    [anon_sym_DASH] = ACTIONS(2133),
    [anon_sym_STAR] = ACTIONS(2137),
    [anon_sym_CARET] = ACTIONS(2135),
    [anon_sym_AMP] = ACTIONS(2135),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2139),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2141),
    [anon_sym_DOT_DOT] = ACTIONS(2143),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [876] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4030),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6912),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2912),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7040),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5276),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3963),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7448),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9641),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(876),
    [sym_preproc_endregion] = STATE(876),
    [sym_preproc_line] = STATE(876),
    [sym_preproc_pragma] = STATE(876),
    [sym_preproc_nullable] = STATE(876),
    [sym_preproc_error] = STATE(876),
    [sym_preproc_warning] = STATE(876),
    [sym_preproc_define] = STATE(876),
    [sym_preproc_undef] = STATE(876),
    [aux_sym_class_declaration_repeat1] = STATE(3831),
    [aux_sym_lambda_expression_repeat1] = STATE(4257),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1785),
    [anon_sym_ref] = ACTIONS(1787),
    [anon_sym_LBRACE] = ACTIONS(2835),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1595),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1791),
    [anon_sym_TILDE] = ACTIONS(1791),
    [anon_sym_PLUS_PLUS] = ACTIONS(1791),
    [anon_sym_DASH_DASH] = ACTIONS(1791),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1789),
    [anon_sym_DASH] = ACTIONS(1789),
    [anon_sym_STAR] = ACTIONS(1793),
    [anon_sym_CARET] = ACTIONS(1791),
    [anon_sym_AMP] = ACTIONS(1791),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1795),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1797),
    [anon_sym_DOT_DOT] = ACTIONS(1799),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [877] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5791),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(877),
    [sym_preproc_endregion] = STATE(877),
    [sym_preproc_line] = STATE(877),
    [sym_preproc_pragma] = STATE(877),
    [sym_preproc_nullable] = STATE(877),
    [sym_preproc_error] = STATE(877),
    [sym_preproc_warning] = STATE(877),
    [sym_preproc_define] = STATE(877),
    [sym_preproc_undef] = STATE(877),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_RBRACE] = ACTIONS(2863),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [878] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3763),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7159),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6330),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4487),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7422),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9176),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(878),
    [sym_preproc_endregion] = STATE(878),
    [sym_preproc_line] = STATE(878),
    [sym_preproc_pragma] = STATE(878),
    [sym_preproc_nullable] = STATE(878),
    [sym_preproc_error] = STATE(878),
    [sym_preproc_warning] = STATE(878),
    [sym_preproc_define] = STATE(878),
    [sym_preproc_undef] = STATE(878),
    [aux_sym_class_declaration_repeat1] = STATE(3877),
    [aux_sym_lambda_expression_repeat1] = STATE(4320),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1979),
    [anon_sym_ref] = ACTIONS(1981),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1985),
    [anon_sym_TILDE] = ACTIONS(1985),
    [anon_sym_PLUS_PLUS] = ACTIONS(1985),
    [anon_sym_DASH_DASH] = ACTIONS(1985),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1983),
    [anon_sym_DASH] = ACTIONS(1983),
    [anon_sym_STAR] = ACTIONS(1987),
    [anon_sym_CARET] = ACTIONS(1985),
    [anon_sym_AMP] = ACTIONS(1985),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1989),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1991),
    [anon_sym_DOT_DOT] = ACTIONS(1993),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [879] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3764),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7159),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6332),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4487),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7422),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9176),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(879),
    [sym_preproc_endregion] = STATE(879),
    [sym_preproc_line] = STATE(879),
    [sym_preproc_pragma] = STATE(879),
    [sym_preproc_nullable] = STATE(879),
    [sym_preproc_error] = STATE(879),
    [sym_preproc_warning] = STATE(879),
    [sym_preproc_define] = STATE(879),
    [sym_preproc_undef] = STATE(879),
    [aux_sym_class_declaration_repeat1] = STATE(3877),
    [aux_sym_lambda_expression_repeat1] = STATE(4320),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1979),
    [anon_sym_ref] = ACTIONS(1981),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1985),
    [anon_sym_TILDE] = ACTIONS(1985),
    [anon_sym_PLUS_PLUS] = ACTIONS(1985),
    [anon_sym_DASH_DASH] = ACTIONS(1985),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1983),
    [anon_sym_DASH] = ACTIONS(1983),
    [anon_sym_STAR] = ACTIONS(1987),
    [anon_sym_CARET] = ACTIONS(1985),
    [anon_sym_AMP] = ACTIONS(1985),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1989),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1991),
    [anon_sym_DOT_DOT] = ACTIONS(1993),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [880] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(2855),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6045),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(880),
    [sym_preproc_endregion] = STATE(880),
    [sym_preproc_line] = STATE(880),
    [sym_preproc_pragma] = STATE(880),
    [sym_preproc_nullable] = STATE(880),
    [sym_preproc_error] = STATE(880),
    [sym_preproc_warning] = STATE(880),
    [sym_preproc_define] = STATE(880),
    [sym_preproc_undef] = STATE(880),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(2767),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [881] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3780),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7159),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6333),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4487),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7422),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9176),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(881),
    [sym_preproc_endregion] = STATE(881),
    [sym_preproc_line] = STATE(881),
    [sym_preproc_pragma] = STATE(881),
    [sym_preproc_nullable] = STATE(881),
    [sym_preproc_error] = STATE(881),
    [sym_preproc_warning] = STATE(881),
    [sym_preproc_define] = STATE(881),
    [sym_preproc_undef] = STATE(881),
    [aux_sym_class_declaration_repeat1] = STATE(3877),
    [aux_sym_lambda_expression_repeat1] = STATE(4320),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1979),
    [anon_sym_ref] = ACTIONS(1981),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1985),
    [anon_sym_TILDE] = ACTIONS(1985),
    [anon_sym_PLUS_PLUS] = ACTIONS(1985),
    [anon_sym_DASH_DASH] = ACTIONS(1985),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1983),
    [anon_sym_DASH] = ACTIONS(1983),
    [anon_sym_STAR] = ACTIONS(1987),
    [anon_sym_CARET] = ACTIONS(1985),
    [anon_sym_AMP] = ACTIONS(1985),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1989),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1991),
    [anon_sym_DOT_DOT] = ACTIONS(1993),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [882] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3735),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7159),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6335),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4487),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7422),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9176),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(882),
    [sym_preproc_endregion] = STATE(882),
    [sym_preproc_line] = STATE(882),
    [sym_preproc_pragma] = STATE(882),
    [sym_preproc_nullable] = STATE(882),
    [sym_preproc_error] = STATE(882),
    [sym_preproc_warning] = STATE(882),
    [sym_preproc_define] = STATE(882),
    [sym_preproc_undef] = STATE(882),
    [aux_sym_class_declaration_repeat1] = STATE(3877),
    [aux_sym_lambda_expression_repeat1] = STATE(4320),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1979),
    [anon_sym_ref] = ACTIONS(1981),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1985),
    [anon_sym_TILDE] = ACTIONS(1985),
    [anon_sym_PLUS_PLUS] = ACTIONS(1985),
    [anon_sym_DASH_DASH] = ACTIONS(1985),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1983),
    [anon_sym_DASH] = ACTIONS(1983),
    [anon_sym_STAR] = ACTIONS(1987),
    [anon_sym_CARET] = ACTIONS(1985),
    [anon_sym_AMP] = ACTIONS(1985),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1989),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1991),
    [anon_sym_DOT_DOT] = ACTIONS(1993),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [883] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3741),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7159),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6336),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4487),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7422),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9176),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(883),
    [sym_preproc_endregion] = STATE(883),
    [sym_preproc_line] = STATE(883),
    [sym_preproc_pragma] = STATE(883),
    [sym_preproc_nullable] = STATE(883),
    [sym_preproc_error] = STATE(883),
    [sym_preproc_warning] = STATE(883),
    [sym_preproc_define] = STATE(883),
    [sym_preproc_undef] = STATE(883),
    [aux_sym_class_declaration_repeat1] = STATE(3877),
    [aux_sym_lambda_expression_repeat1] = STATE(4320),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1979),
    [anon_sym_ref] = ACTIONS(1981),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1985),
    [anon_sym_TILDE] = ACTIONS(1985),
    [anon_sym_PLUS_PLUS] = ACTIONS(1985),
    [anon_sym_DASH_DASH] = ACTIONS(1985),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1983),
    [anon_sym_DASH] = ACTIONS(1983),
    [anon_sym_STAR] = ACTIONS(1987),
    [anon_sym_CARET] = ACTIONS(1985),
    [anon_sym_AMP] = ACTIONS(1985),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1989),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1991),
    [anon_sym_DOT_DOT] = ACTIONS(1993),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [884] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3754),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7159),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6337),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4487),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7422),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9176),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(884),
    [sym_preproc_endregion] = STATE(884),
    [sym_preproc_line] = STATE(884),
    [sym_preproc_pragma] = STATE(884),
    [sym_preproc_nullable] = STATE(884),
    [sym_preproc_error] = STATE(884),
    [sym_preproc_warning] = STATE(884),
    [sym_preproc_define] = STATE(884),
    [sym_preproc_undef] = STATE(884),
    [aux_sym_class_declaration_repeat1] = STATE(3877),
    [aux_sym_lambda_expression_repeat1] = STATE(4320),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1979),
    [anon_sym_ref] = ACTIONS(1981),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1985),
    [anon_sym_TILDE] = ACTIONS(1985),
    [anon_sym_PLUS_PLUS] = ACTIONS(1985),
    [anon_sym_DASH_DASH] = ACTIONS(1985),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1983),
    [anon_sym_DASH] = ACTIONS(1983),
    [anon_sym_STAR] = ACTIONS(1987),
    [anon_sym_CARET] = ACTIONS(1985),
    [anon_sym_AMP] = ACTIONS(1985),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1989),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1991),
    [anon_sym_DOT_DOT] = ACTIONS(1993),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [885] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6728),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2789),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6662),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6519),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(885),
    [sym_preproc_endregion] = STATE(885),
    [sym_preproc_line] = STATE(885),
    [sym_preproc_pragma] = STATE(885),
    [sym_preproc_nullable] = STATE(885),
    [sym_preproc_error] = STATE(885),
    [sym_preproc_warning] = STATE(885),
    [sym_preproc_define] = STATE(885),
    [sym_preproc_undef] = STATE(885),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2047),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_readonly] = ACTIONS(2739),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(1089),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2607),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [886] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4005),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6912),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2912),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7040),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5315),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3963),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7448),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9641),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(886),
    [sym_preproc_endregion] = STATE(886),
    [sym_preproc_line] = STATE(886),
    [sym_preproc_pragma] = STATE(886),
    [sym_preproc_nullable] = STATE(886),
    [sym_preproc_error] = STATE(886),
    [sym_preproc_warning] = STATE(886),
    [sym_preproc_define] = STATE(886),
    [sym_preproc_undef] = STATE(886),
    [aux_sym_class_declaration_repeat1] = STATE(3831),
    [aux_sym_lambda_expression_repeat1] = STATE(4257),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1785),
    [anon_sym_ref] = ACTIONS(1787),
    [anon_sym_LBRACE] = ACTIONS(2835),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1595),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1791),
    [anon_sym_TILDE] = ACTIONS(1791),
    [anon_sym_PLUS_PLUS] = ACTIONS(1791),
    [anon_sym_DASH_DASH] = ACTIONS(1791),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1789),
    [anon_sym_DASH] = ACTIONS(1789),
    [anon_sym_STAR] = ACTIONS(1793),
    [anon_sym_CARET] = ACTIONS(1791),
    [anon_sym_AMP] = ACTIONS(1791),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1795),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1797),
    [anon_sym_DOT_DOT] = ACTIONS(1799),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [887] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4021),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6912),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2912),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7040),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5317),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3963),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7448),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9641),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(887),
    [sym_preproc_endregion] = STATE(887),
    [sym_preproc_line] = STATE(887),
    [sym_preproc_pragma] = STATE(887),
    [sym_preproc_nullable] = STATE(887),
    [sym_preproc_error] = STATE(887),
    [sym_preproc_warning] = STATE(887),
    [sym_preproc_define] = STATE(887),
    [sym_preproc_undef] = STATE(887),
    [aux_sym_class_declaration_repeat1] = STATE(3831),
    [aux_sym_lambda_expression_repeat1] = STATE(4257),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1785),
    [anon_sym_ref] = ACTIONS(1787),
    [anon_sym_LBRACE] = ACTIONS(2835),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1595),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1791),
    [anon_sym_TILDE] = ACTIONS(1791),
    [anon_sym_PLUS_PLUS] = ACTIONS(1791),
    [anon_sym_DASH_DASH] = ACTIONS(1791),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1789),
    [anon_sym_DASH] = ACTIONS(1789),
    [anon_sym_STAR] = ACTIONS(1793),
    [anon_sym_CARET] = ACTIONS(1791),
    [anon_sym_AMP] = ACTIONS(1791),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1795),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1797),
    [anon_sym_DOT_DOT] = ACTIONS(1799),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [888] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4060),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6912),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2912),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7040),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5414),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3963),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7448),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9641),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(888),
    [sym_preproc_endregion] = STATE(888),
    [sym_preproc_line] = STATE(888),
    [sym_preproc_pragma] = STATE(888),
    [sym_preproc_nullable] = STATE(888),
    [sym_preproc_error] = STATE(888),
    [sym_preproc_warning] = STATE(888),
    [sym_preproc_define] = STATE(888),
    [sym_preproc_undef] = STATE(888),
    [aux_sym_class_declaration_repeat1] = STATE(3831),
    [aux_sym_lambda_expression_repeat1] = STATE(4257),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1785),
    [anon_sym_ref] = ACTIONS(1787),
    [anon_sym_LBRACE] = ACTIONS(2835),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1595),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1791),
    [anon_sym_TILDE] = ACTIONS(1791),
    [anon_sym_PLUS_PLUS] = ACTIONS(1791),
    [anon_sym_DASH_DASH] = ACTIONS(1791),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1789),
    [anon_sym_DASH] = ACTIONS(1789),
    [anon_sym_STAR] = ACTIONS(1793),
    [anon_sym_CARET] = ACTIONS(1791),
    [anon_sym_AMP] = ACTIONS(1791),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1795),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1797),
    [anon_sym_DOT_DOT] = ACTIONS(1799),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [889] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4152),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7085),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5890),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4345),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7436),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9001),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(889),
    [sym_preproc_endregion] = STATE(889),
    [sym_preproc_line] = STATE(889),
    [sym_preproc_pragma] = STATE(889),
    [sym_preproc_nullable] = STATE(889),
    [sym_preproc_error] = STATE(889),
    [sym_preproc_warning] = STATE(889),
    [sym_preproc_define] = STATE(889),
    [sym_preproc_undef] = STATE(889),
    [aux_sym_class_declaration_repeat1] = STATE(3846),
    [aux_sym_lambda_expression_repeat1] = STATE(4278),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1669),
    [anon_sym_ref] = ACTIONS(1671),
    [anon_sym_LBRACE] = ACTIONS(2831),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1675),
    [anon_sym_TILDE] = ACTIONS(1675),
    [anon_sym_PLUS_PLUS] = ACTIONS(1675),
    [anon_sym_DASH_DASH] = ACTIONS(1675),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_STAR] = ACTIONS(1677),
    [anon_sym_CARET] = ACTIONS(1675),
    [anon_sym_AMP] = ACTIONS(1675),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1679),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1681),
    [anon_sym_DOT_DOT] = ACTIONS(1683),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [890] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4119),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7085),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5891),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4345),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7436),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9001),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(890),
    [sym_preproc_endregion] = STATE(890),
    [sym_preproc_line] = STATE(890),
    [sym_preproc_pragma] = STATE(890),
    [sym_preproc_nullable] = STATE(890),
    [sym_preproc_error] = STATE(890),
    [sym_preproc_warning] = STATE(890),
    [sym_preproc_define] = STATE(890),
    [sym_preproc_undef] = STATE(890),
    [aux_sym_class_declaration_repeat1] = STATE(3846),
    [aux_sym_lambda_expression_repeat1] = STATE(4278),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1669),
    [anon_sym_ref] = ACTIONS(1671),
    [anon_sym_LBRACE] = ACTIONS(2831),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1675),
    [anon_sym_TILDE] = ACTIONS(1675),
    [anon_sym_PLUS_PLUS] = ACTIONS(1675),
    [anon_sym_DASH_DASH] = ACTIONS(1675),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_STAR] = ACTIONS(1677),
    [anon_sym_CARET] = ACTIONS(1675),
    [anon_sym_AMP] = ACTIONS(1675),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1679),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1681),
    [anon_sym_DOT_DOT] = ACTIONS(1683),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [891] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4218),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7085),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5892),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4345),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7436),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9001),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(891),
    [sym_preproc_endregion] = STATE(891),
    [sym_preproc_line] = STATE(891),
    [sym_preproc_pragma] = STATE(891),
    [sym_preproc_nullable] = STATE(891),
    [sym_preproc_error] = STATE(891),
    [sym_preproc_warning] = STATE(891),
    [sym_preproc_define] = STATE(891),
    [sym_preproc_undef] = STATE(891),
    [aux_sym_class_declaration_repeat1] = STATE(3846),
    [aux_sym_lambda_expression_repeat1] = STATE(4278),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1669),
    [anon_sym_ref] = ACTIONS(1671),
    [anon_sym_LBRACE] = ACTIONS(2831),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1675),
    [anon_sym_TILDE] = ACTIONS(1675),
    [anon_sym_PLUS_PLUS] = ACTIONS(1675),
    [anon_sym_DASH_DASH] = ACTIONS(1675),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_STAR] = ACTIONS(1677),
    [anon_sym_CARET] = ACTIONS(1675),
    [anon_sym_AMP] = ACTIONS(1675),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1679),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1681),
    [anon_sym_DOT_DOT] = ACTIONS(1683),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [892] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4101),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7085),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5894),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4345),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7436),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9001),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(892),
    [sym_preproc_endregion] = STATE(892),
    [sym_preproc_line] = STATE(892),
    [sym_preproc_pragma] = STATE(892),
    [sym_preproc_nullable] = STATE(892),
    [sym_preproc_error] = STATE(892),
    [sym_preproc_warning] = STATE(892),
    [sym_preproc_define] = STATE(892),
    [sym_preproc_undef] = STATE(892),
    [aux_sym_class_declaration_repeat1] = STATE(3846),
    [aux_sym_lambda_expression_repeat1] = STATE(4278),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1669),
    [anon_sym_ref] = ACTIONS(1671),
    [anon_sym_LBRACE] = ACTIONS(2831),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1675),
    [anon_sym_TILDE] = ACTIONS(1675),
    [anon_sym_PLUS_PLUS] = ACTIONS(1675),
    [anon_sym_DASH_DASH] = ACTIONS(1675),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_STAR] = ACTIONS(1677),
    [anon_sym_CARET] = ACTIONS(1675),
    [anon_sym_AMP] = ACTIONS(1675),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1679),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1681),
    [anon_sym_DOT_DOT] = ACTIONS(1683),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [893] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4102),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7085),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5895),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4345),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7436),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9001),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(893),
    [sym_preproc_endregion] = STATE(893),
    [sym_preproc_line] = STATE(893),
    [sym_preproc_pragma] = STATE(893),
    [sym_preproc_nullable] = STATE(893),
    [sym_preproc_error] = STATE(893),
    [sym_preproc_warning] = STATE(893),
    [sym_preproc_define] = STATE(893),
    [sym_preproc_undef] = STATE(893),
    [aux_sym_class_declaration_repeat1] = STATE(3846),
    [aux_sym_lambda_expression_repeat1] = STATE(4278),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1669),
    [anon_sym_ref] = ACTIONS(1671),
    [anon_sym_LBRACE] = ACTIONS(2831),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1675),
    [anon_sym_TILDE] = ACTIONS(1675),
    [anon_sym_PLUS_PLUS] = ACTIONS(1675),
    [anon_sym_DASH_DASH] = ACTIONS(1675),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_STAR] = ACTIONS(1677),
    [anon_sym_CARET] = ACTIONS(1675),
    [anon_sym_AMP] = ACTIONS(1675),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1679),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1681),
    [anon_sym_DOT_DOT] = ACTIONS(1683),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [894] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4111),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7085),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5896),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4345),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7436),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9001),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(894),
    [sym_preproc_endregion] = STATE(894),
    [sym_preproc_line] = STATE(894),
    [sym_preproc_pragma] = STATE(894),
    [sym_preproc_nullable] = STATE(894),
    [sym_preproc_error] = STATE(894),
    [sym_preproc_warning] = STATE(894),
    [sym_preproc_define] = STATE(894),
    [sym_preproc_undef] = STATE(894),
    [aux_sym_class_declaration_repeat1] = STATE(3846),
    [aux_sym_lambda_expression_repeat1] = STATE(4278),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1669),
    [anon_sym_ref] = ACTIONS(1671),
    [anon_sym_LBRACE] = ACTIONS(2831),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1675),
    [anon_sym_TILDE] = ACTIONS(1675),
    [anon_sym_PLUS_PLUS] = ACTIONS(1675),
    [anon_sym_DASH_DASH] = ACTIONS(1675),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_STAR] = ACTIONS(1677),
    [anon_sym_CARET] = ACTIONS(1675),
    [anon_sym_AMP] = ACTIONS(1675),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1679),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1681),
    [anon_sym_DOT_DOT] = ACTIONS(1683),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [895] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7086),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5897),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4345),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7436),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9001),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(895),
    [sym_preproc_endregion] = STATE(895),
    [sym_preproc_line] = STATE(895),
    [sym_preproc_pragma] = STATE(895),
    [sym_preproc_nullable] = STATE(895),
    [sym_preproc_error] = STATE(895),
    [sym_preproc_warning] = STATE(895),
    [sym_preproc_define] = STATE(895),
    [sym_preproc_undef] = STATE(895),
    [aux_sym_class_declaration_repeat1] = STATE(3846),
    [aux_sym_lambda_expression_repeat1] = STATE(4278),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1669),
    [anon_sym_ref] = ACTIONS(1671),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_readonly] = ACTIONS(2767),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1675),
    [anon_sym_TILDE] = ACTIONS(1675),
    [anon_sym_PLUS_PLUS] = ACTIONS(1675),
    [anon_sym_DASH_DASH] = ACTIONS(1675),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_STAR] = ACTIONS(1677),
    [anon_sym_CARET] = ACTIONS(1675),
    [anon_sym_AMP] = ACTIONS(1675),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1679),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1681),
    [anon_sym_DOT_DOT] = ACTIONS(1683),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [896] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6968),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5100),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3813),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9209),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(896),
    [sym_preproc_endregion] = STATE(896),
    [sym_preproc_line] = STATE(896),
    [sym_preproc_pragma] = STATE(896),
    [sym_preproc_nullable] = STATE(896),
    [sym_preproc_error] = STATE(896),
    [sym_preproc_warning] = STATE(896),
    [sym_preproc_define] = STATE(896),
    [sym_preproc_undef] = STATE(896),
    [aux_sym_class_declaration_repeat1] = STATE(3814),
    [aux_sym_lambda_expression_repeat1] = STATE(4209),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1323),
    [anon_sym_ref] = ACTIONS(1325),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_readonly] = ACTIONS(2767),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1083),
    [anon_sym_PLUS_PLUS] = ACTIONS(1083),
    [anon_sym_DASH_DASH] = ACTIONS(1083),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1085),
    [anon_sym_DASH] = ACTIONS(1085),
    [anon_sym_STAR] = ACTIONS(1335),
    [anon_sym_CARET] = ACTIONS(1083),
    [anon_sym_AMP] = ACTIONS(1083),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1341),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1343),
    [anon_sym_DOT_DOT] = ACTIONS(1345),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [897] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6932),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2977),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6997),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6297),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4378),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7430),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9693),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(897),
    [sym_preproc_endregion] = STATE(897),
    [sym_preproc_line] = STATE(897),
    [sym_preproc_pragma] = STATE(897),
    [sym_preproc_nullable] = STATE(897),
    [sym_preproc_error] = STATE(897),
    [sym_preproc_warning] = STATE(897),
    [sym_preproc_define] = STATE(897),
    [sym_preproc_undef] = STATE(897),
    [aux_sym_class_declaration_repeat1] = STATE(3820),
    [aux_sym_lambda_expression_repeat1] = STATE(4234),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2127),
    [anon_sym_ref] = ACTIONS(2129),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2131),
    [anon_sym_readonly] = ACTIONS(2767),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2135),
    [anon_sym_TILDE] = ACTIONS(2135),
    [anon_sym_PLUS_PLUS] = ACTIONS(2135),
    [anon_sym_DASH_DASH] = ACTIONS(2135),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2133),
    [anon_sym_DASH] = ACTIONS(2133),
    [anon_sym_STAR] = ACTIONS(2137),
    [anon_sym_CARET] = ACTIONS(2135),
    [anon_sym_AMP] = ACTIONS(2135),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2139),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2141),
    [anon_sym_DOT_DOT] = ACTIONS(2143),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [898] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3025),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2760),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(2855),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_expression] = STATE(6045),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2755),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(898),
    [sym_preproc_endregion] = STATE(898),
    [sym_preproc_line] = STATE(898),
    [sym_preproc_pragma] = STATE(898),
    [sym_preproc_nullable] = STATE(898),
    [sym_preproc_error] = STATE(898),
    [sym_preproc_warning] = STATE(898),
    [sym_preproc_define] = STATE(898),
    [sym_preproc_undef] = STATE(898),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2839),
    [anon_sym_ref] = ACTIONS(2327),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(2865),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2843),
    [sym_predefined_type] = ACTIONS(2339),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [899] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3780),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6948),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2940),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6999),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5094),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3857),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7444),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9574),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(899),
    [sym_preproc_endregion] = STATE(899),
    [sym_preproc_line] = STATE(899),
    [sym_preproc_pragma] = STATE(899),
    [sym_preproc_nullable] = STATE(899),
    [sym_preproc_error] = STATE(899),
    [sym_preproc_warning] = STATE(899),
    [sym_preproc_define] = STATE(899),
    [sym_preproc_undef] = STATE(899),
    [aux_sym_class_declaration_repeat1] = STATE(3854),
    [aux_sym_lambda_expression_repeat1] = STATE(4136),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2111),
    [anon_sym_ref] = ACTIONS(2113),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1897),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2117),
    [anon_sym_TILDE] = ACTIONS(2117),
    [anon_sym_PLUS_PLUS] = ACTIONS(2117),
    [anon_sym_DASH_DASH] = ACTIONS(2117),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2115),
    [anon_sym_DASH] = ACTIONS(2115),
    [anon_sym_STAR] = ACTIONS(1903),
    [anon_sym_CARET] = ACTIONS(2117),
    [anon_sym_AMP] = ACTIONS(2117),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2119),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2121),
    [anon_sym_DOT_DOT] = ACTIONS(2123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [900] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6765),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2860),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(2855),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6045),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2810),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(900),
    [sym_preproc_endregion] = STATE(900),
    [sym_preproc_line] = STATE(900),
    [sym_preproc_pragma] = STATE(900),
    [sym_preproc_nullable] = STATE(900),
    [sym_preproc_error] = STATE(900),
    [sym_preproc_warning] = STATE(900),
    [sym_preproc_define] = STATE(900),
    [sym_preproc_undef] = STATE(900),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_ref] = ACTIONS(2399),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(2867),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2407),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2727),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [901] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6076),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(901),
    [sym_preproc_endregion] = STATE(901),
    [sym_preproc_line] = STATE(901),
    [sym_preproc_pragma] = STATE(901),
    [sym_preproc_nullable] = STATE(901),
    [sym_preproc_error] = STATE(901),
    [sym_preproc_warning] = STATE(901),
    [sym_preproc_define] = STATE(901),
    [sym_preproc_undef] = STATE(901),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2869),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [902] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4643),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6911),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2930),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7031),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4799),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3742),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7420),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9374),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(902),
    [sym_preproc_endregion] = STATE(902),
    [sym_preproc_line] = STATE(902),
    [sym_preproc_pragma] = STATE(902),
    [sym_preproc_nullable] = STATE(902),
    [sym_preproc_error] = STATE(902),
    [sym_preproc_warning] = STATE(902),
    [sym_preproc_define] = STATE(902),
    [sym_preproc_undef] = STATE(902),
    [aux_sym_class_declaration_repeat1] = STATE(3861),
    [aux_sym_lambda_expression_repeat1] = STATE(4169),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(2089),
    [anon_sym_ref] = ACTIONS(2091),
    [anon_sym_LBRACE] = ACTIONS(2847),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1695),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(2095),
    [anon_sym_TILDE] = ACTIONS(2095),
    [anon_sym_PLUS_PLUS] = ACTIONS(2095),
    [anon_sym_DASH_DASH] = ACTIONS(2095),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(2093),
    [anon_sym_DASH] = ACTIONS(2093),
    [anon_sym_STAR] = ACTIONS(1705),
    [anon_sym_CARET] = ACTIONS(2095),
    [anon_sym_AMP] = ACTIONS(2095),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(2097),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2099),
    [anon_sym_DOT_DOT] = ACTIONS(2101),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [903] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6124),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(903),
    [sym_preproc_endregion] = STATE(903),
    [sym_preproc_line] = STATE(903),
    [sym_preproc_pragma] = STATE(903),
    [sym_preproc_nullable] = STATE(903),
    [sym_preproc_error] = STATE(903),
    [sym_preproc_warning] = STATE(903),
    [sym_preproc_define] = STATE(903),
    [sym_preproc_undef] = STATE(903),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2871),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [904] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6691),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2829),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6662),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6519),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(904),
    [sym_preproc_endregion] = STATE(904),
    [sym_preproc_line] = STATE(904),
    [sym_preproc_pragma] = STATE(904),
    [sym_preproc_nullable] = STATE(904),
    [sym_preproc_error] = STATE(904),
    [sym_preproc_warning] = STATE(904),
    [sym_preproc_define] = STATE(904),
    [sym_preproc_undef] = STATE(904),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2317),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_readonly] = ACTIONS(2833),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2319),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2607),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [905] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6912),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2912),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7041),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5256),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3963),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7448),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9641),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(905),
    [sym_preproc_endregion] = STATE(905),
    [sym_preproc_line] = STATE(905),
    [sym_preproc_pragma] = STATE(905),
    [sym_preproc_nullable] = STATE(905),
    [sym_preproc_error] = STATE(905),
    [sym_preproc_warning] = STATE(905),
    [sym_preproc_define] = STATE(905),
    [sym_preproc_undef] = STATE(905),
    [aux_sym_class_declaration_repeat1] = STATE(3831),
    [aux_sym_lambda_expression_repeat1] = STATE(4257),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1785),
    [anon_sym_ref] = ACTIONS(1787),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1595),
    [anon_sym_readonly] = ACTIONS(2767),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1791),
    [anon_sym_TILDE] = ACTIONS(1791),
    [anon_sym_PLUS_PLUS] = ACTIONS(1791),
    [anon_sym_DASH_DASH] = ACTIONS(1791),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1789),
    [anon_sym_DASH] = ACTIONS(1789),
    [anon_sym_STAR] = ACTIONS(1793),
    [anon_sym_CARET] = ACTIONS(1791),
    [anon_sym_AMP] = ACTIONS(1791),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1795),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1797),
    [anon_sym_DOT_DOT] = ACTIONS(1799),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [906] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4708),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6911),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2930),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7031),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4890),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3742),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7420),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9374),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(906),
    [sym_preproc_endregion] = STATE(906),
    [sym_preproc_line] = STATE(906),
    [sym_preproc_pragma] = STATE(906),
    [sym_preproc_nullable] = STATE(906),
    [sym_preproc_error] = STATE(906),
    [sym_preproc_warning] = STATE(906),
    [sym_preproc_define] = STATE(906),
    [sym_preproc_undef] = STATE(906),
    [aux_sym_class_declaration_repeat1] = STATE(3861),
    [aux_sym_lambda_expression_repeat1] = STATE(4169),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(2089),
    [anon_sym_ref] = ACTIONS(2091),
    [anon_sym_LBRACE] = ACTIONS(2847),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1695),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(2095),
    [anon_sym_TILDE] = ACTIONS(2095),
    [anon_sym_PLUS_PLUS] = ACTIONS(2095),
    [anon_sym_DASH_DASH] = ACTIONS(2095),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(2093),
    [anon_sym_DASH] = ACTIONS(2093),
    [anon_sym_STAR] = ACTIONS(1705),
    [anon_sym_CARET] = ACTIONS(2095),
    [anon_sym_AMP] = ACTIONS(2095),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(2097),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2099),
    [anon_sym_DOT_DOT] = ACTIONS(2101),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [907] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6911),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2930),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7048),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4841),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3742),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7420),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9374),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(907),
    [sym_preproc_endregion] = STATE(907),
    [sym_preproc_line] = STATE(907),
    [sym_preproc_pragma] = STATE(907),
    [sym_preproc_nullable] = STATE(907),
    [sym_preproc_error] = STATE(907),
    [sym_preproc_warning] = STATE(907),
    [sym_preproc_define] = STATE(907),
    [sym_preproc_undef] = STATE(907),
    [aux_sym_class_declaration_repeat1] = STATE(3861),
    [aux_sym_lambda_expression_repeat1] = STATE(4169),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(2089),
    [anon_sym_ref] = ACTIONS(2091),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1695),
    [anon_sym_readonly] = ACTIONS(2767),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(2095),
    [anon_sym_TILDE] = ACTIONS(2095),
    [anon_sym_PLUS_PLUS] = ACTIONS(2095),
    [anon_sym_DASH_DASH] = ACTIONS(2095),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(2093),
    [anon_sym_DASH] = ACTIONS(2093),
    [anon_sym_STAR] = ACTIONS(1705),
    [anon_sym_CARET] = ACTIONS(2095),
    [anon_sym_AMP] = ACTIONS(2095),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(2097),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2099),
    [anon_sym_DOT_DOT] = ACTIONS(2101),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [908] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6956),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6564),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9482),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(908),
    [sym_preproc_endregion] = STATE(908),
    [sym_preproc_line] = STATE(908),
    [sym_preproc_pragma] = STATE(908),
    [sym_preproc_nullable] = STATE(908),
    [sym_preproc_error] = STATE(908),
    [sym_preproc_warning] = STATE(908),
    [sym_preproc_define] = STATE(908),
    [sym_preproc_undef] = STATE(908),
    [aux_sym_class_declaration_repeat1] = STATE(3853),
    [aux_sym_lambda_expression_repeat1] = STATE(4299),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(2873),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1497),
    [anon_sym_ref] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1505),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1507),
    [anon_sym_DOT_DOT] = ACTIONS(1509),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [909] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6956),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6585),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9482),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(909),
    [sym_preproc_endregion] = STATE(909),
    [sym_preproc_line] = STATE(909),
    [sym_preproc_pragma] = STATE(909),
    [sym_preproc_nullable] = STATE(909),
    [sym_preproc_error] = STATE(909),
    [sym_preproc_warning] = STATE(909),
    [sym_preproc_define] = STATE(909),
    [sym_preproc_undef] = STATE(909),
    [aux_sym_class_declaration_repeat1] = STATE(3853),
    [aux_sym_lambda_expression_repeat1] = STATE(4299),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(2875),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1497),
    [anon_sym_ref] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1505),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1507),
    [anon_sym_DOT_DOT] = ACTIONS(1509),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [910] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4719),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6911),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2930),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7031),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4752),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3742),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7420),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9374),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(910),
    [sym_preproc_endregion] = STATE(910),
    [sym_preproc_line] = STATE(910),
    [sym_preproc_pragma] = STATE(910),
    [sym_preproc_nullable] = STATE(910),
    [sym_preproc_error] = STATE(910),
    [sym_preproc_warning] = STATE(910),
    [sym_preproc_define] = STATE(910),
    [sym_preproc_undef] = STATE(910),
    [aux_sym_class_declaration_repeat1] = STATE(3861),
    [aux_sym_lambda_expression_repeat1] = STATE(4169),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(2089),
    [anon_sym_ref] = ACTIONS(2091),
    [anon_sym_LBRACE] = ACTIONS(2847),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1695),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(2095),
    [anon_sym_TILDE] = ACTIONS(2095),
    [anon_sym_PLUS_PLUS] = ACTIONS(2095),
    [anon_sym_DASH_DASH] = ACTIONS(2095),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(2093),
    [anon_sym_DASH] = ACTIONS(2093),
    [anon_sym_STAR] = ACTIONS(1705),
    [anon_sym_CARET] = ACTIONS(2095),
    [anon_sym_AMP] = ACTIONS(2095),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(2097),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2099),
    [anon_sym_DOT_DOT] = ACTIONS(2101),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [911] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6956),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6586),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9482),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(911),
    [sym_preproc_endregion] = STATE(911),
    [sym_preproc_line] = STATE(911),
    [sym_preproc_pragma] = STATE(911),
    [sym_preproc_nullable] = STATE(911),
    [sym_preproc_error] = STATE(911),
    [sym_preproc_warning] = STATE(911),
    [sym_preproc_define] = STATE(911),
    [sym_preproc_undef] = STATE(911),
    [aux_sym_class_declaration_repeat1] = STATE(3853),
    [aux_sym_lambda_expression_repeat1] = STATE(4299),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(2877),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1497),
    [anon_sym_ref] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1505),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1507),
    [anon_sym_DOT_DOT] = ACTIONS(1509),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [912] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4152),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6984),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5150),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3903),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7428),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9348),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(912),
    [sym_preproc_endregion] = STATE(912),
    [sym_preproc_line] = STATE(912),
    [sym_preproc_pragma] = STATE(912),
    [sym_preproc_nullable] = STATE(912),
    [sym_preproc_error] = STATE(912),
    [sym_preproc_warning] = STATE(912),
    [sym_preproc_define] = STATE(912),
    [sym_preproc_undef] = STATE(912),
    [aux_sym_class_declaration_repeat1] = STATE(3817),
    [aux_sym_lambda_expression_repeat1] = STATE(4227),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1389),
    [anon_sym_ref] = ACTIONS(1391),
    [anon_sym_LBRACE] = ACTIONS(2831),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1117),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(1393),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_AMP] = ACTIONS(1117),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1395),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1397),
    [anon_sym_DOT_DOT] = ACTIONS(1399),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [913] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(5561),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6921),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2873),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(6957),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6044),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4346),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7445),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9875),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(913),
    [sym_preproc_endregion] = STATE(913),
    [sym_preproc_line] = STATE(913),
    [sym_preproc_pragma] = STATE(913),
    [sym_preproc_nullable] = STATE(913),
    [sym_preproc_error] = STATE(913),
    [sym_preproc_warning] = STATE(913),
    [sym_preproc_define] = STATE(913),
    [sym_preproc_undef] = STATE(913),
    [aux_sym_class_declaration_repeat1] = STATE(3810),
    [aux_sym_lambda_expression_repeat1] = STATE(4192),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1639),
    [anon_sym_ref] = ACTIONS(1641),
    [anon_sym_LBRACE] = ACTIONS(2857),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1415),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1645),
    [anon_sym_TILDE] = ACTIONS(1645),
    [anon_sym_PLUS_PLUS] = ACTIONS(1645),
    [anon_sym_DASH_DASH] = ACTIONS(1645),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1643),
    [anon_sym_DASH] = ACTIONS(1643),
    [anon_sym_STAR] = ACTIONS(1425),
    [anon_sym_CARET] = ACTIONS(1645),
    [anon_sym_AMP] = ACTIONS(1645),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1647),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1649),
    [anon_sym_DOT_DOT] = ACTIONS(1651),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [914] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(5577),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6921),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2873),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(6957),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6100),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4346),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7445),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9875),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(914),
    [sym_preproc_endregion] = STATE(914),
    [sym_preproc_line] = STATE(914),
    [sym_preproc_pragma] = STATE(914),
    [sym_preproc_nullable] = STATE(914),
    [sym_preproc_error] = STATE(914),
    [sym_preproc_warning] = STATE(914),
    [sym_preproc_define] = STATE(914),
    [sym_preproc_undef] = STATE(914),
    [aux_sym_class_declaration_repeat1] = STATE(3810),
    [aux_sym_lambda_expression_repeat1] = STATE(4192),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1639),
    [anon_sym_ref] = ACTIONS(1641),
    [anon_sym_LBRACE] = ACTIONS(2857),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1415),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1645),
    [anon_sym_TILDE] = ACTIONS(1645),
    [anon_sym_PLUS_PLUS] = ACTIONS(1645),
    [anon_sym_DASH_DASH] = ACTIONS(1645),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1643),
    [anon_sym_DASH] = ACTIONS(1643),
    [anon_sym_STAR] = ACTIONS(1425),
    [anon_sym_CARET] = ACTIONS(1645),
    [anon_sym_AMP] = ACTIONS(1645),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1647),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1649),
    [anon_sym_DOT_DOT] = ACTIONS(1651),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [915] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4119),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6984),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5161),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3903),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7428),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9348),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(915),
    [sym_preproc_endregion] = STATE(915),
    [sym_preproc_line] = STATE(915),
    [sym_preproc_pragma] = STATE(915),
    [sym_preproc_nullable] = STATE(915),
    [sym_preproc_error] = STATE(915),
    [sym_preproc_warning] = STATE(915),
    [sym_preproc_define] = STATE(915),
    [sym_preproc_undef] = STATE(915),
    [aux_sym_class_declaration_repeat1] = STATE(3817),
    [aux_sym_lambda_expression_repeat1] = STATE(4227),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1389),
    [anon_sym_ref] = ACTIONS(1391),
    [anon_sym_LBRACE] = ACTIONS(2831),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1117),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(1393),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_AMP] = ACTIONS(1117),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1395),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1397),
    [anon_sym_DOT_DOT] = ACTIONS(1399),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [916] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6731),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5652),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(916),
    [sym_preproc_endregion] = STATE(916),
    [sym_preproc_line] = STATE(916),
    [sym_preproc_pragma] = STATE(916),
    [sym_preproc_nullable] = STATE(916),
    [sym_preproc_error] = STATE(916),
    [sym_preproc_warning] = STATE(916),
    [sym_preproc_define] = STATE(916),
    [sym_preproc_undef] = STATE(916),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(2767),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [917] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6956),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6430),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9482),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(917),
    [sym_preproc_endregion] = STATE(917),
    [sym_preproc_line] = STATE(917),
    [sym_preproc_pragma] = STATE(917),
    [sym_preproc_nullable] = STATE(917),
    [sym_preproc_error] = STATE(917),
    [sym_preproc_warning] = STATE(917),
    [sym_preproc_define] = STATE(917),
    [sym_preproc_undef] = STATE(917),
    [aux_sym_class_declaration_repeat1] = STATE(3853),
    [aux_sym_lambda_expression_repeat1] = STATE(4299),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(2069),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1497),
    [anon_sym_ref] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1505),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1507),
    [anon_sym_DOT_DOT] = ACTIONS(1509),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [918] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4218),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6984),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5204),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3903),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7428),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9348),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(918),
    [sym_preproc_endregion] = STATE(918),
    [sym_preproc_line] = STATE(918),
    [sym_preproc_pragma] = STATE(918),
    [sym_preproc_nullable] = STATE(918),
    [sym_preproc_error] = STATE(918),
    [sym_preproc_warning] = STATE(918),
    [sym_preproc_define] = STATE(918),
    [sym_preproc_undef] = STATE(918),
    [aux_sym_class_declaration_repeat1] = STATE(3817),
    [aux_sym_lambda_expression_repeat1] = STATE(4227),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1389),
    [anon_sym_ref] = ACTIONS(1391),
    [anon_sym_LBRACE] = ACTIONS(2831),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1117),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(1393),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_AMP] = ACTIONS(1117),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1395),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1397),
    [anon_sym_DOT_DOT] = ACTIONS(1399),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [919] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4101),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6984),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5213),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3903),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7428),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9348),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(919),
    [sym_preproc_endregion] = STATE(919),
    [sym_preproc_line] = STATE(919),
    [sym_preproc_pragma] = STATE(919),
    [sym_preproc_nullable] = STATE(919),
    [sym_preproc_error] = STATE(919),
    [sym_preproc_warning] = STATE(919),
    [sym_preproc_define] = STATE(919),
    [sym_preproc_undef] = STATE(919),
    [aux_sym_class_declaration_repeat1] = STATE(3817),
    [aux_sym_lambda_expression_repeat1] = STATE(4227),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1389),
    [anon_sym_ref] = ACTIONS(1391),
    [anon_sym_LBRACE] = ACTIONS(2831),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1117),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(1393),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_AMP] = ACTIONS(1117),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1395),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1397),
    [anon_sym_DOT_DOT] = ACTIONS(1399),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [920] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4102),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6984),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5172),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3903),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7428),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9348),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(920),
    [sym_preproc_endregion] = STATE(920),
    [sym_preproc_line] = STATE(920),
    [sym_preproc_pragma] = STATE(920),
    [sym_preproc_nullable] = STATE(920),
    [sym_preproc_error] = STATE(920),
    [sym_preproc_warning] = STATE(920),
    [sym_preproc_define] = STATE(920),
    [sym_preproc_undef] = STATE(920),
    [aux_sym_class_declaration_repeat1] = STATE(3817),
    [aux_sym_lambda_expression_repeat1] = STATE(4227),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1389),
    [anon_sym_ref] = ACTIONS(1391),
    [anon_sym_LBRACE] = ACTIONS(2831),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1117),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(1393),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_AMP] = ACTIONS(1117),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1395),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1397),
    [anon_sym_DOT_DOT] = ACTIONS(1399),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [921] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4111),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6984),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5227),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3903),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7428),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9348),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(921),
    [sym_preproc_endregion] = STATE(921),
    [sym_preproc_line] = STATE(921),
    [sym_preproc_pragma] = STATE(921),
    [sym_preproc_nullable] = STATE(921),
    [sym_preproc_error] = STATE(921),
    [sym_preproc_warning] = STATE(921),
    [sym_preproc_define] = STATE(921),
    [sym_preproc_undef] = STATE(921),
    [aux_sym_class_declaration_repeat1] = STATE(3817),
    [aux_sym_lambda_expression_repeat1] = STATE(4227),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1389),
    [anon_sym_ref] = ACTIONS(1391),
    [anon_sym_LBRACE] = ACTIONS(2831),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1117),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(1393),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_AMP] = ACTIONS(1117),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1395),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1397),
    [anon_sym_DOT_DOT] = ACTIONS(1399),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [922] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6956),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6617),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9482),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(922),
    [sym_preproc_endregion] = STATE(922),
    [sym_preproc_line] = STATE(922),
    [sym_preproc_pragma] = STATE(922),
    [sym_preproc_nullable] = STATE(922),
    [sym_preproc_error] = STATE(922),
    [sym_preproc_warning] = STATE(922),
    [sym_preproc_define] = STATE(922),
    [sym_preproc_undef] = STATE(922),
    [aux_sym_class_declaration_repeat1] = STATE(3853),
    [aux_sym_lambda_expression_repeat1] = STATE(4299),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(2033),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1497),
    [anon_sym_ref] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1505),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1507),
    [anon_sym_DOT_DOT] = ACTIONS(1509),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [923] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6911),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2930),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7031),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4889),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3742),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7420),
    [sym__ordering] = STATE(7695),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9374),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(923),
    [sym_preproc_endregion] = STATE(923),
    [sym_preproc_line] = STATE(923),
    [sym_preproc_pragma] = STATE(923),
    [sym_preproc_nullable] = STATE(923),
    [sym_preproc_error] = STATE(923),
    [sym_preproc_warning] = STATE(923),
    [sym_preproc_define] = STATE(923),
    [sym_preproc_undef] = STATE(923),
    [aux_sym_class_declaration_repeat1] = STATE(3861),
    [aux_sym_lambda_expression_repeat1] = STATE(4169),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(2089),
    [anon_sym_ref] = ACTIONS(2091),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1695),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(2095),
    [anon_sym_TILDE] = ACTIONS(2095),
    [anon_sym_PLUS_PLUS] = ACTIONS(2095),
    [anon_sym_DASH_DASH] = ACTIONS(2095),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(2093),
    [anon_sym_DASH] = ACTIONS(2093),
    [anon_sym_STAR] = ACTIONS(1705),
    [anon_sym_CARET] = ACTIONS(2095),
    [anon_sym_AMP] = ACTIONS(2095),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(2097),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2099),
    [anon_sym_DOT_DOT] = ACTIONS(2101),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [924] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(5582),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6921),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2873),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(6957),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5809),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4346),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7445),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9875),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(924),
    [sym_preproc_endregion] = STATE(924),
    [sym_preproc_line] = STATE(924),
    [sym_preproc_pragma] = STATE(924),
    [sym_preproc_nullable] = STATE(924),
    [sym_preproc_error] = STATE(924),
    [sym_preproc_warning] = STATE(924),
    [sym_preproc_define] = STATE(924),
    [sym_preproc_undef] = STATE(924),
    [aux_sym_class_declaration_repeat1] = STATE(3810),
    [aux_sym_lambda_expression_repeat1] = STATE(4192),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1639),
    [anon_sym_ref] = ACTIONS(1641),
    [anon_sym_LBRACE] = ACTIONS(2857),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1415),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1645),
    [anon_sym_TILDE] = ACTIONS(1645),
    [anon_sym_PLUS_PLUS] = ACTIONS(1645),
    [anon_sym_DASH_DASH] = ACTIONS(1645),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1643),
    [anon_sym_DASH] = ACTIONS(1643),
    [anon_sym_STAR] = ACTIONS(1425),
    [anon_sym_CARET] = ACTIONS(1645),
    [anon_sym_AMP] = ACTIONS(1645),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1647),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1649),
    [anon_sym_DOT_DOT] = ACTIONS(1651),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [925] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6956),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6404),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9482),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(925),
    [sym_preproc_endregion] = STATE(925),
    [sym_preproc_line] = STATE(925),
    [sym_preproc_pragma] = STATE(925),
    [sym_preproc_nullable] = STATE(925),
    [sym_preproc_error] = STATE(925),
    [sym_preproc_warning] = STATE(925),
    [sym_preproc_define] = STATE(925),
    [sym_preproc_undef] = STATE(925),
    [aux_sym_class_declaration_repeat1] = STATE(3853),
    [aux_sym_lambda_expression_repeat1] = STATE(4299),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(2879),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1497),
    [anon_sym_ref] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1505),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1507),
    [anon_sym_DOT_DOT] = ACTIONS(1509),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [926] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3735),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7105),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6021),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(926),
    [sym_preproc_endregion] = STATE(926),
    [sym_preproc_line] = STATE(926),
    [sym_preproc_pragma] = STATE(926),
    [sym_preproc_nullable] = STATE(926),
    [sym_preproc_error] = STATE(926),
    [sym_preproc_warning] = STATE(926),
    [sym_preproc_define] = STATE(926),
    [sym_preproc_undef] = STATE(926),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [927] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3991),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6927),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2912),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7057),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5328),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3960),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7439),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9222),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(927),
    [sym_preproc_endregion] = STATE(927),
    [sym_preproc_line] = STATE(927),
    [sym_preproc_pragma] = STATE(927),
    [sym_preproc_nullable] = STATE(927),
    [sym_preproc_error] = STATE(927),
    [sym_preproc_warning] = STATE(927),
    [sym_preproc_define] = STATE(927),
    [sym_preproc_undef] = STATE(927),
    [aux_sym_class_declaration_repeat1] = STATE(3837),
    [aux_sym_lambda_expression_repeat1] = STATE(4265),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1591),
    [anon_sym_ref] = ACTIONS(1593),
    [anon_sym_LBRACE] = ACTIONS(2835),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1595),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1599),
    [anon_sym_TILDE] = ACTIONS(1599),
    [anon_sym_PLUS_PLUS] = ACTIONS(1599),
    [anon_sym_DASH_DASH] = ACTIONS(1599),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1597),
    [anon_sym_DASH] = ACTIONS(1597),
    [anon_sym_STAR] = ACTIONS(1601),
    [anon_sym_CARET] = ACTIONS(1599),
    [anon_sym_AMP] = ACTIONS(1599),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1603),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1605),
    [anon_sym_DOT_DOT] = ACTIONS(1607),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [928] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6956),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6408),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9482),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(928),
    [sym_preproc_endregion] = STATE(928),
    [sym_preproc_line] = STATE(928),
    [sym_preproc_pragma] = STATE(928),
    [sym_preproc_nullable] = STATE(928),
    [sym_preproc_error] = STATE(928),
    [sym_preproc_warning] = STATE(928),
    [sym_preproc_define] = STATE(928),
    [sym_preproc_undef] = STATE(928),
    [aux_sym_class_declaration_repeat1] = STATE(3853),
    [aux_sym_lambda_expression_repeat1] = STATE(4299),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(2881),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1497),
    [anon_sym_ref] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1505),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1507),
    [anon_sym_DOT_DOT] = ACTIONS(1509),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [929] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4028),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6927),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2912),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7057),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5344),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3960),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7439),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9222),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(929),
    [sym_preproc_endregion] = STATE(929),
    [sym_preproc_line] = STATE(929),
    [sym_preproc_pragma] = STATE(929),
    [sym_preproc_nullable] = STATE(929),
    [sym_preproc_error] = STATE(929),
    [sym_preproc_warning] = STATE(929),
    [sym_preproc_define] = STATE(929),
    [sym_preproc_undef] = STATE(929),
    [aux_sym_class_declaration_repeat1] = STATE(3837),
    [aux_sym_lambda_expression_repeat1] = STATE(4265),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1591),
    [anon_sym_ref] = ACTIONS(1593),
    [anon_sym_LBRACE] = ACTIONS(2835),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1595),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1599),
    [anon_sym_TILDE] = ACTIONS(1599),
    [anon_sym_PLUS_PLUS] = ACTIONS(1599),
    [anon_sym_DASH_DASH] = ACTIONS(1599),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1597),
    [anon_sym_DASH] = ACTIONS(1597),
    [anon_sym_STAR] = ACTIONS(1601),
    [anon_sym_CARET] = ACTIONS(1599),
    [anon_sym_AMP] = ACTIONS(1599),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1603),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1605),
    [anon_sym_DOT_DOT] = ACTIONS(1607),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [930] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6956),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6413),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9482),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(930),
    [sym_preproc_endregion] = STATE(930),
    [sym_preproc_line] = STATE(930),
    [sym_preproc_pragma] = STATE(930),
    [sym_preproc_nullable] = STATE(930),
    [sym_preproc_error] = STATE(930),
    [sym_preproc_warning] = STATE(930),
    [sym_preproc_define] = STATE(930),
    [sym_preproc_undef] = STATE(930),
    [aux_sym_class_declaration_repeat1] = STATE(3853),
    [aux_sym_lambda_expression_repeat1] = STATE(4299),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(2883),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1497),
    [anon_sym_ref] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1505),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1507),
    [anon_sym_DOT_DOT] = ACTIONS(1509),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [931] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6956),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6382),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9482),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(931),
    [sym_preproc_endregion] = STATE(931),
    [sym_preproc_line] = STATE(931),
    [sym_preproc_pragma] = STATE(931),
    [sym_preproc_nullable] = STATE(931),
    [sym_preproc_error] = STATE(931),
    [sym_preproc_warning] = STATE(931),
    [sym_preproc_define] = STATE(931),
    [sym_preproc_undef] = STATE(931),
    [aux_sym_class_declaration_repeat1] = STATE(3853),
    [aux_sym_lambda_expression_repeat1] = STATE(4299),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(2079),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1497),
    [anon_sym_ref] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1505),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1507),
    [anon_sym_DOT_DOT] = ACTIONS(1509),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [932] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4030),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6927),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2912),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7057),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5333),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3960),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7439),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9222),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(932),
    [sym_preproc_endregion] = STATE(932),
    [sym_preproc_line] = STATE(932),
    [sym_preproc_pragma] = STATE(932),
    [sym_preproc_nullable] = STATE(932),
    [sym_preproc_error] = STATE(932),
    [sym_preproc_warning] = STATE(932),
    [sym_preproc_define] = STATE(932),
    [sym_preproc_undef] = STATE(932),
    [aux_sym_class_declaration_repeat1] = STATE(3837),
    [aux_sym_lambda_expression_repeat1] = STATE(4265),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1591),
    [anon_sym_ref] = ACTIONS(1593),
    [anon_sym_LBRACE] = ACTIONS(2835),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1595),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1599),
    [anon_sym_TILDE] = ACTIONS(1599),
    [anon_sym_PLUS_PLUS] = ACTIONS(1599),
    [anon_sym_DASH_DASH] = ACTIONS(1599),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1597),
    [anon_sym_DASH] = ACTIONS(1597),
    [anon_sym_STAR] = ACTIONS(1601),
    [anon_sym_CARET] = ACTIONS(1599),
    [anon_sym_AMP] = ACTIONS(1599),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1603),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1605),
    [anon_sym_DOT_DOT] = ACTIONS(1607),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [933] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6956),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6389),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9482),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(933),
    [sym_preproc_endregion] = STATE(933),
    [sym_preproc_line] = STATE(933),
    [sym_preproc_pragma] = STATE(933),
    [sym_preproc_nullable] = STATE(933),
    [sym_preproc_error] = STATE(933),
    [sym_preproc_warning] = STATE(933),
    [sym_preproc_define] = STATE(933),
    [sym_preproc_undef] = STATE(933),
    [aux_sym_class_declaration_repeat1] = STATE(3853),
    [aux_sym_lambda_expression_repeat1] = STATE(4299),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(2885),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1497),
    [anon_sym_ref] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1505),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1507),
    [anon_sym_DOT_DOT] = ACTIONS(1509),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [934] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3763),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6948),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2940),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7022),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4959),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3795),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7417),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9004),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(934),
    [sym_preproc_endregion] = STATE(934),
    [sym_preproc_line] = STATE(934),
    [sym_preproc_pragma] = STATE(934),
    [sym_preproc_nullable] = STATE(934),
    [sym_preproc_error] = STATE(934),
    [sym_preproc_warning] = STATE(934),
    [sym_preproc_define] = STATE(934),
    [sym_preproc_undef] = STATE(934),
    [aux_sym_class_declaration_repeat1] = STATE(3827),
    [aux_sym_lambda_expression_repeat1] = STATE(4246),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1893),
    [anon_sym_ref] = ACTIONS(1895),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1897),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1901),
    [anon_sym_TILDE] = ACTIONS(1901),
    [anon_sym_PLUS_PLUS] = ACTIONS(1901),
    [anon_sym_DASH_DASH] = ACTIONS(1901),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1899),
    [anon_sym_DASH] = ACTIONS(1899),
    [anon_sym_STAR] = ACTIONS(1903),
    [anon_sym_CARET] = ACTIONS(1901),
    [anon_sym_AMP] = ACTIONS(1901),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1905),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1907),
    [anon_sym_DOT_DOT] = ACTIONS(1909),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [935] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3764),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6948),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2940),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7022),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4963),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3795),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7417),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9004),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(935),
    [sym_preproc_endregion] = STATE(935),
    [sym_preproc_line] = STATE(935),
    [sym_preproc_pragma] = STATE(935),
    [sym_preproc_nullable] = STATE(935),
    [sym_preproc_error] = STATE(935),
    [sym_preproc_warning] = STATE(935),
    [sym_preproc_define] = STATE(935),
    [sym_preproc_undef] = STATE(935),
    [aux_sym_class_declaration_repeat1] = STATE(3827),
    [aux_sym_lambda_expression_repeat1] = STATE(4246),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1893),
    [anon_sym_ref] = ACTIONS(1895),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1897),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1901),
    [anon_sym_TILDE] = ACTIONS(1901),
    [anon_sym_PLUS_PLUS] = ACTIONS(1901),
    [anon_sym_DASH_DASH] = ACTIONS(1901),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1899),
    [anon_sym_DASH] = ACTIONS(1899),
    [anon_sym_STAR] = ACTIONS(1903),
    [anon_sym_CARET] = ACTIONS(1901),
    [anon_sym_AMP] = ACTIONS(1901),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1905),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1907),
    [anon_sym_DOT_DOT] = ACTIONS(1909),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [936] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3780),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6948),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2940),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7022),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4964),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3795),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7417),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9004),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(936),
    [sym_preproc_endregion] = STATE(936),
    [sym_preproc_line] = STATE(936),
    [sym_preproc_pragma] = STATE(936),
    [sym_preproc_nullable] = STATE(936),
    [sym_preproc_error] = STATE(936),
    [sym_preproc_warning] = STATE(936),
    [sym_preproc_define] = STATE(936),
    [sym_preproc_undef] = STATE(936),
    [aux_sym_class_declaration_repeat1] = STATE(3827),
    [aux_sym_lambda_expression_repeat1] = STATE(4246),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1893),
    [anon_sym_ref] = ACTIONS(1895),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1897),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1901),
    [anon_sym_TILDE] = ACTIONS(1901),
    [anon_sym_PLUS_PLUS] = ACTIONS(1901),
    [anon_sym_DASH_DASH] = ACTIONS(1901),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1899),
    [anon_sym_DASH] = ACTIONS(1899),
    [anon_sym_STAR] = ACTIONS(1903),
    [anon_sym_CARET] = ACTIONS(1901),
    [anon_sym_AMP] = ACTIONS(1901),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1905),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1907),
    [anon_sym_DOT_DOT] = ACTIONS(1909),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [937] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3735),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6948),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2940),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7022),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4984),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3795),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7417),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9004),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(937),
    [sym_preproc_endregion] = STATE(937),
    [sym_preproc_line] = STATE(937),
    [sym_preproc_pragma] = STATE(937),
    [sym_preproc_nullable] = STATE(937),
    [sym_preproc_error] = STATE(937),
    [sym_preproc_warning] = STATE(937),
    [sym_preproc_define] = STATE(937),
    [sym_preproc_undef] = STATE(937),
    [aux_sym_class_declaration_repeat1] = STATE(3827),
    [aux_sym_lambda_expression_repeat1] = STATE(4246),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1893),
    [anon_sym_ref] = ACTIONS(1895),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1897),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1901),
    [anon_sym_TILDE] = ACTIONS(1901),
    [anon_sym_PLUS_PLUS] = ACTIONS(1901),
    [anon_sym_DASH_DASH] = ACTIONS(1901),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1899),
    [anon_sym_DASH] = ACTIONS(1899),
    [anon_sym_STAR] = ACTIONS(1903),
    [anon_sym_CARET] = ACTIONS(1901),
    [anon_sym_AMP] = ACTIONS(1901),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1905),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1907),
    [anon_sym_DOT_DOT] = ACTIONS(1909),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [938] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3741),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6948),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2940),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7022),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4986),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3795),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7417),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9004),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(938),
    [sym_preproc_endregion] = STATE(938),
    [sym_preproc_line] = STATE(938),
    [sym_preproc_pragma] = STATE(938),
    [sym_preproc_nullable] = STATE(938),
    [sym_preproc_error] = STATE(938),
    [sym_preproc_warning] = STATE(938),
    [sym_preproc_define] = STATE(938),
    [sym_preproc_undef] = STATE(938),
    [aux_sym_class_declaration_repeat1] = STATE(3827),
    [aux_sym_lambda_expression_repeat1] = STATE(4246),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1893),
    [anon_sym_ref] = ACTIONS(1895),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1897),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1901),
    [anon_sym_TILDE] = ACTIONS(1901),
    [anon_sym_PLUS_PLUS] = ACTIONS(1901),
    [anon_sym_DASH_DASH] = ACTIONS(1901),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1899),
    [anon_sym_DASH] = ACTIONS(1899),
    [anon_sym_STAR] = ACTIONS(1903),
    [anon_sym_CARET] = ACTIONS(1901),
    [anon_sym_AMP] = ACTIONS(1901),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1905),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1907),
    [anon_sym_DOT_DOT] = ACTIONS(1909),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [939] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3754),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6948),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2940),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7022),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4967),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3795),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7417),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9004),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(939),
    [sym_preproc_endregion] = STATE(939),
    [sym_preproc_line] = STATE(939),
    [sym_preproc_pragma] = STATE(939),
    [sym_preproc_nullable] = STATE(939),
    [sym_preproc_error] = STATE(939),
    [sym_preproc_warning] = STATE(939),
    [sym_preproc_define] = STATE(939),
    [sym_preproc_undef] = STATE(939),
    [aux_sym_class_declaration_repeat1] = STATE(3827),
    [aux_sym_lambda_expression_repeat1] = STATE(4246),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1893),
    [anon_sym_ref] = ACTIONS(1895),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1897),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1901),
    [anon_sym_TILDE] = ACTIONS(1901),
    [anon_sym_PLUS_PLUS] = ACTIONS(1901),
    [anon_sym_DASH_DASH] = ACTIONS(1901),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1899),
    [anon_sym_DASH] = ACTIONS(1899),
    [anon_sym_STAR] = ACTIONS(1903),
    [anon_sym_CARET] = ACTIONS(1901),
    [anon_sym_AMP] = ACTIONS(1901),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1905),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1907),
    [anon_sym_DOT_DOT] = ACTIONS(1909),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [940] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6956),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6393),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9482),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(940),
    [sym_preproc_endregion] = STATE(940),
    [sym_preproc_line] = STATE(940),
    [sym_preproc_pragma] = STATE(940),
    [sym_preproc_nullable] = STATE(940),
    [sym_preproc_error] = STATE(940),
    [sym_preproc_warning] = STATE(940),
    [sym_preproc_define] = STATE(940),
    [sym_preproc_undef] = STATE(940),
    [aux_sym_class_declaration_repeat1] = STATE(3853),
    [aux_sym_lambda_expression_repeat1] = STATE(4299),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(2887),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1497),
    [anon_sym_ref] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1505),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1507),
    [anon_sym_DOT_DOT] = ACTIONS(1509),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [941] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4643),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6911),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2930),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7027),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4462),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3605),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7434),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9856),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(941),
    [sym_preproc_endregion] = STATE(941),
    [sym_preproc_line] = STATE(941),
    [sym_preproc_pragma] = STATE(941),
    [sym_preproc_nullable] = STATE(941),
    [sym_preproc_error] = STATE(941),
    [sym_preproc_warning] = STATE(941),
    [sym_preproc_define] = STATE(941),
    [sym_preproc_undef] = STATE(941),
    [aux_sym_class_declaration_repeat1] = STATE(3828),
    [aux_sym_lambda_expression_repeat1] = STATE(4248),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1687),
    [anon_sym_ref] = ACTIONS(1689),
    [anon_sym_LBRACE] = ACTIONS(2847),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1695),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1701),
    [anon_sym_TILDE] = ACTIONS(1701),
    [anon_sym_PLUS_PLUS] = ACTIONS(1701),
    [anon_sym_DASH_DASH] = ACTIONS(1701),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1699),
    [anon_sym_DASH] = ACTIONS(1699),
    [anon_sym_STAR] = ACTIONS(1705),
    [anon_sym_CARET] = ACTIONS(1701),
    [anon_sym_AMP] = ACTIONS(1701),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(1715),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1717),
    [anon_sym_DOT_DOT] = ACTIONS(1719),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [942] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4708),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6911),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2930),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7027),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4476),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3605),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7434),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9856),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(942),
    [sym_preproc_endregion] = STATE(942),
    [sym_preproc_line] = STATE(942),
    [sym_preproc_pragma] = STATE(942),
    [sym_preproc_nullable] = STATE(942),
    [sym_preproc_error] = STATE(942),
    [sym_preproc_warning] = STATE(942),
    [sym_preproc_define] = STATE(942),
    [sym_preproc_undef] = STATE(942),
    [aux_sym_class_declaration_repeat1] = STATE(3828),
    [aux_sym_lambda_expression_repeat1] = STATE(4248),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1687),
    [anon_sym_ref] = ACTIONS(1689),
    [anon_sym_LBRACE] = ACTIONS(2847),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1695),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1701),
    [anon_sym_TILDE] = ACTIONS(1701),
    [anon_sym_PLUS_PLUS] = ACTIONS(1701),
    [anon_sym_DASH_DASH] = ACTIONS(1701),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1699),
    [anon_sym_DASH] = ACTIONS(1699),
    [anon_sym_STAR] = ACTIONS(1705),
    [anon_sym_CARET] = ACTIONS(1701),
    [anon_sym_AMP] = ACTIONS(1701),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(1715),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1717),
    [anon_sym_DOT_DOT] = ACTIONS(1719),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [943] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3763),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6956),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5776),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9482),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(943),
    [sym_preproc_endregion] = STATE(943),
    [sym_preproc_line] = STATE(943),
    [sym_preproc_pragma] = STATE(943),
    [sym_preproc_nullable] = STATE(943),
    [sym_preproc_error] = STATE(943),
    [sym_preproc_warning] = STATE(943),
    [sym_preproc_define] = STATE(943),
    [sym_preproc_undef] = STATE(943),
    [aux_sym_class_declaration_repeat1] = STATE(3853),
    [aux_sym_lambda_expression_repeat1] = STATE(4299),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1497),
    [anon_sym_ref] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1505),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1507),
    [anon_sym_DOT_DOT] = ACTIONS(1509),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [944] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4719),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6911),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2930),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7027),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4498),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3605),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7434),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9856),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(944),
    [sym_preproc_endregion] = STATE(944),
    [sym_preproc_line] = STATE(944),
    [sym_preproc_pragma] = STATE(944),
    [sym_preproc_nullable] = STATE(944),
    [sym_preproc_error] = STATE(944),
    [sym_preproc_warning] = STATE(944),
    [sym_preproc_define] = STATE(944),
    [sym_preproc_undef] = STATE(944),
    [aux_sym_class_declaration_repeat1] = STATE(3828),
    [aux_sym_lambda_expression_repeat1] = STATE(4248),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1687),
    [anon_sym_ref] = ACTIONS(1689),
    [anon_sym_LBRACE] = ACTIONS(2847),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1695),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1701),
    [anon_sym_TILDE] = ACTIONS(1701),
    [anon_sym_PLUS_PLUS] = ACTIONS(1701),
    [anon_sym_DASH_DASH] = ACTIONS(1701),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1699),
    [anon_sym_DASH] = ACTIONS(1699),
    [anon_sym_STAR] = ACTIONS(1705),
    [anon_sym_CARET] = ACTIONS(1701),
    [anon_sym_AMP] = ACTIONS(1701),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(1715),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1717),
    [anon_sym_DOT_DOT] = ACTIONS(1719),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [945] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4101),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6913),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2905),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6979),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5455),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4178),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7433),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9183),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(945),
    [sym_preproc_endregion] = STATE(945),
    [sym_preproc_line] = STATE(945),
    [sym_preproc_pragma] = STATE(945),
    [sym_preproc_nullable] = STATE(945),
    [sym_preproc_error] = STATE(945),
    [sym_preproc_warning] = STATE(945),
    [sym_preproc_define] = STATE(945),
    [sym_preproc_undef] = STATE(945),
    [aux_sym_class_declaration_repeat1] = STATE(3816),
    [aux_sym_lambda_expression_repeat1] = STATE(4225),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1573),
    [anon_sym_ref] = ACTIONS(1575),
    [anon_sym_LBRACE] = ACTIONS(2831),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1577),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1581),
    [anon_sym_TILDE] = ACTIONS(1581),
    [anon_sym_PLUS_PLUS] = ACTIONS(1581),
    [anon_sym_DASH_DASH] = ACTIONS(1581),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1579),
    [anon_sym_DASH] = ACTIONS(1579),
    [anon_sym_STAR] = ACTIONS(1583),
    [anon_sym_CARET] = ACTIONS(1581),
    [anon_sym_AMP] = ACTIONS(1581),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1585),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1587),
    [anon_sym_DOT_DOT] = ACTIONS(1589),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [946] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5791),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(946),
    [sym_preproc_endregion] = STATE(946),
    [sym_preproc_line] = STATE(946),
    [sym_preproc_pragma] = STATE(946),
    [sym_preproc_nullable] = STATE(946),
    [sym_preproc_error] = STATE(946),
    [sym_preproc_warning] = STATE(946),
    [sym_preproc_define] = STATE(946),
    [sym_preproc_undef] = STATE(946),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_RBRACE] = ACTIONS(2889),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [947] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4677),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6911),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2930),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7027),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4526),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3605),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7434),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9856),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(947),
    [sym_preproc_endregion] = STATE(947),
    [sym_preproc_line] = STATE(947),
    [sym_preproc_pragma] = STATE(947),
    [sym_preproc_nullable] = STATE(947),
    [sym_preproc_error] = STATE(947),
    [sym_preproc_warning] = STATE(947),
    [sym_preproc_define] = STATE(947),
    [sym_preproc_undef] = STATE(947),
    [aux_sym_class_declaration_repeat1] = STATE(3828),
    [aux_sym_lambda_expression_repeat1] = STATE(4248),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1687),
    [anon_sym_ref] = ACTIONS(1689),
    [anon_sym_LBRACE] = ACTIONS(2847),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1695),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1701),
    [anon_sym_TILDE] = ACTIONS(1701),
    [anon_sym_PLUS_PLUS] = ACTIONS(1701),
    [anon_sym_DASH_DASH] = ACTIONS(1701),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1699),
    [anon_sym_DASH] = ACTIONS(1699),
    [anon_sym_STAR] = ACTIONS(1705),
    [anon_sym_CARET] = ACTIONS(1701),
    [anon_sym_AMP] = ACTIONS(1701),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(1715),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1717),
    [anon_sym_DOT_DOT] = ACTIONS(1719),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [948] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4671),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6911),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2930),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7027),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4527),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3605),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7434),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9856),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(948),
    [sym_preproc_endregion] = STATE(948),
    [sym_preproc_line] = STATE(948),
    [sym_preproc_pragma] = STATE(948),
    [sym_preproc_nullable] = STATE(948),
    [sym_preproc_error] = STATE(948),
    [sym_preproc_warning] = STATE(948),
    [sym_preproc_define] = STATE(948),
    [sym_preproc_undef] = STATE(948),
    [aux_sym_class_declaration_repeat1] = STATE(3828),
    [aux_sym_lambda_expression_repeat1] = STATE(4248),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1687),
    [anon_sym_ref] = ACTIONS(1689),
    [anon_sym_LBRACE] = ACTIONS(2847),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1695),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1701),
    [anon_sym_TILDE] = ACTIONS(1701),
    [anon_sym_PLUS_PLUS] = ACTIONS(1701),
    [anon_sym_DASH_DASH] = ACTIONS(1701),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1699),
    [anon_sym_DASH] = ACTIONS(1699),
    [anon_sym_STAR] = ACTIONS(1705),
    [anon_sym_CARET] = ACTIONS(1701),
    [anon_sym_AMP] = ACTIONS(1701),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(1715),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1717),
    [anon_sym_DOT_DOT] = ACTIONS(1719),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [949] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4676),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6911),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2930),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7027),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4531),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3605),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7434),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9856),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(949),
    [sym_preproc_endregion] = STATE(949),
    [sym_preproc_line] = STATE(949),
    [sym_preproc_pragma] = STATE(949),
    [sym_preproc_nullable] = STATE(949),
    [sym_preproc_error] = STATE(949),
    [sym_preproc_warning] = STATE(949),
    [sym_preproc_define] = STATE(949),
    [sym_preproc_undef] = STATE(949),
    [aux_sym_class_declaration_repeat1] = STATE(3828),
    [aux_sym_lambda_expression_repeat1] = STATE(4248),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1687),
    [anon_sym_ref] = ACTIONS(1689),
    [anon_sym_LBRACE] = ACTIONS(2847),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1695),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1701),
    [anon_sym_TILDE] = ACTIONS(1701),
    [anon_sym_PLUS_PLUS] = ACTIONS(1701),
    [anon_sym_DASH_DASH] = ACTIONS(1701),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1699),
    [anon_sym_DASH] = ACTIONS(1699),
    [anon_sym_STAR] = ACTIONS(1705),
    [anon_sym_CARET] = ACTIONS(1701),
    [anon_sym_AMP] = ACTIONS(1701),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(1715),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1717),
    [anon_sym_DOT_DOT] = ACTIONS(1719),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [950] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6948),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2940),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7023),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4953),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3795),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7417),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9004),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(950),
    [sym_preproc_endregion] = STATE(950),
    [sym_preproc_line] = STATE(950),
    [sym_preproc_pragma] = STATE(950),
    [sym_preproc_nullable] = STATE(950),
    [sym_preproc_error] = STATE(950),
    [sym_preproc_warning] = STATE(950),
    [sym_preproc_define] = STATE(950),
    [sym_preproc_undef] = STATE(950),
    [aux_sym_class_declaration_repeat1] = STATE(3827),
    [aux_sym_lambda_expression_repeat1] = STATE(4246),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1893),
    [anon_sym_ref] = ACTIONS(1895),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1897),
    [anon_sym_readonly] = ACTIONS(2767),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1901),
    [anon_sym_TILDE] = ACTIONS(1901),
    [anon_sym_PLUS_PLUS] = ACTIONS(1901),
    [anon_sym_DASH_DASH] = ACTIONS(1901),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1899),
    [anon_sym_DASH] = ACTIONS(1899),
    [anon_sym_STAR] = ACTIONS(1903),
    [anon_sym_CARET] = ACTIONS(1901),
    [anon_sym_AMP] = ACTIONS(1901),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1905),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1907),
    [anon_sym_DOT_DOT] = ACTIONS(1909),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [951] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6911),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2930),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7028),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4521),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3605),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7434),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9856),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(951),
    [sym_preproc_endregion] = STATE(951),
    [sym_preproc_line] = STATE(951),
    [sym_preproc_pragma] = STATE(951),
    [sym_preproc_nullable] = STATE(951),
    [sym_preproc_error] = STATE(951),
    [sym_preproc_warning] = STATE(951),
    [sym_preproc_define] = STATE(951),
    [sym_preproc_undef] = STATE(951),
    [aux_sym_class_declaration_repeat1] = STATE(3828),
    [aux_sym_lambda_expression_repeat1] = STATE(4248),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1687),
    [anon_sym_ref] = ACTIONS(1689),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1695),
    [anon_sym_readonly] = ACTIONS(2767),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1701),
    [anon_sym_TILDE] = ACTIONS(1701),
    [anon_sym_PLUS_PLUS] = ACTIONS(1701),
    [anon_sym_DASH_DASH] = ACTIONS(1701),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1699),
    [anon_sym_DASH] = ACTIONS(1699),
    [anon_sym_STAR] = ACTIONS(1705),
    [anon_sym_CARET] = ACTIONS(1701),
    [anon_sym_AMP] = ACTIONS(1701),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(1715),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1717),
    [anon_sym_DOT_DOT] = ACTIONS(1719),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [952] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(5615),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6921),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2873),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(6957),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5825),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4346),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7445),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9875),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(952),
    [sym_preproc_endregion] = STATE(952),
    [sym_preproc_line] = STATE(952),
    [sym_preproc_pragma] = STATE(952),
    [sym_preproc_nullable] = STATE(952),
    [sym_preproc_error] = STATE(952),
    [sym_preproc_warning] = STATE(952),
    [sym_preproc_define] = STATE(952),
    [sym_preproc_undef] = STATE(952),
    [aux_sym_class_declaration_repeat1] = STATE(3810),
    [aux_sym_lambda_expression_repeat1] = STATE(4192),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1639),
    [anon_sym_ref] = ACTIONS(1641),
    [anon_sym_LBRACE] = ACTIONS(2857),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1415),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1645),
    [anon_sym_TILDE] = ACTIONS(1645),
    [anon_sym_PLUS_PLUS] = ACTIONS(1645),
    [anon_sym_DASH_DASH] = ACTIONS(1645),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1643),
    [anon_sym_DASH] = ACTIONS(1643),
    [anon_sym_STAR] = ACTIONS(1425),
    [anon_sym_CARET] = ACTIONS(1645),
    [anon_sym_AMP] = ACTIONS(1645),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1647),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1649),
    [anon_sym_DOT_DOT] = ACTIONS(1651),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [953] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(5561),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6921),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2873),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7036),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5330),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4038),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7429),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9220),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(953),
    [sym_preproc_endregion] = STATE(953),
    [sym_preproc_line] = STATE(953),
    [sym_preproc_pragma] = STATE(953),
    [sym_preproc_nullable] = STATE(953),
    [sym_preproc_error] = STATE(953),
    [sym_preproc_warning] = STATE(953),
    [sym_preproc_define] = STATE(953),
    [sym_preproc_undef] = STATE(953),
    [aux_sym_class_declaration_repeat1] = STATE(3830),
    [aux_sym_lambda_expression_repeat1] = STATE(4255),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1407),
    [anon_sym_ref] = ACTIONS(1409),
    [anon_sym_LBRACE] = ACTIONS(2857),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1415),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1421),
    [anon_sym_TILDE] = ACTIONS(1421),
    [anon_sym_PLUS_PLUS] = ACTIONS(1421),
    [anon_sym_DASH_DASH] = ACTIONS(1421),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1419),
    [anon_sym_DASH] = ACTIONS(1419),
    [anon_sym_STAR] = ACTIONS(1425),
    [anon_sym_CARET] = ACTIONS(1421),
    [anon_sym_AMP] = ACTIONS(1421),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1439),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1441),
    [anon_sym_DOT_DOT] = ACTIONS(1443),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [954] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(5577),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6921),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2873),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7036),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5381),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4038),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7429),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9220),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(954),
    [sym_preproc_endregion] = STATE(954),
    [sym_preproc_line] = STATE(954),
    [sym_preproc_pragma] = STATE(954),
    [sym_preproc_nullable] = STATE(954),
    [sym_preproc_error] = STATE(954),
    [sym_preproc_warning] = STATE(954),
    [sym_preproc_define] = STATE(954),
    [sym_preproc_undef] = STATE(954),
    [aux_sym_class_declaration_repeat1] = STATE(3830),
    [aux_sym_lambda_expression_repeat1] = STATE(4255),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1407),
    [anon_sym_ref] = ACTIONS(1409),
    [anon_sym_LBRACE] = ACTIONS(2857),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1415),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1421),
    [anon_sym_TILDE] = ACTIONS(1421),
    [anon_sym_PLUS_PLUS] = ACTIONS(1421),
    [anon_sym_DASH_DASH] = ACTIONS(1421),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1419),
    [anon_sym_DASH] = ACTIONS(1419),
    [anon_sym_STAR] = ACTIONS(1425),
    [anon_sym_CARET] = ACTIONS(1421),
    [anon_sym_AMP] = ACTIONS(1421),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1439),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1441),
    [anon_sym_DOT_DOT] = ACTIONS(1443),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [955] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(5582),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6921),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2873),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7036),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5273),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4038),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7429),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9220),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(955),
    [sym_preproc_endregion] = STATE(955),
    [sym_preproc_line] = STATE(955),
    [sym_preproc_pragma] = STATE(955),
    [sym_preproc_nullable] = STATE(955),
    [sym_preproc_error] = STATE(955),
    [sym_preproc_warning] = STATE(955),
    [sym_preproc_define] = STATE(955),
    [sym_preproc_undef] = STATE(955),
    [aux_sym_class_declaration_repeat1] = STATE(3830),
    [aux_sym_lambda_expression_repeat1] = STATE(4255),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1407),
    [anon_sym_ref] = ACTIONS(1409),
    [anon_sym_LBRACE] = ACTIONS(2857),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1415),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1421),
    [anon_sym_TILDE] = ACTIONS(1421),
    [anon_sym_PLUS_PLUS] = ACTIONS(1421),
    [anon_sym_DASH_DASH] = ACTIONS(1421),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1419),
    [anon_sym_DASH] = ACTIONS(1419),
    [anon_sym_STAR] = ACTIONS(1425),
    [anon_sym_CARET] = ACTIONS(1421),
    [anon_sym_AMP] = ACTIONS(1421),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1439),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1441),
    [anon_sym_DOT_DOT] = ACTIONS(1443),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [956] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(5615),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6921),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2873),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7036),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5303),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4038),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7429),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9220),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(956),
    [sym_preproc_endregion] = STATE(956),
    [sym_preproc_line] = STATE(956),
    [sym_preproc_pragma] = STATE(956),
    [sym_preproc_nullable] = STATE(956),
    [sym_preproc_error] = STATE(956),
    [sym_preproc_warning] = STATE(956),
    [sym_preproc_define] = STATE(956),
    [sym_preproc_undef] = STATE(956),
    [aux_sym_class_declaration_repeat1] = STATE(3830),
    [aux_sym_lambda_expression_repeat1] = STATE(4255),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1407),
    [anon_sym_ref] = ACTIONS(1409),
    [anon_sym_LBRACE] = ACTIONS(2857),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1415),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1421),
    [anon_sym_TILDE] = ACTIONS(1421),
    [anon_sym_PLUS_PLUS] = ACTIONS(1421),
    [anon_sym_DASH_DASH] = ACTIONS(1421),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1419),
    [anon_sym_DASH] = ACTIONS(1419),
    [anon_sym_STAR] = ACTIONS(1425),
    [anon_sym_CARET] = ACTIONS(1421),
    [anon_sym_AMP] = ACTIONS(1421),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1439),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1441),
    [anon_sym_DOT_DOT] = ACTIONS(1443),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [957] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(5618),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6921),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2873),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7036),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5304),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4038),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7429),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9220),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(957),
    [sym_preproc_endregion] = STATE(957),
    [sym_preproc_line] = STATE(957),
    [sym_preproc_pragma] = STATE(957),
    [sym_preproc_nullable] = STATE(957),
    [sym_preproc_error] = STATE(957),
    [sym_preproc_warning] = STATE(957),
    [sym_preproc_define] = STATE(957),
    [sym_preproc_undef] = STATE(957),
    [aux_sym_class_declaration_repeat1] = STATE(3830),
    [aux_sym_lambda_expression_repeat1] = STATE(4255),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1407),
    [anon_sym_ref] = ACTIONS(1409),
    [anon_sym_LBRACE] = ACTIONS(2857),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1415),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1421),
    [anon_sym_TILDE] = ACTIONS(1421),
    [anon_sym_PLUS_PLUS] = ACTIONS(1421),
    [anon_sym_DASH_DASH] = ACTIONS(1421),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1419),
    [anon_sym_DASH] = ACTIONS(1419),
    [anon_sym_STAR] = ACTIONS(1425),
    [anon_sym_CARET] = ACTIONS(1421),
    [anon_sym_AMP] = ACTIONS(1421),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1439),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1441),
    [anon_sym_DOT_DOT] = ACTIONS(1443),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [958] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(5639),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6921),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2873),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7036),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5396),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4038),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7429),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9220),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(958),
    [sym_preproc_endregion] = STATE(958),
    [sym_preproc_line] = STATE(958),
    [sym_preproc_pragma] = STATE(958),
    [sym_preproc_nullable] = STATE(958),
    [sym_preproc_error] = STATE(958),
    [sym_preproc_warning] = STATE(958),
    [sym_preproc_define] = STATE(958),
    [sym_preproc_undef] = STATE(958),
    [aux_sym_class_declaration_repeat1] = STATE(3830),
    [aux_sym_lambda_expression_repeat1] = STATE(4255),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1407),
    [anon_sym_ref] = ACTIONS(1409),
    [anon_sym_LBRACE] = ACTIONS(2857),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1415),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1421),
    [anon_sym_TILDE] = ACTIONS(1421),
    [anon_sym_PLUS_PLUS] = ACTIONS(1421),
    [anon_sym_DASH_DASH] = ACTIONS(1421),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1419),
    [anon_sym_DASH] = ACTIONS(1419),
    [anon_sym_STAR] = ACTIONS(1425),
    [anon_sym_CARET] = ACTIONS(1421),
    [anon_sym_AMP] = ACTIONS(1421),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1439),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1441),
    [anon_sym_DOT_DOT] = ACTIONS(1443),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [959] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3764),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6956),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5783),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9482),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(959),
    [sym_preproc_endregion] = STATE(959),
    [sym_preproc_line] = STATE(959),
    [sym_preproc_pragma] = STATE(959),
    [sym_preproc_nullable] = STATE(959),
    [sym_preproc_error] = STATE(959),
    [sym_preproc_warning] = STATE(959),
    [sym_preproc_define] = STATE(959),
    [sym_preproc_undef] = STATE(959),
    [aux_sym_class_declaration_repeat1] = STATE(3853),
    [aux_sym_lambda_expression_repeat1] = STATE(4299),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1497),
    [anon_sym_ref] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1505),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1507),
    [anon_sym_DOT_DOT] = ACTIONS(1509),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [960] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(5618),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6921),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2873),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(6957),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5828),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4346),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7445),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9875),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(960),
    [sym_preproc_endregion] = STATE(960),
    [sym_preproc_line] = STATE(960),
    [sym_preproc_pragma] = STATE(960),
    [sym_preproc_nullable] = STATE(960),
    [sym_preproc_error] = STATE(960),
    [sym_preproc_warning] = STATE(960),
    [sym_preproc_define] = STATE(960),
    [sym_preproc_undef] = STATE(960),
    [aux_sym_class_declaration_repeat1] = STATE(3810),
    [aux_sym_lambda_expression_repeat1] = STATE(4192),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1639),
    [anon_sym_ref] = ACTIONS(1641),
    [anon_sym_LBRACE] = ACTIONS(2857),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1415),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1645),
    [anon_sym_TILDE] = ACTIONS(1645),
    [anon_sym_PLUS_PLUS] = ACTIONS(1645),
    [anon_sym_DASH_DASH] = ACTIONS(1645),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1643),
    [anon_sym_DASH] = ACTIONS(1643),
    [anon_sym_STAR] = ACTIONS(1425),
    [anon_sym_CARET] = ACTIONS(1645),
    [anon_sym_AMP] = ACTIONS(1645),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1647),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1649),
    [anon_sym_DOT_DOT] = ACTIONS(1651),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [961] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4152),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7010),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5962),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4334),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9265),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(961),
    [sym_preproc_endregion] = STATE(961),
    [sym_preproc_line] = STATE(961),
    [sym_preproc_pragma] = STATE(961),
    [sym_preproc_nullable] = STATE(961),
    [sym_preproc_error] = STATE(961),
    [sym_preproc_warning] = STATE(961),
    [sym_preproc_define] = STATE(961),
    [sym_preproc_undef] = STATE(961),
    [aux_sym_class_declaration_repeat1] = STATE(3823),
    [aux_sym_lambda_expression_repeat1] = STATE(4240),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1751),
    [anon_sym_ref] = ACTIONS(1753),
    [anon_sym_LBRACE] = ACTIONS(2831),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1755),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1759),
    [anon_sym_TILDE] = ACTIONS(1759),
    [anon_sym_PLUS_PLUS] = ACTIONS(1759),
    [anon_sym_DASH_DASH] = ACTIONS(1759),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1757),
    [anon_sym_DASH] = ACTIONS(1757),
    [anon_sym_STAR] = ACTIONS(1381),
    [anon_sym_CARET] = ACTIONS(1759),
    [anon_sym_AMP] = ACTIONS(1759),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1761),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1763),
    [anon_sym_DOT_DOT] = ACTIONS(1765),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [962] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4119),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7010),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5963),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4334),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9265),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(962),
    [sym_preproc_endregion] = STATE(962),
    [sym_preproc_line] = STATE(962),
    [sym_preproc_pragma] = STATE(962),
    [sym_preproc_nullable] = STATE(962),
    [sym_preproc_error] = STATE(962),
    [sym_preproc_warning] = STATE(962),
    [sym_preproc_define] = STATE(962),
    [sym_preproc_undef] = STATE(962),
    [aux_sym_class_declaration_repeat1] = STATE(3823),
    [aux_sym_lambda_expression_repeat1] = STATE(4240),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1751),
    [anon_sym_ref] = ACTIONS(1753),
    [anon_sym_LBRACE] = ACTIONS(2831),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1755),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1759),
    [anon_sym_TILDE] = ACTIONS(1759),
    [anon_sym_PLUS_PLUS] = ACTIONS(1759),
    [anon_sym_DASH_DASH] = ACTIONS(1759),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1757),
    [anon_sym_DASH] = ACTIONS(1757),
    [anon_sym_STAR] = ACTIONS(1381),
    [anon_sym_CARET] = ACTIONS(1759),
    [anon_sym_AMP] = ACTIONS(1759),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1761),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1763),
    [anon_sym_DOT_DOT] = ACTIONS(1765),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [963] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4119),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6913),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2905),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6979),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5451),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4178),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7433),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9183),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(963),
    [sym_preproc_endregion] = STATE(963),
    [sym_preproc_line] = STATE(963),
    [sym_preproc_pragma] = STATE(963),
    [sym_preproc_nullable] = STATE(963),
    [sym_preproc_error] = STATE(963),
    [sym_preproc_warning] = STATE(963),
    [sym_preproc_define] = STATE(963),
    [sym_preproc_undef] = STATE(963),
    [aux_sym_class_declaration_repeat1] = STATE(3816),
    [aux_sym_lambda_expression_repeat1] = STATE(4225),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1573),
    [anon_sym_ref] = ACTIONS(1575),
    [anon_sym_LBRACE] = ACTIONS(2831),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1577),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1581),
    [anon_sym_TILDE] = ACTIONS(1581),
    [anon_sym_PLUS_PLUS] = ACTIONS(1581),
    [anon_sym_DASH_DASH] = ACTIONS(1581),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1579),
    [anon_sym_DASH] = ACTIONS(1579),
    [anon_sym_STAR] = ACTIONS(1583),
    [anon_sym_CARET] = ACTIONS(1581),
    [anon_sym_AMP] = ACTIONS(1581),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1585),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1587),
    [anon_sym_DOT_DOT] = ACTIONS(1589),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [964] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4101),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7010),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5966),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4334),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9265),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(964),
    [sym_preproc_endregion] = STATE(964),
    [sym_preproc_line] = STATE(964),
    [sym_preproc_pragma] = STATE(964),
    [sym_preproc_nullable] = STATE(964),
    [sym_preproc_error] = STATE(964),
    [sym_preproc_warning] = STATE(964),
    [sym_preproc_define] = STATE(964),
    [sym_preproc_undef] = STATE(964),
    [aux_sym_class_declaration_repeat1] = STATE(3823),
    [aux_sym_lambda_expression_repeat1] = STATE(4240),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1751),
    [anon_sym_ref] = ACTIONS(1753),
    [anon_sym_LBRACE] = ACTIONS(2831),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1755),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1759),
    [anon_sym_TILDE] = ACTIONS(1759),
    [anon_sym_PLUS_PLUS] = ACTIONS(1759),
    [anon_sym_DASH_DASH] = ACTIONS(1759),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1757),
    [anon_sym_DASH] = ACTIONS(1757),
    [anon_sym_STAR] = ACTIONS(1381),
    [anon_sym_CARET] = ACTIONS(1759),
    [anon_sym_AMP] = ACTIONS(1759),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1761),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1763),
    [anon_sym_DOT_DOT] = ACTIONS(1765),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [965] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4102),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7010),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5967),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4334),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9265),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(965),
    [sym_preproc_endregion] = STATE(965),
    [sym_preproc_line] = STATE(965),
    [sym_preproc_pragma] = STATE(965),
    [sym_preproc_nullable] = STATE(965),
    [sym_preproc_error] = STATE(965),
    [sym_preproc_warning] = STATE(965),
    [sym_preproc_define] = STATE(965),
    [sym_preproc_undef] = STATE(965),
    [aux_sym_class_declaration_repeat1] = STATE(3823),
    [aux_sym_lambda_expression_repeat1] = STATE(4240),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1751),
    [anon_sym_ref] = ACTIONS(1753),
    [anon_sym_LBRACE] = ACTIONS(2831),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1755),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1759),
    [anon_sym_TILDE] = ACTIONS(1759),
    [anon_sym_PLUS_PLUS] = ACTIONS(1759),
    [anon_sym_DASH_DASH] = ACTIONS(1759),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1757),
    [anon_sym_DASH] = ACTIONS(1757),
    [anon_sym_STAR] = ACTIONS(1381),
    [anon_sym_CARET] = ACTIONS(1759),
    [anon_sym_AMP] = ACTIONS(1759),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1761),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1763),
    [anon_sym_DOT_DOT] = ACTIONS(1765),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [966] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4111),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7010),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5968),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4334),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9265),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(966),
    [sym_preproc_endregion] = STATE(966),
    [sym_preproc_line] = STATE(966),
    [sym_preproc_pragma] = STATE(966),
    [sym_preproc_nullable] = STATE(966),
    [sym_preproc_error] = STATE(966),
    [sym_preproc_warning] = STATE(966),
    [sym_preproc_define] = STATE(966),
    [sym_preproc_undef] = STATE(966),
    [aux_sym_class_declaration_repeat1] = STATE(3823),
    [aux_sym_lambda_expression_repeat1] = STATE(4240),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1751),
    [anon_sym_ref] = ACTIONS(1753),
    [anon_sym_LBRACE] = ACTIONS(2831),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1755),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1759),
    [anon_sym_TILDE] = ACTIONS(1759),
    [anon_sym_PLUS_PLUS] = ACTIONS(1759),
    [anon_sym_DASH_DASH] = ACTIONS(1759),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1757),
    [anon_sym_DASH] = ACTIONS(1757),
    [anon_sym_STAR] = ACTIONS(1381),
    [anon_sym_CARET] = ACTIONS(1759),
    [anon_sym_AMP] = ACTIONS(1759),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1761),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1763),
    [anon_sym_DOT_DOT] = ACTIONS(1765),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [967] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6921),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2873),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7037),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5292),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4038),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7429),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9220),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(967),
    [sym_preproc_endregion] = STATE(967),
    [sym_preproc_line] = STATE(967),
    [sym_preproc_pragma] = STATE(967),
    [sym_preproc_nullable] = STATE(967),
    [sym_preproc_error] = STATE(967),
    [sym_preproc_warning] = STATE(967),
    [sym_preproc_define] = STATE(967),
    [sym_preproc_undef] = STATE(967),
    [aux_sym_class_declaration_repeat1] = STATE(3830),
    [aux_sym_lambda_expression_repeat1] = STATE(4255),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1407),
    [anon_sym_ref] = ACTIONS(1409),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1415),
    [anon_sym_readonly] = ACTIONS(2767),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1421),
    [anon_sym_TILDE] = ACTIONS(1421),
    [anon_sym_PLUS_PLUS] = ACTIONS(1421),
    [anon_sym_DASH_DASH] = ACTIONS(1421),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1419),
    [anon_sym_DASH] = ACTIONS(1419),
    [anon_sym_STAR] = ACTIONS(1425),
    [anon_sym_CARET] = ACTIONS(1421),
    [anon_sym_AMP] = ACTIONS(1421),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1439),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1441),
    [anon_sym_DOT_DOT] = ACTIONS(1443),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [968] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7011),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5969),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4334),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9265),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(968),
    [sym_preproc_endregion] = STATE(968),
    [sym_preproc_line] = STATE(968),
    [sym_preproc_pragma] = STATE(968),
    [sym_preproc_nullable] = STATE(968),
    [sym_preproc_error] = STATE(968),
    [sym_preproc_warning] = STATE(968),
    [sym_preproc_define] = STATE(968),
    [sym_preproc_undef] = STATE(968),
    [aux_sym_class_declaration_repeat1] = STATE(3823),
    [aux_sym_lambda_expression_repeat1] = STATE(4240),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1751),
    [anon_sym_ref] = ACTIONS(1753),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1755),
    [anon_sym_readonly] = ACTIONS(2767),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1759),
    [anon_sym_TILDE] = ACTIONS(1759),
    [anon_sym_PLUS_PLUS] = ACTIONS(1759),
    [anon_sym_DASH_DASH] = ACTIONS(1759),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1757),
    [anon_sym_DASH] = ACTIONS(1757),
    [anon_sym_STAR] = ACTIONS(1381),
    [anon_sym_CARET] = ACTIONS(1759),
    [anon_sym_AMP] = ACTIONS(1759),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1761),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1763),
    [anon_sym_DOT_DOT] = ACTIONS(1765),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [969] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(5639),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6921),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2873),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(6957),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5838),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4346),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7445),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9875),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(969),
    [sym_preproc_endregion] = STATE(969),
    [sym_preproc_line] = STATE(969),
    [sym_preproc_pragma] = STATE(969),
    [sym_preproc_nullable] = STATE(969),
    [sym_preproc_error] = STATE(969),
    [sym_preproc_warning] = STATE(969),
    [sym_preproc_define] = STATE(969),
    [sym_preproc_undef] = STATE(969),
    [aux_sym_class_declaration_repeat1] = STATE(3810),
    [aux_sym_lambda_expression_repeat1] = STATE(4192),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1639),
    [anon_sym_ref] = ACTIONS(1641),
    [anon_sym_LBRACE] = ACTIONS(2857),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1415),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1645),
    [anon_sym_TILDE] = ACTIONS(1645),
    [anon_sym_PLUS_PLUS] = ACTIONS(1645),
    [anon_sym_DASH_DASH] = ACTIONS(1645),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1643),
    [anon_sym_DASH] = ACTIONS(1643),
    [anon_sym_STAR] = ACTIONS(1425),
    [anon_sym_CARET] = ACTIONS(1645),
    [anon_sym_AMP] = ACTIONS(1645),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1647),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1649),
    [anon_sym_DOT_DOT] = ACTIONS(1651),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [970] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7132),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6001),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4364),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9470),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(970),
    [sym_preproc_endregion] = STATE(970),
    [sym_preproc_line] = STATE(970),
    [sym_preproc_pragma] = STATE(970),
    [sym_preproc_nullable] = STATE(970),
    [sym_preproc_error] = STATE(970),
    [sym_preproc_warning] = STATE(970),
    [sym_preproc_define] = STATE(970),
    [sym_preproc_undef] = STATE(970),
    [aux_sym_class_declaration_repeat1] = STATE(3870),
    [aux_sym_lambda_expression_repeat1] = STATE(4302),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1555),
    [anon_sym_ref] = ACTIONS(1557),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_readonly] = ACTIONS(2767),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(695),
    [anon_sym_TILDE] = ACTIONS(695),
    [anon_sym_PLUS_PLUS] = ACTIONS(695),
    [anon_sym_DASH_DASH] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(697),
    [anon_sym_DASH] = ACTIONS(697),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(695),
    [anon_sym_AMP] = ACTIONS(695),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1559),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1561),
    [anon_sym_DOT_DOT] = ACTIONS(1563),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [971] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6916),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7130),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4894),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3752),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7413),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9092),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(971),
    [sym_preproc_endregion] = STATE(971),
    [sym_preproc_line] = STATE(971),
    [sym_preproc_pragma] = STATE(971),
    [sym_preproc_nullable] = STATE(971),
    [sym_preproc_error] = STATE(971),
    [sym_preproc_warning] = STATE(971),
    [sym_preproc_define] = STATE(971),
    [sym_preproc_undef] = STATE(971),
    [aux_sym_class_declaration_repeat1] = STATE(3845),
    [aux_sym_lambda_expression_repeat1] = STATE(4181),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1241),
    [anon_sym_ref] = ACTIONS(1243),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_readonly] = ACTIONS(2767),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1255),
    [anon_sym_TILDE] = ACTIONS(1255),
    [anon_sym_PLUS_PLUS] = ACTIONS(1255),
    [anon_sym_DASH_DASH] = ACTIONS(1255),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1253),
    [anon_sym_DASH] = ACTIONS(1253),
    [anon_sym_STAR] = ACTIONS(1259),
    [anon_sym_CARET] = ACTIONS(1255),
    [anon_sym_AMP] = ACTIONS(1255),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1269),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1271),
    [anon_sym_DOT_DOT] = ACTIONS(1273),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [972] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4643),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6925),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2932),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7073),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4411),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3565),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7434),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9324),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(972),
    [sym_preproc_endregion] = STATE(972),
    [sym_preproc_line] = STATE(972),
    [sym_preproc_pragma] = STATE(972),
    [sym_preproc_nullable] = STATE(972),
    [sym_preproc_error] = STATE(972),
    [sym_preproc_warning] = STATE(972),
    [sym_preproc_define] = STATE(972),
    [sym_preproc_undef] = STATE(972),
    [aux_sym_class_declaration_repeat1] = STATE(3842),
    [aux_sym_lambda_expression_repeat1] = STATE(4273),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1767),
    [anon_sym_ref] = ACTIONS(1769),
    [anon_sym_LBRACE] = ACTIONS(2847),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1771),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1775),
    [anon_sym_TILDE] = ACTIONS(1775),
    [anon_sym_PLUS_PLUS] = ACTIONS(1775),
    [anon_sym_DASH_DASH] = ACTIONS(1775),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1773),
    [anon_sym_DASH] = ACTIONS(1773),
    [anon_sym_STAR] = ACTIONS(1777),
    [anon_sym_CARET] = ACTIONS(1775),
    [anon_sym_AMP] = ACTIONS(1775),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(1779),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1781),
    [anon_sym_DOT_DOT] = ACTIONS(1783),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [973] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4708),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6925),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2932),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7073),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4413),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3565),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7434),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9324),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(973),
    [sym_preproc_endregion] = STATE(973),
    [sym_preproc_line] = STATE(973),
    [sym_preproc_pragma] = STATE(973),
    [sym_preproc_nullable] = STATE(973),
    [sym_preproc_error] = STATE(973),
    [sym_preproc_warning] = STATE(973),
    [sym_preproc_define] = STATE(973),
    [sym_preproc_undef] = STATE(973),
    [aux_sym_class_declaration_repeat1] = STATE(3842),
    [aux_sym_lambda_expression_repeat1] = STATE(4273),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1767),
    [anon_sym_ref] = ACTIONS(1769),
    [anon_sym_LBRACE] = ACTIONS(2847),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1771),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1775),
    [anon_sym_TILDE] = ACTIONS(1775),
    [anon_sym_PLUS_PLUS] = ACTIONS(1775),
    [anon_sym_DASH_DASH] = ACTIONS(1775),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1773),
    [anon_sym_DASH] = ACTIONS(1773),
    [anon_sym_STAR] = ACTIONS(1777),
    [anon_sym_CARET] = ACTIONS(1775),
    [anon_sym_AMP] = ACTIONS(1775),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(1779),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1781),
    [anon_sym_DOT_DOT] = ACTIONS(1783),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [974] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4719),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6925),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2932),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7073),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4416),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3565),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7434),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9324),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(974),
    [sym_preproc_endregion] = STATE(974),
    [sym_preproc_line] = STATE(974),
    [sym_preproc_pragma] = STATE(974),
    [sym_preproc_nullable] = STATE(974),
    [sym_preproc_error] = STATE(974),
    [sym_preproc_warning] = STATE(974),
    [sym_preproc_define] = STATE(974),
    [sym_preproc_undef] = STATE(974),
    [aux_sym_class_declaration_repeat1] = STATE(3842),
    [aux_sym_lambda_expression_repeat1] = STATE(4273),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1767),
    [anon_sym_ref] = ACTIONS(1769),
    [anon_sym_LBRACE] = ACTIONS(2847),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1771),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1775),
    [anon_sym_TILDE] = ACTIONS(1775),
    [anon_sym_PLUS_PLUS] = ACTIONS(1775),
    [anon_sym_DASH_DASH] = ACTIONS(1775),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1773),
    [anon_sym_DASH] = ACTIONS(1773),
    [anon_sym_STAR] = ACTIONS(1777),
    [anon_sym_CARET] = ACTIONS(1775),
    [anon_sym_AMP] = ACTIONS(1775),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(1779),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1781),
    [anon_sym_DOT_DOT] = ACTIONS(1783),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [975] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4677),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6925),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2932),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7073),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4418),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3565),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7434),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9324),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(975),
    [sym_preproc_endregion] = STATE(975),
    [sym_preproc_line] = STATE(975),
    [sym_preproc_pragma] = STATE(975),
    [sym_preproc_nullable] = STATE(975),
    [sym_preproc_error] = STATE(975),
    [sym_preproc_warning] = STATE(975),
    [sym_preproc_define] = STATE(975),
    [sym_preproc_undef] = STATE(975),
    [aux_sym_class_declaration_repeat1] = STATE(3842),
    [aux_sym_lambda_expression_repeat1] = STATE(4273),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1767),
    [anon_sym_ref] = ACTIONS(1769),
    [anon_sym_LBRACE] = ACTIONS(2847),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1771),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1775),
    [anon_sym_TILDE] = ACTIONS(1775),
    [anon_sym_PLUS_PLUS] = ACTIONS(1775),
    [anon_sym_DASH_DASH] = ACTIONS(1775),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1773),
    [anon_sym_DASH] = ACTIONS(1773),
    [anon_sym_STAR] = ACTIONS(1777),
    [anon_sym_CARET] = ACTIONS(1775),
    [anon_sym_AMP] = ACTIONS(1775),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(1779),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1781),
    [anon_sym_DOT_DOT] = ACTIONS(1783),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [976] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4671),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6925),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2932),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7073),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4419),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3565),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7434),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9324),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(976),
    [sym_preproc_endregion] = STATE(976),
    [sym_preproc_line] = STATE(976),
    [sym_preproc_pragma] = STATE(976),
    [sym_preproc_nullable] = STATE(976),
    [sym_preproc_error] = STATE(976),
    [sym_preproc_warning] = STATE(976),
    [sym_preproc_define] = STATE(976),
    [sym_preproc_undef] = STATE(976),
    [aux_sym_class_declaration_repeat1] = STATE(3842),
    [aux_sym_lambda_expression_repeat1] = STATE(4273),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1767),
    [anon_sym_ref] = ACTIONS(1769),
    [anon_sym_LBRACE] = ACTIONS(2847),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1771),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1775),
    [anon_sym_TILDE] = ACTIONS(1775),
    [anon_sym_PLUS_PLUS] = ACTIONS(1775),
    [anon_sym_DASH_DASH] = ACTIONS(1775),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1773),
    [anon_sym_DASH] = ACTIONS(1773),
    [anon_sym_STAR] = ACTIONS(1777),
    [anon_sym_CARET] = ACTIONS(1775),
    [anon_sym_AMP] = ACTIONS(1775),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(1779),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1781),
    [anon_sym_DOT_DOT] = ACTIONS(1783),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [977] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4676),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6925),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2932),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7073),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4420),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3565),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7434),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9324),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(977),
    [sym_preproc_endregion] = STATE(977),
    [sym_preproc_line] = STATE(977),
    [sym_preproc_pragma] = STATE(977),
    [sym_preproc_nullable] = STATE(977),
    [sym_preproc_error] = STATE(977),
    [sym_preproc_warning] = STATE(977),
    [sym_preproc_define] = STATE(977),
    [sym_preproc_undef] = STATE(977),
    [aux_sym_class_declaration_repeat1] = STATE(3842),
    [aux_sym_lambda_expression_repeat1] = STATE(4273),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1767),
    [anon_sym_ref] = ACTIONS(1769),
    [anon_sym_LBRACE] = ACTIONS(2847),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1771),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1775),
    [anon_sym_TILDE] = ACTIONS(1775),
    [anon_sym_PLUS_PLUS] = ACTIONS(1775),
    [anon_sym_DASH_DASH] = ACTIONS(1775),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1773),
    [anon_sym_DASH] = ACTIONS(1773),
    [anon_sym_STAR] = ACTIONS(1777),
    [anon_sym_CARET] = ACTIONS(1775),
    [anon_sym_AMP] = ACTIONS(1775),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(1779),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1781),
    [anon_sym_DOT_DOT] = ACTIONS(1783),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [978] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6925),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2932),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7074),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4376),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3565),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7434),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9324),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(978),
    [sym_preproc_endregion] = STATE(978),
    [sym_preproc_line] = STATE(978),
    [sym_preproc_pragma] = STATE(978),
    [sym_preproc_nullable] = STATE(978),
    [sym_preproc_error] = STATE(978),
    [sym_preproc_warning] = STATE(978),
    [sym_preproc_define] = STATE(978),
    [sym_preproc_undef] = STATE(978),
    [aux_sym_class_declaration_repeat1] = STATE(3842),
    [aux_sym_lambda_expression_repeat1] = STATE(4273),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1767),
    [anon_sym_ref] = ACTIONS(1769),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1771),
    [anon_sym_readonly] = ACTIONS(2767),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1775),
    [anon_sym_TILDE] = ACTIONS(1775),
    [anon_sym_PLUS_PLUS] = ACTIONS(1775),
    [anon_sym_DASH_DASH] = ACTIONS(1775),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1773),
    [anon_sym_DASH] = ACTIONS(1773),
    [anon_sym_STAR] = ACTIONS(1777),
    [anon_sym_CARET] = ACTIONS(1775),
    [anon_sym_AMP] = ACTIONS(1775),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(1779),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1781),
    [anon_sym_DOT_DOT] = ACTIONS(1783),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [979] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4005),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6927),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2912),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7057),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5329),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3960),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7439),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9222),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(979),
    [sym_preproc_endregion] = STATE(979),
    [sym_preproc_line] = STATE(979),
    [sym_preproc_pragma] = STATE(979),
    [sym_preproc_nullable] = STATE(979),
    [sym_preproc_error] = STATE(979),
    [sym_preproc_warning] = STATE(979),
    [sym_preproc_define] = STATE(979),
    [sym_preproc_undef] = STATE(979),
    [aux_sym_class_declaration_repeat1] = STATE(3837),
    [aux_sym_lambda_expression_repeat1] = STATE(4265),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1591),
    [anon_sym_ref] = ACTIONS(1593),
    [anon_sym_LBRACE] = ACTIONS(2835),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1595),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1599),
    [anon_sym_TILDE] = ACTIONS(1599),
    [anon_sym_PLUS_PLUS] = ACTIONS(1599),
    [anon_sym_DASH_DASH] = ACTIONS(1599),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1597),
    [anon_sym_DASH] = ACTIONS(1597),
    [anon_sym_STAR] = ACTIONS(1601),
    [anon_sym_CARET] = ACTIONS(1599),
    [anon_sym_AMP] = ACTIONS(1599),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1603),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1605),
    [anon_sym_DOT_DOT] = ACTIONS(1607),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [980] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(5561),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6937),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2861),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7081),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5217),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(3898),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7429),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9350),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(980),
    [sym_preproc_endregion] = STATE(980),
    [sym_preproc_line] = STATE(980),
    [sym_preproc_pragma] = STATE(980),
    [sym_preproc_nullable] = STATE(980),
    [sym_preproc_error] = STATE(980),
    [sym_preproc_warning] = STATE(980),
    [sym_preproc_define] = STATE(980),
    [sym_preproc_undef] = STATE(980),
    [aux_sym_class_declaration_repeat1] = STATE(3879),
    [aux_sym_lambda_expression_repeat1] = STATE(4092),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1477),
    [anon_sym_ref] = ACTIONS(1479),
    [anon_sym_LBRACE] = ACTIONS(2857),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1481),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1485),
    [anon_sym_TILDE] = ACTIONS(1485),
    [anon_sym_PLUS_PLUS] = ACTIONS(1485),
    [anon_sym_DASH_DASH] = ACTIONS(1485),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1483),
    [anon_sym_DASH] = ACTIONS(1483),
    [anon_sym_STAR] = ACTIONS(1487),
    [anon_sym_CARET] = ACTIONS(1485),
    [anon_sym_AMP] = ACTIONS(1485),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1489),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1491),
    [anon_sym_DOT_DOT] = ACTIONS(1493),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [981] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(5577),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6937),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2861),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7081),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5222),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(3898),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7429),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9350),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(981),
    [sym_preproc_endregion] = STATE(981),
    [sym_preproc_line] = STATE(981),
    [sym_preproc_pragma] = STATE(981),
    [sym_preproc_nullable] = STATE(981),
    [sym_preproc_error] = STATE(981),
    [sym_preproc_warning] = STATE(981),
    [sym_preproc_define] = STATE(981),
    [sym_preproc_undef] = STATE(981),
    [aux_sym_class_declaration_repeat1] = STATE(3879),
    [aux_sym_lambda_expression_repeat1] = STATE(4092),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1477),
    [anon_sym_ref] = ACTIONS(1479),
    [anon_sym_LBRACE] = ACTIONS(2857),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1481),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1485),
    [anon_sym_TILDE] = ACTIONS(1485),
    [anon_sym_PLUS_PLUS] = ACTIONS(1485),
    [anon_sym_DASH_DASH] = ACTIONS(1485),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1483),
    [anon_sym_DASH] = ACTIONS(1483),
    [anon_sym_STAR] = ACTIONS(1487),
    [anon_sym_CARET] = ACTIONS(1485),
    [anon_sym_AMP] = ACTIONS(1485),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1489),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1491),
    [anon_sym_DOT_DOT] = ACTIONS(1493),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [982] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(5582),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6937),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2861),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7081),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5224),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(3898),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7429),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9350),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(982),
    [sym_preproc_endregion] = STATE(982),
    [sym_preproc_line] = STATE(982),
    [sym_preproc_pragma] = STATE(982),
    [sym_preproc_nullable] = STATE(982),
    [sym_preproc_error] = STATE(982),
    [sym_preproc_warning] = STATE(982),
    [sym_preproc_define] = STATE(982),
    [sym_preproc_undef] = STATE(982),
    [aux_sym_class_declaration_repeat1] = STATE(3879),
    [aux_sym_lambda_expression_repeat1] = STATE(4092),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1477),
    [anon_sym_ref] = ACTIONS(1479),
    [anon_sym_LBRACE] = ACTIONS(2857),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1481),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1485),
    [anon_sym_TILDE] = ACTIONS(1485),
    [anon_sym_PLUS_PLUS] = ACTIONS(1485),
    [anon_sym_DASH_DASH] = ACTIONS(1485),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1483),
    [anon_sym_DASH] = ACTIONS(1483),
    [anon_sym_STAR] = ACTIONS(1487),
    [anon_sym_CARET] = ACTIONS(1485),
    [anon_sym_AMP] = ACTIONS(1485),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1489),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1491),
    [anon_sym_DOT_DOT] = ACTIONS(1493),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [983] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(5615),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6937),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2861),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7081),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5230),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(3898),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7429),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9350),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(983),
    [sym_preproc_endregion] = STATE(983),
    [sym_preproc_line] = STATE(983),
    [sym_preproc_pragma] = STATE(983),
    [sym_preproc_nullable] = STATE(983),
    [sym_preproc_error] = STATE(983),
    [sym_preproc_warning] = STATE(983),
    [sym_preproc_define] = STATE(983),
    [sym_preproc_undef] = STATE(983),
    [aux_sym_class_declaration_repeat1] = STATE(3879),
    [aux_sym_lambda_expression_repeat1] = STATE(4092),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1477),
    [anon_sym_ref] = ACTIONS(1479),
    [anon_sym_LBRACE] = ACTIONS(2857),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1481),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1485),
    [anon_sym_TILDE] = ACTIONS(1485),
    [anon_sym_PLUS_PLUS] = ACTIONS(1485),
    [anon_sym_DASH_DASH] = ACTIONS(1485),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1483),
    [anon_sym_DASH] = ACTIONS(1483),
    [anon_sym_STAR] = ACTIONS(1487),
    [anon_sym_CARET] = ACTIONS(1485),
    [anon_sym_AMP] = ACTIONS(1485),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1489),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1491),
    [anon_sym_DOT_DOT] = ACTIONS(1493),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [984] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(5618),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6937),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2861),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7081),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5233),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(3898),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7429),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9350),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(984),
    [sym_preproc_endregion] = STATE(984),
    [sym_preproc_line] = STATE(984),
    [sym_preproc_pragma] = STATE(984),
    [sym_preproc_nullable] = STATE(984),
    [sym_preproc_error] = STATE(984),
    [sym_preproc_warning] = STATE(984),
    [sym_preproc_define] = STATE(984),
    [sym_preproc_undef] = STATE(984),
    [aux_sym_class_declaration_repeat1] = STATE(3879),
    [aux_sym_lambda_expression_repeat1] = STATE(4092),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1477),
    [anon_sym_ref] = ACTIONS(1479),
    [anon_sym_LBRACE] = ACTIONS(2857),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1481),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1485),
    [anon_sym_TILDE] = ACTIONS(1485),
    [anon_sym_PLUS_PLUS] = ACTIONS(1485),
    [anon_sym_DASH_DASH] = ACTIONS(1485),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1483),
    [anon_sym_DASH] = ACTIONS(1483),
    [anon_sym_STAR] = ACTIONS(1487),
    [anon_sym_CARET] = ACTIONS(1485),
    [anon_sym_AMP] = ACTIONS(1485),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1489),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1491),
    [anon_sym_DOT_DOT] = ACTIONS(1493),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [985] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(5639),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6937),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2861),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7081),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5235),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(3898),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7429),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9350),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(985),
    [sym_preproc_endregion] = STATE(985),
    [sym_preproc_line] = STATE(985),
    [sym_preproc_pragma] = STATE(985),
    [sym_preproc_nullable] = STATE(985),
    [sym_preproc_error] = STATE(985),
    [sym_preproc_warning] = STATE(985),
    [sym_preproc_define] = STATE(985),
    [sym_preproc_undef] = STATE(985),
    [aux_sym_class_declaration_repeat1] = STATE(3879),
    [aux_sym_lambda_expression_repeat1] = STATE(4092),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1477),
    [anon_sym_ref] = ACTIONS(1479),
    [anon_sym_LBRACE] = ACTIONS(2857),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1481),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1485),
    [anon_sym_TILDE] = ACTIONS(1485),
    [anon_sym_PLUS_PLUS] = ACTIONS(1485),
    [anon_sym_DASH_DASH] = ACTIONS(1485),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1483),
    [anon_sym_DASH] = ACTIONS(1483),
    [anon_sym_STAR] = ACTIONS(1487),
    [anon_sym_CARET] = ACTIONS(1485),
    [anon_sym_AMP] = ACTIONS(1485),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1489),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1491),
    [anon_sym_DOT_DOT] = ACTIONS(1493),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [986] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6937),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2861),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7082),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5162),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(3898),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7429),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9350),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(986),
    [sym_preproc_endregion] = STATE(986),
    [sym_preproc_line] = STATE(986),
    [sym_preproc_pragma] = STATE(986),
    [sym_preproc_nullable] = STATE(986),
    [sym_preproc_error] = STATE(986),
    [sym_preproc_warning] = STATE(986),
    [sym_preproc_define] = STATE(986),
    [sym_preproc_undef] = STATE(986),
    [aux_sym_class_declaration_repeat1] = STATE(3879),
    [aux_sym_lambda_expression_repeat1] = STATE(4092),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1477),
    [anon_sym_ref] = ACTIONS(1479),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1481),
    [anon_sym_readonly] = ACTIONS(2767),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1485),
    [anon_sym_TILDE] = ACTIONS(1485),
    [anon_sym_PLUS_PLUS] = ACTIONS(1485),
    [anon_sym_DASH_DASH] = ACTIONS(1485),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1483),
    [anon_sym_DASH] = ACTIONS(1483),
    [anon_sym_STAR] = ACTIONS(1487),
    [anon_sym_CARET] = ACTIONS(1485),
    [anon_sym_AMP] = ACTIONS(1485),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1489),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1491),
    [anon_sym_DOT_DOT] = ACTIONS(1493),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [987] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4021),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6927),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2912),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7057),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5370),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3960),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7439),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9222),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(987),
    [sym_preproc_endregion] = STATE(987),
    [sym_preproc_line] = STATE(987),
    [sym_preproc_pragma] = STATE(987),
    [sym_preproc_nullable] = STATE(987),
    [sym_preproc_error] = STATE(987),
    [sym_preproc_warning] = STATE(987),
    [sym_preproc_define] = STATE(987),
    [sym_preproc_undef] = STATE(987),
    [aux_sym_class_declaration_repeat1] = STATE(3837),
    [aux_sym_lambda_expression_repeat1] = STATE(4265),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1591),
    [anon_sym_ref] = ACTIONS(1593),
    [anon_sym_LBRACE] = ACTIONS(2835),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1595),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1599),
    [anon_sym_TILDE] = ACTIONS(1599),
    [anon_sym_PLUS_PLUS] = ACTIONS(1599),
    [anon_sym_DASH_DASH] = ACTIONS(1599),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1597),
    [anon_sym_DASH] = ACTIONS(1597),
    [anon_sym_STAR] = ACTIONS(1601),
    [anon_sym_CARET] = ACTIONS(1599),
    [anon_sym_AMP] = ACTIONS(1599),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1603),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1605),
    [anon_sym_DOT_DOT] = ACTIONS(1607),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [988] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4060),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6927),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2912),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7057),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5372),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3960),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7439),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9222),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(988),
    [sym_preproc_endregion] = STATE(988),
    [sym_preproc_line] = STATE(988),
    [sym_preproc_pragma] = STATE(988),
    [sym_preproc_nullable] = STATE(988),
    [sym_preproc_error] = STATE(988),
    [sym_preproc_warning] = STATE(988),
    [sym_preproc_define] = STATE(988),
    [sym_preproc_undef] = STATE(988),
    [aux_sym_class_declaration_repeat1] = STATE(3837),
    [aux_sym_lambda_expression_repeat1] = STATE(4265),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1591),
    [anon_sym_ref] = ACTIONS(1593),
    [anon_sym_LBRACE] = ACTIONS(2835),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1595),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1599),
    [anon_sym_TILDE] = ACTIONS(1599),
    [anon_sym_PLUS_PLUS] = ACTIONS(1599),
    [anon_sym_DASH_DASH] = ACTIONS(1599),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1597),
    [anon_sym_DASH] = ACTIONS(1597),
    [anon_sym_STAR] = ACTIONS(1601),
    [anon_sym_CARET] = ACTIONS(1599),
    [anon_sym_AMP] = ACTIONS(1599),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1603),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1605),
    [anon_sym_DOT_DOT] = ACTIONS(1607),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [989] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3780),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6956),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5786),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9482),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(989),
    [sym_preproc_endregion] = STATE(989),
    [sym_preproc_line] = STATE(989),
    [sym_preproc_pragma] = STATE(989),
    [sym_preproc_nullable] = STATE(989),
    [sym_preproc_error] = STATE(989),
    [sym_preproc_warning] = STATE(989),
    [sym_preproc_define] = STATE(989),
    [sym_preproc_undef] = STATE(989),
    [aux_sym_class_declaration_repeat1] = STATE(3853),
    [aux_sym_lambda_expression_repeat1] = STATE(4299),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1497),
    [anon_sym_ref] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1505),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1507),
    [anon_sym_DOT_DOT] = ACTIONS(1509),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [990] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6985),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5190),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3903),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7428),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9348),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(990),
    [sym_preproc_endregion] = STATE(990),
    [sym_preproc_line] = STATE(990),
    [sym_preproc_pragma] = STATE(990),
    [sym_preproc_nullable] = STATE(990),
    [sym_preproc_error] = STATE(990),
    [sym_preproc_warning] = STATE(990),
    [sym_preproc_define] = STATE(990),
    [sym_preproc_undef] = STATE(990),
    [aux_sym_class_declaration_repeat1] = STATE(3817),
    [aux_sym_lambda_expression_repeat1] = STATE(4227),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1389),
    [anon_sym_ref] = ACTIONS(1391),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_readonly] = ACTIONS(2767),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1117),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(1393),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_AMP] = ACTIONS(1117),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1395),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1397),
    [anon_sym_DOT_DOT] = ACTIONS(1399),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [991] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6927),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2912),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7058),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5293),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3960),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7439),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9222),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(991),
    [sym_preproc_endregion] = STATE(991),
    [sym_preproc_line] = STATE(991),
    [sym_preproc_pragma] = STATE(991),
    [sym_preproc_nullable] = STATE(991),
    [sym_preproc_error] = STATE(991),
    [sym_preproc_warning] = STATE(991),
    [sym_preproc_define] = STATE(991),
    [sym_preproc_undef] = STATE(991),
    [aux_sym_class_declaration_repeat1] = STATE(3837),
    [aux_sym_lambda_expression_repeat1] = STATE(4265),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1591),
    [anon_sym_ref] = ACTIONS(1593),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1595),
    [anon_sym_readonly] = ACTIONS(2767),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1599),
    [anon_sym_TILDE] = ACTIONS(1599),
    [anon_sym_PLUS_PLUS] = ACTIONS(1599),
    [anon_sym_DASH_DASH] = ACTIONS(1599),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1597),
    [anon_sym_DASH] = ACTIONS(1597),
    [anon_sym_STAR] = ACTIONS(1601),
    [anon_sym_CARET] = ACTIONS(1599),
    [anon_sym_AMP] = ACTIONS(1599),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1603),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1605),
    [anon_sym_DOT_DOT] = ACTIONS(1607),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [992] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3741),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7105),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6026),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(992),
    [sym_preproc_endregion] = STATE(992),
    [sym_preproc_line] = STATE(992),
    [sym_preproc_pragma] = STATE(992),
    [sym_preproc_nullable] = STATE(992),
    [sym_preproc_error] = STATE(992),
    [sym_preproc_warning] = STATE(992),
    [sym_preproc_define] = STATE(992),
    [sym_preproc_undef] = STATE(992),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [993] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6956),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5466),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9482),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(993),
    [sym_preproc_endregion] = STATE(993),
    [sym_preproc_line] = STATE(993),
    [sym_preproc_pragma] = STATE(993),
    [sym_preproc_nullable] = STATE(993),
    [sym_preproc_error] = STATE(993),
    [sym_preproc_warning] = STATE(993),
    [sym_preproc_define] = STATE(993),
    [sym_preproc_undef] = STATE(993),
    [aux_sym_class_declaration_repeat1] = STATE(3853),
    [aux_sym_lambda_expression_repeat1] = STATE(4299),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(2891),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1497),
    [anon_sym_ref] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1505),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1507),
    [anon_sym_DOT_DOT] = ACTIONS(1509),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [994] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4102),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6913),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2905),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6979),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5456),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4178),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7433),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9183),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(994),
    [sym_preproc_endregion] = STATE(994),
    [sym_preproc_line] = STATE(994),
    [sym_preproc_pragma] = STATE(994),
    [sym_preproc_nullable] = STATE(994),
    [sym_preproc_error] = STATE(994),
    [sym_preproc_warning] = STATE(994),
    [sym_preproc_define] = STATE(994),
    [sym_preproc_undef] = STATE(994),
    [aux_sym_class_declaration_repeat1] = STATE(3816),
    [aux_sym_lambda_expression_repeat1] = STATE(4225),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1573),
    [anon_sym_ref] = ACTIONS(1575),
    [anon_sym_LBRACE] = ACTIONS(2831),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1577),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1581),
    [anon_sym_TILDE] = ACTIONS(1581),
    [anon_sym_PLUS_PLUS] = ACTIONS(1581),
    [anon_sym_DASH_DASH] = ACTIONS(1581),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1579),
    [anon_sym_DASH] = ACTIONS(1579),
    [anon_sym_STAR] = ACTIONS(1583),
    [anon_sym_CARET] = ACTIONS(1581),
    [anon_sym_AMP] = ACTIONS(1581),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1585),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1587),
    [anon_sym_DOT_DOT] = ACTIONS(1589),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [995] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4111),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6913),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2905),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6979),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5457),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4178),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7433),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9183),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(995),
    [sym_preproc_endregion] = STATE(995),
    [sym_preproc_line] = STATE(995),
    [sym_preproc_pragma] = STATE(995),
    [sym_preproc_nullable] = STATE(995),
    [sym_preproc_error] = STATE(995),
    [sym_preproc_warning] = STATE(995),
    [sym_preproc_define] = STATE(995),
    [sym_preproc_undef] = STATE(995),
    [aux_sym_class_declaration_repeat1] = STATE(3816),
    [aux_sym_lambda_expression_repeat1] = STATE(4225),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1573),
    [anon_sym_ref] = ACTIONS(1575),
    [anon_sym_LBRACE] = ACTIONS(2831),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1577),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1581),
    [anon_sym_TILDE] = ACTIONS(1581),
    [anon_sym_PLUS_PLUS] = ACTIONS(1581),
    [anon_sym_DASH_DASH] = ACTIONS(1581),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1579),
    [anon_sym_DASH] = ACTIONS(1579),
    [anon_sym_STAR] = ACTIONS(1583),
    [anon_sym_CARET] = ACTIONS(1581),
    [anon_sym_AMP] = ACTIONS(1581),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1585),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1587),
    [anon_sym_DOT_DOT] = ACTIONS(1589),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [996] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6956),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6621),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9482),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(996),
    [sym_preproc_endregion] = STATE(996),
    [sym_preproc_line] = STATE(996),
    [sym_preproc_pragma] = STATE(996),
    [sym_preproc_nullable] = STATE(996),
    [sym_preproc_error] = STATE(996),
    [sym_preproc_warning] = STATE(996),
    [sym_preproc_define] = STATE(996),
    [sym_preproc_undef] = STATE(996),
    [aux_sym_class_declaration_repeat1] = STATE(3853),
    [aux_sym_lambda_expression_repeat1] = STATE(4299),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(2025),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1497),
    [anon_sym_ref] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1505),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1507),
    [anon_sym_DOT_DOT] = ACTIONS(1509),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [997] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6662),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6519),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(997),
    [sym_preproc_endregion] = STATE(997),
    [sym_preproc_line] = STATE(997),
    [sym_preproc_pragma] = STATE(997),
    [sym_preproc_nullable] = STATE(997),
    [sym_preproc_error] = STATE(997),
    [sym_preproc_warning] = STATE(997),
    [sym_preproc_define] = STATE(997),
    [sym_preproc_undef] = STATE(997),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2011),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_readonly] = ACTIONS(2767),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [998] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5791),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(998),
    [sym_preproc_endregion] = STATE(998),
    [sym_preproc_line] = STATE(998),
    [sym_preproc_pragma] = STATE(998),
    [sym_preproc_nullable] = STATE(998),
    [sym_preproc_error] = STATE(998),
    [sym_preproc_warning] = STATE(998),
    [sym_preproc_define] = STATE(998),
    [sym_preproc_undef] = STATE(998),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_RBRACE] = ACTIONS(2893),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [999] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3483),
    [sym_alias_qualified_name] = STATE(3486),
    [sym__simple_name] = STATE(2832),
    [sym_qualified_name] = STATE(3486),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(3096),
    [sym_implicit_type] = STATE(3330),
    [sym_array_type] = STATE(3488),
    [sym__array_base_type] = STATE(8756),
    [sym_nullable_type] = STATE(3489),
    [sym_pointer_type] = STATE(3489),
    [sym__pointer_base_type] = STATE(9221),
    [sym_function_pointer_type] = STATE(3489),
    [sym_ref_type] = STATE(3330),
    [sym_scoped_type] = STATE(3330),
    [sym_tuple_type] = STATE(3490),
    [sym_expression] = STATE(6045),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2792),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(999),
    [sym_preproc_endregion] = STATE(999),
    [sym_preproc_line] = STATE(999),
    [sym_preproc_pragma] = STATE(999),
    [sym_preproc_nullable] = STATE(999),
    [sym_preproc_error] = STATE(999),
    [sym_preproc_warning] = STATE(999),
    [sym_preproc_define] = STATE(999),
    [sym_preproc_undef] = STATE(999),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2895),
    [anon_sym_ref] = ACTIONS(2357),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(2361),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(2897),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2367),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2899),
    [sym_predefined_type] = ACTIONS(2901),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1000] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4676),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6911),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2930),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7031),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4867),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3742),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7420),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9374),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(1000),
    [sym_preproc_endregion] = STATE(1000),
    [sym_preproc_line] = STATE(1000),
    [sym_preproc_pragma] = STATE(1000),
    [sym_preproc_nullable] = STATE(1000),
    [sym_preproc_error] = STATE(1000),
    [sym_preproc_warning] = STATE(1000),
    [sym_preproc_define] = STATE(1000),
    [sym_preproc_undef] = STATE(1000),
    [aux_sym_class_declaration_repeat1] = STATE(3861),
    [aux_sym_lambda_expression_repeat1] = STATE(4169),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(2089),
    [anon_sym_ref] = ACTIONS(2091),
    [anon_sym_LBRACE] = ACTIONS(2847),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1695),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(2095),
    [anon_sym_TILDE] = ACTIONS(2095),
    [anon_sym_PLUS_PLUS] = ACTIONS(2095),
    [anon_sym_DASH_DASH] = ACTIONS(2095),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(2093),
    [anon_sym_DASH] = ACTIONS(2093),
    [anon_sym_STAR] = ACTIONS(1705),
    [anon_sym_CARET] = ACTIONS(2095),
    [anon_sym_AMP] = ACTIONS(2095),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(2097),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2099),
    [anon_sym_DOT_DOT] = ACTIONS(2101),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [1001] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6123),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1001),
    [sym_preproc_endregion] = STATE(1001),
    [sym_preproc_line] = STATE(1001),
    [sym_preproc_pragma] = STATE(1001),
    [sym_preproc_nullable] = STATE(1001),
    [sym_preproc_error] = STATE(1001),
    [sym_preproc_warning] = STATE(1001),
    [sym_preproc_define] = STATE(1001),
    [sym_preproc_undef] = STATE(1001),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2903),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1002] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6911),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2930),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7031),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4889),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3742),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7420),
    [sym__ordering] = STATE(7601),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9374),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(1002),
    [sym_preproc_endregion] = STATE(1002),
    [sym_preproc_line] = STATE(1002),
    [sym_preproc_pragma] = STATE(1002),
    [sym_preproc_nullable] = STATE(1002),
    [sym_preproc_error] = STATE(1002),
    [sym_preproc_warning] = STATE(1002),
    [sym_preproc_define] = STATE(1002),
    [sym_preproc_undef] = STATE(1002),
    [aux_sym_class_declaration_repeat1] = STATE(3861),
    [aux_sym_lambda_expression_repeat1] = STATE(4169),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(2089),
    [anon_sym_ref] = ACTIONS(2091),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1695),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(2095),
    [anon_sym_TILDE] = ACTIONS(2095),
    [anon_sym_PLUS_PLUS] = ACTIONS(2095),
    [anon_sym_DASH_DASH] = ACTIONS(2095),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(2093),
    [anon_sym_DASH] = ACTIONS(2093),
    [anon_sym_STAR] = ACTIONS(1705),
    [anon_sym_CARET] = ACTIONS(2095),
    [anon_sym_AMP] = ACTIONS(2095),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(2097),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2099),
    [anon_sym_DOT_DOT] = ACTIONS(2101),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [1003] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4152),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6962),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5188),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3931),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9818),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1003),
    [sym_preproc_endregion] = STATE(1003),
    [sym_preproc_line] = STATE(1003),
    [sym_preproc_pragma] = STATE(1003),
    [sym_preproc_nullable] = STATE(1003),
    [sym_preproc_error] = STATE(1003),
    [sym_preproc_warning] = STATE(1003),
    [sym_preproc_define] = STATE(1003),
    [sym_preproc_undef] = STATE(1003),
    [aux_sym_class_declaration_repeat1] = STATE(3811),
    [aux_sym_lambda_expression_repeat1] = STATE(4201),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1373),
    [anon_sym_ref] = ACTIONS(1375),
    [anon_sym_LBRACE] = ACTIONS(2831),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1379),
    [anon_sym_TILDE] = ACTIONS(1379),
    [anon_sym_PLUS_PLUS] = ACTIONS(1379),
    [anon_sym_DASH_DASH] = ACTIONS(1379),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1377),
    [anon_sym_DASH] = ACTIONS(1377),
    [anon_sym_STAR] = ACTIONS(1381),
    [anon_sym_CARET] = ACTIONS(1379),
    [anon_sym_AMP] = ACTIONS(1379),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1383),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1385),
    [anon_sym_DOT_DOT] = ACTIONS(1387),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1004] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6956),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6472),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9482),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1004),
    [sym_preproc_endregion] = STATE(1004),
    [sym_preproc_line] = STATE(1004),
    [sym_preproc_pragma] = STATE(1004),
    [sym_preproc_nullable] = STATE(1004),
    [sym_preproc_error] = STATE(1004),
    [sym_preproc_warning] = STATE(1004),
    [sym_preproc_define] = STATE(1004),
    [sym_preproc_undef] = STATE(1004),
    [aux_sym_class_declaration_repeat1] = STATE(3853),
    [aux_sym_lambda_expression_repeat1] = STATE(4299),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(2905),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1497),
    [anon_sym_ref] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1505),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1507),
    [anon_sym_DOT_DOT] = ACTIONS(1509),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1005] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3991),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6950),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7044),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5124),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3868),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7432),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9127),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1005),
    [sym_preproc_endregion] = STATE(1005),
    [sym_preproc_line] = STATE(1005),
    [sym_preproc_pragma] = STATE(1005),
    [sym_preproc_nullable] = STATE(1005),
    [sym_preproc_error] = STATE(1005),
    [sym_preproc_warning] = STATE(1005),
    [sym_preproc_define] = STATE(1005),
    [sym_preproc_undef] = STATE(1005),
    [aux_sym_class_declaration_repeat1] = STATE(3832),
    [aux_sym_lambda_expression_repeat1] = STATE(4259),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1357),
    [anon_sym_ref] = ACTIONS(1359),
    [anon_sym_LBRACE] = ACTIONS(2835),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1363),
    [anon_sym_TILDE] = ACTIONS(1363),
    [anon_sym_PLUS_PLUS] = ACTIONS(1363),
    [anon_sym_DASH_DASH] = ACTIONS(1363),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1361),
    [anon_sym_DASH] = ACTIONS(1361),
    [anon_sym_STAR] = ACTIONS(1365),
    [anon_sym_CARET] = ACTIONS(1363),
    [anon_sym_AMP] = ACTIONS(1363),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1367),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1369),
    [anon_sym_DOT_DOT] = ACTIONS(1371),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1006] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6956),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6476),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9482),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1006),
    [sym_preproc_endregion] = STATE(1006),
    [sym_preproc_line] = STATE(1006),
    [sym_preproc_pragma] = STATE(1006),
    [sym_preproc_nullable] = STATE(1006),
    [sym_preproc_error] = STATE(1006),
    [sym_preproc_warning] = STATE(1006),
    [sym_preproc_define] = STATE(1006),
    [sym_preproc_undef] = STATE(1006),
    [aux_sym_class_declaration_repeat1] = STATE(3853),
    [aux_sym_lambda_expression_repeat1] = STATE(4299),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(2907),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1497),
    [anon_sym_ref] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1505),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1507),
    [anon_sym_DOT_DOT] = ACTIONS(1509),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1007] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4119),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6962),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5198),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3931),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9818),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1007),
    [sym_preproc_endregion] = STATE(1007),
    [sym_preproc_line] = STATE(1007),
    [sym_preproc_pragma] = STATE(1007),
    [sym_preproc_nullable] = STATE(1007),
    [sym_preproc_error] = STATE(1007),
    [sym_preproc_warning] = STATE(1007),
    [sym_preproc_define] = STATE(1007),
    [sym_preproc_undef] = STATE(1007),
    [aux_sym_class_declaration_repeat1] = STATE(3811),
    [aux_sym_lambda_expression_repeat1] = STATE(4201),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1373),
    [anon_sym_ref] = ACTIONS(1375),
    [anon_sym_LBRACE] = ACTIONS(2831),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1379),
    [anon_sym_TILDE] = ACTIONS(1379),
    [anon_sym_PLUS_PLUS] = ACTIONS(1379),
    [anon_sym_DASH_DASH] = ACTIONS(1379),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1377),
    [anon_sym_DASH] = ACTIONS(1377),
    [anon_sym_STAR] = ACTIONS(1381),
    [anon_sym_CARET] = ACTIONS(1379),
    [anon_sym_AMP] = ACTIONS(1379),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1383),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1385),
    [anon_sym_DOT_DOT] = ACTIONS(1387),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1008] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6956),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6477),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9482),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1008),
    [sym_preproc_endregion] = STATE(1008),
    [sym_preproc_line] = STATE(1008),
    [sym_preproc_pragma] = STATE(1008),
    [sym_preproc_nullable] = STATE(1008),
    [sym_preproc_error] = STATE(1008),
    [sym_preproc_warning] = STATE(1008),
    [sym_preproc_define] = STATE(1008),
    [sym_preproc_undef] = STATE(1008),
    [aux_sym_class_declaration_repeat1] = STATE(3853),
    [aux_sym_lambda_expression_repeat1] = STATE(4299),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(2909),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1497),
    [anon_sym_ref] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1505),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1507),
    [anon_sym_DOT_DOT] = ACTIONS(1509),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1009] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4028),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6950),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7044),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5126),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3868),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7432),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9127),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1009),
    [sym_preproc_endregion] = STATE(1009),
    [sym_preproc_line] = STATE(1009),
    [sym_preproc_pragma] = STATE(1009),
    [sym_preproc_nullable] = STATE(1009),
    [sym_preproc_error] = STATE(1009),
    [sym_preproc_warning] = STATE(1009),
    [sym_preproc_define] = STATE(1009),
    [sym_preproc_undef] = STATE(1009),
    [aux_sym_class_declaration_repeat1] = STATE(3832),
    [aux_sym_lambda_expression_repeat1] = STATE(4259),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1357),
    [anon_sym_ref] = ACTIONS(1359),
    [anon_sym_LBRACE] = ACTIONS(2835),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1363),
    [anon_sym_TILDE] = ACTIONS(1363),
    [anon_sym_PLUS_PLUS] = ACTIONS(1363),
    [anon_sym_DASH_DASH] = ACTIONS(1363),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1361),
    [anon_sym_DASH] = ACTIONS(1361),
    [anon_sym_STAR] = ACTIONS(1365),
    [anon_sym_CARET] = ACTIONS(1363),
    [anon_sym_AMP] = ACTIONS(1363),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1367),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1369),
    [anon_sym_DOT_DOT] = ACTIONS(1371),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1010] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7105),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6640),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1010),
    [sym_preproc_endregion] = STATE(1010),
    [sym_preproc_line] = STATE(1010),
    [sym_preproc_pragma] = STATE(1010),
    [sym_preproc_nullable] = STATE(1010),
    [sym_preproc_error] = STATE(1010),
    [sym_preproc_warning] = STATE(1010),
    [sym_preproc_define] = STATE(1010),
    [sym_preproc_undef] = STATE(1010),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_if_token3] = ACTIONS(2911),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1011] = {
    [sym_attribute_argument] = STATE(8985),
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6165),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2843),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1011),
    [sym_preproc_endregion] = STATE(1011),
    [sym_preproc_line] = STATE(1011),
    [sym_preproc_pragma] = STATE(1011),
    [sym_preproc_nullable] = STATE(1011),
    [sym_preproc_error] = STATE(1011),
    [sym_preproc_warning] = STATE(1011),
    [sym_preproc_define] = STATE(1011),
    [sym_preproc_undef] = STATE(1011),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1012] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3763),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7131),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5954),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4364),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9470),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1012),
    [sym_preproc_endregion] = STATE(1012),
    [sym_preproc_line] = STATE(1012),
    [sym_preproc_pragma] = STATE(1012),
    [sym_preproc_nullable] = STATE(1012),
    [sym_preproc_error] = STATE(1012),
    [sym_preproc_warning] = STATE(1012),
    [sym_preproc_define] = STATE(1012),
    [sym_preproc_undef] = STATE(1012),
    [aux_sym_class_declaration_repeat1] = STATE(3870),
    [aux_sym_lambda_expression_repeat1] = STATE(4302),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1555),
    [anon_sym_ref] = ACTIONS(1557),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(695),
    [anon_sym_TILDE] = ACTIONS(695),
    [anon_sym_PLUS_PLUS] = ACTIONS(695),
    [anon_sym_DASH_DASH] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(697),
    [anon_sym_DASH] = ACTIONS(697),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(695),
    [anon_sym_AMP] = ACTIONS(695),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1559),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1561),
    [anon_sym_DOT_DOT] = ACTIONS(1563),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1013] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3763),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5610),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1013),
    [sym_preproc_endregion] = STATE(1013),
    [sym_preproc_line] = STATE(1013),
    [sym_preproc_pragma] = STATE(1013),
    [sym_preproc_nullable] = STATE(1013),
    [sym_preproc_error] = STATE(1013),
    [sym_preproc_warning] = STATE(1013),
    [sym_preproc_define] = STATE(1013),
    [sym_preproc_undef] = STATE(1013),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1014] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3763),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7139),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6448),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1014),
    [sym_preproc_endregion] = STATE(1014),
    [sym_preproc_line] = STATE(1014),
    [sym_preproc_pragma] = STATE(1014),
    [sym_preproc_nullable] = STATE(1014),
    [sym_preproc_error] = STATE(1014),
    [sym_preproc_warning] = STATE(1014),
    [sym_preproc_define] = STATE(1014),
    [sym_preproc_undef] = STATE(1014),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2011),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1015] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4005),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6915),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7018),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4461),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3585),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7418),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9926),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1015),
    [sym_preproc_endregion] = STATE(1015),
    [sym_preproc_line] = STATE(1015),
    [sym_preproc_pragma] = STATE(1015),
    [sym_preproc_nullable] = STATE(1015),
    [sym_preproc_error] = STATE(1015),
    [sym_preproc_warning] = STATE(1015),
    [sym_preproc_define] = STATE(1015),
    [sym_preproc_undef] = STATE(1015),
    [aux_sym_class_declaration_repeat1] = STATE(3825),
    [aux_sym_lambda_expression_repeat1] = STATE(4244),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1161),
    [anon_sym_ref] = ACTIONS(1163),
    [anon_sym_LBRACE] = ACTIONS(2835),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1177),
    [anon_sym_TILDE] = ACTIONS(1177),
    [anon_sym_PLUS_PLUS] = ACTIONS(1177),
    [anon_sym_DASH_DASH] = ACTIONS(1177),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1175),
    [anon_sym_DASH] = ACTIONS(1175),
    [anon_sym_STAR] = ACTIONS(1181),
    [anon_sym_CARET] = ACTIONS(1177),
    [anon_sym_AMP] = ACTIONS(1177),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1191),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1193),
    [anon_sym_DOT_DOT] = ACTIONS(1195),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1016] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5791),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1016),
    [sym_preproc_endregion] = STATE(1016),
    [sym_preproc_line] = STATE(1016),
    [sym_preproc_pragma] = STATE(1016),
    [sym_preproc_nullable] = STATE(1016),
    [sym_preproc_error] = STATE(1016),
    [sym_preproc_warning] = STATE(1016),
    [sym_preproc_define] = STATE(1016),
    [sym_preproc_undef] = STATE(1016),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_RBRACE] = ACTIONS(2913),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1017] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3735),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6956),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5788),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9482),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1017),
    [sym_preproc_endregion] = STATE(1017),
    [sym_preproc_line] = STATE(1017),
    [sym_preproc_pragma] = STATE(1017),
    [sym_preproc_nullable] = STATE(1017),
    [sym_preproc_error] = STATE(1017),
    [sym_preproc_warning] = STATE(1017),
    [sym_preproc_define] = STATE(1017),
    [sym_preproc_undef] = STATE(1017),
    [aux_sym_class_declaration_repeat1] = STATE(3853),
    [aux_sym_lambda_expression_repeat1] = STATE(4299),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1497),
    [anon_sym_ref] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1505),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1507),
    [anon_sym_DOT_DOT] = ACTIONS(1509),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1018] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3764),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7139),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6451),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1018),
    [sym_preproc_endregion] = STATE(1018),
    [sym_preproc_line] = STATE(1018),
    [sym_preproc_pragma] = STATE(1018),
    [sym_preproc_nullable] = STATE(1018),
    [sym_preproc_error] = STATE(1018),
    [sym_preproc_warning] = STATE(1018),
    [sym_preproc_define] = STATE(1018),
    [sym_preproc_undef] = STATE(1018),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2011),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1019] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3741),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6956),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5619),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9482),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1019),
    [sym_preproc_endregion] = STATE(1019),
    [sym_preproc_line] = STATE(1019),
    [sym_preproc_pragma] = STATE(1019),
    [sym_preproc_nullable] = STATE(1019),
    [sym_preproc_error] = STATE(1019),
    [sym_preproc_warning] = STATE(1019),
    [sym_preproc_define] = STATE(1019),
    [sym_preproc_undef] = STATE(1019),
    [aux_sym_class_declaration_repeat1] = STATE(3853),
    [aux_sym_lambda_expression_repeat1] = STATE(4299),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1497),
    [anon_sym_ref] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1505),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1507),
    [anon_sym_DOT_DOT] = ACTIONS(1509),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1020] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6956),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6493),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9482),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1020),
    [sym_preproc_endregion] = STATE(1020),
    [sym_preproc_line] = STATE(1020),
    [sym_preproc_pragma] = STATE(1020),
    [sym_preproc_nullable] = STATE(1020),
    [sym_preproc_error] = STATE(1020),
    [sym_preproc_warning] = STATE(1020),
    [sym_preproc_define] = STATE(1020),
    [sym_preproc_undef] = STATE(1020),
    [aux_sym_class_declaration_repeat1] = STATE(3853),
    [aux_sym_lambda_expression_repeat1] = STATE(4299),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(2915),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1497),
    [anon_sym_ref] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1505),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1507),
    [anon_sym_DOT_DOT] = ACTIONS(1509),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1021] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5791),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1021),
    [sym_preproc_endregion] = STATE(1021),
    [sym_preproc_line] = STATE(1021),
    [sym_preproc_pragma] = STATE(1021),
    [sym_preproc_nullable] = STATE(1021),
    [sym_preproc_error] = STATE(1021),
    [sym_preproc_warning] = STATE(1021),
    [sym_preproc_define] = STATE(1021),
    [sym_preproc_undef] = STATE(1021),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_RBRACE] = ACTIONS(2917),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1022] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6956),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6498),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9482),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1022),
    [sym_preproc_endregion] = STATE(1022),
    [sym_preproc_line] = STATE(1022),
    [sym_preproc_pragma] = STATE(1022),
    [sym_preproc_nullable] = STATE(1022),
    [sym_preproc_error] = STATE(1022),
    [sym_preproc_warning] = STATE(1022),
    [sym_preproc_define] = STATE(1022),
    [sym_preproc_undef] = STATE(1022),
    [aux_sym_class_declaration_repeat1] = STATE(3853),
    [aux_sym_lambda_expression_repeat1] = STATE(4299),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(2919),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1497),
    [anon_sym_ref] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1505),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1507),
    [anon_sym_DOT_DOT] = ACTIONS(1509),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1023] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4030),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6950),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7044),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5129),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3868),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7432),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9127),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1023),
    [sym_preproc_endregion] = STATE(1023),
    [sym_preproc_line] = STATE(1023),
    [sym_preproc_pragma] = STATE(1023),
    [sym_preproc_nullable] = STATE(1023),
    [sym_preproc_error] = STATE(1023),
    [sym_preproc_warning] = STATE(1023),
    [sym_preproc_define] = STATE(1023),
    [sym_preproc_undef] = STATE(1023),
    [aux_sym_class_declaration_repeat1] = STATE(3832),
    [aux_sym_lambda_expression_repeat1] = STATE(4259),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1357),
    [anon_sym_ref] = ACTIONS(1359),
    [anon_sym_LBRACE] = ACTIONS(2835),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1363),
    [anon_sym_TILDE] = ACTIONS(1363),
    [anon_sym_PLUS_PLUS] = ACTIONS(1363),
    [anon_sym_DASH_DASH] = ACTIONS(1363),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1361),
    [anon_sym_DASH] = ACTIONS(1361),
    [anon_sym_STAR] = ACTIONS(1365),
    [anon_sym_CARET] = ACTIONS(1363),
    [anon_sym_AMP] = ACTIONS(1363),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1367),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1369),
    [anon_sym_DOT_DOT] = ACTIONS(1371),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1024] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6956),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6499),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9482),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1024),
    [sym_preproc_endregion] = STATE(1024),
    [sym_preproc_line] = STATE(1024),
    [sym_preproc_pragma] = STATE(1024),
    [sym_preproc_nullable] = STATE(1024),
    [sym_preproc_error] = STATE(1024),
    [sym_preproc_warning] = STATE(1024),
    [sym_preproc_define] = STATE(1024),
    [sym_preproc_undef] = STATE(1024),
    [aux_sym_class_declaration_repeat1] = STATE(3853),
    [aux_sym_lambda_expression_repeat1] = STATE(4299),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(2921),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1497),
    [anon_sym_ref] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1505),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1507),
    [anon_sym_DOT_DOT] = ACTIONS(1509),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1025] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5791),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1025),
    [sym_preproc_endregion] = STATE(1025),
    [sym_preproc_line] = STATE(1025),
    [sym_preproc_pragma] = STATE(1025),
    [sym_preproc_nullable] = STATE(1025),
    [sym_preproc_error] = STATE(1025),
    [sym_preproc_warning] = STATE(1025),
    [sym_preproc_define] = STATE(1025),
    [sym_preproc_undef] = STATE(1025),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_RBRACE] = ACTIONS(2923),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1026] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3764),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7131),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5970),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4364),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9470),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1026),
    [sym_preproc_endregion] = STATE(1026),
    [sym_preproc_line] = STATE(1026),
    [sym_preproc_pragma] = STATE(1026),
    [sym_preproc_nullable] = STATE(1026),
    [sym_preproc_error] = STATE(1026),
    [sym_preproc_warning] = STATE(1026),
    [sym_preproc_define] = STATE(1026),
    [sym_preproc_undef] = STATE(1026),
    [aux_sym_class_declaration_repeat1] = STATE(3870),
    [aux_sym_lambda_expression_repeat1] = STATE(4302),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1555),
    [anon_sym_ref] = ACTIONS(1557),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(695),
    [anon_sym_TILDE] = ACTIONS(695),
    [anon_sym_PLUS_PLUS] = ACTIONS(695),
    [anon_sym_DASH_DASH] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(697),
    [anon_sym_DASH] = ACTIONS(697),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(695),
    [anon_sym_AMP] = ACTIONS(695),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1559),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1561),
    [anon_sym_DOT_DOT] = ACTIONS(1563),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1027] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3780),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7139),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6453),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1027),
    [sym_preproc_endregion] = STATE(1027),
    [sym_preproc_line] = STATE(1027),
    [sym_preproc_pragma] = STATE(1027),
    [sym_preproc_nullable] = STATE(1027),
    [sym_preproc_error] = STATE(1027),
    [sym_preproc_warning] = STATE(1027),
    [sym_preproc_define] = STATE(1027),
    [sym_preproc_undef] = STATE(1027),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2011),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1028] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6915),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7019),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4514),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3585),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7418),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9926),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1028),
    [sym_preproc_endregion] = STATE(1028),
    [sym_preproc_line] = STATE(1028),
    [sym_preproc_pragma] = STATE(1028),
    [sym_preproc_nullable] = STATE(1028),
    [sym_preproc_error] = STATE(1028),
    [sym_preproc_warning] = STATE(1028),
    [sym_preproc_define] = STATE(1028),
    [sym_preproc_undef] = STATE(1028),
    [aux_sym_class_declaration_repeat1] = STATE(3825),
    [aux_sym_lambda_expression_repeat1] = STATE(4244),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1161),
    [anon_sym_ref] = ACTIONS(1163),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_readonly] = ACTIONS(2767),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1177),
    [anon_sym_TILDE] = ACTIONS(1177),
    [anon_sym_PLUS_PLUS] = ACTIONS(1177),
    [anon_sym_DASH_DASH] = ACTIONS(1177),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1175),
    [anon_sym_DASH] = ACTIONS(1175),
    [anon_sym_STAR] = ACTIONS(1181),
    [anon_sym_CARET] = ACTIONS(1177),
    [anon_sym_AMP] = ACTIONS(1177),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1191),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1193),
    [anon_sym_DOT_DOT] = ACTIONS(1195),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1029] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5887),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1029),
    [sym_preproc_endregion] = STATE(1029),
    [sym_preproc_line] = STATE(1029),
    [sym_preproc_pragma] = STATE(1029),
    [sym_preproc_nullable] = STATE(1029),
    [sym_preproc_error] = STATE(1029),
    [sym_preproc_warning] = STATE(1029),
    [sym_preproc_define] = STATE(1029),
    [sym_preproc_undef] = STATE(1029),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2925),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1030] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5979),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1030),
    [sym_preproc_endregion] = STATE(1030),
    [sym_preproc_line] = STATE(1030),
    [sym_preproc_pragma] = STATE(1030),
    [sym_preproc_nullable] = STATE(1030),
    [sym_preproc_error] = STATE(1030),
    [sym_preproc_warning] = STATE(1030),
    [sym_preproc_define] = STATE(1030),
    [sym_preproc_undef] = STATE(1030),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2927),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1031] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3763),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7105),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5977),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1031),
    [sym_preproc_endregion] = STATE(1031),
    [sym_preproc_line] = STATE(1031),
    [sym_preproc_pragma] = STATE(1031),
    [sym_preproc_nullable] = STATE(1031),
    [sym_preproc_error] = STATE(1031),
    [sym_preproc_warning] = STATE(1031),
    [sym_preproc_define] = STATE(1031),
    [sym_preproc_undef] = STATE(1031),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1032] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5791),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1032),
    [sym_preproc_endregion] = STATE(1032),
    [sym_preproc_line] = STATE(1032),
    [sym_preproc_pragma] = STATE(1032),
    [sym_preproc_nullable] = STATE(1032),
    [sym_preproc_error] = STATE(1032),
    [sym_preproc_warning] = STATE(1032),
    [sym_preproc_define] = STATE(1032),
    [sym_preproc_undef] = STATE(1032),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_RBRACE] = ACTIONS(2929),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1033] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5821),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1033),
    [sym_preproc_endregion] = STATE(1033),
    [sym_preproc_line] = STATE(1033),
    [sym_preproc_pragma] = STATE(1033),
    [sym_preproc_nullable] = STATE(1033),
    [sym_preproc_error] = STATE(1033),
    [sym_preproc_warning] = STATE(1033),
    [sym_preproc_define] = STATE(1033),
    [sym_preproc_undef] = STATE(1033),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2931),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1034] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3764),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5789),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1034),
    [sym_preproc_endregion] = STATE(1034),
    [sym_preproc_line] = STATE(1034),
    [sym_preproc_pragma] = STATE(1034),
    [sym_preproc_nullable] = STATE(1034),
    [sym_preproc_error] = STATE(1034),
    [sym_preproc_warning] = STATE(1034),
    [sym_preproc_define] = STATE(1034),
    [sym_preproc_undef] = STATE(1034),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1035] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4218),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6962),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5218),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3931),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9818),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1035),
    [sym_preproc_endregion] = STATE(1035),
    [sym_preproc_line] = STATE(1035),
    [sym_preproc_pragma] = STATE(1035),
    [sym_preproc_nullable] = STATE(1035),
    [sym_preproc_error] = STATE(1035),
    [sym_preproc_warning] = STATE(1035),
    [sym_preproc_define] = STATE(1035),
    [sym_preproc_undef] = STATE(1035),
    [aux_sym_class_declaration_repeat1] = STATE(3811),
    [aux_sym_lambda_expression_repeat1] = STATE(4201),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1373),
    [anon_sym_ref] = ACTIONS(1375),
    [anon_sym_LBRACE] = ACTIONS(2831),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1379),
    [anon_sym_TILDE] = ACTIONS(1379),
    [anon_sym_PLUS_PLUS] = ACTIONS(1379),
    [anon_sym_DASH_DASH] = ACTIONS(1379),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1377),
    [anon_sym_DASH] = ACTIONS(1377),
    [anon_sym_STAR] = ACTIONS(1381),
    [anon_sym_CARET] = ACTIONS(1379),
    [anon_sym_AMP] = ACTIONS(1379),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1383),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1385),
    [anon_sym_DOT_DOT] = ACTIONS(1387),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1036] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5791),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1036),
    [sym_preproc_endregion] = STATE(1036),
    [sym_preproc_line] = STATE(1036),
    [sym_preproc_pragma] = STATE(1036),
    [sym_preproc_nullable] = STATE(1036),
    [sym_preproc_error] = STATE(1036),
    [sym_preproc_warning] = STATE(1036),
    [sym_preproc_define] = STATE(1036),
    [sym_preproc_undef] = STATE(1036),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_RBRACE] = ACTIONS(2933),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1037] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3735),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7139),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6464),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1037),
    [sym_preproc_endregion] = STATE(1037),
    [sym_preproc_line] = STATE(1037),
    [sym_preproc_pragma] = STATE(1037),
    [sym_preproc_nullable] = STATE(1037),
    [sym_preproc_error] = STATE(1037),
    [sym_preproc_warning] = STATE(1037),
    [sym_preproc_define] = STATE(1037),
    [sym_preproc_undef] = STATE(1037),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2011),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1038] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3741),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7139),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6465),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1038),
    [sym_preproc_endregion] = STATE(1038),
    [sym_preproc_line] = STATE(1038),
    [sym_preproc_pragma] = STATE(1038),
    [sym_preproc_nullable] = STATE(1038),
    [sym_preproc_error] = STATE(1038),
    [sym_preproc_warning] = STATE(1038),
    [sym_preproc_define] = STATE(1038),
    [sym_preproc_undef] = STATE(1038),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2011),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1039] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4021),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6915),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7018),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4469),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3585),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7418),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9926),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1039),
    [sym_preproc_endregion] = STATE(1039),
    [sym_preproc_line] = STATE(1039),
    [sym_preproc_pragma] = STATE(1039),
    [sym_preproc_nullable] = STATE(1039),
    [sym_preproc_error] = STATE(1039),
    [sym_preproc_warning] = STATE(1039),
    [sym_preproc_define] = STATE(1039),
    [sym_preproc_undef] = STATE(1039),
    [aux_sym_class_declaration_repeat1] = STATE(3825),
    [aux_sym_lambda_expression_repeat1] = STATE(4244),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1161),
    [anon_sym_ref] = ACTIONS(1163),
    [anon_sym_LBRACE] = ACTIONS(2835),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1177),
    [anon_sym_TILDE] = ACTIONS(1177),
    [anon_sym_PLUS_PLUS] = ACTIONS(1177),
    [anon_sym_DASH_DASH] = ACTIONS(1177),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1175),
    [anon_sym_DASH] = ACTIONS(1175),
    [anon_sym_STAR] = ACTIONS(1181),
    [anon_sym_CARET] = ACTIONS(1177),
    [anon_sym_AMP] = ACTIONS(1177),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1191),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1193),
    [anon_sym_DOT_DOT] = ACTIONS(1195),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1040] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6948),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2940),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7005),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5062),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3857),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7444),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9574),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1040),
    [sym_preproc_endregion] = STATE(1040),
    [sym_preproc_line] = STATE(1040),
    [sym_preproc_pragma] = STATE(1040),
    [sym_preproc_nullable] = STATE(1040),
    [sym_preproc_error] = STATE(1040),
    [sym_preproc_warning] = STATE(1040),
    [sym_preproc_define] = STATE(1040),
    [sym_preproc_undef] = STATE(1040),
    [aux_sym_class_declaration_repeat1] = STATE(3854),
    [aux_sym_lambda_expression_repeat1] = STATE(4136),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2111),
    [anon_sym_ref] = ACTIONS(2113),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1897),
    [anon_sym_readonly] = ACTIONS(2767),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2117),
    [anon_sym_TILDE] = ACTIONS(2117),
    [anon_sym_PLUS_PLUS] = ACTIONS(2117),
    [anon_sym_DASH_DASH] = ACTIONS(2117),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2115),
    [anon_sym_DASH] = ACTIONS(2115),
    [anon_sym_STAR] = ACTIONS(1903),
    [anon_sym_CARET] = ACTIONS(2117),
    [anon_sym_AMP] = ACTIONS(2117),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2119),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2121),
    [anon_sym_DOT_DOT] = ACTIONS(2123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1041] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6221),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2789),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6731),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5652),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1041),
    [sym_preproc_endregion] = STATE(1041),
    [sym_preproc_line] = STATE(1041),
    [sym_preproc_pragma] = STATE(1041),
    [sym_preproc_nullable] = STATE(1041),
    [sym_preproc_error] = STATE(1041),
    [sym_preproc_warning] = STATE(1041),
    [sym_preproc_define] = STATE(1041),
    [sym_preproc_undef] = STATE(1041),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(2725),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(2739),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(1089),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2727),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1042] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3754),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7139),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6470),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1042),
    [sym_preproc_endregion] = STATE(1042),
    [sym_preproc_line] = STATE(1042),
    [sym_preproc_pragma] = STATE(1042),
    [sym_preproc_nullable] = STATE(1042),
    [sym_preproc_error] = STATE(1042),
    [sym_preproc_warning] = STATE(1042),
    [sym_preproc_define] = STATE(1042),
    [sym_preproc_undef] = STATE(1042),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2011),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1043] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6956),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6343),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9482),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1043),
    [sym_preproc_endregion] = STATE(1043),
    [sym_preproc_line] = STATE(1043),
    [sym_preproc_pragma] = STATE(1043),
    [sym_preproc_nullable] = STATE(1043),
    [sym_preproc_error] = STATE(1043),
    [sym_preproc_warning] = STATE(1043),
    [sym_preproc_define] = STATE(1043),
    [sym_preproc_undef] = STATE(1043),
    [aux_sym_class_declaration_repeat1] = STATE(3853),
    [aux_sym_lambda_expression_repeat1] = STATE(4299),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(2935),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1497),
    [anon_sym_ref] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1505),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1507),
    [anon_sym_DOT_DOT] = ACTIONS(1509),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1044] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3637),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6916),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7128),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4917),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3752),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7413),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9092),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1044),
    [sym_preproc_endregion] = STATE(1044),
    [sym_preproc_line] = STATE(1044),
    [sym_preproc_pragma] = STATE(1044),
    [sym_preproc_nullable] = STATE(1044),
    [sym_preproc_error] = STATE(1044),
    [sym_preproc_warning] = STATE(1044),
    [sym_preproc_define] = STATE(1044),
    [sym_preproc_undef] = STATE(1044),
    [aux_sym_class_declaration_repeat1] = STATE(3845),
    [aux_sym_lambda_expression_repeat1] = STATE(4181),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1241),
    [anon_sym_ref] = ACTIONS(1243),
    [anon_sym_LBRACE] = ACTIONS(2825),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1255),
    [anon_sym_TILDE] = ACTIONS(1255),
    [anon_sym_PLUS_PLUS] = ACTIONS(1255),
    [anon_sym_DASH_DASH] = ACTIONS(1255),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1253),
    [anon_sym_DASH] = ACTIONS(1253),
    [anon_sym_STAR] = ACTIONS(1259),
    [anon_sym_CARET] = ACTIONS(1255),
    [anon_sym_AMP] = ACTIONS(1255),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1269),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1271),
    [anon_sym_DOT_DOT] = ACTIONS(1273),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1045] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6712),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2801),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6743),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5726),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4216),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9065),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1045),
    [sym_preproc_endregion] = STATE(1045),
    [sym_preproc_line] = STATE(1045),
    [sym_preproc_pragma] = STATE(1045),
    [sym_preproc_nullable] = STATE(1045),
    [sym_preproc_error] = STATE(1045),
    [sym_preproc_warning] = STATE(1045),
    [sym_preproc_define] = STATE(1045),
    [sym_preproc_undef] = STATE(1045),
    [aux_sym_class_declaration_repeat1] = STATE(3874),
    [aux_sym_lambda_expression_repeat1] = STATE(4311),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1531),
    [anon_sym_ref] = ACTIONS(2041),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_readonly] = ACTIONS(2739),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1537),
    [anon_sym_TILDE] = ACTIONS(1537),
    [anon_sym_PLUS_PLUS] = ACTIONS(1537),
    [anon_sym_DASH_DASH] = ACTIONS(1537),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1535),
    [anon_sym_DASH] = ACTIONS(1535),
    [anon_sym_STAR] = ACTIONS(1121),
    [anon_sym_CARET] = ACTIONS(1537),
    [anon_sym_AMP] = ACTIONS(1537),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(1089),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2607),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1129),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1131),
    [anon_sym_DOT_DOT] = ACTIONS(1135),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1046] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3780),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5622),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1046),
    [sym_preproc_endregion] = STATE(1046),
    [sym_preproc_line] = STATE(1046),
    [sym_preproc_pragma] = STATE(1046),
    [sym_preproc_nullable] = STATE(1046),
    [sym_preproc_error] = STATE(1046),
    [sym_preproc_warning] = STATE(1046),
    [sym_preproc_define] = STATE(1046),
    [sym_preproc_undef] = STATE(1046),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1047] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3780),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7131),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5976),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4364),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9470),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1047),
    [sym_preproc_endregion] = STATE(1047),
    [sym_preproc_line] = STATE(1047),
    [sym_preproc_pragma] = STATE(1047),
    [sym_preproc_nullable] = STATE(1047),
    [sym_preproc_error] = STATE(1047),
    [sym_preproc_warning] = STATE(1047),
    [sym_preproc_define] = STATE(1047),
    [sym_preproc_undef] = STATE(1047),
    [aux_sym_class_declaration_repeat1] = STATE(3870),
    [aux_sym_lambda_expression_repeat1] = STATE(4302),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1555),
    [anon_sym_ref] = ACTIONS(1557),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(695),
    [anon_sym_TILDE] = ACTIONS(695),
    [anon_sym_PLUS_PLUS] = ACTIONS(695),
    [anon_sym_DASH_DASH] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(697),
    [anon_sym_DASH] = ACTIONS(697),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(695),
    [anon_sym_AMP] = ACTIONS(695),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1559),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1561),
    [anon_sym_DOT_DOT] = ACTIONS(1563),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1048] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4060),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6915),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7018),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4470),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3585),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7418),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9926),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1048),
    [sym_preproc_endregion] = STATE(1048),
    [sym_preproc_line] = STATE(1048),
    [sym_preproc_pragma] = STATE(1048),
    [sym_preproc_nullable] = STATE(1048),
    [sym_preproc_error] = STATE(1048),
    [sym_preproc_warning] = STATE(1048),
    [sym_preproc_define] = STATE(1048),
    [sym_preproc_undef] = STATE(1048),
    [aux_sym_class_declaration_repeat1] = STATE(3825),
    [aux_sym_lambda_expression_repeat1] = STATE(4244),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1161),
    [anon_sym_ref] = ACTIONS(1163),
    [anon_sym_LBRACE] = ACTIONS(2835),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1177),
    [anon_sym_TILDE] = ACTIONS(1177),
    [anon_sym_PLUS_PLUS] = ACTIONS(1177),
    [anon_sym_DASH_DASH] = ACTIONS(1177),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1175),
    [anon_sym_DASH] = ACTIONS(1175),
    [anon_sym_STAR] = ACTIONS(1181),
    [anon_sym_CARET] = ACTIONS(1177),
    [anon_sym_AMP] = ACTIONS(1177),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1191),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1193),
    [anon_sym_DOT_DOT] = ACTIONS(1195),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1049] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3637),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6914),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2960),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7049),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6188),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4399),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7440),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9013),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1049),
    [sym_preproc_endregion] = STATE(1049),
    [sym_preproc_line] = STATE(1049),
    [sym_preproc_pragma] = STATE(1049),
    [sym_preproc_nullable] = STATE(1049),
    [sym_preproc_error] = STATE(1049),
    [sym_preproc_warning] = STATE(1049),
    [sym_preproc_define] = STATE(1049),
    [sym_preproc_undef] = STATE(1049),
    [aux_sym_class_declaration_repeat1] = STATE(3833),
    [aux_sym_lambda_expression_repeat1] = STATE(4261),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2151),
    [anon_sym_ref] = ACTIONS(2153),
    [anon_sym_LBRACE] = ACTIONS(2825),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2155),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2159),
    [anon_sym_TILDE] = ACTIONS(2159),
    [anon_sym_PLUS_PLUS] = ACTIONS(2159),
    [anon_sym_DASH_DASH] = ACTIONS(2159),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2157),
    [anon_sym_DASH] = ACTIONS(2157),
    [anon_sym_STAR] = ACTIONS(2161),
    [anon_sym_CARET] = ACTIONS(2159),
    [anon_sym_AMP] = ACTIONS(2159),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2163),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2165),
    [anon_sym_DOT_DOT] = ACTIONS(2167),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1050] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3714),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6914),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2960),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7049),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6190),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4399),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7440),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9013),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1050),
    [sym_preproc_endregion] = STATE(1050),
    [sym_preproc_line] = STATE(1050),
    [sym_preproc_pragma] = STATE(1050),
    [sym_preproc_nullable] = STATE(1050),
    [sym_preproc_error] = STATE(1050),
    [sym_preproc_warning] = STATE(1050),
    [sym_preproc_define] = STATE(1050),
    [sym_preproc_undef] = STATE(1050),
    [aux_sym_class_declaration_repeat1] = STATE(3833),
    [aux_sym_lambda_expression_repeat1] = STATE(4261),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2151),
    [anon_sym_ref] = ACTIONS(2153),
    [anon_sym_LBRACE] = ACTIONS(2825),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2155),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2159),
    [anon_sym_TILDE] = ACTIONS(2159),
    [anon_sym_PLUS_PLUS] = ACTIONS(2159),
    [anon_sym_DASH_DASH] = ACTIONS(2159),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2157),
    [anon_sym_DASH] = ACTIONS(2157),
    [anon_sym_STAR] = ACTIONS(2161),
    [anon_sym_CARET] = ACTIONS(2159),
    [anon_sym_AMP] = ACTIONS(2159),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2163),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2165),
    [anon_sym_DOT_DOT] = ACTIONS(2167),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1051] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3641),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6914),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2960),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7049),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6191),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4399),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7440),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9013),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1051),
    [sym_preproc_endregion] = STATE(1051),
    [sym_preproc_line] = STATE(1051),
    [sym_preproc_pragma] = STATE(1051),
    [sym_preproc_nullable] = STATE(1051),
    [sym_preproc_error] = STATE(1051),
    [sym_preproc_warning] = STATE(1051),
    [sym_preproc_define] = STATE(1051),
    [sym_preproc_undef] = STATE(1051),
    [aux_sym_class_declaration_repeat1] = STATE(3833),
    [aux_sym_lambda_expression_repeat1] = STATE(4261),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2151),
    [anon_sym_ref] = ACTIONS(2153),
    [anon_sym_LBRACE] = ACTIONS(2825),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2155),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2159),
    [anon_sym_TILDE] = ACTIONS(2159),
    [anon_sym_PLUS_PLUS] = ACTIONS(2159),
    [anon_sym_DASH_DASH] = ACTIONS(2159),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2157),
    [anon_sym_DASH] = ACTIONS(2157),
    [anon_sym_STAR] = ACTIONS(2161),
    [anon_sym_CARET] = ACTIONS(2159),
    [anon_sym_AMP] = ACTIONS(2159),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2163),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2165),
    [anon_sym_DOT_DOT] = ACTIONS(2167),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1052] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3689),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6914),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2960),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7049),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6203),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4399),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7440),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9013),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1052),
    [sym_preproc_endregion] = STATE(1052),
    [sym_preproc_line] = STATE(1052),
    [sym_preproc_pragma] = STATE(1052),
    [sym_preproc_nullable] = STATE(1052),
    [sym_preproc_error] = STATE(1052),
    [sym_preproc_warning] = STATE(1052),
    [sym_preproc_define] = STATE(1052),
    [sym_preproc_undef] = STATE(1052),
    [aux_sym_class_declaration_repeat1] = STATE(3833),
    [aux_sym_lambda_expression_repeat1] = STATE(4261),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2151),
    [anon_sym_ref] = ACTIONS(2153),
    [anon_sym_LBRACE] = ACTIONS(2825),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2155),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2159),
    [anon_sym_TILDE] = ACTIONS(2159),
    [anon_sym_PLUS_PLUS] = ACTIONS(2159),
    [anon_sym_DASH_DASH] = ACTIONS(2159),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2157),
    [anon_sym_DASH] = ACTIONS(2157),
    [anon_sym_STAR] = ACTIONS(2161),
    [anon_sym_CARET] = ACTIONS(2159),
    [anon_sym_AMP] = ACTIONS(2159),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2163),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2165),
    [anon_sym_DOT_DOT] = ACTIONS(2167),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1053] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3692),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6914),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2960),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7049),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6208),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4399),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7440),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9013),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1053),
    [sym_preproc_endregion] = STATE(1053),
    [sym_preproc_line] = STATE(1053),
    [sym_preproc_pragma] = STATE(1053),
    [sym_preproc_nullable] = STATE(1053),
    [sym_preproc_error] = STATE(1053),
    [sym_preproc_warning] = STATE(1053),
    [sym_preproc_define] = STATE(1053),
    [sym_preproc_undef] = STATE(1053),
    [aux_sym_class_declaration_repeat1] = STATE(3833),
    [aux_sym_lambda_expression_repeat1] = STATE(4261),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2151),
    [anon_sym_ref] = ACTIONS(2153),
    [anon_sym_LBRACE] = ACTIONS(2825),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2155),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2159),
    [anon_sym_TILDE] = ACTIONS(2159),
    [anon_sym_PLUS_PLUS] = ACTIONS(2159),
    [anon_sym_DASH_DASH] = ACTIONS(2159),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2157),
    [anon_sym_DASH] = ACTIONS(2157),
    [anon_sym_STAR] = ACTIONS(2161),
    [anon_sym_CARET] = ACTIONS(2159),
    [anon_sym_AMP] = ACTIONS(2159),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2163),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2165),
    [anon_sym_DOT_DOT] = ACTIONS(2167),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1054] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3708),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6914),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2960),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7049),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6222),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4399),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7440),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9013),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1054),
    [sym_preproc_endregion] = STATE(1054),
    [sym_preproc_line] = STATE(1054),
    [sym_preproc_pragma] = STATE(1054),
    [sym_preproc_nullable] = STATE(1054),
    [sym_preproc_error] = STATE(1054),
    [sym_preproc_warning] = STATE(1054),
    [sym_preproc_define] = STATE(1054),
    [sym_preproc_undef] = STATE(1054),
    [aux_sym_class_declaration_repeat1] = STATE(3833),
    [aux_sym_lambda_expression_repeat1] = STATE(4261),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2151),
    [anon_sym_ref] = ACTIONS(2153),
    [anon_sym_LBRACE] = ACTIONS(2825),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2155),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2159),
    [anon_sym_TILDE] = ACTIONS(2159),
    [anon_sym_PLUS_PLUS] = ACTIONS(2159),
    [anon_sym_DASH_DASH] = ACTIONS(2159),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2157),
    [anon_sym_DASH] = ACTIONS(2157),
    [anon_sym_STAR] = ACTIONS(2161),
    [anon_sym_CARET] = ACTIONS(2159),
    [anon_sym_AMP] = ACTIONS(2159),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2163),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2165),
    [anon_sym_DOT_DOT] = ACTIONS(2167),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1055] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5791),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1055),
    [sym_preproc_endregion] = STATE(1055),
    [sym_preproc_line] = STATE(1055),
    [sym_preproc_pragma] = STATE(1055),
    [sym_preproc_nullable] = STATE(1055),
    [sym_preproc_error] = STATE(1055),
    [sym_preproc_warning] = STATE(1055),
    [sym_preproc_define] = STATE(1055),
    [sym_preproc_undef] = STATE(1055),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_RBRACE] = ACTIONS(2937),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1056] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6914),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2960),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7050),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6153),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4399),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7440),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9013),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1056),
    [sym_preproc_endregion] = STATE(1056),
    [sym_preproc_line] = STATE(1056),
    [sym_preproc_pragma] = STATE(1056),
    [sym_preproc_nullable] = STATE(1056),
    [sym_preproc_error] = STATE(1056),
    [sym_preproc_warning] = STATE(1056),
    [sym_preproc_define] = STATE(1056),
    [sym_preproc_undef] = STATE(1056),
    [aux_sym_class_declaration_repeat1] = STATE(3833),
    [aux_sym_lambda_expression_repeat1] = STATE(4261),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2151),
    [anon_sym_ref] = ACTIONS(2153),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2155),
    [anon_sym_readonly] = ACTIONS(2767),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2159),
    [anon_sym_TILDE] = ACTIONS(2159),
    [anon_sym_PLUS_PLUS] = ACTIONS(2159),
    [anon_sym_DASH_DASH] = ACTIONS(2159),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2157),
    [anon_sym_DASH] = ACTIONS(2157),
    [anon_sym_STAR] = ACTIONS(2161),
    [anon_sym_CARET] = ACTIONS(2159),
    [anon_sym_AMP] = ACTIONS(2159),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2163),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2165),
    [anon_sym_DOT_DOT] = ACTIONS(2167),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1057] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4005),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6950),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7044),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5131),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3868),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7432),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9127),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1057),
    [sym_preproc_endregion] = STATE(1057),
    [sym_preproc_line] = STATE(1057),
    [sym_preproc_pragma] = STATE(1057),
    [sym_preproc_nullable] = STATE(1057),
    [sym_preproc_error] = STATE(1057),
    [sym_preproc_warning] = STATE(1057),
    [sym_preproc_define] = STATE(1057),
    [sym_preproc_undef] = STATE(1057),
    [aux_sym_class_declaration_repeat1] = STATE(3832),
    [aux_sym_lambda_expression_repeat1] = STATE(4259),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1357),
    [anon_sym_ref] = ACTIONS(1359),
    [anon_sym_LBRACE] = ACTIONS(2835),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1363),
    [anon_sym_TILDE] = ACTIONS(1363),
    [anon_sym_PLUS_PLUS] = ACTIONS(1363),
    [anon_sym_DASH_DASH] = ACTIONS(1363),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1361),
    [anon_sym_DASH] = ACTIONS(1361),
    [anon_sym_STAR] = ACTIONS(1365),
    [anon_sym_CARET] = ACTIONS(1363),
    [anon_sym_AMP] = ACTIONS(1363),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1367),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1369),
    [anon_sym_DOT_DOT] = ACTIONS(1371),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1058] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4152),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6917),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2905),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7006),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5493),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4199),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7447),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9823),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1058),
    [sym_preproc_endregion] = STATE(1058),
    [sym_preproc_line] = STATE(1058),
    [sym_preproc_pragma] = STATE(1058),
    [sym_preproc_nullable] = STATE(1058),
    [sym_preproc_error] = STATE(1058),
    [sym_preproc_warning] = STATE(1058),
    [sym_preproc_define] = STATE(1058),
    [sym_preproc_undef] = STATE(1058),
    [aux_sym_class_declaration_repeat1] = STATE(3822),
    [aux_sym_lambda_expression_repeat1] = STATE(4238),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1623),
    [anon_sym_ref] = ACTIONS(1625),
    [anon_sym_LBRACE] = ACTIONS(2831),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1577),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1629),
    [anon_sym_TILDE] = ACTIONS(1629),
    [anon_sym_PLUS_PLUS] = ACTIONS(1629),
    [anon_sym_DASH_DASH] = ACTIONS(1629),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1627),
    [anon_sym_DASH] = ACTIONS(1627),
    [anon_sym_STAR] = ACTIONS(1631),
    [anon_sym_CARET] = ACTIONS(1629),
    [anon_sym_AMP] = ACTIONS(1629),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1633),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1635),
    [anon_sym_DOT_DOT] = ACTIONS(1637),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1059] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4119),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6917),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2905),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7006),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5494),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4199),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7447),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9823),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1059),
    [sym_preproc_endregion] = STATE(1059),
    [sym_preproc_line] = STATE(1059),
    [sym_preproc_pragma] = STATE(1059),
    [sym_preproc_nullable] = STATE(1059),
    [sym_preproc_error] = STATE(1059),
    [sym_preproc_warning] = STATE(1059),
    [sym_preproc_define] = STATE(1059),
    [sym_preproc_undef] = STATE(1059),
    [aux_sym_class_declaration_repeat1] = STATE(3822),
    [aux_sym_lambda_expression_repeat1] = STATE(4238),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1623),
    [anon_sym_ref] = ACTIONS(1625),
    [anon_sym_LBRACE] = ACTIONS(2831),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1577),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1629),
    [anon_sym_TILDE] = ACTIONS(1629),
    [anon_sym_PLUS_PLUS] = ACTIONS(1629),
    [anon_sym_DASH_DASH] = ACTIONS(1629),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1627),
    [anon_sym_DASH] = ACTIONS(1627),
    [anon_sym_STAR] = ACTIONS(1631),
    [anon_sym_CARET] = ACTIONS(1629),
    [anon_sym_AMP] = ACTIONS(1629),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1633),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1635),
    [anon_sym_DOT_DOT] = ACTIONS(1637),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1060] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4218),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6917),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2905),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7006),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5495),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4199),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7447),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9823),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1060),
    [sym_preproc_endregion] = STATE(1060),
    [sym_preproc_line] = STATE(1060),
    [sym_preproc_pragma] = STATE(1060),
    [sym_preproc_nullable] = STATE(1060),
    [sym_preproc_error] = STATE(1060),
    [sym_preproc_warning] = STATE(1060),
    [sym_preproc_define] = STATE(1060),
    [sym_preproc_undef] = STATE(1060),
    [aux_sym_class_declaration_repeat1] = STATE(3822),
    [aux_sym_lambda_expression_repeat1] = STATE(4238),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1623),
    [anon_sym_ref] = ACTIONS(1625),
    [anon_sym_LBRACE] = ACTIONS(2831),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1577),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1629),
    [anon_sym_TILDE] = ACTIONS(1629),
    [anon_sym_PLUS_PLUS] = ACTIONS(1629),
    [anon_sym_DASH_DASH] = ACTIONS(1629),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1627),
    [anon_sym_DASH] = ACTIONS(1627),
    [anon_sym_STAR] = ACTIONS(1631),
    [anon_sym_CARET] = ACTIONS(1629),
    [anon_sym_AMP] = ACTIONS(1629),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1633),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1635),
    [anon_sym_DOT_DOT] = ACTIONS(1637),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1061] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4101),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6917),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2905),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7006),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5497),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4199),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7447),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9823),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1061),
    [sym_preproc_endregion] = STATE(1061),
    [sym_preproc_line] = STATE(1061),
    [sym_preproc_pragma] = STATE(1061),
    [sym_preproc_nullable] = STATE(1061),
    [sym_preproc_error] = STATE(1061),
    [sym_preproc_warning] = STATE(1061),
    [sym_preproc_define] = STATE(1061),
    [sym_preproc_undef] = STATE(1061),
    [aux_sym_class_declaration_repeat1] = STATE(3822),
    [aux_sym_lambda_expression_repeat1] = STATE(4238),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1623),
    [anon_sym_ref] = ACTIONS(1625),
    [anon_sym_LBRACE] = ACTIONS(2831),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1577),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1629),
    [anon_sym_TILDE] = ACTIONS(1629),
    [anon_sym_PLUS_PLUS] = ACTIONS(1629),
    [anon_sym_DASH_DASH] = ACTIONS(1629),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1627),
    [anon_sym_DASH] = ACTIONS(1627),
    [anon_sym_STAR] = ACTIONS(1631),
    [anon_sym_CARET] = ACTIONS(1629),
    [anon_sym_AMP] = ACTIONS(1629),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1633),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1635),
    [anon_sym_DOT_DOT] = ACTIONS(1637),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1062] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4102),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6917),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2905),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7006),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5498),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4199),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7447),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9823),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1062),
    [sym_preproc_endregion] = STATE(1062),
    [sym_preproc_line] = STATE(1062),
    [sym_preproc_pragma] = STATE(1062),
    [sym_preproc_nullable] = STATE(1062),
    [sym_preproc_error] = STATE(1062),
    [sym_preproc_warning] = STATE(1062),
    [sym_preproc_define] = STATE(1062),
    [sym_preproc_undef] = STATE(1062),
    [aux_sym_class_declaration_repeat1] = STATE(3822),
    [aux_sym_lambda_expression_repeat1] = STATE(4238),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1623),
    [anon_sym_ref] = ACTIONS(1625),
    [anon_sym_LBRACE] = ACTIONS(2831),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1577),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1629),
    [anon_sym_TILDE] = ACTIONS(1629),
    [anon_sym_PLUS_PLUS] = ACTIONS(1629),
    [anon_sym_DASH_DASH] = ACTIONS(1629),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1627),
    [anon_sym_DASH] = ACTIONS(1627),
    [anon_sym_STAR] = ACTIONS(1631),
    [anon_sym_CARET] = ACTIONS(1629),
    [anon_sym_AMP] = ACTIONS(1629),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1633),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1635),
    [anon_sym_DOT_DOT] = ACTIONS(1637),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1063] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4111),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6917),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2905),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7006),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5499),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4199),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7447),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9823),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1063),
    [sym_preproc_endregion] = STATE(1063),
    [sym_preproc_line] = STATE(1063),
    [sym_preproc_pragma] = STATE(1063),
    [sym_preproc_nullable] = STATE(1063),
    [sym_preproc_error] = STATE(1063),
    [sym_preproc_warning] = STATE(1063),
    [sym_preproc_define] = STATE(1063),
    [sym_preproc_undef] = STATE(1063),
    [aux_sym_class_declaration_repeat1] = STATE(3822),
    [aux_sym_lambda_expression_repeat1] = STATE(4238),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1623),
    [anon_sym_ref] = ACTIONS(1625),
    [anon_sym_LBRACE] = ACTIONS(2831),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1577),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1629),
    [anon_sym_TILDE] = ACTIONS(1629),
    [anon_sym_PLUS_PLUS] = ACTIONS(1629),
    [anon_sym_DASH_DASH] = ACTIONS(1629),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1627),
    [anon_sym_DASH] = ACTIONS(1627),
    [anon_sym_STAR] = ACTIONS(1631),
    [anon_sym_CARET] = ACTIONS(1629),
    [anon_sym_AMP] = ACTIONS(1629),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1633),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1635),
    [anon_sym_DOT_DOT] = ACTIONS(1637),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1064] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5949),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1064),
    [sym_preproc_endregion] = STATE(1064),
    [sym_preproc_line] = STATE(1064),
    [sym_preproc_pragma] = STATE(1064),
    [sym_preproc_nullable] = STATE(1064),
    [sym_preproc_error] = STATE(1064),
    [sym_preproc_warning] = STATE(1064),
    [sym_preproc_define] = STATE(1064),
    [sym_preproc_undef] = STATE(1064),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2939),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1065] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3735),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6948),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2940),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6999),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5064),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3857),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7444),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9574),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1065),
    [sym_preproc_endregion] = STATE(1065),
    [sym_preproc_line] = STATE(1065),
    [sym_preproc_pragma] = STATE(1065),
    [sym_preproc_nullable] = STATE(1065),
    [sym_preproc_error] = STATE(1065),
    [sym_preproc_warning] = STATE(1065),
    [sym_preproc_define] = STATE(1065),
    [sym_preproc_undef] = STATE(1065),
    [aux_sym_class_declaration_repeat1] = STATE(3854),
    [aux_sym_lambda_expression_repeat1] = STATE(4136),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2111),
    [anon_sym_ref] = ACTIONS(2113),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1897),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2117),
    [anon_sym_TILDE] = ACTIONS(2117),
    [anon_sym_PLUS_PLUS] = ACTIONS(2117),
    [anon_sym_DASH_DASH] = ACTIONS(2117),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2115),
    [anon_sym_DASH] = ACTIONS(2115),
    [anon_sym_STAR] = ACTIONS(1903),
    [anon_sym_CARET] = ACTIONS(2117),
    [anon_sym_AMP] = ACTIONS(2117),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2119),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2121),
    [anon_sym_DOT_DOT] = ACTIONS(2123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1066] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3991),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6941),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2977),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7077),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5642),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4200),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7415),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9773),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1066),
    [sym_preproc_endregion] = STATE(1066),
    [sym_preproc_line] = STATE(1066),
    [sym_preproc_pragma] = STATE(1066),
    [sym_preproc_nullable] = STATE(1066),
    [sym_preproc_error] = STATE(1066),
    [sym_preproc_warning] = STATE(1066),
    [sym_preproc_define] = STATE(1066),
    [sym_preproc_undef] = STATE(1066),
    [aux_sym_class_declaration_repeat1] = STATE(3843),
    [aux_sym_lambda_expression_repeat1] = STATE(4275),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1911),
    [anon_sym_ref] = ACTIONS(1913),
    [anon_sym_LBRACE] = ACTIONS(2835),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1915),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1919),
    [anon_sym_TILDE] = ACTIONS(1919),
    [anon_sym_PLUS_PLUS] = ACTIONS(1919),
    [anon_sym_DASH_DASH] = ACTIONS(1919),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1917),
    [anon_sym_DASH] = ACTIONS(1917),
    [anon_sym_STAR] = ACTIONS(1921),
    [anon_sym_CARET] = ACTIONS(1919),
    [anon_sym_AMP] = ACTIONS(1919),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1923),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1925),
    [anon_sym_DOT_DOT] = ACTIONS(1927),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1067] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4028),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6941),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2977),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7077),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5643),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4200),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7415),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9773),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1067),
    [sym_preproc_endregion] = STATE(1067),
    [sym_preproc_line] = STATE(1067),
    [sym_preproc_pragma] = STATE(1067),
    [sym_preproc_nullable] = STATE(1067),
    [sym_preproc_error] = STATE(1067),
    [sym_preproc_warning] = STATE(1067),
    [sym_preproc_define] = STATE(1067),
    [sym_preproc_undef] = STATE(1067),
    [aux_sym_class_declaration_repeat1] = STATE(3843),
    [aux_sym_lambda_expression_repeat1] = STATE(4275),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1911),
    [anon_sym_ref] = ACTIONS(1913),
    [anon_sym_LBRACE] = ACTIONS(2835),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1915),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1919),
    [anon_sym_TILDE] = ACTIONS(1919),
    [anon_sym_PLUS_PLUS] = ACTIONS(1919),
    [anon_sym_DASH_DASH] = ACTIONS(1919),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1917),
    [anon_sym_DASH] = ACTIONS(1917),
    [anon_sym_STAR] = ACTIONS(1921),
    [anon_sym_CARET] = ACTIONS(1919),
    [anon_sym_AMP] = ACTIONS(1919),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1923),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1925),
    [anon_sym_DOT_DOT] = ACTIONS(1927),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1068] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3754),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6956),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5416),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9482),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1068),
    [sym_preproc_endregion] = STATE(1068),
    [sym_preproc_line] = STATE(1068),
    [sym_preproc_pragma] = STATE(1068),
    [sym_preproc_nullable] = STATE(1068),
    [sym_preproc_error] = STATE(1068),
    [sym_preproc_warning] = STATE(1068),
    [sym_preproc_define] = STATE(1068),
    [sym_preproc_undef] = STATE(1068),
    [aux_sym_class_declaration_repeat1] = STATE(3853),
    [aux_sym_lambda_expression_repeat1] = STATE(4299),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1497),
    [anon_sym_ref] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1505),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1507),
    [anon_sym_DOT_DOT] = ACTIONS(1509),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1069] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3714),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6916),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7128),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4815),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3752),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7413),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9092),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1069),
    [sym_preproc_endregion] = STATE(1069),
    [sym_preproc_line] = STATE(1069),
    [sym_preproc_pragma] = STATE(1069),
    [sym_preproc_nullable] = STATE(1069),
    [sym_preproc_error] = STATE(1069),
    [sym_preproc_warning] = STATE(1069),
    [sym_preproc_define] = STATE(1069),
    [sym_preproc_undef] = STATE(1069),
    [aux_sym_class_declaration_repeat1] = STATE(3845),
    [aux_sym_lambda_expression_repeat1] = STATE(4181),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1241),
    [anon_sym_ref] = ACTIONS(1243),
    [anon_sym_LBRACE] = ACTIONS(2825),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1255),
    [anon_sym_TILDE] = ACTIONS(1255),
    [anon_sym_PLUS_PLUS] = ACTIONS(1255),
    [anon_sym_DASH_DASH] = ACTIONS(1255),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1253),
    [anon_sym_DASH] = ACTIONS(1253),
    [anon_sym_STAR] = ACTIONS(1259),
    [anon_sym_CARET] = ACTIONS(1255),
    [anon_sym_AMP] = ACTIONS(1255),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1269),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1271),
    [anon_sym_DOT_DOT] = ACTIONS(1273),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1070] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4030),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6941),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2977),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7077),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5644),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4200),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7415),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9773),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1070),
    [sym_preproc_endregion] = STATE(1070),
    [sym_preproc_line] = STATE(1070),
    [sym_preproc_pragma] = STATE(1070),
    [sym_preproc_nullable] = STATE(1070),
    [sym_preproc_error] = STATE(1070),
    [sym_preproc_warning] = STATE(1070),
    [sym_preproc_define] = STATE(1070),
    [sym_preproc_undef] = STATE(1070),
    [aux_sym_class_declaration_repeat1] = STATE(3843),
    [aux_sym_lambda_expression_repeat1] = STATE(4275),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1911),
    [anon_sym_ref] = ACTIONS(1913),
    [anon_sym_LBRACE] = ACTIONS(2835),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1915),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1919),
    [anon_sym_TILDE] = ACTIONS(1919),
    [anon_sym_PLUS_PLUS] = ACTIONS(1919),
    [anon_sym_DASH_DASH] = ACTIONS(1919),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1917),
    [anon_sym_DASH] = ACTIONS(1917),
    [anon_sym_STAR] = ACTIONS(1921),
    [anon_sym_CARET] = ACTIONS(1919),
    [anon_sym_AMP] = ACTIONS(1919),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1923),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1925),
    [anon_sym_DOT_DOT] = ACTIONS(1927),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1071] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3741),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6948),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2940),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6999),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5054),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3857),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7444),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9574),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1071),
    [sym_preproc_endregion] = STATE(1071),
    [sym_preproc_line] = STATE(1071),
    [sym_preproc_pragma] = STATE(1071),
    [sym_preproc_nullable] = STATE(1071),
    [sym_preproc_error] = STATE(1071),
    [sym_preproc_warning] = STATE(1071),
    [sym_preproc_define] = STATE(1071),
    [sym_preproc_undef] = STATE(1071),
    [aux_sym_class_declaration_repeat1] = STATE(3854),
    [aux_sym_lambda_expression_repeat1] = STATE(4136),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2111),
    [anon_sym_ref] = ACTIONS(2113),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1897),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2117),
    [anon_sym_TILDE] = ACTIONS(2117),
    [anon_sym_PLUS_PLUS] = ACTIONS(2117),
    [anon_sym_DASH_DASH] = ACTIONS(2117),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2115),
    [anon_sym_DASH] = ACTIONS(2115),
    [anon_sym_STAR] = ACTIONS(1903),
    [anon_sym_CARET] = ACTIONS(2117),
    [anon_sym_AMP] = ACTIONS(2117),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2119),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2121),
    [anon_sym_DOT_DOT] = ACTIONS(2123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1072] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3641),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6916),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7128),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4852),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3752),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7413),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9092),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1072),
    [sym_preproc_endregion] = STATE(1072),
    [sym_preproc_line] = STATE(1072),
    [sym_preproc_pragma] = STATE(1072),
    [sym_preproc_nullable] = STATE(1072),
    [sym_preproc_error] = STATE(1072),
    [sym_preproc_warning] = STATE(1072),
    [sym_preproc_define] = STATE(1072),
    [sym_preproc_undef] = STATE(1072),
    [aux_sym_class_declaration_repeat1] = STATE(3845),
    [aux_sym_lambda_expression_repeat1] = STATE(4181),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1241),
    [anon_sym_ref] = ACTIONS(1243),
    [anon_sym_LBRACE] = ACTIONS(2825),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1255),
    [anon_sym_TILDE] = ACTIONS(1255),
    [anon_sym_PLUS_PLUS] = ACTIONS(1255),
    [anon_sym_DASH_DASH] = ACTIONS(1255),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1253),
    [anon_sym_DASH] = ACTIONS(1253),
    [anon_sym_STAR] = ACTIONS(1259),
    [anon_sym_CARET] = ACTIONS(1255),
    [anon_sym_AMP] = ACTIONS(1255),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1269),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1271),
    [anon_sym_DOT_DOT] = ACTIONS(1273),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1073] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4005),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6941),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2977),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7077),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5646),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4200),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7415),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9773),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1073),
    [sym_preproc_endregion] = STATE(1073),
    [sym_preproc_line] = STATE(1073),
    [sym_preproc_pragma] = STATE(1073),
    [sym_preproc_nullable] = STATE(1073),
    [sym_preproc_error] = STATE(1073),
    [sym_preproc_warning] = STATE(1073),
    [sym_preproc_define] = STATE(1073),
    [sym_preproc_undef] = STATE(1073),
    [aux_sym_class_declaration_repeat1] = STATE(3843),
    [aux_sym_lambda_expression_repeat1] = STATE(4275),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1911),
    [anon_sym_ref] = ACTIONS(1913),
    [anon_sym_LBRACE] = ACTIONS(2835),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1915),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1919),
    [anon_sym_TILDE] = ACTIONS(1919),
    [anon_sym_PLUS_PLUS] = ACTIONS(1919),
    [anon_sym_DASH_DASH] = ACTIONS(1919),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1917),
    [anon_sym_DASH] = ACTIONS(1917),
    [anon_sym_STAR] = ACTIONS(1921),
    [anon_sym_CARET] = ACTIONS(1919),
    [anon_sym_AMP] = ACTIONS(1919),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1923),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1925),
    [anon_sym_DOT_DOT] = ACTIONS(1927),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1074] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4021),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6941),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2977),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7077),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5647),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4200),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7415),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9773),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1074),
    [sym_preproc_endregion] = STATE(1074),
    [sym_preproc_line] = STATE(1074),
    [sym_preproc_pragma] = STATE(1074),
    [sym_preproc_nullable] = STATE(1074),
    [sym_preproc_error] = STATE(1074),
    [sym_preproc_warning] = STATE(1074),
    [sym_preproc_define] = STATE(1074),
    [sym_preproc_undef] = STATE(1074),
    [aux_sym_class_declaration_repeat1] = STATE(3843),
    [aux_sym_lambda_expression_repeat1] = STATE(4275),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1911),
    [anon_sym_ref] = ACTIONS(1913),
    [anon_sym_LBRACE] = ACTIONS(2835),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1915),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1919),
    [anon_sym_TILDE] = ACTIONS(1919),
    [anon_sym_PLUS_PLUS] = ACTIONS(1919),
    [anon_sym_DASH_DASH] = ACTIONS(1919),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1917),
    [anon_sym_DASH] = ACTIONS(1917),
    [anon_sym_STAR] = ACTIONS(1921),
    [anon_sym_CARET] = ACTIONS(1919),
    [anon_sym_AMP] = ACTIONS(1919),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1923),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1925),
    [anon_sym_DOT_DOT] = ACTIONS(1927),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1075] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4060),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6941),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2977),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7077),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5648),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4200),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7415),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9773),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1075),
    [sym_preproc_endregion] = STATE(1075),
    [sym_preproc_line] = STATE(1075),
    [sym_preproc_pragma] = STATE(1075),
    [sym_preproc_nullable] = STATE(1075),
    [sym_preproc_error] = STATE(1075),
    [sym_preproc_warning] = STATE(1075),
    [sym_preproc_define] = STATE(1075),
    [sym_preproc_undef] = STATE(1075),
    [aux_sym_class_declaration_repeat1] = STATE(3843),
    [aux_sym_lambda_expression_repeat1] = STATE(4275),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1911),
    [anon_sym_ref] = ACTIONS(1913),
    [anon_sym_LBRACE] = ACTIONS(2835),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1915),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1919),
    [anon_sym_TILDE] = ACTIONS(1919),
    [anon_sym_PLUS_PLUS] = ACTIONS(1919),
    [anon_sym_DASH_DASH] = ACTIONS(1919),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1917),
    [anon_sym_DASH] = ACTIONS(1917),
    [anon_sym_STAR] = ACTIONS(1921),
    [anon_sym_CARET] = ACTIONS(1919),
    [anon_sym_AMP] = ACTIONS(1919),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1923),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1925),
    [anon_sym_DOT_DOT] = ACTIONS(1927),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1076] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6917),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2905),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7007),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5500),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4199),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7447),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9823),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1076),
    [sym_preproc_endregion] = STATE(1076),
    [sym_preproc_line] = STATE(1076),
    [sym_preproc_pragma] = STATE(1076),
    [sym_preproc_nullable] = STATE(1076),
    [sym_preproc_error] = STATE(1076),
    [sym_preproc_warning] = STATE(1076),
    [sym_preproc_define] = STATE(1076),
    [sym_preproc_undef] = STATE(1076),
    [aux_sym_class_declaration_repeat1] = STATE(3822),
    [aux_sym_lambda_expression_repeat1] = STATE(4238),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1623),
    [anon_sym_ref] = ACTIONS(1625),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1577),
    [anon_sym_readonly] = ACTIONS(2767),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1629),
    [anon_sym_TILDE] = ACTIONS(1629),
    [anon_sym_PLUS_PLUS] = ACTIONS(1629),
    [anon_sym_DASH_DASH] = ACTIONS(1629),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1627),
    [anon_sym_DASH] = ACTIONS(1627),
    [anon_sym_STAR] = ACTIONS(1631),
    [anon_sym_CARET] = ACTIONS(1629),
    [anon_sym_AMP] = ACTIONS(1629),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1633),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1635),
    [anon_sym_DOT_DOT] = ACTIONS(1637),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1077] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6941),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2977),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7078),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5649),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4200),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7415),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9773),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1077),
    [sym_preproc_endregion] = STATE(1077),
    [sym_preproc_line] = STATE(1077),
    [sym_preproc_pragma] = STATE(1077),
    [sym_preproc_nullable] = STATE(1077),
    [sym_preproc_error] = STATE(1077),
    [sym_preproc_warning] = STATE(1077),
    [sym_preproc_define] = STATE(1077),
    [sym_preproc_undef] = STATE(1077),
    [aux_sym_class_declaration_repeat1] = STATE(3843),
    [aux_sym_lambda_expression_repeat1] = STATE(4275),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1911),
    [anon_sym_ref] = ACTIONS(1913),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1915),
    [anon_sym_readonly] = ACTIONS(2767),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1919),
    [anon_sym_TILDE] = ACTIONS(1919),
    [anon_sym_PLUS_PLUS] = ACTIONS(1919),
    [anon_sym_DASH_DASH] = ACTIONS(1919),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1917),
    [anon_sym_DASH] = ACTIONS(1917),
    [anon_sym_STAR] = ACTIONS(1921),
    [anon_sym_CARET] = ACTIONS(1919),
    [anon_sym_AMP] = ACTIONS(1919),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1923),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1925),
    [anon_sym_DOT_DOT] = ACTIONS(1927),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1078] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5791),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1078),
    [sym_preproc_endregion] = STATE(1078),
    [sym_preproc_line] = STATE(1078),
    [sym_preproc_pragma] = STATE(1078),
    [sym_preproc_nullable] = STATE(1078),
    [sym_preproc_error] = STATE(1078),
    [sym_preproc_warning] = STATE(1078),
    [sym_preproc_define] = STATE(1078),
    [sym_preproc_undef] = STATE(1078),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_RBRACE] = ACTIONS(2941),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1079] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5871),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1079),
    [sym_preproc_endregion] = STATE(1079),
    [sym_preproc_line] = STATE(1079),
    [sym_preproc_pragma] = STATE(1079),
    [sym_preproc_nullable] = STATE(1079),
    [sym_preproc_error] = STATE(1079),
    [sym_preproc_warning] = STATE(1079),
    [sym_preproc_define] = STATE(1079),
    [sym_preproc_undef] = STATE(1079),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2943),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1080] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3735),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5628),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1080),
    [sym_preproc_endregion] = STATE(1080),
    [sym_preproc_line] = STATE(1080),
    [sym_preproc_pragma] = STATE(1080),
    [sym_preproc_nullable] = STATE(1080),
    [sym_preproc_error] = STATE(1080),
    [sym_preproc_warning] = STATE(1080),
    [sym_preproc_define] = STATE(1080),
    [sym_preproc_undef] = STATE(1080),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1081] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3741),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5630),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1081),
    [sym_preproc_endregion] = STATE(1081),
    [sym_preproc_line] = STATE(1081),
    [sym_preproc_pragma] = STATE(1081),
    [sym_preproc_nullable] = STATE(1081),
    [sym_preproc_error] = STATE(1081),
    [sym_preproc_warning] = STATE(1081),
    [sym_preproc_define] = STATE(1081),
    [sym_preproc_undef] = STATE(1081),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1082] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4021),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6950),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7044),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5132),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3868),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7432),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9127),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1082),
    [sym_preproc_endregion] = STATE(1082),
    [sym_preproc_line] = STATE(1082),
    [sym_preproc_pragma] = STATE(1082),
    [sym_preproc_nullable] = STATE(1082),
    [sym_preproc_error] = STATE(1082),
    [sym_preproc_warning] = STATE(1082),
    [sym_preproc_define] = STATE(1082),
    [sym_preproc_undef] = STATE(1082),
    [aux_sym_class_declaration_repeat1] = STATE(3832),
    [aux_sym_lambda_expression_repeat1] = STATE(4259),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1357),
    [anon_sym_ref] = ACTIONS(1359),
    [anon_sym_LBRACE] = ACTIONS(2835),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1363),
    [anon_sym_TILDE] = ACTIONS(1363),
    [anon_sym_PLUS_PLUS] = ACTIONS(1363),
    [anon_sym_DASH_DASH] = ACTIONS(1363),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1361),
    [anon_sym_DASH] = ACTIONS(1361),
    [anon_sym_STAR] = ACTIONS(1365),
    [anon_sym_CARET] = ACTIONS(1363),
    [anon_sym_AMP] = ACTIONS(1363),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1367),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1369),
    [anon_sym_DOT_DOT] = ACTIONS(1371),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1083] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6920),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2942),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7144),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6531),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4489),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7426),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9002),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1083),
    [sym_preproc_endregion] = STATE(1083),
    [sym_preproc_line] = STATE(1083),
    [sym_preproc_pragma] = STATE(1083),
    [sym_preproc_nullable] = STATE(1083),
    [sym_preproc_error] = STATE(1083),
    [sym_preproc_warning] = STATE(1083),
    [sym_preproc_define] = STATE(1083),
    [sym_preproc_undef] = STATE(1083),
    [aux_sym_class_declaration_repeat1] = STATE(3809),
    [aux_sym_lambda_expression_repeat1] = STATE(4308),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2189),
    [anon_sym_ref] = ACTIONS(2191),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2193),
    [anon_sym_readonly] = ACTIONS(2767),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2197),
    [anon_sym_TILDE] = ACTIONS(2197),
    [anon_sym_PLUS_PLUS] = ACTIONS(2197),
    [anon_sym_DASH_DASH] = ACTIONS(2197),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2195),
    [anon_sym_DASH] = ACTIONS(2195),
    [anon_sym_STAR] = ACTIONS(2199),
    [anon_sym_CARET] = ACTIONS(2197),
    [anon_sym_AMP] = ACTIONS(2197),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2201),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2203),
    [anon_sym_DOT_DOT] = ACTIONS(2205),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1084] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5920),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1084),
    [sym_preproc_endregion] = STATE(1084),
    [sym_preproc_line] = STATE(1084),
    [sym_preproc_pragma] = STATE(1084),
    [sym_preproc_nullable] = STATE(1084),
    [sym_preproc_error] = STATE(1084),
    [sym_preproc_warning] = STATE(1084),
    [sym_preproc_define] = STATE(1084),
    [sym_preproc_undef] = STATE(1084),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2945),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1085] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3763),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7163),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6403),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4473),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9905),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1085),
    [sym_preproc_endregion] = STATE(1085),
    [sym_preproc_line] = STATE(1085),
    [sym_preproc_pragma] = STATE(1085),
    [sym_preproc_nullable] = STATE(1085),
    [sym_preproc_error] = STATE(1085),
    [sym_preproc_warning] = STATE(1085),
    [sym_preproc_define] = STATE(1085),
    [sym_preproc_undef] = STATE(1085),
    [aux_sym_class_declaration_repeat1] = STATE(3878),
    [aux_sym_lambda_expression_repeat1] = STATE(4331),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2055),
    [anon_sym_ref] = ACTIONS(2057),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2061),
    [anon_sym_TILDE] = ACTIONS(2061),
    [anon_sym_PLUS_PLUS] = ACTIONS(2061),
    [anon_sym_DASH_DASH] = ACTIONS(2061),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2059),
    [anon_sym_DASH] = ACTIONS(2059),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(2061),
    [anon_sym_AMP] = ACTIONS(2061),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2063),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2065),
    [anon_sym_DOT_DOT] = ACTIONS(2067),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1086] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3764),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7163),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6405),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4473),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9905),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1086),
    [sym_preproc_endregion] = STATE(1086),
    [sym_preproc_line] = STATE(1086),
    [sym_preproc_pragma] = STATE(1086),
    [sym_preproc_nullable] = STATE(1086),
    [sym_preproc_error] = STATE(1086),
    [sym_preproc_warning] = STATE(1086),
    [sym_preproc_define] = STATE(1086),
    [sym_preproc_undef] = STATE(1086),
    [aux_sym_class_declaration_repeat1] = STATE(3878),
    [aux_sym_lambda_expression_repeat1] = STATE(4331),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2055),
    [anon_sym_ref] = ACTIONS(2057),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2061),
    [anon_sym_TILDE] = ACTIONS(2061),
    [anon_sym_PLUS_PLUS] = ACTIONS(2061),
    [anon_sym_DASH_DASH] = ACTIONS(2061),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2059),
    [anon_sym_DASH] = ACTIONS(2059),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(2061),
    [anon_sym_AMP] = ACTIONS(2061),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2063),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2065),
    [anon_sym_DOT_DOT] = ACTIONS(2067),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1087] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4677),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6911),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2930),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7031),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4808),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3742),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7420),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9374),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(1087),
    [sym_preproc_endregion] = STATE(1087),
    [sym_preproc_line] = STATE(1087),
    [sym_preproc_pragma] = STATE(1087),
    [sym_preproc_nullable] = STATE(1087),
    [sym_preproc_error] = STATE(1087),
    [sym_preproc_warning] = STATE(1087),
    [sym_preproc_define] = STATE(1087),
    [sym_preproc_undef] = STATE(1087),
    [aux_sym_class_declaration_repeat1] = STATE(3861),
    [aux_sym_lambda_expression_repeat1] = STATE(4169),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(2089),
    [anon_sym_ref] = ACTIONS(2091),
    [anon_sym_LBRACE] = ACTIONS(2847),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1695),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(2095),
    [anon_sym_TILDE] = ACTIONS(2095),
    [anon_sym_PLUS_PLUS] = ACTIONS(2095),
    [anon_sym_DASH_DASH] = ACTIONS(2095),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(2093),
    [anon_sym_DASH] = ACTIONS(2093),
    [anon_sym_STAR] = ACTIONS(1705),
    [anon_sym_CARET] = ACTIONS(2095),
    [anon_sym_AMP] = ACTIONS(2095),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(2097),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2099),
    [anon_sym_DOT_DOT] = ACTIONS(2101),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [1088] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3780),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7163),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6406),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4473),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9905),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1088),
    [sym_preproc_endregion] = STATE(1088),
    [sym_preproc_line] = STATE(1088),
    [sym_preproc_pragma] = STATE(1088),
    [sym_preproc_nullable] = STATE(1088),
    [sym_preproc_error] = STATE(1088),
    [sym_preproc_warning] = STATE(1088),
    [sym_preproc_define] = STATE(1088),
    [sym_preproc_undef] = STATE(1088),
    [aux_sym_class_declaration_repeat1] = STATE(3878),
    [aux_sym_lambda_expression_repeat1] = STATE(4331),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2055),
    [anon_sym_ref] = ACTIONS(2057),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2061),
    [anon_sym_TILDE] = ACTIONS(2061),
    [anon_sym_PLUS_PLUS] = ACTIONS(2061),
    [anon_sym_DASH_DASH] = ACTIONS(2061),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2059),
    [anon_sym_DASH] = ACTIONS(2059),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(2061),
    [anon_sym_AMP] = ACTIONS(2061),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2063),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2065),
    [anon_sym_DOT_DOT] = ACTIONS(2067),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1089] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3735),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7163),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6411),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4473),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9905),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1089),
    [sym_preproc_endregion] = STATE(1089),
    [sym_preproc_line] = STATE(1089),
    [sym_preproc_pragma] = STATE(1089),
    [sym_preproc_nullable] = STATE(1089),
    [sym_preproc_error] = STATE(1089),
    [sym_preproc_warning] = STATE(1089),
    [sym_preproc_define] = STATE(1089),
    [sym_preproc_undef] = STATE(1089),
    [aux_sym_class_declaration_repeat1] = STATE(3878),
    [aux_sym_lambda_expression_repeat1] = STATE(4331),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2055),
    [anon_sym_ref] = ACTIONS(2057),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2061),
    [anon_sym_TILDE] = ACTIONS(2061),
    [anon_sym_PLUS_PLUS] = ACTIONS(2061),
    [anon_sym_DASH_DASH] = ACTIONS(2061),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2059),
    [anon_sym_DASH] = ACTIONS(2059),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(2061),
    [anon_sym_AMP] = ACTIONS(2061),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2063),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2065),
    [anon_sym_DOT_DOT] = ACTIONS(2067),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1090] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3741),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7163),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6412),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4473),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9905),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1090),
    [sym_preproc_endregion] = STATE(1090),
    [sym_preproc_line] = STATE(1090),
    [sym_preproc_pragma] = STATE(1090),
    [sym_preproc_nullable] = STATE(1090),
    [sym_preproc_error] = STATE(1090),
    [sym_preproc_warning] = STATE(1090),
    [sym_preproc_define] = STATE(1090),
    [sym_preproc_undef] = STATE(1090),
    [aux_sym_class_declaration_repeat1] = STATE(3878),
    [aux_sym_lambda_expression_repeat1] = STATE(4331),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2055),
    [anon_sym_ref] = ACTIONS(2057),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2061),
    [anon_sym_TILDE] = ACTIONS(2061),
    [anon_sym_PLUS_PLUS] = ACTIONS(2061),
    [anon_sym_DASH_DASH] = ACTIONS(2061),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2059),
    [anon_sym_DASH] = ACTIONS(2059),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(2061),
    [anon_sym_AMP] = ACTIONS(2061),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2063),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2065),
    [anon_sym_DOT_DOT] = ACTIONS(2067),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1091] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3754),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7163),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6414),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4473),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9905),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1091),
    [sym_preproc_endregion] = STATE(1091),
    [sym_preproc_line] = STATE(1091),
    [sym_preproc_pragma] = STATE(1091),
    [sym_preproc_nullable] = STATE(1091),
    [sym_preproc_error] = STATE(1091),
    [sym_preproc_warning] = STATE(1091),
    [sym_preproc_define] = STATE(1091),
    [sym_preproc_undef] = STATE(1091),
    [aux_sym_class_declaration_repeat1] = STATE(3878),
    [aux_sym_lambda_expression_repeat1] = STATE(4331),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2055),
    [anon_sym_ref] = ACTIONS(2057),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2061),
    [anon_sym_TILDE] = ACTIONS(2061),
    [anon_sym_PLUS_PLUS] = ACTIONS(2061),
    [anon_sym_DASH_DASH] = ACTIONS(2061),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2059),
    [anon_sym_DASH] = ACTIONS(2059),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(2061),
    [anon_sym_AMP] = ACTIONS(2061),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2063),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2065),
    [anon_sym_DOT_DOT] = ACTIONS(2067),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1092] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4101),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6962),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5236),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3931),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9818),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1092),
    [sym_preproc_endregion] = STATE(1092),
    [sym_preproc_line] = STATE(1092),
    [sym_preproc_pragma] = STATE(1092),
    [sym_preproc_nullable] = STATE(1092),
    [sym_preproc_error] = STATE(1092),
    [sym_preproc_warning] = STATE(1092),
    [sym_preproc_define] = STATE(1092),
    [sym_preproc_undef] = STATE(1092),
    [aux_sym_class_declaration_repeat1] = STATE(3811),
    [aux_sym_lambda_expression_repeat1] = STATE(4201),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1373),
    [anon_sym_ref] = ACTIONS(1375),
    [anon_sym_LBRACE] = ACTIONS(2831),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1379),
    [anon_sym_TILDE] = ACTIONS(1379),
    [anon_sym_PLUS_PLUS] = ACTIONS(1379),
    [anon_sym_DASH_DASH] = ACTIONS(1379),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1377),
    [anon_sym_DASH] = ACTIONS(1377),
    [anon_sym_STAR] = ACTIONS(1381),
    [anon_sym_CARET] = ACTIONS(1379),
    [anon_sym_AMP] = ACTIONS(1379),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1383),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1385),
    [anon_sym_DOT_DOT] = ACTIONS(1387),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1093] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6039),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1093),
    [sym_preproc_endregion] = STATE(1093),
    [sym_preproc_line] = STATE(1093),
    [sym_preproc_pragma] = STATE(1093),
    [sym_preproc_nullable] = STATE(1093),
    [sym_preproc_error] = STATE(1093),
    [sym_preproc_warning] = STATE(1093),
    [sym_preproc_define] = STATE(1093),
    [sym_preproc_undef] = STATE(1093),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2947),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1094] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6730),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2801),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6731),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5652),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1094),
    [sym_preproc_endregion] = STATE(1094),
    [sym_preproc_line] = STATE(1094),
    [sym_preproc_pragma] = STATE(1094),
    [sym_preproc_nullable] = STATE(1094),
    [sym_preproc_error] = STATE(1094),
    [sym_preproc_warning] = STATE(1094),
    [sym_preproc_define] = STATE(1094),
    [sym_preproc_undef] = STATE(1094),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(2737),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(2739),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(1089),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2727),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1095] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7165),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6590),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4473),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9905),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1095),
    [sym_preproc_endregion] = STATE(1095),
    [sym_preproc_line] = STATE(1095),
    [sym_preproc_pragma] = STATE(1095),
    [sym_preproc_nullable] = STATE(1095),
    [sym_preproc_error] = STATE(1095),
    [sym_preproc_warning] = STATE(1095),
    [sym_preproc_define] = STATE(1095),
    [sym_preproc_undef] = STATE(1095),
    [aux_sym_class_declaration_repeat1] = STATE(3878),
    [aux_sym_lambda_expression_repeat1] = STATE(4331),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2055),
    [anon_sym_ref] = ACTIONS(2057),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(2767),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2061),
    [anon_sym_TILDE] = ACTIONS(2061),
    [anon_sym_PLUS_PLUS] = ACTIONS(2061),
    [anon_sym_DASH_DASH] = ACTIONS(2061),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2059),
    [anon_sym_DASH] = ACTIONS(2059),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(2061),
    [anon_sym_AMP] = ACTIONS(2061),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2063),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2065),
    [anon_sym_DOT_DOT] = ACTIONS(2067),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1096] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5978),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1096),
    [sym_preproc_endregion] = STATE(1096),
    [sym_preproc_line] = STATE(1096),
    [sym_preproc_pragma] = STATE(1096),
    [sym_preproc_nullable] = STATE(1096),
    [sym_preproc_error] = STATE(1096),
    [sym_preproc_warning] = STATE(1096),
    [sym_preproc_define] = STATE(1096),
    [sym_preproc_undef] = STATE(1096),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2949),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1097] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5822),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1097),
    [sym_preproc_endregion] = STATE(1097),
    [sym_preproc_line] = STATE(1097),
    [sym_preproc_pragma] = STATE(1097),
    [sym_preproc_nullable] = STATE(1097),
    [sym_preproc_error] = STATE(1097),
    [sym_preproc_warning] = STATE(1097),
    [sym_preproc_define] = STATE(1097),
    [sym_preproc_undef] = STATE(1097),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2951),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1098] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4102),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6962),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5239),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3931),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9818),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1098),
    [sym_preproc_endregion] = STATE(1098),
    [sym_preproc_line] = STATE(1098),
    [sym_preproc_pragma] = STATE(1098),
    [sym_preproc_nullable] = STATE(1098),
    [sym_preproc_error] = STATE(1098),
    [sym_preproc_warning] = STATE(1098),
    [sym_preproc_define] = STATE(1098),
    [sym_preproc_undef] = STATE(1098),
    [aux_sym_class_declaration_repeat1] = STATE(3811),
    [aux_sym_lambda_expression_repeat1] = STATE(4201),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1373),
    [anon_sym_ref] = ACTIONS(1375),
    [anon_sym_LBRACE] = ACTIONS(2831),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1379),
    [anon_sym_TILDE] = ACTIONS(1379),
    [anon_sym_PLUS_PLUS] = ACTIONS(1379),
    [anon_sym_DASH_DASH] = ACTIONS(1379),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1377),
    [anon_sym_DASH] = ACTIONS(1377),
    [anon_sym_STAR] = ACTIONS(1381),
    [anon_sym_CARET] = ACTIONS(1379),
    [anon_sym_AMP] = ACTIONS(1379),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1383),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1385),
    [anon_sym_DOT_DOT] = ACTIONS(1387),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1099] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4111),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6962),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5142),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3931),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9818),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1099),
    [sym_preproc_endregion] = STATE(1099),
    [sym_preproc_line] = STATE(1099),
    [sym_preproc_pragma] = STATE(1099),
    [sym_preproc_nullable] = STATE(1099),
    [sym_preproc_error] = STATE(1099),
    [sym_preproc_warning] = STATE(1099),
    [sym_preproc_define] = STATE(1099),
    [sym_preproc_undef] = STATE(1099),
    [aux_sym_class_declaration_repeat1] = STATE(3811),
    [aux_sym_lambda_expression_repeat1] = STATE(4201),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1373),
    [anon_sym_ref] = ACTIONS(1375),
    [anon_sym_LBRACE] = ACTIONS(2831),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1379),
    [anon_sym_TILDE] = ACTIONS(1379),
    [anon_sym_PLUS_PLUS] = ACTIONS(1379),
    [anon_sym_DASH_DASH] = ACTIONS(1379),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1377),
    [anon_sym_DASH] = ACTIONS(1377),
    [anon_sym_STAR] = ACTIONS(1381),
    [anon_sym_CARET] = ACTIONS(1379),
    [anon_sym_AMP] = ACTIONS(1379),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1383),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1385),
    [anon_sym_DOT_DOT] = ACTIONS(1387),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1100] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6956),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6559),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9482),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1100),
    [sym_preproc_endregion] = STATE(1100),
    [sym_preproc_line] = STATE(1100),
    [sym_preproc_pragma] = STATE(1100),
    [sym_preproc_nullable] = STATE(1100),
    [sym_preproc_error] = STATE(1100),
    [sym_preproc_warning] = STATE(1100),
    [sym_preproc_define] = STATE(1100),
    [sym_preproc_undef] = STATE(1100),
    [aux_sym_class_declaration_repeat1] = STATE(3853),
    [aux_sym_lambda_expression_repeat1] = STATE(4299),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(2953),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1497),
    [anon_sym_ref] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1505),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1507),
    [anon_sym_DOT_DOT] = ACTIONS(1509),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1101] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(3025),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2760),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(2855),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_expression] = STATE(6045),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2835),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1101),
    [sym_preproc_endregion] = STATE(1101),
    [sym_preproc_line] = STATE(1101),
    [sym_preproc_pragma] = STATE(1101),
    [sym_preproc_nullable] = STATE(1101),
    [sym_preproc_error] = STATE(1101),
    [sym_preproc_warning] = STATE(1101),
    [sym_preproc_define] = STATE(1101),
    [sym_preproc_undef] = STATE(1101),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2839),
    [anon_sym_ref] = ACTIONS(2467),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_readonly] = ACTIONS(2865),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2335),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2955),
    [sym_predefined_type] = ACTIONS(2339),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1102] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3637),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6955),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2975),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7120),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4769),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3789),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7416),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9625),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1102),
    [sym_preproc_endregion] = STATE(1102),
    [sym_preproc_line] = STATE(1102),
    [sym_preproc_pragma] = STATE(1102),
    [sym_preproc_nullable] = STATE(1102),
    [sym_preproc_error] = STATE(1102),
    [sym_preproc_warning] = STATE(1102),
    [sym_preproc_define] = STATE(1102),
    [sym_preproc_undef] = STATE(1102),
    [aux_sym_class_declaration_repeat1] = STATE(3864),
    [aux_sym_lambda_expression_repeat1] = STATE(4297),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1929),
    [anon_sym_ref] = ACTIONS(1931),
    [anon_sym_LBRACE] = ACTIONS(2825),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1933),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1937),
    [anon_sym_TILDE] = ACTIONS(1937),
    [anon_sym_PLUS_PLUS] = ACTIONS(1937),
    [anon_sym_DASH_DASH] = ACTIONS(1937),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1935),
    [anon_sym_DASH] = ACTIONS(1935),
    [anon_sym_STAR] = ACTIONS(1939),
    [anon_sym_CARET] = ACTIONS(1937),
    [anon_sym_AMP] = ACTIONS(1937),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1941),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1943),
    [anon_sym_DOT_DOT] = ACTIONS(1945),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1103] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3714),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6955),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2975),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7120),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4770),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3789),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7416),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9625),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1103),
    [sym_preproc_endregion] = STATE(1103),
    [sym_preproc_line] = STATE(1103),
    [sym_preproc_pragma] = STATE(1103),
    [sym_preproc_nullable] = STATE(1103),
    [sym_preproc_error] = STATE(1103),
    [sym_preproc_warning] = STATE(1103),
    [sym_preproc_define] = STATE(1103),
    [sym_preproc_undef] = STATE(1103),
    [aux_sym_class_declaration_repeat1] = STATE(3864),
    [aux_sym_lambda_expression_repeat1] = STATE(4297),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1929),
    [anon_sym_ref] = ACTIONS(1931),
    [anon_sym_LBRACE] = ACTIONS(2825),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1933),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1937),
    [anon_sym_TILDE] = ACTIONS(1937),
    [anon_sym_PLUS_PLUS] = ACTIONS(1937),
    [anon_sym_DASH_DASH] = ACTIONS(1937),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1935),
    [anon_sym_DASH] = ACTIONS(1935),
    [anon_sym_STAR] = ACTIONS(1939),
    [anon_sym_CARET] = ACTIONS(1937),
    [anon_sym_AMP] = ACTIONS(1937),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1941),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1943),
    [anon_sym_DOT_DOT] = ACTIONS(1945),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1104] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3641),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6955),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2975),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7120),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4771),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3789),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7416),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9625),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1104),
    [sym_preproc_endregion] = STATE(1104),
    [sym_preproc_line] = STATE(1104),
    [sym_preproc_pragma] = STATE(1104),
    [sym_preproc_nullable] = STATE(1104),
    [sym_preproc_error] = STATE(1104),
    [sym_preproc_warning] = STATE(1104),
    [sym_preproc_define] = STATE(1104),
    [sym_preproc_undef] = STATE(1104),
    [aux_sym_class_declaration_repeat1] = STATE(3864),
    [aux_sym_lambda_expression_repeat1] = STATE(4297),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1929),
    [anon_sym_ref] = ACTIONS(1931),
    [anon_sym_LBRACE] = ACTIONS(2825),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1933),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1937),
    [anon_sym_TILDE] = ACTIONS(1937),
    [anon_sym_PLUS_PLUS] = ACTIONS(1937),
    [anon_sym_DASH_DASH] = ACTIONS(1937),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1935),
    [anon_sym_DASH] = ACTIONS(1935),
    [anon_sym_STAR] = ACTIONS(1939),
    [anon_sym_CARET] = ACTIONS(1937),
    [anon_sym_AMP] = ACTIONS(1937),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1941),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1943),
    [anon_sym_DOT_DOT] = ACTIONS(1945),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1105] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3689),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6955),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2975),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7120),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4773),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3789),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7416),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9625),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1105),
    [sym_preproc_endregion] = STATE(1105),
    [sym_preproc_line] = STATE(1105),
    [sym_preproc_pragma] = STATE(1105),
    [sym_preproc_nullable] = STATE(1105),
    [sym_preproc_error] = STATE(1105),
    [sym_preproc_warning] = STATE(1105),
    [sym_preproc_define] = STATE(1105),
    [sym_preproc_undef] = STATE(1105),
    [aux_sym_class_declaration_repeat1] = STATE(3864),
    [aux_sym_lambda_expression_repeat1] = STATE(4297),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1929),
    [anon_sym_ref] = ACTIONS(1931),
    [anon_sym_LBRACE] = ACTIONS(2825),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1933),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1937),
    [anon_sym_TILDE] = ACTIONS(1937),
    [anon_sym_PLUS_PLUS] = ACTIONS(1937),
    [anon_sym_DASH_DASH] = ACTIONS(1937),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1935),
    [anon_sym_DASH] = ACTIONS(1935),
    [anon_sym_STAR] = ACTIONS(1939),
    [anon_sym_CARET] = ACTIONS(1937),
    [anon_sym_AMP] = ACTIONS(1937),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1941),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1943),
    [anon_sym_DOT_DOT] = ACTIONS(1945),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1106] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3692),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6955),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2975),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7120),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4774),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3789),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7416),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9625),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1106),
    [sym_preproc_endregion] = STATE(1106),
    [sym_preproc_line] = STATE(1106),
    [sym_preproc_pragma] = STATE(1106),
    [sym_preproc_nullable] = STATE(1106),
    [sym_preproc_error] = STATE(1106),
    [sym_preproc_warning] = STATE(1106),
    [sym_preproc_define] = STATE(1106),
    [sym_preproc_undef] = STATE(1106),
    [aux_sym_class_declaration_repeat1] = STATE(3864),
    [aux_sym_lambda_expression_repeat1] = STATE(4297),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1929),
    [anon_sym_ref] = ACTIONS(1931),
    [anon_sym_LBRACE] = ACTIONS(2825),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1933),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1937),
    [anon_sym_TILDE] = ACTIONS(1937),
    [anon_sym_PLUS_PLUS] = ACTIONS(1937),
    [anon_sym_DASH_DASH] = ACTIONS(1937),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1935),
    [anon_sym_DASH] = ACTIONS(1935),
    [anon_sym_STAR] = ACTIONS(1939),
    [anon_sym_CARET] = ACTIONS(1937),
    [anon_sym_AMP] = ACTIONS(1937),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1941),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1943),
    [anon_sym_DOT_DOT] = ACTIONS(1945),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1107] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3708),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6955),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2975),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7120),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4775),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3789),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7416),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9625),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1107),
    [sym_preproc_endregion] = STATE(1107),
    [sym_preproc_line] = STATE(1107),
    [sym_preproc_pragma] = STATE(1107),
    [sym_preproc_nullable] = STATE(1107),
    [sym_preproc_error] = STATE(1107),
    [sym_preproc_warning] = STATE(1107),
    [sym_preproc_define] = STATE(1107),
    [sym_preproc_undef] = STATE(1107),
    [aux_sym_class_declaration_repeat1] = STATE(3864),
    [aux_sym_lambda_expression_repeat1] = STATE(4297),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1929),
    [anon_sym_ref] = ACTIONS(1931),
    [anon_sym_LBRACE] = ACTIONS(2825),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1933),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1937),
    [anon_sym_TILDE] = ACTIONS(1937),
    [anon_sym_PLUS_PLUS] = ACTIONS(1937),
    [anon_sym_DASH_DASH] = ACTIONS(1937),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1935),
    [anon_sym_DASH] = ACTIONS(1935),
    [anon_sym_STAR] = ACTIONS(1939),
    [anon_sym_CARET] = ACTIONS(1937),
    [anon_sym_AMP] = ACTIONS(1937),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1941),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1943),
    [anon_sym_DOT_DOT] = ACTIONS(1945),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1108] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6955),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2975),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7121),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4835),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3789),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7416),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9625),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1108),
    [sym_preproc_endregion] = STATE(1108),
    [sym_preproc_line] = STATE(1108),
    [sym_preproc_pragma] = STATE(1108),
    [sym_preproc_nullable] = STATE(1108),
    [sym_preproc_error] = STATE(1108),
    [sym_preproc_warning] = STATE(1108),
    [sym_preproc_define] = STATE(1108),
    [sym_preproc_undef] = STATE(1108),
    [aux_sym_class_declaration_repeat1] = STATE(3864),
    [aux_sym_lambda_expression_repeat1] = STATE(4297),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1929),
    [anon_sym_ref] = ACTIONS(1931),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1933),
    [anon_sym_readonly] = ACTIONS(2767),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1937),
    [anon_sym_TILDE] = ACTIONS(1937),
    [anon_sym_PLUS_PLUS] = ACTIONS(1937),
    [anon_sym_DASH_DASH] = ACTIONS(1937),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1935),
    [anon_sym_DASH] = ACTIONS(1935),
    [anon_sym_STAR] = ACTIONS(1939),
    [anon_sym_CARET] = ACTIONS(1937),
    [anon_sym_AMP] = ACTIONS(1937),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1941),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1943),
    [anon_sym_DOT_DOT] = ACTIONS(1945),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1109] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6956),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6352),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9482),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1109),
    [sym_preproc_endregion] = STATE(1109),
    [sym_preproc_line] = STATE(1109),
    [sym_preproc_pragma] = STATE(1109),
    [sym_preproc_nullable] = STATE(1109),
    [sym_preproc_error] = STATE(1109),
    [sym_preproc_warning] = STATE(1109),
    [sym_preproc_define] = STATE(1109),
    [sym_preproc_undef] = STATE(1109),
    [aux_sym_class_declaration_repeat1] = STATE(3853),
    [aux_sym_lambda_expression_repeat1] = STATE(4299),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(2957),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1497),
    [anon_sym_ref] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1505),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1507),
    [anon_sym_DOT_DOT] = ACTIONS(1509),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1110] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4671),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6911),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2930),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7031),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4825),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3742),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7420),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9374),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(1110),
    [sym_preproc_endregion] = STATE(1110),
    [sym_preproc_line] = STATE(1110),
    [sym_preproc_pragma] = STATE(1110),
    [sym_preproc_nullable] = STATE(1110),
    [sym_preproc_error] = STATE(1110),
    [sym_preproc_warning] = STATE(1110),
    [sym_preproc_define] = STATE(1110),
    [sym_preproc_undef] = STATE(1110),
    [aux_sym_class_declaration_repeat1] = STATE(3861),
    [aux_sym_lambda_expression_repeat1] = STATE(4169),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(2089),
    [anon_sym_ref] = ACTIONS(2091),
    [anon_sym_LBRACE] = ACTIONS(2847),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1695),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(2095),
    [anon_sym_TILDE] = ACTIONS(2095),
    [anon_sym_PLUS_PLUS] = ACTIONS(2095),
    [anon_sym_DASH_DASH] = ACTIONS(2095),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(2093),
    [anon_sym_DASH] = ACTIONS(2093),
    [anon_sym_STAR] = ACTIONS(1705),
    [anon_sym_CARET] = ACTIONS(2095),
    [anon_sym_AMP] = ACTIONS(2095),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(2097),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2099),
    [anon_sym_DOT_DOT] = ACTIONS(2101),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [1111] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6921),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2873),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(6958),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5792),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4346),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7445),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9875),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(1111),
    [sym_preproc_endregion] = STATE(1111),
    [sym_preproc_line] = STATE(1111),
    [sym_preproc_pragma] = STATE(1111),
    [sym_preproc_nullable] = STATE(1111),
    [sym_preproc_error] = STATE(1111),
    [sym_preproc_warning] = STATE(1111),
    [sym_preproc_define] = STATE(1111),
    [sym_preproc_undef] = STATE(1111),
    [aux_sym_class_declaration_repeat1] = STATE(3810),
    [aux_sym_lambda_expression_repeat1] = STATE(4192),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1639),
    [anon_sym_ref] = ACTIONS(1641),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1415),
    [anon_sym_readonly] = ACTIONS(2767),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1645),
    [anon_sym_TILDE] = ACTIONS(1645),
    [anon_sym_PLUS_PLUS] = ACTIONS(1645),
    [anon_sym_DASH_DASH] = ACTIONS(1645),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1643),
    [anon_sym_DASH] = ACTIONS(1643),
    [anon_sym_STAR] = ACTIONS(1425),
    [anon_sym_CARET] = ACTIONS(1645),
    [anon_sym_AMP] = ACTIONS(1645),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1647),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1649),
    [anon_sym_DOT_DOT] = ACTIONS(1651),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [1112] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3735),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7131),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6004),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4364),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9470),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1112),
    [sym_preproc_endregion] = STATE(1112),
    [sym_preproc_line] = STATE(1112),
    [sym_preproc_pragma] = STATE(1112),
    [sym_preproc_nullable] = STATE(1112),
    [sym_preproc_error] = STATE(1112),
    [sym_preproc_warning] = STATE(1112),
    [sym_preproc_define] = STATE(1112),
    [sym_preproc_undef] = STATE(1112),
    [aux_sym_class_declaration_repeat1] = STATE(3870),
    [aux_sym_lambda_expression_repeat1] = STATE(4302),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1555),
    [anon_sym_ref] = ACTIONS(1557),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(695),
    [anon_sym_TILDE] = ACTIONS(695),
    [anon_sym_PLUS_PLUS] = ACTIONS(695),
    [anon_sym_DASH_DASH] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(697),
    [anon_sym_DASH] = ACTIONS(697),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(695),
    [anon_sym_AMP] = ACTIONS(695),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1559),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1561),
    [anon_sym_DOT_DOT] = ACTIONS(1563),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1113] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5957),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1113),
    [sym_preproc_endregion] = STATE(1113),
    [sym_preproc_line] = STATE(1113),
    [sym_preproc_pragma] = STATE(1113),
    [sym_preproc_nullable] = STATE(1113),
    [sym_preproc_error] = STATE(1113),
    [sym_preproc_warning] = STATE(1113),
    [sym_preproc_define] = STATE(1113),
    [sym_preproc_undef] = STATE(1113),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2959),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1114] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5958),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1114),
    [sym_preproc_endregion] = STATE(1114),
    [sym_preproc_line] = STATE(1114),
    [sym_preproc_pragma] = STATE(1114),
    [sym_preproc_nullable] = STATE(1114),
    [sym_preproc_error] = STATE(1114),
    [sym_preproc_warning] = STATE(1114),
    [sym_preproc_define] = STATE(1114),
    [sym_preproc_undef] = STATE(1114),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2961),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1115] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3763),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6920),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2942),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7143),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6682),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4489),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7426),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9002),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1115),
    [sym_preproc_endregion] = STATE(1115),
    [sym_preproc_line] = STATE(1115),
    [sym_preproc_pragma] = STATE(1115),
    [sym_preproc_nullable] = STATE(1115),
    [sym_preproc_error] = STATE(1115),
    [sym_preproc_warning] = STATE(1115),
    [sym_preproc_define] = STATE(1115),
    [sym_preproc_undef] = STATE(1115),
    [aux_sym_class_declaration_repeat1] = STATE(3809),
    [aux_sym_lambda_expression_repeat1] = STATE(4308),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2189),
    [anon_sym_ref] = ACTIONS(2191),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2193),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2197),
    [anon_sym_TILDE] = ACTIONS(2197),
    [anon_sym_PLUS_PLUS] = ACTIONS(2197),
    [anon_sym_DASH_DASH] = ACTIONS(2197),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2195),
    [anon_sym_DASH] = ACTIONS(2195),
    [anon_sym_STAR] = ACTIONS(2199),
    [anon_sym_CARET] = ACTIONS(2197),
    [anon_sym_AMP] = ACTIONS(2197),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2201),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2203),
    [anon_sym_DOT_DOT] = ACTIONS(2205),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1116] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3741),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7131),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6016),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4364),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9470),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1116),
    [sym_preproc_endregion] = STATE(1116),
    [sym_preproc_line] = STATE(1116),
    [sym_preproc_pragma] = STATE(1116),
    [sym_preproc_nullable] = STATE(1116),
    [sym_preproc_error] = STATE(1116),
    [sym_preproc_warning] = STATE(1116),
    [sym_preproc_define] = STATE(1116),
    [sym_preproc_undef] = STATE(1116),
    [aux_sym_class_declaration_repeat1] = STATE(3870),
    [aux_sym_lambda_expression_repeat1] = STATE(4302),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1555),
    [anon_sym_ref] = ACTIONS(1557),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(695),
    [anon_sym_TILDE] = ACTIONS(695),
    [anon_sym_PLUS_PLUS] = ACTIONS(695),
    [anon_sym_DASH_DASH] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(697),
    [anon_sym_DASH] = ACTIONS(697),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(695),
    [anon_sym_AMP] = ACTIONS(695),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1559),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1561),
    [anon_sym_DOT_DOT] = ACTIONS(1563),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1117] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5791),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1117),
    [sym_preproc_endregion] = STATE(1117),
    [sym_preproc_line] = STATE(1117),
    [sym_preproc_pragma] = STATE(1117),
    [sym_preproc_nullable] = STATE(1117),
    [sym_preproc_error] = STATE(1117),
    [sym_preproc_warning] = STATE(1117),
    [sym_preproc_define] = STATE(1117),
    [sym_preproc_undef] = STATE(1117),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_RBRACE] = ACTIONS(2963),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1118] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3764),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6920),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2942),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7143),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6689),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4489),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7426),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9002),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1118),
    [sym_preproc_endregion] = STATE(1118),
    [sym_preproc_line] = STATE(1118),
    [sym_preproc_pragma] = STATE(1118),
    [sym_preproc_nullable] = STATE(1118),
    [sym_preproc_error] = STATE(1118),
    [sym_preproc_warning] = STATE(1118),
    [sym_preproc_define] = STATE(1118),
    [sym_preproc_undef] = STATE(1118),
    [aux_sym_class_declaration_repeat1] = STATE(3809),
    [aux_sym_lambda_expression_repeat1] = STATE(4308),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2189),
    [anon_sym_ref] = ACTIONS(2191),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2193),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2197),
    [anon_sym_TILDE] = ACTIONS(2197),
    [anon_sym_PLUS_PLUS] = ACTIONS(2197),
    [anon_sym_DASH_DASH] = ACTIONS(2197),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2195),
    [anon_sym_DASH] = ACTIONS(2195),
    [anon_sym_STAR] = ACTIONS(2199),
    [anon_sym_CARET] = ACTIONS(2197),
    [anon_sym_AMP] = ACTIONS(2197),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2201),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2203),
    [anon_sym_DOT_DOT] = ACTIONS(2205),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1119] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3991),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6915),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7018),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4544),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3585),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7418),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9926),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1119),
    [sym_preproc_endregion] = STATE(1119),
    [sym_preproc_line] = STATE(1119),
    [sym_preproc_pragma] = STATE(1119),
    [sym_preproc_nullable] = STATE(1119),
    [sym_preproc_error] = STATE(1119),
    [sym_preproc_warning] = STATE(1119),
    [sym_preproc_define] = STATE(1119),
    [sym_preproc_undef] = STATE(1119),
    [aux_sym_class_declaration_repeat1] = STATE(3825),
    [aux_sym_lambda_expression_repeat1] = STATE(4244),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1161),
    [anon_sym_ref] = ACTIONS(1163),
    [anon_sym_LBRACE] = ACTIONS(2835),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1177),
    [anon_sym_TILDE] = ACTIONS(1177),
    [anon_sym_PLUS_PLUS] = ACTIONS(1177),
    [anon_sym_DASH_DASH] = ACTIONS(1177),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1175),
    [anon_sym_DASH] = ACTIONS(1175),
    [anon_sym_STAR] = ACTIONS(1181),
    [anon_sym_CARET] = ACTIONS(1177),
    [anon_sym_AMP] = ACTIONS(1177),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1191),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1193),
    [anon_sym_DOT_DOT] = ACTIONS(1195),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1120] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4060),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6950),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7044),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5133),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3868),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7432),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9127),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1120),
    [sym_preproc_endregion] = STATE(1120),
    [sym_preproc_line] = STATE(1120),
    [sym_preproc_pragma] = STATE(1120),
    [sym_preproc_nullable] = STATE(1120),
    [sym_preproc_error] = STATE(1120),
    [sym_preproc_warning] = STATE(1120),
    [sym_preproc_define] = STATE(1120),
    [sym_preproc_undef] = STATE(1120),
    [aux_sym_class_declaration_repeat1] = STATE(3832),
    [aux_sym_lambda_expression_repeat1] = STATE(4259),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1357),
    [anon_sym_ref] = ACTIONS(1359),
    [anon_sym_LBRACE] = ACTIONS(2835),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1363),
    [anon_sym_TILDE] = ACTIONS(1363),
    [anon_sym_PLUS_PLUS] = ACTIONS(1363),
    [anon_sym_DASH_DASH] = ACTIONS(1363),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1361),
    [anon_sym_DASH] = ACTIONS(1361),
    [anon_sym_STAR] = ACTIONS(1365),
    [anon_sym_CARET] = ACTIONS(1363),
    [anon_sym_AMP] = ACTIONS(1363),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1367),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1369),
    [anon_sym_DOT_DOT] = ACTIONS(1371),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1121] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3754),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6948),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2940),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6999),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5056),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3857),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7444),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9574),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1121),
    [sym_preproc_endregion] = STATE(1121),
    [sym_preproc_line] = STATE(1121),
    [sym_preproc_pragma] = STATE(1121),
    [sym_preproc_nullable] = STATE(1121),
    [sym_preproc_error] = STATE(1121),
    [sym_preproc_warning] = STATE(1121),
    [sym_preproc_define] = STATE(1121),
    [sym_preproc_undef] = STATE(1121),
    [aux_sym_class_declaration_repeat1] = STATE(3854),
    [aux_sym_lambda_expression_repeat1] = STATE(4136),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2111),
    [anon_sym_ref] = ACTIONS(2113),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1897),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2117),
    [anon_sym_TILDE] = ACTIONS(2117),
    [anon_sym_PLUS_PLUS] = ACTIONS(2117),
    [anon_sym_DASH_DASH] = ACTIONS(2117),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2115),
    [anon_sym_DASH] = ACTIONS(2115),
    [anon_sym_STAR] = ACTIONS(1903),
    [anon_sym_CARET] = ACTIONS(2117),
    [anon_sym_AMP] = ACTIONS(2117),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2119),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2121),
    [anon_sym_DOT_DOT] = ACTIONS(2123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1122] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6964),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6066),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_declaration_expression] = STATE(8686),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1122),
    [sym_preproc_endregion] = STATE(1122),
    [sym_preproc_line] = STATE(1122),
    [sym_preproc_pragma] = STATE(1122),
    [sym_preproc_nullable] = STATE(1122),
    [sym_preproc_error] = STATE(1122),
    [sym_preproc_warning] = STATE(1122),
    [sym_preproc_define] = STATE(1122),
    [sym_preproc_undef] = STATE(1122),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1123] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3780),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6920),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2942),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7143),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6315),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4489),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7426),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9002),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1123),
    [sym_preproc_endregion] = STATE(1123),
    [sym_preproc_line] = STATE(1123),
    [sym_preproc_pragma] = STATE(1123),
    [sym_preproc_nullable] = STATE(1123),
    [sym_preproc_error] = STATE(1123),
    [sym_preproc_warning] = STATE(1123),
    [sym_preproc_define] = STATE(1123),
    [sym_preproc_undef] = STATE(1123),
    [aux_sym_class_declaration_repeat1] = STATE(3809),
    [aux_sym_lambda_expression_repeat1] = STATE(4308),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2189),
    [anon_sym_ref] = ACTIONS(2191),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2193),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2197),
    [anon_sym_TILDE] = ACTIONS(2197),
    [anon_sym_PLUS_PLUS] = ACTIONS(2197),
    [anon_sym_DASH_DASH] = ACTIONS(2197),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2195),
    [anon_sym_DASH] = ACTIONS(2195),
    [anon_sym_STAR] = ACTIONS(2199),
    [anon_sym_CARET] = ACTIONS(2197),
    [anon_sym_AMP] = ACTIONS(2197),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2201),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2203),
    [anon_sym_DOT_DOT] = ACTIONS(2205),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1124] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3637),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6955),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2975),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6988),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5043),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3800),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7425),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9573),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1124),
    [sym_preproc_endregion] = STATE(1124),
    [sym_preproc_line] = STATE(1124),
    [sym_preproc_pragma] = STATE(1124),
    [sym_preproc_nullable] = STATE(1124),
    [sym_preproc_error] = STATE(1124),
    [sym_preproc_warning] = STATE(1124),
    [sym_preproc_define] = STATE(1124),
    [sym_preproc_undef] = STATE(1124),
    [aux_sym_class_declaration_repeat1] = STATE(3818),
    [aux_sym_lambda_expression_repeat1] = STATE(4229),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2259),
    [anon_sym_ref] = ACTIONS(2261),
    [anon_sym_LBRACE] = ACTIONS(2825),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1933),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2265),
    [anon_sym_TILDE] = ACTIONS(2265),
    [anon_sym_PLUS_PLUS] = ACTIONS(2265),
    [anon_sym_DASH_DASH] = ACTIONS(2265),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2263),
    [anon_sym_DASH] = ACTIONS(2263),
    [anon_sym_STAR] = ACTIONS(1939),
    [anon_sym_CARET] = ACTIONS(2265),
    [anon_sym_AMP] = ACTIONS(2265),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2267),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2269),
    [anon_sym_DOT_DOT] = ACTIONS(2271),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1125] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6017),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1125),
    [sym_preproc_endregion] = STATE(1125),
    [sym_preproc_line] = STATE(1125),
    [sym_preproc_pragma] = STATE(1125),
    [sym_preproc_nullable] = STATE(1125),
    [sym_preproc_error] = STATE(1125),
    [sym_preproc_warning] = STATE(1125),
    [sym_preproc_define] = STATE(1125),
    [sym_preproc_undef] = STATE(1125),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2965),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1126] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6018),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1126),
    [sym_preproc_endregion] = STATE(1126),
    [sym_preproc_line] = STATE(1126),
    [sym_preproc_pragma] = STATE(1126),
    [sym_preproc_nullable] = STATE(1126),
    [sym_preproc_error] = STATE(1126),
    [sym_preproc_warning] = STATE(1126),
    [sym_preproc_define] = STATE(1126),
    [sym_preproc_undef] = STATE(1126),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2967),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1127] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3714),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6955),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2975),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6988),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5042),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3800),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7425),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9573),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1127),
    [sym_preproc_endregion] = STATE(1127),
    [sym_preproc_line] = STATE(1127),
    [sym_preproc_pragma] = STATE(1127),
    [sym_preproc_nullable] = STATE(1127),
    [sym_preproc_error] = STATE(1127),
    [sym_preproc_warning] = STATE(1127),
    [sym_preproc_define] = STATE(1127),
    [sym_preproc_undef] = STATE(1127),
    [aux_sym_class_declaration_repeat1] = STATE(3818),
    [aux_sym_lambda_expression_repeat1] = STATE(4229),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2259),
    [anon_sym_ref] = ACTIONS(2261),
    [anon_sym_LBRACE] = ACTIONS(2825),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1933),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2265),
    [anon_sym_TILDE] = ACTIONS(2265),
    [anon_sym_PLUS_PLUS] = ACTIONS(2265),
    [anon_sym_DASH_DASH] = ACTIONS(2265),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2263),
    [anon_sym_DASH] = ACTIONS(2263),
    [anon_sym_STAR] = ACTIONS(1939),
    [anon_sym_CARET] = ACTIONS(2265),
    [anon_sym_AMP] = ACTIONS(2265),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2267),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2269),
    [anon_sym_DOT_DOT] = ACTIONS(2271),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1128] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5791),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1128),
    [sym_preproc_endregion] = STATE(1128),
    [sym_preproc_line] = STATE(1128),
    [sym_preproc_pragma] = STATE(1128),
    [sym_preproc_nullable] = STATE(1128),
    [sym_preproc_error] = STATE(1128),
    [sym_preproc_warning] = STATE(1128),
    [sym_preproc_define] = STATE(1128),
    [sym_preproc_undef] = STATE(1128),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_RBRACE] = ACTIONS(2969),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1129] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3763),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6948),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2940),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6999),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5078),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3857),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7444),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9574),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1129),
    [sym_preproc_endregion] = STATE(1129),
    [sym_preproc_line] = STATE(1129),
    [sym_preproc_pragma] = STATE(1129),
    [sym_preproc_nullable] = STATE(1129),
    [sym_preproc_error] = STATE(1129),
    [sym_preproc_warning] = STATE(1129),
    [sym_preproc_define] = STATE(1129),
    [sym_preproc_undef] = STATE(1129),
    [aux_sym_class_declaration_repeat1] = STATE(3854),
    [aux_sym_lambda_expression_repeat1] = STATE(4136),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2111),
    [anon_sym_ref] = ACTIONS(2113),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1897),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2117),
    [anon_sym_TILDE] = ACTIONS(2117),
    [anon_sym_PLUS_PLUS] = ACTIONS(2117),
    [anon_sym_DASH_DASH] = ACTIONS(2117),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2115),
    [anon_sym_DASH] = ACTIONS(2115),
    [anon_sym_STAR] = ACTIONS(1903),
    [anon_sym_CARET] = ACTIONS(2117),
    [anon_sym_AMP] = ACTIONS(2117),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2119),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2121),
    [anon_sym_DOT_DOT] = ACTIONS(2123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1130] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3641),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6955),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2975),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6988),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5030),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3800),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7425),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9573),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1130),
    [sym_preproc_endregion] = STATE(1130),
    [sym_preproc_line] = STATE(1130),
    [sym_preproc_pragma] = STATE(1130),
    [sym_preproc_nullable] = STATE(1130),
    [sym_preproc_error] = STATE(1130),
    [sym_preproc_warning] = STATE(1130),
    [sym_preproc_define] = STATE(1130),
    [sym_preproc_undef] = STATE(1130),
    [aux_sym_class_declaration_repeat1] = STATE(3818),
    [aux_sym_lambda_expression_repeat1] = STATE(4229),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2259),
    [anon_sym_ref] = ACTIONS(2261),
    [anon_sym_LBRACE] = ACTIONS(2825),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1933),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2265),
    [anon_sym_TILDE] = ACTIONS(2265),
    [anon_sym_PLUS_PLUS] = ACTIONS(2265),
    [anon_sym_DASH_DASH] = ACTIONS(2265),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2263),
    [anon_sym_DASH] = ACTIONS(2263),
    [anon_sym_STAR] = ACTIONS(1939),
    [anon_sym_CARET] = ACTIONS(2265),
    [anon_sym_AMP] = ACTIONS(2265),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2267),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2269),
    [anon_sym_DOT_DOT] = ACTIONS(2271),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1131] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7131),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5908),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4364),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9470),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1131),
    [sym_preproc_endregion] = STATE(1131),
    [sym_preproc_line] = STATE(1131),
    [sym_preproc_pragma] = STATE(1131),
    [sym_preproc_nullable] = STATE(1131),
    [sym_preproc_error] = STATE(1131),
    [sym_preproc_warning] = STATE(1131),
    [sym_preproc_define] = STATE(1131),
    [sym_preproc_undef] = STATE(1131),
    [aux_sym_class_declaration_repeat1] = STATE(3870),
    [aux_sym_lambda_expression_repeat1] = STATE(4302),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_SEMI] = ACTIONS(2861),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1555),
    [anon_sym_ref] = ACTIONS(1557),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(695),
    [anon_sym_TILDE] = ACTIONS(695),
    [anon_sym_PLUS_PLUS] = ACTIONS(695),
    [anon_sym_DASH_DASH] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(697),
    [anon_sym_DASH] = ACTIONS(697),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(695),
    [anon_sym_AMP] = ACTIONS(695),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1559),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1561),
    [anon_sym_DOT_DOT] = ACTIONS(1563),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1132] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3754),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5633),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1132),
    [sym_preproc_endregion] = STATE(1132),
    [sym_preproc_line] = STATE(1132),
    [sym_preproc_pragma] = STATE(1132),
    [sym_preproc_nullable] = STATE(1132),
    [sym_preproc_error] = STATE(1132),
    [sym_preproc_warning] = STATE(1132),
    [sym_preproc_define] = STATE(1132),
    [sym_preproc_undef] = STATE(1132),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1133] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3689),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6955),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2975),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6988),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4997),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3800),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7425),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9573),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1133),
    [sym_preproc_endregion] = STATE(1133),
    [sym_preproc_line] = STATE(1133),
    [sym_preproc_pragma] = STATE(1133),
    [sym_preproc_nullable] = STATE(1133),
    [sym_preproc_error] = STATE(1133),
    [sym_preproc_warning] = STATE(1133),
    [sym_preproc_define] = STATE(1133),
    [sym_preproc_undef] = STATE(1133),
    [aux_sym_class_declaration_repeat1] = STATE(3818),
    [aux_sym_lambda_expression_repeat1] = STATE(4229),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2259),
    [anon_sym_ref] = ACTIONS(2261),
    [anon_sym_LBRACE] = ACTIONS(2825),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1933),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2265),
    [anon_sym_TILDE] = ACTIONS(2265),
    [anon_sym_PLUS_PLUS] = ACTIONS(2265),
    [anon_sym_DASH_DASH] = ACTIONS(2265),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2263),
    [anon_sym_DASH] = ACTIONS(2263),
    [anon_sym_STAR] = ACTIONS(1939),
    [anon_sym_CARET] = ACTIONS(2265),
    [anon_sym_AMP] = ACTIONS(2265),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2267),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2269),
    [anon_sym_DOT_DOT] = ACTIONS(2271),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1134] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3735),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6920),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2942),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7143),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6338),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4489),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7426),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9002),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1134),
    [sym_preproc_endregion] = STATE(1134),
    [sym_preproc_line] = STATE(1134),
    [sym_preproc_pragma] = STATE(1134),
    [sym_preproc_nullable] = STATE(1134),
    [sym_preproc_error] = STATE(1134),
    [sym_preproc_warning] = STATE(1134),
    [sym_preproc_define] = STATE(1134),
    [sym_preproc_undef] = STATE(1134),
    [aux_sym_class_declaration_repeat1] = STATE(3809),
    [aux_sym_lambda_expression_repeat1] = STATE(4308),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2189),
    [anon_sym_ref] = ACTIONS(2191),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2193),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2197),
    [anon_sym_TILDE] = ACTIONS(2197),
    [anon_sym_PLUS_PLUS] = ACTIONS(2197),
    [anon_sym_DASH_DASH] = ACTIONS(2197),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2195),
    [anon_sym_DASH] = ACTIONS(2195),
    [anon_sym_STAR] = ACTIONS(2199),
    [anon_sym_CARET] = ACTIONS(2197),
    [anon_sym_AMP] = ACTIONS(2197),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2201),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2203),
    [anon_sym_DOT_DOT] = ACTIONS(2205),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1135] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3741),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6920),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2942),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7143),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6339),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4489),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7426),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9002),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1135),
    [sym_preproc_endregion] = STATE(1135),
    [sym_preproc_line] = STATE(1135),
    [sym_preproc_pragma] = STATE(1135),
    [sym_preproc_nullable] = STATE(1135),
    [sym_preproc_error] = STATE(1135),
    [sym_preproc_warning] = STATE(1135),
    [sym_preproc_define] = STATE(1135),
    [sym_preproc_undef] = STATE(1135),
    [aux_sym_class_declaration_repeat1] = STATE(3809),
    [aux_sym_lambda_expression_repeat1] = STATE(4308),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2189),
    [anon_sym_ref] = ACTIONS(2191),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2193),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2197),
    [anon_sym_TILDE] = ACTIONS(2197),
    [anon_sym_PLUS_PLUS] = ACTIONS(2197),
    [anon_sym_DASH_DASH] = ACTIONS(2197),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2195),
    [anon_sym_DASH] = ACTIONS(2195),
    [anon_sym_STAR] = ACTIONS(2199),
    [anon_sym_CARET] = ACTIONS(2197),
    [anon_sym_AMP] = ACTIONS(2197),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2201),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2203),
    [anon_sym_DOT_DOT] = ACTIONS(2205),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1136] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3692),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6955),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2975),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6988),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4989),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3800),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7425),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9573),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1136),
    [sym_preproc_endregion] = STATE(1136),
    [sym_preproc_line] = STATE(1136),
    [sym_preproc_pragma] = STATE(1136),
    [sym_preproc_nullable] = STATE(1136),
    [sym_preproc_error] = STATE(1136),
    [sym_preproc_warning] = STATE(1136),
    [sym_preproc_define] = STATE(1136),
    [sym_preproc_undef] = STATE(1136),
    [aux_sym_class_declaration_repeat1] = STATE(3818),
    [aux_sym_lambda_expression_repeat1] = STATE(4229),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2259),
    [anon_sym_ref] = ACTIONS(2261),
    [anon_sym_LBRACE] = ACTIONS(2825),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1933),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2265),
    [anon_sym_TILDE] = ACTIONS(2265),
    [anon_sym_PLUS_PLUS] = ACTIONS(2265),
    [anon_sym_DASH_DASH] = ACTIONS(2265),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2263),
    [anon_sym_DASH] = ACTIONS(2263),
    [anon_sym_STAR] = ACTIONS(1939),
    [anon_sym_CARET] = ACTIONS(2265),
    [anon_sym_AMP] = ACTIONS(2265),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2267),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2269),
    [anon_sym_DOT_DOT] = ACTIONS(2271),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1137] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3754),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7131),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6029),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4364),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9470),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1137),
    [sym_preproc_endregion] = STATE(1137),
    [sym_preproc_line] = STATE(1137),
    [sym_preproc_pragma] = STATE(1137),
    [sym_preproc_nullable] = STATE(1137),
    [sym_preproc_error] = STATE(1137),
    [sym_preproc_warning] = STATE(1137),
    [sym_preproc_define] = STATE(1137),
    [sym_preproc_undef] = STATE(1137),
    [aux_sym_class_declaration_repeat1] = STATE(3870),
    [aux_sym_lambda_expression_repeat1] = STATE(4302),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1555),
    [anon_sym_ref] = ACTIONS(1557),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(695),
    [anon_sym_TILDE] = ACTIONS(695),
    [anon_sym_PLUS_PLUS] = ACTIONS(695),
    [anon_sym_DASH_DASH] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(697),
    [anon_sym_DASH] = ACTIONS(697),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(695),
    [anon_sym_AMP] = ACTIONS(695),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1559),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1561),
    [anon_sym_DOT_DOT] = ACTIONS(1563),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1138] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5972),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1138),
    [sym_preproc_endregion] = STATE(1138),
    [sym_preproc_line] = STATE(1138),
    [sym_preproc_pragma] = STATE(1138),
    [sym_preproc_nullable] = STATE(1138),
    [sym_preproc_error] = STATE(1138),
    [sym_preproc_warning] = STATE(1138),
    [sym_preproc_define] = STATE(1138),
    [sym_preproc_undef] = STATE(1138),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2971),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1139] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3754),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6920),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2942),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7143),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6340),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4489),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7426),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9002),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1139),
    [sym_preproc_endregion] = STATE(1139),
    [sym_preproc_line] = STATE(1139),
    [sym_preproc_pragma] = STATE(1139),
    [sym_preproc_nullable] = STATE(1139),
    [sym_preproc_error] = STATE(1139),
    [sym_preproc_warning] = STATE(1139),
    [sym_preproc_define] = STATE(1139),
    [sym_preproc_undef] = STATE(1139),
    [aux_sym_class_declaration_repeat1] = STATE(3809),
    [aux_sym_lambda_expression_repeat1] = STATE(4308),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2189),
    [anon_sym_ref] = ACTIONS(2191),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2193),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2197),
    [anon_sym_TILDE] = ACTIONS(2197),
    [anon_sym_PLUS_PLUS] = ACTIONS(2197),
    [anon_sym_DASH_DASH] = ACTIONS(2197),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2195),
    [anon_sym_DASH] = ACTIONS(2195),
    [anon_sym_STAR] = ACTIONS(2199),
    [anon_sym_CARET] = ACTIONS(2197),
    [anon_sym_AMP] = ACTIONS(2197),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2201),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2203),
    [anon_sym_DOT_DOT] = ACTIONS(2205),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1140] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5973),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1140),
    [sym_preproc_endregion] = STATE(1140),
    [sym_preproc_line] = STATE(1140),
    [sym_preproc_pragma] = STATE(1140),
    [sym_preproc_nullable] = STATE(1140),
    [sym_preproc_error] = STATE(1140),
    [sym_preproc_warning] = STATE(1140),
    [sym_preproc_define] = STATE(1140),
    [sym_preproc_undef] = STATE(1140),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_RPAREN] = ACTIONS(2973),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1141] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6763),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2865),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6662),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6519),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2810),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1141),
    [sym_preproc_endregion] = STATE(1141),
    [sym_preproc_line] = STATE(1141),
    [sym_preproc_pragma] = STATE(1141),
    [sym_preproc_nullable] = STATE(1141),
    [sym_preproc_error] = STATE(1141),
    [sym_preproc_warning] = STATE(1141),
    [sym_preproc_define] = STATE(1141),
    [sym_preproc_undef] = STATE(1141),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2595),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_readonly] = ACTIONS(2867),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(2407),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(2727),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1142] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3708),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6955),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2975),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6988),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5009),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3800),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7425),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9573),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1142),
    [sym_preproc_endregion] = STATE(1142),
    [sym_preproc_line] = STATE(1142),
    [sym_preproc_pragma] = STATE(1142),
    [sym_preproc_nullable] = STATE(1142),
    [sym_preproc_error] = STATE(1142),
    [sym_preproc_warning] = STATE(1142),
    [sym_preproc_define] = STATE(1142),
    [sym_preproc_undef] = STATE(1142),
    [aux_sym_class_declaration_repeat1] = STATE(3818),
    [aux_sym_lambda_expression_repeat1] = STATE(4229),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2259),
    [anon_sym_ref] = ACTIONS(2261),
    [anon_sym_LBRACE] = ACTIONS(2825),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1933),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2265),
    [anon_sym_TILDE] = ACTIONS(2265),
    [anon_sym_PLUS_PLUS] = ACTIONS(2265),
    [anon_sym_DASH_DASH] = ACTIONS(2265),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2263),
    [anon_sym_DASH] = ACTIONS(2263),
    [anon_sym_STAR] = ACTIONS(1939),
    [anon_sym_CARET] = ACTIONS(2265),
    [anon_sym_AMP] = ACTIONS(2265),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2267),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2269),
    [anon_sym_DOT_DOT] = ACTIONS(2271),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1143] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3754),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7105),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5931),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1143),
    [sym_preproc_endregion] = STATE(1143),
    [sym_preproc_line] = STATE(1143),
    [sym_preproc_pragma] = STATE(1143),
    [sym_preproc_nullable] = STATE(1143),
    [sym_preproc_error] = STATE(1143),
    [sym_preproc_warning] = STATE(1143),
    [sym_preproc_define] = STATE(1143),
    [sym_preproc_undef] = STATE(1143),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(2837),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1144] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4028),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6915),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7018),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4539),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3585),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7418),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9926),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1144),
    [sym_preproc_endregion] = STATE(1144),
    [sym_preproc_line] = STATE(1144),
    [sym_preproc_pragma] = STATE(1144),
    [sym_preproc_nullable] = STATE(1144),
    [sym_preproc_error] = STATE(1144),
    [sym_preproc_warning] = STATE(1144),
    [sym_preproc_define] = STATE(1144),
    [sym_preproc_undef] = STATE(1144),
    [aux_sym_class_declaration_repeat1] = STATE(3825),
    [aux_sym_lambda_expression_repeat1] = STATE(4244),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1161),
    [anon_sym_ref] = ACTIONS(1163),
    [anon_sym_LBRACE] = ACTIONS(2835),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1177),
    [anon_sym_TILDE] = ACTIONS(1177),
    [anon_sym_PLUS_PLUS] = ACTIONS(1177),
    [anon_sym_DASH_DASH] = ACTIONS(1177),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1175),
    [anon_sym_DASH] = ACTIONS(1175),
    [anon_sym_STAR] = ACTIONS(1181),
    [anon_sym_CARET] = ACTIONS(1177),
    [anon_sym_AMP] = ACTIONS(1177),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1191),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1193),
    [anon_sym_DOT_DOT] = ACTIONS(1195),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1145] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6223),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym__anonymous_object_member_declarator] = STATE(8895),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2867),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1145),
    [sym_preproc_endregion] = STATE(1145),
    [sym_preproc_line] = STATE(1145),
    [sym_preproc_pragma] = STATE(1145),
    [sym_preproc_nullable] = STATE(1145),
    [sym_preproc_error] = STATE(1145),
    [sym_preproc_warning] = STATE(1145),
    [sym_preproc_define] = STATE(1145),
    [sym_preproc_undef] = STATE(1145),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1146] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3689),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6916),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7128),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4919),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3752),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7413),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9092),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1146),
    [sym_preproc_endregion] = STATE(1146),
    [sym_preproc_line] = STATE(1146),
    [sym_preproc_pragma] = STATE(1146),
    [sym_preproc_nullable] = STATE(1146),
    [sym_preproc_error] = STATE(1146),
    [sym_preproc_warning] = STATE(1146),
    [sym_preproc_define] = STATE(1146),
    [sym_preproc_undef] = STATE(1146),
    [aux_sym_class_declaration_repeat1] = STATE(3845),
    [aux_sym_lambda_expression_repeat1] = STATE(4181),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1241),
    [anon_sym_ref] = ACTIONS(1243),
    [anon_sym_LBRACE] = ACTIONS(2825),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1255),
    [anon_sym_TILDE] = ACTIONS(1255),
    [anon_sym_PLUS_PLUS] = ACTIONS(1255),
    [anon_sym_DASH_DASH] = ACTIONS(1255),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1253),
    [anon_sym_DASH] = ACTIONS(1253),
    [anon_sym_STAR] = ACTIONS(1259),
    [anon_sym_CARET] = ACTIONS(1255),
    [anon_sym_AMP] = ACTIONS(1255),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1269),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1271),
    [anon_sym_DOT_DOT] = ACTIONS(1273),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1147] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(3637),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6926),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2950),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7053),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6270),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4458),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7431),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9158),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1147),
    [sym_preproc_endregion] = STATE(1147),
    [sym_preproc_line] = STATE(1147),
    [sym_preproc_pragma] = STATE(1147),
    [sym_preproc_nullable] = STATE(1147),
    [sym_preproc_error] = STATE(1147),
    [sym_preproc_warning] = STATE(1147),
    [sym_preproc_define] = STATE(1147),
    [sym_preproc_undef] = STATE(1147),
    [aux_sym_class_declaration_repeat1] = STATE(3835),
    [aux_sym_lambda_expression_repeat1] = STATE(4263),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2213),
    [anon_sym_ref] = ACTIONS(2215),
    [anon_sym_LBRACE] = ACTIONS(2825),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2217),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2221),
    [anon_sym_TILDE] = ACTIONS(2221),
    [anon_sym_PLUS_PLUS] = ACTIONS(2221),
    [anon_sym_DASH_DASH] = ACTIONS(2221),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2219),
    [anon_sym_DASH] = ACTIONS(2219),
    [anon_sym_STAR] = ACTIONS(2223),
    [anon_sym_CARET] = ACTIONS(2221),
    [anon_sym_AMP] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2225),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2227),
    [anon_sym_DOT_DOT] = ACTIONS(2229),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1148] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6955),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2975),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6989),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5003),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3800),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7425),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9573),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1148),
    [sym_preproc_endregion] = STATE(1148),
    [sym_preproc_line] = STATE(1148),
    [sym_preproc_pragma] = STATE(1148),
    [sym_preproc_nullable] = STATE(1148),
    [sym_preproc_error] = STATE(1148),
    [sym_preproc_warning] = STATE(1148),
    [sym_preproc_define] = STATE(1148),
    [sym_preproc_undef] = STATE(1148),
    [aux_sym_class_declaration_repeat1] = STATE(3818),
    [aux_sym_lambda_expression_repeat1] = STATE(4229),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2259),
    [anon_sym_ref] = ACTIONS(2261),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1933),
    [anon_sym_readonly] = ACTIONS(2767),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2265),
    [anon_sym_TILDE] = ACTIONS(2265),
    [anon_sym_PLUS_PLUS] = ACTIONS(2265),
    [anon_sym_DASH_DASH] = ACTIONS(2265),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2263),
    [anon_sym_DASH] = ACTIONS(2263),
    [anon_sym_STAR] = ACTIONS(1939),
    [anon_sym_CARET] = ACTIONS(2265),
    [anon_sym_AMP] = ACTIONS(2265),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2267),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2269),
    [anon_sym_DOT_DOT] = ACTIONS(2271),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1149] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4030),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6915),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7018),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4492),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3585),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7418),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9926),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1149),
    [sym_preproc_endregion] = STATE(1149),
    [sym_preproc_line] = STATE(1149),
    [sym_preproc_pragma] = STATE(1149),
    [sym_preproc_nullable] = STATE(1149),
    [sym_preproc_error] = STATE(1149),
    [sym_preproc_warning] = STATE(1149),
    [sym_preproc_define] = STATE(1149),
    [sym_preproc_undef] = STATE(1149),
    [aux_sym_class_declaration_repeat1] = STATE(3825),
    [aux_sym_lambda_expression_repeat1] = STATE(4244),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1161),
    [anon_sym_ref] = ACTIONS(1163),
    [anon_sym_LBRACE] = ACTIONS(2835),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1177),
    [anon_sym_TILDE] = ACTIONS(1177),
    [anon_sym_PLUS_PLUS] = ACTIONS(1177),
    [anon_sym_DASH_DASH] = ACTIONS(1177),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1175),
    [anon_sym_DASH] = ACTIONS(1175),
    [anon_sym_STAR] = ACTIONS(1181),
    [anon_sym_CARET] = ACTIONS(1177),
    [anon_sym_AMP] = ACTIONS(1177),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1191),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1193),
    [anon_sym_DOT_DOT] = ACTIONS(1195),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1150] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_block] = STATE(4218),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7010),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5964),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4334),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9265),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1150),
    [sym_preproc_endregion] = STATE(1150),
    [sym_preproc_line] = STATE(1150),
    [sym_preproc_pragma] = STATE(1150),
    [sym_preproc_nullable] = STATE(1150),
    [sym_preproc_error] = STATE(1150),
    [sym_preproc_warning] = STATE(1150),
    [sym_preproc_define] = STATE(1150),
    [sym_preproc_undef] = STATE(1150),
    [aux_sym_class_declaration_repeat1] = STATE(3823),
    [aux_sym_lambda_expression_repeat1] = STATE(4240),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1751),
    [anon_sym_ref] = ACTIONS(1753),
    [anon_sym_LBRACE] = ACTIONS(2831),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1755),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1759),
    [anon_sym_TILDE] = ACTIONS(1759),
    [anon_sym_PLUS_PLUS] = ACTIONS(1759),
    [anon_sym_DASH_DASH] = ACTIONS(1759),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1757),
    [anon_sym_DASH] = ACTIONS(1757),
    [anon_sym_STAR] = ACTIONS(1381),
    [anon_sym_CARET] = ACTIONS(1759),
    [anon_sym_AMP] = ACTIONS(1759),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1761),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1763),
    [anon_sym_DOT_DOT] = ACTIONS(1765),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1151] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6913),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2905),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6979),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5425),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4178),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7433),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9183),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1151),
    [sym_preproc_endregion] = STATE(1151),
    [sym_preproc_line] = STATE(1151),
    [sym_preproc_pragma] = STATE(1151),
    [sym_preproc_nullable] = STATE(1151),
    [sym_preproc_error] = STATE(1151),
    [sym_preproc_warning] = STATE(1151),
    [sym_preproc_define] = STATE(1151),
    [sym_preproc_undef] = STATE(1151),
    [aux_sym_class_declaration_repeat1] = STATE(3816),
    [aux_sym_lambda_expression_repeat1] = STATE(4225),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1573),
    [anon_sym_ref] = ACTIONS(1575),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1577),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1581),
    [anon_sym_TILDE] = ACTIONS(1581),
    [anon_sym_PLUS_PLUS] = ACTIONS(1581),
    [anon_sym_DASH_DASH] = ACTIONS(1581),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1579),
    [anon_sym_DASH] = ACTIONS(1579),
    [anon_sym_STAR] = ACTIONS(1583),
    [anon_sym_CARET] = ACTIONS(1581),
    [anon_sym_AMP] = ACTIONS(1581),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1585),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1587),
    [anon_sym_DOT_DOT] = ACTIONS(1589),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1152] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6673),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1152),
    [sym_preproc_endregion] = STATE(1152),
    [sym_preproc_line] = STATE(1152),
    [sym_preproc_pragma] = STATE(1152),
    [sym_preproc_nullable] = STATE(1152),
    [sym_preproc_error] = STATE(1152),
    [sym_preproc_warning] = STATE(1152),
    [sym_preproc_define] = STATE(1152),
    [sym_preproc_undef] = STATE(1152),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1153] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6948),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2940),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6999),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5101),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3857),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7444),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9574),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1153),
    [sym_preproc_endregion] = STATE(1153),
    [sym_preproc_line] = STATE(1153),
    [sym_preproc_pragma] = STATE(1153),
    [sym_preproc_nullable] = STATE(1153),
    [sym_preproc_error] = STATE(1153),
    [sym_preproc_warning] = STATE(1153),
    [sym_preproc_define] = STATE(1153),
    [sym_preproc_undef] = STATE(1153),
    [aux_sym_class_declaration_repeat1] = STATE(3854),
    [aux_sym_lambda_expression_repeat1] = STATE(4136),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2111),
    [anon_sym_ref] = ACTIONS(2113),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1897),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2117),
    [anon_sym_TILDE] = ACTIONS(2117),
    [anon_sym_PLUS_PLUS] = ACTIONS(2117),
    [anon_sym_DASH_DASH] = ACTIONS(2117),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2115),
    [anon_sym_DASH] = ACTIONS(2115),
    [anon_sym_STAR] = ACTIONS(1903),
    [anon_sym_CARET] = ACTIONS(2117),
    [anon_sym_AMP] = ACTIONS(2117),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2119),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2121),
    [anon_sym_DOT_DOT] = ACTIONS(2123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1154] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6920),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2942),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7143),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6419),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4489),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7426),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9002),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1154),
    [sym_preproc_endregion] = STATE(1154),
    [sym_preproc_line] = STATE(1154),
    [sym_preproc_pragma] = STATE(1154),
    [sym_preproc_nullable] = STATE(1154),
    [sym_preproc_error] = STATE(1154),
    [sym_preproc_warning] = STATE(1154),
    [sym_preproc_define] = STATE(1154),
    [sym_preproc_undef] = STATE(1154),
    [aux_sym_class_declaration_repeat1] = STATE(3809),
    [aux_sym_lambda_expression_repeat1] = STATE(4308),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2189),
    [anon_sym_ref] = ACTIONS(2191),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2193),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2197),
    [anon_sym_TILDE] = ACTIONS(2197),
    [anon_sym_PLUS_PLUS] = ACTIONS(2197),
    [anon_sym_DASH_DASH] = ACTIONS(2197),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2195),
    [anon_sym_DASH] = ACTIONS(2195),
    [anon_sym_STAR] = ACTIONS(2199),
    [anon_sym_CARET] = ACTIONS(2197),
    [anon_sym_AMP] = ACTIONS(2197),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2201),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2203),
    [anon_sym_DOT_DOT] = ACTIONS(2205),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1155] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6916),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7128),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4902),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3752),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7413),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9092),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1155),
    [sym_preproc_endregion] = STATE(1155),
    [sym_preproc_line] = STATE(1155),
    [sym_preproc_pragma] = STATE(1155),
    [sym_preproc_nullable] = STATE(1155),
    [sym_preproc_error] = STATE(1155),
    [sym_preproc_warning] = STATE(1155),
    [sym_preproc_define] = STATE(1155),
    [sym_preproc_undef] = STATE(1155),
    [aux_sym_class_declaration_repeat1] = STATE(3845),
    [aux_sym_lambda_expression_repeat1] = STATE(4181),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1241),
    [anon_sym_ref] = ACTIONS(1243),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1255),
    [anon_sym_TILDE] = ACTIONS(1255),
    [anon_sym_PLUS_PLUS] = ACTIONS(1255),
    [anon_sym_DASH_DASH] = ACTIONS(1255),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1253),
    [anon_sym_DASH] = ACTIONS(1253),
    [anon_sym_STAR] = ACTIONS(1259),
    [anon_sym_CARET] = ACTIONS(1255),
    [anon_sym_AMP] = ACTIONS(1255),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1269),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1271),
    [anon_sym_DOT_DOT] = ACTIONS(1273),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1156] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6921),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2873),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(6957),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5305),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4346),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7445),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9875),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(1156),
    [sym_preproc_endregion] = STATE(1156),
    [sym_preproc_line] = STATE(1156),
    [sym_preproc_pragma] = STATE(1156),
    [sym_preproc_nullable] = STATE(1156),
    [sym_preproc_error] = STATE(1156),
    [sym_preproc_warning] = STATE(1156),
    [sym_preproc_define] = STATE(1156),
    [sym_preproc_undef] = STATE(1156),
    [aux_sym_class_declaration_repeat1] = STATE(3810),
    [aux_sym_lambda_expression_repeat1] = STATE(4192),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1639),
    [anon_sym_ref] = ACTIONS(1641),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1415),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1645),
    [anon_sym_TILDE] = ACTIONS(1645),
    [anon_sym_PLUS_PLUS] = ACTIONS(1645),
    [anon_sym_DASH_DASH] = ACTIONS(1645),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1643),
    [anon_sym_DASH] = ACTIONS(1643),
    [anon_sym_STAR] = ACTIONS(1425),
    [anon_sym_CARET] = ACTIONS(1645),
    [anon_sym_AMP] = ACTIONS(1645),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1647),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1649),
    [anon_sym_DOT_DOT] = ACTIONS(1651),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [1157] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6911),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2930),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7031),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4868),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3742),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7420),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9374),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(1157),
    [sym_preproc_endregion] = STATE(1157),
    [sym_preproc_line] = STATE(1157),
    [sym_preproc_pragma] = STATE(1157),
    [sym_preproc_nullable] = STATE(1157),
    [sym_preproc_error] = STATE(1157),
    [sym_preproc_warning] = STATE(1157),
    [sym_preproc_define] = STATE(1157),
    [sym_preproc_undef] = STATE(1157),
    [aux_sym_class_declaration_repeat1] = STATE(3861),
    [aux_sym_lambda_expression_repeat1] = STATE(4169),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(2089),
    [anon_sym_ref] = ACTIONS(2091),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1695),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(2095),
    [anon_sym_TILDE] = ACTIONS(2095),
    [anon_sym_PLUS_PLUS] = ACTIONS(2095),
    [anon_sym_DASH_DASH] = ACTIONS(2095),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(2093),
    [anon_sym_DASH] = ACTIONS(2093),
    [anon_sym_STAR] = ACTIONS(1705),
    [anon_sym_CARET] = ACTIONS(2095),
    [anon_sym_AMP] = ACTIONS(2095),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(2097),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2099),
    [anon_sym_DOT_DOT] = ACTIONS(2101),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [1158] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6911),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2930),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7031),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4373),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3742),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7420),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9374),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(1158),
    [sym_preproc_endregion] = STATE(1158),
    [sym_preproc_line] = STATE(1158),
    [sym_preproc_pragma] = STATE(1158),
    [sym_preproc_nullable] = STATE(1158),
    [sym_preproc_error] = STATE(1158),
    [sym_preproc_warning] = STATE(1158),
    [sym_preproc_define] = STATE(1158),
    [sym_preproc_undef] = STATE(1158),
    [aux_sym_class_declaration_repeat1] = STATE(3861),
    [aux_sym_lambda_expression_repeat1] = STATE(4169),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(2089),
    [anon_sym_ref] = ACTIONS(2091),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1695),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(2095),
    [anon_sym_TILDE] = ACTIONS(2095),
    [anon_sym_PLUS_PLUS] = ACTIONS(2095),
    [anon_sym_DASH_DASH] = ACTIONS(2095),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(2093),
    [anon_sym_DASH] = ACTIONS(2093),
    [anon_sym_STAR] = ACTIONS(1705),
    [anon_sym_CARET] = ACTIONS(2095),
    [anon_sym_AMP] = ACTIONS(2095),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(2097),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2099),
    [anon_sym_DOT_DOT] = ACTIONS(2101),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [1159] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6948),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2940),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6999),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5055),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3857),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7444),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9574),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1159),
    [sym_preproc_endregion] = STATE(1159),
    [sym_preproc_line] = STATE(1159),
    [sym_preproc_pragma] = STATE(1159),
    [sym_preproc_nullable] = STATE(1159),
    [sym_preproc_error] = STATE(1159),
    [sym_preproc_warning] = STATE(1159),
    [sym_preproc_define] = STATE(1159),
    [sym_preproc_undef] = STATE(1159),
    [aux_sym_class_declaration_repeat1] = STATE(3854),
    [aux_sym_lambda_expression_repeat1] = STATE(4136),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2111),
    [anon_sym_ref] = ACTIONS(2113),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1897),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2117),
    [anon_sym_TILDE] = ACTIONS(2117),
    [anon_sym_PLUS_PLUS] = ACTIONS(2117),
    [anon_sym_DASH_DASH] = ACTIONS(2117),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2115),
    [anon_sym_DASH] = ACTIONS(2115),
    [anon_sym_STAR] = ACTIONS(1903),
    [anon_sym_CARET] = ACTIONS(2117),
    [anon_sym_AMP] = ACTIONS(2117),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2119),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2121),
    [anon_sym_DOT_DOT] = ACTIONS(2123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1160] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6948),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2940),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6999),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5068),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3857),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7444),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9574),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1160),
    [sym_preproc_endregion] = STATE(1160),
    [sym_preproc_line] = STATE(1160),
    [sym_preproc_pragma] = STATE(1160),
    [sym_preproc_nullable] = STATE(1160),
    [sym_preproc_error] = STATE(1160),
    [sym_preproc_warning] = STATE(1160),
    [sym_preproc_define] = STATE(1160),
    [sym_preproc_undef] = STATE(1160),
    [aux_sym_class_declaration_repeat1] = STATE(3854),
    [aux_sym_lambda_expression_repeat1] = STATE(4136),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2111),
    [anon_sym_ref] = ACTIONS(2113),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1897),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2117),
    [anon_sym_TILDE] = ACTIONS(2117),
    [anon_sym_PLUS_PLUS] = ACTIONS(2117),
    [anon_sym_DASH_DASH] = ACTIONS(2117),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2115),
    [anon_sym_DASH] = ACTIONS(2115),
    [anon_sym_STAR] = ACTIONS(1903),
    [anon_sym_CARET] = ACTIONS(2117),
    [anon_sym_AMP] = ACTIONS(2117),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2119),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2121),
    [anon_sym_DOT_DOT] = ACTIONS(2123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1161] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6948),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2940),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6999),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5069),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3857),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7444),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9574),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1161),
    [sym_preproc_endregion] = STATE(1161),
    [sym_preproc_line] = STATE(1161),
    [sym_preproc_pragma] = STATE(1161),
    [sym_preproc_nullable] = STATE(1161),
    [sym_preproc_error] = STATE(1161),
    [sym_preproc_warning] = STATE(1161),
    [sym_preproc_define] = STATE(1161),
    [sym_preproc_undef] = STATE(1161),
    [aux_sym_class_declaration_repeat1] = STATE(3854),
    [aux_sym_lambda_expression_repeat1] = STATE(4136),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2111),
    [anon_sym_ref] = ACTIONS(2113),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1897),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2117),
    [anon_sym_TILDE] = ACTIONS(2117),
    [anon_sym_PLUS_PLUS] = ACTIONS(2117),
    [anon_sym_DASH_DASH] = ACTIONS(2117),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2115),
    [anon_sym_DASH] = ACTIONS(2115),
    [anon_sym_STAR] = ACTIONS(1903),
    [anon_sym_CARET] = ACTIONS(2117),
    [anon_sym_AMP] = ACTIONS(2117),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2119),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2121),
    [anon_sym_DOT_DOT] = ACTIONS(2123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1162] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6948),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2940),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6999),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5070),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3857),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7444),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9574),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1162),
    [sym_preproc_endregion] = STATE(1162),
    [sym_preproc_line] = STATE(1162),
    [sym_preproc_pragma] = STATE(1162),
    [sym_preproc_nullable] = STATE(1162),
    [sym_preproc_error] = STATE(1162),
    [sym_preproc_warning] = STATE(1162),
    [sym_preproc_define] = STATE(1162),
    [sym_preproc_undef] = STATE(1162),
    [aux_sym_class_declaration_repeat1] = STATE(3854),
    [aux_sym_lambda_expression_repeat1] = STATE(4136),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2111),
    [anon_sym_ref] = ACTIONS(2113),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1897),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2117),
    [anon_sym_TILDE] = ACTIONS(2117),
    [anon_sym_PLUS_PLUS] = ACTIONS(2117),
    [anon_sym_DASH_DASH] = ACTIONS(2117),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2115),
    [anon_sym_DASH] = ACTIONS(2115),
    [anon_sym_STAR] = ACTIONS(1903),
    [anon_sym_CARET] = ACTIONS(2117),
    [anon_sym_AMP] = ACTIONS(2117),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2119),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2121),
    [anon_sym_DOT_DOT] = ACTIONS(2123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1163] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6948),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2940),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6999),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5072),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3857),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7444),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9574),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1163),
    [sym_preproc_endregion] = STATE(1163),
    [sym_preproc_line] = STATE(1163),
    [sym_preproc_pragma] = STATE(1163),
    [sym_preproc_nullable] = STATE(1163),
    [sym_preproc_error] = STATE(1163),
    [sym_preproc_warning] = STATE(1163),
    [sym_preproc_define] = STATE(1163),
    [sym_preproc_undef] = STATE(1163),
    [aux_sym_class_declaration_repeat1] = STATE(3854),
    [aux_sym_lambda_expression_repeat1] = STATE(4136),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2111),
    [anon_sym_ref] = ACTIONS(2113),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1897),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2117),
    [anon_sym_TILDE] = ACTIONS(2117),
    [anon_sym_PLUS_PLUS] = ACTIONS(2117),
    [anon_sym_DASH_DASH] = ACTIONS(2117),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2115),
    [anon_sym_DASH] = ACTIONS(2115),
    [anon_sym_STAR] = ACTIONS(1903),
    [anon_sym_CARET] = ACTIONS(2117),
    [anon_sym_AMP] = ACTIONS(2117),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2119),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2121),
    [anon_sym_DOT_DOT] = ACTIONS(2123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1164] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6948),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2940),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6999),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5074),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3857),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7444),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9574),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1164),
    [sym_preproc_endregion] = STATE(1164),
    [sym_preproc_line] = STATE(1164),
    [sym_preproc_pragma] = STATE(1164),
    [sym_preproc_nullable] = STATE(1164),
    [sym_preproc_error] = STATE(1164),
    [sym_preproc_warning] = STATE(1164),
    [sym_preproc_define] = STATE(1164),
    [sym_preproc_undef] = STATE(1164),
    [aux_sym_class_declaration_repeat1] = STATE(3854),
    [aux_sym_lambda_expression_repeat1] = STATE(4136),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2111),
    [anon_sym_ref] = ACTIONS(2113),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1897),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2117),
    [anon_sym_TILDE] = ACTIONS(2117),
    [anon_sym_PLUS_PLUS] = ACTIONS(2117),
    [anon_sym_DASH_DASH] = ACTIONS(2117),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2115),
    [anon_sym_DASH] = ACTIONS(2115),
    [anon_sym_STAR] = ACTIONS(1903),
    [anon_sym_CARET] = ACTIONS(2117),
    [anon_sym_AMP] = ACTIONS(2117),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2119),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2121),
    [anon_sym_DOT_DOT] = ACTIONS(2123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1165] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6948),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2940),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6999),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5075),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3857),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7444),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9574),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1165),
    [sym_preproc_endregion] = STATE(1165),
    [sym_preproc_line] = STATE(1165),
    [sym_preproc_pragma] = STATE(1165),
    [sym_preproc_nullable] = STATE(1165),
    [sym_preproc_error] = STATE(1165),
    [sym_preproc_warning] = STATE(1165),
    [sym_preproc_define] = STATE(1165),
    [sym_preproc_undef] = STATE(1165),
    [aux_sym_class_declaration_repeat1] = STATE(3854),
    [aux_sym_lambda_expression_repeat1] = STATE(4136),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2111),
    [anon_sym_ref] = ACTIONS(2113),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1897),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2117),
    [anon_sym_TILDE] = ACTIONS(2117),
    [anon_sym_PLUS_PLUS] = ACTIONS(2117),
    [anon_sym_DASH_DASH] = ACTIONS(2117),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2115),
    [anon_sym_DASH] = ACTIONS(2115),
    [anon_sym_STAR] = ACTIONS(1903),
    [anon_sym_CARET] = ACTIONS(2117),
    [anon_sym_AMP] = ACTIONS(2117),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2119),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2121),
    [anon_sym_DOT_DOT] = ACTIONS(2123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1166] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6948),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2940),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6999),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5077),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3857),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7444),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9574),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1166),
    [sym_preproc_endregion] = STATE(1166),
    [sym_preproc_line] = STATE(1166),
    [sym_preproc_pragma] = STATE(1166),
    [sym_preproc_nullable] = STATE(1166),
    [sym_preproc_error] = STATE(1166),
    [sym_preproc_warning] = STATE(1166),
    [sym_preproc_define] = STATE(1166),
    [sym_preproc_undef] = STATE(1166),
    [aux_sym_class_declaration_repeat1] = STATE(3854),
    [aux_sym_lambda_expression_repeat1] = STATE(4136),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2111),
    [anon_sym_ref] = ACTIONS(2113),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1897),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2117),
    [anon_sym_TILDE] = ACTIONS(2117),
    [anon_sym_PLUS_PLUS] = ACTIONS(2117),
    [anon_sym_DASH_DASH] = ACTIONS(2117),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2115),
    [anon_sym_DASH] = ACTIONS(2115),
    [anon_sym_STAR] = ACTIONS(1903),
    [anon_sym_CARET] = ACTIONS(2117),
    [anon_sym_AMP] = ACTIONS(2117),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2119),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2121),
    [anon_sym_DOT_DOT] = ACTIONS(2123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1167] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6948),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2940),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6999),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5088),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3857),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7444),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9574),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1167),
    [sym_preproc_endregion] = STATE(1167),
    [sym_preproc_line] = STATE(1167),
    [sym_preproc_pragma] = STATE(1167),
    [sym_preproc_nullable] = STATE(1167),
    [sym_preproc_error] = STATE(1167),
    [sym_preproc_warning] = STATE(1167),
    [sym_preproc_define] = STATE(1167),
    [sym_preproc_undef] = STATE(1167),
    [aux_sym_class_declaration_repeat1] = STATE(3854),
    [aux_sym_lambda_expression_repeat1] = STATE(4136),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2111),
    [anon_sym_ref] = ACTIONS(2113),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1897),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2117),
    [anon_sym_TILDE] = ACTIONS(2117),
    [anon_sym_PLUS_PLUS] = ACTIONS(2117),
    [anon_sym_DASH_DASH] = ACTIONS(2117),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2115),
    [anon_sym_DASH] = ACTIONS(2115),
    [anon_sym_STAR] = ACTIONS(1903),
    [anon_sym_CARET] = ACTIONS(2117),
    [anon_sym_AMP] = ACTIONS(2117),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2119),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2121),
    [anon_sym_DOT_DOT] = ACTIONS(2123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1168] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6948),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2940),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6999),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5091),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3857),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7444),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9574),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1168),
    [sym_preproc_endregion] = STATE(1168),
    [sym_preproc_line] = STATE(1168),
    [sym_preproc_pragma] = STATE(1168),
    [sym_preproc_nullable] = STATE(1168),
    [sym_preproc_error] = STATE(1168),
    [sym_preproc_warning] = STATE(1168),
    [sym_preproc_define] = STATE(1168),
    [sym_preproc_undef] = STATE(1168),
    [aux_sym_class_declaration_repeat1] = STATE(3854),
    [aux_sym_lambda_expression_repeat1] = STATE(4136),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2111),
    [anon_sym_ref] = ACTIONS(2113),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1897),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2117),
    [anon_sym_TILDE] = ACTIONS(2117),
    [anon_sym_PLUS_PLUS] = ACTIONS(2117),
    [anon_sym_DASH_DASH] = ACTIONS(2117),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2115),
    [anon_sym_DASH] = ACTIONS(2115),
    [anon_sym_STAR] = ACTIONS(1903),
    [anon_sym_CARET] = ACTIONS(2117),
    [anon_sym_AMP] = ACTIONS(2117),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2119),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2121),
    [anon_sym_DOT_DOT] = ACTIONS(2123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1169] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6948),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2940),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6999),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5127),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3857),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7444),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9574),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1169),
    [sym_preproc_endregion] = STATE(1169),
    [sym_preproc_line] = STATE(1169),
    [sym_preproc_pragma] = STATE(1169),
    [sym_preproc_nullable] = STATE(1169),
    [sym_preproc_error] = STATE(1169),
    [sym_preproc_warning] = STATE(1169),
    [sym_preproc_define] = STATE(1169),
    [sym_preproc_undef] = STATE(1169),
    [aux_sym_class_declaration_repeat1] = STATE(3854),
    [aux_sym_lambda_expression_repeat1] = STATE(4136),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2111),
    [anon_sym_ref] = ACTIONS(2113),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1897),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2117),
    [anon_sym_TILDE] = ACTIONS(2117),
    [anon_sym_PLUS_PLUS] = ACTIONS(2117),
    [anon_sym_DASH_DASH] = ACTIONS(2117),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2115),
    [anon_sym_DASH] = ACTIONS(2115),
    [anon_sym_STAR] = ACTIONS(1903),
    [anon_sym_CARET] = ACTIONS(2117),
    [anon_sym_AMP] = ACTIONS(2117),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2119),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2121),
    [anon_sym_DOT_DOT] = ACTIONS(2123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1170] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6911),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2930),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7031),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4787),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3742),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7420),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9374),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(1170),
    [sym_preproc_endregion] = STATE(1170),
    [sym_preproc_line] = STATE(1170),
    [sym_preproc_pragma] = STATE(1170),
    [sym_preproc_nullable] = STATE(1170),
    [sym_preproc_error] = STATE(1170),
    [sym_preproc_warning] = STATE(1170),
    [sym_preproc_define] = STATE(1170),
    [sym_preproc_undef] = STATE(1170),
    [aux_sym_class_declaration_repeat1] = STATE(3861),
    [aux_sym_lambda_expression_repeat1] = STATE(4169),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(2089),
    [anon_sym_ref] = ACTIONS(2091),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1695),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(2095),
    [anon_sym_TILDE] = ACTIONS(2095),
    [anon_sym_PLUS_PLUS] = ACTIONS(2095),
    [anon_sym_DASH_DASH] = ACTIONS(2095),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(2093),
    [anon_sym_DASH] = ACTIONS(2093),
    [anon_sym_STAR] = ACTIONS(1705),
    [anon_sym_CARET] = ACTIONS(2095),
    [anon_sym_AMP] = ACTIONS(2095),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(2097),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2099),
    [anon_sym_DOT_DOT] = ACTIONS(2101),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [1171] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6948),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2940),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6999),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4972),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3857),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7444),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9574),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1171),
    [sym_preproc_endregion] = STATE(1171),
    [sym_preproc_line] = STATE(1171),
    [sym_preproc_pragma] = STATE(1171),
    [sym_preproc_nullable] = STATE(1171),
    [sym_preproc_error] = STATE(1171),
    [sym_preproc_warning] = STATE(1171),
    [sym_preproc_define] = STATE(1171),
    [sym_preproc_undef] = STATE(1171),
    [aux_sym_class_declaration_repeat1] = STATE(3854),
    [aux_sym_lambda_expression_repeat1] = STATE(4136),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2111),
    [anon_sym_ref] = ACTIONS(2113),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1897),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2117),
    [anon_sym_TILDE] = ACTIONS(2117),
    [anon_sym_PLUS_PLUS] = ACTIONS(2117),
    [anon_sym_DASH_DASH] = ACTIONS(2117),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2115),
    [anon_sym_DASH] = ACTIONS(2115),
    [anon_sym_STAR] = ACTIONS(1903),
    [anon_sym_CARET] = ACTIONS(2117),
    [anon_sym_AMP] = ACTIONS(2117),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2119),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2121),
    [anon_sym_DOT_DOT] = ACTIONS(2123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1172] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6911),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2930),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7027),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4488),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3605),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7434),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9856),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(1172),
    [sym_preproc_endregion] = STATE(1172),
    [sym_preproc_line] = STATE(1172),
    [sym_preproc_pragma] = STATE(1172),
    [sym_preproc_nullable] = STATE(1172),
    [sym_preproc_error] = STATE(1172),
    [sym_preproc_warning] = STATE(1172),
    [sym_preproc_define] = STATE(1172),
    [sym_preproc_undef] = STATE(1172),
    [aux_sym_class_declaration_repeat1] = STATE(3828),
    [aux_sym_lambda_expression_repeat1] = STATE(4248),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1687),
    [anon_sym_ref] = ACTIONS(1689),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1695),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1701),
    [anon_sym_TILDE] = ACTIONS(1701),
    [anon_sym_PLUS_PLUS] = ACTIONS(1701),
    [anon_sym_DASH_DASH] = ACTIONS(1701),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1699),
    [anon_sym_DASH] = ACTIONS(1699),
    [anon_sym_STAR] = ACTIONS(1705),
    [anon_sym_CARET] = ACTIONS(1701),
    [anon_sym_AMP] = ACTIONS(1701),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(1715),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1717),
    [anon_sym_DOT_DOT] = ACTIONS(1719),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [1173] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6911),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2930),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7031),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4756),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3742),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7420),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9374),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(1173),
    [sym_preproc_endregion] = STATE(1173),
    [sym_preproc_line] = STATE(1173),
    [sym_preproc_pragma] = STATE(1173),
    [sym_preproc_nullable] = STATE(1173),
    [sym_preproc_error] = STATE(1173),
    [sym_preproc_warning] = STATE(1173),
    [sym_preproc_define] = STATE(1173),
    [sym_preproc_undef] = STATE(1173),
    [aux_sym_class_declaration_repeat1] = STATE(3861),
    [aux_sym_lambda_expression_repeat1] = STATE(4169),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(2089),
    [anon_sym_ref] = ACTIONS(2091),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1695),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(2095),
    [anon_sym_TILDE] = ACTIONS(2095),
    [anon_sym_PLUS_PLUS] = ACTIONS(2095),
    [anon_sym_DASH_DASH] = ACTIONS(2095),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(2093),
    [anon_sym_DASH] = ACTIONS(2093),
    [anon_sym_STAR] = ACTIONS(1705),
    [anon_sym_CARET] = ACTIONS(2095),
    [anon_sym_AMP] = ACTIONS(2095),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(2097),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2099),
    [anon_sym_DOT_DOT] = ACTIONS(2101),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [1174] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7105),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4338),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1174),
    [sym_preproc_endregion] = STATE(1174),
    [sym_preproc_line] = STATE(1174),
    [sym_preproc_pragma] = STATE(1174),
    [sym_preproc_nullable] = STATE(1174),
    [sym_preproc_error] = STATE(1174),
    [sym_preproc_warning] = STATE(1174),
    [sym_preproc_define] = STATE(1174),
    [sym_preproc_undef] = STATE(1174),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1175] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6051),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1175),
    [sym_preproc_endregion] = STATE(1175),
    [sym_preproc_line] = STATE(1175),
    [sym_preproc_pragma] = STATE(1175),
    [sym_preproc_nullable] = STATE(1175),
    [sym_preproc_error] = STATE(1175),
    [sym_preproc_warning] = STATE(1175),
    [sym_preproc_define] = STATE(1175),
    [sym_preproc_undef] = STATE(1175),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1176] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6916),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7128),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4833),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3752),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7413),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9092),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1176),
    [sym_preproc_endregion] = STATE(1176),
    [sym_preproc_line] = STATE(1176),
    [sym_preproc_pragma] = STATE(1176),
    [sym_preproc_nullable] = STATE(1176),
    [sym_preproc_error] = STATE(1176),
    [sym_preproc_warning] = STATE(1176),
    [sym_preproc_define] = STATE(1176),
    [sym_preproc_undef] = STATE(1176),
    [aux_sym_class_declaration_repeat1] = STATE(3845),
    [aux_sym_lambda_expression_repeat1] = STATE(4181),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1241),
    [anon_sym_ref] = ACTIONS(1243),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1255),
    [anon_sym_TILDE] = ACTIONS(1255),
    [anon_sym_PLUS_PLUS] = ACTIONS(1255),
    [anon_sym_DASH_DASH] = ACTIONS(1255),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1253),
    [anon_sym_DASH] = ACTIONS(1253),
    [anon_sym_STAR] = ACTIONS(1259),
    [anon_sym_CARET] = ACTIONS(1255),
    [anon_sym_AMP] = ACTIONS(1255),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1269),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1271),
    [anon_sym_DOT_DOT] = ACTIONS(1273),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1177] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6916),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7128),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3567),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3752),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7413),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9092),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1177),
    [sym_preproc_endregion] = STATE(1177),
    [sym_preproc_line] = STATE(1177),
    [sym_preproc_pragma] = STATE(1177),
    [sym_preproc_nullable] = STATE(1177),
    [sym_preproc_error] = STATE(1177),
    [sym_preproc_warning] = STATE(1177),
    [sym_preproc_define] = STATE(1177),
    [sym_preproc_undef] = STATE(1177),
    [aux_sym_class_declaration_repeat1] = STATE(3845),
    [aux_sym_lambda_expression_repeat1] = STATE(4181),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1241),
    [anon_sym_ref] = ACTIONS(1243),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1255),
    [anon_sym_TILDE] = ACTIONS(1255),
    [anon_sym_PLUS_PLUS] = ACTIONS(1255),
    [anon_sym_DASH_DASH] = ACTIONS(1255),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1253),
    [anon_sym_DASH] = ACTIONS(1253),
    [anon_sym_STAR] = ACTIONS(1259),
    [anon_sym_CARET] = ACTIONS(1255),
    [anon_sym_AMP] = ACTIONS(1255),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1269),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1271),
    [anon_sym_DOT_DOT] = ACTIONS(1273),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1178] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6911),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2930),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7031),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4899),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3742),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7420),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9374),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(1178),
    [sym_preproc_endregion] = STATE(1178),
    [sym_preproc_line] = STATE(1178),
    [sym_preproc_pragma] = STATE(1178),
    [sym_preproc_nullable] = STATE(1178),
    [sym_preproc_error] = STATE(1178),
    [sym_preproc_warning] = STATE(1178),
    [sym_preproc_define] = STATE(1178),
    [sym_preproc_undef] = STATE(1178),
    [aux_sym_class_declaration_repeat1] = STATE(3861),
    [aux_sym_lambda_expression_repeat1] = STATE(4169),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(2089),
    [anon_sym_ref] = ACTIONS(2091),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1695),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(2095),
    [anon_sym_TILDE] = ACTIONS(2095),
    [anon_sym_PLUS_PLUS] = ACTIONS(2095),
    [anon_sym_DASH_DASH] = ACTIONS(2095),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(2093),
    [anon_sym_DASH] = ACTIONS(2093),
    [anon_sym_STAR] = ACTIONS(1705),
    [anon_sym_CARET] = ACTIONS(2095),
    [anon_sym_AMP] = ACTIONS(2095),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(2097),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2099),
    [anon_sym_DOT_DOT] = ACTIONS(2101),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [1179] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6911),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2930),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7031),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4914),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3742),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7420),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9374),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(1179),
    [sym_preproc_endregion] = STATE(1179),
    [sym_preproc_line] = STATE(1179),
    [sym_preproc_pragma] = STATE(1179),
    [sym_preproc_nullable] = STATE(1179),
    [sym_preproc_error] = STATE(1179),
    [sym_preproc_warning] = STATE(1179),
    [sym_preproc_define] = STATE(1179),
    [sym_preproc_undef] = STATE(1179),
    [aux_sym_class_declaration_repeat1] = STATE(3861),
    [aux_sym_lambda_expression_repeat1] = STATE(4169),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(2089),
    [anon_sym_ref] = ACTIONS(2091),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1695),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(2095),
    [anon_sym_TILDE] = ACTIONS(2095),
    [anon_sym_PLUS_PLUS] = ACTIONS(2095),
    [anon_sym_DASH_DASH] = ACTIONS(2095),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(2093),
    [anon_sym_DASH] = ACTIONS(2093),
    [anon_sym_STAR] = ACTIONS(1705),
    [anon_sym_CARET] = ACTIONS(2095),
    [anon_sym_AMP] = ACTIONS(2095),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(2097),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2099),
    [anon_sym_DOT_DOT] = ACTIONS(2101),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [1180] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6911),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2930),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7031),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4916),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3742),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7420),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9374),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(1180),
    [sym_preproc_endregion] = STATE(1180),
    [sym_preproc_line] = STATE(1180),
    [sym_preproc_pragma] = STATE(1180),
    [sym_preproc_nullable] = STATE(1180),
    [sym_preproc_error] = STATE(1180),
    [sym_preproc_warning] = STATE(1180),
    [sym_preproc_define] = STATE(1180),
    [sym_preproc_undef] = STATE(1180),
    [aux_sym_class_declaration_repeat1] = STATE(3861),
    [aux_sym_lambda_expression_repeat1] = STATE(4169),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(2089),
    [anon_sym_ref] = ACTIONS(2091),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1695),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(2095),
    [anon_sym_TILDE] = ACTIONS(2095),
    [anon_sym_PLUS_PLUS] = ACTIONS(2095),
    [anon_sym_DASH_DASH] = ACTIONS(2095),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(2093),
    [anon_sym_DASH] = ACTIONS(2093),
    [anon_sym_STAR] = ACTIONS(1705),
    [anon_sym_CARET] = ACTIONS(2095),
    [anon_sym_AMP] = ACTIONS(2095),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(2097),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2099),
    [anon_sym_DOT_DOT] = ACTIONS(2101),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [1181] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6911),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2930),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7031),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4918),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3742),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7420),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9374),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(1181),
    [sym_preproc_endregion] = STATE(1181),
    [sym_preproc_line] = STATE(1181),
    [sym_preproc_pragma] = STATE(1181),
    [sym_preproc_nullable] = STATE(1181),
    [sym_preproc_error] = STATE(1181),
    [sym_preproc_warning] = STATE(1181),
    [sym_preproc_define] = STATE(1181),
    [sym_preproc_undef] = STATE(1181),
    [aux_sym_class_declaration_repeat1] = STATE(3861),
    [aux_sym_lambda_expression_repeat1] = STATE(4169),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(2089),
    [anon_sym_ref] = ACTIONS(2091),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1695),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(2095),
    [anon_sym_TILDE] = ACTIONS(2095),
    [anon_sym_PLUS_PLUS] = ACTIONS(2095),
    [anon_sym_DASH_DASH] = ACTIONS(2095),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(2093),
    [anon_sym_DASH] = ACTIONS(2093),
    [anon_sym_STAR] = ACTIONS(1705),
    [anon_sym_CARET] = ACTIONS(2095),
    [anon_sym_AMP] = ACTIONS(2095),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(2097),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2099),
    [anon_sym_DOT_DOT] = ACTIONS(2101),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [1182] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6911),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2930),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7031),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4922),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3742),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7420),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9374),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(1182),
    [sym_preproc_endregion] = STATE(1182),
    [sym_preproc_line] = STATE(1182),
    [sym_preproc_pragma] = STATE(1182),
    [sym_preproc_nullable] = STATE(1182),
    [sym_preproc_error] = STATE(1182),
    [sym_preproc_warning] = STATE(1182),
    [sym_preproc_define] = STATE(1182),
    [sym_preproc_undef] = STATE(1182),
    [aux_sym_class_declaration_repeat1] = STATE(3861),
    [aux_sym_lambda_expression_repeat1] = STATE(4169),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(2089),
    [anon_sym_ref] = ACTIONS(2091),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1695),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(2095),
    [anon_sym_TILDE] = ACTIONS(2095),
    [anon_sym_PLUS_PLUS] = ACTIONS(2095),
    [anon_sym_DASH_DASH] = ACTIONS(2095),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(2093),
    [anon_sym_DASH] = ACTIONS(2093),
    [anon_sym_STAR] = ACTIONS(1705),
    [anon_sym_CARET] = ACTIONS(2095),
    [anon_sym_AMP] = ACTIONS(2095),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(2097),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2099),
    [anon_sym_DOT_DOT] = ACTIONS(2101),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [1183] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6911),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2930),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7031),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4923),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3742),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7420),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9374),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(1183),
    [sym_preproc_endregion] = STATE(1183),
    [sym_preproc_line] = STATE(1183),
    [sym_preproc_pragma] = STATE(1183),
    [sym_preproc_nullable] = STATE(1183),
    [sym_preproc_error] = STATE(1183),
    [sym_preproc_warning] = STATE(1183),
    [sym_preproc_define] = STATE(1183),
    [sym_preproc_undef] = STATE(1183),
    [aux_sym_class_declaration_repeat1] = STATE(3861),
    [aux_sym_lambda_expression_repeat1] = STATE(4169),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(2089),
    [anon_sym_ref] = ACTIONS(2091),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1695),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(2095),
    [anon_sym_TILDE] = ACTIONS(2095),
    [anon_sym_PLUS_PLUS] = ACTIONS(2095),
    [anon_sym_DASH_DASH] = ACTIONS(2095),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(2093),
    [anon_sym_DASH] = ACTIONS(2093),
    [anon_sym_STAR] = ACTIONS(1705),
    [anon_sym_CARET] = ACTIONS(2095),
    [anon_sym_AMP] = ACTIONS(2095),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(2097),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2099),
    [anon_sym_DOT_DOT] = ACTIONS(2101),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [1184] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6911),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2930),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7031),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4924),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3742),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7420),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9374),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(1184),
    [sym_preproc_endregion] = STATE(1184),
    [sym_preproc_line] = STATE(1184),
    [sym_preproc_pragma] = STATE(1184),
    [sym_preproc_nullable] = STATE(1184),
    [sym_preproc_error] = STATE(1184),
    [sym_preproc_warning] = STATE(1184),
    [sym_preproc_define] = STATE(1184),
    [sym_preproc_undef] = STATE(1184),
    [aux_sym_class_declaration_repeat1] = STATE(3861),
    [aux_sym_lambda_expression_repeat1] = STATE(4169),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(2089),
    [anon_sym_ref] = ACTIONS(2091),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1695),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(2095),
    [anon_sym_TILDE] = ACTIONS(2095),
    [anon_sym_PLUS_PLUS] = ACTIONS(2095),
    [anon_sym_DASH_DASH] = ACTIONS(2095),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(2093),
    [anon_sym_DASH] = ACTIONS(2093),
    [anon_sym_STAR] = ACTIONS(1705),
    [anon_sym_CARET] = ACTIONS(2095),
    [anon_sym_AMP] = ACTIONS(2095),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(2097),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2099),
    [anon_sym_DOT_DOT] = ACTIONS(2101),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [1185] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6911),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2930),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7031),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4928),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3742),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7420),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9374),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(1185),
    [sym_preproc_endregion] = STATE(1185),
    [sym_preproc_line] = STATE(1185),
    [sym_preproc_pragma] = STATE(1185),
    [sym_preproc_nullable] = STATE(1185),
    [sym_preproc_error] = STATE(1185),
    [sym_preproc_warning] = STATE(1185),
    [sym_preproc_define] = STATE(1185),
    [sym_preproc_undef] = STATE(1185),
    [aux_sym_class_declaration_repeat1] = STATE(3861),
    [aux_sym_lambda_expression_repeat1] = STATE(4169),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(2089),
    [anon_sym_ref] = ACTIONS(2091),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1695),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(2095),
    [anon_sym_TILDE] = ACTIONS(2095),
    [anon_sym_PLUS_PLUS] = ACTIONS(2095),
    [anon_sym_DASH_DASH] = ACTIONS(2095),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(2093),
    [anon_sym_DASH] = ACTIONS(2093),
    [anon_sym_STAR] = ACTIONS(1705),
    [anon_sym_CARET] = ACTIONS(2095),
    [anon_sym_AMP] = ACTIONS(2095),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(2097),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2099),
    [anon_sym_DOT_DOT] = ACTIONS(2101),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [1186] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6911),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2930),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7031),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4944),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3742),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7420),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9374),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(1186),
    [sym_preproc_endregion] = STATE(1186),
    [sym_preproc_line] = STATE(1186),
    [sym_preproc_pragma] = STATE(1186),
    [sym_preproc_nullable] = STATE(1186),
    [sym_preproc_error] = STATE(1186),
    [sym_preproc_warning] = STATE(1186),
    [sym_preproc_define] = STATE(1186),
    [sym_preproc_undef] = STATE(1186),
    [aux_sym_class_declaration_repeat1] = STATE(3861),
    [aux_sym_lambda_expression_repeat1] = STATE(4169),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(2089),
    [anon_sym_ref] = ACTIONS(2091),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1695),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(2095),
    [anon_sym_TILDE] = ACTIONS(2095),
    [anon_sym_PLUS_PLUS] = ACTIONS(2095),
    [anon_sym_DASH_DASH] = ACTIONS(2095),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(2093),
    [anon_sym_DASH] = ACTIONS(2093),
    [anon_sym_STAR] = ACTIONS(1705),
    [anon_sym_CARET] = ACTIONS(2095),
    [anon_sym_AMP] = ACTIONS(2095),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(2097),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2099),
    [anon_sym_DOT_DOT] = ACTIONS(2101),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [1187] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6911),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2930),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7031),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4880),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3742),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7420),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9374),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(1187),
    [sym_preproc_endregion] = STATE(1187),
    [sym_preproc_line] = STATE(1187),
    [sym_preproc_pragma] = STATE(1187),
    [sym_preproc_nullable] = STATE(1187),
    [sym_preproc_error] = STATE(1187),
    [sym_preproc_warning] = STATE(1187),
    [sym_preproc_define] = STATE(1187),
    [sym_preproc_undef] = STATE(1187),
    [aux_sym_class_declaration_repeat1] = STATE(3861),
    [aux_sym_lambda_expression_repeat1] = STATE(4169),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(2089),
    [anon_sym_ref] = ACTIONS(2091),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1695),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(2095),
    [anon_sym_TILDE] = ACTIONS(2095),
    [anon_sym_PLUS_PLUS] = ACTIONS(2095),
    [anon_sym_DASH_DASH] = ACTIONS(2095),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(2093),
    [anon_sym_DASH] = ACTIONS(2093),
    [anon_sym_STAR] = ACTIONS(1705),
    [anon_sym_CARET] = ACTIONS(2095),
    [anon_sym_AMP] = ACTIONS(2095),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(2097),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2099),
    [anon_sym_DOT_DOT] = ACTIONS(2101),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [1188] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6911),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2930),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7031),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4886),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3742),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7420),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9374),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(1188),
    [sym_preproc_endregion] = STATE(1188),
    [sym_preproc_line] = STATE(1188),
    [sym_preproc_pragma] = STATE(1188),
    [sym_preproc_nullable] = STATE(1188),
    [sym_preproc_error] = STATE(1188),
    [sym_preproc_warning] = STATE(1188),
    [sym_preproc_define] = STATE(1188),
    [sym_preproc_undef] = STATE(1188),
    [aux_sym_class_declaration_repeat1] = STATE(3861),
    [aux_sym_lambda_expression_repeat1] = STATE(4169),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(2089),
    [anon_sym_ref] = ACTIONS(2091),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1695),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(2095),
    [anon_sym_TILDE] = ACTIONS(2095),
    [anon_sym_PLUS_PLUS] = ACTIONS(2095),
    [anon_sym_DASH_DASH] = ACTIONS(2095),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(2093),
    [anon_sym_DASH] = ACTIONS(2093),
    [anon_sym_STAR] = ACTIONS(1705),
    [anon_sym_CARET] = ACTIONS(2095),
    [anon_sym_AMP] = ACTIONS(2095),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(2097),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2099),
    [anon_sym_DOT_DOT] = ACTIONS(2101),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [1189] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6916),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7128),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4847),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3752),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7413),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9092),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1189),
    [sym_preproc_endregion] = STATE(1189),
    [sym_preproc_line] = STATE(1189),
    [sym_preproc_pragma] = STATE(1189),
    [sym_preproc_nullable] = STATE(1189),
    [sym_preproc_error] = STATE(1189),
    [sym_preproc_warning] = STATE(1189),
    [sym_preproc_define] = STATE(1189),
    [sym_preproc_undef] = STATE(1189),
    [aux_sym_class_declaration_repeat1] = STATE(3845),
    [aux_sym_lambda_expression_repeat1] = STATE(4181),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1241),
    [anon_sym_ref] = ACTIONS(1243),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1255),
    [anon_sym_TILDE] = ACTIONS(1255),
    [anon_sym_PLUS_PLUS] = ACTIONS(1255),
    [anon_sym_DASH_DASH] = ACTIONS(1255),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1253),
    [anon_sym_DASH] = ACTIONS(1253),
    [anon_sym_STAR] = ACTIONS(1259),
    [anon_sym_CARET] = ACTIONS(1255),
    [anon_sym_AMP] = ACTIONS(1255),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1269),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1271),
    [anon_sym_DOT_DOT] = ACTIONS(1273),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1190] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6911),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2930),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7031),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4389),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3742),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7420),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9374),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(1190),
    [sym_preproc_endregion] = STATE(1190),
    [sym_preproc_line] = STATE(1190),
    [sym_preproc_pragma] = STATE(1190),
    [sym_preproc_nullable] = STATE(1190),
    [sym_preproc_error] = STATE(1190),
    [sym_preproc_warning] = STATE(1190),
    [sym_preproc_define] = STATE(1190),
    [sym_preproc_undef] = STATE(1190),
    [aux_sym_class_declaration_repeat1] = STATE(3861),
    [aux_sym_lambda_expression_repeat1] = STATE(4169),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(2089),
    [anon_sym_ref] = ACTIONS(2091),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1695),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(2095),
    [anon_sym_TILDE] = ACTIONS(2095),
    [anon_sym_PLUS_PLUS] = ACTIONS(2095),
    [anon_sym_DASH_DASH] = ACTIONS(2095),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(2093),
    [anon_sym_DASH] = ACTIONS(2093),
    [anon_sym_STAR] = ACTIONS(1705),
    [anon_sym_CARET] = ACTIONS(2095),
    [anon_sym_AMP] = ACTIONS(2095),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(2097),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2099),
    [anon_sym_DOT_DOT] = ACTIONS(2101),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [1191] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6915),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7018),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4466),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3585),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7418),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9926),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1191),
    [sym_preproc_endregion] = STATE(1191),
    [sym_preproc_line] = STATE(1191),
    [sym_preproc_pragma] = STATE(1191),
    [sym_preproc_nullable] = STATE(1191),
    [sym_preproc_error] = STATE(1191),
    [sym_preproc_warning] = STATE(1191),
    [sym_preproc_define] = STATE(1191),
    [sym_preproc_undef] = STATE(1191),
    [aux_sym_class_declaration_repeat1] = STATE(3825),
    [aux_sym_lambda_expression_repeat1] = STATE(4244),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1161),
    [anon_sym_ref] = ACTIONS(1163),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1177),
    [anon_sym_TILDE] = ACTIONS(1177),
    [anon_sym_PLUS_PLUS] = ACTIONS(1177),
    [anon_sym_DASH_DASH] = ACTIONS(1177),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1175),
    [anon_sym_DASH] = ACTIONS(1175),
    [anon_sym_STAR] = ACTIONS(1181),
    [anon_sym_CARET] = ACTIONS(1177),
    [anon_sym_AMP] = ACTIONS(1177),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1191),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1193),
    [anon_sym_DOT_DOT] = ACTIONS(1195),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1192] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6929),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6473),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4473),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9905),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1192),
    [sym_preproc_endregion] = STATE(1192),
    [sym_preproc_line] = STATE(1192),
    [sym_preproc_pragma] = STATE(1192),
    [sym_preproc_nullable] = STATE(1192),
    [sym_preproc_error] = STATE(1192),
    [sym_preproc_warning] = STATE(1192),
    [sym_preproc_define] = STATE(1192),
    [sym_preproc_undef] = STATE(1192),
    [aux_sym_class_declaration_repeat1] = STATE(3878),
    [aux_sym_lambda_expression_repeat1] = STATE(4331),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2055),
    [anon_sym_ref] = ACTIONS(2057),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2061),
    [anon_sym_TILDE] = ACTIONS(2061),
    [anon_sym_PLUS_PLUS] = ACTIONS(2061),
    [anon_sym_DASH_DASH] = ACTIONS(2061),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2059),
    [anon_sym_DASH] = ACTIONS(2059),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(2061),
    [anon_sym_AMP] = ACTIONS(2061),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2063),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2065),
    [anon_sym_DOT_DOT] = ACTIONS(2067),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1193] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6948),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2940),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6999),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5116),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3857),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7444),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9574),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1193),
    [sym_preproc_endregion] = STATE(1193),
    [sym_preproc_line] = STATE(1193),
    [sym_preproc_pragma] = STATE(1193),
    [sym_preproc_nullable] = STATE(1193),
    [sym_preproc_error] = STATE(1193),
    [sym_preproc_warning] = STATE(1193),
    [sym_preproc_define] = STATE(1193),
    [sym_preproc_undef] = STATE(1193),
    [aux_sym_class_declaration_repeat1] = STATE(3854),
    [aux_sym_lambda_expression_repeat1] = STATE(4136),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2111),
    [anon_sym_ref] = ACTIONS(2113),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1897),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2117),
    [anon_sym_TILDE] = ACTIONS(2117),
    [anon_sym_PLUS_PLUS] = ACTIONS(2117),
    [anon_sym_DASH_DASH] = ACTIONS(2117),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2115),
    [anon_sym_DASH] = ACTIONS(2115),
    [anon_sym_STAR] = ACTIONS(1903),
    [anon_sym_CARET] = ACTIONS(2117),
    [anon_sym_AMP] = ACTIONS(2117),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2119),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2121),
    [anon_sym_DOT_DOT] = ACTIONS(2123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1194] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6916),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7128),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4905),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3752),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7413),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9092),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1194),
    [sym_preproc_endregion] = STATE(1194),
    [sym_preproc_line] = STATE(1194),
    [sym_preproc_pragma] = STATE(1194),
    [sym_preproc_nullable] = STATE(1194),
    [sym_preproc_error] = STATE(1194),
    [sym_preproc_warning] = STATE(1194),
    [sym_preproc_define] = STATE(1194),
    [sym_preproc_undef] = STATE(1194),
    [aux_sym_class_declaration_repeat1] = STATE(3845),
    [aux_sym_lambda_expression_repeat1] = STATE(4181),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1241),
    [anon_sym_ref] = ACTIONS(1243),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1255),
    [anon_sym_TILDE] = ACTIONS(1255),
    [anon_sym_PLUS_PLUS] = ACTIONS(1255),
    [anon_sym_DASH_DASH] = ACTIONS(1255),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1253),
    [anon_sym_DASH] = ACTIONS(1253),
    [anon_sym_STAR] = ACTIONS(1259),
    [anon_sym_CARET] = ACTIONS(1255),
    [anon_sym_AMP] = ACTIONS(1255),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1269),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1271),
    [anon_sym_DOT_DOT] = ACTIONS(1273),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1195] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7131),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6152),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4364),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9470),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1195),
    [sym_preproc_endregion] = STATE(1195),
    [sym_preproc_line] = STATE(1195),
    [sym_preproc_pragma] = STATE(1195),
    [sym_preproc_nullable] = STATE(1195),
    [sym_preproc_error] = STATE(1195),
    [sym_preproc_warning] = STATE(1195),
    [sym_preproc_define] = STATE(1195),
    [sym_preproc_undef] = STATE(1195),
    [aux_sym_class_declaration_repeat1] = STATE(3870),
    [aux_sym_lambda_expression_repeat1] = STATE(4302),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1555),
    [anon_sym_ref] = ACTIONS(1557),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(695),
    [anon_sym_TILDE] = ACTIONS(695),
    [anon_sym_PLUS_PLUS] = ACTIONS(695),
    [anon_sym_DASH_DASH] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(697),
    [anon_sym_DASH] = ACTIONS(697),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(695),
    [anon_sym_AMP] = ACTIONS(695),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1559),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1561),
    [anon_sym_DOT_DOT] = ACTIONS(1563),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1196] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7131),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6162),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4364),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9470),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1196),
    [sym_preproc_endregion] = STATE(1196),
    [sym_preproc_line] = STATE(1196),
    [sym_preproc_pragma] = STATE(1196),
    [sym_preproc_nullable] = STATE(1196),
    [sym_preproc_error] = STATE(1196),
    [sym_preproc_warning] = STATE(1196),
    [sym_preproc_define] = STATE(1196),
    [sym_preproc_undef] = STATE(1196),
    [aux_sym_class_declaration_repeat1] = STATE(3870),
    [aux_sym_lambda_expression_repeat1] = STATE(4302),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1555),
    [anon_sym_ref] = ACTIONS(1557),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(695),
    [anon_sym_TILDE] = ACTIONS(695),
    [anon_sym_PLUS_PLUS] = ACTIONS(695),
    [anon_sym_DASH_DASH] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(697),
    [anon_sym_DASH] = ACTIONS(697),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(695),
    [anon_sym_AMP] = ACTIONS(695),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1559),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1561),
    [anon_sym_DOT_DOT] = ACTIONS(1563),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1197] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6962),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5164),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3931),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9818),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1197),
    [sym_preproc_endregion] = STATE(1197),
    [sym_preproc_line] = STATE(1197),
    [sym_preproc_pragma] = STATE(1197),
    [sym_preproc_nullable] = STATE(1197),
    [sym_preproc_error] = STATE(1197),
    [sym_preproc_warning] = STATE(1197),
    [sym_preproc_define] = STATE(1197),
    [sym_preproc_undef] = STATE(1197),
    [aux_sym_class_declaration_repeat1] = STATE(3811),
    [aux_sym_lambda_expression_repeat1] = STATE(4201),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1373),
    [anon_sym_ref] = ACTIONS(1375),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1379),
    [anon_sym_TILDE] = ACTIONS(1379),
    [anon_sym_PLUS_PLUS] = ACTIONS(1379),
    [anon_sym_DASH_DASH] = ACTIONS(1379),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1377),
    [anon_sym_DASH] = ACTIONS(1377),
    [anon_sym_STAR] = ACTIONS(1381),
    [anon_sym_CARET] = ACTIONS(1379),
    [anon_sym_AMP] = ACTIONS(1379),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1383),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1385),
    [anon_sym_DOT_DOT] = ACTIONS(1387),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1198] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6921),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2873),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(6957),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5873),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4346),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7445),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9875),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(1198),
    [sym_preproc_endregion] = STATE(1198),
    [sym_preproc_line] = STATE(1198),
    [sym_preproc_pragma] = STATE(1198),
    [sym_preproc_nullable] = STATE(1198),
    [sym_preproc_error] = STATE(1198),
    [sym_preproc_warning] = STATE(1198),
    [sym_preproc_define] = STATE(1198),
    [sym_preproc_undef] = STATE(1198),
    [aux_sym_class_declaration_repeat1] = STATE(3810),
    [aux_sym_lambda_expression_repeat1] = STATE(4192),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1639),
    [anon_sym_ref] = ACTIONS(1641),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1415),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1645),
    [anon_sym_TILDE] = ACTIONS(1645),
    [anon_sym_PLUS_PLUS] = ACTIONS(1645),
    [anon_sym_DASH_DASH] = ACTIONS(1645),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1643),
    [anon_sym_DASH] = ACTIONS(1643),
    [anon_sym_STAR] = ACTIONS(1425),
    [anon_sym_CARET] = ACTIONS(1645),
    [anon_sym_AMP] = ACTIONS(1645),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1647),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1649),
    [anon_sym_DOT_DOT] = ACTIONS(1651),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [1199] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6921),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2873),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(6957),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5156),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4346),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7445),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9875),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(1199),
    [sym_preproc_endregion] = STATE(1199),
    [sym_preproc_line] = STATE(1199),
    [sym_preproc_pragma] = STATE(1199),
    [sym_preproc_nullable] = STATE(1199),
    [sym_preproc_error] = STATE(1199),
    [sym_preproc_warning] = STATE(1199),
    [sym_preproc_define] = STATE(1199),
    [sym_preproc_undef] = STATE(1199),
    [aux_sym_class_declaration_repeat1] = STATE(3810),
    [aux_sym_lambda_expression_repeat1] = STATE(4192),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1639),
    [anon_sym_ref] = ACTIONS(1641),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1415),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1645),
    [anon_sym_TILDE] = ACTIONS(1645),
    [anon_sym_PLUS_PLUS] = ACTIONS(1645),
    [anon_sym_DASH_DASH] = ACTIONS(1645),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1643),
    [anon_sym_DASH] = ACTIONS(1643),
    [anon_sym_STAR] = ACTIONS(1425),
    [anon_sym_CARET] = ACTIONS(1645),
    [anon_sym_AMP] = ACTIONS(1645),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1647),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1649),
    [anon_sym_DOT_DOT] = ACTIONS(1651),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [1200] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6916),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7128),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4865),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3752),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7413),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9092),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1200),
    [sym_preproc_endregion] = STATE(1200),
    [sym_preproc_line] = STATE(1200),
    [sym_preproc_pragma] = STATE(1200),
    [sym_preproc_nullable] = STATE(1200),
    [sym_preproc_error] = STATE(1200),
    [sym_preproc_warning] = STATE(1200),
    [sym_preproc_define] = STATE(1200),
    [sym_preproc_undef] = STATE(1200),
    [aux_sym_class_declaration_repeat1] = STATE(3845),
    [aux_sym_lambda_expression_repeat1] = STATE(4181),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1241),
    [anon_sym_ref] = ACTIONS(1243),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1255),
    [anon_sym_TILDE] = ACTIONS(1255),
    [anon_sym_PLUS_PLUS] = ACTIONS(1255),
    [anon_sym_DASH_DASH] = ACTIONS(1255),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1253),
    [anon_sym_DASH] = ACTIONS(1253),
    [anon_sym_STAR] = ACTIONS(1259),
    [anon_sym_CARET] = ACTIONS(1255),
    [anon_sym_AMP] = ACTIONS(1255),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1269),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1271),
    [anon_sym_DOT_DOT] = ACTIONS(1273),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1201] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6916),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7128),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4816),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3752),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7413),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9092),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1201),
    [sym_preproc_endregion] = STATE(1201),
    [sym_preproc_line] = STATE(1201),
    [sym_preproc_pragma] = STATE(1201),
    [sym_preproc_nullable] = STATE(1201),
    [sym_preproc_error] = STATE(1201),
    [sym_preproc_warning] = STATE(1201),
    [sym_preproc_define] = STATE(1201),
    [sym_preproc_undef] = STATE(1201),
    [aux_sym_class_declaration_repeat1] = STATE(3845),
    [aux_sym_lambda_expression_repeat1] = STATE(4181),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1241),
    [anon_sym_ref] = ACTIONS(1243),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1255),
    [anon_sym_TILDE] = ACTIONS(1255),
    [anon_sym_PLUS_PLUS] = ACTIONS(1255),
    [anon_sym_DASH_DASH] = ACTIONS(1255),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1253),
    [anon_sym_DASH] = ACTIONS(1253),
    [anon_sym_STAR] = ACTIONS(1259),
    [anon_sym_CARET] = ACTIONS(1255),
    [anon_sym_AMP] = ACTIONS(1255),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1269),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1271),
    [anon_sym_DOT_DOT] = ACTIONS(1273),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1202] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6916),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7128),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4878),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3752),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7413),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9092),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1202),
    [sym_preproc_endregion] = STATE(1202),
    [sym_preproc_line] = STATE(1202),
    [sym_preproc_pragma] = STATE(1202),
    [sym_preproc_nullable] = STATE(1202),
    [sym_preproc_error] = STATE(1202),
    [sym_preproc_warning] = STATE(1202),
    [sym_preproc_define] = STATE(1202),
    [sym_preproc_undef] = STATE(1202),
    [aux_sym_class_declaration_repeat1] = STATE(3845),
    [aux_sym_lambda_expression_repeat1] = STATE(4181),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1241),
    [anon_sym_ref] = ACTIONS(1243),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1255),
    [anon_sym_TILDE] = ACTIONS(1255),
    [anon_sym_PLUS_PLUS] = ACTIONS(1255),
    [anon_sym_DASH_DASH] = ACTIONS(1255),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1253),
    [anon_sym_DASH] = ACTIONS(1253),
    [anon_sym_STAR] = ACTIONS(1259),
    [anon_sym_CARET] = ACTIONS(1255),
    [anon_sym_AMP] = ACTIONS(1255),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1269),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1271),
    [anon_sym_DOT_DOT] = ACTIONS(1273),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1203] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6916),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7128),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4938),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3752),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7413),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9092),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1203),
    [sym_preproc_endregion] = STATE(1203),
    [sym_preproc_line] = STATE(1203),
    [sym_preproc_pragma] = STATE(1203),
    [sym_preproc_nullable] = STATE(1203),
    [sym_preproc_error] = STATE(1203),
    [sym_preproc_warning] = STATE(1203),
    [sym_preproc_define] = STATE(1203),
    [sym_preproc_undef] = STATE(1203),
    [aux_sym_class_declaration_repeat1] = STATE(3845),
    [aux_sym_lambda_expression_repeat1] = STATE(4181),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1241),
    [anon_sym_ref] = ACTIONS(1243),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1255),
    [anon_sym_TILDE] = ACTIONS(1255),
    [anon_sym_PLUS_PLUS] = ACTIONS(1255),
    [anon_sym_DASH_DASH] = ACTIONS(1255),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1253),
    [anon_sym_DASH] = ACTIONS(1253),
    [anon_sym_STAR] = ACTIONS(1259),
    [anon_sym_CARET] = ACTIONS(1255),
    [anon_sym_AMP] = ACTIONS(1255),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1269),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1271),
    [anon_sym_DOT_DOT] = ACTIONS(1273),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1204] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6916),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7128),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4831),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3752),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7413),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9092),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1204),
    [sym_preproc_endregion] = STATE(1204),
    [sym_preproc_line] = STATE(1204),
    [sym_preproc_pragma] = STATE(1204),
    [sym_preproc_nullable] = STATE(1204),
    [sym_preproc_error] = STATE(1204),
    [sym_preproc_warning] = STATE(1204),
    [sym_preproc_define] = STATE(1204),
    [sym_preproc_undef] = STATE(1204),
    [aux_sym_class_declaration_repeat1] = STATE(3845),
    [aux_sym_lambda_expression_repeat1] = STATE(4181),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1241),
    [anon_sym_ref] = ACTIONS(1243),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1255),
    [anon_sym_TILDE] = ACTIONS(1255),
    [anon_sym_PLUS_PLUS] = ACTIONS(1255),
    [anon_sym_DASH_DASH] = ACTIONS(1255),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1253),
    [anon_sym_DASH] = ACTIONS(1253),
    [anon_sym_STAR] = ACTIONS(1259),
    [anon_sym_CARET] = ACTIONS(1255),
    [anon_sym_AMP] = ACTIONS(1255),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1269),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1271),
    [anon_sym_DOT_DOT] = ACTIONS(1273),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1205] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6916),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7128),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4837),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3752),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7413),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9092),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1205),
    [sym_preproc_endregion] = STATE(1205),
    [sym_preproc_line] = STATE(1205),
    [sym_preproc_pragma] = STATE(1205),
    [sym_preproc_nullable] = STATE(1205),
    [sym_preproc_error] = STATE(1205),
    [sym_preproc_warning] = STATE(1205),
    [sym_preproc_define] = STATE(1205),
    [sym_preproc_undef] = STATE(1205),
    [aux_sym_class_declaration_repeat1] = STATE(3845),
    [aux_sym_lambda_expression_repeat1] = STATE(4181),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1241),
    [anon_sym_ref] = ACTIONS(1243),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1255),
    [anon_sym_TILDE] = ACTIONS(1255),
    [anon_sym_PLUS_PLUS] = ACTIONS(1255),
    [anon_sym_DASH_DASH] = ACTIONS(1255),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1253),
    [anon_sym_DASH] = ACTIONS(1253),
    [anon_sym_STAR] = ACTIONS(1259),
    [anon_sym_CARET] = ACTIONS(1255),
    [anon_sym_AMP] = ACTIONS(1255),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1269),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1271),
    [anon_sym_DOT_DOT] = ACTIONS(1273),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1206] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6916),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7128),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4921),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3752),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7413),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9092),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1206),
    [sym_preproc_endregion] = STATE(1206),
    [sym_preproc_line] = STATE(1206),
    [sym_preproc_pragma] = STATE(1206),
    [sym_preproc_nullable] = STATE(1206),
    [sym_preproc_error] = STATE(1206),
    [sym_preproc_warning] = STATE(1206),
    [sym_preproc_define] = STATE(1206),
    [sym_preproc_undef] = STATE(1206),
    [aux_sym_class_declaration_repeat1] = STATE(3845),
    [aux_sym_lambda_expression_repeat1] = STATE(4181),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1241),
    [anon_sym_ref] = ACTIONS(1243),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1255),
    [anon_sym_TILDE] = ACTIONS(1255),
    [anon_sym_PLUS_PLUS] = ACTIONS(1255),
    [anon_sym_DASH_DASH] = ACTIONS(1255),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1253),
    [anon_sym_DASH] = ACTIONS(1253),
    [anon_sym_STAR] = ACTIONS(1259),
    [anon_sym_CARET] = ACTIONS(1255),
    [anon_sym_AMP] = ACTIONS(1255),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1269),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1271),
    [anon_sym_DOT_DOT] = ACTIONS(1273),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1207] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6916),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7128),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4945),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3752),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7413),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9092),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1207),
    [sym_preproc_endregion] = STATE(1207),
    [sym_preproc_line] = STATE(1207),
    [sym_preproc_pragma] = STATE(1207),
    [sym_preproc_nullable] = STATE(1207),
    [sym_preproc_error] = STATE(1207),
    [sym_preproc_warning] = STATE(1207),
    [sym_preproc_define] = STATE(1207),
    [sym_preproc_undef] = STATE(1207),
    [aux_sym_class_declaration_repeat1] = STATE(3845),
    [aux_sym_lambda_expression_repeat1] = STATE(4181),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1241),
    [anon_sym_ref] = ACTIONS(1243),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1255),
    [anon_sym_TILDE] = ACTIONS(1255),
    [anon_sym_PLUS_PLUS] = ACTIONS(1255),
    [anon_sym_DASH_DASH] = ACTIONS(1255),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1253),
    [anon_sym_DASH] = ACTIONS(1253),
    [anon_sym_STAR] = ACTIONS(1259),
    [anon_sym_CARET] = ACTIONS(1255),
    [anon_sym_AMP] = ACTIONS(1255),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1269),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1271),
    [anon_sym_DOT_DOT] = ACTIONS(1273),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1208] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6916),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7128),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4839),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3752),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7413),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9092),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1208),
    [sym_preproc_endregion] = STATE(1208),
    [sym_preproc_line] = STATE(1208),
    [sym_preproc_pragma] = STATE(1208),
    [sym_preproc_nullable] = STATE(1208),
    [sym_preproc_error] = STATE(1208),
    [sym_preproc_warning] = STATE(1208),
    [sym_preproc_define] = STATE(1208),
    [sym_preproc_undef] = STATE(1208),
    [aux_sym_class_declaration_repeat1] = STATE(3845),
    [aux_sym_lambda_expression_repeat1] = STATE(4181),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1241),
    [anon_sym_ref] = ACTIONS(1243),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1255),
    [anon_sym_TILDE] = ACTIONS(1255),
    [anon_sym_PLUS_PLUS] = ACTIONS(1255),
    [anon_sym_DASH_DASH] = ACTIONS(1255),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1253),
    [anon_sym_DASH] = ACTIONS(1253),
    [anon_sym_STAR] = ACTIONS(1259),
    [anon_sym_CARET] = ACTIONS(1255),
    [anon_sym_AMP] = ACTIONS(1255),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1269),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1271),
    [anon_sym_DOT_DOT] = ACTIONS(1273),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1209] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6916),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7128),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4850),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3752),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7413),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9092),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1209),
    [sym_preproc_endregion] = STATE(1209),
    [sym_preproc_line] = STATE(1209),
    [sym_preproc_pragma] = STATE(1209),
    [sym_preproc_nullable] = STATE(1209),
    [sym_preproc_error] = STATE(1209),
    [sym_preproc_warning] = STATE(1209),
    [sym_preproc_define] = STATE(1209),
    [sym_preproc_undef] = STATE(1209),
    [aux_sym_class_declaration_repeat1] = STATE(3845),
    [aux_sym_lambda_expression_repeat1] = STATE(4181),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1241),
    [anon_sym_ref] = ACTIONS(1243),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1255),
    [anon_sym_TILDE] = ACTIONS(1255),
    [anon_sym_PLUS_PLUS] = ACTIONS(1255),
    [anon_sym_DASH_DASH] = ACTIONS(1255),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1253),
    [anon_sym_DASH] = ACTIONS(1253),
    [anon_sym_STAR] = ACTIONS(1259),
    [anon_sym_CARET] = ACTIONS(1255),
    [anon_sym_AMP] = ACTIONS(1255),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1269),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1271),
    [anon_sym_DOT_DOT] = ACTIONS(1273),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1210] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6916),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7128),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4856),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3752),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7413),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9092),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1210),
    [sym_preproc_endregion] = STATE(1210),
    [sym_preproc_line] = STATE(1210),
    [sym_preproc_pragma] = STATE(1210),
    [sym_preproc_nullable] = STATE(1210),
    [sym_preproc_error] = STATE(1210),
    [sym_preproc_warning] = STATE(1210),
    [sym_preproc_define] = STATE(1210),
    [sym_preproc_undef] = STATE(1210),
    [aux_sym_class_declaration_repeat1] = STATE(3845),
    [aux_sym_lambda_expression_repeat1] = STATE(4181),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1241),
    [anon_sym_ref] = ACTIONS(1243),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1255),
    [anon_sym_TILDE] = ACTIONS(1255),
    [anon_sym_PLUS_PLUS] = ACTIONS(1255),
    [anon_sym_DASH_DASH] = ACTIONS(1255),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1253),
    [anon_sym_DASH] = ACTIONS(1253),
    [anon_sym_STAR] = ACTIONS(1259),
    [anon_sym_CARET] = ACTIONS(1255),
    [anon_sym_AMP] = ACTIONS(1255),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1269),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1271),
    [anon_sym_DOT_DOT] = ACTIONS(1273),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1211] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6921),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2873),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(6957),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6041),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4346),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7445),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9875),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(1211),
    [sym_preproc_endregion] = STATE(1211),
    [sym_preproc_line] = STATE(1211),
    [sym_preproc_pragma] = STATE(1211),
    [sym_preproc_nullable] = STATE(1211),
    [sym_preproc_error] = STATE(1211),
    [sym_preproc_warning] = STATE(1211),
    [sym_preproc_define] = STATE(1211),
    [sym_preproc_undef] = STATE(1211),
    [aux_sym_class_declaration_repeat1] = STATE(3810),
    [aux_sym_lambda_expression_repeat1] = STATE(4192),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1639),
    [anon_sym_ref] = ACTIONS(1641),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1415),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1645),
    [anon_sym_TILDE] = ACTIONS(1645),
    [anon_sym_PLUS_PLUS] = ACTIONS(1645),
    [anon_sym_DASH_DASH] = ACTIONS(1645),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1643),
    [anon_sym_DASH] = ACTIONS(1643),
    [anon_sym_STAR] = ACTIONS(1425),
    [anon_sym_CARET] = ACTIONS(1645),
    [anon_sym_AMP] = ACTIONS(1645),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1647),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1649),
    [anon_sym_DOT_DOT] = ACTIONS(1651),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [1212] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6916),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7128),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3582),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3752),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7413),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9092),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1212),
    [sym_preproc_endregion] = STATE(1212),
    [sym_preproc_line] = STATE(1212),
    [sym_preproc_pragma] = STATE(1212),
    [sym_preproc_nullable] = STATE(1212),
    [sym_preproc_error] = STATE(1212),
    [sym_preproc_warning] = STATE(1212),
    [sym_preproc_define] = STATE(1212),
    [sym_preproc_undef] = STATE(1212),
    [aux_sym_class_declaration_repeat1] = STATE(3845),
    [aux_sym_lambda_expression_repeat1] = STATE(4181),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1241),
    [anon_sym_ref] = ACTIONS(1243),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1255),
    [anon_sym_TILDE] = ACTIONS(1255),
    [anon_sym_PLUS_PLUS] = ACTIONS(1255),
    [anon_sym_DASH_DASH] = ACTIONS(1255),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1253),
    [anon_sym_DASH] = ACTIONS(1253),
    [anon_sym_STAR] = ACTIONS(1259),
    [anon_sym_CARET] = ACTIONS(1255),
    [anon_sym_AMP] = ACTIONS(1255),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1269),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1271),
    [anon_sym_DOT_DOT] = ACTIONS(1273),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1213] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6921),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2873),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7036),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5355),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4038),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7429),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9220),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(1213),
    [sym_preproc_endregion] = STATE(1213),
    [sym_preproc_line] = STATE(1213),
    [sym_preproc_pragma] = STATE(1213),
    [sym_preproc_nullable] = STATE(1213),
    [sym_preproc_error] = STATE(1213),
    [sym_preproc_warning] = STATE(1213),
    [sym_preproc_define] = STATE(1213),
    [sym_preproc_undef] = STATE(1213),
    [aux_sym_class_declaration_repeat1] = STATE(3830),
    [aux_sym_lambda_expression_repeat1] = STATE(4255),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1407),
    [anon_sym_ref] = ACTIONS(1409),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1415),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1421),
    [anon_sym_TILDE] = ACTIONS(1421),
    [anon_sym_PLUS_PLUS] = ACTIONS(1421),
    [anon_sym_DASH_DASH] = ACTIONS(1421),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1419),
    [anon_sym_DASH] = ACTIONS(1419),
    [anon_sym_STAR] = ACTIONS(1425),
    [anon_sym_CARET] = ACTIONS(1421),
    [anon_sym_AMP] = ACTIONS(1421),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1439),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1441),
    [anon_sym_DOT_DOT] = ACTIONS(1443),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [1214] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6921),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2873),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(6957),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5823),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4346),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7445),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9875),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(1214),
    [sym_preproc_endregion] = STATE(1214),
    [sym_preproc_line] = STATE(1214),
    [sym_preproc_pragma] = STATE(1214),
    [sym_preproc_nullable] = STATE(1214),
    [sym_preproc_error] = STATE(1214),
    [sym_preproc_warning] = STATE(1214),
    [sym_preproc_define] = STATE(1214),
    [sym_preproc_undef] = STATE(1214),
    [aux_sym_class_declaration_repeat1] = STATE(3810),
    [aux_sym_lambda_expression_repeat1] = STATE(4192),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1639),
    [anon_sym_ref] = ACTIONS(1641),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1415),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1645),
    [anon_sym_TILDE] = ACTIONS(1645),
    [anon_sym_PLUS_PLUS] = ACTIONS(1645),
    [anon_sym_DASH_DASH] = ACTIONS(1645),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1643),
    [anon_sym_DASH] = ACTIONS(1643),
    [anon_sym_STAR] = ACTIONS(1425),
    [anon_sym_CARET] = ACTIONS(1645),
    [anon_sym_AMP] = ACTIONS(1645),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1647),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1649),
    [anon_sym_DOT_DOT] = ACTIONS(1651),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [1215] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6962),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5209),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3931),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9818),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1215),
    [sym_preproc_endregion] = STATE(1215),
    [sym_preproc_line] = STATE(1215),
    [sym_preproc_pragma] = STATE(1215),
    [sym_preproc_nullable] = STATE(1215),
    [sym_preproc_error] = STATE(1215),
    [sym_preproc_warning] = STATE(1215),
    [sym_preproc_define] = STATE(1215),
    [sym_preproc_undef] = STATE(1215),
    [aux_sym_class_declaration_repeat1] = STATE(3811),
    [aux_sym_lambda_expression_repeat1] = STATE(4201),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1373),
    [anon_sym_ref] = ACTIONS(1375),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1379),
    [anon_sym_TILDE] = ACTIONS(1379),
    [anon_sym_PLUS_PLUS] = ACTIONS(1379),
    [anon_sym_DASH_DASH] = ACTIONS(1379),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1377),
    [anon_sym_DASH] = ACTIONS(1377),
    [anon_sym_STAR] = ACTIONS(1381),
    [anon_sym_CARET] = ACTIONS(1379),
    [anon_sym_AMP] = ACTIONS(1379),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1383),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1385),
    [anon_sym_DOT_DOT] = ACTIONS(1387),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1216] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6962),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3926),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3931),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9818),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1216),
    [sym_preproc_endregion] = STATE(1216),
    [sym_preproc_line] = STATE(1216),
    [sym_preproc_pragma] = STATE(1216),
    [sym_preproc_nullable] = STATE(1216),
    [sym_preproc_error] = STATE(1216),
    [sym_preproc_warning] = STATE(1216),
    [sym_preproc_define] = STATE(1216),
    [sym_preproc_undef] = STATE(1216),
    [aux_sym_class_declaration_repeat1] = STATE(3811),
    [aux_sym_lambda_expression_repeat1] = STATE(4201),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1373),
    [anon_sym_ref] = ACTIONS(1375),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1379),
    [anon_sym_TILDE] = ACTIONS(1379),
    [anon_sym_PLUS_PLUS] = ACTIONS(1379),
    [anon_sym_DASH_DASH] = ACTIONS(1379),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1377),
    [anon_sym_DASH] = ACTIONS(1377),
    [anon_sym_STAR] = ACTIONS(1381),
    [anon_sym_CARET] = ACTIONS(1379),
    [anon_sym_AMP] = ACTIONS(1379),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1383),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1385),
    [anon_sym_DOT_DOT] = ACTIONS(1387),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1217] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6921),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2873),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(6957),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5899),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4346),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7445),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9875),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(1217),
    [sym_preproc_endregion] = STATE(1217),
    [sym_preproc_line] = STATE(1217),
    [sym_preproc_pragma] = STATE(1217),
    [sym_preproc_nullable] = STATE(1217),
    [sym_preproc_error] = STATE(1217),
    [sym_preproc_warning] = STATE(1217),
    [sym_preproc_define] = STATE(1217),
    [sym_preproc_undef] = STATE(1217),
    [aux_sym_class_declaration_repeat1] = STATE(3810),
    [aux_sym_lambda_expression_repeat1] = STATE(4192),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1639),
    [anon_sym_ref] = ACTIONS(1641),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1415),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1645),
    [anon_sym_TILDE] = ACTIONS(1645),
    [anon_sym_PLUS_PLUS] = ACTIONS(1645),
    [anon_sym_DASH_DASH] = ACTIONS(1645),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1643),
    [anon_sym_DASH] = ACTIONS(1643),
    [anon_sym_STAR] = ACTIONS(1425),
    [anon_sym_CARET] = ACTIONS(1645),
    [anon_sym_AMP] = ACTIONS(1645),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1647),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1649),
    [anon_sym_DOT_DOT] = ACTIONS(1651),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [1218] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6921),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2873),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(6957),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5901),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4346),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7445),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9875),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(1218),
    [sym_preproc_endregion] = STATE(1218),
    [sym_preproc_line] = STATE(1218),
    [sym_preproc_pragma] = STATE(1218),
    [sym_preproc_nullable] = STATE(1218),
    [sym_preproc_error] = STATE(1218),
    [sym_preproc_warning] = STATE(1218),
    [sym_preproc_define] = STATE(1218),
    [sym_preproc_undef] = STATE(1218),
    [aux_sym_class_declaration_repeat1] = STATE(3810),
    [aux_sym_lambda_expression_repeat1] = STATE(4192),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1639),
    [anon_sym_ref] = ACTIONS(1641),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1415),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1645),
    [anon_sym_TILDE] = ACTIONS(1645),
    [anon_sym_PLUS_PLUS] = ACTIONS(1645),
    [anon_sym_DASH_DASH] = ACTIONS(1645),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1643),
    [anon_sym_DASH] = ACTIONS(1643),
    [anon_sym_STAR] = ACTIONS(1425),
    [anon_sym_CARET] = ACTIONS(1645),
    [anon_sym_AMP] = ACTIONS(1645),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1647),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1649),
    [anon_sym_DOT_DOT] = ACTIONS(1651),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [1219] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6921),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2873),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(6957),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5902),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4346),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7445),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9875),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(1219),
    [sym_preproc_endregion] = STATE(1219),
    [sym_preproc_line] = STATE(1219),
    [sym_preproc_pragma] = STATE(1219),
    [sym_preproc_nullable] = STATE(1219),
    [sym_preproc_error] = STATE(1219),
    [sym_preproc_warning] = STATE(1219),
    [sym_preproc_define] = STATE(1219),
    [sym_preproc_undef] = STATE(1219),
    [aux_sym_class_declaration_repeat1] = STATE(3810),
    [aux_sym_lambda_expression_repeat1] = STATE(4192),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1639),
    [anon_sym_ref] = ACTIONS(1641),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1415),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1645),
    [anon_sym_TILDE] = ACTIONS(1645),
    [anon_sym_PLUS_PLUS] = ACTIONS(1645),
    [anon_sym_DASH_DASH] = ACTIONS(1645),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1643),
    [anon_sym_DASH] = ACTIONS(1643),
    [anon_sym_STAR] = ACTIONS(1425),
    [anon_sym_CARET] = ACTIONS(1645),
    [anon_sym_AMP] = ACTIONS(1645),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1647),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1649),
    [anon_sym_DOT_DOT] = ACTIONS(1651),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [1220] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6921),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2873),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(6957),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5904),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4346),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7445),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9875),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(1220),
    [sym_preproc_endregion] = STATE(1220),
    [sym_preproc_line] = STATE(1220),
    [sym_preproc_pragma] = STATE(1220),
    [sym_preproc_nullable] = STATE(1220),
    [sym_preproc_error] = STATE(1220),
    [sym_preproc_warning] = STATE(1220),
    [sym_preproc_define] = STATE(1220),
    [sym_preproc_undef] = STATE(1220),
    [aux_sym_class_declaration_repeat1] = STATE(3810),
    [aux_sym_lambda_expression_repeat1] = STATE(4192),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1639),
    [anon_sym_ref] = ACTIONS(1641),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1415),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1645),
    [anon_sym_TILDE] = ACTIONS(1645),
    [anon_sym_PLUS_PLUS] = ACTIONS(1645),
    [anon_sym_DASH_DASH] = ACTIONS(1645),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1643),
    [anon_sym_DASH] = ACTIONS(1643),
    [anon_sym_STAR] = ACTIONS(1425),
    [anon_sym_CARET] = ACTIONS(1645),
    [anon_sym_AMP] = ACTIONS(1645),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1647),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1649),
    [anon_sym_DOT_DOT] = ACTIONS(1651),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [1221] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6921),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2873),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(6957),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5907),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4346),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7445),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9875),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(1221),
    [sym_preproc_endregion] = STATE(1221),
    [sym_preproc_line] = STATE(1221),
    [sym_preproc_pragma] = STATE(1221),
    [sym_preproc_nullable] = STATE(1221),
    [sym_preproc_error] = STATE(1221),
    [sym_preproc_warning] = STATE(1221),
    [sym_preproc_define] = STATE(1221),
    [sym_preproc_undef] = STATE(1221),
    [aux_sym_class_declaration_repeat1] = STATE(3810),
    [aux_sym_lambda_expression_repeat1] = STATE(4192),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1639),
    [anon_sym_ref] = ACTIONS(1641),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1415),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1645),
    [anon_sym_TILDE] = ACTIONS(1645),
    [anon_sym_PLUS_PLUS] = ACTIONS(1645),
    [anon_sym_DASH_DASH] = ACTIONS(1645),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1643),
    [anon_sym_DASH] = ACTIONS(1643),
    [anon_sym_STAR] = ACTIONS(1425),
    [anon_sym_CARET] = ACTIONS(1645),
    [anon_sym_AMP] = ACTIONS(1645),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1647),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1649),
    [anon_sym_DOT_DOT] = ACTIONS(1651),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [1222] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6921),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2873),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(6957),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5910),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4346),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7445),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9875),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(1222),
    [sym_preproc_endregion] = STATE(1222),
    [sym_preproc_line] = STATE(1222),
    [sym_preproc_pragma] = STATE(1222),
    [sym_preproc_nullable] = STATE(1222),
    [sym_preproc_error] = STATE(1222),
    [sym_preproc_warning] = STATE(1222),
    [sym_preproc_define] = STATE(1222),
    [sym_preproc_undef] = STATE(1222),
    [aux_sym_class_declaration_repeat1] = STATE(3810),
    [aux_sym_lambda_expression_repeat1] = STATE(4192),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1639),
    [anon_sym_ref] = ACTIONS(1641),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1415),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1645),
    [anon_sym_TILDE] = ACTIONS(1645),
    [anon_sym_PLUS_PLUS] = ACTIONS(1645),
    [anon_sym_DASH_DASH] = ACTIONS(1645),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1643),
    [anon_sym_DASH] = ACTIONS(1643),
    [anon_sym_STAR] = ACTIONS(1425),
    [anon_sym_CARET] = ACTIONS(1645),
    [anon_sym_AMP] = ACTIONS(1645),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1647),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1649),
    [anon_sym_DOT_DOT] = ACTIONS(1651),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [1223] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6921),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2873),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(6957),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5912),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4346),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7445),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9875),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(1223),
    [sym_preproc_endregion] = STATE(1223),
    [sym_preproc_line] = STATE(1223),
    [sym_preproc_pragma] = STATE(1223),
    [sym_preproc_nullable] = STATE(1223),
    [sym_preproc_error] = STATE(1223),
    [sym_preproc_warning] = STATE(1223),
    [sym_preproc_define] = STATE(1223),
    [sym_preproc_undef] = STATE(1223),
    [aux_sym_class_declaration_repeat1] = STATE(3810),
    [aux_sym_lambda_expression_repeat1] = STATE(4192),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1639),
    [anon_sym_ref] = ACTIONS(1641),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1415),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1645),
    [anon_sym_TILDE] = ACTIONS(1645),
    [anon_sym_PLUS_PLUS] = ACTIONS(1645),
    [anon_sym_DASH_DASH] = ACTIONS(1645),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1643),
    [anon_sym_DASH] = ACTIONS(1643),
    [anon_sym_STAR] = ACTIONS(1425),
    [anon_sym_CARET] = ACTIONS(1645),
    [anon_sym_AMP] = ACTIONS(1645),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1647),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1649),
    [anon_sym_DOT_DOT] = ACTIONS(1651),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [1224] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6921),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2873),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(6957),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5913),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4346),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7445),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9875),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(1224),
    [sym_preproc_endregion] = STATE(1224),
    [sym_preproc_line] = STATE(1224),
    [sym_preproc_pragma] = STATE(1224),
    [sym_preproc_nullable] = STATE(1224),
    [sym_preproc_error] = STATE(1224),
    [sym_preproc_warning] = STATE(1224),
    [sym_preproc_define] = STATE(1224),
    [sym_preproc_undef] = STATE(1224),
    [aux_sym_class_declaration_repeat1] = STATE(3810),
    [aux_sym_lambda_expression_repeat1] = STATE(4192),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1639),
    [anon_sym_ref] = ACTIONS(1641),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1415),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1645),
    [anon_sym_TILDE] = ACTIONS(1645),
    [anon_sym_PLUS_PLUS] = ACTIONS(1645),
    [anon_sym_DASH_DASH] = ACTIONS(1645),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1643),
    [anon_sym_DASH] = ACTIONS(1643),
    [anon_sym_STAR] = ACTIONS(1425),
    [anon_sym_CARET] = ACTIONS(1645),
    [anon_sym_AMP] = ACTIONS(1645),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1647),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1649),
    [anon_sym_DOT_DOT] = ACTIONS(1651),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [1225] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6921),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2873),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(6957),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5914),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4346),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7445),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9875),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(1225),
    [sym_preproc_endregion] = STATE(1225),
    [sym_preproc_line] = STATE(1225),
    [sym_preproc_pragma] = STATE(1225),
    [sym_preproc_nullable] = STATE(1225),
    [sym_preproc_error] = STATE(1225),
    [sym_preproc_warning] = STATE(1225),
    [sym_preproc_define] = STATE(1225),
    [sym_preproc_undef] = STATE(1225),
    [aux_sym_class_declaration_repeat1] = STATE(3810),
    [aux_sym_lambda_expression_repeat1] = STATE(4192),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1639),
    [anon_sym_ref] = ACTIONS(1641),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1415),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1645),
    [anon_sym_TILDE] = ACTIONS(1645),
    [anon_sym_PLUS_PLUS] = ACTIONS(1645),
    [anon_sym_DASH_DASH] = ACTIONS(1645),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1643),
    [anon_sym_DASH] = ACTIONS(1643),
    [anon_sym_STAR] = ACTIONS(1425),
    [anon_sym_CARET] = ACTIONS(1645),
    [anon_sym_AMP] = ACTIONS(1645),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1647),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1649),
    [anon_sym_DOT_DOT] = ACTIONS(1651),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [1226] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6921),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2873),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(6957),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5915),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4346),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7445),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9875),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(1226),
    [sym_preproc_endregion] = STATE(1226),
    [sym_preproc_line] = STATE(1226),
    [sym_preproc_pragma] = STATE(1226),
    [sym_preproc_nullable] = STATE(1226),
    [sym_preproc_error] = STATE(1226),
    [sym_preproc_warning] = STATE(1226),
    [sym_preproc_define] = STATE(1226),
    [sym_preproc_undef] = STATE(1226),
    [aux_sym_class_declaration_repeat1] = STATE(3810),
    [aux_sym_lambda_expression_repeat1] = STATE(4192),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1639),
    [anon_sym_ref] = ACTIONS(1641),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1415),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1645),
    [anon_sym_TILDE] = ACTIONS(1645),
    [anon_sym_PLUS_PLUS] = ACTIONS(1645),
    [anon_sym_DASH_DASH] = ACTIONS(1645),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1643),
    [anon_sym_DASH] = ACTIONS(1643),
    [anon_sym_STAR] = ACTIONS(1425),
    [anon_sym_CARET] = ACTIONS(1645),
    [anon_sym_AMP] = ACTIONS(1645),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1647),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1649),
    [anon_sym_DOT_DOT] = ACTIONS(1651),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [1227] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6921),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2873),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(6957),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5918),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4346),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7445),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9875),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(1227),
    [sym_preproc_endregion] = STATE(1227),
    [sym_preproc_line] = STATE(1227),
    [sym_preproc_pragma] = STATE(1227),
    [sym_preproc_nullable] = STATE(1227),
    [sym_preproc_error] = STATE(1227),
    [sym_preproc_warning] = STATE(1227),
    [sym_preproc_define] = STATE(1227),
    [sym_preproc_undef] = STATE(1227),
    [aux_sym_class_declaration_repeat1] = STATE(3810),
    [aux_sym_lambda_expression_repeat1] = STATE(4192),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1639),
    [anon_sym_ref] = ACTIONS(1641),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1415),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1645),
    [anon_sym_TILDE] = ACTIONS(1645),
    [anon_sym_PLUS_PLUS] = ACTIONS(1645),
    [anon_sym_DASH_DASH] = ACTIONS(1645),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1643),
    [anon_sym_DASH] = ACTIONS(1643),
    [anon_sym_STAR] = ACTIONS(1425),
    [anon_sym_CARET] = ACTIONS(1645),
    [anon_sym_AMP] = ACTIONS(1645),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1647),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1649),
    [anon_sym_DOT_DOT] = ACTIONS(1651),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [1228] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6962),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5185),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3931),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9818),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1228),
    [sym_preproc_endregion] = STATE(1228),
    [sym_preproc_line] = STATE(1228),
    [sym_preproc_pragma] = STATE(1228),
    [sym_preproc_nullable] = STATE(1228),
    [sym_preproc_error] = STATE(1228),
    [sym_preproc_warning] = STATE(1228),
    [sym_preproc_define] = STATE(1228),
    [sym_preproc_undef] = STATE(1228),
    [aux_sym_class_declaration_repeat1] = STATE(3811),
    [aux_sym_lambda_expression_repeat1] = STATE(4201),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1373),
    [anon_sym_ref] = ACTIONS(1375),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1379),
    [anon_sym_TILDE] = ACTIONS(1379),
    [anon_sym_PLUS_PLUS] = ACTIONS(1379),
    [anon_sym_DASH_DASH] = ACTIONS(1379),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1377),
    [anon_sym_DASH] = ACTIONS(1377),
    [anon_sym_STAR] = ACTIONS(1381),
    [anon_sym_CARET] = ACTIONS(1379),
    [anon_sym_AMP] = ACTIONS(1379),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1383),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1385),
    [anon_sym_DOT_DOT] = ACTIONS(1387),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1229] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6921),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2873),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(6957),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5210),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4346),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7445),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9875),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(1229),
    [sym_preproc_endregion] = STATE(1229),
    [sym_preproc_line] = STATE(1229),
    [sym_preproc_pragma] = STATE(1229),
    [sym_preproc_nullable] = STATE(1229),
    [sym_preproc_error] = STATE(1229),
    [sym_preproc_warning] = STATE(1229),
    [sym_preproc_define] = STATE(1229),
    [sym_preproc_undef] = STATE(1229),
    [aux_sym_class_declaration_repeat1] = STATE(3810),
    [aux_sym_lambda_expression_repeat1] = STATE(4192),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1639),
    [anon_sym_ref] = ACTIONS(1641),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1415),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1645),
    [anon_sym_TILDE] = ACTIONS(1645),
    [anon_sym_PLUS_PLUS] = ACTIONS(1645),
    [anon_sym_DASH_DASH] = ACTIONS(1645),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1643),
    [anon_sym_DASH] = ACTIONS(1643),
    [anon_sym_STAR] = ACTIONS(1425),
    [anon_sym_CARET] = ACTIONS(1645),
    [anon_sym_AMP] = ACTIONS(1645),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1647),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1649),
    [anon_sym_DOT_DOT] = ACTIONS(1651),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [1230] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6955),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2975),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7120),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4811),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3789),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7416),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9625),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1230),
    [sym_preproc_endregion] = STATE(1230),
    [sym_preproc_line] = STATE(1230),
    [sym_preproc_pragma] = STATE(1230),
    [sym_preproc_nullable] = STATE(1230),
    [sym_preproc_error] = STATE(1230),
    [sym_preproc_warning] = STATE(1230),
    [sym_preproc_define] = STATE(1230),
    [sym_preproc_undef] = STATE(1230),
    [aux_sym_class_declaration_repeat1] = STATE(3864),
    [aux_sym_lambda_expression_repeat1] = STATE(4297),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1929),
    [anon_sym_ref] = ACTIONS(1931),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1933),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1937),
    [anon_sym_TILDE] = ACTIONS(1937),
    [anon_sym_PLUS_PLUS] = ACTIONS(1937),
    [anon_sym_DASH_DASH] = ACTIONS(1937),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1935),
    [anon_sym_DASH] = ACTIONS(1935),
    [anon_sym_STAR] = ACTIONS(1939),
    [anon_sym_CARET] = ACTIONS(1937),
    [anon_sym_AMP] = ACTIONS(1937),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1941),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1943),
    [anon_sym_DOT_DOT] = ACTIONS(1945),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1231] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6962),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5170),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3931),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9818),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1231),
    [sym_preproc_endregion] = STATE(1231),
    [sym_preproc_line] = STATE(1231),
    [sym_preproc_pragma] = STATE(1231),
    [sym_preproc_nullable] = STATE(1231),
    [sym_preproc_error] = STATE(1231),
    [sym_preproc_warning] = STATE(1231),
    [sym_preproc_define] = STATE(1231),
    [sym_preproc_undef] = STATE(1231),
    [aux_sym_class_declaration_repeat1] = STATE(3811),
    [aux_sym_lambda_expression_repeat1] = STATE(4201),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1373),
    [anon_sym_ref] = ACTIONS(1375),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1379),
    [anon_sym_TILDE] = ACTIONS(1379),
    [anon_sym_PLUS_PLUS] = ACTIONS(1379),
    [anon_sym_DASH_DASH] = ACTIONS(1379),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1377),
    [anon_sym_DASH] = ACTIONS(1377),
    [anon_sym_STAR] = ACTIONS(1381),
    [anon_sym_CARET] = ACTIONS(1379),
    [anon_sym_AMP] = ACTIONS(1379),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1383),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1385),
    [anon_sym_DOT_DOT] = ACTIONS(1387),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1232] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6915),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7018),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4465),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3585),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7418),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9926),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1232),
    [sym_preproc_endregion] = STATE(1232),
    [sym_preproc_line] = STATE(1232),
    [sym_preproc_pragma] = STATE(1232),
    [sym_preproc_nullable] = STATE(1232),
    [sym_preproc_error] = STATE(1232),
    [sym_preproc_warning] = STATE(1232),
    [sym_preproc_define] = STATE(1232),
    [sym_preproc_undef] = STATE(1232),
    [aux_sym_class_declaration_repeat1] = STATE(3825),
    [aux_sym_lambda_expression_repeat1] = STATE(4244),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1161),
    [anon_sym_ref] = ACTIONS(1163),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1177),
    [anon_sym_TILDE] = ACTIONS(1177),
    [anon_sym_PLUS_PLUS] = ACTIONS(1177),
    [anon_sym_DASH_DASH] = ACTIONS(1177),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1175),
    [anon_sym_DASH] = ACTIONS(1175),
    [anon_sym_STAR] = ACTIONS(1181),
    [anon_sym_CARET] = ACTIONS(1177),
    [anon_sym_AMP] = ACTIONS(1177),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1191),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1193),
    [anon_sym_DOT_DOT] = ACTIONS(1195),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1233] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6915),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7018),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3838),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3585),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7418),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9926),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1233),
    [sym_preproc_endregion] = STATE(1233),
    [sym_preproc_line] = STATE(1233),
    [sym_preproc_pragma] = STATE(1233),
    [sym_preproc_nullable] = STATE(1233),
    [sym_preproc_error] = STATE(1233),
    [sym_preproc_warning] = STATE(1233),
    [sym_preproc_define] = STATE(1233),
    [sym_preproc_undef] = STATE(1233),
    [aux_sym_class_declaration_repeat1] = STATE(3825),
    [aux_sym_lambda_expression_repeat1] = STATE(4244),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1161),
    [anon_sym_ref] = ACTIONS(1163),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1177),
    [anon_sym_TILDE] = ACTIONS(1177),
    [anon_sym_PLUS_PLUS] = ACTIONS(1177),
    [anon_sym_DASH_DASH] = ACTIONS(1177),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1175),
    [anon_sym_DASH] = ACTIONS(1175),
    [anon_sym_STAR] = ACTIONS(1181),
    [anon_sym_CARET] = ACTIONS(1177),
    [anon_sym_AMP] = ACTIONS(1177),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1191),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1193),
    [anon_sym_DOT_DOT] = ACTIONS(1195),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1234] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6915),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7018),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4495),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3585),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7418),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9926),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1234),
    [sym_preproc_endregion] = STATE(1234),
    [sym_preproc_line] = STATE(1234),
    [sym_preproc_pragma] = STATE(1234),
    [sym_preproc_nullable] = STATE(1234),
    [sym_preproc_error] = STATE(1234),
    [sym_preproc_warning] = STATE(1234),
    [sym_preproc_define] = STATE(1234),
    [sym_preproc_undef] = STATE(1234),
    [aux_sym_class_declaration_repeat1] = STATE(3825),
    [aux_sym_lambda_expression_repeat1] = STATE(4244),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1161),
    [anon_sym_ref] = ACTIONS(1163),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1177),
    [anon_sym_TILDE] = ACTIONS(1177),
    [anon_sym_PLUS_PLUS] = ACTIONS(1177),
    [anon_sym_DASH_DASH] = ACTIONS(1177),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1175),
    [anon_sym_DASH] = ACTIONS(1175),
    [anon_sym_STAR] = ACTIONS(1181),
    [anon_sym_CARET] = ACTIONS(1177),
    [anon_sym_AMP] = ACTIONS(1177),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1191),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1193),
    [anon_sym_DOT_DOT] = ACTIONS(1195),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1235] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6915),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7018),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4511),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3585),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7418),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9926),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1235),
    [sym_preproc_endregion] = STATE(1235),
    [sym_preproc_line] = STATE(1235),
    [sym_preproc_pragma] = STATE(1235),
    [sym_preproc_nullable] = STATE(1235),
    [sym_preproc_error] = STATE(1235),
    [sym_preproc_warning] = STATE(1235),
    [sym_preproc_define] = STATE(1235),
    [sym_preproc_undef] = STATE(1235),
    [aux_sym_class_declaration_repeat1] = STATE(3825),
    [aux_sym_lambda_expression_repeat1] = STATE(4244),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1161),
    [anon_sym_ref] = ACTIONS(1163),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1177),
    [anon_sym_TILDE] = ACTIONS(1177),
    [anon_sym_PLUS_PLUS] = ACTIONS(1177),
    [anon_sym_DASH_DASH] = ACTIONS(1177),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1175),
    [anon_sym_DASH] = ACTIONS(1175),
    [anon_sym_STAR] = ACTIONS(1181),
    [anon_sym_CARET] = ACTIONS(1177),
    [anon_sym_AMP] = ACTIONS(1177),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1191),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1193),
    [anon_sym_DOT_DOT] = ACTIONS(1195),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1236] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6915),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7018),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4512),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3585),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7418),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9926),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1236),
    [sym_preproc_endregion] = STATE(1236),
    [sym_preproc_line] = STATE(1236),
    [sym_preproc_pragma] = STATE(1236),
    [sym_preproc_nullable] = STATE(1236),
    [sym_preproc_error] = STATE(1236),
    [sym_preproc_warning] = STATE(1236),
    [sym_preproc_define] = STATE(1236),
    [sym_preproc_undef] = STATE(1236),
    [aux_sym_class_declaration_repeat1] = STATE(3825),
    [aux_sym_lambda_expression_repeat1] = STATE(4244),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1161),
    [anon_sym_ref] = ACTIONS(1163),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1177),
    [anon_sym_TILDE] = ACTIONS(1177),
    [anon_sym_PLUS_PLUS] = ACTIONS(1177),
    [anon_sym_DASH_DASH] = ACTIONS(1177),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1175),
    [anon_sym_DASH] = ACTIONS(1175),
    [anon_sym_STAR] = ACTIONS(1181),
    [anon_sym_CARET] = ACTIONS(1177),
    [anon_sym_AMP] = ACTIONS(1177),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1191),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1193),
    [anon_sym_DOT_DOT] = ACTIONS(1195),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1237] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6915),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7018),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4515),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3585),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7418),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9926),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1237),
    [sym_preproc_endregion] = STATE(1237),
    [sym_preproc_line] = STATE(1237),
    [sym_preproc_pragma] = STATE(1237),
    [sym_preproc_nullable] = STATE(1237),
    [sym_preproc_error] = STATE(1237),
    [sym_preproc_warning] = STATE(1237),
    [sym_preproc_define] = STATE(1237),
    [sym_preproc_undef] = STATE(1237),
    [aux_sym_class_declaration_repeat1] = STATE(3825),
    [aux_sym_lambda_expression_repeat1] = STATE(4244),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1161),
    [anon_sym_ref] = ACTIONS(1163),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1177),
    [anon_sym_TILDE] = ACTIONS(1177),
    [anon_sym_PLUS_PLUS] = ACTIONS(1177),
    [anon_sym_DASH_DASH] = ACTIONS(1177),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1175),
    [anon_sym_DASH] = ACTIONS(1175),
    [anon_sym_STAR] = ACTIONS(1181),
    [anon_sym_CARET] = ACTIONS(1177),
    [anon_sym_AMP] = ACTIONS(1177),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1191),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1193),
    [anon_sym_DOT_DOT] = ACTIONS(1195),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1238] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6915),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7018),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4517),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3585),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7418),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9926),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1238),
    [sym_preproc_endregion] = STATE(1238),
    [sym_preproc_line] = STATE(1238),
    [sym_preproc_pragma] = STATE(1238),
    [sym_preproc_nullable] = STATE(1238),
    [sym_preproc_error] = STATE(1238),
    [sym_preproc_warning] = STATE(1238),
    [sym_preproc_define] = STATE(1238),
    [sym_preproc_undef] = STATE(1238),
    [aux_sym_class_declaration_repeat1] = STATE(3825),
    [aux_sym_lambda_expression_repeat1] = STATE(4244),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1161),
    [anon_sym_ref] = ACTIONS(1163),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1177),
    [anon_sym_TILDE] = ACTIONS(1177),
    [anon_sym_PLUS_PLUS] = ACTIONS(1177),
    [anon_sym_DASH_DASH] = ACTIONS(1177),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1175),
    [anon_sym_DASH] = ACTIONS(1175),
    [anon_sym_STAR] = ACTIONS(1181),
    [anon_sym_CARET] = ACTIONS(1177),
    [anon_sym_AMP] = ACTIONS(1177),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1191),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1193),
    [anon_sym_DOT_DOT] = ACTIONS(1195),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1239] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6915),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7018),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4525),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3585),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7418),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9926),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1239),
    [sym_preproc_endregion] = STATE(1239),
    [sym_preproc_line] = STATE(1239),
    [sym_preproc_pragma] = STATE(1239),
    [sym_preproc_nullable] = STATE(1239),
    [sym_preproc_error] = STATE(1239),
    [sym_preproc_warning] = STATE(1239),
    [sym_preproc_define] = STATE(1239),
    [sym_preproc_undef] = STATE(1239),
    [aux_sym_class_declaration_repeat1] = STATE(3825),
    [aux_sym_lambda_expression_repeat1] = STATE(4244),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1161),
    [anon_sym_ref] = ACTIONS(1163),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1177),
    [anon_sym_TILDE] = ACTIONS(1177),
    [anon_sym_PLUS_PLUS] = ACTIONS(1177),
    [anon_sym_DASH_DASH] = ACTIONS(1177),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1175),
    [anon_sym_DASH] = ACTIONS(1175),
    [anon_sym_STAR] = ACTIONS(1181),
    [anon_sym_CARET] = ACTIONS(1177),
    [anon_sym_AMP] = ACTIONS(1177),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1191),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1193),
    [anon_sym_DOT_DOT] = ACTIONS(1195),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1240] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6915),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7018),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4534),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3585),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7418),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9926),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1240),
    [sym_preproc_endregion] = STATE(1240),
    [sym_preproc_line] = STATE(1240),
    [sym_preproc_pragma] = STATE(1240),
    [sym_preproc_nullable] = STATE(1240),
    [sym_preproc_error] = STATE(1240),
    [sym_preproc_warning] = STATE(1240),
    [sym_preproc_define] = STATE(1240),
    [sym_preproc_undef] = STATE(1240),
    [aux_sym_class_declaration_repeat1] = STATE(3825),
    [aux_sym_lambda_expression_repeat1] = STATE(4244),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1161),
    [anon_sym_ref] = ACTIONS(1163),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1177),
    [anon_sym_TILDE] = ACTIONS(1177),
    [anon_sym_PLUS_PLUS] = ACTIONS(1177),
    [anon_sym_DASH_DASH] = ACTIONS(1177),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1175),
    [anon_sym_DASH] = ACTIONS(1175),
    [anon_sym_STAR] = ACTIONS(1181),
    [anon_sym_CARET] = ACTIONS(1177),
    [anon_sym_AMP] = ACTIONS(1177),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1191),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1193),
    [anon_sym_DOT_DOT] = ACTIONS(1195),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1241] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6915),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7018),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4543),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3585),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7418),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9926),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1241),
    [sym_preproc_endregion] = STATE(1241),
    [sym_preproc_line] = STATE(1241),
    [sym_preproc_pragma] = STATE(1241),
    [sym_preproc_nullable] = STATE(1241),
    [sym_preproc_error] = STATE(1241),
    [sym_preproc_warning] = STATE(1241),
    [sym_preproc_define] = STATE(1241),
    [sym_preproc_undef] = STATE(1241),
    [aux_sym_class_declaration_repeat1] = STATE(3825),
    [aux_sym_lambda_expression_repeat1] = STATE(4244),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1161),
    [anon_sym_ref] = ACTIONS(1163),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1177),
    [anon_sym_TILDE] = ACTIONS(1177),
    [anon_sym_PLUS_PLUS] = ACTIONS(1177),
    [anon_sym_DASH_DASH] = ACTIONS(1177),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1175),
    [anon_sym_DASH] = ACTIONS(1175),
    [anon_sym_STAR] = ACTIONS(1181),
    [anon_sym_CARET] = ACTIONS(1177),
    [anon_sym_AMP] = ACTIONS(1177),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1191),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1193),
    [anon_sym_DOT_DOT] = ACTIONS(1195),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1242] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6915),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7018),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4510),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3585),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7418),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9926),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1242),
    [sym_preproc_endregion] = STATE(1242),
    [sym_preproc_line] = STATE(1242),
    [sym_preproc_pragma] = STATE(1242),
    [sym_preproc_nullable] = STATE(1242),
    [sym_preproc_error] = STATE(1242),
    [sym_preproc_warning] = STATE(1242),
    [sym_preproc_define] = STATE(1242),
    [sym_preproc_undef] = STATE(1242),
    [aux_sym_class_declaration_repeat1] = STATE(3825),
    [aux_sym_lambda_expression_repeat1] = STATE(4244),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1161),
    [anon_sym_ref] = ACTIONS(1163),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1177),
    [anon_sym_TILDE] = ACTIONS(1177),
    [anon_sym_PLUS_PLUS] = ACTIONS(1177),
    [anon_sym_DASH_DASH] = ACTIONS(1177),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1175),
    [anon_sym_DASH] = ACTIONS(1175),
    [anon_sym_STAR] = ACTIONS(1181),
    [anon_sym_CARET] = ACTIONS(1177),
    [anon_sym_AMP] = ACTIONS(1177),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1191),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1193),
    [anon_sym_DOT_DOT] = ACTIONS(1195),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1243] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6915),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7018),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4522),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3585),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7418),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9926),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1243),
    [sym_preproc_endregion] = STATE(1243),
    [sym_preproc_line] = STATE(1243),
    [sym_preproc_pragma] = STATE(1243),
    [sym_preproc_nullable] = STATE(1243),
    [sym_preproc_error] = STATE(1243),
    [sym_preproc_warning] = STATE(1243),
    [sym_preproc_define] = STATE(1243),
    [sym_preproc_undef] = STATE(1243),
    [aux_sym_class_declaration_repeat1] = STATE(3825),
    [aux_sym_lambda_expression_repeat1] = STATE(4244),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1161),
    [anon_sym_ref] = ACTIONS(1163),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1177),
    [anon_sym_TILDE] = ACTIONS(1177),
    [anon_sym_PLUS_PLUS] = ACTIONS(1177),
    [anon_sym_DASH_DASH] = ACTIONS(1177),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1175),
    [anon_sym_DASH] = ACTIONS(1175),
    [anon_sym_STAR] = ACTIONS(1181),
    [anon_sym_CARET] = ACTIONS(1177),
    [anon_sym_AMP] = ACTIONS(1177),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1191),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1193),
    [anon_sym_DOT_DOT] = ACTIONS(1195),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1244] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6915),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7018),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4471),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3585),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7418),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9926),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1244),
    [sym_preproc_endregion] = STATE(1244),
    [sym_preproc_line] = STATE(1244),
    [sym_preproc_pragma] = STATE(1244),
    [sym_preproc_nullable] = STATE(1244),
    [sym_preproc_error] = STATE(1244),
    [sym_preproc_warning] = STATE(1244),
    [sym_preproc_define] = STATE(1244),
    [sym_preproc_undef] = STATE(1244),
    [aux_sym_class_declaration_repeat1] = STATE(3825),
    [aux_sym_lambda_expression_repeat1] = STATE(4244),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1161),
    [anon_sym_ref] = ACTIONS(1163),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1177),
    [anon_sym_TILDE] = ACTIONS(1177),
    [anon_sym_PLUS_PLUS] = ACTIONS(1177),
    [anon_sym_DASH_DASH] = ACTIONS(1177),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1175),
    [anon_sym_DASH] = ACTIONS(1175),
    [anon_sym_STAR] = ACTIONS(1181),
    [anon_sym_CARET] = ACTIONS(1177),
    [anon_sym_AMP] = ACTIONS(1177),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1191),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1193),
    [anon_sym_DOT_DOT] = ACTIONS(1195),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1245] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6915),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7018),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4538),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3585),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7418),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9926),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1245),
    [sym_preproc_endregion] = STATE(1245),
    [sym_preproc_line] = STATE(1245),
    [sym_preproc_pragma] = STATE(1245),
    [sym_preproc_nullable] = STATE(1245),
    [sym_preproc_error] = STATE(1245),
    [sym_preproc_warning] = STATE(1245),
    [sym_preproc_define] = STATE(1245),
    [sym_preproc_undef] = STATE(1245),
    [aux_sym_class_declaration_repeat1] = STATE(3825),
    [aux_sym_lambda_expression_repeat1] = STATE(4244),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1161),
    [anon_sym_ref] = ACTIONS(1163),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1177),
    [anon_sym_TILDE] = ACTIONS(1177),
    [anon_sym_PLUS_PLUS] = ACTIONS(1177),
    [anon_sym_DASH_DASH] = ACTIONS(1177),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1175),
    [anon_sym_DASH] = ACTIONS(1175),
    [anon_sym_STAR] = ACTIONS(1181),
    [anon_sym_CARET] = ACTIONS(1177),
    [anon_sym_AMP] = ACTIONS(1177),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1191),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1193),
    [anon_sym_DOT_DOT] = ACTIONS(1195),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1246] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6915),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7018),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3867),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3585),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7418),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9926),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1246),
    [sym_preproc_endregion] = STATE(1246),
    [sym_preproc_line] = STATE(1246),
    [sym_preproc_pragma] = STATE(1246),
    [sym_preproc_nullable] = STATE(1246),
    [sym_preproc_error] = STATE(1246),
    [sym_preproc_warning] = STATE(1246),
    [sym_preproc_define] = STATE(1246),
    [sym_preproc_undef] = STATE(1246),
    [aux_sym_class_declaration_repeat1] = STATE(3825),
    [aux_sym_lambda_expression_repeat1] = STATE(4244),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1161),
    [anon_sym_ref] = ACTIONS(1163),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1177),
    [anon_sym_TILDE] = ACTIONS(1177),
    [anon_sym_PLUS_PLUS] = ACTIONS(1177),
    [anon_sym_DASH_DASH] = ACTIONS(1177),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1175),
    [anon_sym_DASH] = ACTIONS(1175),
    [anon_sym_STAR] = ACTIONS(1181),
    [anon_sym_CARET] = ACTIONS(1177),
    [anon_sym_AMP] = ACTIONS(1177),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1191),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1193),
    [anon_sym_DOT_DOT] = ACTIONS(1195),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1247] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6915),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7018),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4519),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3585),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7418),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9926),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1247),
    [sym_preproc_endregion] = STATE(1247),
    [sym_preproc_line] = STATE(1247),
    [sym_preproc_pragma] = STATE(1247),
    [sym_preproc_nullable] = STATE(1247),
    [sym_preproc_error] = STATE(1247),
    [sym_preproc_warning] = STATE(1247),
    [sym_preproc_define] = STATE(1247),
    [sym_preproc_undef] = STATE(1247),
    [aux_sym_class_declaration_repeat1] = STATE(3825),
    [aux_sym_lambda_expression_repeat1] = STATE(4244),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1161),
    [anon_sym_ref] = ACTIONS(1163),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1177),
    [anon_sym_TILDE] = ACTIONS(1177),
    [anon_sym_PLUS_PLUS] = ACTIONS(1177),
    [anon_sym_DASH_DASH] = ACTIONS(1177),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1175),
    [anon_sym_DASH] = ACTIONS(1175),
    [anon_sym_STAR] = ACTIONS(1181),
    [anon_sym_CARET] = ACTIONS(1177),
    [anon_sym_AMP] = ACTIONS(1177),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1191),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1193),
    [anon_sym_DOT_DOT] = ACTIONS(1195),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1248] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5868),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1248),
    [sym_preproc_endregion] = STATE(1248),
    [sym_preproc_line] = STATE(1248),
    [sym_preproc_pragma] = STATE(1248),
    [sym_preproc_nullable] = STATE(1248),
    [sym_preproc_error] = STATE(1248),
    [sym_preproc_warning] = STATE(1248),
    [sym_preproc_define] = STATE(1248),
    [sym_preproc_undef] = STATE(1248),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1249] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5869),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1249),
    [sym_preproc_endregion] = STATE(1249),
    [sym_preproc_line] = STATE(1249),
    [sym_preproc_pragma] = STATE(1249),
    [sym_preproc_nullable] = STATE(1249),
    [sym_preproc_error] = STATE(1249),
    [sym_preproc_warning] = STATE(1249),
    [sym_preproc_define] = STATE(1249),
    [sym_preproc_undef] = STATE(1249),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1250] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4354),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1250),
    [sym_preproc_endregion] = STATE(1250),
    [sym_preproc_line] = STATE(1250),
    [sym_preproc_pragma] = STATE(1250),
    [sym_preproc_nullable] = STATE(1250),
    [sym_preproc_error] = STATE(1250),
    [sym_preproc_warning] = STATE(1250),
    [sym_preproc_define] = STATE(1250),
    [sym_preproc_undef] = STATE(1250),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1251] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7105),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3056),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1251),
    [sym_preproc_endregion] = STATE(1251),
    [sym_preproc_line] = STATE(1251),
    [sym_preproc_pragma] = STATE(1251),
    [sym_preproc_nullable] = STATE(1251),
    [sym_preproc_error] = STATE(1251),
    [sym_preproc_warning] = STATE(1251),
    [sym_preproc_define] = STATE(1251),
    [sym_preproc_undef] = STATE(1251),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1252] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6956),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5611),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9482),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1252),
    [sym_preproc_endregion] = STATE(1252),
    [sym_preproc_line] = STATE(1252),
    [sym_preproc_pragma] = STATE(1252),
    [sym_preproc_nullable] = STATE(1252),
    [sym_preproc_error] = STATE(1252),
    [sym_preproc_warning] = STATE(1252),
    [sym_preproc_define] = STATE(1252),
    [sym_preproc_undef] = STATE(1252),
    [aux_sym_class_declaration_repeat1] = STATE(3853),
    [aux_sym_lambda_expression_repeat1] = STATE(4299),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1497),
    [anon_sym_ref] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1505),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1507),
    [anon_sym_DOT_DOT] = ACTIONS(1509),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1253] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6956),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4336),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9482),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1253),
    [sym_preproc_endregion] = STATE(1253),
    [sym_preproc_line] = STATE(1253),
    [sym_preproc_pragma] = STATE(1253),
    [sym_preproc_nullable] = STATE(1253),
    [sym_preproc_error] = STATE(1253),
    [sym_preproc_warning] = STATE(1253),
    [sym_preproc_define] = STATE(1253),
    [sym_preproc_undef] = STATE(1253),
    [aux_sym_class_declaration_repeat1] = STATE(3853),
    [aux_sym_lambda_expression_repeat1] = STATE(4299),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1497),
    [anon_sym_ref] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1505),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1507),
    [anon_sym_DOT_DOT] = ACTIONS(1509),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1254] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6192),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1254),
    [sym_preproc_endregion] = STATE(1254),
    [sym_preproc_line] = STATE(1254),
    [sym_preproc_pragma] = STATE(1254),
    [sym_preproc_nullable] = STATE(1254),
    [sym_preproc_error] = STATE(1254),
    [sym_preproc_warning] = STATE(1254),
    [sym_preproc_define] = STATE(1254),
    [sym_preproc_undef] = STATE(1254),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1255] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6553),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1255),
    [sym_preproc_endregion] = STATE(1255),
    [sym_preproc_line] = STATE(1255),
    [sym_preproc_pragma] = STATE(1255),
    [sym_preproc_nullable] = STATE(1255),
    [sym_preproc_error] = STATE(1255),
    [sym_preproc_warning] = STATE(1255),
    [sym_preproc_define] = STATE(1255),
    [sym_preproc_undef] = STATE(1255),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1256] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6956),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4354),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9482),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1256),
    [sym_preproc_endregion] = STATE(1256),
    [sym_preproc_line] = STATE(1256),
    [sym_preproc_pragma] = STATE(1256),
    [sym_preproc_nullable] = STATE(1256),
    [sym_preproc_error] = STATE(1256),
    [sym_preproc_warning] = STATE(1256),
    [sym_preproc_define] = STATE(1256),
    [sym_preproc_undef] = STATE(1256),
    [aux_sym_class_declaration_repeat1] = STATE(3853),
    [aux_sym_lambda_expression_repeat1] = STATE(4299),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1497),
    [anon_sym_ref] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1505),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1507),
    [anon_sym_DOT_DOT] = ACTIONS(1509),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1257] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7131),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6231),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4364),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9470),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1257),
    [sym_preproc_endregion] = STATE(1257),
    [sym_preproc_line] = STATE(1257),
    [sym_preproc_pragma] = STATE(1257),
    [sym_preproc_nullable] = STATE(1257),
    [sym_preproc_error] = STATE(1257),
    [sym_preproc_warning] = STATE(1257),
    [sym_preproc_define] = STATE(1257),
    [sym_preproc_undef] = STATE(1257),
    [aux_sym_class_declaration_repeat1] = STATE(3870),
    [aux_sym_lambda_expression_repeat1] = STATE(4302),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1555),
    [anon_sym_ref] = ACTIONS(1557),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(695),
    [anon_sym_TILDE] = ACTIONS(695),
    [anon_sym_PLUS_PLUS] = ACTIONS(695),
    [anon_sym_DASH_DASH] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(697),
    [anon_sym_DASH] = ACTIONS(697),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(695),
    [anon_sym_AMP] = ACTIONS(695),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1559),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1561),
    [anon_sym_DOT_DOT] = ACTIONS(1563),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1258] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5592),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1258),
    [sym_preproc_endregion] = STATE(1258),
    [sym_preproc_line] = STATE(1258),
    [sym_preproc_pragma] = STATE(1258),
    [sym_preproc_nullable] = STATE(1258),
    [sym_preproc_error] = STATE(1258),
    [sym_preproc_warning] = STATE(1258),
    [sym_preproc_define] = STATE(1258),
    [sym_preproc_undef] = STATE(1258),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1259] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5593),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1259),
    [sym_preproc_endregion] = STATE(1259),
    [sym_preproc_line] = STATE(1259),
    [sym_preproc_pragma] = STATE(1259),
    [sym_preproc_nullable] = STATE(1259),
    [sym_preproc_error] = STATE(1259),
    [sym_preproc_warning] = STATE(1259),
    [sym_preproc_define] = STATE(1259),
    [sym_preproc_undef] = STATE(1259),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1260] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5594),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1260),
    [sym_preproc_endregion] = STATE(1260),
    [sym_preproc_line] = STATE(1260),
    [sym_preproc_pragma] = STATE(1260),
    [sym_preproc_nullable] = STATE(1260),
    [sym_preproc_error] = STATE(1260),
    [sym_preproc_warning] = STATE(1260),
    [sym_preproc_define] = STATE(1260),
    [sym_preproc_undef] = STATE(1260),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1261] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5595),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1261),
    [sym_preproc_endregion] = STATE(1261),
    [sym_preproc_line] = STATE(1261),
    [sym_preproc_pragma] = STATE(1261),
    [sym_preproc_nullable] = STATE(1261),
    [sym_preproc_error] = STATE(1261),
    [sym_preproc_warning] = STATE(1261),
    [sym_preproc_define] = STATE(1261),
    [sym_preproc_undef] = STATE(1261),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1262] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5596),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1262),
    [sym_preproc_endregion] = STATE(1262),
    [sym_preproc_line] = STATE(1262),
    [sym_preproc_pragma] = STATE(1262),
    [sym_preproc_nullable] = STATE(1262),
    [sym_preproc_error] = STATE(1262),
    [sym_preproc_warning] = STATE(1262),
    [sym_preproc_define] = STATE(1262),
    [sym_preproc_undef] = STATE(1262),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1263] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5597),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1263),
    [sym_preproc_endregion] = STATE(1263),
    [sym_preproc_line] = STATE(1263),
    [sym_preproc_pragma] = STATE(1263),
    [sym_preproc_nullable] = STATE(1263),
    [sym_preproc_error] = STATE(1263),
    [sym_preproc_warning] = STATE(1263),
    [sym_preproc_define] = STATE(1263),
    [sym_preproc_undef] = STATE(1263),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1264] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5598),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1264),
    [sym_preproc_endregion] = STATE(1264),
    [sym_preproc_line] = STATE(1264),
    [sym_preproc_pragma] = STATE(1264),
    [sym_preproc_nullable] = STATE(1264),
    [sym_preproc_error] = STATE(1264),
    [sym_preproc_warning] = STATE(1264),
    [sym_preproc_define] = STATE(1264),
    [sym_preproc_undef] = STATE(1264),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1265] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5599),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1265),
    [sym_preproc_endregion] = STATE(1265),
    [sym_preproc_line] = STATE(1265),
    [sym_preproc_pragma] = STATE(1265),
    [sym_preproc_nullable] = STATE(1265),
    [sym_preproc_error] = STATE(1265),
    [sym_preproc_warning] = STATE(1265),
    [sym_preproc_define] = STATE(1265),
    [sym_preproc_undef] = STATE(1265),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1266] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5602),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1266),
    [sym_preproc_endregion] = STATE(1266),
    [sym_preproc_line] = STATE(1266),
    [sym_preproc_pragma] = STATE(1266),
    [sym_preproc_nullable] = STATE(1266),
    [sym_preproc_error] = STATE(1266),
    [sym_preproc_warning] = STATE(1266),
    [sym_preproc_define] = STATE(1266),
    [sym_preproc_undef] = STATE(1266),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1267] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5603),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1267),
    [sym_preproc_endregion] = STATE(1267),
    [sym_preproc_line] = STATE(1267),
    [sym_preproc_pragma] = STATE(1267),
    [sym_preproc_nullable] = STATE(1267),
    [sym_preproc_error] = STATE(1267),
    [sym_preproc_warning] = STATE(1267),
    [sym_preproc_define] = STATE(1267),
    [sym_preproc_undef] = STATE(1267),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1268] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5604),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1268),
    [sym_preproc_endregion] = STATE(1268),
    [sym_preproc_line] = STATE(1268),
    [sym_preproc_pragma] = STATE(1268),
    [sym_preproc_nullable] = STATE(1268),
    [sym_preproc_error] = STATE(1268),
    [sym_preproc_warning] = STATE(1268),
    [sym_preproc_define] = STATE(1268),
    [sym_preproc_undef] = STATE(1268),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1269] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5612),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1269),
    [sym_preproc_endregion] = STATE(1269),
    [sym_preproc_line] = STATE(1269),
    [sym_preproc_pragma] = STATE(1269),
    [sym_preproc_nullable] = STATE(1269),
    [sym_preproc_error] = STATE(1269),
    [sym_preproc_warning] = STATE(1269),
    [sym_preproc_define] = STATE(1269),
    [sym_preproc_undef] = STATE(1269),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1270] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6918),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6973),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5410),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4069),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7443),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9676),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1270),
    [sym_preproc_endregion] = STATE(1270),
    [sym_preproc_line] = STATE(1270),
    [sym_preproc_pragma] = STATE(1270),
    [sym_preproc_nullable] = STATE(1270),
    [sym_preproc_error] = STATE(1270),
    [sym_preproc_warning] = STATE(1270),
    [sym_preproc_define] = STATE(1270),
    [sym_preproc_undef] = STATE(1270),
    [aux_sym_class_declaration_repeat1] = STATE(3815),
    [aux_sym_lambda_expression_repeat1] = STATE(4217),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1515),
    [anon_sym_ref] = ACTIONS(1517),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1521),
    [anon_sym_TILDE] = ACTIONS(1521),
    [anon_sym_PLUS_PLUS] = ACTIONS(1521),
    [anon_sym_DASH_DASH] = ACTIONS(1521),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1519),
    [anon_sym_DASH] = ACTIONS(1519),
    [anon_sym_STAR] = ACTIONS(1523),
    [anon_sym_CARET] = ACTIONS(1521),
    [anon_sym_AMP] = ACTIONS(1521),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1525),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1527),
    [anon_sym_DOT_DOT] = ACTIONS(1529),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1271] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4338),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1271),
    [sym_preproc_endregion] = STATE(1271),
    [sym_preproc_line] = STATE(1271),
    [sym_preproc_pragma] = STATE(1271),
    [sym_preproc_nullable] = STATE(1271),
    [sym_preproc_error] = STATE(1271),
    [sym_preproc_warning] = STATE(1271),
    [sym_preproc_define] = STATE(1271),
    [sym_preproc_undef] = STATE(1271),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1272] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6235),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1272),
    [sym_preproc_endregion] = STATE(1272),
    [sym_preproc_line] = STATE(1272),
    [sym_preproc_pragma] = STATE(1272),
    [sym_preproc_nullable] = STATE(1272),
    [sym_preproc_error] = STATE(1272),
    [sym_preproc_warning] = STATE(1272),
    [sym_preproc_define] = STATE(1272),
    [sym_preproc_undef] = STATE(1272),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1273] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6236),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1273),
    [sym_preproc_endregion] = STATE(1273),
    [sym_preproc_line] = STATE(1273),
    [sym_preproc_pragma] = STATE(1273),
    [sym_preproc_nullable] = STATE(1273),
    [sym_preproc_error] = STATE(1273),
    [sym_preproc_warning] = STATE(1273),
    [sym_preproc_define] = STATE(1273),
    [sym_preproc_undef] = STATE(1273),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1274] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6624),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1274),
    [sym_preproc_endregion] = STATE(1274),
    [sym_preproc_line] = STATE(1274),
    [sym_preproc_pragma] = STATE(1274),
    [sym_preproc_nullable] = STATE(1274),
    [sym_preproc_error] = STATE(1274),
    [sym_preproc_warning] = STATE(1274),
    [sym_preproc_define] = STATE(1274),
    [sym_preproc_undef] = STATE(1274),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1275] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5474),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1275),
    [sym_preproc_endregion] = STATE(1275),
    [sym_preproc_line] = STATE(1275),
    [sym_preproc_pragma] = STATE(1275),
    [sym_preproc_nullable] = STATE(1275),
    [sym_preproc_error] = STATE(1275),
    [sym_preproc_warning] = STATE(1275),
    [sym_preproc_define] = STATE(1275),
    [sym_preproc_undef] = STATE(1275),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1276] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6967),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5053),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3813),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9209),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1276),
    [sym_preproc_endregion] = STATE(1276),
    [sym_preproc_line] = STATE(1276),
    [sym_preproc_pragma] = STATE(1276),
    [sym_preproc_nullable] = STATE(1276),
    [sym_preproc_error] = STATE(1276),
    [sym_preproc_warning] = STATE(1276),
    [sym_preproc_define] = STATE(1276),
    [sym_preproc_undef] = STATE(1276),
    [aux_sym_class_declaration_repeat1] = STATE(3814),
    [aux_sym_lambda_expression_repeat1] = STATE(4209),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1323),
    [anon_sym_ref] = ACTIONS(1325),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1083),
    [anon_sym_PLUS_PLUS] = ACTIONS(1083),
    [anon_sym_DASH_DASH] = ACTIONS(1083),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1085),
    [anon_sym_DASH] = ACTIONS(1085),
    [anon_sym_STAR] = ACTIONS(1335),
    [anon_sym_CARET] = ACTIONS(1083),
    [anon_sym_AMP] = ACTIONS(1083),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1341),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1343),
    [anon_sym_DOT_DOT] = ACTIONS(1345),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1277] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6948),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2940),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6999),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5051),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3857),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7444),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9574),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1277),
    [sym_preproc_endregion] = STATE(1277),
    [sym_preproc_line] = STATE(1277),
    [sym_preproc_pragma] = STATE(1277),
    [sym_preproc_nullable] = STATE(1277),
    [sym_preproc_error] = STATE(1277),
    [sym_preproc_warning] = STATE(1277),
    [sym_preproc_define] = STATE(1277),
    [sym_preproc_undef] = STATE(1277),
    [aux_sym_class_declaration_repeat1] = STATE(3854),
    [aux_sym_lambda_expression_repeat1] = STATE(4136),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2111),
    [anon_sym_ref] = ACTIONS(2113),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1897),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2117),
    [anon_sym_TILDE] = ACTIONS(2117),
    [anon_sym_PLUS_PLUS] = ACTIONS(2117),
    [anon_sym_DASH_DASH] = ACTIONS(2117),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2115),
    [anon_sym_DASH] = ACTIONS(2115),
    [anon_sym_STAR] = ACTIONS(1903),
    [anon_sym_CARET] = ACTIONS(2117),
    [anon_sym_AMP] = ACTIONS(2117),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2119),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2121),
    [anon_sym_DOT_DOT] = ACTIONS(2123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1278] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5791),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1278),
    [sym_preproc_endregion] = STATE(1278),
    [sym_preproc_line] = STATE(1278),
    [sym_preproc_pragma] = STATE(1278),
    [sym_preproc_nullable] = STATE(1278),
    [sym_preproc_error] = STATE(1278),
    [sym_preproc_warning] = STATE(1278),
    [sym_preproc_define] = STATE(1278),
    [sym_preproc_undef] = STATE(1278),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1279] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6248),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1279),
    [sym_preproc_endregion] = STATE(1279),
    [sym_preproc_line] = STATE(1279),
    [sym_preproc_pragma] = STATE(1279),
    [sym_preproc_nullable] = STATE(1279),
    [sym_preproc_error] = STATE(1279),
    [sym_preproc_warning] = STATE(1279),
    [sym_preproc_define] = STATE(1279),
    [sym_preproc_undef] = STATE(1279),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1280] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6259),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1280),
    [sym_preproc_endregion] = STATE(1280),
    [sym_preproc_line] = STATE(1280),
    [sym_preproc_pragma] = STATE(1280),
    [sym_preproc_nullable] = STATE(1280),
    [sym_preproc_error] = STATE(1280),
    [sym_preproc_warning] = STATE(1280),
    [sym_preproc_define] = STATE(1280),
    [sym_preproc_undef] = STATE(1280),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1281] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5624),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1281),
    [sym_preproc_endregion] = STATE(1281),
    [sym_preproc_line] = STATE(1281),
    [sym_preproc_pragma] = STATE(1281),
    [sym_preproc_nullable] = STATE(1281),
    [sym_preproc_error] = STATE(1281),
    [sym_preproc_warning] = STATE(1281),
    [sym_preproc_define] = STATE(1281),
    [sym_preproc_undef] = STATE(1281),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1282] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4336),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1282),
    [sym_preproc_endregion] = STATE(1282),
    [sym_preproc_line] = STATE(1282),
    [sym_preproc_pragma] = STATE(1282),
    [sym_preproc_nullable] = STATE(1282),
    [sym_preproc_error] = STATE(1282),
    [sym_preproc_warning] = STATE(1282),
    [sym_preproc_define] = STATE(1282),
    [sym_preproc_undef] = STATE(1282),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1283] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6918),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6973),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5291),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4069),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7443),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9676),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1283),
    [sym_preproc_endregion] = STATE(1283),
    [sym_preproc_line] = STATE(1283),
    [sym_preproc_pragma] = STATE(1283),
    [sym_preproc_nullable] = STATE(1283),
    [sym_preproc_error] = STATE(1283),
    [sym_preproc_warning] = STATE(1283),
    [sym_preproc_define] = STATE(1283),
    [sym_preproc_undef] = STATE(1283),
    [aux_sym_class_declaration_repeat1] = STATE(3815),
    [aux_sym_lambda_expression_repeat1] = STATE(4217),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1515),
    [anon_sym_ref] = ACTIONS(1517),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1521),
    [anon_sym_TILDE] = ACTIONS(1521),
    [anon_sym_PLUS_PLUS] = ACTIONS(1521),
    [anon_sym_DASH_DASH] = ACTIONS(1521),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1519),
    [anon_sym_DASH] = ACTIONS(1519),
    [anon_sym_STAR] = ACTIONS(1523),
    [anon_sym_CARET] = ACTIONS(1521),
    [anon_sym_AMP] = ACTIONS(1521),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1525),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1527),
    [anon_sym_DOT_DOT] = ACTIONS(1529),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1284] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7105),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5955),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1284),
    [sym_preproc_endregion] = STATE(1284),
    [sym_preproc_line] = STATE(1284),
    [sym_preproc_pragma] = STATE(1284),
    [sym_preproc_nullable] = STATE(1284),
    [sym_preproc_error] = STATE(1284),
    [sym_preproc_warning] = STATE(1284),
    [sym_preproc_define] = STATE(1284),
    [sym_preproc_undef] = STATE(1284),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1285] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7131),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6209),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4364),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9470),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1285),
    [sym_preproc_endregion] = STATE(1285),
    [sym_preproc_line] = STATE(1285),
    [sym_preproc_pragma] = STATE(1285),
    [sym_preproc_nullable] = STATE(1285),
    [sym_preproc_error] = STATE(1285),
    [sym_preproc_warning] = STATE(1285),
    [sym_preproc_define] = STATE(1285),
    [sym_preproc_undef] = STATE(1285),
    [aux_sym_class_declaration_repeat1] = STATE(3870),
    [aux_sym_lambda_expression_repeat1] = STATE(4302),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1555),
    [anon_sym_ref] = ACTIONS(1557),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(695),
    [anon_sym_TILDE] = ACTIONS(695),
    [anon_sym_PLUS_PLUS] = ACTIONS(695),
    [anon_sym_DASH_DASH] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(697),
    [anon_sym_DASH] = ACTIONS(697),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(695),
    [anon_sym_AMP] = ACTIONS(695),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1559),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1561),
    [anon_sym_DOT_DOT] = ACTIONS(1563),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1286] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7139),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6432),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1286),
    [sym_preproc_endregion] = STATE(1286),
    [sym_preproc_line] = STATE(1286),
    [sym_preproc_pragma] = STATE(1286),
    [sym_preproc_nullable] = STATE(1286),
    [sym_preproc_error] = STATE(1286),
    [sym_preproc_warning] = STATE(1286),
    [sym_preproc_define] = STATE(1286),
    [sym_preproc_undef] = STATE(1286),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2011),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1287] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6956),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6683),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9482),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1287),
    [sym_preproc_endregion] = STATE(1287),
    [sym_preproc_line] = STATE(1287),
    [sym_preproc_pragma] = STATE(1287),
    [sym_preproc_nullable] = STATE(1287),
    [sym_preproc_error] = STATE(1287),
    [sym_preproc_warning] = STATE(1287),
    [sym_preproc_define] = STATE(1287),
    [sym_preproc_undef] = STATE(1287),
    [aux_sym_class_declaration_repeat1] = STATE(3853),
    [aux_sym_lambda_expression_repeat1] = STATE(4299),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1497),
    [anon_sym_ref] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1505),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1507),
    [anon_sym_DOT_DOT] = ACTIONS(1509),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1288] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7131),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6212),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4364),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9470),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1288),
    [sym_preproc_endregion] = STATE(1288),
    [sym_preproc_line] = STATE(1288),
    [sym_preproc_pragma] = STATE(1288),
    [sym_preproc_nullable] = STATE(1288),
    [sym_preproc_error] = STATE(1288),
    [sym_preproc_warning] = STATE(1288),
    [sym_preproc_define] = STATE(1288),
    [sym_preproc_undef] = STATE(1288),
    [aux_sym_class_declaration_repeat1] = STATE(3870),
    [aux_sym_lambda_expression_repeat1] = STATE(4302),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1555),
    [anon_sym_ref] = ACTIONS(1557),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(695),
    [anon_sym_TILDE] = ACTIONS(695),
    [anon_sym_PLUS_PLUS] = ACTIONS(695),
    [anon_sym_DASH_DASH] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(697),
    [anon_sym_DASH] = ACTIONS(697),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(695),
    [anon_sym_AMP] = ACTIONS(695),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1559),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1561),
    [anon_sym_DOT_DOT] = ACTIONS(1563),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1289] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7105),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5971),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1289),
    [sym_preproc_endregion] = STATE(1289),
    [sym_preproc_line] = STATE(1289),
    [sym_preproc_pragma] = STATE(1289),
    [sym_preproc_nullable] = STATE(1289),
    [sym_preproc_error] = STATE(1289),
    [sym_preproc_warning] = STATE(1289),
    [sym_preproc_define] = STATE(1289),
    [sym_preproc_undef] = STATE(1289),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1290] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7105),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5984),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1290),
    [sym_preproc_endregion] = STATE(1290),
    [sym_preproc_line] = STATE(1290),
    [sym_preproc_pragma] = STATE(1290),
    [sym_preproc_nullable] = STATE(1290),
    [sym_preproc_error] = STATE(1290),
    [sym_preproc_warning] = STATE(1290),
    [sym_preproc_define] = STATE(1290),
    [sym_preproc_undef] = STATE(1290),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1291] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6937),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2861),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7001),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5165),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4149),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7445),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9763),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(1291),
    [sym_preproc_endregion] = STATE(1291),
    [sym_preproc_line] = STATE(1291),
    [sym_preproc_pragma] = STATE(1291),
    [sym_preproc_nullable] = STATE(1291),
    [sym_preproc_error] = STATE(1291),
    [sym_preproc_warning] = STATE(1291),
    [sym_preproc_define] = STATE(1291),
    [sym_preproc_undef] = STATE(1291),
    [aux_sym_class_declaration_repeat1] = STATE(3821),
    [aux_sym_lambda_expression_repeat1] = STATE(4236),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1609),
    [anon_sym_ref] = ACTIONS(1611),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1481),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1615),
    [anon_sym_TILDE] = ACTIONS(1615),
    [anon_sym_PLUS_PLUS] = ACTIONS(1615),
    [anon_sym_DASH_DASH] = ACTIONS(1615),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1613),
    [anon_sym_DASH] = ACTIONS(1613),
    [anon_sym_STAR] = ACTIONS(1487),
    [anon_sym_CARET] = ACTIONS(1615),
    [anon_sym_AMP] = ACTIONS(1615),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1617),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1619),
    [anon_sym_DOT_DOT] = ACTIONS(1621),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [1292] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6937),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2861),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7105),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6726),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3938),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1292),
    [sym_preproc_endregion] = STATE(1292),
    [sym_preproc_line] = STATE(1292),
    [sym_preproc_pragma] = STATE(1292),
    [sym_preproc_nullable] = STATE(1292),
    [sym_preproc_error] = STATE(1292),
    [sym_preproc_warning] = STATE(1292),
    [sym_preproc_define] = STATE(1292),
    [sym_preproc_undef] = STATE(1292),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(2975),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(1487),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1293] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6967),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5134),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3813),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9209),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1293),
    [sym_preproc_endregion] = STATE(1293),
    [sym_preproc_line] = STATE(1293),
    [sym_preproc_pragma] = STATE(1293),
    [sym_preproc_nullable] = STATE(1293),
    [sym_preproc_error] = STATE(1293),
    [sym_preproc_warning] = STATE(1293),
    [sym_preproc_define] = STATE(1293),
    [sym_preproc_undef] = STATE(1293),
    [aux_sym_class_declaration_repeat1] = STATE(3814),
    [aux_sym_lambda_expression_repeat1] = STATE(4209),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1323),
    [anon_sym_ref] = ACTIONS(1325),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1083),
    [anon_sym_PLUS_PLUS] = ACTIONS(1083),
    [anon_sym_DASH_DASH] = ACTIONS(1083),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1085),
    [anon_sym_DASH] = ACTIONS(1085),
    [anon_sym_STAR] = ACTIONS(1335),
    [anon_sym_CARET] = ACTIONS(1083),
    [anon_sym_AMP] = ACTIONS(1083),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1341),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1343),
    [anon_sym_DOT_DOT] = ACTIONS(1345),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1294] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6967),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5136),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3813),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9209),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1294),
    [sym_preproc_endregion] = STATE(1294),
    [sym_preproc_line] = STATE(1294),
    [sym_preproc_pragma] = STATE(1294),
    [sym_preproc_nullable] = STATE(1294),
    [sym_preproc_error] = STATE(1294),
    [sym_preproc_warning] = STATE(1294),
    [sym_preproc_define] = STATE(1294),
    [sym_preproc_undef] = STATE(1294),
    [aux_sym_class_declaration_repeat1] = STATE(3814),
    [aux_sym_lambda_expression_repeat1] = STATE(4209),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1323),
    [anon_sym_ref] = ACTIONS(1325),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1083),
    [anon_sym_PLUS_PLUS] = ACTIONS(1083),
    [anon_sym_DASH_DASH] = ACTIONS(1083),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1085),
    [anon_sym_DASH] = ACTIONS(1085),
    [anon_sym_STAR] = ACTIONS(1335),
    [anon_sym_CARET] = ACTIONS(1083),
    [anon_sym_AMP] = ACTIONS(1083),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1341),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1343),
    [anon_sym_DOT_DOT] = ACTIONS(1345),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1295] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6967),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5109),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3813),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9209),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1295),
    [sym_preproc_endregion] = STATE(1295),
    [sym_preproc_line] = STATE(1295),
    [sym_preproc_pragma] = STATE(1295),
    [sym_preproc_nullable] = STATE(1295),
    [sym_preproc_error] = STATE(1295),
    [sym_preproc_warning] = STATE(1295),
    [sym_preproc_define] = STATE(1295),
    [sym_preproc_undef] = STATE(1295),
    [aux_sym_class_declaration_repeat1] = STATE(3814),
    [aux_sym_lambda_expression_repeat1] = STATE(4209),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1323),
    [anon_sym_ref] = ACTIONS(1325),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1083),
    [anon_sym_PLUS_PLUS] = ACTIONS(1083),
    [anon_sym_DASH_DASH] = ACTIONS(1083),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1085),
    [anon_sym_DASH] = ACTIONS(1085),
    [anon_sym_STAR] = ACTIONS(1335),
    [anon_sym_CARET] = ACTIONS(1083),
    [anon_sym_AMP] = ACTIONS(1083),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1341),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1343),
    [anon_sym_DOT_DOT] = ACTIONS(1345),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1296] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6967),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5050),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3813),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9209),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1296),
    [sym_preproc_endregion] = STATE(1296),
    [sym_preproc_line] = STATE(1296),
    [sym_preproc_pragma] = STATE(1296),
    [sym_preproc_nullable] = STATE(1296),
    [sym_preproc_error] = STATE(1296),
    [sym_preproc_warning] = STATE(1296),
    [sym_preproc_define] = STATE(1296),
    [sym_preproc_undef] = STATE(1296),
    [aux_sym_class_declaration_repeat1] = STATE(3814),
    [aux_sym_lambda_expression_repeat1] = STATE(4209),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1323),
    [anon_sym_ref] = ACTIONS(1325),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1083),
    [anon_sym_PLUS_PLUS] = ACTIONS(1083),
    [anon_sym_DASH_DASH] = ACTIONS(1083),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1085),
    [anon_sym_DASH] = ACTIONS(1085),
    [anon_sym_STAR] = ACTIONS(1335),
    [anon_sym_CARET] = ACTIONS(1083),
    [anon_sym_AMP] = ACTIONS(1083),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1341),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1343),
    [anon_sym_DOT_DOT] = ACTIONS(1345),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1297] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6967),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5058),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3813),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9209),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1297),
    [sym_preproc_endregion] = STATE(1297),
    [sym_preproc_line] = STATE(1297),
    [sym_preproc_pragma] = STATE(1297),
    [sym_preproc_nullable] = STATE(1297),
    [sym_preproc_error] = STATE(1297),
    [sym_preproc_warning] = STATE(1297),
    [sym_preproc_define] = STATE(1297),
    [sym_preproc_undef] = STATE(1297),
    [aux_sym_class_declaration_repeat1] = STATE(3814),
    [aux_sym_lambda_expression_repeat1] = STATE(4209),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1323),
    [anon_sym_ref] = ACTIONS(1325),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1083),
    [anon_sym_PLUS_PLUS] = ACTIONS(1083),
    [anon_sym_DASH_DASH] = ACTIONS(1083),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1085),
    [anon_sym_DASH] = ACTIONS(1085),
    [anon_sym_STAR] = ACTIONS(1335),
    [anon_sym_CARET] = ACTIONS(1083),
    [anon_sym_AMP] = ACTIONS(1083),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1341),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1343),
    [anon_sym_DOT_DOT] = ACTIONS(1345),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1298] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6967),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5073),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3813),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9209),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1298),
    [sym_preproc_endregion] = STATE(1298),
    [sym_preproc_line] = STATE(1298),
    [sym_preproc_pragma] = STATE(1298),
    [sym_preproc_nullable] = STATE(1298),
    [sym_preproc_error] = STATE(1298),
    [sym_preproc_warning] = STATE(1298),
    [sym_preproc_define] = STATE(1298),
    [sym_preproc_undef] = STATE(1298),
    [aux_sym_class_declaration_repeat1] = STATE(3814),
    [aux_sym_lambda_expression_repeat1] = STATE(4209),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1323),
    [anon_sym_ref] = ACTIONS(1325),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1083),
    [anon_sym_PLUS_PLUS] = ACTIONS(1083),
    [anon_sym_DASH_DASH] = ACTIONS(1083),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1085),
    [anon_sym_DASH] = ACTIONS(1085),
    [anon_sym_STAR] = ACTIONS(1335),
    [anon_sym_CARET] = ACTIONS(1083),
    [anon_sym_AMP] = ACTIONS(1083),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1341),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1343),
    [anon_sym_DOT_DOT] = ACTIONS(1345),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1299] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6967),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5084),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3813),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9209),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1299),
    [sym_preproc_endregion] = STATE(1299),
    [sym_preproc_line] = STATE(1299),
    [sym_preproc_pragma] = STATE(1299),
    [sym_preproc_nullable] = STATE(1299),
    [sym_preproc_error] = STATE(1299),
    [sym_preproc_warning] = STATE(1299),
    [sym_preproc_define] = STATE(1299),
    [sym_preproc_undef] = STATE(1299),
    [aux_sym_class_declaration_repeat1] = STATE(3814),
    [aux_sym_lambda_expression_repeat1] = STATE(4209),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1323),
    [anon_sym_ref] = ACTIONS(1325),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1083),
    [anon_sym_PLUS_PLUS] = ACTIONS(1083),
    [anon_sym_DASH_DASH] = ACTIONS(1083),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1085),
    [anon_sym_DASH] = ACTIONS(1085),
    [anon_sym_STAR] = ACTIONS(1335),
    [anon_sym_CARET] = ACTIONS(1083),
    [anon_sym_AMP] = ACTIONS(1083),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1341),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1343),
    [anon_sym_DOT_DOT] = ACTIONS(1345),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1300] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6967),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5086),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3813),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9209),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1300),
    [sym_preproc_endregion] = STATE(1300),
    [sym_preproc_line] = STATE(1300),
    [sym_preproc_pragma] = STATE(1300),
    [sym_preproc_nullable] = STATE(1300),
    [sym_preproc_error] = STATE(1300),
    [sym_preproc_warning] = STATE(1300),
    [sym_preproc_define] = STATE(1300),
    [sym_preproc_undef] = STATE(1300),
    [aux_sym_class_declaration_repeat1] = STATE(3814),
    [aux_sym_lambda_expression_repeat1] = STATE(4209),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1323),
    [anon_sym_ref] = ACTIONS(1325),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1083),
    [anon_sym_PLUS_PLUS] = ACTIONS(1083),
    [anon_sym_DASH_DASH] = ACTIONS(1083),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1085),
    [anon_sym_DASH] = ACTIONS(1085),
    [anon_sym_STAR] = ACTIONS(1335),
    [anon_sym_CARET] = ACTIONS(1083),
    [anon_sym_AMP] = ACTIONS(1083),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1341),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1343),
    [anon_sym_DOT_DOT] = ACTIONS(1345),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1301] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6967),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5087),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3813),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9209),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1301),
    [sym_preproc_endregion] = STATE(1301),
    [sym_preproc_line] = STATE(1301),
    [sym_preproc_pragma] = STATE(1301),
    [sym_preproc_nullable] = STATE(1301),
    [sym_preproc_error] = STATE(1301),
    [sym_preproc_warning] = STATE(1301),
    [sym_preproc_define] = STATE(1301),
    [sym_preproc_undef] = STATE(1301),
    [aux_sym_class_declaration_repeat1] = STATE(3814),
    [aux_sym_lambda_expression_repeat1] = STATE(4209),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1323),
    [anon_sym_ref] = ACTIONS(1325),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1083),
    [anon_sym_PLUS_PLUS] = ACTIONS(1083),
    [anon_sym_DASH_DASH] = ACTIONS(1083),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1085),
    [anon_sym_DASH] = ACTIONS(1085),
    [anon_sym_STAR] = ACTIONS(1335),
    [anon_sym_CARET] = ACTIONS(1083),
    [anon_sym_AMP] = ACTIONS(1083),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1341),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1343),
    [anon_sym_DOT_DOT] = ACTIONS(1345),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1302] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6967),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5089),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3813),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9209),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1302),
    [sym_preproc_endregion] = STATE(1302),
    [sym_preproc_line] = STATE(1302),
    [sym_preproc_pragma] = STATE(1302),
    [sym_preproc_nullable] = STATE(1302),
    [sym_preproc_error] = STATE(1302),
    [sym_preproc_warning] = STATE(1302),
    [sym_preproc_define] = STATE(1302),
    [sym_preproc_undef] = STATE(1302),
    [aux_sym_class_declaration_repeat1] = STATE(3814),
    [aux_sym_lambda_expression_repeat1] = STATE(4209),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1323),
    [anon_sym_ref] = ACTIONS(1325),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1083),
    [anon_sym_PLUS_PLUS] = ACTIONS(1083),
    [anon_sym_DASH_DASH] = ACTIONS(1083),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1085),
    [anon_sym_DASH] = ACTIONS(1085),
    [anon_sym_STAR] = ACTIONS(1335),
    [anon_sym_CARET] = ACTIONS(1083),
    [anon_sym_AMP] = ACTIONS(1083),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1341),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1343),
    [anon_sym_DOT_DOT] = ACTIONS(1345),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1303] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6967),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5090),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3813),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9209),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1303),
    [sym_preproc_endregion] = STATE(1303),
    [sym_preproc_line] = STATE(1303),
    [sym_preproc_pragma] = STATE(1303),
    [sym_preproc_nullable] = STATE(1303),
    [sym_preproc_error] = STATE(1303),
    [sym_preproc_warning] = STATE(1303),
    [sym_preproc_define] = STATE(1303),
    [sym_preproc_undef] = STATE(1303),
    [aux_sym_class_declaration_repeat1] = STATE(3814),
    [aux_sym_lambda_expression_repeat1] = STATE(4209),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1323),
    [anon_sym_ref] = ACTIONS(1325),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1083),
    [anon_sym_PLUS_PLUS] = ACTIONS(1083),
    [anon_sym_DASH_DASH] = ACTIONS(1083),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1085),
    [anon_sym_DASH] = ACTIONS(1085),
    [anon_sym_STAR] = ACTIONS(1335),
    [anon_sym_CARET] = ACTIONS(1083),
    [anon_sym_AMP] = ACTIONS(1083),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1341),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1343),
    [anon_sym_DOT_DOT] = ACTIONS(1345),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1304] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6967),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3932),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3813),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9209),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1304),
    [sym_preproc_endregion] = STATE(1304),
    [sym_preproc_line] = STATE(1304),
    [sym_preproc_pragma] = STATE(1304),
    [sym_preproc_nullable] = STATE(1304),
    [sym_preproc_error] = STATE(1304),
    [sym_preproc_warning] = STATE(1304),
    [sym_preproc_define] = STATE(1304),
    [sym_preproc_undef] = STATE(1304),
    [aux_sym_class_declaration_repeat1] = STATE(3814),
    [aux_sym_lambda_expression_repeat1] = STATE(4209),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1323),
    [anon_sym_ref] = ACTIONS(1325),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1083),
    [anon_sym_PLUS_PLUS] = ACTIONS(1083),
    [anon_sym_DASH_DASH] = ACTIONS(1083),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1085),
    [anon_sym_DASH] = ACTIONS(1085),
    [anon_sym_STAR] = ACTIONS(1335),
    [anon_sym_CARET] = ACTIONS(1083),
    [anon_sym_AMP] = ACTIONS(1083),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1341),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1343),
    [anon_sym_DOT_DOT] = ACTIONS(1345),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1305] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6925),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2932),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6992),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4576),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3702),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7420),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9634),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(1305),
    [sym_preproc_endregion] = STATE(1305),
    [sym_preproc_line] = STATE(1305),
    [sym_preproc_pragma] = STATE(1305),
    [sym_preproc_nullable] = STATE(1305),
    [sym_preproc_error] = STATE(1305),
    [sym_preproc_warning] = STATE(1305),
    [sym_preproc_define] = STATE(1305),
    [sym_preproc_undef] = STATE(1305),
    [aux_sym_class_declaration_repeat1] = STATE(3819),
    [aux_sym_lambda_expression_repeat1] = STATE(4232),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1995),
    [anon_sym_ref] = ACTIONS(1997),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1771),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(2001),
    [anon_sym_TILDE] = ACTIONS(2001),
    [anon_sym_PLUS_PLUS] = ACTIONS(2001),
    [anon_sym_DASH_DASH] = ACTIONS(2001),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1999),
    [anon_sym_DASH] = ACTIONS(1999),
    [anon_sym_STAR] = ACTIONS(1777),
    [anon_sym_CARET] = ACTIONS(2001),
    [anon_sym_AMP] = ACTIONS(2001),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(2003),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2005),
    [anon_sym_DOT_DOT] = ACTIONS(2007),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [1306] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6925),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2932),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6992),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4373),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3702),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7420),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9634),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(1306),
    [sym_preproc_endregion] = STATE(1306),
    [sym_preproc_line] = STATE(1306),
    [sym_preproc_pragma] = STATE(1306),
    [sym_preproc_nullable] = STATE(1306),
    [sym_preproc_error] = STATE(1306),
    [sym_preproc_warning] = STATE(1306),
    [sym_preproc_define] = STATE(1306),
    [sym_preproc_undef] = STATE(1306),
    [aux_sym_class_declaration_repeat1] = STATE(3819),
    [aux_sym_lambda_expression_repeat1] = STATE(4232),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1995),
    [anon_sym_ref] = ACTIONS(1997),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1771),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(2001),
    [anon_sym_TILDE] = ACTIONS(2001),
    [anon_sym_PLUS_PLUS] = ACTIONS(2001),
    [anon_sym_DASH_DASH] = ACTIONS(2001),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1999),
    [anon_sym_DASH] = ACTIONS(1999),
    [anon_sym_STAR] = ACTIONS(1777),
    [anon_sym_CARET] = ACTIONS(2001),
    [anon_sym_AMP] = ACTIONS(2001),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(2003),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2005),
    [anon_sym_DOT_DOT] = ACTIONS(2007),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [1307] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7105),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3056),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1307),
    [sym_preproc_endregion] = STATE(1307),
    [sym_preproc_line] = STATE(1307),
    [sym_preproc_pragma] = STATE(1307),
    [sym_preproc_nullable] = STATE(1307),
    [sym_preproc_error] = STATE(1307),
    [sym_preproc_warning] = STATE(1307),
    [sym_preproc_define] = STATE(1307),
    [sym_preproc_undef] = STATE(1307),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1308] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6925),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2932),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6992),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4587),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3702),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7420),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9634),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(1308),
    [sym_preproc_endregion] = STATE(1308),
    [sym_preproc_line] = STATE(1308),
    [sym_preproc_pragma] = STATE(1308),
    [sym_preproc_nullable] = STATE(1308),
    [sym_preproc_error] = STATE(1308),
    [sym_preproc_warning] = STATE(1308),
    [sym_preproc_define] = STATE(1308),
    [sym_preproc_undef] = STATE(1308),
    [aux_sym_class_declaration_repeat1] = STATE(3819),
    [aux_sym_lambda_expression_repeat1] = STATE(4232),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1995),
    [anon_sym_ref] = ACTIONS(1997),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1771),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(2001),
    [anon_sym_TILDE] = ACTIONS(2001),
    [anon_sym_PLUS_PLUS] = ACTIONS(2001),
    [anon_sym_DASH_DASH] = ACTIONS(2001),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1999),
    [anon_sym_DASH] = ACTIONS(1999),
    [anon_sym_STAR] = ACTIONS(1777),
    [anon_sym_CARET] = ACTIONS(2001),
    [anon_sym_AMP] = ACTIONS(2001),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(2003),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2005),
    [anon_sym_DOT_DOT] = ACTIONS(2007),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [1309] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6925),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2932),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7073),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4414),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3565),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7434),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9324),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(1309),
    [sym_preproc_endregion] = STATE(1309),
    [sym_preproc_line] = STATE(1309),
    [sym_preproc_pragma] = STATE(1309),
    [sym_preproc_nullable] = STATE(1309),
    [sym_preproc_error] = STATE(1309),
    [sym_preproc_warning] = STATE(1309),
    [sym_preproc_define] = STATE(1309),
    [sym_preproc_undef] = STATE(1309),
    [aux_sym_class_declaration_repeat1] = STATE(3842),
    [aux_sym_lambda_expression_repeat1] = STATE(4273),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1767),
    [anon_sym_ref] = ACTIONS(1769),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1771),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1775),
    [anon_sym_TILDE] = ACTIONS(1775),
    [anon_sym_PLUS_PLUS] = ACTIONS(1775),
    [anon_sym_DASH_DASH] = ACTIONS(1775),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1773),
    [anon_sym_DASH] = ACTIONS(1773),
    [anon_sym_STAR] = ACTIONS(1777),
    [anon_sym_CARET] = ACTIONS(1775),
    [anon_sym_AMP] = ACTIONS(1775),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(1779),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1781),
    [anon_sym_DOT_DOT] = ACTIONS(1783),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [1310] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6925),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2932),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6992),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4599),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3702),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7420),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9634),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(1310),
    [sym_preproc_endregion] = STATE(1310),
    [sym_preproc_line] = STATE(1310),
    [sym_preproc_pragma] = STATE(1310),
    [sym_preproc_nullable] = STATE(1310),
    [sym_preproc_error] = STATE(1310),
    [sym_preproc_warning] = STATE(1310),
    [sym_preproc_define] = STATE(1310),
    [sym_preproc_undef] = STATE(1310),
    [aux_sym_class_declaration_repeat1] = STATE(3819),
    [aux_sym_lambda_expression_repeat1] = STATE(4232),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1995),
    [anon_sym_ref] = ACTIONS(1997),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1771),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(2001),
    [anon_sym_TILDE] = ACTIONS(2001),
    [anon_sym_PLUS_PLUS] = ACTIONS(2001),
    [anon_sym_DASH_DASH] = ACTIONS(2001),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1999),
    [anon_sym_DASH] = ACTIONS(1999),
    [anon_sym_STAR] = ACTIONS(1777),
    [anon_sym_CARET] = ACTIONS(2001),
    [anon_sym_AMP] = ACTIONS(2001),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(2003),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2005),
    [anon_sym_DOT_DOT] = ACTIONS(2007),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [1311] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6918),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6973),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5267),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4069),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7443),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9676),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1311),
    [sym_preproc_endregion] = STATE(1311),
    [sym_preproc_line] = STATE(1311),
    [sym_preproc_pragma] = STATE(1311),
    [sym_preproc_nullable] = STATE(1311),
    [sym_preproc_error] = STATE(1311),
    [sym_preproc_warning] = STATE(1311),
    [sym_preproc_define] = STATE(1311),
    [sym_preproc_undef] = STATE(1311),
    [aux_sym_class_declaration_repeat1] = STATE(3815),
    [aux_sym_lambda_expression_repeat1] = STATE(4217),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1515),
    [anon_sym_ref] = ACTIONS(1517),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1521),
    [anon_sym_TILDE] = ACTIONS(1521),
    [anon_sym_PLUS_PLUS] = ACTIONS(1521),
    [anon_sym_DASH_DASH] = ACTIONS(1521),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1519),
    [anon_sym_DASH] = ACTIONS(1519),
    [anon_sym_STAR] = ACTIONS(1523),
    [anon_sym_CARET] = ACTIONS(1521),
    [anon_sym_AMP] = ACTIONS(1521),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1525),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1527),
    [anon_sym_DOT_DOT] = ACTIONS(1529),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1312] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6918),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6973),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3567),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4069),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7443),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9676),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1312),
    [sym_preproc_endregion] = STATE(1312),
    [sym_preproc_line] = STATE(1312),
    [sym_preproc_pragma] = STATE(1312),
    [sym_preproc_nullable] = STATE(1312),
    [sym_preproc_error] = STATE(1312),
    [sym_preproc_warning] = STATE(1312),
    [sym_preproc_define] = STATE(1312),
    [sym_preproc_undef] = STATE(1312),
    [aux_sym_class_declaration_repeat1] = STATE(3815),
    [aux_sym_lambda_expression_repeat1] = STATE(4217),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1515),
    [anon_sym_ref] = ACTIONS(1517),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1521),
    [anon_sym_TILDE] = ACTIONS(1521),
    [anon_sym_PLUS_PLUS] = ACTIONS(1521),
    [anon_sym_DASH_DASH] = ACTIONS(1521),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1519),
    [anon_sym_DASH] = ACTIONS(1519),
    [anon_sym_STAR] = ACTIONS(1523),
    [anon_sym_CARET] = ACTIONS(1521),
    [anon_sym_AMP] = ACTIONS(1521),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1525),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1527),
    [anon_sym_DOT_DOT] = ACTIONS(1529),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1313] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6925),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2932),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6992),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4617),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3702),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7420),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9634),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(1313),
    [sym_preproc_endregion] = STATE(1313),
    [sym_preproc_line] = STATE(1313),
    [sym_preproc_pragma] = STATE(1313),
    [sym_preproc_nullable] = STATE(1313),
    [sym_preproc_error] = STATE(1313),
    [sym_preproc_warning] = STATE(1313),
    [sym_preproc_define] = STATE(1313),
    [sym_preproc_undef] = STATE(1313),
    [aux_sym_class_declaration_repeat1] = STATE(3819),
    [aux_sym_lambda_expression_repeat1] = STATE(4232),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1995),
    [anon_sym_ref] = ACTIONS(1997),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1771),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(2001),
    [anon_sym_TILDE] = ACTIONS(2001),
    [anon_sym_PLUS_PLUS] = ACTIONS(2001),
    [anon_sym_DASH_DASH] = ACTIONS(2001),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1999),
    [anon_sym_DASH] = ACTIONS(1999),
    [anon_sym_STAR] = ACTIONS(1777),
    [anon_sym_CARET] = ACTIONS(2001),
    [anon_sym_AMP] = ACTIONS(2001),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(2003),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2005),
    [anon_sym_DOT_DOT] = ACTIONS(2007),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [1314] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6925),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2932),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6992),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4618),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3702),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7420),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9634),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(1314),
    [sym_preproc_endregion] = STATE(1314),
    [sym_preproc_line] = STATE(1314),
    [sym_preproc_pragma] = STATE(1314),
    [sym_preproc_nullable] = STATE(1314),
    [sym_preproc_error] = STATE(1314),
    [sym_preproc_warning] = STATE(1314),
    [sym_preproc_define] = STATE(1314),
    [sym_preproc_undef] = STATE(1314),
    [aux_sym_class_declaration_repeat1] = STATE(3819),
    [aux_sym_lambda_expression_repeat1] = STATE(4232),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1995),
    [anon_sym_ref] = ACTIONS(1997),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1771),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(2001),
    [anon_sym_TILDE] = ACTIONS(2001),
    [anon_sym_PLUS_PLUS] = ACTIONS(2001),
    [anon_sym_DASH_DASH] = ACTIONS(2001),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1999),
    [anon_sym_DASH] = ACTIONS(1999),
    [anon_sym_STAR] = ACTIONS(1777),
    [anon_sym_CARET] = ACTIONS(2001),
    [anon_sym_AMP] = ACTIONS(2001),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(2003),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2005),
    [anon_sym_DOT_DOT] = ACTIONS(2007),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [1315] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6925),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2932),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6992),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4619),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3702),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7420),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9634),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(1315),
    [sym_preproc_endregion] = STATE(1315),
    [sym_preproc_line] = STATE(1315),
    [sym_preproc_pragma] = STATE(1315),
    [sym_preproc_nullable] = STATE(1315),
    [sym_preproc_error] = STATE(1315),
    [sym_preproc_warning] = STATE(1315),
    [sym_preproc_define] = STATE(1315),
    [sym_preproc_undef] = STATE(1315),
    [aux_sym_class_declaration_repeat1] = STATE(3819),
    [aux_sym_lambda_expression_repeat1] = STATE(4232),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1995),
    [anon_sym_ref] = ACTIONS(1997),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1771),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(2001),
    [anon_sym_TILDE] = ACTIONS(2001),
    [anon_sym_PLUS_PLUS] = ACTIONS(2001),
    [anon_sym_DASH_DASH] = ACTIONS(2001),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1999),
    [anon_sym_DASH] = ACTIONS(1999),
    [anon_sym_STAR] = ACTIONS(1777),
    [anon_sym_CARET] = ACTIONS(2001),
    [anon_sym_AMP] = ACTIONS(2001),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(2003),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2005),
    [anon_sym_DOT_DOT] = ACTIONS(2007),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [1316] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6925),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2932),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6992),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4674),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3702),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7420),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9634),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(1316),
    [sym_preproc_endregion] = STATE(1316),
    [sym_preproc_line] = STATE(1316),
    [sym_preproc_pragma] = STATE(1316),
    [sym_preproc_nullable] = STATE(1316),
    [sym_preproc_error] = STATE(1316),
    [sym_preproc_warning] = STATE(1316),
    [sym_preproc_define] = STATE(1316),
    [sym_preproc_undef] = STATE(1316),
    [aux_sym_class_declaration_repeat1] = STATE(3819),
    [aux_sym_lambda_expression_repeat1] = STATE(4232),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1995),
    [anon_sym_ref] = ACTIONS(1997),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1771),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(2001),
    [anon_sym_TILDE] = ACTIONS(2001),
    [anon_sym_PLUS_PLUS] = ACTIONS(2001),
    [anon_sym_DASH_DASH] = ACTIONS(2001),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1999),
    [anon_sym_DASH] = ACTIONS(1999),
    [anon_sym_STAR] = ACTIONS(1777),
    [anon_sym_CARET] = ACTIONS(2001),
    [anon_sym_AMP] = ACTIONS(2001),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(2003),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2005),
    [anon_sym_DOT_DOT] = ACTIONS(2007),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [1317] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6925),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2932),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6992),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4679),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3702),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7420),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9634),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(1317),
    [sym_preproc_endregion] = STATE(1317),
    [sym_preproc_line] = STATE(1317),
    [sym_preproc_pragma] = STATE(1317),
    [sym_preproc_nullable] = STATE(1317),
    [sym_preproc_error] = STATE(1317),
    [sym_preproc_warning] = STATE(1317),
    [sym_preproc_define] = STATE(1317),
    [sym_preproc_undef] = STATE(1317),
    [aux_sym_class_declaration_repeat1] = STATE(3819),
    [aux_sym_lambda_expression_repeat1] = STATE(4232),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1995),
    [anon_sym_ref] = ACTIONS(1997),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1771),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(2001),
    [anon_sym_TILDE] = ACTIONS(2001),
    [anon_sym_PLUS_PLUS] = ACTIONS(2001),
    [anon_sym_DASH_DASH] = ACTIONS(2001),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1999),
    [anon_sym_DASH] = ACTIONS(1999),
    [anon_sym_STAR] = ACTIONS(1777),
    [anon_sym_CARET] = ACTIONS(2001),
    [anon_sym_AMP] = ACTIONS(2001),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(2003),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2005),
    [anon_sym_DOT_DOT] = ACTIONS(2007),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [1318] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6925),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2932),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6992),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4680),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3702),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7420),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9634),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(1318),
    [sym_preproc_endregion] = STATE(1318),
    [sym_preproc_line] = STATE(1318),
    [sym_preproc_pragma] = STATE(1318),
    [sym_preproc_nullable] = STATE(1318),
    [sym_preproc_error] = STATE(1318),
    [sym_preproc_warning] = STATE(1318),
    [sym_preproc_define] = STATE(1318),
    [sym_preproc_undef] = STATE(1318),
    [aux_sym_class_declaration_repeat1] = STATE(3819),
    [aux_sym_lambda_expression_repeat1] = STATE(4232),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1995),
    [anon_sym_ref] = ACTIONS(1997),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1771),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(2001),
    [anon_sym_TILDE] = ACTIONS(2001),
    [anon_sym_PLUS_PLUS] = ACTIONS(2001),
    [anon_sym_DASH_DASH] = ACTIONS(2001),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1999),
    [anon_sym_DASH] = ACTIONS(1999),
    [anon_sym_STAR] = ACTIONS(1777),
    [anon_sym_CARET] = ACTIONS(2001),
    [anon_sym_AMP] = ACTIONS(2001),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(2003),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2005),
    [anon_sym_DOT_DOT] = ACTIONS(2007),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [1319] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6925),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2932),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6992),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4623),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3702),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7420),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9634),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(1319),
    [sym_preproc_endregion] = STATE(1319),
    [sym_preproc_line] = STATE(1319),
    [sym_preproc_pragma] = STATE(1319),
    [sym_preproc_nullable] = STATE(1319),
    [sym_preproc_error] = STATE(1319),
    [sym_preproc_warning] = STATE(1319),
    [sym_preproc_define] = STATE(1319),
    [sym_preproc_undef] = STATE(1319),
    [aux_sym_class_declaration_repeat1] = STATE(3819),
    [aux_sym_lambda_expression_repeat1] = STATE(4232),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1995),
    [anon_sym_ref] = ACTIONS(1997),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1771),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(2001),
    [anon_sym_TILDE] = ACTIONS(2001),
    [anon_sym_PLUS_PLUS] = ACTIONS(2001),
    [anon_sym_DASH_DASH] = ACTIONS(2001),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1999),
    [anon_sym_DASH] = ACTIONS(1999),
    [anon_sym_STAR] = ACTIONS(1777),
    [anon_sym_CARET] = ACTIONS(2001),
    [anon_sym_AMP] = ACTIONS(2001),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(2003),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2005),
    [anon_sym_DOT_DOT] = ACTIONS(2007),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [1320] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6925),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2932),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6992),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4681),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3702),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7420),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9634),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(1320),
    [sym_preproc_endregion] = STATE(1320),
    [sym_preproc_line] = STATE(1320),
    [sym_preproc_pragma] = STATE(1320),
    [sym_preproc_nullable] = STATE(1320),
    [sym_preproc_error] = STATE(1320),
    [sym_preproc_warning] = STATE(1320),
    [sym_preproc_define] = STATE(1320),
    [sym_preproc_undef] = STATE(1320),
    [aux_sym_class_declaration_repeat1] = STATE(3819),
    [aux_sym_lambda_expression_repeat1] = STATE(4232),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1995),
    [anon_sym_ref] = ACTIONS(1997),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1771),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(2001),
    [anon_sym_TILDE] = ACTIONS(2001),
    [anon_sym_PLUS_PLUS] = ACTIONS(2001),
    [anon_sym_DASH_DASH] = ACTIONS(2001),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1999),
    [anon_sym_DASH] = ACTIONS(1999),
    [anon_sym_STAR] = ACTIONS(1777),
    [anon_sym_CARET] = ACTIONS(2001),
    [anon_sym_AMP] = ACTIONS(2001),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(2003),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2005),
    [anon_sym_DOT_DOT] = ACTIONS(2007),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [1321] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6925),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2932),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6992),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4683),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3702),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7420),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9634),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(1321),
    [sym_preproc_endregion] = STATE(1321),
    [sym_preproc_line] = STATE(1321),
    [sym_preproc_pragma] = STATE(1321),
    [sym_preproc_nullable] = STATE(1321),
    [sym_preproc_error] = STATE(1321),
    [sym_preproc_warning] = STATE(1321),
    [sym_preproc_define] = STATE(1321),
    [sym_preproc_undef] = STATE(1321),
    [aux_sym_class_declaration_repeat1] = STATE(3819),
    [aux_sym_lambda_expression_repeat1] = STATE(4232),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1995),
    [anon_sym_ref] = ACTIONS(1997),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1771),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(2001),
    [anon_sym_TILDE] = ACTIONS(2001),
    [anon_sym_PLUS_PLUS] = ACTIONS(2001),
    [anon_sym_DASH_DASH] = ACTIONS(2001),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1999),
    [anon_sym_DASH] = ACTIONS(1999),
    [anon_sym_STAR] = ACTIONS(1777),
    [anon_sym_CARET] = ACTIONS(2001),
    [anon_sym_AMP] = ACTIONS(2001),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(2003),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2005),
    [anon_sym_DOT_DOT] = ACTIONS(2007),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [1322] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6925),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2932),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6992),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4685),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3702),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7420),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9634),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(1322),
    [sym_preproc_endregion] = STATE(1322),
    [sym_preproc_line] = STATE(1322),
    [sym_preproc_pragma] = STATE(1322),
    [sym_preproc_nullable] = STATE(1322),
    [sym_preproc_error] = STATE(1322),
    [sym_preproc_warning] = STATE(1322),
    [sym_preproc_define] = STATE(1322),
    [sym_preproc_undef] = STATE(1322),
    [aux_sym_class_declaration_repeat1] = STATE(3819),
    [aux_sym_lambda_expression_repeat1] = STATE(4232),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1995),
    [anon_sym_ref] = ACTIONS(1997),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1771),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(2001),
    [anon_sym_TILDE] = ACTIONS(2001),
    [anon_sym_PLUS_PLUS] = ACTIONS(2001),
    [anon_sym_DASH_DASH] = ACTIONS(2001),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1999),
    [anon_sym_DASH] = ACTIONS(1999),
    [anon_sym_STAR] = ACTIONS(1777),
    [anon_sym_CARET] = ACTIONS(2001),
    [anon_sym_AMP] = ACTIONS(2001),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(2003),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2005),
    [anon_sym_DOT_DOT] = ACTIONS(2007),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [1323] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6925),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2932),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6992),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4689),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3702),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7420),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9634),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(1323),
    [sym_preproc_endregion] = STATE(1323),
    [sym_preproc_line] = STATE(1323),
    [sym_preproc_pragma] = STATE(1323),
    [sym_preproc_nullable] = STATE(1323),
    [sym_preproc_error] = STATE(1323),
    [sym_preproc_warning] = STATE(1323),
    [sym_preproc_define] = STATE(1323),
    [sym_preproc_undef] = STATE(1323),
    [aux_sym_class_declaration_repeat1] = STATE(3819),
    [aux_sym_lambda_expression_repeat1] = STATE(4232),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1995),
    [anon_sym_ref] = ACTIONS(1997),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1771),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(2001),
    [anon_sym_TILDE] = ACTIONS(2001),
    [anon_sym_PLUS_PLUS] = ACTIONS(2001),
    [anon_sym_DASH_DASH] = ACTIONS(2001),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1999),
    [anon_sym_DASH] = ACTIONS(1999),
    [anon_sym_STAR] = ACTIONS(1777),
    [anon_sym_CARET] = ACTIONS(2001),
    [anon_sym_AMP] = ACTIONS(2001),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(2003),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2005),
    [anon_sym_DOT_DOT] = ACTIONS(2007),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [1324] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6918),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6973),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5369),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4069),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7443),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9676),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1324),
    [sym_preproc_endregion] = STATE(1324),
    [sym_preproc_line] = STATE(1324),
    [sym_preproc_pragma] = STATE(1324),
    [sym_preproc_nullable] = STATE(1324),
    [sym_preproc_error] = STATE(1324),
    [sym_preproc_warning] = STATE(1324),
    [sym_preproc_define] = STATE(1324),
    [sym_preproc_undef] = STATE(1324),
    [aux_sym_class_declaration_repeat1] = STATE(3815),
    [aux_sym_lambda_expression_repeat1] = STATE(4217),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1515),
    [anon_sym_ref] = ACTIONS(1517),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1521),
    [anon_sym_TILDE] = ACTIONS(1521),
    [anon_sym_PLUS_PLUS] = ACTIONS(1521),
    [anon_sym_DASH_DASH] = ACTIONS(1521),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1519),
    [anon_sym_DASH] = ACTIONS(1519),
    [anon_sym_STAR] = ACTIONS(1523),
    [anon_sym_CARET] = ACTIONS(1521),
    [anon_sym_AMP] = ACTIONS(1521),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1525),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1527),
    [anon_sym_DOT_DOT] = ACTIONS(1529),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1325] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6925),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2932),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6992),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4389),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3702),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7420),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9634),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(1325),
    [sym_preproc_endregion] = STATE(1325),
    [sym_preproc_line] = STATE(1325),
    [sym_preproc_pragma] = STATE(1325),
    [sym_preproc_nullable] = STATE(1325),
    [sym_preproc_error] = STATE(1325),
    [sym_preproc_warning] = STATE(1325),
    [sym_preproc_define] = STATE(1325),
    [sym_preproc_undef] = STATE(1325),
    [aux_sym_class_declaration_repeat1] = STATE(3819),
    [aux_sym_lambda_expression_repeat1] = STATE(4232),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1995),
    [anon_sym_ref] = ACTIONS(1997),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1771),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(2001),
    [anon_sym_TILDE] = ACTIONS(2001),
    [anon_sym_PLUS_PLUS] = ACTIONS(2001),
    [anon_sym_DASH_DASH] = ACTIONS(2001),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1999),
    [anon_sym_DASH] = ACTIONS(1999),
    [anon_sym_STAR] = ACTIONS(1777),
    [anon_sym_CARET] = ACTIONS(2001),
    [anon_sym_AMP] = ACTIONS(2001),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(2003),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2005),
    [anon_sym_DOT_DOT] = ACTIONS(2007),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [1326] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6950),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7044),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5105),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3868),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7432),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9127),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1326),
    [sym_preproc_endregion] = STATE(1326),
    [sym_preproc_line] = STATE(1326),
    [sym_preproc_pragma] = STATE(1326),
    [sym_preproc_nullable] = STATE(1326),
    [sym_preproc_error] = STATE(1326),
    [sym_preproc_warning] = STATE(1326),
    [sym_preproc_define] = STATE(1326),
    [sym_preproc_undef] = STATE(1326),
    [aux_sym_class_declaration_repeat1] = STATE(3832),
    [aux_sym_lambda_expression_repeat1] = STATE(4259),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1357),
    [anon_sym_ref] = ACTIONS(1359),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1363),
    [anon_sym_TILDE] = ACTIONS(1363),
    [anon_sym_PLUS_PLUS] = ACTIONS(1363),
    [anon_sym_DASH_DASH] = ACTIONS(1363),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1361),
    [anon_sym_DASH] = ACTIONS(1361),
    [anon_sym_STAR] = ACTIONS(1365),
    [anon_sym_CARET] = ACTIONS(1363),
    [anon_sym_AMP] = ACTIONS(1363),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1367),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1369),
    [anon_sym_DOT_DOT] = ACTIONS(1371),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1327] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6943),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2986),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7151),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6357),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4518),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7441),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9110),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1327),
    [sym_preproc_endregion] = STATE(1327),
    [sym_preproc_line] = STATE(1327),
    [sym_preproc_pragma] = STATE(1327),
    [sym_preproc_nullable] = STATE(1327),
    [sym_preproc_error] = STATE(1327),
    [sym_preproc_warning] = STATE(1327),
    [sym_preproc_define] = STATE(1327),
    [sym_preproc_undef] = STATE(1327),
    [aux_sym_class_declaration_repeat1] = STATE(3875),
    [aux_sym_lambda_expression_repeat1] = STATE(4315),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2169),
    [anon_sym_ref] = ACTIONS(2171),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2173),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2177),
    [anon_sym_TILDE] = ACTIONS(2177),
    [anon_sym_PLUS_PLUS] = ACTIONS(2177),
    [anon_sym_DASH_DASH] = ACTIONS(2177),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2175),
    [anon_sym_DASH] = ACTIONS(2175),
    [anon_sym_STAR] = ACTIONS(2179),
    [anon_sym_CARET] = ACTIONS(2177),
    [anon_sym_AMP] = ACTIONS(2177),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2181),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2183),
    [anon_sym_DOT_DOT] = ACTIONS(2185),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1328] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6918),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6973),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5257),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4069),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7443),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9676),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1328),
    [sym_preproc_endregion] = STATE(1328),
    [sym_preproc_line] = STATE(1328),
    [sym_preproc_pragma] = STATE(1328),
    [sym_preproc_nullable] = STATE(1328),
    [sym_preproc_error] = STATE(1328),
    [sym_preproc_warning] = STATE(1328),
    [sym_preproc_define] = STATE(1328),
    [sym_preproc_undef] = STATE(1328),
    [aux_sym_class_declaration_repeat1] = STATE(3815),
    [aux_sym_lambda_expression_repeat1] = STATE(4217),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1515),
    [anon_sym_ref] = ACTIONS(1517),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1521),
    [anon_sym_TILDE] = ACTIONS(1521),
    [anon_sym_PLUS_PLUS] = ACTIONS(1521),
    [anon_sym_DASH_DASH] = ACTIONS(1521),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1519),
    [anon_sym_DASH] = ACTIONS(1519),
    [anon_sym_STAR] = ACTIONS(1523),
    [anon_sym_CARET] = ACTIONS(1521),
    [anon_sym_AMP] = ACTIONS(1521),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1525),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1527),
    [anon_sym_DOT_DOT] = ACTIONS(1529),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1329] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6922),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2984),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7155),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6387),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4541),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7435),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9148),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1329),
    [sym_preproc_endregion] = STATE(1329),
    [sym_preproc_line] = STATE(1329),
    [sym_preproc_pragma] = STATE(1329),
    [sym_preproc_nullable] = STATE(1329),
    [sym_preproc_error] = STATE(1329),
    [sym_preproc_warning] = STATE(1329),
    [sym_preproc_define] = STATE(1329),
    [sym_preproc_undef] = STATE(1329),
    [aux_sym_class_declaration_repeat1] = STATE(3876),
    [aux_sym_lambda_expression_repeat1] = STATE(4317),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2231),
    [anon_sym_ref] = ACTIONS(2233),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2235),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2239),
    [anon_sym_TILDE] = ACTIONS(2239),
    [anon_sym_PLUS_PLUS] = ACTIONS(2239),
    [anon_sym_DASH_DASH] = ACTIONS(2239),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2237),
    [anon_sym_DASH] = ACTIONS(2237),
    [anon_sym_STAR] = ACTIONS(2241),
    [anon_sym_CARET] = ACTIONS(2239),
    [anon_sym_AMP] = ACTIONS(2239),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2243),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2245),
    [anon_sym_DOT_DOT] = ACTIONS(2247),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1330] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6948),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2940),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6999),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5140),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3857),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7444),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9574),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1330),
    [sym_preproc_endregion] = STATE(1330),
    [sym_preproc_line] = STATE(1330),
    [sym_preproc_pragma] = STATE(1330),
    [sym_preproc_nullable] = STATE(1330),
    [sym_preproc_error] = STATE(1330),
    [sym_preproc_warning] = STATE(1330),
    [sym_preproc_define] = STATE(1330),
    [sym_preproc_undef] = STATE(1330),
    [aux_sym_class_declaration_repeat1] = STATE(3854),
    [aux_sym_lambda_expression_repeat1] = STATE(4136),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2111),
    [anon_sym_ref] = ACTIONS(2113),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1897),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2117),
    [anon_sym_TILDE] = ACTIONS(2117),
    [anon_sym_PLUS_PLUS] = ACTIONS(2117),
    [anon_sym_DASH_DASH] = ACTIONS(2117),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2115),
    [anon_sym_DASH] = ACTIONS(2115),
    [anon_sym_STAR] = ACTIONS(1903),
    [anon_sym_CARET] = ACTIONS(2117),
    [anon_sym_AMP] = ACTIONS(2117),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2119),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2121),
    [anon_sym_DOT_DOT] = ACTIONS(2123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1331] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6916),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7128),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4910),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3752),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7413),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9092),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1331),
    [sym_preproc_endregion] = STATE(1331),
    [sym_preproc_line] = STATE(1331),
    [sym_preproc_pragma] = STATE(1331),
    [sym_preproc_nullable] = STATE(1331),
    [sym_preproc_error] = STATE(1331),
    [sym_preproc_warning] = STATE(1331),
    [sym_preproc_define] = STATE(1331),
    [sym_preproc_undef] = STATE(1331),
    [aux_sym_class_declaration_repeat1] = STATE(3845),
    [aux_sym_lambda_expression_repeat1] = STATE(4181),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1241),
    [anon_sym_ref] = ACTIONS(1243),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1255),
    [anon_sym_TILDE] = ACTIONS(1255),
    [anon_sym_PLUS_PLUS] = ACTIONS(1255),
    [anon_sym_DASH_DASH] = ACTIONS(1255),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1253),
    [anon_sym_DASH] = ACTIONS(1253),
    [anon_sym_STAR] = ACTIONS(1259),
    [anon_sym_CARET] = ACTIONS(1255),
    [anon_sym_AMP] = ACTIONS(1255),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1269),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1271),
    [anon_sym_DOT_DOT] = ACTIONS(1273),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1332] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6937),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2861),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7001),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5675),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4149),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7445),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9763),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(1332),
    [sym_preproc_endregion] = STATE(1332),
    [sym_preproc_line] = STATE(1332),
    [sym_preproc_pragma] = STATE(1332),
    [sym_preproc_nullable] = STATE(1332),
    [sym_preproc_error] = STATE(1332),
    [sym_preproc_warning] = STATE(1332),
    [sym_preproc_define] = STATE(1332),
    [sym_preproc_undef] = STATE(1332),
    [aux_sym_class_declaration_repeat1] = STATE(3821),
    [aux_sym_lambda_expression_repeat1] = STATE(4236),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1609),
    [anon_sym_ref] = ACTIONS(1611),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1481),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1615),
    [anon_sym_TILDE] = ACTIONS(1615),
    [anon_sym_PLUS_PLUS] = ACTIONS(1615),
    [anon_sym_DASH_DASH] = ACTIONS(1615),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1613),
    [anon_sym_DASH] = ACTIONS(1613),
    [anon_sym_STAR] = ACTIONS(1487),
    [anon_sym_CARET] = ACTIONS(1615),
    [anon_sym_AMP] = ACTIONS(1615),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1617),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1619),
    [anon_sym_DOT_DOT] = ACTIONS(1621),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [1333] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6937),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2861),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7001),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5156),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4149),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7445),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9763),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(1333),
    [sym_preproc_endregion] = STATE(1333),
    [sym_preproc_line] = STATE(1333),
    [sym_preproc_pragma] = STATE(1333),
    [sym_preproc_nullable] = STATE(1333),
    [sym_preproc_error] = STATE(1333),
    [sym_preproc_warning] = STATE(1333),
    [sym_preproc_define] = STATE(1333),
    [sym_preproc_undef] = STATE(1333),
    [aux_sym_class_declaration_repeat1] = STATE(3821),
    [aux_sym_lambda_expression_repeat1] = STATE(4236),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1609),
    [anon_sym_ref] = ACTIONS(1611),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1481),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1615),
    [anon_sym_TILDE] = ACTIONS(1615),
    [anon_sym_PLUS_PLUS] = ACTIONS(1615),
    [anon_sym_DASH_DASH] = ACTIONS(1615),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1613),
    [anon_sym_DASH] = ACTIONS(1613),
    [anon_sym_STAR] = ACTIONS(1487),
    [anon_sym_CARET] = ACTIONS(1615),
    [anon_sym_AMP] = ACTIONS(1615),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1617),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1619),
    [anon_sym_DOT_DOT] = ACTIONS(1621),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [1334] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6918),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6973),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5288),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4069),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7443),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9676),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1334),
    [sym_preproc_endregion] = STATE(1334),
    [sym_preproc_line] = STATE(1334),
    [sym_preproc_pragma] = STATE(1334),
    [sym_preproc_nullable] = STATE(1334),
    [sym_preproc_error] = STATE(1334),
    [sym_preproc_warning] = STATE(1334),
    [sym_preproc_define] = STATE(1334),
    [sym_preproc_undef] = STATE(1334),
    [aux_sym_class_declaration_repeat1] = STATE(3815),
    [aux_sym_lambda_expression_repeat1] = STATE(4217),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1515),
    [anon_sym_ref] = ACTIONS(1517),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1521),
    [anon_sym_TILDE] = ACTIONS(1521),
    [anon_sym_PLUS_PLUS] = ACTIONS(1521),
    [anon_sym_DASH_DASH] = ACTIONS(1521),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1519),
    [anon_sym_DASH] = ACTIONS(1519),
    [anon_sym_STAR] = ACTIONS(1523),
    [anon_sym_CARET] = ACTIONS(1521),
    [anon_sym_AMP] = ACTIONS(1521),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1525),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1527),
    [anon_sym_DOT_DOT] = ACTIONS(1529),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1335] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6918),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6973),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5296),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4069),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7443),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9676),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1335),
    [sym_preproc_endregion] = STATE(1335),
    [sym_preproc_line] = STATE(1335),
    [sym_preproc_pragma] = STATE(1335),
    [sym_preproc_nullable] = STATE(1335),
    [sym_preproc_error] = STATE(1335),
    [sym_preproc_warning] = STATE(1335),
    [sym_preproc_define] = STATE(1335),
    [sym_preproc_undef] = STATE(1335),
    [aux_sym_class_declaration_repeat1] = STATE(3815),
    [aux_sym_lambda_expression_repeat1] = STATE(4217),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1515),
    [anon_sym_ref] = ACTIONS(1517),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1521),
    [anon_sym_TILDE] = ACTIONS(1521),
    [anon_sym_PLUS_PLUS] = ACTIONS(1521),
    [anon_sym_DASH_DASH] = ACTIONS(1521),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1519),
    [anon_sym_DASH] = ACTIONS(1519),
    [anon_sym_STAR] = ACTIONS(1523),
    [anon_sym_CARET] = ACTIONS(1521),
    [anon_sym_AMP] = ACTIONS(1521),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1525),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1527),
    [anon_sym_DOT_DOT] = ACTIONS(1529),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1336] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6918),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6973),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5300),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4069),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7443),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9676),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1336),
    [sym_preproc_endregion] = STATE(1336),
    [sym_preproc_line] = STATE(1336),
    [sym_preproc_pragma] = STATE(1336),
    [sym_preproc_nullable] = STATE(1336),
    [sym_preproc_error] = STATE(1336),
    [sym_preproc_warning] = STATE(1336),
    [sym_preproc_define] = STATE(1336),
    [sym_preproc_undef] = STATE(1336),
    [aux_sym_class_declaration_repeat1] = STATE(3815),
    [aux_sym_lambda_expression_repeat1] = STATE(4217),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1515),
    [anon_sym_ref] = ACTIONS(1517),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1521),
    [anon_sym_TILDE] = ACTIONS(1521),
    [anon_sym_PLUS_PLUS] = ACTIONS(1521),
    [anon_sym_DASH_DASH] = ACTIONS(1521),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1519),
    [anon_sym_DASH] = ACTIONS(1519),
    [anon_sym_STAR] = ACTIONS(1523),
    [anon_sym_CARET] = ACTIONS(1521),
    [anon_sym_AMP] = ACTIONS(1521),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1525),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1527),
    [anon_sym_DOT_DOT] = ACTIONS(1529),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1337] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6918),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6973),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5309),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4069),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7443),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9676),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1337),
    [sym_preproc_endregion] = STATE(1337),
    [sym_preproc_line] = STATE(1337),
    [sym_preproc_pragma] = STATE(1337),
    [sym_preproc_nullable] = STATE(1337),
    [sym_preproc_error] = STATE(1337),
    [sym_preproc_warning] = STATE(1337),
    [sym_preproc_define] = STATE(1337),
    [sym_preproc_undef] = STATE(1337),
    [aux_sym_class_declaration_repeat1] = STATE(3815),
    [aux_sym_lambda_expression_repeat1] = STATE(4217),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1515),
    [anon_sym_ref] = ACTIONS(1517),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1521),
    [anon_sym_TILDE] = ACTIONS(1521),
    [anon_sym_PLUS_PLUS] = ACTIONS(1521),
    [anon_sym_DASH_DASH] = ACTIONS(1521),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1519),
    [anon_sym_DASH] = ACTIONS(1519),
    [anon_sym_STAR] = ACTIONS(1523),
    [anon_sym_CARET] = ACTIONS(1521),
    [anon_sym_AMP] = ACTIONS(1521),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1525),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1527),
    [anon_sym_DOT_DOT] = ACTIONS(1529),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1338] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6918),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6973),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5311),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4069),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7443),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9676),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1338),
    [sym_preproc_endregion] = STATE(1338),
    [sym_preproc_line] = STATE(1338),
    [sym_preproc_pragma] = STATE(1338),
    [sym_preproc_nullable] = STATE(1338),
    [sym_preproc_error] = STATE(1338),
    [sym_preproc_warning] = STATE(1338),
    [sym_preproc_define] = STATE(1338),
    [sym_preproc_undef] = STATE(1338),
    [aux_sym_class_declaration_repeat1] = STATE(3815),
    [aux_sym_lambda_expression_repeat1] = STATE(4217),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1515),
    [anon_sym_ref] = ACTIONS(1517),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1521),
    [anon_sym_TILDE] = ACTIONS(1521),
    [anon_sym_PLUS_PLUS] = ACTIONS(1521),
    [anon_sym_DASH_DASH] = ACTIONS(1521),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1519),
    [anon_sym_DASH] = ACTIONS(1519),
    [anon_sym_STAR] = ACTIONS(1523),
    [anon_sym_CARET] = ACTIONS(1521),
    [anon_sym_AMP] = ACTIONS(1521),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1525),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1527),
    [anon_sym_DOT_DOT] = ACTIONS(1529),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1339] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6918),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6973),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5312),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4069),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7443),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9676),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1339),
    [sym_preproc_endregion] = STATE(1339),
    [sym_preproc_line] = STATE(1339),
    [sym_preproc_pragma] = STATE(1339),
    [sym_preproc_nullable] = STATE(1339),
    [sym_preproc_error] = STATE(1339),
    [sym_preproc_warning] = STATE(1339),
    [sym_preproc_define] = STATE(1339),
    [sym_preproc_undef] = STATE(1339),
    [aux_sym_class_declaration_repeat1] = STATE(3815),
    [aux_sym_lambda_expression_repeat1] = STATE(4217),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1515),
    [anon_sym_ref] = ACTIONS(1517),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1521),
    [anon_sym_TILDE] = ACTIONS(1521),
    [anon_sym_PLUS_PLUS] = ACTIONS(1521),
    [anon_sym_DASH_DASH] = ACTIONS(1521),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1519),
    [anon_sym_DASH] = ACTIONS(1519),
    [anon_sym_STAR] = ACTIONS(1523),
    [anon_sym_CARET] = ACTIONS(1521),
    [anon_sym_AMP] = ACTIONS(1521),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1525),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1527),
    [anon_sym_DOT_DOT] = ACTIONS(1529),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1340] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6918),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6973),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5363),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4069),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7443),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9676),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1340),
    [sym_preproc_endregion] = STATE(1340),
    [sym_preproc_line] = STATE(1340),
    [sym_preproc_pragma] = STATE(1340),
    [sym_preproc_nullable] = STATE(1340),
    [sym_preproc_error] = STATE(1340),
    [sym_preproc_warning] = STATE(1340),
    [sym_preproc_define] = STATE(1340),
    [sym_preproc_undef] = STATE(1340),
    [aux_sym_class_declaration_repeat1] = STATE(3815),
    [aux_sym_lambda_expression_repeat1] = STATE(4217),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1515),
    [anon_sym_ref] = ACTIONS(1517),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1521),
    [anon_sym_TILDE] = ACTIONS(1521),
    [anon_sym_PLUS_PLUS] = ACTIONS(1521),
    [anon_sym_DASH_DASH] = ACTIONS(1521),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1519),
    [anon_sym_DASH] = ACTIONS(1519),
    [anon_sym_STAR] = ACTIONS(1523),
    [anon_sym_CARET] = ACTIONS(1521),
    [anon_sym_AMP] = ACTIONS(1521),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1525),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1527),
    [anon_sym_DOT_DOT] = ACTIONS(1529),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1341] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6918),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6973),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5398),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4069),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7443),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9676),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1341),
    [sym_preproc_endregion] = STATE(1341),
    [sym_preproc_line] = STATE(1341),
    [sym_preproc_pragma] = STATE(1341),
    [sym_preproc_nullable] = STATE(1341),
    [sym_preproc_error] = STATE(1341),
    [sym_preproc_warning] = STATE(1341),
    [sym_preproc_define] = STATE(1341),
    [sym_preproc_undef] = STATE(1341),
    [aux_sym_class_declaration_repeat1] = STATE(3815),
    [aux_sym_lambda_expression_repeat1] = STATE(4217),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1515),
    [anon_sym_ref] = ACTIONS(1517),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1521),
    [anon_sym_TILDE] = ACTIONS(1521),
    [anon_sym_PLUS_PLUS] = ACTIONS(1521),
    [anon_sym_DASH_DASH] = ACTIONS(1521),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1519),
    [anon_sym_DASH] = ACTIONS(1519),
    [anon_sym_STAR] = ACTIONS(1523),
    [anon_sym_CARET] = ACTIONS(1521),
    [anon_sym_AMP] = ACTIONS(1521),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1525),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1527),
    [anon_sym_DOT_DOT] = ACTIONS(1529),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1342] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6918),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6973),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5248),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4069),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7443),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9676),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1342),
    [sym_preproc_endregion] = STATE(1342),
    [sym_preproc_line] = STATE(1342),
    [sym_preproc_pragma] = STATE(1342),
    [sym_preproc_nullable] = STATE(1342),
    [sym_preproc_error] = STATE(1342),
    [sym_preproc_warning] = STATE(1342),
    [sym_preproc_define] = STATE(1342),
    [sym_preproc_undef] = STATE(1342),
    [aux_sym_class_declaration_repeat1] = STATE(3815),
    [aux_sym_lambda_expression_repeat1] = STATE(4217),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1515),
    [anon_sym_ref] = ACTIONS(1517),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1521),
    [anon_sym_TILDE] = ACTIONS(1521),
    [anon_sym_PLUS_PLUS] = ACTIONS(1521),
    [anon_sym_DASH_DASH] = ACTIONS(1521),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1519),
    [anon_sym_DASH] = ACTIONS(1519),
    [anon_sym_STAR] = ACTIONS(1523),
    [anon_sym_CARET] = ACTIONS(1521),
    [anon_sym_AMP] = ACTIONS(1521),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1525),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1527),
    [anon_sym_DOT_DOT] = ACTIONS(1529),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1343] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6918),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6973),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5252),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4069),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7443),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9676),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1343),
    [sym_preproc_endregion] = STATE(1343),
    [sym_preproc_line] = STATE(1343),
    [sym_preproc_pragma] = STATE(1343),
    [sym_preproc_nullable] = STATE(1343),
    [sym_preproc_error] = STATE(1343),
    [sym_preproc_warning] = STATE(1343),
    [sym_preproc_define] = STATE(1343),
    [sym_preproc_undef] = STATE(1343),
    [aux_sym_class_declaration_repeat1] = STATE(3815),
    [aux_sym_lambda_expression_repeat1] = STATE(4217),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1515),
    [anon_sym_ref] = ACTIONS(1517),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1521),
    [anon_sym_TILDE] = ACTIONS(1521),
    [anon_sym_PLUS_PLUS] = ACTIONS(1521),
    [anon_sym_DASH_DASH] = ACTIONS(1521),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1519),
    [anon_sym_DASH] = ACTIONS(1519),
    [anon_sym_STAR] = ACTIONS(1523),
    [anon_sym_CARET] = ACTIONS(1521),
    [anon_sym_AMP] = ACTIONS(1521),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1525),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1527),
    [anon_sym_DOT_DOT] = ACTIONS(1529),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1344] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6918),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6973),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5275),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4069),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7443),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9676),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1344),
    [sym_preproc_endregion] = STATE(1344),
    [sym_preproc_line] = STATE(1344),
    [sym_preproc_pragma] = STATE(1344),
    [sym_preproc_nullable] = STATE(1344),
    [sym_preproc_error] = STATE(1344),
    [sym_preproc_warning] = STATE(1344),
    [sym_preproc_define] = STATE(1344),
    [sym_preproc_undef] = STATE(1344),
    [aux_sym_class_declaration_repeat1] = STATE(3815),
    [aux_sym_lambda_expression_repeat1] = STATE(4217),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1515),
    [anon_sym_ref] = ACTIONS(1517),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1521),
    [anon_sym_TILDE] = ACTIONS(1521),
    [anon_sym_PLUS_PLUS] = ACTIONS(1521),
    [anon_sym_DASH_DASH] = ACTIONS(1521),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1519),
    [anon_sym_DASH] = ACTIONS(1519),
    [anon_sym_STAR] = ACTIONS(1523),
    [anon_sym_CARET] = ACTIONS(1521),
    [anon_sym_AMP] = ACTIONS(1521),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1525),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1527),
    [anon_sym_DOT_DOT] = ACTIONS(1529),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1345] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6937),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2861),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7001),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5681),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4149),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7445),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9763),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(1345),
    [sym_preproc_endregion] = STATE(1345),
    [sym_preproc_line] = STATE(1345),
    [sym_preproc_pragma] = STATE(1345),
    [sym_preproc_nullable] = STATE(1345),
    [sym_preproc_error] = STATE(1345),
    [sym_preproc_warning] = STATE(1345),
    [sym_preproc_define] = STATE(1345),
    [sym_preproc_undef] = STATE(1345),
    [aux_sym_class_declaration_repeat1] = STATE(3821),
    [aux_sym_lambda_expression_repeat1] = STATE(4236),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1609),
    [anon_sym_ref] = ACTIONS(1611),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1481),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1615),
    [anon_sym_TILDE] = ACTIONS(1615),
    [anon_sym_PLUS_PLUS] = ACTIONS(1615),
    [anon_sym_DASH_DASH] = ACTIONS(1615),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1613),
    [anon_sym_DASH] = ACTIONS(1613),
    [anon_sym_STAR] = ACTIONS(1487),
    [anon_sym_CARET] = ACTIONS(1615),
    [anon_sym_AMP] = ACTIONS(1615),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1617),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1619),
    [anon_sym_DOT_DOT] = ACTIONS(1621),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [1346] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6918),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6973),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3582),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4069),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7443),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9676),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1346),
    [sym_preproc_endregion] = STATE(1346),
    [sym_preproc_line] = STATE(1346),
    [sym_preproc_pragma] = STATE(1346),
    [sym_preproc_nullable] = STATE(1346),
    [sym_preproc_error] = STATE(1346),
    [sym_preproc_warning] = STATE(1346),
    [sym_preproc_define] = STATE(1346),
    [sym_preproc_undef] = STATE(1346),
    [aux_sym_class_declaration_repeat1] = STATE(3815),
    [aux_sym_lambda_expression_repeat1] = STATE(4217),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1515),
    [anon_sym_ref] = ACTIONS(1517),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1521),
    [anon_sym_TILDE] = ACTIONS(1521),
    [anon_sym_PLUS_PLUS] = ACTIONS(1521),
    [anon_sym_DASH_DASH] = ACTIONS(1521),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1519),
    [anon_sym_DASH] = ACTIONS(1519),
    [anon_sym_STAR] = ACTIONS(1523),
    [anon_sym_CARET] = ACTIONS(1521),
    [anon_sym_AMP] = ACTIONS(1521),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1525),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1527),
    [anon_sym_DOT_DOT] = ACTIONS(1529),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1347] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6937),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2861),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7081),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5181),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(3898),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7429),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9350),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(1347),
    [sym_preproc_endregion] = STATE(1347),
    [sym_preproc_line] = STATE(1347),
    [sym_preproc_pragma] = STATE(1347),
    [sym_preproc_nullable] = STATE(1347),
    [sym_preproc_error] = STATE(1347),
    [sym_preproc_warning] = STATE(1347),
    [sym_preproc_define] = STATE(1347),
    [sym_preproc_undef] = STATE(1347),
    [aux_sym_class_declaration_repeat1] = STATE(3879),
    [aux_sym_lambda_expression_repeat1] = STATE(4092),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1477),
    [anon_sym_ref] = ACTIONS(1479),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1481),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1485),
    [anon_sym_TILDE] = ACTIONS(1485),
    [anon_sym_PLUS_PLUS] = ACTIONS(1485),
    [anon_sym_DASH_DASH] = ACTIONS(1485),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1483),
    [anon_sym_DASH] = ACTIONS(1483),
    [anon_sym_STAR] = ACTIONS(1487),
    [anon_sym_CARET] = ACTIONS(1485),
    [anon_sym_AMP] = ACTIONS(1485),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1489),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1491),
    [anon_sym_DOT_DOT] = ACTIONS(1493),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [1348] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6937),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2861),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7001),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5704),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4149),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7445),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9763),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(1348),
    [sym_preproc_endregion] = STATE(1348),
    [sym_preproc_line] = STATE(1348),
    [sym_preproc_pragma] = STATE(1348),
    [sym_preproc_nullable] = STATE(1348),
    [sym_preproc_error] = STATE(1348),
    [sym_preproc_warning] = STATE(1348),
    [sym_preproc_define] = STATE(1348),
    [sym_preproc_undef] = STATE(1348),
    [aux_sym_class_declaration_repeat1] = STATE(3821),
    [aux_sym_lambda_expression_repeat1] = STATE(4236),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1609),
    [anon_sym_ref] = ACTIONS(1611),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1481),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1615),
    [anon_sym_TILDE] = ACTIONS(1615),
    [anon_sym_PLUS_PLUS] = ACTIONS(1615),
    [anon_sym_DASH_DASH] = ACTIONS(1615),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1613),
    [anon_sym_DASH] = ACTIONS(1613),
    [anon_sym_STAR] = ACTIONS(1487),
    [anon_sym_CARET] = ACTIONS(1615),
    [anon_sym_AMP] = ACTIONS(1615),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1617),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1619),
    [anon_sym_DOT_DOT] = ACTIONS(1621),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [1349] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6921),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2873),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(6957),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6155),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4346),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7445),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9875),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(1349),
    [sym_preproc_endregion] = STATE(1349),
    [sym_preproc_line] = STATE(1349),
    [sym_preproc_pragma] = STATE(1349),
    [sym_preproc_nullable] = STATE(1349),
    [sym_preproc_error] = STATE(1349),
    [sym_preproc_warning] = STATE(1349),
    [sym_preproc_define] = STATE(1349),
    [sym_preproc_undef] = STATE(1349),
    [aux_sym_class_declaration_repeat1] = STATE(3810),
    [aux_sym_lambda_expression_repeat1] = STATE(4192),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1639),
    [anon_sym_ref] = ACTIONS(1641),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1415),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1645),
    [anon_sym_TILDE] = ACTIONS(1645),
    [anon_sym_PLUS_PLUS] = ACTIONS(1645),
    [anon_sym_DASH_DASH] = ACTIONS(1645),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1643),
    [anon_sym_DASH] = ACTIONS(1643),
    [anon_sym_STAR] = ACTIONS(1425),
    [anon_sym_CARET] = ACTIONS(1645),
    [anon_sym_AMP] = ACTIONS(1645),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1647),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1649),
    [anon_sym_DOT_DOT] = ACTIONS(1651),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [1350] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6967),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5079),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3813),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9209),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1350),
    [sym_preproc_endregion] = STATE(1350),
    [sym_preproc_line] = STATE(1350),
    [sym_preproc_pragma] = STATE(1350),
    [sym_preproc_nullable] = STATE(1350),
    [sym_preproc_error] = STATE(1350),
    [sym_preproc_warning] = STATE(1350),
    [sym_preproc_define] = STATE(1350),
    [sym_preproc_undef] = STATE(1350),
    [aux_sym_class_declaration_repeat1] = STATE(3814),
    [aux_sym_lambda_expression_repeat1] = STATE(4209),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1323),
    [anon_sym_ref] = ACTIONS(1325),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1083),
    [anon_sym_PLUS_PLUS] = ACTIONS(1083),
    [anon_sym_DASH_DASH] = ACTIONS(1083),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1085),
    [anon_sym_DASH] = ACTIONS(1085),
    [anon_sym_STAR] = ACTIONS(1335),
    [anon_sym_CARET] = ACTIONS(1083),
    [anon_sym_AMP] = ACTIONS(1083),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1341),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1343),
    [anon_sym_DOT_DOT] = ACTIONS(1345),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1351] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6967),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3926),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3813),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9209),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1351),
    [sym_preproc_endregion] = STATE(1351),
    [sym_preproc_line] = STATE(1351),
    [sym_preproc_pragma] = STATE(1351),
    [sym_preproc_nullable] = STATE(1351),
    [sym_preproc_error] = STATE(1351),
    [sym_preproc_warning] = STATE(1351),
    [sym_preproc_define] = STATE(1351),
    [sym_preproc_undef] = STATE(1351),
    [aux_sym_class_declaration_repeat1] = STATE(3814),
    [aux_sym_lambda_expression_repeat1] = STATE(4209),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1323),
    [anon_sym_ref] = ACTIONS(1325),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1083),
    [anon_sym_PLUS_PLUS] = ACTIONS(1083),
    [anon_sym_DASH_DASH] = ACTIONS(1083),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1085),
    [anon_sym_DASH] = ACTIONS(1085),
    [anon_sym_STAR] = ACTIONS(1335),
    [anon_sym_CARET] = ACTIONS(1083),
    [anon_sym_AMP] = ACTIONS(1083),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1341),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1343),
    [anon_sym_DOT_DOT] = ACTIONS(1345),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1352] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6937),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2861),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7001),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5716),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4149),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7445),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9763),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(1352),
    [sym_preproc_endregion] = STATE(1352),
    [sym_preproc_line] = STATE(1352),
    [sym_preproc_pragma] = STATE(1352),
    [sym_preproc_nullable] = STATE(1352),
    [sym_preproc_error] = STATE(1352),
    [sym_preproc_warning] = STATE(1352),
    [sym_preproc_define] = STATE(1352),
    [sym_preproc_undef] = STATE(1352),
    [aux_sym_class_declaration_repeat1] = STATE(3821),
    [aux_sym_lambda_expression_repeat1] = STATE(4236),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1609),
    [anon_sym_ref] = ACTIONS(1611),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1481),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1615),
    [anon_sym_TILDE] = ACTIONS(1615),
    [anon_sym_PLUS_PLUS] = ACTIONS(1615),
    [anon_sym_DASH_DASH] = ACTIONS(1615),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1613),
    [anon_sym_DASH] = ACTIONS(1613),
    [anon_sym_STAR] = ACTIONS(1487),
    [anon_sym_CARET] = ACTIONS(1615),
    [anon_sym_AMP] = ACTIONS(1615),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1617),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1619),
    [anon_sym_DOT_DOT] = ACTIONS(1621),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [1353] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6937),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2861),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7001),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5717),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4149),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7445),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9763),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(1353),
    [sym_preproc_endregion] = STATE(1353),
    [sym_preproc_line] = STATE(1353),
    [sym_preproc_pragma] = STATE(1353),
    [sym_preproc_nullable] = STATE(1353),
    [sym_preproc_error] = STATE(1353),
    [sym_preproc_warning] = STATE(1353),
    [sym_preproc_define] = STATE(1353),
    [sym_preproc_undef] = STATE(1353),
    [aux_sym_class_declaration_repeat1] = STATE(3821),
    [aux_sym_lambda_expression_repeat1] = STATE(4236),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1609),
    [anon_sym_ref] = ACTIONS(1611),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1481),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1615),
    [anon_sym_TILDE] = ACTIONS(1615),
    [anon_sym_PLUS_PLUS] = ACTIONS(1615),
    [anon_sym_DASH_DASH] = ACTIONS(1615),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1613),
    [anon_sym_DASH] = ACTIONS(1613),
    [anon_sym_STAR] = ACTIONS(1487),
    [anon_sym_CARET] = ACTIONS(1615),
    [anon_sym_AMP] = ACTIONS(1615),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1617),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1619),
    [anon_sym_DOT_DOT] = ACTIONS(1621),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [1354] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6937),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2861),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7001),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5718),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4149),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7445),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9763),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(1354),
    [sym_preproc_endregion] = STATE(1354),
    [sym_preproc_line] = STATE(1354),
    [sym_preproc_pragma] = STATE(1354),
    [sym_preproc_nullable] = STATE(1354),
    [sym_preproc_error] = STATE(1354),
    [sym_preproc_warning] = STATE(1354),
    [sym_preproc_define] = STATE(1354),
    [sym_preproc_undef] = STATE(1354),
    [aux_sym_class_declaration_repeat1] = STATE(3821),
    [aux_sym_lambda_expression_repeat1] = STATE(4236),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1609),
    [anon_sym_ref] = ACTIONS(1611),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1481),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1615),
    [anon_sym_TILDE] = ACTIONS(1615),
    [anon_sym_PLUS_PLUS] = ACTIONS(1615),
    [anon_sym_DASH_DASH] = ACTIONS(1615),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1613),
    [anon_sym_DASH] = ACTIONS(1613),
    [anon_sym_STAR] = ACTIONS(1487),
    [anon_sym_CARET] = ACTIONS(1615),
    [anon_sym_AMP] = ACTIONS(1615),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1617),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1619),
    [anon_sym_DOT_DOT] = ACTIONS(1621),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [1355] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6937),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2861),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7001),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5441),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4149),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7445),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9763),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(1355),
    [sym_preproc_endregion] = STATE(1355),
    [sym_preproc_line] = STATE(1355),
    [sym_preproc_pragma] = STATE(1355),
    [sym_preproc_nullable] = STATE(1355),
    [sym_preproc_error] = STATE(1355),
    [sym_preproc_warning] = STATE(1355),
    [sym_preproc_define] = STATE(1355),
    [sym_preproc_undef] = STATE(1355),
    [aux_sym_class_declaration_repeat1] = STATE(3821),
    [aux_sym_lambda_expression_repeat1] = STATE(4236),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1609),
    [anon_sym_ref] = ACTIONS(1611),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1481),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1615),
    [anon_sym_TILDE] = ACTIONS(1615),
    [anon_sym_PLUS_PLUS] = ACTIONS(1615),
    [anon_sym_DASH_DASH] = ACTIONS(1615),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1613),
    [anon_sym_DASH] = ACTIONS(1613),
    [anon_sym_STAR] = ACTIONS(1487),
    [anon_sym_CARET] = ACTIONS(1615),
    [anon_sym_AMP] = ACTIONS(1615),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1617),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1619),
    [anon_sym_DOT_DOT] = ACTIONS(1621),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [1356] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6937),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2861),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7001),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5442),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4149),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7445),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9763),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(1356),
    [sym_preproc_endregion] = STATE(1356),
    [sym_preproc_line] = STATE(1356),
    [sym_preproc_pragma] = STATE(1356),
    [sym_preproc_nullable] = STATE(1356),
    [sym_preproc_error] = STATE(1356),
    [sym_preproc_warning] = STATE(1356),
    [sym_preproc_define] = STATE(1356),
    [sym_preproc_undef] = STATE(1356),
    [aux_sym_class_declaration_repeat1] = STATE(3821),
    [aux_sym_lambda_expression_repeat1] = STATE(4236),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1609),
    [anon_sym_ref] = ACTIONS(1611),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1481),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1615),
    [anon_sym_TILDE] = ACTIONS(1615),
    [anon_sym_PLUS_PLUS] = ACTIONS(1615),
    [anon_sym_DASH_DASH] = ACTIONS(1615),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1613),
    [anon_sym_DASH] = ACTIONS(1613),
    [anon_sym_STAR] = ACTIONS(1487),
    [anon_sym_CARET] = ACTIONS(1615),
    [anon_sym_AMP] = ACTIONS(1615),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1617),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1619),
    [anon_sym_DOT_DOT] = ACTIONS(1621),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [1357] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6937),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2861),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7001),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5443),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4149),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7445),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9763),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(1357),
    [sym_preproc_endregion] = STATE(1357),
    [sym_preproc_line] = STATE(1357),
    [sym_preproc_pragma] = STATE(1357),
    [sym_preproc_nullable] = STATE(1357),
    [sym_preproc_error] = STATE(1357),
    [sym_preproc_warning] = STATE(1357),
    [sym_preproc_define] = STATE(1357),
    [sym_preproc_undef] = STATE(1357),
    [aux_sym_class_declaration_repeat1] = STATE(3821),
    [aux_sym_lambda_expression_repeat1] = STATE(4236),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1609),
    [anon_sym_ref] = ACTIONS(1611),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1481),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1615),
    [anon_sym_TILDE] = ACTIONS(1615),
    [anon_sym_PLUS_PLUS] = ACTIONS(1615),
    [anon_sym_DASH_DASH] = ACTIONS(1615),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1613),
    [anon_sym_DASH] = ACTIONS(1613),
    [anon_sym_STAR] = ACTIONS(1487),
    [anon_sym_CARET] = ACTIONS(1615),
    [anon_sym_AMP] = ACTIONS(1615),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1617),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1619),
    [anon_sym_DOT_DOT] = ACTIONS(1621),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [1358] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6937),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2861),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7001),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5719),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4149),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7445),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9763),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(1358),
    [sym_preproc_endregion] = STATE(1358),
    [sym_preproc_line] = STATE(1358),
    [sym_preproc_pragma] = STATE(1358),
    [sym_preproc_nullable] = STATE(1358),
    [sym_preproc_error] = STATE(1358),
    [sym_preproc_warning] = STATE(1358),
    [sym_preproc_define] = STATE(1358),
    [sym_preproc_undef] = STATE(1358),
    [aux_sym_class_declaration_repeat1] = STATE(3821),
    [aux_sym_lambda_expression_repeat1] = STATE(4236),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1609),
    [anon_sym_ref] = ACTIONS(1611),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1481),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1615),
    [anon_sym_TILDE] = ACTIONS(1615),
    [anon_sym_PLUS_PLUS] = ACTIONS(1615),
    [anon_sym_DASH_DASH] = ACTIONS(1615),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1613),
    [anon_sym_DASH] = ACTIONS(1613),
    [anon_sym_STAR] = ACTIONS(1487),
    [anon_sym_CARET] = ACTIONS(1615),
    [anon_sym_AMP] = ACTIONS(1615),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1617),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1619),
    [anon_sym_DOT_DOT] = ACTIONS(1621),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [1359] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6937),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2861),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7001),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5444),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4149),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7445),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9763),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(1359),
    [sym_preproc_endregion] = STATE(1359),
    [sym_preproc_line] = STATE(1359),
    [sym_preproc_pragma] = STATE(1359),
    [sym_preproc_nullable] = STATE(1359),
    [sym_preproc_error] = STATE(1359),
    [sym_preproc_warning] = STATE(1359),
    [sym_preproc_define] = STATE(1359),
    [sym_preproc_undef] = STATE(1359),
    [aux_sym_class_declaration_repeat1] = STATE(3821),
    [aux_sym_lambda_expression_repeat1] = STATE(4236),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1609),
    [anon_sym_ref] = ACTIONS(1611),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1481),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1615),
    [anon_sym_TILDE] = ACTIONS(1615),
    [anon_sym_PLUS_PLUS] = ACTIONS(1615),
    [anon_sym_DASH_DASH] = ACTIONS(1615),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1613),
    [anon_sym_DASH] = ACTIONS(1613),
    [anon_sym_STAR] = ACTIONS(1487),
    [anon_sym_CARET] = ACTIONS(1615),
    [anon_sym_AMP] = ACTIONS(1615),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1617),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1619),
    [anon_sym_DOT_DOT] = ACTIONS(1621),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [1360] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6937),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2861),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7001),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5446),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4149),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7445),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9763),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(1360),
    [sym_preproc_endregion] = STATE(1360),
    [sym_preproc_line] = STATE(1360),
    [sym_preproc_pragma] = STATE(1360),
    [sym_preproc_nullable] = STATE(1360),
    [sym_preproc_error] = STATE(1360),
    [sym_preproc_warning] = STATE(1360),
    [sym_preproc_define] = STATE(1360),
    [sym_preproc_undef] = STATE(1360),
    [aux_sym_class_declaration_repeat1] = STATE(3821),
    [aux_sym_lambda_expression_repeat1] = STATE(4236),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1609),
    [anon_sym_ref] = ACTIONS(1611),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1481),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1615),
    [anon_sym_TILDE] = ACTIONS(1615),
    [anon_sym_PLUS_PLUS] = ACTIONS(1615),
    [anon_sym_DASH_DASH] = ACTIONS(1615),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1613),
    [anon_sym_DASH] = ACTIONS(1613),
    [anon_sym_STAR] = ACTIONS(1487),
    [anon_sym_CARET] = ACTIONS(1615),
    [anon_sym_AMP] = ACTIONS(1615),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1617),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1619),
    [anon_sym_DOT_DOT] = ACTIONS(1621),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [1361] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6937),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2861),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7001),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5447),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4149),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7445),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9763),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(1361),
    [sym_preproc_endregion] = STATE(1361),
    [sym_preproc_line] = STATE(1361),
    [sym_preproc_pragma] = STATE(1361),
    [sym_preproc_nullable] = STATE(1361),
    [sym_preproc_error] = STATE(1361),
    [sym_preproc_warning] = STATE(1361),
    [sym_preproc_define] = STATE(1361),
    [sym_preproc_undef] = STATE(1361),
    [aux_sym_class_declaration_repeat1] = STATE(3821),
    [aux_sym_lambda_expression_repeat1] = STATE(4236),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1609),
    [anon_sym_ref] = ACTIONS(1611),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1481),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1615),
    [anon_sym_TILDE] = ACTIONS(1615),
    [anon_sym_PLUS_PLUS] = ACTIONS(1615),
    [anon_sym_DASH_DASH] = ACTIONS(1615),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1613),
    [anon_sym_DASH] = ACTIONS(1613),
    [anon_sym_STAR] = ACTIONS(1487),
    [anon_sym_CARET] = ACTIONS(1615),
    [anon_sym_AMP] = ACTIONS(1615),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1617),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1619),
    [anon_sym_DOT_DOT] = ACTIONS(1621),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [1362] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6937),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2861),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7001),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5448),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4149),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7445),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9763),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(1362),
    [sym_preproc_endregion] = STATE(1362),
    [sym_preproc_line] = STATE(1362),
    [sym_preproc_pragma] = STATE(1362),
    [sym_preproc_nullable] = STATE(1362),
    [sym_preproc_error] = STATE(1362),
    [sym_preproc_warning] = STATE(1362),
    [sym_preproc_define] = STATE(1362),
    [sym_preproc_undef] = STATE(1362),
    [aux_sym_class_declaration_repeat1] = STATE(3821),
    [aux_sym_lambda_expression_repeat1] = STATE(4236),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1609),
    [anon_sym_ref] = ACTIONS(1611),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1481),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1615),
    [anon_sym_TILDE] = ACTIONS(1615),
    [anon_sym_PLUS_PLUS] = ACTIONS(1615),
    [anon_sym_DASH_DASH] = ACTIONS(1615),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1613),
    [anon_sym_DASH] = ACTIONS(1613),
    [anon_sym_STAR] = ACTIONS(1487),
    [anon_sym_CARET] = ACTIONS(1615),
    [anon_sym_AMP] = ACTIONS(1615),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1617),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1619),
    [anon_sym_DOT_DOT] = ACTIONS(1621),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [1363] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6967),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5081),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3813),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9209),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1363),
    [sym_preproc_endregion] = STATE(1363),
    [sym_preproc_line] = STATE(1363),
    [sym_preproc_pragma] = STATE(1363),
    [sym_preproc_nullable] = STATE(1363),
    [sym_preproc_error] = STATE(1363),
    [sym_preproc_warning] = STATE(1363),
    [sym_preproc_define] = STATE(1363),
    [sym_preproc_undef] = STATE(1363),
    [aux_sym_class_declaration_repeat1] = STATE(3814),
    [aux_sym_lambda_expression_repeat1] = STATE(4209),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1323),
    [anon_sym_ref] = ACTIONS(1325),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1083),
    [anon_sym_PLUS_PLUS] = ACTIONS(1083),
    [anon_sym_DASH_DASH] = ACTIONS(1083),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1085),
    [anon_sym_DASH] = ACTIONS(1085),
    [anon_sym_STAR] = ACTIONS(1335),
    [anon_sym_CARET] = ACTIONS(1083),
    [anon_sym_AMP] = ACTIONS(1083),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1341),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1343),
    [anon_sym_DOT_DOT] = ACTIONS(1345),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1364] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6185),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1364),
    [sym_preproc_endregion] = STATE(1364),
    [sym_preproc_line] = STATE(1364),
    [sym_preproc_pragma] = STATE(1364),
    [sym_preproc_nullable] = STATE(1364),
    [sym_preproc_error] = STATE(1364),
    [sym_preproc_warning] = STATE(1364),
    [sym_preproc_define] = STATE(1364),
    [sym_preproc_undef] = STATE(1364),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1365] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6937),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2861),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7001),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5210),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4149),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7445),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9763),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(1365),
    [sym_preproc_endregion] = STATE(1365),
    [sym_preproc_line] = STATE(1365),
    [sym_preproc_pragma] = STATE(1365),
    [sym_preproc_nullable] = STATE(1365),
    [sym_preproc_error] = STATE(1365),
    [sym_preproc_warning] = STATE(1365),
    [sym_preproc_define] = STATE(1365),
    [sym_preproc_undef] = STATE(1365),
    [aux_sym_class_declaration_repeat1] = STATE(3821),
    [aux_sym_lambda_expression_repeat1] = STATE(4236),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1609),
    [anon_sym_ref] = ACTIONS(1611),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1481),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1615),
    [anon_sym_TILDE] = ACTIONS(1615),
    [anon_sym_PLUS_PLUS] = ACTIONS(1615),
    [anon_sym_DASH_DASH] = ACTIONS(1615),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1613),
    [anon_sym_DASH] = ACTIONS(1613),
    [anon_sym_STAR] = ACTIONS(1487),
    [anon_sym_CARET] = ACTIONS(1615),
    [anon_sym_AMP] = ACTIONS(1615),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1617),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1619),
    [anon_sym_DOT_DOT] = ACTIONS(1621),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [1366] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6967),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5095),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3813),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9209),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1366),
    [sym_preproc_endregion] = STATE(1366),
    [sym_preproc_line] = STATE(1366),
    [sym_preproc_pragma] = STATE(1366),
    [sym_preproc_nullable] = STATE(1366),
    [sym_preproc_error] = STATE(1366),
    [sym_preproc_warning] = STATE(1366),
    [sym_preproc_define] = STATE(1366),
    [sym_preproc_undef] = STATE(1366),
    [aux_sym_class_declaration_repeat1] = STATE(3814),
    [aux_sym_lambda_expression_repeat1] = STATE(4209),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1323),
    [anon_sym_ref] = ACTIONS(1325),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1083),
    [anon_sym_PLUS_PLUS] = ACTIONS(1083),
    [anon_sym_DASH_DASH] = ACTIONS(1083),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1085),
    [anon_sym_DASH] = ACTIONS(1085),
    [anon_sym_STAR] = ACTIONS(1335),
    [anon_sym_CARET] = ACTIONS(1083),
    [anon_sym_AMP] = ACTIONS(1083),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1341),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1343),
    [anon_sym_DOT_DOT] = ACTIONS(1345),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1367] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6211),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1367),
    [sym_preproc_endregion] = STATE(1367),
    [sym_preproc_line] = STATE(1367),
    [sym_preproc_pragma] = STATE(1367),
    [sym_preproc_nullable] = STATE(1367),
    [sym_preproc_error] = STATE(1367),
    [sym_preproc_warning] = STATE(1367),
    [sym_preproc_define] = STATE(1367),
    [sym_preproc_undef] = STATE(1367),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1368] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6067),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1368),
    [sym_preproc_endregion] = STATE(1368),
    [sym_preproc_line] = STATE(1368),
    [sym_preproc_pragma] = STATE(1368),
    [sym_preproc_nullable] = STATE(1368),
    [sym_preproc_error] = STATE(1368),
    [sym_preproc_warning] = STATE(1368),
    [sym_preproc_define] = STATE(1368),
    [sym_preproc_undef] = STATE(1368),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1369] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6912),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2912),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7040),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5249),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3963),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7448),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9641),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1369),
    [sym_preproc_endregion] = STATE(1369),
    [sym_preproc_line] = STATE(1369),
    [sym_preproc_pragma] = STATE(1369),
    [sym_preproc_nullable] = STATE(1369),
    [sym_preproc_error] = STATE(1369),
    [sym_preproc_warning] = STATE(1369),
    [sym_preproc_define] = STATE(1369),
    [sym_preproc_undef] = STATE(1369),
    [aux_sym_class_declaration_repeat1] = STATE(3831),
    [aux_sym_lambda_expression_repeat1] = STATE(4257),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1785),
    [anon_sym_ref] = ACTIONS(1787),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1595),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1791),
    [anon_sym_TILDE] = ACTIONS(1791),
    [anon_sym_PLUS_PLUS] = ACTIONS(1791),
    [anon_sym_DASH_DASH] = ACTIONS(1791),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1789),
    [anon_sym_DASH] = ACTIONS(1789),
    [anon_sym_STAR] = ACTIONS(1793),
    [anon_sym_CARET] = ACTIONS(1791),
    [anon_sym_AMP] = ACTIONS(1791),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1795),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1797),
    [anon_sym_DOT_DOT] = ACTIONS(1799),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1370] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6912),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2912),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7040),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3838),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3963),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7448),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9641),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1370),
    [sym_preproc_endregion] = STATE(1370),
    [sym_preproc_line] = STATE(1370),
    [sym_preproc_pragma] = STATE(1370),
    [sym_preproc_nullable] = STATE(1370),
    [sym_preproc_error] = STATE(1370),
    [sym_preproc_warning] = STATE(1370),
    [sym_preproc_define] = STATE(1370),
    [sym_preproc_undef] = STATE(1370),
    [aux_sym_class_declaration_repeat1] = STATE(3831),
    [aux_sym_lambda_expression_repeat1] = STATE(4257),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1785),
    [anon_sym_ref] = ACTIONS(1787),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1595),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1791),
    [anon_sym_TILDE] = ACTIONS(1791),
    [anon_sym_PLUS_PLUS] = ACTIONS(1791),
    [anon_sym_DASH_DASH] = ACTIONS(1791),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1789),
    [anon_sym_DASH] = ACTIONS(1789),
    [anon_sym_STAR] = ACTIONS(1793),
    [anon_sym_CARET] = ACTIONS(1791),
    [anon_sym_AMP] = ACTIONS(1791),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1795),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1797),
    [anon_sym_DOT_DOT] = ACTIONS(1799),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1371] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6950),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7044),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5110),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3868),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7432),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9127),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1371),
    [sym_preproc_endregion] = STATE(1371),
    [sym_preproc_line] = STATE(1371),
    [sym_preproc_pragma] = STATE(1371),
    [sym_preproc_nullable] = STATE(1371),
    [sym_preproc_error] = STATE(1371),
    [sym_preproc_warning] = STATE(1371),
    [sym_preproc_define] = STATE(1371),
    [sym_preproc_undef] = STATE(1371),
    [aux_sym_class_declaration_repeat1] = STATE(3832),
    [aux_sym_lambda_expression_repeat1] = STATE(4259),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1357),
    [anon_sym_ref] = ACTIONS(1359),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1363),
    [anon_sym_TILDE] = ACTIONS(1363),
    [anon_sym_PLUS_PLUS] = ACTIONS(1363),
    [anon_sym_DASH_DASH] = ACTIONS(1363),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1361),
    [anon_sym_DASH] = ACTIONS(1361),
    [anon_sym_STAR] = ACTIONS(1365),
    [anon_sym_CARET] = ACTIONS(1363),
    [anon_sym_AMP] = ACTIONS(1363),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1367),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1369),
    [anon_sym_DOT_DOT] = ACTIONS(1371),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1372] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6950),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7044),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5111),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3868),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7432),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9127),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1372),
    [sym_preproc_endregion] = STATE(1372),
    [sym_preproc_line] = STATE(1372),
    [sym_preproc_pragma] = STATE(1372),
    [sym_preproc_nullable] = STATE(1372),
    [sym_preproc_error] = STATE(1372),
    [sym_preproc_warning] = STATE(1372),
    [sym_preproc_define] = STATE(1372),
    [sym_preproc_undef] = STATE(1372),
    [aux_sym_class_declaration_repeat1] = STATE(3832),
    [aux_sym_lambda_expression_repeat1] = STATE(4259),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1357),
    [anon_sym_ref] = ACTIONS(1359),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1363),
    [anon_sym_TILDE] = ACTIONS(1363),
    [anon_sym_PLUS_PLUS] = ACTIONS(1363),
    [anon_sym_DASH_DASH] = ACTIONS(1363),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1361),
    [anon_sym_DASH] = ACTIONS(1361),
    [anon_sym_STAR] = ACTIONS(1365),
    [anon_sym_CARET] = ACTIONS(1363),
    [anon_sym_AMP] = ACTIONS(1363),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1367),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1369),
    [anon_sym_DOT_DOT] = ACTIONS(1371),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1373] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6950),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7044),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5112),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3868),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7432),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9127),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1373),
    [sym_preproc_endregion] = STATE(1373),
    [sym_preproc_line] = STATE(1373),
    [sym_preproc_pragma] = STATE(1373),
    [sym_preproc_nullable] = STATE(1373),
    [sym_preproc_error] = STATE(1373),
    [sym_preproc_warning] = STATE(1373),
    [sym_preproc_define] = STATE(1373),
    [sym_preproc_undef] = STATE(1373),
    [aux_sym_class_declaration_repeat1] = STATE(3832),
    [aux_sym_lambda_expression_repeat1] = STATE(4259),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1357),
    [anon_sym_ref] = ACTIONS(1359),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1363),
    [anon_sym_TILDE] = ACTIONS(1363),
    [anon_sym_PLUS_PLUS] = ACTIONS(1363),
    [anon_sym_DASH_DASH] = ACTIONS(1363),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1361),
    [anon_sym_DASH] = ACTIONS(1361),
    [anon_sym_STAR] = ACTIONS(1365),
    [anon_sym_CARET] = ACTIONS(1363),
    [anon_sym_AMP] = ACTIONS(1363),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1367),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1369),
    [anon_sym_DOT_DOT] = ACTIONS(1371),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1374] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6950),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7044),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5113),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3868),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7432),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9127),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1374),
    [sym_preproc_endregion] = STATE(1374),
    [sym_preproc_line] = STATE(1374),
    [sym_preproc_pragma] = STATE(1374),
    [sym_preproc_nullable] = STATE(1374),
    [sym_preproc_error] = STATE(1374),
    [sym_preproc_warning] = STATE(1374),
    [sym_preproc_define] = STATE(1374),
    [sym_preproc_undef] = STATE(1374),
    [aux_sym_class_declaration_repeat1] = STATE(3832),
    [aux_sym_lambda_expression_repeat1] = STATE(4259),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1357),
    [anon_sym_ref] = ACTIONS(1359),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1363),
    [anon_sym_TILDE] = ACTIONS(1363),
    [anon_sym_PLUS_PLUS] = ACTIONS(1363),
    [anon_sym_DASH_DASH] = ACTIONS(1363),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1361),
    [anon_sym_DASH] = ACTIONS(1361),
    [anon_sym_STAR] = ACTIONS(1365),
    [anon_sym_CARET] = ACTIONS(1363),
    [anon_sym_AMP] = ACTIONS(1363),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1367),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1369),
    [anon_sym_DOT_DOT] = ACTIONS(1371),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1375] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6950),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7044),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5114),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3868),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7432),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9127),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1375),
    [sym_preproc_endregion] = STATE(1375),
    [sym_preproc_line] = STATE(1375),
    [sym_preproc_pragma] = STATE(1375),
    [sym_preproc_nullable] = STATE(1375),
    [sym_preproc_error] = STATE(1375),
    [sym_preproc_warning] = STATE(1375),
    [sym_preproc_define] = STATE(1375),
    [sym_preproc_undef] = STATE(1375),
    [aux_sym_class_declaration_repeat1] = STATE(3832),
    [aux_sym_lambda_expression_repeat1] = STATE(4259),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1357),
    [anon_sym_ref] = ACTIONS(1359),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1363),
    [anon_sym_TILDE] = ACTIONS(1363),
    [anon_sym_PLUS_PLUS] = ACTIONS(1363),
    [anon_sym_DASH_DASH] = ACTIONS(1363),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1361),
    [anon_sym_DASH] = ACTIONS(1361),
    [anon_sym_STAR] = ACTIONS(1365),
    [anon_sym_CARET] = ACTIONS(1363),
    [anon_sym_AMP] = ACTIONS(1363),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1367),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1369),
    [anon_sym_DOT_DOT] = ACTIONS(1371),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1376] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6950),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7044),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5115),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3868),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7432),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9127),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1376),
    [sym_preproc_endregion] = STATE(1376),
    [sym_preproc_line] = STATE(1376),
    [sym_preproc_pragma] = STATE(1376),
    [sym_preproc_nullable] = STATE(1376),
    [sym_preproc_error] = STATE(1376),
    [sym_preproc_warning] = STATE(1376),
    [sym_preproc_define] = STATE(1376),
    [sym_preproc_undef] = STATE(1376),
    [aux_sym_class_declaration_repeat1] = STATE(3832),
    [aux_sym_lambda_expression_repeat1] = STATE(4259),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1357),
    [anon_sym_ref] = ACTIONS(1359),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1363),
    [anon_sym_TILDE] = ACTIONS(1363),
    [anon_sym_PLUS_PLUS] = ACTIONS(1363),
    [anon_sym_DASH_DASH] = ACTIONS(1363),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1361),
    [anon_sym_DASH] = ACTIONS(1361),
    [anon_sym_STAR] = ACTIONS(1365),
    [anon_sym_CARET] = ACTIONS(1363),
    [anon_sym_AMP] = ACTIONS(1363),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1367),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1369),
    [anon_sym_DOT_DOT] = ACTIONS(1371),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1377] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6950),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7044),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5117),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3868),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7432),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9127),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1377),
    [sym_preproc_endregion] = STATE(1377),
    [sym_preproc_line] = STATE(1377),
    [sym_preproc_pragma] = STATE(1377),
    [sym_preproc_nullable] = STATE(1377),
    [sym_preproc_error] = STATE(1377),
    [sym_preproc_warning] = STATE(1377),
    [sym_preproc_define] = STATE(1377),
    [sym_preproc_undef] = STATE(1377),
    [aux_sym_class_declaration_repeat1] = STATE(3832),
    [aux_sym_lambda_expression_repeat1] = STATE(4259),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1357),
    [anon_sym_ref] = ACTIONS(1359),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1363),
    [anon_sym_TILDE] = ACTIONS(1363),
    [anon_sym_PLUS_PLUS] = ACTIONS(1363),
    [anon_sym_DASH_DASH] = ACTIONS(1363),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1361),
    [anon_sym_DASH] = ACTIONS(1361),
    [anon_sym_STAR] = ACTIONS(1365),
    [anon_sym_CARET] = ACTIONS(1363),
    [anon_sym_AMP] = ACTIONS(1363),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1367),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1369),
    [anon_sym_DOT_DOT] = ACTIONS(1371),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1378] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6950),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7044),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5118),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3868),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7432),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9127),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1378),
    [sym_preproc_endregion] = STATE(1378),
    [sym_preproc_line] = STATE(1378),
    [sym_preproc_pragma] = STATE(1378),
    [sym_preproc_nullable] = STATE(1378),
    [sym_preproc_error] = STATE(1378),
    [sym_preproc_warning] = STATE(1378),
    [sym_preproc_define] = STATE(1378),
    [sym_preproc_undef] = STATE(1378),
    [aux_sym_class_declaration_repeat1] = STATE(3832),
    [aux_sym_lambda_expression_repeat1] = STATE(4259),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1357),
    [anon_sym_ref] = ACTIONS(1359),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1363),
    [anon_sym_TILDE] = ACTIONS(1363),
    [anon_sym_PLUS_PLUS] = ACTIONS(1363),
    [anon_sym_DASH_DASH] = ACTIONS(1363),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1361),
    [anon_sym_DASH] = ACTIONS(1361),
    [anon_sym_STAR] = ACTIONS(1365),
    [anon_sym_CARET] = ACTIONS(1363),
    [anon_sym_AMP] = ACTIONS(1363),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1367),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1369),
    [anon_sym_DOT_DOT] = ACTIONS(1371),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1379] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6950),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7044),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5049),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3868),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7432),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9127),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1379),
    [sym_preproc_endregion] = STATE(1379),
    [sym_preproc_line] = STATE(1379),
    [sym_preproc_pragma] = STATE(1379),
    [sym_preproc_nullable] = STATE(1379),
    [sym_preproc_error] = STATE(1379),
    [sym_preproc_warning] = STATE(1379),
    [sym_preproc_define] = STATE(1379),
    [sym_preproc_undef] = STATE(1379),
    [aux_sym_class_declaration_repeat1] = STATE(3832),
    [aux_sym_lambda_expression_repeat1] = STATE(4259),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1357),
    [anon_sym_ref] = ACTIONS(1359),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1363),
    [anon_sym_TILDE] = ACTIONS(1363),
    [anon_sym_PLUS_PLUS] = ACTIONS(1363),
    [anon_sym_DASH_DASH] = ACTIONS(1363),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1361),
    [anon_sym_DASH] = ACTIONS(1361),
    [anon_sym_STAR] = ACTIONS(1365),
    [anon_sym_CARET] = ACTIONS(1363),
    [anon_sym_AMP] = ACTIONS(1363),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1367),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1369),
    [anon_sym_DOT_DOT] = ACTIONS(1371),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1380] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6950),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7044),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5121),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3868),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7432),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9127),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1380),
    [sym_preproc_endregion] = STATE(1380),
    [sym_preproc_line] = STATE(1380),
    [sym_preproc_pragma] = STATE(1380),
    [sym_preproc_nullable] = STATE(1380),
    [sym_preproc_error] = STATE(1380),
    [sym_preproc_warning] = STATE(1380),
    [sym_preproc_define] = STATE(1380),
    [sym_preproc_undef] = STATE(1380),
    [aux_sym_class_declaration_repeat1] = STATE(3832),
    [aux_sym_lambda_expression_repeat1] = STATE(4259),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1357),
    [anon_sym_ref] = ACTIONS(1359),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1363),
    [anon_sym_TILDE] = ACTIONS(1363),
    [anon_sym_PLUS_PLUS] = ACTIONS(1363),
    [anon_sym_DASH_DASH] = ACTIONS(1363),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1361),
    [anon_sym_DASH] = ACTIONS(1361),
    [anon_sym_STAR] = ACTIONS(1365),
    [anon_sym_CARET] = ACTIONS(1363),
    [anon_sym_AMP] = ACTIONS(1363),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1367),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1369),
    [anon_sym_DOT_DOT] = ACTIONS(1371),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1381] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6950),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7044),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5122),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3868),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7432),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9127),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1381),
    [sym_preproc_endregion] = STATE(1381),
    [sym_preproc_line] = STATE(1381),
    [sym_preproc_pragma] = STATE(1381),
    [sym_preproc_nullable] = STATE(1381),
    [sym_preproc_error] = STATE(1381),
    [sym_preproc_warning] = STATE(1381),
    [sym_preproc_define] = STATE(1381),
    [sym_preproc_undef] = STATE(1381),
    [aux_sym_class_declaration_repeat1] = STATE(3832),
    [aux_sym_lambda_expression_repeat1] = STATE(4259),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1357),
    [anon_sym_ref] = ACTIONS(1359),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1363),
    [anon_sym_TILDE] = ACTIONS(1363),
    [anon_sym_PLUS_PLUS] = ACTIONS(1363),
    [anon_sym_DASH_DASH] = ACTIONS(1363),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1361),
    [anon_sym_DASH] = ACTIONS(1361),
    [anon_sym_STAR] = ACTIONS(1365),
    [anon_sym_CARET] = ACTIONS(1363),
    [anon_sym_AMP] = ACTIONS(1363),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1367),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1369),
    [anon_sym_DOT_DOT] = ACTIONS(1371),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1382] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6912),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2912),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7040),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5289),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3963),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7448),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9641),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1382),
    [sym_preproc_endregion] = STATE(1382),
    [sym_preproc_line] = STATE(1382),
    [sym_preproc_pragma] = STATE(1382),
    [sym_preproc_nullable] = STATE(1382),
    [sym_preproc_error] = STATE(1382),
    [sym_preproc_warning] = STATE(1382),
    [sym_preproc_define] = STATE(1382),
    [sym_preproc_undef] = STATE(1382),
    [aux_sym_class_declaration_repeat1] = STATE(3831),
    [aux_sym_lambda_expression_repeat1] = STATE(4257),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1785),
    [anon_sym_ref] = ACTIONS(1787),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1595),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1791),
    [anon_sym_TILDE] = ACTIONS(1791),
    [anon_sym_PLUS_PLUS] = ACTIONS(1791),
    [anon_sym_DASH_DASH] = ACTIONS(1791),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1789),
    [anon_sym_DASH] = ACTIONS(1789),
    [anon_sym_STAR] = ACTIONS(1793),
    [anon_sym_CARET] = ACTIONS(1791),
    [anon_sym_AMP] = ACTIONS(1791),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1795),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1797),
    [anon_sym_DOT_DOT] = ACTIONS(1799),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1383] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6950),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7044),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3867),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3868),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7432),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9127),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1383),
    [sym_preproc_endregion] = STATE(1383),
    [sym_preproc_line] = STATE(1383),
    [sym_preproc_pragma] = STATE(1383),
    [sym_preproc_nullable] = STATE(1383),
    [sym_preproc_error] = STATE(1383),
    [sym_preproc_warning] = STATE(1383),
    [sym_preproc_define] = STATE(1383),
    [sym_preproc_undef] = STATE(1383),
    [aux_sym_class_declaration_repeat1] = STATE(3832),
    [aux_sym_lambda_expression_repeat1] = STATE(4259),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1357),
    [anon_sym_ref] = ACTIONS(1359),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1363),
    [anon_sym_TILDE] = ACTIONS(1363),
    [anon_sym_PLUS_PLUS] = ACTIONS(1363),
    [anon_sym_DASH_DASH] = ACTIONS(1363),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1361),
    [anon_sym_DASH] = ACTIONS(1361),
    [anon_sym_STAR] = ACTIONS(1365),
    [anon_sym_CARET] = ACTIONS(1363),
    [anon_sym_AMP] = ACTIONS(1363),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1367),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1369),
    [anon_sym_DOT_DOT] = ACTIONS(1371),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1384] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6912),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2912),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7040),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5284),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3963),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7448),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9641),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1384),
    [sym_preproc_endregion] = STATE(1384),
    [sym_preproc_line] = STATE(1384),
    [sym_preproc_pragma] = STATE(1384),
    [sym_preproc_nullable] = STATE(1384),
    [sym_preproc_error] = STATE(1384),
    [sym_preproc_warning] = STATE(1384),
    [sym_preproc_define] = STATE(1384),
    [sym_preproc_undef] = STATE(1384),
    [aux_sym_class_declaration_repeat1] = STATE(3831),
    [aux_sym_lambda_expression_repeat1] = STATE(4257),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1785),
    [anon_sym_ref] = ACTIONS(1787),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1595),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1791),
    [anon_sym_TILDE] = ACTIONS(1791),
    [anon_sym_PLUS_PLUS] = ACTIONS(1791),
    [anon_sym_DASH_DASH] = ACTIONS(1791),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1789),
    [anon_sym_DASH] = ACTIONS(1789),
    [anon_sym_STAR] = ACTIONS(1793),
    [anon_sym_CARET] = ACTIONS(1791),
    [anon_sym_AMP] = ACTIONS(1791),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1795),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1797),
    [anon_sym_DOT_DOT] = ACTIONS(1799),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1385] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6142),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1385),
    [sym_preproc_endregion] = STATE(1385),
    [sym_preproc_line] = STATE(1385),
    [sym_preproc_pragma] = STATE(1385),
    [sym_preproc_nullable] = STATE(1385),
    [sym_preproc_error] = STATE(1385),
    [sym_preproc_warning] = STATE(1385),
    [sym_preproc_define] = STATE(1385),
    [sym_preproc_undef] = STATE(1385),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1386] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7131),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4354),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4364),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9470),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1386),
    [sym_preproc_endregion] = STATE(1386),
    [sym_preproc_line] = STATE(1386),
    [sym_preproc_pragma] = STATE(1386),
    [sym_preproc_nullable] = STATE(1386),
    [sym_preproc_error] = STATE(1386),
    [sym_preproc_warning] = STATE(1386),
    [sym_preproc_define] = STATE(1386),
    [sym_preproc_undef] = STATE(1386),
    [aux_sym_class_declaration_repeat1] = STATE(3870),
    [aux_sym_lambda_expression_repeat1] = STATE(4302),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1555),
    [anon_sym_ref] = ACTIONS(1557),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(695),
    [anon_sym_TILDE] = ACTIONS(695),
    [anon_sym_PLUS_PLUS] = ACTIONS(695),
    [anon_sym_DASH_DASH] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(697),
    [anon_sym_DASH] = ACTIONS(697),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(695),
    [anon_sym_AMP] = ACTIONS(695),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1559),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1561),
    [anon_sym_DOT_DOT] = ACTIONS(1563),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1387] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6948),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2940),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7105),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6718),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3056),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1387),
    [sym_preproc_endregion] = STATE(1387),
    [sym_preproc_line] = STATE(1387),
    [sym_preproc_pragma] = STATE(1387),
    [sym_preproc_nullable] = STATE(1387),
    [sym_preproc_error] = STATE(1387),
    [sym_preproc_warning] = STATE(1387),
    [sym_preproc_define] = STATE(1387),
    [sym_preproc_undef] = STATE(1387),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2977),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(1903),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1388] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7105),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5917),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1388),
    [sym_preproc_endregion] = STATE(1388),
    [sym_preproc_line] = STATE(1388),
    [sym_preproc_pragma] = STATE(1388),
    [sym_preproc_nullable] = STATE(1388),
    [sym_preproc_error] = STATE(1388),
    [sym_preproc_warning] = STATE(1388),
    [sym_preproc_define] = STATE(1388),
    [sym_preproc_undef] = STATE(1388),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1389] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7105),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4336),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1389),
    [sym_preproc_endregion] = STATE(1389),
    [sym_preproc_line] = STATE(1389),
    [sym_preproc_pragma] = STATE(1389),
    [sym_preproc_nullable] = STATE(1389),
    [sym_preproc_error] = STATE(1389),
    [sym_preproc_warning] = STATE(1389),
    [sym_preproc_define] = STATE(1389),
    [sym_preproc_undef] = STATE(1389),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1390] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6956),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5760),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9482),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1390),
    [sym_preproc_endregion] = STATE(1390),
    [sym_preproc_line] = STATE(1390),
    [sym_preproc_pragma] = STATE(1390),
    [sym_preproc_nullable] = STATE(1390),
    [sym_preproc_error] = STATE(1390),
    [sym_preproc_warning] = STATE(1390),
    [sym_preproc_define] = STATE(1390),
    [sym_preproc_undef] = STATE(1390),
    [aux_sym_class_declaration_repeat1] = STATE(3853),
    [aux_sym_lambda_expression_repeat1] = STATE(4299),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1497),
    [anon_sym_ref] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1505),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1507),
    [anon_sym_DOT_DOT] = ACTIONS(1509),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1391] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6572),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1391),
    [sym_preproc_endregion] = STATE(1391),
    [sym_preproc_line] = STATE(1391),
    [sym_preproc_pragma] = STATE(1391),
    [sym_preproc_nullable] = STATE(1391),
    [sym_preproc_error] = STATE(1391),
    [sym_preproc_warning] = STATE(1391),
    [sym_preproc_define] = STATE(1391),
    [sym_preproc_undef] = STATE(1391),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1392] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6956),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5761),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9482),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1392),
    [sym_preproc_endregion] = STATE(1392),
    [sym_preproc_line] = STATE(1392),
    [sym_preproc_pragma] = STATE(1392),
    [sym_preproc_nullable] = STATE(1392),
    [sym_preproc_error] = STATE(1392),
    [sym_preproc_warning] = STATE(1392),
    [sym_preproc_define] = STATE(1392),
    [sym_preproc_undef] = STATE(1392),
    [aux_sym_class_declaration_repeat1] = STATE(3853),
    [aux_sym_lambda_expression_repeat1] = STATE(4299),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1497),
    [anon_sym_ref] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1505),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1507),
    [anon_sym_DOT_DOT] = ACTIONS(1509),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1393] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6956),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5762),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9482),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1393),
    [sym_preproc_endregion] = STATE(1393),
    [sym_preproc_line] = STATE(1393),
    [sym_preproc_pragma] = STATE(1393),
    [sym_preproc_nullable] = STATE(1393),
    [sym_preproc_error] = STATE(1393),
    [sym_preproc_warning] = STATE(1393),
    [sym_preproc_define] = STATE(1393),
    [sym_preproc_undef] = STATE(1393),
    [aux_sym_class_declaration_repeat1] = STATE(3853),
    [aux_sym_lambda_expression_repeat1] = STATE(4299),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1497),
    [anon_sym_ref] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1505),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1507),
    [anon_sym_DOT_DOT] = ACTIONS(1509),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1394] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6956),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5763),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9482),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1394),
    [sym_preproc_endregion] = STATE(1394),
    [sym_preproc_line] = STATE(1394),
    [sym_preproc_pragma] = STATE(1394),
    [sym_preproc_nullable] = STATE(1394),
    [sym_preproc_error] = STATE(1394),
    [sym_preproc_warning] = STATE(1394),
    [sym_preproc_define] = STATE(1394),
    [sym_preproc_undef] = STATE(1394),
    [aux_sym_class_declaration_repeat1] = STATE(3853),
    [aux_sym_lambda_expression_repeat1] = STATE(4299),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1497),
    [anon_sym_ref] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1505),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1507),
    [anon_sym_DOT_DOT] = ACTIONS(1509),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1395] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6956),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5764),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9482),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1395),
    [sym_preproc_endregion] = STATE(1395),
    [sym_preproc_line] = STATE(1395),
    [sym_preproc_pragma] = STATE(1395),
    [sym_preproc_nullable] = STATE(1395),
    [sym_preproc_error] = STATE(1395),
    [sym_preproc_warning] = STATE(1395),
    [sym_preproc_define] = STATE(1395),
    [sym_preproc_undef] = STATE(1395),
    [aux_sym_class_declaration_repeat1] = STATE(3853),
    [aux_sym_lambda_expression_repeat1] = STATE(4299),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1497),
    [anon_sym_ref] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1505),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1507),
    [anon_sym_DOT_DOT] = ACTIONS(1509),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1396] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6956),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5765),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9482),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1396),
    [sym_preproc_endregion] = STATE(1396),
    [sym_preproc_line] = STATE(1396),
    [sym_preproc_pragma] = STATE(1396),
    [sym_preproc_nullable] = STATE(1396),
    [sym_preproc_error] = STATE(1396),
    [sym_preproc_warning] = STATE(1396),
    [sym_preproc_define] = STATE(1396),
    [sym_preproc_undef] = STATE(1396),
    [aux_sym_class_declaration_repeat1] = STATE(3853),
    [aux_sym_lambda_expression_repeat1] = STATE(4299),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1497),
    [anon_sym_ref] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1505),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1507),
    [anon_sym_DOT_DOT] = ACTIONS(1509),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1397] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6956),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5766),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9482),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1397),
    [sym_preproc_endregion] = STATE(1397),
    [sym_preproc_line] = STATE(1397),
    [sym_preproc_pragma] = STATE(1397),
    [sym_preproc_nullable] = STATE(1397),
    [sym_preproc_error] = STATE(1397),
    [sym_preproc_warning] = STATE(1397),
    [sym_preproc_define] = STATE(1397),
    [sym_preproc_undef] = STATE(1397),
    [aux_sym_class_declaration_repeat1] = STATE(3853),
    [aux_sym_lambda_expression_repeat1] = STATE(4299),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1497),
    [anon_sym_ref] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1505),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1507),
    [anon_sym_DOT_DOT] = ACTIONS(1509),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1398] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6956),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5767),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9482),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1398),
    [sym_preproc_endregion] = STATE(1398),
    [sym_preproc_line] = STATE(1398),
    [sym_preproc_pragma] = STATE(1398),
    [sym_preproc_nullable] = STATE(1398),
    [sym_preproc_error] = STATE(1398),
    [sym_preproc_warning] = STATE(1398),
    [sym_preproc_define] = STATE(1398),
    [sym_preproc_undef] = STATE(1398),
    [aux_sym_class_declaration_repeat1] = STATE(3853),
    [aux_sym_lambda_expression_repeat1] = STATE(4299),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1497),
    [anon_sym_ref] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1505),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1507),
    [anon_sym_DOT_DOT] = ACTIONS(1509),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1399] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6956),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5769),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9482),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1399),
    [sym_preproc_endregion] = STATE(1399),
    [sym_preproc_line] = STATE(1399),
    [sym_preproc_pragma] = STATE(1399),
    [sym_preproc_nullable] = STATE(1399),
    [sym_preproc_error] = STATE(1399),
    [sym_preproc_warning] = STATE(1399),
    [sym_preproc_define] = STATE(1399),
    [sym_preproc_undef] = STATE(1399),
    [aux_sym_class_declaration_repeat1] = STATE(3853),
    [aux_sym_lambda_expression_repeat1] = STATE(4299),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1497),
    [anon_sym_ref] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1505),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1507),
    [anon_sym_DOT_DOT] = ACTIONS(1509),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1400] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6956),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5770),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9482),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1400),
    [sym_preproc_endregion] = STATE(1400),
    [sym_preproc_line] = STATE(1400),
    [sym_preproc_pragma] = STATE(1400),
    [sym_preproc_nullable] = STATE(1400),
    [sym_preproc_error] = STATE(1400),
    [sym_preproc_warning] = STATE(1400),
    [sym_preproc_define] = STATE(1400),
    [sym_preproc_undef] = STATE(1400),
    [aux_sym_class_declaration_repeat1] = STATE(3853),
    [aux_sym_lambda_expression_repeat1] = STATE(4299),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1497),
    [anon_sym_ref] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1505),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1507),
    [anon_sym_DOT_DOT] = ACTIONS(1509),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1401] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6956),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5771),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9482),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1401),
    [sym_preproc_endregion] = STATE(1401),
    [sym_preproc_line] = STATE(1401),
    [sym_preproc_pragma] = STATE(1401),
    [sym_preproc_nullable] = STATE(1401),
    [sym_preproc_error] = STATE(1401),
    [sym_preproc_warning] = STATE(1401),
    [sym_preproc_define] = STATE(1401),
    [sym_preproc_undef] = STATE(1401),
    [aux_sym_class_declaration_repeat1] = STATE(3853),
    [aux_sym_lambda_expression_repeat1] = STATE(4299),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1497),
    [anon_sym_ref] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1505),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1507),
    [anon_sym_DOT_DOT] = ACTIONS(1509),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1402] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7105),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5932),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1402),
    [sym_preproc_endregion] = STATE(1402),
    [sym_preproc_line] = STATE(1402),
    [sym_preproc_pragma] = STATE(1402),
    [sym_preproc_nullable] = STATE(1402),
    [sym_preproc_error] = STATE(1402),
    [sym_preproc_warning] = STATE(1402),
    [sym_preproc_define] = STATE(1402),
    [sym_preproc_undef] = STATE(1402),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1403] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6955),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2975),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6988),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5024),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3800),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7425),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9573),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1403),
    [sym_preproc_endregion] = STATE(1403),
    [sym_preproc_line] = STATE(1403),
    [sym_preproc_pragma] = STATE(1403),
    [sym_preproc_nullable] = STATE(1403),
    [sym_preproc_error] = STATE(1403),
    [sym_preproc_warning] = STATE(1403),
    [sym_preproc_define] = STATE(1403),
    [sym_preproc_undef] = STATE(1403),
    [aux_sym_class_declaration_repeat1] = STATE(3818),
    [aux_sym_lambda_expression_repeat1] = STATE(4229),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2259),
    [anon_sym_ref] = ACTIONS(2261),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1933),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2265),
    [anon_sym_TILDE] = ACTIONS(2265),
    [anon_sym_PLUS_PLUS] = ACTIONS(2265),
    [anon_sym_DASH_DASH] = ACTIONS(2265),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2263),
    [anon_sym_DASH] = ACTIONS(2263),
    [anon_sym_STAR] = ACTIONS(1939),
    [anon_sym_CARET] = ACTIONS(2265),
    [anon_sym_AMP] = ACTIONS(2265),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2267),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2269),
    [anon_sym_DOT_DOT] = ACTIONS(2271),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1404] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6575),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1404),
    [sym_preproc_endregion] = STATE(1404),
    [sym_preproc_line] = STATE(1404),
    [sym_preproc_pragma] = STATE(1404),
    [sym_preproc_nullable] = STATE(1404),
    [sym_preproc_error] = STATE(1404),
    [sym_preproc_warning] = STATE(1404),
    [sym_preproc_define] = STATE(1404),
    [sym_preproc_undef] = STATE(1404),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1405] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6956),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4338),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9482),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1405),
    [sym_preproc_endregion] = STATE(1405),
    [sym_preproc_line] = STATE(1405),
    [sym_preproc_pragma] = STATE(1405),
    [sym_preproc_nullable] = STATE(1405),
    [sym_preproc_error] = STATE(1405),
    [sym_preproc_warning] = STATE(1405),
    [sym_preproc_define] = STATE(1405),
    [sym_preproc_undef] = STATE(1405),
    [aux_sym_class_declaration_repeat1] = STATE(3853),
    [aux_sym_lambda_expression_repeat1] = STATE(4299),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1497),
    [anon_sym_ref] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1505),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1507),
    [anon_sym_DOT_DOT] = ACTIONS(1509),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1406] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6576),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1406),
    [sym_preproc_endregion] = STATE(1406),
    [sym_preproc_line] = STATE(1406),
    [sym_preproc_pragma] = STATE(1406),
    [sym_preproc_nullable] = STATE(1406),
    [sym_preproc_error] = STATE(1406),
    [sym_preproc_warning] = STATE(1406),
    [sym_preproc_define] = STATE(1406),
    [sym_preproc_undef] = STATE(1406),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1407] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6913),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2905),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6979),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5654),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4178),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7433),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9183),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1407),
    [sym_preproc_endregion] = STATE(1407),
    [sym_preproc_line] = STATE(1407),
    [sym_preproc_pragma] = STATE(1407),
    [sym_preproc_nullable] = STATE(1407),
    [sym_preproc_error] = STATE(1407),
    [sym_preproc_warning] = STATE(1407),
    [sym_preproc_define] = STATE(1407),
    [sym_preproc_undef] = STATE(1407),
    [aux_sym_class_declaration_repeat1] = STATE(3816),
    [aux_sym_lambda_expression_repeat1] = STATE(4225),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1573),
    [anon_sym_ref] = ACTIONS(1575),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1577),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1581),
    [anon_sym_TILDE] = ACTIONS(1581),
    [anon_sym_PLUS_PLUS] = ACTIONS(1581),
    [anon_sym_DASH_DASH] = ACTIONS(1581),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1579),
    [anon_sym_DASH] = ACTIONS(1579),
    [anon_sym_STAR] = ACTIONS(1583),
    [anon_sym_CARET] = ACTIONS(1581),
    [anon_sym_AMP] = ACTIONS(1581),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1585),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1587),
    [anon_sym_DOT_DOT] = ACTIONS(1589),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1408] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6956),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5787),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9482),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1408),
    [sym_preproc_endregion] = STATE(1408),
    [sym_preproc_line] = STATE(1408),
    [sym_preproc_pragma] = STATE(1408),
    [sym_preproc_nullable] = STATE(1408),
    [sym_preproc_error] = STATE(1408),
    [sym_preproc_warning] = STATE(1408),
    [sym_preproc_define] = STATE(1408),
    [sym_preproc_undef] = STATE(1408),
    [aux_sym_class_declaration_repeat1] = STATE(3853),
    [aux_sym_lambda_expression_repeat1] = STATE(4299),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1497),
    [anon_sym_ref] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1505),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1507),
    [anon_sym_DOT_DOT] = ACTIONS(1509),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1409] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6145),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1409),
    [sym_preproc_endregion] = STATE(1409),
    [sym_preproc_line] = STATE(1409),
    [sym_preproc_pragma] = STATE(1409),
    [sym_preproc_nullable] = STATE(1409),
    [sym_preproc_error] = STATE(1409),
    [sym_preproc_warning] = STATE(1409),
    [sym_preproc_define] = STATE(1409),
    [sym_preproc_undef] = STATE(1409),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1410] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6955),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2975),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6988),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5028),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3800),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7425),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9573),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1410),
    [sym_preproc_endregion] = STATE(1410),
    [sym_preproc_line] = STATE(1410),
    [sym_preproc_pragma] = STATE(1410),
    [sym_preproc_nullable] = STATE(1410),
    [sym_preproc_error] = STATE(1410),
    [sym_preproc_warning] = STATE(1410),
    [sym_preproc_define] = STATE(1410),
    [sym_preproc_undef] = STATE(1410),
    [aux_sym_class_declaration_repeat1] = STATE(3818),
    [aux_sym_lambda_expression_repeat1] = STATE(4229),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2259),
    [anon_sym_ref] = ACTIONS(2261),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1933),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2265),
    [anon_sym_TILDE] = ACTIONS(2265),
    [anon_sym_PLUS_PLUS] = ACTIONS(2265),
    [anon_sym_DASH_DASH] = ACTIONS(2265),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2263),
    [anon_sym_DASH] = ACTIONS(2263),
    [anon_sym_STAR] = ACTIONS(1939),
    [anon_sym_CARET] = ACTIONS(2265),
    [anon_sym_AMP] = ACTIONS(2265),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2267),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2269),
    [anon_sym_DOT_DOT] = ACTIONS(2271),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1411] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7159),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6579),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4487),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7422),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9176),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1411),
    [sym_preproc_endregion] = STATE(1411),
    [sym_preproc_line] = STATE(1411),
    [sym_preproc_pragma] = STATE(1411),
    [sym_preproc_nullable] = STATE(1411),
    [sym_preproc_error] = STATE(1411),
    [sym_preproc_warning] = STATE(1411),
    [sym_preproc_define] = STATE(1411),
    [sym_preproc_undef] = STATE(1411),
    [aux_sym_class_declaration_repeat1] = STATE(3877),
    [aux_sym_lambda_expression_repeat1] = STATE(4320),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1979),
    [anon_sym_ref] = ACTIONS(1981),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1985),
    [anon_sym_TILDE] = ACTIONS(1985),
    [anon_sym_PLUS_PLUS] = ACTIONS(1985),
    [anon_sym_DASH_DASH] = ACTIONS(1985),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1983),
    [anon_sym_DASH] = ACTIONS(1983),
    [anon_sym_STAR] = ACTIONS(1987),
    [anon_sym_CARET] = ACTIONS(1985),
    [anon_sym_AMP] = ACTIONS(1985),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1989),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1991),
    [anon_sym_DOT_DOT] = ACTIONS(1993),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1412] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6913),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2905),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6979),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5417),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4178),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7433),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9183),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1412),
    [sym_preproc_endregion] = STATE(1412),
    [sym_preproc_line] = STATE(1412),
    [sym_preproc_pragma] = STATE(1412),
    [sym_preproc_nullable] = STATE(1412),
    [sym_preproc_error] = STATE(1412),
    [sym_preproc_warning] = STATE(1412),
    [sym_preproc_define] = STATE(1412),
    [sym_preproc_undef] = STATE(1412),
    [aux_sym_class_declaration_repeat1] = STATE(3816),
    [aux_sym_lambda_expression_repeat1] = STATE(4225),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1573),
    [anon_sym_ref] = ACTIONS(1575),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1577),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1581),
    [anon_sym_TILDE] = ACTIONS(1581),
    [anon_sym_PLUS_PLUS] = ACTIONS(1581),
    [anon_sym_DASH_DASH] = ACTIONS(1581),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1579),
    [anon_sym_DASH] = ACTIONS(1579),
    [anon_sym_STAR] = ACTIONS(1583),
    [anon_sym_CARET] = ACTIONS(1581),
    [anon_sym_AMP] = ACTIONS(1581),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1585),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1587),
    [anon_sym_DOT_DOT] = ACTIONS(1589),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1413] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6913),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2905),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6979),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5418),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4178),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7433),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9183),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1413),
    [sym_preproc_endregion] = STATE(1413),
    [sym_preproc_line] = STATE(1413),
    [sym_preproc_pragma] = STATE(1413),
    [sym_preproc_nullable] = STATE(1413),
    [sym_preproc_error] = STATE(1413),
    [sym_preproc_warning] = STATE(1413),
    [sym_preproc_define] = STATE(1413),
    [sym_preproc_undef] = STATE(1413),
    [aux_sym_class_declaration_repeat1] = STATE(3816),
    [aux_sym_lambda_expression_repeat1] = STATE(4225),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1573),
    [anon_sym_ref] = ACTIONS(1575),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1577),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1581),
    [anon_sym_TILDE] = ACTIONS(1581),
    [anon_sym_PLUS_PLUS] = ACTIONS(1581),
    [anon_sym_DASH_DASH] = ACTIONS(1581),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1579),
    [anon_sym_DASH] = ACTIONS(1579),
    [anon_sym_STAR] = ACTIONS(1583),
    [anon_sym_CARET] = ACTIONS(1581),
    [anon_sym_AMP] = ACTIONS(1581),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1585),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1587),
    [anon_sym_DOT_DOT] = ACTIONS(1589),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1414] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6913),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2905),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6979),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5655),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4178),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7433),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9183),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1414),
    [sym_preproc_endregion] = STATE(1414),
    [sym_preproc_line] = STATE(1414),
    [sym_preproc_pragma] = STATE(1414),
    [sym_preproc_nullable] = STATE(1414),
    [sym_preproc_error] = STATE(1414),
    [sym_preproc_warning] = STATE(1414),
    [sym_preproc_define] = STATE(1414),
    [sym_preproc_undef] = STATE(1414),
    [aux_sym_class_declaration_repeat1] = STATE(3816),
    [aux_sym_lambda_expression_repeat1] = STATE(4225),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1573),
    [anon_sym_ref] = ACTIONS(1575),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1577),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1581),
    [anon_sym_TILDE] = ACTIONS(1581),
    [anon_sym_PLUS_PLUS] = ACTIONS(1581),
    [anon_sym_DASH_DASH] = ACTIONS(1581),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1579),
    [anon_sym_DASH] = ACTIONS(1579),
    [anon_sym_STAR] = ACTIONS(1583),
    [anon_sym_CARET] = ACTIONS(1581),
    [anon_sym_AMP] = ACTIONS(1581),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1585),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1587),
    [anon_sym_DOT_DOT] = ACTIONS(1589),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1415] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6913),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2905),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6979),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5419),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4178),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7433),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9183),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1415),
    [sym_preproc_endregion] = STATE(1415),
    [sym_preproc_line] = STATE(1415),
    [sym_preproc_pragma] = STATE(1415),
    [sym_preproc_nullable] = STATE(1415),
    [sym_preproc_error] = STATE(1415),
    [sym_preproc_warning] = STATE(1415),
    [sym_preproc_define] = STATE(1415),
    [sym_preproc_undef] = STATE(1415),
    [aux_sym_class_declaration_repeat1] = STATE(3816),
    [aux_sym_lambda_expression_repeat1] = STATE(4225),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1573),
    [anon_sym_ref] = ACTIONS(1575),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1577),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1581),
    [anon_sym_TILDE] = ACTIONS(1581),
    [anon_sym_PLUS_PLUS] = ACTIONS(1581),
    [anon_sym_DASH_DASH] = ACTIONS(1581),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1579),
    [anon_sym_DASH] = ACTIONS(1579),
    [anon_sym_STAR] = ACTIONS(1583),
    [anon_sym_CARET] = ACTIONS(1581),
    [anon_sym_AMP] = ACTIONS(1581),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1585),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1587),
    [anon_sym_DOT_DOT] = ACTIONS(1589),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1416] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6913),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2905),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6979),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5420),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4178),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7433),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9183),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1416),
    [sym_preproc_endregion] = STATE(1416),
    [sym_preproc_line] = STATE(1416),
    [sym_preproc_pragma] = STATE(1416),
    [sym_preproc_nullable] = STATE(1416),
    [sym_preproc_error] = STATE(1416),
    [sym_preproc_warning] = STATE(1416),
    [sym_preproc_define] = STATE(1416),
    [sym_preproc_undef] = STATE(1416),
    [aux_sym_class_declaration_repeat1] = STATE(3816),
    [aux_sym_lambda_expression_repeat1] = STATE(4225),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1573),
    [anon_sym_ref] = ACTIONS(1575),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1577),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1581),
    [anon_sym_TILDE] = ACTIONS(1581),
    [anon_sym_PLUS_PLUS] = ACTIONS(1581),
    [anon_sym_DASH_DASH] = ACTIONS(1581),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1579),
    [anon_sym_DASH] = ACTIONS(1579),
    [anon_sym_STAR] = ACTIONS(1583),
    [anon_sym_CARET] = ACTIONS(1581),
    [anon_sym_AMP] = ACTIONS(1581),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1585),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1587),
    [anon_sym_DOT_DOT] = ACTIONS(1589),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1417] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6913),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2905),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6979),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5421),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4178),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7433),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9183),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1417),
    [sym_preproc_endregion] = STATE(1417),
    [sym_preproc_line] = STATE(1417),
    [sym_preproc_pragma] = STATE(1417),
    [sym_preproc_nullable] = STATE(1417),
    [sym_preproc_error] = STATE(1417),
    [sym_preproc_warning] = STATE(1417),
    [sym_preproc_define] = STATE(1417),
    [sym_preproc_undef] = STATE(1417),
    [aux_sym_class_declaration_repeat1] = STATE(3816),
    [aux_sym_lambda_expression_repeat1] = STATE(4225),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1573),
    [anon_sym_ref] = ACTIONS(1575),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1577),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1581),
    [anon_sym_TILDE] = ACTIONS(1581),
    [anon_sym_PLUS_PLUS] = ACTIONS(1581),
    [anon_sym_DASH_DASH] = ACTIONS(1581),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1579),
    [anon_sym_DASH] = ACTIONS(1579),
    [anon_sym_STAR] = ACTIONS(1583),
    [anon_sym_CARET] = ACTIONS(1581),
    [anon_sym_AMP] = ACTIONS(1581),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1585),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1587),
    [anon_sym_DOT_DOT] = ACTIONS(1589),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1418] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6913),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2905),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6979),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5422),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4178),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7433),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9183),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1418),
    [sym_preproc_endregion] = STATE(1418),
    [sym_preproc_line] = STATE(1418),
    [sym_preproc_pragma] = STATE(1418),
    [sym_preproc_nullable] = STATE(1418),
    [sym_preproc_error] = STATE(1418),
    [sym_preproc_warning] = STATE(1418),
    [sym_preproc_define] = STATE(1418),
    [sym_preproc_undef] = STATE(1418),
    [aux_sym_class_declaration_repeat1] = STATE(3816),
    [aux_sym_lambda_expression_repeat1] = STATE(4225),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1573),
    [anon_sym_ref] = ACTIONS(1575),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1577),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1581),
    [anon_sym_TILDE] = ACTIONS(1581),
    [anon_sym_PLUS_PLUS] = ACTIONS(1581),
    [anon_sym_DASH_DASH] = ACTIONS(1581),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1579),
    [anon_sym_DASH] = ACTIONS(1579),
    [anon_sym_STAR] = ACTIONS(1583),
    [anon_sym_CARET] = ACTIONS(1581),
    [anon_sym_AMP] = ACTIONS(1581),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1585),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1587),
    [anon_sym_DOT_DOT] = ACTIONS(1589),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1419] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6913),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2905),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6979),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5423),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4178),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7433),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9183),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1419),
    [sym_preproc_endregion] = STATE(1419),
    [sym_preproc_line] = STATE(1419),
    [sym_preproc_pragma] = STATE(1419),
    [sym_preproc_nullable] = STATE(1419),
    [sym_preproc_error] = STATE(1419),
    [sym_preproc_warning] = STATE(1419),
    [sym_preproc_define] = STATE(1419),
    [sym_preproc_undef] = STATE(1419),
    [aux_sym_class_declaration_repeat1] = STATE(3816),
    [aux_sym_lambda_expression_repeat1] = STATE(4225),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1573),
    [anon_sym_ref] = ACTIONS(1575),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1577),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1581),
    [anon_sym_TILDE] = ACTIONS(1581),
    [anon_sym_PLUS_PLUS] = ACTIONS(1581),
    [anon_sym_DASH_DASH] = ACTIONS(1581),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1579),
    [anon_sym_DASH] = ACTIONS(1579),
    [anon_sym_STAR] = ACTIONS(1583),
    [anon_sym_CARET] = ACTIONS(1581),
    [anon_sym_AMP] = ACTIONS(1581),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1585),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1587),
    [anon_sym_DOT_DOT] = ACTIONS(1589),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1420] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6913),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2905),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6979),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5424),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4178),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7433),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9183),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1420),
    [sym_preproc_endregion] = STATE(1420),
    [sym_preproc_line] = STATE(1420),
    [sym_preproc_pragma] = STATE(1420),
    [sym_preproc_nullable] = STATE(1420),
    [sym_preproc_error] = STATE(1420),
    [sym_preproc_warning] = STATE(1420),
    [sym_preproc_define] = STATE(1420),
    [sym_preproc_undef] = STATE(1420),
    [aux_sym_class_declaration_repeat1] = STATE(3816),
    [aux_sym_lambda_expression_repeat1] = STATE(4225),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1573),
    [anon_sym_ref] = ACTIONS(1575),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1577),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1581),
    [anon_sym_TILDE] = ACTIONS(1581),
    [anon_sym_PLUS_PLUS] = ACTIONS(1581),
    [anon_sym_DASH_DASH] = ACTIONS(1581),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1579),
    [anon_sym_DASH] = ACTIONS(1579),
    [anon_sym_STAR] = ACTIONS(1583),
    [anon_sym_CARET] = ACTIONS(1581),
    [anon_sym_AMP] = ACTIONS(1581),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1585),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1587),
    [anon_sym_DOT_DOT] = ACTIONS(1589),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1421] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6913),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2905),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6979),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5426),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4178),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7433),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9183),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1421),
    [sym_preproc_endregion] = STATE(1421),
    [sym_preproc_line] = STATE(1421),
    [sym_preproc_pragma] = STATE(1421),
    [sym_preproc_nullable] = STATE(1421),
    [sym_preproc_error] = STATE(1421),
    [sym_preproc_warning] = STATE(1421),
    [sym_preproc_define] = STATE(1421),
    [sym_preproc_undef] = STATE(1421),
    [aux_sym_class_declaration_repeat1] = STATE(3816),
    [aux_sym_lambda_expression_repeat1] = STATE(4225),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1573),
    [anon_sym_ref] = ACTIONS(1575),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1577),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1581),
    [anon_sym_TILDE] = ACTIONS(1581),
    [anon_sym_PLUS_PLUS] = ACTIONS(1581),
    [anon_sym_DASH_DASH] = ACTIONS(1581),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1579),
    [anon_sym_DASH] = ACTIONS(1579),
    [anon_sym_STAR] = ACTIONS(1583),
    [anon_sym_CARET] = ACTIONS(1581),
    [anon_sym_AMP] = ACTIONS(1581),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1585),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1587),
    [anon_sym_DOT_DOT] = ACTIONS(1589),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1422] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6913),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2905),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6979),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3932),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4178),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7433),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9183),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1422),
    [sym_preproc_endregion] = STATE(1422),
    [sym_preproc_line] = STATE(1422),
    [sym_preproc_pragma] = STATE(1422),
    [sym_preproc_nullable] = STATE(1422),
    [sym_preproc_error] = STATE(1422),
    [sym_preproc_warning] = STATE(1422),
    [sym_preproc_define] = STATE(1422),
    [sym_preproc_undef] = STATE(1422),
    [aux_sym_class_declaration_repeat1] = STATE(3816),
    [aux_sym_lambda_expression_repeat1] = STATE(4225),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1573),
    [anon_sym_ref] = ACTIONS(1575),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1577),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1581),
    [anon_sym_TILDE] = ACTIONS(1581),
    [anon_sym_PLUS_PLUS] = ACTIONS(1581),
    [anon_sym_DASH_DASH] = ACTIONS(1581),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1579),
    [anon_sym_DASH] = ACTIONS(1579),
    [anon_sym_STAR] = ACTIONS(1583),
    [anon_sym_CARET] = ACTIONS(1581),
    [anon_sym_AMP] = ACTIONS(1581),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1585),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1587),
    [anon_sym_DOT_DOT] = ACTIONS(1589),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1423] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6955),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2975),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6988),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5040),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3800),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7425),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9573),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1423),
    [sym_preproc_endregion] = STATE(1423),
    [sym_preproc_line] = STATE(1423),
    [sym_preproc_pragma] = STATE(1423),
    [sym_preproc_nullable] = STATE(1423),
    [sym_preproc_error] = STATE(1423),
    [sym_preproc_warning] = STATE(1423),
    [sym_preproc_define] = STATE(1423),
    [sym_preproc_undef] = STATE(1423),
    [aux_sym_class_declaration_repeat1] = STATE(3818),
    [aux_sym_lambda_expression_repeat1] = STATE(4229),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2259),
    [anon_sym_ref] = ACTIONS(2261),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1933),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2265),
    [anon_sym_TILDE] = ACTIONS(2265),
    [anon_sym_PLUS_PLUS] = ACTIONS(2265),
    [anon_sym_DASH_DASH] = ACTIONS(2265),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2263),
    [anon_sym_DASH] = ACTIONS(2263),
    [anon_sym_STAR] = ACTIONS(1939),
    [anon_sym_CARET] = ACTIONS(2265),
    [anon_sym_AMP] = ACTIONS(2265),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2267),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2269),
    [anon_sym_DOT_DOT] = ACTIONS(2271),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1424] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6955),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2975),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6988),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3567),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3800),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7425),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9573),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1424),
    [sym_preproc_endregion] = STATE(1424),
    [sym_preproc_line] = STATE(1424),
    [sym_preproc_pragma] = STATE(1424),
    [sym_preproc_nullable] = STATE(1424),
    [sym_preproc_error] = STATE(1424),
    [sym_preproc_warning] = STATE(1424),
    [sym_preproc_define] = STATE(1424),
    [sym_preproc_undef] = STATE(1424),
    [aux_sym_class_declaration_repeat1] = STATE(3818),
    [aux_sym_lambda_expression_repeat1] = STATE(4229),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2259),
    [anon_sym_ref] = ACTIONS(2261),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1933),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2265),
    [anon_sym_TILDE] = ACTIONS(2265),
    [anon_sym_PLUS_PLUS] = ACTIONS(2265),
    [anon_sym_DASH_DASH] = ACTIONS(2265),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2263),
    [anon_sym_DASH] = ACTIONS(2263),
    [anon_sym_STAR] = ACTIONS(1939),
    [anon_sym_CARET] = ACTIONS(2265),
    [anon_sym_AMP] = ACTIONS(2265),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2267),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2269),
    [anon_sym_DOT_DOT] = ACTIONS(2271),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1425] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6955),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2975),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6988),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5031),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3800),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7425),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9573),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1425),
    [sym_preproc_endregion] = STATE(1425),
    [sym_preproc_line] = STATE(1425),
    [sym_preproc_pragma] = STATE(1425),
    [sym_preproc_nullable] = STATE(1425),
    [sym_preproc_error] = STATE(1425),
    [sym_preproc_warning] = STATE(1425),
    [sym_preproc_define] = STATE(1425),
    [sym_preproc_undef] = STATE(1425),
    [aux_sym_class_declaration_repeat1] = STATE(3818),
    [aux_sym_lambda_expression_repeat1] = STATE(4229),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2259),
    [anon_sym_ref] = ACTIONS(2261),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1933),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2265),
    [anon_sym_TILDE] = ACTIONS(2265),
    [anon_sym_PLUS_PLUS] = ACTIONS(2265),
    [anon_sym_DASH_DASH] = ACTIONS(2265),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2263),
    [anon_sym_DASH] = ACTIONS(2263),
    [anon_sym_STAR] = ACTIONS(1939),
    [anon_sym_CARET] = ACTIONS(2265),
    [anon_sym_AMP] = ACTIONS(2265),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2267),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2269),
    [anon_sym_DOT_DOT] = ACTIONS(2271),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1426] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6167),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1426),
    [sym_preproc_endregion] = STATE(1426),
    [sym_preproc_line] = STATE(1426),
    [sym_preproc_pragma] = STATE(1426),
    [sym_preproc_nullable] = STATE(1426),
    [sym_preproc_error] = STATE(1426),
    [sym_preproc_warning] = STATE(1426),
    [sym_preproc_define] = STATE(1426),
    [sym_preproc_undef] = STATE(1426),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1427] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6941),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2977),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7077),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5656),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4200),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7415),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9773),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1427),
    [sym_preproc_endregion] = STATE(1427),
    [sym_preproc_line] = STATE(1427),
    [sym_preproc_pragma] = STATE(1427),
    [sym_preproc_nullable] = STATE(1427),
    [sym_preproc_error] = STATE(1427),
    [sym_preproc_warning] = STATE(1427),
    [sym_preproc_define] = STATE(1427),
    [sym_preproc_undef] = STATE(1427),
    [aux_sym_class_declaration_repeat1] = STATE(3843),
    [aux_sym_lambda_expression_repeat1] = STATE(4275),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1911),
    [anon_sym_ref] = ACTIONS(1913),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1915),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1919),
    [anon_sym_TILDE] = ACTIONS(1919),
    [anon_sym_PLUS_PLUS] = ACTIONS(1919),
    [anon_sym_DASH_DASH] = ACTIONS(1919),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1917),
    [anon_sym_DASH] = ACTIONS(1917),
    [anon_sym_STAR] = ACTIONS(1921),
    [anon_sym_CARET] = ACTIONS(1919),
    [anon_sym_AMP] = ACTIONS(1919),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1923),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1925),
    [anon_sym_DOT_DOT] = ACTIONS(1927),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1428] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6922),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2984),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7155),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6676),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4541),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7435),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9148),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1428),
    [sym_preproc_endregion] = STATE(1428),
    [sym_preproc_line] = STATE(1428),
    [sym_preproc_pragma] = STATE(1428),
    [sym_preproc_nullable] = STATE(1428),
    [sym_preproc_error] = STATE(1428),
    [sym_preproc_warning] = STATE(1428),
    [sym_preproc_define] = STATE(1428),
    [sym_preproc_undef] = STATE(1428),
    [aux_sym_class_declaration_repeat1] = STATE(3876),
    [aux_sym_lambda_expression_repeat1] = STATE(4317),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2231),
    [anon_sym_ref] = ACTIONS(2233),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2235),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2239),
    [anon_sym_TILDE] = ACTIONS(2239),
    [anon_sym_PLUS_PLUS] = ACTIONS(2239),
    [anon_sym_DASH_DASH] = ACTIONS(2239),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2237),
    [anon_sym_DASH] = ACTIONS(2237),
    [anon_sym_STAR] = ACTIONS(2241),
    [anon_sym_CARET] = ACTIONS(2239),
    [anon_sym_AMP] = ACTIONS(2239),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2243),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2245),
    [anon_sym_DOT_DOT] = ACTIONS(2247),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1429] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6955),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2975),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6988),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4996),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3800),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7425),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9573),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1429),
    [sym_preproc_endregion] = STATE(1429),
    [sym_preproc_line] = STATE(1429),
    [sym_preproc_pragma] = STATE(1429),
    [sym_preproc_nullable] = STATE(1429),
    [sym_preproc_error] = STATE(1429),
    [sym_preproc_warning] = STATE(1429),
    [sym_preproc_define] = STATE(1429),
    [sym_preproc_undef] = STATE(1429),
    [aux_sym_class_declaration_repeat1] = STATE(3818),
    [aux_sym_lambda_expression_repeat1] = STATE(4229),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2259),
    [anon_sym_ref] = ACTIONS(2261),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1933),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2265),
    [anon_sym_TILDE] = ACTIONS(2265),
    [anon_sym_PLUS_PLUS] = ACTIONS(2265),
    [anon_sym_DASH_DASH] = ACTIONS(2265),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2263),
    [anon_sym_DASH] = ACTIONS(2263),
    [anon_sym_STAR] = ACTIONS(1939),
    [anon_sym_CARET] = ACTIONS(2265),
    [anon_sym_AMP] = ACTIONS(2265),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2267),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2269),
    [anon_sym_DOT_DOT] = ACTIONS(2271),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1430] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6955),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2975),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6988),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5047),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3800),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7425),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9573),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1430),
    [sym_preproc_endregion] = STATE(1430),
    [sym_preproc_line] = STATE(1430),
    [sym_preproc_pragma] = STATE(1430),
    [sym_preproc_nullable] = STATE(1430),
    [sym_preproc_error] = STATE(1430),
    [sym_preproc_warning] = STATE(1430),
    [sym_preproc_define] = STATE(1430),
    [sym_preproc_undef] = STATE(1430),
    [aux_sym_class_declaration_repeat1] = STATE(3818),
    [aux_sym_lambda_expression_repeat1] = STATE(4229),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2259),
    [anon_sym_ref] = ACTIONS(2261),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1933),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2265),
    [anon_sym_TILDE] = ACTIONS(2265),
    [anon_sym_PLUS_PLUS] = ACTIONS(2265),
    [anon_sym_DASH_DASH] = ACTIONS(2265),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2263),
    [anon_sym_DASH] = ACTIONS(2263),
    [anon_sym_STAR] = ACTIONS(1939),
    [anon_sym_CARET] = ACTIONS(2265),
    [anon_sym_AMP] = ACTIONS(2265),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2267),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2269),
    [anon_sym_DOT_DOT] = ACTIONS(2271),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1431] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6955),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2975),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6988),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5006),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3800),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7425),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9573),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1431),
    [sym_preproc_endregion] = STATE(1431),
    [sym_preproc_line] = STATE(1431),
    [sym_preproc_pragma] = STATE(1431),
    [sym_preproc_nullable] = STATE(1431),
    [sym_preproc_error] = STATE(1431),
    [sym_preproc_warning] = STATE(1431),
    [sym_preproc_define] = STATE(1431),
    [sym_preproc_undef] = STATE(1431),
    [aux_sym_class_declaration_repeat1] = STATE(3818),
    [aux_sym_lambda_expression_repeat1] = STATE(4229),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2259),
    [anon_sym_ref] = ACTIONS(2261),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1933),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2265),
    [anon_sym_TILDE] = ACTIONS(2265),
    [anon_sym_PLUS_PLUS] = ACTIONS(2265),
    [anon_sym_DASH_DASH] = ACTIONS(2265),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2263),
    [anon_sym_DASH] = ACTIONS(2263),
    [anon_sym_STAR] = ACTIONS(1939),
    [anon_sym_CARET] = ACTIONS(2265),
    [anon_sym_AMP] = ACTIONS(2265),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2267),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2269),
    [anon_sym_DOT_DOT] = ACTIONS(2271),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1432] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6955),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2975),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6988),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5018),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3800),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7425),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9573),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1432),
    [sym_preproc_endregion] = STATE(1432),
    [sym_preproc_line] = STATE(1432),
    [sym_preproc_pragma] = STATE(1432),
    [sym_preproc_nullable] = STATE(1432),
    [sym_preproc_error] = STATE(1432),
    [sym_preproc_warning] = STATE(1432),
    [sym_preproc_define] = STATE(1432),
    [sym_preproc_undef] = STATE(1432),
    [aux_sym_class_declaration_repeat1] = STATE(3818),
    [aux_sym_lambda_expression_repeat1] = STATE(4229),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2259),
    [anon_sym_ref] = ACTIONS(2261),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1933),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2265),
    [anon_sym_TILDE] = ACTIONS(2265),
    [anon_sym_PLUS_PLUS] = ACTIONS(2265),
    [anon_sym_DASH_DASH] = ACTIONS(2265),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2263),
    [anon_sym_DASH] = ACTIONS(2263),
    [anon_sym_STAR] = ACTIONS(1939),
    [anon_sym_CARET] = ACTIONS(2265),
    [anon_sym_AMP] = ACTIONS(2265),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2267),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2269),
    [anon_sym_DOT_DOT] = ACTIONS(2271),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1433] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6955),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2975),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6988),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5041),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3800),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7425),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9573),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1433),
    [sym_preproc_endregion] = STATE(1433),
    [sym_preproc_line] = STATE(1433),
    [sym_preproc_pragma] = STATE(1433),
    [sym_preproc_nullable] = STATE(1433),
    [sym_preproc_error] = STATE(1433),
    [sym_preproc_warning] = STATE(1433),
    [sym_preproc_define] = STATE(1433),
    [sym_preproc_undef] = STATE(1433),
    [aux_sym_class_declaration_repeat1] = STATE(3818),
    [aux_sym_lambda_expression_repeat1] = STATE(4229),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2259),
    [anon_sym_ref] = ACTIONS(2261),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1933),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2265),
    [anon_sym_TILDE] = ACTIONS(2265),
    [anon_sym_PLUS_PLUS] = ACTIONS(2265),
    [anon_sym_DASH_DASH] = ACTIONS(2265),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2263),
    [anon_sym_DASH] = ACTIONS(2263),
    [anon_sym_STAR] = ACTIONS(1939),
    [anon_sym_CARET] = ACTIONS(2265),
    [anon_sym_AMP] = ACTIONS(2265),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2267),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2269),
    [anon_sym_DOT_DOT] = ACTIONS(2271),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1434] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6955),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2975),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6988),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5038),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3800),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7425),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9573),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1434),
    [sym_preproc_endregion] = STATE(1434),
    [sym_preproc_line] = STATE(1434),
    [sym_preproc_pragma] = STATE(1434),
    [sym_preproc_nullable] = STATE(1434),
    [sym_preproc_error] = STATE(1434),
    [sym_preproc_warning] = STATE(1434),
    [sym_preproc_define] = STATE(1434),
    [sym_preproc_undef] = STATE(1434),
    [aux_sym_class_declaration_repeat1] = STATE(3818),
    [aux_sym_lambda_expression_repeat1] = STATE(4229),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2259),
    [anon_sym_ref] = ACTIONS(2261),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1933),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2265),
    [anon_sym_TILDE] = ACTIONS(2265),
    [anon_sym_PLUS_PLUS] = ACTIONS(2265),
    [anon_sym_DASH_DASH] = ACTIONS(2265),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2263),
    [anon_sym_DASH] = ACTIONS(2263),
    [anon_sym_STAR] = ACTIONS(1939),
    [anon_sym_CARET] = ACTIONS(2265),
    [anon_sym_AMP] = ACTIONS(2265),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2267),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2269),
    [anon_sym_DOT_DOT] = ACTIONS(2271),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1435] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6955),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2975),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6988),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4991),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3800),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7425),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9573),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1435),
    [sym_preproc_endregion] = STATE(1435),
    [sym_preproc_line] = STATE(1435),
    [sym_preproc_pragma] = STATE(1435),
    [sym_preproc_nullable] = STATE(1435),
    [sym_preproc_error] = STATE(1435),
    [sym_preproc_warning] = STATE(1435),
    [sym_preproc_define] = STATE(1435),
    [sym_preproc_undef] = STATE(1435),
    [aux_sym_class_declaration_repeat1] = STATE(3818),
    [aux_sym_lambda_expression_repeat1] = STATE(4229),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2259),
    [anon_sym_ref] = ACTIONS(2261),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1933),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2265),
    [anon_sym_TILDE] = ACTIONS(2265),
    [anon_sym_PLUS_PLUS] = ACTIONS(2265),
    [anon_sym_DASH_DASH] = ACTIONS(2265),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2263),
    [anon_sym_DASH] = ACTIONS(2263),
    [anon_sym_STAR] = ACTIONS(1939),
    [anon_sym_CARET] = ACTIONS(2265),
    [anon_sym_AMP] = ACTIONS(2265),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2267),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2269),
    [anon_sym_DOT_DOT] = ACTIONS(2271),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1436] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6955),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2975),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6988),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5008),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3800),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7425),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9573),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1436),
    [sym_preproc_endregion] = STATE(1436),
    [sym_preproc_line] = STATE(1436),
    [sym_preproc_pragma] = STATE(1436),
    [sym_preproc_nullable] = STATE(1436),
    [sym_preproc_error] = STATE(1436),
    [sym_preproc_warning] = STATE(1436),
    [sym_preproc_define] = STATE(1436),
    [sym_preproc_undef] = STATE(1436),
    [aux_sym_class_declaration_repeat1] = STATE(3818),
    [aux_sym_lambda_expression_repeat1] = STATE(4229),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2259),
    [anon_sym_ref] = ACTIONS(2261),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1933),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2265),
    [anon_sym_TILDE] = ACTIONS(2265),
    [anon_sym_PLUS_PLUS] = ACTIONS(2265),
    [anon_sym_DASH_DASH] = ACTIONS(2265),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2263),
    [anon_sym_DASH] = ACTIONS(2263),
    [anon_sym_STAR] = ACTIONS(1939),
    [anon_sym_CARET] = ACTIONS(2265),
    [anon_sym_AMP] = ACTIONS(2265),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2267),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2269),
    [anon_sym_DOT_DOT] = ACTIONS(2271),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1437] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6955),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2975),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6988),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5013),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3800),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7425),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9573),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1437),
    [sym_preproc_endregion] = STATE(1437),
    [sym_preproc_line] = STATE(1437),
    [sym_preproc_pragma] = STATE(1437),
    [sym_preproc_nullable] = STATE(1437),
    [sym_preproc_error] = STATE(1437),
    [sym_preproc_warning] = STATE(1437),
    [sym_preproc_define] = STATE(1437),
    [sym_preproc_undef] = STATE(1437),
    [aux_sym_class_declaration_repeat1] = STATE(3818),
    [aux_sym_lambda_expression_repeat1] = STATE(4229),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2259),
    [anon_sym_ref] = ACTIONS(2261),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1933),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2265),
    [anon_sym_TILDE] = ACTIONS(2265),
    [anon_sym_PLUS_PLUS] = ACTIONS(2265),
    [anon_sym_DASH_DASH] = ACTIONS(2265),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2263),
    [anon_sym_DASH] = ACTIONS(2263),
    [anon_sym_STAR] = ACTIONS(1939),
    [anon_sym_CARET] = ACTIONS(2265),
    [anon_sym_AMP] = ACTIONS(2265),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2267),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2269),
    [anon_sym_DOT_DOT] = ACTIONS(2271),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1438] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6955),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2975),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6988),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4994),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3800),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7425),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9573),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1438),
    [sym_preproc_endregion] = STATE(1438),
    [sym_preproc_line] = STATE(1438),
    [sym_preproc_pragma] = STATE(1438),
    [sym_preproc_nullable] = STATE(1438),
    [sym_preproc_error] = STATE(1438),
    [sym_preproc_warning] = STATE(1438),
    [sym_preproc_define] = STATE(1438),
    [sym_preproc_undef] = STATE(1438),
    [aux_sym_class_declaration_repeat1] = STATE(3818),
    [aux_sym_lambda_expression_repeat1] = STATE(4229),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2259),
    [anon_sym_ref] = ACTIONS(2261),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1933),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2265),
    [anon_sym_TILDE] = ACTIONS(2265),
    [anon_sym_PLUS_PLUS] = ACTIONS(2265),
    [anon_sym_DASH_DASH] = ACTIONS(2265),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2263),
    [anon_sym_DASH] = ACTIONS(2263),
    [anon_sym_STAR] = ACTIONS(1939),
    [anon_sym_CARET] = ACTIONS(2265),
    [anon_sym_AMP] = ACTIONS(2265),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2267),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2269),
    [anon_sym_DOT_DOT] = ACTIONS(2271),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1439] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6955),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2975),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6988),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5017),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3800),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7425),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9573),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1439),
    [sym_preproc_endregion] = STATE(1439),
    [sym_preproc_line] = STATE(1439),
    [sym_preproc_pragma] = STATE(1439),
    [sym_preproc_nullable] = STATE(1439),
    [sym_preproc_error] = STATE(1439),
    [sym_preproc_warning] = STATE(1439),
    [sym_preproc_define] = STATE(1439),
    [sym_preproc_undef] = STATE(1439),
    [aux_sym_class_declaration_repeat1] = STATE(3818),
    [aux_sym_lambda_expression_repeat1] = STATE(4229),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2259),
    [anon_sym_ref] = ACTIONS(2261),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1933),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2265),
    [anon_sym_TILDE] = ACTIONS(2265),
    [anon_sym_PLUS_PLUS] = ACTIONS(2265),
    [anon_sym_DASH_DASH] = ACTIONS(2265),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2263),
    [anon_sym_DASH] = ACTIONS(2263),
    [anon_sym_STAR] = ACTIONS(1939),
    [anon_sym_CARET] = ACTIONS(2265),
    [anon_sym_AMP] = ACTIONS(2265),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2267),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2269),
    [anon_sym_DOT_DOT] = ACTIONS(2271),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1440] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6955),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2975),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6988),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5015),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3800),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7425),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9573),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1440),
    [sym_preproc_endregion] = STATE(1440),
    [sym_preproc_line] = STATE(1440),
    [sym_preproc_pragma] = STATE(1440),
    [sym_preproc_nullable] = STATE(1440),
    [sym_preproc_error] = STATE(1440),
    [sym_preproc_warning] = STATE(1440),
    [sym_preproc_define] = STATE(1440),
    [sym_preproc_undef] = STATE(1440),
    [aux_sym_class_declaration_repeat1] = STATE(3818),
    [aux_sym_lambda_expression_repeat1] = STATE(4229),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2259),
    [anon_sym_ref] = ACTIONS(2261),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1933),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2265),
    [anon_sym_TILDE] = ACTIONS(2265),
    [anon_sym_PLUS_PLUS] = ACTIONS(2265),
    [anon_sym_DASH_DASH] = ACTIONS(2265),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2263),
    [anon_sym_DASH] = ACTIONS(2263),
    [anon_sym_STAR] = ACTIONS(1939),
    [anon_sym_CARET] = ACTIONS(2265),
    [anon_sym_AMP] = ACTIONS(2265),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2267),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2269),
    [anon_sym_DOT_DOT] = ACTIONS(2271),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1441] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6955),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2975),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6988),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3582),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3800),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7425),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9573),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1441),
    [sym_preproc_endregion] = STATE(1441),
    [sym_preproc_line] = STATE(1441),
    [sym_preproc_pragma] = STATE(1441),
    [sym_preproc_nullable] = STATE(1441),
    [sym_preproc_error] = STATE(1441),
    [sym_preproc_warning] = STATE(1441),
    [sym_preproc_define] = STATE(1441),
    [sym_preproc_undef] = STATE(1441),
    [aux_sym_class_declaration_repeat1] = STATE(3818),
    [aux_sym_lambda_expression_repeat1] = STATE(4229),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2259),
    [anon_sym_ref] = ACTIONS(2261),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1933),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2265),
    [anon_sym_TILDE] = ACTIONS(2265),
    [anon_sym_PLUS_PLUS] = ACTIONS(2265),
    [anon_sym_DASH_DASH] = ACTIONS(2265),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2263),
    [anon_sym_DASH] = ACTIONS(2263),
    [anon_sym_STAR] = ACTIONS(1939),
    [anon_sym_CARET] = ACTIONS(2265),
    [anon_sym_AMP] = ACTIONS(2265),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2267),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2269),
    [anon_sym_DOT_DOT] = ACTIONS(2271),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1442] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6913),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2905),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6979),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5440),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4178),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7433),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9183),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1442),
    [sym_preproc_endregion] = STATE(1442),
    [sym_preproc_line] = STATE(1442),
    [sym_preproc_pragma] = STATE(1442),
    [sym_preproc_nullable] = STATE(1442),
    [sym_preproc_error] = STATE(1442),
    [sym_preproc_warning] = STATE(1442),
    [sym_preproc_define] = STATE(1442),
    [sym_preproc_undef] = STATE(1442),
    [aux_sym_class_declaration_repeat1] = STATE(3816),
    [aux_sym_lambda_expression_repeat1] = STATE(4225),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1573),
    [anon_sym_ref] = ACTIONS(1575),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1577),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1581),
    [anon_sym_TILDE] = ACTIONS(1581),
    [anon_sym_PLUS_PLUS] = ACTIONS(1581),
    [anon_sym_DASH_DASH] = ACTIONS(1581),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1579),
    [anon_sym_DASH] = ACTIONS(1579),
    [anon_sym_STAR] = ACTIONS(1583),
    [anon_sym_CARET] = ACTIONS(1581),
    [anon_sym_AMP] = ACTIONS(1581),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1585),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1587),
    [anon_sym_DOT_DOT] = ACTIONS(1589),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1443] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6913),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2905),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6979),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3926),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4178),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7433),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9183),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1443),
    [sym_preproc_endregion] = STATE(1443),
    [sym_preproc_line] = STATE(1443),
    [sym_preproc_pragma] = STATE(1443),
    [sym_preproc_nullable] = STATE(1443),
    [sym_preproc_error] = STATE(1443),
    [sym_preproc_warning] = STATE(1443),
    [sym_preproc_define] = STATE(1443),
    [sym_preproc_undef] = STATE(1443),
    [aux_sym_class_declaration_repeat1] = STATE(3816),
    [aux_sym_lambda_expression_repeat1] = STATE(4225),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1573),
    [anon_sym_ref] = ACTIONS(1575),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1577),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1581),
    [anon_sym_TILDE] = ACTIONS(1581),
    [anon_sym_PLUS_PLUS] = ACTIONS(1581),
    [anon_sym_DASH_DASH] = ACTIONS(1581),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1579),
    [anon_sym_DASH] = ACTIONS(1579),
    [anon_sym_STAR] = ACTIONS(1583),
    [anon_sym_CARET] = ACTIONS(1581),
    [anon_sym_AMP] = ACTIONS(1581),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1585),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1587),
    [anon_sym_DOT_DOT] = ACTIONS(1589),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1444] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6913),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2905),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6979),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5449),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4178),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7433),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9183),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1444),
    [sym_preproc_endregion] = STATE(1444),
    [sym_preproc_line] = STATE(1444),
    [sym_preproc_pragma] = STATE(1444),
    [sym_preproc_nullable] = STATE(1444),
    [sym_preproc_error] = STATE(1444),
    [sym_preproc_warning] = STATE(1444),
    [sym_preproc_define] = STATE(1444),
    [sym_preproc_undef] = STATE(1444),
    [aux_sym_class_declaration_repeat1] = STATE(3816),
    [aux_sym_lambda_expression_repeat1] = STATE(4225),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1573),
    [anon_sym_ref] = ACTIONS(1575),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1577),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1581),
    [anon_sym_TILDE] = ACTIONS(1581),
    [anon_sym_PLUS_PLUS] = ACTIONS(1581),
    [anon_sym_DASH_DASH] = ACTIONS(1581),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1579),
    [anon_sym_DASH] = ACTIONS(1579),
    [anon_sym_STAR] = ACTIONS(1583),
    [anon_sym_CARET] = ACTIONS(1581),
    [anon_sym_AMP] = ACTIONS(1581),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1585),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1587),
    [anon_sym_DOT_DOT] = ACTIONS(1589),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1445] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6913),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2905),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6979),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5454),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4178),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7433),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9183),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1445),
    [sym_preproc_endregion] = STATE(1445),
    [sym_preproc_line] = STATE(1445),
    [sym_preproc_pragma] = STATE(1445),
    [sym_preproc_nullable] = STATE(1445),
    [sym_preproc_error] = STATE(1445),
    [sym_preproc_warning] = STATE(1445),
    [sym_preproc_define] = STATE(1445),
    [sym_preproc_undef] = STATE(1445),
    [aux_sym_class_declaration_repeat1] = STATE(3816),
    [aux_sym_lambda_expression_repeat1] = STATE(4225),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1573),
    [anon_sym_ref] = ACTIONS(1575),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1577),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1581),
    [anon_sym_TILDE] = ACTIONS(1581),
    [anon_sym_PLUS_PLUS] = ACTIONS(1581),
    [anon_sym_DASH_DASH] = ACTIONS(1581),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1579),
    [anon_sym_DASH] = ACTIONS(1579),
    [anon_sym_STAR] = ACTIONS(1583),
    [anon_sym_CARET] = ACTIONS(1581),
    [anon_sym_AMP] = ACTIONS(1581),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1585),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1587),
    [anon_sym_DOT_DOT] = ACTIONS(1589),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1446] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6950),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7044),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5108),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3868),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7432),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9127),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1446),
    [sym_preproc_endregion] = STATE(1446),
    [sym_preproc_line] = STATE(1446),
    [sym_preproc_pragma] = STATE(1446),
    [sym_preproc_nullable] = STATE(1446),
    [sym_preproc_error] = STATE(1446),
    [sym_preproc_warning] = STATE(1446),
    [sym_preproc_define] = STATE(1446),
    [sym_preproc_undef] = STATE(1446),
    [aux_sym_class_declaration_repeat1] = STATE(3832),
    [aux_sym_lambda_expression_repeat1] = STATE(4259),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1357),
    [anon_sym_ref] = ACTIONS(1359),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1363),
    [anon_sym_TILDE] = ACTIONS(1363),
    [anon_sym_PLUS_PLUS] = ACTIONS(1363),
    [anon_sym_DASH_DASH] = ACTIONS(1363),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1361),
    [anon_sym_DASH] = ACTIONS(1361),
    [anon_sym_STAR] = ACTIONS(1365),
    [anon_sym_CARET] = ACTIONS(1363),
    [anon_sym_AMP] = ACTIONS(1363),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1367),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1369),
    [anon_sym_DOT_DOT] = ACTIONS(1371),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1447] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6950),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7044),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3838),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3868),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7432),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9127),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1447),
    [sym_preproc_endregion] = STATE(1447),
    [sym_preproc_line] = STATE(1447),
    [sym_preproc_pragma] = STATE(1447),
    [sym_preproc_nullable] = STATE(1447),
    [sym_preproc_error] = STATE(1447),
    [sym_preproc_warning] = STATE(1447),
    [sym_preproc_define] = STATE(1447),
    [sym_preproc_undef] = STATE(1447),
    [aux_sym_class_declaration_repeat1] = STATE(3832),
    [aux_sym_lambda_expression_repeat1] = STATE(4259),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1357),
    [anon_sym_ref] = ACTIONS(1359),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1363),
    [anon_sym_TILDE] = ACTIONS(1363),
    [anon_sym_PLUS_PLUS] = ACTIONS(1363),
    [anon_sym_DASH_DASH] = ACTIONS(1363),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1361),
    [anon_sym_DASH] = ACTIONS(1361),
    [anon_sym_STAR] = ACTIONS(1365),
    [anon_sym_CARET] = ACTIONS(1363),
    [anon_sym_AMP] = ACTIONS(1363),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1367),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1369),
    [anon_sym_DOT_DOT] = ACTIONS(1371),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1448] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6912),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2912),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7040),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5324),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3963),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7448),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9641),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1448),
    [sym_preproc_endregion] = STATE(1448),
    [sym_preproc_line] = STATE(1448),
    [sym_preproc_pragma] = STATE(1448),
    [sym_preproc_nullable] = STATE(1448),
    [sym_preproc_error] = STATE(1448),
    [sym_preproc_warning] = STATE(1448),
    [sym_preproc_define] = STATE(1448),
    [sym_preproc_undef] = STATE(1448),
    [aux_sym_class_declaration_repeat1] = STATE(3831),
    [aux_sym_lambda_expression_repeat1] = STATE(4257),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1785),
    [anon_sym_ref] = ACTIONS(1787),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1595),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1791),
    [anon_sym_TILDE] = ACTIONS(1791),
    [anon_sym_PLUS_PLUS] = ACTIONS(1791),
    [anon_sym_DASH_DASH] = ACTIONS(1791),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1789),
    [anon_sym_DASH] = ACTIONS(1789),
    [anon_sym_STAR] = ACTIONS(1793),
    [anon_sym_CARET] = ACTIONS(1791),
    [anon_sym_AMP] = ACTIONS(1791),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1795),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1797),
    [anon_sym_DOT_DOT] = ACTIONS(1799),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1449] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6912),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2912),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7040),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5280),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3963),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7448),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9641),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1449),
    [sym_preproc_endregion] = STATE(1449),
    [sym_preproc_line] = STATE(1449),
    [sym_preproc_pragma] = STATE(1449),
    [sym_preproc_nullable] = STATE(1449),
    [sym_preproc_error] = STATE(1449),
    [sym_preproc_warning] = STATE(1449),
    [sym_preproc_define] = STATE(1449),
    [sym_preproc_undef] = STATE(1449),
    [aux_sym_class_declaration_repeat1] = STATE(3831),
    [aux_sym_lambda_expression_repeat1] = STATE(4257),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1785),
    [anon_sym_ref] = ACTIONS(1787),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1595),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1791),
    [anon_sym_TILDE] = ACTIONS(1791),
    [anon_sym_PLUS_PLUS] = ACTIONS(1791),
    [anon_sym_DASH_DASH] = ACTIONS(1791),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1789),
    [anon_sym_DASH] = ACTIONS(1789),
    [anon_sym_STAR] = ACTIONS(1793),
    [anon_sym_CARET] = ACTIONS(1791),
    [anon_sym_AMP] = ACTIONS(1791),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1795),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1797),
    [anon_sym_DOT_DOT] = ACTIONS(1799),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1450] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6912),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2912),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7040),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5376),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3963),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7448),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9641),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1450),
    [sym_preproc_endregion] = STATE(1450),
    [sym_preproc_line] = STATE(1450),
    [sym_preproc_pragma] = STATE(1450),
    [sym_preproc_nullable] = STATE(1450),
    [sym_preproc_error] = STATE(1450),
    [sym_preproc_warning] = STATE(1450),
    [sym_preproc_define] = STATE(1450),
    [sym_preproc_undef] = STATE(1450),
    [aux_sym_class_declaration_repeat1] = STATE(3831),
    [aux_sym_lambda_expression_repeat1] = STATE(4257),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1785),
    [anon_sym_ref] = ACTIONS(1787),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1595),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1791),
    [anon_sym_TILDE] = ACTIONS(1791),
    [anon_sym_PLUS_PLUS] = ACTIONS(1791),
    [anon_sym_DASH_DASH] = ACTIONS(1791),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1789),
    [anon_sym_DASH] = ACTIONS(1789),
    [anon_sym_STAR] = ACTIONS(1793),
    [anon_sym_CARET] = ACTIONS(1791),
    [anon_sym_AMP] = ACTIONS(1791),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1795),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1797),
    [anon_sym_DOT_DOT] = ACTIONS(1799),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1451] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6912),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2912),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7040),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5331),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3963),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7448),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9641),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1451),
    [sym_preproc_endregion] = STATE(1451),
    [sym_preproc_line] = STATE(1451),
    [sym_preproc_pragma] = STATE(1451),
    [sym_preproc_nullable] = STATE(1451),
    [sym_preproc_error] = STATE(1451),
    [sym_preproc_warning] = STATE(1451),
    [sym_preproc_define] = STATE(1451),
    [sym_preproc_undef] = STATE(1451),
    [aux_sym_class_declaration_repeat1] = STATE(3831),
    [aux_sym_lambda_expression_repeat1] = STATE(4257),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1785),
    [anon_sym_ref] = ACTIONS(1787),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1595),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1791),
    [anon_sym_TILDE] = ACTIONS(1791),
    [anon_sym_PLUS_PLUS] = ACTIONS(1791),
    [anon_sym_DASH_DASH] = ACTIONS(1791),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1789),
    [anon_sym_DASH] = ACTIONS(1789),
    [anon_sym_STAR] = ACTIONS(1793),
    [anon_sym_CARET] = ACTIONS(1791),
    [anon_sym_AMP] = ACTIONS(1791),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1795),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1797),
    [anon_sym_DOT_DOT] = ACTIONS(1799),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1452] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6912),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2912),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7040),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5404),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3963),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7448),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9641),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1452),
    [sym_preproc_endregion] = STATE(1452),
    [sym_preproc_line] = STATE(1452),
    [sym_preproc_pragma] = STATE(1452),
    [sym_preproc_nullable] = STATE(1452),
    [sym_preproc_error] = STATE(1452),
    [sym_preproc_warning] = STATE(1452),
    [sym_preproc_define] = STATE(1452),
    [sym_preproc_undef] = STATE(1452),
    [aux_sym_class_declaration_repeat1] = STATE(3831),
    [aux_sym_lambda_expression_repeat1] = STATE(4257),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1785),
    [anon_sym_ref] = ACTIONS(1787),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1595),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1791),
    [anon_sym_TILDE] = ACTIONS(1791),
    [anon_sym_PLUS_PLUS] = ACTIONS(1791),
    [anon_sym_DASH_DASH] = ACTIONS(1791),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1789),
    [anon_sym_DASH] = ACTIONS(1789),
    [anon_sym_STAR] = ACTIONS(1793),
    [anon_sym_CARET] = ACTIONS(1791),
    [anon_sym_AMP] = ACTIONS(1791),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1795),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1797),
    [anon_sym_DOT_DOT] = ACTIONS(1799),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1453] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6912),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2912),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7040),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5393),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3963),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7448),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9641),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1453),
    [sym_preproc_endregion] = STATE(1453),
    [sym_preproc_line] = STATE(1453),
    [sym_preproc_pragma] = STATE(1453),
    [sym_preproc_nullable] = STATE(1453),
    [sym_preproc_error] = STATE(1453),
    [sym_preproc_warning] = STATE(1453),
    [sym_preproc_define] = STATE(1453),
    [sym_preproc_undef] = STATE(1453),
    [aux_sym_class_declaration_repeat1] = STATE(3831),
    [aux_sym_lambda_expression_repeat1] = STATE(4257),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1785),
    [anon_sym_ref] = ACTIONS(1787),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1595),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1791),
    [anon_sym_TILDE] = ACTIONS(1791),
    [anon_sym_PLUS_PLUS] = ACTIONS(1791),
    [anon_sym_DASH_DASH] = ACTIONS(1791),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1789),
    [anon_sym_DASH] = ACTIONS(1789),
    [anon_sym_STAR] = ACTIONS(1793),
    [anon_sym_CARET] = ACTIONS(1791),
    [anon_sym_AMP] = ACTIONS(1791),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1795),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1797),
    [anon_sym_DOT_DOT] = ACTIONS(1799),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1454] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6912),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2912),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7040),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5274),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3963),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7448),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9641),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1454),
    [sym_preproc_endregion] = STATE(1454),
    [sym_preproc_line] = STATE(1454),
    [sym_preproc_pragma] = STATE(1454),
    [sym_preproc_nullable] = STATE(1454),
    [sym_preproc_error] = STATE(1454),
    [sym_preproc_warning] = STATE(1454),
    [sym_preproc_define] = STATE(1454),
    [sym_preproc_undef] = STATE(1454),
    [aux_sym_class_declaration_repeat1] = STATE(3831),
    [aux_sym_lambda_expression_repeat1] = STATE(4257),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1785),
    [anon_sym_ref] = ACTIONS(1787),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1595),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1791),
    [anon_sym_TILDE] = ACTIONS(1791),
    [anon_sym_PLUS_PLUS] = ACTIONS(1791),
    [anon_sym_DASH_DASH] = ACTIONS(1791),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1789),
    [anon_sym_DASH] = ACTIONS(1789),
    [anon_sym_STAR] = ACTIONS(1793),
    [anon_sym_CARET] = ACTIONS(1791),
    [anon_sym_AMP] = ACTIONS(1791),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1795),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1797),
    [anon_sym_DOT_DOT] = ACTIONS(1799),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1455] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6912),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2912),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7040),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5394),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3963),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7448),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9641),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1455),
    [sym_preproc_endregion] = STATE(1455),
    [sym_preproc_line] = STATE(1455),
    [sym_preproc_pragma] = STATE(1455),
    [sym_preproc_nullable] = STATE(1455),
    [sym_preproc_error] = STATE(1455),
    [sym_preproc_warning] = STATE(1455),
    [sym_preproc_define] = STATE(1455),
    [sym_preproc_undef] = STATE(1455),
    [aux_sym_class_declaration_repeat1] = STATE(3831),
    [aux_sym_lambda_expression_repeat1] = STATE(4257),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1785),
    [anon_sym_ref] = ACTIONS(1787),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1595),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1791),
    [anon_sym_TILDE] = ACTIONS(1791),
    [anon_sym_PLUS_PLUS] = ACTIONS(1791),
    [anon_sym_DASH_DASH] = ACTIONS(1791),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1789),
    [anon_sym_DASH] = ACTIONS(1789),
    [anon_sym_STAR] = ACTIONS(1793),
    [anon_sym_CARET] = ACTIONS(1791),
    [anon_sym_AMP] = ACTIONS(1791),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1795),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1797),
    [anon_sym_DOT_DOT] = ACTIONS(1799),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1456] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6912),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2912),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7040),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5322),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3963),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7448),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9641),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1456),
    [sym_preproc_endregion] = STATE(1456),
    [sym_preproc_line] = STATE(1456),
    [sym_preproc_pragma] = STATE(1456),
    [sym_preproc_nullable] = STATE(1456),
    [sym_preproc_error] = STATE(1456),
    [sym_preproc_warning] = STATE(1456),
    [sym_preproc_define] = STATE(1456),
    [sym_preproc_undef] = STATE(1456),
    [aux_sym_class_declaration_repeat1] = STATE(3831),
    [aux_sym_lambda_expression_repeat1] = STATE(4257),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1785),
    [anon_sym_ref] = ACTIONS(1787),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1595),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1791),
    [anon_sym_TILDE] = ACTIONS(1791),
    [anon_sym_PLUS_PLUS] = ACTIONS(1791),
    [anon_sym_DASH_DASH] = ACTIONS(1791),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1789),
    [anon_sym_DASH] = ACTIONS(1789),
    [anon_sym_STAR] = ACTIONS(1793),
    [anon_sym_CARET] = ACTIONS(1791),
    [anon_sym_AMP] = ACTIONS(1791),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1795),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1797),
    [anon_sym_DOT_DOT] = ACTIONS(1799),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1457] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6912),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2912),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7040),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5382),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3963),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7448),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9641),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1457),
    [sym_preproc_endregion] = STATE(1457),
    [sym_preproc_line] = STATE(1457),
    [sym_preproc_pragma] = STATE(1457),
    [sym_preproc_nullable] = STATE(1457),
    [sym_preproc_error] = STATE(1457),
    [sym_preproc_warning] = STATE(1457),
    [sym_preproc_define] = STATE(1457),
    [sym_preproc_undef] = STATE(1457),
    [aux_sym_class_declaration_repeat1] = STATE(3831),
    [aux_sym_lambda_expression_repeat1] = STATE(4257),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1785),
    [anon_sym_ref] = ACTIONS(1787),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1595),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1791),
    [anon_sym_TILDE] = ACTIONS(1791),
    [anon_sym_PLUS_PLUS] = ACTIONS(1791),
    [anon_sym_DASH_DASH] = ACTIONS(1791),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1789),
    [anon_sym_DASH] = ACTIONS(1789),
    [anon_sym_STAR] = ACTIONS(1793),
    [anon_sym_CARET] = ACTIONS(1791),
    [anon_sym_AMP] = ACTIONS(1791),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1795),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1797),
    [anon_sym_DOT_DOT] = ACTIONS(1799),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1458] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6912),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2912),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7040),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5403),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3963),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7448),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9641),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1458),
    [sym_preproc_endregion] = STATE(1458),
    [sym_preproc_line] = STATE(1458),
    [sym_preproc_pragma] = STATE(1458),
    [sym_preproc_nullable] = STATE(1458),
    [sym_preproc_error] = STATE(1458),
    [sym_preproc_warning] = STATE(1458),
    [sym_preproc_define] = STATE(1458),
    [sym_preproc_undef] = STATE(1458),
    [aux_sym_class_declaration_repeat1] = STATE(3831),
    [aux_sym_lambda_expression_repeat1] = STATE(4257),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1785),
    [anon_sym_ref] = ACTIONS(1787),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1595),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1791),
    [anon_sym_TILDE] = ACTIONS(1791),
    [anon_sym_PLUS_PLUS] = ACTIONS(1791),
    [anon_sym_DASH_DASH] = ACTIONS(1791),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1789),
    [anon_sym_DASH] = ACTIONS(1789),
    [anon_sym_STAR] = ACTIONS(1793),
    [anon_sym_CARET] = ACTIONS(1791),
    [anon_sym_AMP] = ACTIONS(1791),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1795),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1797),
    [anon_sym_DOT_DOT] = ACTIONS(1799),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1459] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6950),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7044),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5123),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3868),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7432),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9127),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1459),
    [sym_preproc_endregion] = STATE(1459),
    [sym_preproc_line] = STATE(1459),
    [sym_preproc_pragma] = STATE(1459),
    [sym_preproc_nullable] = STATE(1459),
    [sym_preproc_error] = STATE(1459),
    [sym_preproc_warning] = STATE(1459),
    [sym_preproc_define] = STATE(1459),
    [sym_preproc_undef] = STATE(1459),
    [aux_sym_class_declaration_repeat1] = STATE(3832),
    [aux_sym_lambda_expression_repeat1] = STATE(4259),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1357),
    [anon_sym_ref] = ACTIONS(1359),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1363),
    [anon_sym_TILDE] = ACTIONS(1363),
    [anon_sym_PLUS_PLUS] = ACTIONS(1363),
    [anon_sym_DASH_DASH] = ACTIONS(1363),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1361),
    [anon_sym_DASH] = ACTIONS(1361),
    [anon_sym_STAR] = ACTIONS(1365),
    [anon_sym_CARET] = ACTIONS(1363),
    [anon_sym_AMP] = ACTIONS(1363),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1367),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1369),
    [anon_sym_DOT_DOT] = ACTIONS(1371),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1460] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5935),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1460),
    [sym_preproc_endregion] = STATE(1460),
    [sym_preproc_line] = STATE(1460),
    [sym_preproc_pragma] = STATE(1460),
    [sym_preproc_nullable] = STATE(1460),
    [sym_preproc_error] = STATE(1460),
    [sym_preproc_warning] = STATE(1460),
    [sym_preproc_define] = STATE(1460),
    [sym_preproc_undef] = STATE(1460),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1461] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6912),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2912),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7040),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3867),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3963),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7448),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9641),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1461),
    [sym_preproc_endregion] = STATE(1461),
    [sym_preproc_line] = STATE(1461),
    [sym_preproc_pragma] = STATE(1461),
    [sym_preproc_nullable] = STATE(1461),
    [sym_preproc_error] = STATE(1461),
    [sym_preproc_warning] = STATE(1461),
    [sym_preproc_define] = STATE(1461),
    [sym_preproc_undef] = STATE(1461),
    [aux_sym_class_declaration_repeat1] = STATE(3831),
    [aux_sym_lambda_expression_repeat1] = STATE(4257),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1785),
    [anon_sym_ref] = ACTIONS(1787),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1595),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1791),
    [anon_sym_TILDE] = ACTIONS(1791),
    [anon_sym_PLUS_PLUS] = ACTIONS(1791),
    [anon_sym_DASH_DASH] = ACTIONS(1791),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1789),
    [anon_sym_DASH] = ACTIONS(1789),
    [anon_sym_STAR] = ACTIONS(1793),
    [anon_sym_CARET] = ACTIONS(1791),
    [anon_sym_AMP] = ACTIONS(1791),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1795),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1797),
    [anon_sym_DOT_DOT] = ACTIONS(1799),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1462] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6950),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7044),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5130),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3868),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7432),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9127),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1462),
    [sym_preproc_endregion] = STATE(1462),
    [sym_preproc_line] = STATE(1462),
    [sym_preproc_pragma] = STATE(1462),
    [sym_preproc_nullable] = STATE(1462),
    [sym_preproc_error] = STATE(1462),
    [sym_preproc_warning] = STATE(1462),
    [sym_preproc_define] = STATE(1462),
    [sym_preproc_undef] = STATE(1462),
    [aux_sym_class_declaration_repeat1] = STATE(3832),
    [aux_sym_lambda_expression_repeat1] = STATE(4259),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1357),
    [anon_sym_ref] = ACTIONS(1359),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1363),
    [anon_sym_TILDE] = ACTIONS(1363),
    [anon_sym_PLUS_PLUS] = ACTIONS(1363),
    [anon_sym_DASH_DASH] = ACTIONS(1363),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1361),
    [anon_sym_DASH] = ACTIONS(1361),
    [anon_sym_STAR] = ACTIONS(1365),
    [anon_sym_CARET] = ACTIONS(1363),
    [anon_sym_AMP] = ACTIONS(1363),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1367),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1369),
    [anon_sym_DOT_DOT] = ACTIONS(1371),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1463] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6962),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3917),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3931),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9818),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1463),
    [sym_preproc_endregion] = STATE(1463),
    [sym_preproc_line] = STATE(1463),
    [sym_preproc_pragma] = STATE(1463),
    [sym_preproc_nullable] = STATE(1463),
    [sym_preproc_error] = STATE(1463),
    [sym_preproc_warning] = STATE(1463),
    [sym_preproc_define] = STATE(1463),
    [sym_preproc_undef] = STATE(1463),
    [aux_sym_class_declaration_repeat1] = STATE(3811),
    [aux_sym_lambda_expression_repeat1] = STATE(4201),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1373),
    [anon_sym_ref] = ACTIONS(1375),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1379),
    [anon_sym_TILDE] = ACTIONS(1379),
    [anon_sym_PLUS_PLUS] = ACTIONS(1379),
    [anon_sym_DASH_DASH] = ACTIONS(1379),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1377),
    [anon_sym_DASH] = ACTIONS(1377),
    [anon_sym_STAR] = ACTIONS(1381),
    [anon_sym_CARET] = ACTIONS(1379),
    [anon_sym_AMP] = ACTIONS(1379),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1383),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1385),
    [anon_sym_DOT_DOT] = ACTIONS(1387),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1464] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6911),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2930),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7105),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6723),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3569),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1464),
    [sym_preproc_endregion] = STATE(1464),
    [sym_preproc_line] = STATE(1464),
    [sym_preproc_pragma] = STATE(1464),
    [sym_preproc_nullable] = STATE(1464),
    [sym_preproc_error] = STATE(1464),
    [sym_preproc_warning] = STATE(1464),
    [sym_preproc_define] = STATE(1464),
    [sym_preproc_undef] = STATE(1464),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(2979),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(1705),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1465] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6229),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1465),
    [sym_preproc_endregion] = STATE(1465),
    [sym_preproc_line] = STATE(1465),
    [sym_preproc_pragma] = STATE(1465),
    [sym_preproc_nullable] = STATE(1465),
    [sym_preproc_error] = STATE(1465),
    [sym_preproc_warning] = STATE(1465),
    [sym_preproc_define] = STATE(1465),
    [sym_preproc_undef] = STATE(1465),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1466] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7131),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5985),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4364),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9470),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1466),
    [sym_preproc_endregion] = STATE(1466),
    [sym_preproc_line] = STATE(1466),
    [sym_preproc_pragma] = STATE(1466),
    [sym_preproc_nullable] = STATE(1466),
    [sym_preproc_error] = STATE(1466),
    [sym_preproc_warning] = STATE(1466),
    [sym_preproc_define] = STATE(1466),
    [sym_preproc_undef] = STATE(1466),
    [aux_sym_class_declaration_repeat1] = STATE(3870),
    [aux_sym_lambda_expression_repeat1] = STATE(4302),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1555),
    [anon_sym_ref] = ACTIONS(1557),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(695),
    [anon_sym_TILDE] = ACTIONS(695),
    [anon_sym_PLUS_PLUS] = ACTIONS(695),
    [anon_sym_DASH_DASH] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(697),
    [anon_sym_DASH] = ACTIONS(697),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(695),
    [anon_sym_AMP] = ACTIONS(695),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1559),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1561),
    [anon_sym_DOT_DOT] = ACTIONS(1563),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1467] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7131),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4336),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4364),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9470),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1467),
    [sym_preproc_endregion] = STATE(1467),
    [sym_preproc_line] = STATE(1467),
    [sym_preproc_pragma] = STATE(1467),
    [sym_preproc_nullable] = STATE(1467),
    [sym_preproc_error] = STATE(1467),
    [sym_preproc_warning] = STATE(1467),
    [sym_preproc_define] = STATE(1467),
    [sym_preproc_undef] = STATE(1467),
    [aux_sym_class_declaration_repeat1] = STATE(3870),
    [aux_sym_lambda_expression_repeat1] = STATE(4302),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1555),
    [anon_sym_ref] = ACTIONS(1557),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(695),
    [anon_sym_TILDE] = ACTIONS(695),
    [anon_sym_PLUS_PLUS] = ACTIONS(695),
    [anon_sym_DASH_DASH] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(697),
    [anon_sym_DASH] = ACTIONS(697),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(695),
    [anon_sym_AMP] = ACTIONS(695),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1559),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1561),
    [anon_sym_DOT_DOT] = ACTIONS(1563),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1468] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7131),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5922),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4364),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9470),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1468),
    [sym_preproc_endregion] = STATE(1468),
    [sym_preproc_line] = STATE(1468),
    [sym_preproc_pragma] = STATE(1468),
    [sym_preproc_nullable] = STATE(1468),
    [sym_preproc_error] = STATE(1468),
    [sym_preproc_warning] = STATE(1468),
    [sym_preproc_define] = STATE(1468),
    [sym_preproc_undef] = STATE(1468),
    [aux_sym_class_declaration_repeat1] = STATE(3870),
    [aux_sym_lambda_expression_repeat1] = STATE(4302),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1555),
    [anon_sym_ref] = ACTIONS(1557),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(695),
    [anon_sym_TILDE] = ACTIONS(695),
    [anon_sym_PLUS_PLUS] = ACTIONS(695),
    [anon_sym_DASH_DASH] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(697),
    [anon_sym_DASH] = ACTIONS(697),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(695),
    [anon_sym_AMP] = ACTIONS(695),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1559),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1561),
    [anon_sym_DOT_DOT] = ACTIONS(1563),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1469] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7131),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5923),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4364),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9470),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1469),
    [sym_preproc_endregion] = STATE(1469),
    [sym_preproc_line] = STATE(1469),
    [sym_preproc_pragma] = STATE(1469),
    [sym_preproc_nullable] = STATE(1469),
    [sym_preproc_error] = STATE(1469),
    [sym_preproc_warning] = STATE(1469),
    [sym_preproc_define] = STATE(1469),
    [sym_preproc_undef] = STATE(1469),
    [aux_sym_class_declaration_repeat1] = STATE(3870),
    [aux_sym_lambda_expression_repeat1] = STATE(4302),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1555),
    [anon_sym_ref] = ACTIONS(1557),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(695),
    [anon_sym_TILDE] = ACTIONS(695),
    [anon_sym_PLUS_PLUS] = ACTIONS(695),
    [anon_sym_DASH_DASH] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(697),
    [anon_sym_DASH] = ACTIONS(697),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(695),
    [anon_sym_AMP] = ACTIONS(695),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1559),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1561),
    [anon_sym_DOT_DOT] = ACTIONS(1563),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1470] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7131),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5924),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4364),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9470),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1470),
    [sym_preproc_endregion] = STATE(1470),
    [sym_preproc_line] = STATE(1470),
    [sym_preproc_pragma] = STATE(1470),
    [sym_preproc_nullable] = STATE(1470),
    [sym_preproc_error] = STATE(1470),
    [sym_preproc_warning] = STATE(1470),
    [sym_preproc_define] = STATE(1470),
    [sym_preproc_undef] = STATE(1470),
    [aux_sym_class_declaration_repeat1] = STATE(3870),
    [aux_sym_lambda_expression_repeat1] = STATE(4302),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1555),
    [anon_sym_ref] = ACTIONS(1557),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(695),
    [anon_sym_TILDE] = ACTIONS(695),
    [anon_sym_PLUS_PLUS] = ACTIONS(695),
    [anon_sym_DASH_DASH] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(697),
    [anon_sym_DASH] = ACTIONS(697),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(695),
    [anon_sym_AMP] = ACTIONS(695),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1559),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1561),
    [anon_sym_DOT_DOT] = ACTIONS(1563),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1471] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7131),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5925),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4364),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9470),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1471),
    [sym_preproc_endregion] = STATE(1471),
    [sym_preproc_line] = STATE(1471),
    [sym_preproc_pragma] = STATE(1471),
    [sym_preproc_nullable] = STATE(1471),
    [sym_preproc_error] = STATE(1471),
    [sym_preproc_warning] = STATE(1471),
    [sym_preproc_define] = STATE(1471),
    [sym_preproc_undef] = STATE(1471),
    [aux_sym_class_declaration_repeat1] = STATE(3870),
    [aux_sym_lambda_expression_repeat1] = STATE(4302),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1555),
    [anon_sym_ref] = ACTIONS(1557),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(695),
    [anon_sym_TILDE] = ACTIONS(695),
    [anon_sym_PLUS_PLUS] = ACTIONS(695),
    [anon_sym_DASH_DASH] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(697),
    [anon_sym_DASH] = ACTIONS(697),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(695),
    [anon_sym_AMP] = ACTIONS(695),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1559),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1561),
    [anon_sym_DOT_DOT] = ACTIONS(1563),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1472] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7131),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5926),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4364),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9470),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1472),
    [sym_preproc_endregion] = STATE(1472),
    [sym_preproc_line] = STATE(1472),
    [sym_preproc_pragma] = STATE(1472),
    [sym_preproc_nullable] = STATE(1472),
    [sym_preproc_error] = STATE(1472),
    [sym_preproc_warning] = STATE(1472),
    [sym_preproc_define] = STATE(1472),
    [sym_preproc_undef] = STATE(1472),
    [aux_sym_class_declaration_repeat1] = STATE(3870),
    [aux_sym_lambda_expression_repeat1] = STATE(4302),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1555),
    [anon_sym_ref] = ACTIONS(1557),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(695),
    [anon_sym_TILDE] = ACTIONS(695),
    [anon_sym_PLUS_PLUS] = ACTIONS(695),
    [anon_sym_DASH_DASH] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(697),
    [anon_sym_DASH] = ACTIONS(697),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(695),
    [anon_sym_AMP] = ACTIONS(695),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1559),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1561),
    [anon_sym_DOT_DOT] = ACTIONS(1563),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1473] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7131),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5927),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4364),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9470),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1473),
    [sym_preproc_endregion] = STATE(1473),
    [sym_preproc_line] = STATE(1473),
    [sym_preproc_pragma] = STATE(1473),
    [sym_preproc_nullable] = STATE(1473),
    [sym_preproc_error] = STATE(1473),
    [sym_preproc_warning] = STATE(1473),
    [sym_preproc_define] = STATE(1473),
    [sym_preproc_undef] = STATE(1473),
    [aux_sym_class_declaration_repeat1] = STATE(3870),
    [aux_sym_lambda_expression_repeat1] = STATE(4302),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1555),
    [anon_sym_ref] = ACTIONS(1557),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(695),
    [anon_sym_TILDE] = ACTIONS(695),
    [anon_sym_PLUS_PLUS] = ACTIONS(695),
    [anon_sym_DASH_DASH] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(697),
    [anon_sym_DASH] = ACTIONS(697),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(695),
    [anon_sym_AMP] = ACTIONS(695),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1559),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1561),
    [anon_sym_DOT_DOT] = ACTIONS(1563),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1474] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7131),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5928),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4364),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9470),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1474),
    [sym_preproc_endregion] = STATE(1474),
    [sym_preproc_line] = STATE(1474),
    [sym_preproc_pragma] = STATE(1474),
    [sym_preproc_nullable] = STATE(1474),
    [sym_preproc_error] = STATE(1474),
    [sym_preproc_warning] = STATE(1474),
    [sym_preproc_define] = STATE(1474),
    [sym_preproc_undef] = STATE(1474),
    [aux_sym_class_declaration_repeat1] = STATE(3870),
    [aux_sym_lambda_expression_repeat1] = STATE(4302),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1555),
    [anon_sym_ref] = ACTIONS(1557),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(695),
    [anon_sym_TILDE] = ACTIONS(695),
    [anon_sym_PLUS_PLUS] = ACTIONS(695),
    [anon_sym_DASH_DASH] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(697),
    [anon_sym_DASH] = ACTIONS(697),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(695),
    [anon_sym_AMP] = ACTIONS(695),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1559),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1561),
    [anon_sym_DOT_DOT] = ACTIONS(1563),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1475] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7131),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5929),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4364),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9470),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1475),
    [sym_preproc_endregion] = STATE(1475),
    [sym_preproc_line] = STATE(1475),
    [sym_preproc_pragma] = STATE(1475),
    [sym_preproc_nullable] = STATE(1475),
    [sym_preproc_error] = STATE(1475),
    [sym_preproc_warning] = STATE(1475),
    [sym_preproc_define] = STATE(1475),
    [sym_preproc_undef] = STATE(1475),
    [aux_sym_class_declaration_repeat1] = STATE(3870),
    [aux_sym_lambda_expression_repeat1] = STATE(4302),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1555),
    [anon_sym_ref] = ACTIONS(1557),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(695),
    [anon_sym_TILDE] = ACTIONS(695),
    [anon_sym_PLUS_PLUS] = ACTIONS(695),
    [anon_sym_DASH_DASH] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(697),
    [anon_sym_DASH] = ACTIONS(697),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(695),
    [anon_sym_AMP] = ACTIONS(695),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1559),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1561),
    [anon_sym_DOT_DOT] = ACTIONS(1563),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1476] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7131),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5951),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4364),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9470),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1476),
    [sym_preproc_endregion] = STATE(1476),
    [sym_preproc_line] = STATE(1476),
    [sym_preproc_pragma] = STATE(1476),
    [sym_preproc_nullable] = STATE(1476),
    [sym_preproc_error] = STATE(1476),
    [sym_preproc_warning] = STATE(1476),
    [sym_preproc_define] = STATE(1476),
    [sym_preproc_undef] = STATE(1476),
    [aux_sym_class_declaration_repeat1] = STATE(3870),
    [aux_sym_lambda_expression_repeat1] = STATE(4302),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1555),
    [anon_sym_ref] = ACTIONS(1557),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(695),
    [anon_sym_TILDE] = ACTIONS(695),
    [anon_sym_PLUS_PLUS] = ACTIONS(695),
    [anon_sym_DASH_DASH] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(697),
    [anon_sym_DASH] = ACTIONS(697),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(695),
    [anon_sym_AMP] = ACTIONS(695),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1559),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1561),
    [anon_sym_DOT_DOT] = ACTIONS(1563),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1477] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7131),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5952),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4364),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9470),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1477),
    [sym_preproc_endregion] = STATE(1477),
    [sym_preproc_line] = STATE(1477),
    [sym_preproc_pragma] = STATE(1477),
    [sym_preproc_nullable] = STATE(1477),
    [sym_preproc_error] = STATE(1477),
    [sym_preproc_warning] = STATE(1477),
    [sym_preproc_define] = STATE(1477),
    [sym_preproc_undef] = STATE(1477),
    [aux_sym_class_declaration_repeat1] = STATE(3870),
    [aux_sym_lambda_expression_repeat1] = STATE(4302),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1555),
    [anon_sym_ref] = ACTIONS(1557),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(695),
    [anon_sym_TILDE] = ACTIONS(695),
    [anon_sym_PLUS_PLUS] = ACTIONS(695),
    [anon_sym_DASH_DASH] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(697),
    [anon_sym_DASH] = ACTIONS(697),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(695),
    [anon_sym_AMP] = ACTIONS(695),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1559),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1561),
    [anon_sym_DOT_DOT] = ACTIONS(1563),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1478] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7131),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5953),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4364),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9470),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1478),
    [sym_preproc_endregion] = STATE(1478),
    [sym_preproc_line] = STATE(1478),
    [sym_preproc_pragma] = STATE(1478),
    [sym_preproc_nullable] = STATE(1478),
    [sym_preproc_error] = STATE(1478),
    [sym_preproc_warning] = STATE(1478),
    [sym_preproc_define] = STATE(1478),
    [sym_preproc_undef] = STATE(1478),
    [aux_sym_class_declaration_repeat1] = STATE(3870),
    [aux_sym_lambda_expression_repeat1] = STATE(4302),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1555),
    [anon_sym_ref] = ACTIONS(1557),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(695),
    [anon_sym_TILDE] = ACTIONS(695),
    [anon_sym_PLUS_PLUS] = ACTIONS(695),
    [anon_sym_DASH_DASH] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(697),
    [anon_sym_DASH] = ACTIONS(697),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(695),
    [anon_sym_AMP] = ACTIONS(695),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1559),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1561),
    [anon_sym_DOT_DOT] = ACTIONS(1563),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1479] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6345),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1479),
    [sym_preproc_endregion] = STATE(1479),
    [sym_preproc_line] = STATE(1479),
    [sym_preproc_pragma] = STATE(1479),
    [sym_preproc_nullable] = STATE(1479),
    [sym_preproc_error] = STATE(1479),
    [sym_preproc_warning] = STATE(1479),
    [sym_preproc_define] = STATE(1479),
    [sym_preproc_undef] = STATE(1479),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1480] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7131),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5986),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4364),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9470),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1480),
    [sym_preproc_endregion] = STATE(1480),
    [sym_preproc_line] = STATE(1480),
    [sym_preproc_pragma] = STATE(1480),
    [sym_preproc_nullable] = STATE(1480),
    [sym_preproc_error] = STATE(1480),
    [sym_preproc_warning] = STATE(1480),
    [sym_preproc_define] = STATE(1480),
    [sym_preproc_undef] = STATE(1480),
    [aux_sym_class_declaration_repeat1] = STATE(3870),
    [aux_sym_lambda_expression_repeat1] = STATE(4302),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1555),
    [anon_sym_ref] = ACTIONS(1557),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(695),
    [anon_sym_TILDE] = ACTIONS(695),
    [anon_sym_PLUS_PLUS] = ACTIONS(695),
    [anon_sym_DASH_DASH] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(697),
    [anon_sym_DASH] = ACTIONS(697),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(695),
    [anon_sym_AMP] = ACTIONS(695),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1559),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1561),
    [anon_sym_DOT_DOT] = ACTIONS(1563),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1481] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6925),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2932),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6992),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4636),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3702),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7420),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9634),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(1481),
    [sym_preproc_endregion] = STATE(1481),
    [sym_preproc_line] = STATE(1481),
    [sym_preproc_pragma] = STATE(1481),
    [sym_preproc_nullable] = STATE(1481),
    [sym_preproc_error] = STATE(1481),
    [sym_preproc_warning] = STATE(1481),
    [sym_preproc_define] = STATE(1481),
    [sym_preproc_undef] = STATE(1481),
    [aux_sym_class_declaration_repeat1] = STATE(3819),
    [aux_sym_lambda_expression_repeat1] = STATE(4232),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1995),
    [anon_sym_ref] = ACTIONS(1997),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1771),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(2001),
    [anon_sym_TILDE] = ACTIONS(2001),
    [anon_sym_PLUS_PLUS] = ACTIONS(2001),
    [anon_sym_DASH_DASH] = ACTIONS(2001),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1999),
    [anon_sym_DASH] = ACTIONS(1999),
    [anon_sym_STAR] = ACTIONS(1777),
    [anon_sym_CARET] = ACTIONS(2001),
    [anon_sym_AMP] = ACTIONS(2001),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(2003),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2005),
    [anon_sym_DOT_DOT] = ACTIONS(2007),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [1482] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7131),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4338),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4364),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9470),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1482),
    [sym_preproc_endregion] = STATE(1482),
    [sym_preproc_line] = STATE(1482),
    [sym_preproc_pragma] = STATE(1482),
    [sym_preproc_nullable] = STATE(1482),
    [sym_preproc_error] = STATE(1482),
    [sym_preproc_warning] = STATE(1482),
    [sym_preproc_define] = STATE(1482),
    [sym_preproc_undef] = STATE(1482),
    [aux_sym_class_declaration_repeat1] = STATE(3870),
    [aux_sym_lambda_expression_repeat1] = STATE(4302),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1555),
    [anon_sym_ref] = ACTIONS(1557),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(695),
    [anon_sym_TILDE] = ACTIONS(695),
    [anon_sym_PLUS_PLUS] = ACTIONS(695),
    [anon_sym_DASH_DASH] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(697),
    [anon_sym_DASH] = ACTIONS(697),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(695),
    [anon_sym_AMP] = ACTIONS(695),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1559),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1561),
    [anon_sym_DOT_DOT] = ACTIONS(1563),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1483] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6485),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1483),
    [sym_preproc_endregion] = STATE(1483),
    [sym_preproc_line] = STATE(1483),
    [sym_preproc_pragma] = STATE(1483),
    [sym_preproc_nullable] = STATE(1483),
    [sym_preproc_error] = STATE(1483),
    [sym_preproc_warning] = STATE(1483),
    [sym_preproc_define] = STATE(1483),
    [sym_preproc_undef] = STATE(1483),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1484] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6917),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2905),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7006),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5676),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4199),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7447),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9823),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1484),
    [sym_preproc_endregion] = STATE(1484),
    [sym_preproc_line] = STATE(1484),
    [sym_preproc_pragma] = STATE(1484),
    [sym_preproc_nullable] = STATE(1484),
    [sym_preproc_error] = STATE(1484),
    [sym_preproc_warning] = STATE(1484),
    [sym_preproc_define] = STATE(1484),
    [sym_preproc_undef] = STATE(1484),
    [aux_sym_class_declaration_repeat1] = STATE(3822),
    [aux_sym_lambda_expression_repeat1] = STATE(4238),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1623),
    [anon_sym_ref] = ACTIONS(1625),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1577),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1629),
    [anon_sym_TILDE] = ACTIONS(1629),
    [anon_sym_PLUS_PLUS] = ACTIONS(1629),
    [anon_sym_DASH_DASH] = ACTIONS(1629),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1627),
    [anon_sym_DASH] = ACTIONS(1627),
    [anon_sym_STAR] = ACTIONS(1631),
    [anon_sym_CARET] = ACTIONS(1629),
    [anon_sym_AMP] = ACTIONS(1629),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1633),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1635),
    [anon_sym_DOT_DOT] = ACTIONS(1637),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1485] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6284),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1485),
    [sym_preproc_endregion] = STATE(1485),
    [sym_preproc_line] = STATE(1485),
    [sym_preproc_pragma] = STATE(1485),
    [sym_preproc_nullable] = STATE(1485),
    [sym_preproc_error] = STATE(1485),
    [sym_preproc_warning] = STATE(1485),
    [sym_preproc_define] = STATE(1485),
    [sym_preproc_undef] = STATE(1485),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1486] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7131),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5981),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4364),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9470),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1486),
    [sym_preproc_endregion] = STATE(1486),
    [sym_preproc_line] = STATE(1486),
    [sym_preproc_pragma] = STATE(1486),
    [sym_preproc_nullable] = STATE(1486),
    [sym_preproc_error] = STATE(1486),
    [sym_preproc_warning] = STATE(1486),
    [sym_preproc_define] = STATE(1486),
    [sym_preproc_undef] = STATE(1486),
    [aux_sym_class_declaration_repeat1] = STATE(3870),
    [aux_sym_lambda_expression_repeat1] = STATE(4302),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1555),
    [anon_sym_ref] = ACTIONS(1557),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(695),
    [anon_sym_TILDE] = ACTIONS(695),
    [anon_sym_PLUS_PLUS] = ACTIONS(695),
    [anon_sym_DASH_DASH] = ACTIONS(695),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(697),
    [anon_sym_DASH] = ACTIONS(697),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(695),
    [anon_sym_AMP] = ACTIONS(695),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1559),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1561),
    [anon_sym_DOT_DOT] = ACTIONS(1563),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1487] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6346),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1487),
    [sym_preproc_endregion] = STATE(1487),
    [sym_preproc_line] = STATE(1487),
    [sym_preproc_pragma] = STATE(1487),
    [sym_preproc_nullable] = STATE(1487),
    [sym_preproc_error] = STATE(1487),
    [sym_preproc_warning] = STATE(1487),
    [sym_preproc_define] = STATE(1487),
    [sym_preproc_undef] = STATE(1487),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1488] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6925),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2932),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6992),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4646),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3702),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7420),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9634),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(1488),
    [sym_preproc_endregion] = STATE(1488),
    [sym_preproc_line] = STATE(1488),
    [sym_preproc_pragma] = STATE(1488),
    [sym_preproc_nullable] = STATE(1488),
    [sym_preproc_error] = STATE(1488),
    [sym_preproc_warning] = STATE(1488),
    [sym_preproc_define] = STATE(1488),
    [sym_preproc_undef] = STATE(1488),
    [aux_sym_class_declaration_repeat1] = STATE(3819),
    [aux_sym_lambda_expression_repeat1] = STATE(4232),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1995),
    [anon_sym_ref] = ACTIONS(1997),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1771),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(2001),
    [anon_sym_TILDE] = ACTIONS(2001),
    [anon_sym_PLUS_PLUS] = ACTIONS(2001),
    [anon_sym_DASH_DASH] = ACTIONS(2001),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1999),
    [anon_sym_DASH] = ACTIONS(1999),
    [anon_sym_STAR] = ACTIONS(1777),
    [anon_sym_CARET] = ACTIONS(2001),
    [anon_sym_AMP] = ACTIONS(2001),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(2003),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2005),
    [anon_sym_DOT_DOT] = ACTIONS(2007),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [1489] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6353),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1489),
    [sym_preproc_endregion] = STATE(1489),
    [sym_preproc_line] = STATE(1489),
    [sym_preproc_pragma] = STATE(1489),
    [sym_preproc_nullable] = STATE(1489),
    [sym_preproc_error] = STATE(1489),
    [sym_preproc_warning] = STATE(1489),
    [sym_preproc_define] = STATE(1489),
    [sym_preproc_undef] = STATE(1489),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1490] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6956),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6355),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9482),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1490),
    [sym_preproc_endregion] = STATE(1490),
    [sym_preproc_line] = STATE(1490),
    [sym_preproc_pragma] = STATE(1490),
    [sym_preproc_nullable] = STATE(1490),
    [sym_preproc_error] = STATE(1490),
    [sym_preproc_warning] = STATE(1490),
    [sym_preproc_define] = STATE(1490),
    [sym_preproc_undef] = STATE(1490),
    [aux_sym_class_declaration_repeat1] = STATE(3853),
    [aux_sym_lambda_expression_repeat1] = STATE(4299),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1497),
    [anon_sym_ref] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1505),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1507),
    [anon_sym_DOT_DOT] = ACTIONS(1509),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1491] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6955),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2975),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6988),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4999),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3800),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7425),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9573),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1491),
    [sym_preproc_endregion] = STATE(1491),
    [sym_preproc_line] = STATE(1491),
    [sym_preproc_pragma] = STATE(1491),
    [sym_preproc_nullable] = STATE(1491),
    [sym_preproc_error] = STATE(1491),
    [sym_preproc_warning] = STATE(1491),
    [sym_preproc_define] = STATE(1491),
    [sym_preproc_undef] = STATE(1491),
    [aux_sym_class_declaration_repeat1] = STATE(3818),
    [aux_sym_lambda_expression_repeat1] = STATE(4229),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2259),
    [anon_sym_ref] = ACTIONS(2261),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1933),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2265),
    [anon_sym_TILDE] = ACTIONS(2265),
    [anon_sym_PLUS_PLUS] = ACTIONS(2265),
    [anon_sym_DASH_DASH] = ACTIONS(2265),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2263),
    [anon_sym_DASH] = ACTIONS(2263),
    [anon_sym_STAR] = ACTIONS(1939),
    [anon_sym_CARET] = ACTIONS(2265),
    [anon_sym_AMP] = ACTIONS(2265),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2267),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2269),
    [anon_sym_DOT_DOT] = ACTIONS(2271),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1492] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6984),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5191),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3903),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7428),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9348),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1492),
    [sym_preproc_endregion] = STATE(1492),
    [sym_preproc_line] = STATE(1492),
    [sym_preproc_pragma] = STATE(1492),
    [sym_preproc_nullable] = STATE(1492),
    [sym_preproc_error] = STATE(1492),
    [sym_preproc_warning] = STATE(1492),
    [sym_preproc_define] = STATE(1492),
    [sym_preproc_undef] = STATE(1492),
    [aux_sym_class_declaration_repeat1] = STATE(3817),
    [aux_sym_lambda_expression_repeat1] = STATE(4227),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1389),
    [anon_sym_ref] = ACTIONS(1391),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1117),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(1393),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_AMP] = ACTIONS(1117),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1395),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1397),
    [anon_sym_DOT_DOT] = ACTIONS(1399),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1493] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6984),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5205),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3903),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7428),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9348),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1493),
    [sym_preproc_endregion] = STATE(1493),
    [sym_preproc_line] = STATE(1493),
    [sym_preproc_pragma] = STATE(1493),
    [sym_preproc_nullable] = STATE(1493),
    [sym_preproc_error] = STATE(1493),
    [sym_preproc_warning] = STATE(1493),
    [sym_preproc_define] = STATE(1493),
    [sym_preproc_undef] = STATE(1493),
    [aux_sym_class_declaration_repeat1] = STATE(3817),
    [aux_sym_lambda_expression_repeat1] = STATE(4227),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1389),
    [anon_sym_ref] = ACTIONS(1391),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1117),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(1393),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_AMP] = ACTIONS(1117),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1395),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1397),
    [anon_sym_DOT_DOT] = ACTIONS(1399),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1494] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6984),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5160),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3903),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7428),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9348),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1494),
    [sym_preproc_endregion] = STATE(1494),
    [sym_preproc_line] = STATE(1494),
    [sym_preproc_pragma] = STATE(1494),
    [sym_preproc_nullable] = STATE(1494),
    [sym_preproc_error] = STATE(1494),
    [sym_preproc_warning] = STATE(1494),
    [sym_preproc_define] = STATE(1494),
    [sym_preproc_undef] = STATE(1494),
    [aux_sym_class_declaration_repeat1] = STATE(3817),
    [aux_sym_lambda_expression_repeat1] = STATE(4227),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1389),
    [anon_sym_ref] = ACTIONS(1391),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1117),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(1393),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_AMP] = ACTIONS(1117),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1395),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1397),
    [anon_sym_DOT_DOT] = ACTIONS(1399),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1495] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6984),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5206),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3903),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7428),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9348),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1495),
    [sym_preproc_endregion] = STATE(1495),
    [sym_preproc_line] = STATE(1495),
    [sym_preproc_pragma] = STATE(1495),
    [sym_preproc_nullable] = STATE(1495),
    [sym_preproc_error] = STATE(1495),
    [sym_preproc_warning] = STATE(1495),
    [sym_preproc_define] = STATE(1495),
    [sym_preproc_undef] = STATE(1495),
    [aux_sym_class_declaration_repeat1] = STATE(3817),
    [aux_sym_lambda_expression_repeat1] = STATE(4227),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1389),
    [anon_sym_ref] = ACTIONS(1391),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1117),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(1393),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_AMP] = ACTIONS(1117),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1395),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1397),
    [anon_sym_DOT_DOT] = ACTIONS(1399),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1496] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6984),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5208),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3903),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7428),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9348),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1496),
    [sym_preproc_endregion] = STATE(1496),
    [sym_preproc_line] = STATE(1496),
    [sym_preproc_pragma] = STATE(1496),
    [sym_preproc_nullable] = STATE(1496),
    [sym_preproc_error] = STATE(1496),
    [sym_preproc_warning] = STATE(1496),
    [sym_preproc_define] = STATE(1496),
    [sym_preproc_undef] = STATE(1496),
    [aux_sym_class_declaration_repeat1] = STATE(3817),
    [aux_sym_lambda_expression_repeat1] = STATE(4227),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1389),
    [anon_sym_ref] = ACTIONS(1391),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1117),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(1393),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_AMP] = ACTIONS(1117),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1395),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1397),
    [anon_sym_DOT_DOT] = ACTIONS(1399),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1497] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6984),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5211),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3903),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7428),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9348),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1497),
    [sym_preproc_endregion] = STATE(1497),
    [sym_preproc_line] = STATE(1497),
    [sym_preproc_pragma] = STATE(1497),
    [sym_preproc_nullable] = STATE(1497),
    [sym_preproc_error] = STATE(1497),
    [sym_preproc_warning] = STATE(1497),
    [sym_preproc_define] = STATE(1497),
    [sym_preproc_undef] = STATE(1497),
    [aux_sym_class_declaration_repeat1] = STATE(3817),
    [aux_sym_lambda_expression_repeat1] = STATE(4227),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1389),
    [anon_sym_ref] = ACTIONS(1391),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1117),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(1393),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_AMP] = ACTIONS(1117),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1395),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1397),
    [anon_sym_DOT_DOT] = ACTIONS(1399),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1498] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6984),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5215),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3903),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7428),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9348),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1498),
    [sym_preproc_endregion] = STATE(1498),
    [sym_preproc_line] = STATE(1498),
    [sym_preproc_pragma] = STATE(1498),
    [sym_preproc_nullable] = STATE(1498),
    [sym_preproc_error] = STATE(1498),
    [sym_preproc_warning] = STATE(1498),
    [sym_preproc_define] = STATE(1498),
    [sym_preproc_undef] = STATE(1498),
    [aux_sym_class_declaration_repeat1] = STATE(3817),
    [aux_sym_lambda_expression_repeat1] = STATE(4227),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1389),
    [anon_sym_ref] = ACTIONS(1391),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1117),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(1393),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_AMP] = ACTIONS(1117),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1395),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1397),
    [anon_sym_DOT_DOT] = ACTIONS(1399),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1499] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6984),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5220),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3903),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7428),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9348),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1499),
    [sym_preproc_endregion] = STATE(1499),
    [sym_preproc_line] = STATE(1499),
    [sym_preproc_pragma] = STATE(1499),
    [sym_preproc_nullable] = STATE(1499),
    [sym_preproc_error] = STATE(1499),
    [sym_preproc_warning] = STATE(1499),
    [sym_preproc_define] = STATE(1499),
    [sym_preproc_undef] = STATE(1499),
    [aux_sym_class_declaration_repeat1] = STATE(3817),
    [aux_sym_lambda_expression_repeat1] = STATE(4227),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1389),
    [anon_sym_ref] = ACTIONS(1391),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1117),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(1393),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_AMP] = ACTIONS(1117),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1395),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1397),
    [anon_sym_DOT_DOT] = ACTIONS(1399),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1500] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6984),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5225),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3903),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7428),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9348),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1500),
    [sym_preproc_endregion] = STATE(1500),
    [sym_preproc_line] = STATE(1500),
    [sym_preproc_pragma] = STATE(1500),
    [sym_preproc_nullable] = STATE(1500),
    [sym_preproc_error] = STATE(1500),
    [sym_preproc_warning] = STATE(1500),
    [sym_preproc_define] = STATE(1500),
    [sym_preproc_undef] = STATE(1500),
    [aux_sym_class_declaration_repeat1] = STATE(3817),
    [aux_sym_lambda_expression_repeat1] = STATE(4227),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1389),
    [anon_sym_ref] = ACTIONS(1391),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1117),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(1393),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_AMP] = ACTIONS(1117),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1395),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1397),
    [anon_sym_DOT_DOT] = ACTIONS(1399),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1501] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6984),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5232),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3903),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7428),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9348),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1501),
    [sym_preproc_endregion] = STATE(1501),
    [sym_preproc_line] = STATE(1501),
    [sym_preproc_pragma] = STATE(1501),
    [sym_preproc_nullable] = STATE(1501),
    [sym_preproc_error] = STATE(1501),
    [sym_preproc_warning] = STATE(1501),
    [sym_preproc_define] = STATE(1501),
    [sym_preproc_undef] = STATE(1501),
    [aux_sym_class_declaration_repeat1] = STATE(3817),
    [aux_sym_lambda_expression_repeat1] = STATE(4227),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1389),
    [anon_sym_ref] = ACTIONS(1391),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1117),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(1393),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_AMP] = ACTIONS(1117),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1395),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1397),
    [anon_sym_DOT_DOT] = ACTIONS(1399),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1502] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6984),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5143),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3903),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7428),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9348),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1502),
    [sym_preproc_endregion] = STATE(1502),
    [sym_preproc_line] = STATE(1502),
    [sym_preproc_pragma] = STATE(1502),
    [sym_preproc_nullable] = STATE(1502),
    [sym_preproc_error] = STATE(1502),
    [sym_preproc_warning] = STATE(1502),
    [sym_preproc_define] = STATE(1502),
    [sym_preproc_undef] = STATE(1502),
    [aux_sym_class_declaration_repeat1] = STATE(3817),
    [aux_sym_lambda_expression_repeat1] = STATE(4227),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1389),
    [anon_sym_ref] = ACTIONS(1391),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1117),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(1393),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_AMP] = ACTIONS(1117),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1395),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1397),
    [anon_sym_DOT_DOT] = ACTIONS(1399),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1503] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6984),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3932),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3903),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7428),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9348),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1503),
    [sym_preproc_endregion] = STATE(1503),
    [sym_preproc_line] = STATE(1503),
    [sym_preproc_pragma] = STATE(1503),
    [sym_preproc_nullable] = STATE(1503),
    [sym_preproc_error] = STATE(1503),
    [sym_preproc_warning] = STATE(1503),
    [sym_preproc_define] = STATE(1503),
    [sym_preproc_undef] = STATE(1503),
    [aux_sym_class_declaration_repeat1] = STATE(3817),
    [aux_sym_lambda_expression_repeat1] = STATE(4227),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1389),
    [anon_sym_ref] = ACTIONS(1391),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1117),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(1393),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_AMP] = ACTIONS(1117),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1395),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1397),
    [anon_sym_DOT_DOT] = ACTIONS(1399),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1504] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6932),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2977),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6996),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6282),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4378),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7430),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9693),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1504),
    [sym_preproc_endregion] = STATE(1504),
    [sym_preproc_line] = STATE(1504),
    [sym_preproc_pragma] = STATE(1504),
    [sym_preproc_nullable] = STATE(1504),
    [sym_preproc_error] = STATE(1504),
    [sym_preproc_warning] = STATE(1504),
    [sym_preproc_define] = STATE(1504),
    [sym_preproc_undef] = STATE(1504),
    [aux_sym_class_declaration_repeat1] = STATE(3820),
    [aux_sym_lambda_expression_repeat1] = STATE(4234),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2127),
    [anon_sym_ref] = ACTIONS(2129),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2131),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2135),
    [anon_sym_TILDE] = ACTIONS(2135),
    [anon_sym_PLUS_PLUS] = ACTIONS(2135),
    [anon_sym_DASH_DASH] = ACTIONS(2135),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2133),
    [anon_sym_DASH] = ACTIONS(2133),
    [anon_sym_STAR] = ACTIONS(2137),
    [anon_sym_CARET] = ACTIONS(2135),
    [anon_sym_AMP] = ACTIONS(2135),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2139),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2141),
    [anon_sym_DOT_DOT] = ACTIONS(2143),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1505] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6932),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2977),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6996),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3567),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4378),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7430),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9693),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1505),
    [sym_preproc_endregion] = STATE(1505),
    [sym_preproc_line] = STATE(1505),
    [sym_preproc_pragma] = STATE(1505),
    [sym_preproc_nullable] = STATE(1505),
    [sym_preproc_error] = STATE(1505),
    [sym_preproc_warning] = STATE(1505),
    [sym_preproc_define] = STATE(1505),
    [sym_preproc_undef] = STATE(1505),
    [aux_sym_class_declaration_repeat1] = STATE(3820),
    [aux_sym_lambda_expression_repeat1] = STATE(4234),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2127),
    [anon_sym_ref] = ACTIONS(2129),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2131),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2135),
    [anon_sym_TILDE] = ACTIONS(2135),
    [anon_sym_PLUS_PLUS] = ACTIONS(2135),
    [anon_sym_DASH_DASH] = ACTIONS(2135),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2133),
    [anon_sym_DASH] = ACTIONS(2133),
    [anon_sym_STAR] = ACTIONS(2137),
    [anon_sym_CARET] = ACTIONS(2135),
    [anon_sym_AMP] = ACTIONS(2135),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2139),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2141),
    [anon_sym_DOT_DOT] = ACTIONS(2143),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1506] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6932),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2977),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6996),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6308),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4378),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7430),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9693),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1506),
    [sym_preproc_endregion] = STATE(1506),
    [sym_preproc_line] = STATE(1506),
    [sym_preproc_pragma] = STATE(1506),
    [sym_preproc_nullable] = STATE(1506),
    [sym_preproc_error] = STATE(1506),
    [sym_preproc_warning] = STATE(1506),
    [sym_preproc_define] = STATE(1506),
    [sym_preproc_undef] = STATE(1506),
    [aux_sym_class_declaration_repeat1] = STATE(3820),
    [aux_sym_lambda_expression_repeat1] = STATE(4234),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2127),
    [anon_sym_ref] = ACTIONS(2129),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2131),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2135),
    [anon_sym_TILDE] = ACTIONS(2135),
    [anon_sym_PLUS_PLUS] = ACTIONS(2135),
    [anon_sym_DASH_DASH] = ACTIONS(2135),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2133),
    [anon_sym_DASH] = ACTIONS(2133),
    [anon_sym_STAR] = ACTIONS(2137),
    [anon_sym_CARET] = ACTIONS(2135),
    [anon_sym_AMP] = ACTIONS(2135),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2139),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2141),
    [anon_sym_DOT_DOT] = ACTIONS(2143),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1507] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6912),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2912),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7040),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5378),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3963),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7448),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9641),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1507),
    [sym_preproc_endregion] = STATE(1507),
    [sym_preproc_line] = STATE(1507),
    [sym_preproc_pragma] = STATE(1507),
    [sym_preproc_nullable] = STATE(1507),
    [sym_preproc_error] = STATE(1507),
    [sym_preproc_warning] = STATE(1507),
    [sym_preproc_define] = STATE(1507),
    [sym_preproc_undef] = STATE(1507),
    [aux_sym_class_declaration_repeat1] = STATE(3831),
    [aux_sym_lambda_expression_repeat1] = STATE(4257),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1785),
    [anon_sym_ref] = ACTIONS(1787),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1595),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1791),
    [anon_sym_TILDE] = ACTIONS(1791),
    [anon_sym_PLUS_PLUS] = ACTIONS(1791),
    [anon_sym_DASH_DASH] = ACTIONS(1791),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1789),
    [anon_sym_DASH] = ACTIONS(1789),
    [anon_sym_STAR] = ACTIONS(1793),
    [anon_sym_CARET] = ACTIONS(1791),
    [anon_sym_AMP] = ACTIONS(1791),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1795),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1797),
    [anon_sym_DOT_DOT] = ACTIONS(1799),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1508] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6932),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2977),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6996),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6143),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4378),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7430),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9693),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1508),
    [sym_preproc_endregion] = STATE(1508),
    [sym_preproc_line] = STATE(1508),
    [sym_preproc_pragma] = STATE(1508),
    [sym_preproc_nullable] = STATE(1508),
    [sym_preproc_error] = STATE(1508),
    [sym_preproc_warning] = STATE(1508),
    [sym_preproc_define] = STATE(1508),
    [sym_preproc_undef] = STATE(1508),
    [aux_sym_class_declaration_repeat1] = STATE(3820),
    [aux_sym_lambda_expression_repeat1] = STATE(4234),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2127),
    [anon_sym_ref] = ACTIONS(2129),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2131),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2135),
    [anon_sym_TILDE] = ACTIONS(2135),
    [anon_sym_PLUS_PLUS] = ACTIONS(2135),
    [anon_sym_DASH_DASH] = ACTIONS(2135),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2133),
    [anon_sym_DASH] = ACTIONS(2133),
    [anon_sym_STAR] = ACTIONS(2137),
    [anon_sym_CARET] = ACTIONS(2135),
    [anon_sym_AMP] = ACTIONS(2135),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2139),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2141),
    [anon_sym_DOT_DOT] = ACTIONS(2143),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1509] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6932),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2977),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6996),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6160),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4378),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7430),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9693),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1509),
    [sym_preproc_endregion] = STATE(1509),
    [sym_preproc_line] = STATE(1509),
    [sym_preproc_pragma] = STATE(1509),
    [sym_preproc_nullable] = STATE(1509),
    [sym_preproc_error] = STATE(1509),
    [sym_preproc_warning] = STATE(1509),
    [sym_preproc_define] = STATE(1509),
    [sym_preproc_undef] = STATE(1509),
    [aux_sym_class_declaration_repeat1] = STATE(3820),
    [aux_sym_lambda_expression_repeat1] = STATE(4234),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2127),
    [anon_sym_ref] = ACTIONS(2129),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2131),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2135),
    [anon_sym_TILDE] = ACTIONS(2135),
    [anon_sym_PLUS_PLUS] = ACTIONS(2135),
    [anon_sym_DASH_DASH] = ACTIONS(2135),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2133),
    [anon_sym_DASH] = ACTIONS(2133),
    [anon_sym_STAR] = ACTIONS(2137),
    [anon_sym_CARET] = ACTIONS(2135),
    [anon_sym_AMP] = ACTIONS(2135),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2139),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2141),
    [anon_sym_DOT_DOT] = ACTIONS(2143),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1510] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6932),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2977),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6996),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6150),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4378),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7430),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9693),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1510),
    [sym_preproc_endregion] = STATE(1510),
    [sym_preproc_line] = STATE(1510),
    [sym_preproc_pragma] = STATE(1510),
    [sym_preproc_nullable] = STATE(1510),
    [sym_preproc_error] = STATE(1510),
    [sym_preproc_warning] = STATE(1510),
    [sym_preproc_define] = STATE(1510),
    [sym_preproc_undef] = STATE(1510),
    [aux_sym_class_declaration_repeat1] = STATE(3820),
    [aux_sym_lambda_expression_repeat1] = STATE(4234),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2127),
    [anon_sym_ref] = ACTIONS(2129),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2131),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2135),
    [anon_sym_TILDE] = ACTIONS(2135),
    [anon_sym_PLUS_PLUS] = ACTIONS(2135),
    [anon_sym_DASH_DASH] = ACTIONS(2135),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2133),
    [anon_sym_DASH] = ACTIONS(2133),
    [anon_sym_STAR] = ACTIONS(2137),
    [anon_sym_CARET] = ACTIONS(2135),
    [anon_sym_AMP] = ACTIONS(2135),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2139),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2141),
    [anon_sym_DOT_DOT] = ACTIONS(2143),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1511] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6932),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2977),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6996),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6161),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4378),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7430),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9693),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1511),
    [sym_preproc_endregion] = STATE(1511),
    [sym_preproc_line] = STATE(1511),
    [sym_preproc_pragma] = STATE(1511),
    [sym_preproc_nullable] = STATE(1511),
    [sym_preproc_error] = STATE(1511),
    [sym_preproc_warning] = STATE(1511),
    [sym_preproc_define] = STATE(1511),
    [sym_preproc_undef] = STATE(1511),
    [aux_sym_class_declaration_repeat1] = STATE(3820),
    [aux_sym_lambda_expression_repeat1] = STATE(4234),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2127),
    [anon_sym_ref] = ACTIONS(2129),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2131),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2135),
    [anon_sym_TILDE] = ACTIONS(2135),
    [anon_sym_PLUS_PLUS] = ACTIONS(2135),
    [anon_sym_DASH_DASH] = ACTIONS(2135),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2133),
    [anon_sym_DASH] = ACTIONS(2133),
    [anon_sym_STAR] = ACTIONS(2137),
    [anon_sym_CARET] = ACTIONS(2135),
    [anon_sym_AMP] = ACTIONS(2135),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2139),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2141),
    [anon_sym_DOT_DOT] = ACTIONS(2143),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1512] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6932),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2977),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6996),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6172),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4378),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7430),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9693),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1512),
    [sym_preproc_endregion] = STATE(1512),
    [sym_preproc_line] = STATE(1512),
    [sym_preproc_pragma] = STATE(1512),
    [sym_preproc_nullable] = STATE(1512),
    [sym_preproc_error] = STATE(1512),
    [sym_preproc_warning] = STATE(1512),
    [sym_preproc_define] = STATE(1512),
    [sym_preproc_undef] = STATE(1512),
    [aux_sym_class_declaration_repeat1] = STATE(3820),
    [aux_sym_lambda_expression_repeat1] = STATE(4234),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2127),
    [anon_sym_ref] = ACTIONS(2129),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2131),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2135),
    [anon_sym_TILDE] = ACTIONS(2135),
    [anon_sym_PLUS_PLUS] = ACTIONS(2135),
    [anon_sym_DASH_DASH] = ACTIONS(2135),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2133),
    [anon_sym_DASH] = ACTIONS(2133),
    [anon_sym_STAR] = ACTIONS(2137),
    [anon_sym_CARET] = ACTIONS(2135),
    [anon_sym_AMP] = ACTIONS(2135),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2139),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2141),
    [anon_sym_DOT_DOT] = ACTIONS(2143),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1513] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6932),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2977),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6996),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6178),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4378),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7430),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9693),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1513),
    [sym_preproc_endregion] = STATE(1513),
    [sym_preproc_line] = STATE(1513),
    [sym_preproc_pragma] = STATE(1513),
    [sym_preproc_nullable] = STATE(1513),
    [sym_preproc_error] = STATE(1513),
    [sym_preproc_warning] = STATE(1513),
    [sym_preproc_define] = STATE(1513),
    [sym_preproc_undef] = STATE(1513),
    [aux_sym_class_declaration_repeat1] = STATE(3820),
    [aux_sym_lambda_expression_repeat1] = STATE(4234),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2127),
    [anon_sym_ref] = ACTIONS(2129),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2131),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2135),
    [anon_sym_TILDE] = ACTIONS(2135),
    [anon_sym_PLUS_PLUS] = ACTIONS(2135),
    [anon_sym_DASH_DASH] = ACTIONS(2135),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2133),
    [anon_sym_DASH] = ACTIONS(2133),
    [anon_sym_STAR] = ACTIONS(2137),
    [anon_sym_CARET] = ACTIONS(2135),
    [anon_sym_AMP] = ACTIONS(2135),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2139),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2141),
    [anon_sym_DOT_DOT] = ACTIONS(2143),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1514] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6932),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2977),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6996),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6180),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4378),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7430),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9693),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1514),
    [sym_preproc_endregion] = STATE(1514),
    [sym_preproc_line] = STATE(1514),
    [sym_preproc_pragma] = STATE(1514),
    [sym_preproc_nullable] = STATE(1514),
    [sym_preproc_error] = STATE(1514),
    [sym_preproc_warning] = STATE(1514),
    [sym_preproc_define] = STATE(1514),
    [sym_preproc_undef] = STATE(1514),
    [aux_sym_class_declaration_repeat1] = STATE(3820),
    [aux_sym_lambda_expression_repeat1] = STATE(4234),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2127),
    [anon_sym_ref] = ACTIONS(2129),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2131),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2135),
    [anon_sym_TILDE] = ACTIONS(2135),
    [anon_sym_PLUS_PLUS] = ACTIONS(2135),
    [anon_sym_DASH_DASH] = ACTIONS(2135),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2133),
    [anon_sym_DASH] = ACTIONS(2133),
    [anon_sym_STAR] = ACTIONS(2137),
    [anon_sym_CARET] = ACTIONS(2135),
    [anon_sym_AMP] = ACTIONS(2135),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2139),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2141),
    [anon_sym_DOT_DOT] = ACTIONS(2143),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1515] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6932),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2977),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6996),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6260),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4378),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7430),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9693),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1515),
    [sym_preproc_endregion] = STATE(1515),
    [sym_preproc_line] = STATE(1515),
    [sym_preproc_pragma] = STATE(1515),
    [sym_preproc_nullable] = STATE(1515),
    [sym_preproc_error] = STATE(1515),
    [sym_preproc_warning] = STATE(1515),
    [sym_preproc_define] = STATE(1515),
    [sym_preproc_undef] = STATE(1515),
    [aux_sym_class_declaration_repeat1] = STATE(3820),
    [aux_sym_lambda_expression_repeat1] = STATE(4234),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2127),
    [anon_sym_ref] = ACTIONS(2129),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2131),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2135),
    [anon_sym_TILDE] = ACTIONS(2135),
    [anon_sym_PLUS_PLUS] = ACTIONS(2135),
    [anon_sym_DASH_DASH] = ACTIONS(2135),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2133),
    [anon_sym_DASH] = ACTIONS(2133),
    [anon_sym_STAR] = ACTIONS(2137),
    [anon_sym_CARET] = ACTIONS(2135),
    [anon_sym_AMP] = ACTIONS(2135),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2139),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2141),
    [anon_sym_DOT_DOT] = ACTIONS(2143),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1516] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6932),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2977),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6996),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6281),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4378),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7430),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9693),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1516),
    [sym_preproc_endregion] = STATE(1516),
    [sym_preproc_line] = STATE(1516),
    [sym_preproc_pragma] = STATE(1516),
    [sym_preproc_nullable] = STATE(1516),
    [sym_preproc_error] = STATE(1516),
    [sym_preproc_warning] = STATE(1516),
    [sym_preproc_define] = STATE(1516),
    [sym_preproc_undef] = STATE(1516),
    [aux_sym_class_declaration_repeat1] = STATE(3820),
    [aux_sym_lambda_expression_repeat1] = STATE(4234),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2127),
    [anon_sym_ref] = ACTIONS(2129),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2131),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2135),
    [anon_sym_TILDE] = ACTIONS(2135),
    [anon_sym_PLUS_PLUS] = ACTIONS(2135),
    [anon_sym_DASH_DASH] = ACTIONS(2135),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2133),
    [anon_sym_DASH] = ACTIONS(2133),
    [anon_sym_STAR] = ACTIONS(2137),
    [anon_sym_CARET] = ACTIONS(2135),
    [anon_sym_AMP] = ACTIONS(2135),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2139),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2141),
    [anon_sym_DOT_DOT] = ACTIONS(2143),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1517] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6932),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2977),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6996),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6292),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4378),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7430),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9693),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1517),
    [sym_preproc_endregion] = STATE(1517),
    [sym_preproc_line] = STATE(1517),
    [sym_preproc_pragma] = STATE(1517),
    [sym_preproc_nullable] = STATE(1517),
    [sym_preproc_error] = STATE(1517),
    [sym_preproc_warning] = STATE(1517),
    [sym_preproc_define] = STATE(1517),
    [sym_preproc_undef] = STATE(1517),
    [aux_sym_class_declaration_repeat1] = STATE(3820),
    [aux_sym_lambda_expression_repeat1] = STATE(4234),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2127),
    [anon_sym_ref] = ACTIONS(2129),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2131),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2135),
    [anon_sym_TILDE] = ACTIONS(2135),
    [anon_sym_PLUS_PLUS] = ACTIONS(2135),
    [anon_sym_DASH_DASH] = ACTIONS(2135),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2133),
    [anon_sym_DASH] = ACTIONS(2133),
    [anon_sym_STAR] = ACTIONS(2137),
    [anon_sym_CARET] = ACTIONS(2135),
    [anon_sym_AMP] = ACTIONS(2135),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2139),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2141),
    [anon_sym_DOT_DOT] = ACTIONS(2143),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1518] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6932),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2977),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6996),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6293),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4378),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7430),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9693),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1518),
    [sym_preproc_endregion] = STATE(1518),
    [sym_preproc_line] = STATE(1518),
    [sym_preproc_pragma] = STATE(1518),
    [sym_preproc_nullable] = STATE(1518),
    [sym_preproc_error] = STATE(1518),
    [sym_preproc_warning] = STATE(1518),
    [sym_preproc_define] = STATE(1518),
    [sym_preproc_undef] = STATE(1518),
    [aux_sym_class_declaration_repeat1] = STATE(3820),
    [aux_sym_lambda_expression_repeat1] = STATE(4234),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2127),
    [anon_sym_ref] = ACTIONS(2129),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2131),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2135),
    [anon_sym_TILDE] = ACTIONS(2135),
    [anon_sym_PLUS_PLUS] = ACTIONS(2135),
    [anon_sym_DASH_DASH] = ACTIONS(2135),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2133),
    [anon_sym_DASH] = ACTIONS(2133),
    [anon_sym_STAR] = ACTIONS(2137),
    [anon_sym_CARET] = ACTIONS(2135),
    [anon_sym_AMP] = ACTIONS(2135),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2139),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2141),
    [anon_sym_DOT_DOT] = ACTIONS(2143),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1519] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6932),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2977),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6996),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6128),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4378),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7430),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9693),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1519),
    [sym_preproc_endregion] = STATE(1519),
    [sym_preproc_line] = STATE(1519),
    [sym_preproc_pragma] = STATE(1519),
    [sym_preproc_nullable] = STATE(1519),
    [sym_preproc_error] = STATE(1519),
    [sym_preproc_warning] = STATE(1519),
    [sym_preproc_define] = STATE(1519),
    [sym_preproc_undef] = STATE(1519),
    [aux_sym_class_declaration_repeat1] = STATE(3820),
    [aux_sym_lambda_expression_repeat1] = STATE(4234),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2127),
    [anon_sym_ref] = ACTIONS(2129),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2131),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2135),
    [anon_sym_TILDE] = ACTIONS(2135),
    [anon_sym_PLUS_PLUS] = ACTIONS(2135),
    [anon_sym_DASH_DASH] = ACTIONS(2135),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2133),
    [anon_sym_DASH] = ACTIONS(2133),
    [anon_sym_STAR] = ACTIONS(2137),
    [anon_sym_CARET] = ACTIONS(2135),
    [anon_sym_AMP] = ACTIONS(2135),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2139),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2141),
    [anon_sym_DOT_DOT] = ACTIONS(2143),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1520] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6932),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2977),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6996),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3582),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4378),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7430),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9693),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1520),
    [sym_preproc_endregion] = STATE(1520),
    [sym_preproc_line] = STATE(1520),
    [sym_preproc_pragma] = STATE(1520),
    [sym_preproc_nullable] = STATE(1520),
    [sym_preproc_error] = STATE(1520),
    [sym_preproc_warning] = STATE(1520),
    [sym_preproc_define] = STATE(1520),
    [sym_preproc_undef] = STATE(1520),
    [aux_sym_class_declaration_repeat1] = STATE(3820),
    [aux_sym_lambda_expression_repeat1] = STATE(4234),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2127),
    [anon_sym_ref] = ACTIONS(2129),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2131),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2135),
    [anon_sym_TILDE] = ACTIONS(2135),
    [anon_sym_PLUS_PLUS] = ACTIONS(2135),
    [anon_sym_DASH_DASH] = ACTIONS(2135),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2133),
    [anon_sym_DASH] = ACTIONS(2133),
    [anon_sym_STAR] = ACTIONS(2137),
    [anon_sym_CARET] = ACTIONS(2135),
    [anon_sym_AMP] = ACTIONS(2135),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2139),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2141),
    [anon_sym_DOT_DOT] = ACTIONS(2143),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1521] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6984),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5169),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3903),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7428),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9348),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1521),
    [sym_preproc_endregion] = STATE(1521),
    [sym_preproc_line] = STATE(1521),
    [sym_preproc_pragma] = STATE(1521),
    [sym_preproc_nullable] = STATE(1521),
    [sym_preproc_error] = STATE(1521),
    [sym_preproc_warning] = STATE(1521),
    [sym_preproc_define] = STATE(1521),
    [sym_preproc_undef] = STATE(1521),
    [aux_sym_class_declaration_repeat1] = STATE(3817),
    [aux_sym_lambda_expression_repeat1] = STATE(4227),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1389),
    [anon_sym_ref] = ACTIONS(1391),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1117),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(1393),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_AMP] = ACTIONS(1117),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1395),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1397),
    [anon_sym_DOT_DOT] = ACTIONS(1399),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1522] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6984),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3926),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3903),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7428),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9348),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1522),
    [sym_preproc_endregion] = STATE(1522),
    [sym_preproc_line] = STATE(1522),
    [sym_preproc_pragma] = STATE(1522),
    [sym_preproc_nullable] = STATE(1522),
    [sym_preproc_error] = STATE(1522),
    [sym_preproc_warning] = STATE(1522),
    [sym_preproc_define] = STATE(1522),
    [sym_preproc_undef] = STATE(1522),
    [aux_sym_class_declaration_repeat1] = STATE(3817),
    [aux_sym_lambda_expression_repeat1] = STATE(4227),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1389),
    [anon_sym_ref] = ACTIONS(1391),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1117),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(1393),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_AMP] = ACTIONS(1117),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1395),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1397),
    [anon_sym_DOT_DOT] = ACTIONS(1399),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1523] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6984),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5148),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3903),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7428),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9348),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1523),
    [sym_preproc_endregion] = STATE(1523),
    [sym_preproc_line] = STATE(1523),
    [sym_preproc_pragma] = STATE(1523),
    [sym_preproc_nullable] = STATE(1523),
    [sym_preproc_error] = STATE(1523),
    [sym_preproc_warning] = STATE(1523),
    [sym_preproc_define] = STATE(1523),
    [sym_preproc_undef] = STATE(1523),
    [aux_sym_class_declaration_repeat1] = STATE(3817),
    [aux_sym_lambda_expression_repeat1] = STATE(4227),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1389),
    [anon_sym_ref] = ACTIONS(1391),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1117),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(1393),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_AMP] = ACTIONS(1117),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1395),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1397),
    [anon_sym_DOT_DOT] = ACTIONS(1399),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1524] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6984),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5237),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3903),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7428),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9348),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1524),
    [sym_preproc_endregion] = STATE(1524),
    [sym_preproc_line] = STATE(1524),
    [sym_preproc_pragma] = STATE(1524),
    [sym_preproc_nullable] = STATE(1524),
    [sym_preproc_error] = STATE(1524),
    [sym_preproc_warning] = STATE(1524),
    [sym_preproc_define] = STATE(1524),
    [sym_preproc_undef] = STATE(1524),
    [aux_sym_class_declaration_repeat1] = STATE(3817),
    [aux_sym_lambda_expression_repeat1] = STATE(4227),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1389),
    [anon_sym_ref] = ACTIONS(1391),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1117),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(1393),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_AMP] = ACTIONS(1117),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1395),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1397),
    [anon_sym_DOT_DOT] = ACTIONS(1399),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1525] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6927),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2912),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7057),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5307),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3960),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7439),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9222),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1525),
    [sym_preproc_endregion] = STATE(1525),
    [sym_preproc_line] = STATE(1525),
    [sym_preproc_pragma] = STATE(1525),
    [sym_preproc_nullable] = STATE(1525),
    [sym_preproc_error] = STATE(1525),
    [sym_preproc_warning] = STATE(1525),
    [sym_preproc_define] = STATE(1525),
    [sym_preproc_undef] = STATE(1525),
    [aux_sym_class_declaration_repeat1] = STATE(3837),
    [aux_sym_lambda_expression_repeat1] = STATE(4265),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1591),
    [anon_sym_ref] = ACTIONS(1593),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1595),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1599),
    [anon_sym_TILDE] = ACTIONS(1599),
    [anon_sym_PLUS_PLUS] = ACTIONS(1599),
    [anon_sym_DASH_DASH] = ACTIONS(1599),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1597),
    [anon_sym_DASH] = ACTIONS(1597),
    [anon_sym_STAR] = ACTIONS(1601),
    [anon_sym_CARET] = ACTIONS(1599),
    [anon_sym_AMP] = ACTIONS(1599),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1603),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1605),
    [anon_sym_DOT_DOT] = ACTIONS(1607),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1526] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6927),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2912),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7057),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3838),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3960),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7439),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9222),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1526),
    [sym_preproc_endregion] = STATE(1526),
    [sym_preproc_line] = STATE(1526),
    [sym_preproc_pragma] = STATE(1526),
    [sym_preproc_nullable] = STATE(1526),
    [sym_preproc_error] = STATE(1526),
    [sym_preproc_warning] = STATE(1526),
    [sym_preproc_define] = STATE(1526),
    [sym_preproc_undef] = STATE(1526),
    [aux_sym_class_declaration_repeat1] = STATE(3837),
    [aux_sym_lambda_expression_repeat1] = STATE(4265),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1591),
    [anon_sym_ref] = ACTIONS(1593),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1595),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1599),
    [anon_sym_TILDE] = ACTIONS(1599),
    [anon_sym_PLUS_PLUS] = ACTIONS(1599),
    [anon_sym_DASH_DASH] = ACTIONS(1599),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1597),
    [anon_sym_DASH] = ACTIONS(1597),
    [anon_sym_STAR] = ACTIONS(1601),
    [anon_sym_CARET] = ACTIONS(1599),
    [anon_sym_AMP] = ACTIONS(1599),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1603),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1605),
    [anon_sym_DOT_DOT] = ACTIONS(1607),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1527] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6941),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2977),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7077),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5476),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4200),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7415),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9773),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1527),
    [sym_preproc_endregion] = STATE(1527),
    [sym_preproc_line] = STATE(1527),
    [sym_preproc_pragma] = STATE(1527),
    [sym_preproc_nullable] = STATE(1527),
    [sym_preproc_error] = STATE(1527),
    [sym_preproc_warning] = STATE(1527),
    [sym_preproc_define] = STATE(1527),
    [sym_preproc_undef] = STATE(1527),
    [aux_sym_class_declaration_repeat1] = STATE(3843),
    [aux_sym_lambda_expression_repeat1] = STATE(4275),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1911),
    [anon_sym_ref] = ACTIONS(1913),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1915),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1919),
    [anon_sym_TILDE] = ACTIONS(1919),
    [anon_sym_PLUS_PLUS] = ACTIONS(1919),
    [anon_sym_DASH_DASH] = ACTIONS(1919),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1917),
    [anon_sym_DASH] = ACTIONS(1917),
    [anon_sym_STAR] = ACTIONS(1921),
    [anon_sym_CARET] = ACTIONS(1919),
    [anon_sym_AMP] = ACTIONS(1919),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1923),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1925),
    [anon_sym_DOT_DOT] = ACTIONS(1927),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1528] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6941),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2977),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7077),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5636),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4200),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7415),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9773),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1528),
    [sym_preproc_endregion] = STATE(1528),
    [sym_preproc_line] = STATE(1528),
    [sym_preproc_pragma] = STATE(1528),
    [sym_preproc_nullable] = STATE(1528),
    [sym_preproc_error] = STATE(1528),
    [sym_preproc_warning] = STATE(1528),
    [sym_preproc_define] = STATE(1528),
    [sym_preproc_undef] = STATE(1528),
    [aux_sym_class_declaration_repeat1] = STATE(3843),
    [aux_sym_lambda_expression_repeat1] = STATE(4275),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1911),
    [anon_sym_ref] = ACTIONS(1913),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1915),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1919),
    [anon_sym_TILDE] = ACTIONS(1919),
    [anon_sym_PLUS_PLUS] = ACTIONS(1919),
    [anon_sym_DASH_DASH] = ACTIONS(1919),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1917),
    [anon_sym_DASH] = ACTIONS(1917),
    [anon_sym_STAR] = ACTIONS(1921),
    [anon_sym_CARET] = ACTIONS(1919),
    [anon_sym_AMP] = ACTIONS(1919),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1923),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1925),
    [anon_sym_DOT_DOT] = ACTIONS(1927),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1529] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6941),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2977),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7077),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5459),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4200),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7415),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9773),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1529),
    [sym_preproc_endregion] = STATE(1529),
    [sym_preproc_line] = STATE(1529),
    [sym_preproc_pragma] = STATE(1529),
    [sym_preproc_nullable] = STATE(1529),
    [sym_preproc_error] = STATE(1529),
    [sym_preproc_warning] = STATE(1529),
    [sym_preproc_define] = STATE(1529),
    [sym_preproc_undef] = STATE(1529),
    [aux_sym_class_declaration_repeat1] = STATE(3843),
    [aux_sym_lambda_expression_repeat1] = STATE(4275),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1911),
    [anon_sym_ref] = ACTIONS(1913),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1915),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1919),
    [anon_sym_TILDE] = ACTIONS(1919),
    [anon_sym_PLUS_PLUS] = ACTIONS(1919),
    [anon_sym_DASH_DASH] = ACTIONS(1919),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1917),
    [anon_sym_DASH] = ACTIONS(1917),
    [anon_sym_STAR] = ACTIONS(1921),
    [anon_sym_CARET] = ACTIONS(1919),
    [anon_sym_AMP] = ACTIONS(1919),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1923),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1925),
    [anon_sym_DOT_DOT] = ACTIONS(1927),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1530] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6941),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2977),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7077),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5460),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4200),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7415),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9773),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1530),
    [sym_preproc_endregion] = STATE(1530),
    [sym_preproc_line] = STATE(1530),
    [sym_preproc_pragma] = STATE(1530),
    [sym_preproc_nullable] = STATE(1530),
    [sym_preproc_error] = STATE(1530),
    [sym_preproc_warning] = STATE(1530),
    [sym_preproc_define] = STATE(1530),
    [sym_preproc_undef] = STATE(1530),
    [aux_sym_class_declaration_repeat1] = STATE(3843),
    [aux_sym_lambda_expression_repeat1] = STATE(4275),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1911),
    [anon_sym_ref] = ACTIONS(1913),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1915),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1919),
    [anon_sym_TILDE] = ACTIONS(1919),
    [anon_sym_PLUS_PLUS] = ACTIONS(1919),
    [anon_sym_DASH_DASH] = ACTIONS(1919),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1917),
    [anon_sym_DASH] = ACTIONS(1917),
    [anon_sym_STAR] = ACTIONS(1921),
    [anon_sym_CARET] = ACTIONS(1919),
    [anon_sym_AMP] = ACTIONS(1919),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1923),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1925),
    [anon_sym_DOT_DOT] = ACTIONS(1927),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1531] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6941),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2977),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7077),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5461),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4200),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7415),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9773),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1531),
    [sym_preproc_endregion] = STATE(1531),
    [sym_preproc_line] = STATE(1531),
    [sym_preproc_pragma] = STATE(1531),
    [sym_preproc_nullable] = STATE(1531),
    [sym_preproc_error] = STATE(1531),
    [sym_preproc_warning] = STATE(1531),
    [sym_preproc_define] = STATE(1531),
    [sym_preproc_undef] = STATE(1531),
    [aux_sym_class_declaration_repeat1] = STATE(3843),
    [aux_sym_lambda_expression_repeat1] = STATE(4275),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1911),
    [anon_sym_ref] = ACTIONS(1913),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1915),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1919),
    [anon_sym_TILDE] = ACTIONS(1919),
    [anon_sym_PLUS_PLUS] = ACTIONS(1919),
    [anon_sym_DASH_DASH] = ACTIONS(1919),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1917),
    [anon_sym_DASH] = ACTIONS(1917),
    [anon_sym_STAR] = ACTIONS(1921),
    [anon_sym_CARET] = ACTIONS(1919),
    [anon_sym_AMP] = ACTIONS(1919),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1923),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1925),
    [anon_sym_DOT_DOT] = ACTIONS(1927),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1532] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6941),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2977),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7077),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5477),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4200),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7415),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9773),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1532),
    [sym_preproc_endregion] = STATE(1532),
    [sym_preproc_line] = STATE(1532),
    [sym_preproc_pragma] = STATE(1532),
    [sym_preproc_nullable] = STATE(1532),
    [sym_preproc_error] = STATE(1532),
    [sym_preproc_warning] = STATE(1532),
    [sym_preproc_define] = STATE(1532),
    [sym_preproc_undef] = STATE(1532),
    [aux_sym_class_declaration_repeat1] = STATE(3843),
    [aux_sym_lambda_expression_repeat1] = STATE(4275),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1911),
    [anon_sym_ref] = ACTIONS(1913),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1915),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1919),
    [anon_sym_TILDE] = ACTIONS(1919),
    [anon_sym_PLUS_PLUS] = ACTIONS(1919),
    [anon_sym_DASH_DASH] = ACTIONS(1919),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1917),
    [anon_sym_DASH] = ACTIONS(1917),
    [anon_sym_STAR] = ACTIONS(1921),
    [anon_sym_CARET] = ACTIONS(1919),
    [anon_sym_AMP] = ACTIONS(1919),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1923),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1925),
    [anon_sym_DOT_DOT] = ACTIONS(1927),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1533] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6941),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2977),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7077),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5462),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4200),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7415),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9773),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1533),
    [sym_preproc_endregion] = STATE(1533),
    [sym_preproc_line] = STATE(1533),
    [sym_preproc_pragma] = STATE(1533),
    [sym_preproc_nullable] = STATE(1533),
    [sym_preproc_error] = STATE(1533),
    [sym_preproc_warning] = STATE(1533),
    [sym_preproc_define] = STATE(1533),
    [sym_preproc_undef] = STATE(1533),
    [aux_sym_class_declaration_repeat1] = STATE(3843),
    [aux_sym_lambda_expression_repeat1] = STATE(4275),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1911),
    [anon_sym_ref] = ACTIONS(1913),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1915),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1919),
    [anon_sym_TILDE] = ACTIONS(1919),
    [anon_sym_PLUS_PLUS] = ACTIONS(1919),
    [anon_sym_DASH_DASH] = ACTIONS(1919),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1917),
    [anon_sym_DASH] = ACTIONS(1917),
    [anon_sym_STAR] = ACTIONS(1921),
    [anon_sym_CARET] = ACTIONS(1919),
    [anon_sym_AMP] = ACTIONS(1919),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1923),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1925),
    [anon_sym_DOT_DOT] = ACTIONS(1927),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1534] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6941),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2977),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7077),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5463),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4200),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7415),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9773),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1534),
    [sym_preproc_endregion] = STATE(1534),
    [sym_preproc_line] = STATE(1534),
    [sym_preproc_pragma] = STATE(1534),
    [sym_preproc_nullable] = STATE(1534),
    [sym_preproc_error] = STATE(1534),
    [sym_preproc_warning] = STATE(1534),
    [sym_preproc_define] = STATE(1534),
    [sym_preproc_undef] = STATE(1534),
    [aux_sym_class_declaration_repeat1] = STATE(3843),
    [aux_sym_lambda_expression_repeat1] = STATE(4275),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1911),
    [anon_sym_ref] = ACTIONS(1913),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1915),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1919),
    [anon_sym_TILDE] = ACTIONS(1919),
    [anon_sym_PLUS_PLUS] = ACTIONS(1919),
    [anon_sym_DASH_DASH] = ACTIONS(1919),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1917),
    [anon_sym_DASH] = ACTIONS(1917),
    [anon_sym_STAR] = ACTIONS(1921),
    [anon_sym_CARET] = ACTIONS(1919),
    [anon_sym_AMP] = ACTIONS(1919),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1923),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1925),
    [anon_sym_DOT_DOT] = ACTIONS(1927),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1535] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6941),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2977),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7077),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5464),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4200),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7415),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9773),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1535),
    [sym_preproc_endregion] = STATE(1535),
    [sym_preproc_line] = STATE(1535),
    [sym_preproc_pragma] = STATE(1535),
    [sym_preproc_nullable] = STATE(1535),
    [sym_preproc_error] = STATE(1535),
    [sym_preproc_warning] = STATE(1535),
    [sym_preproc_define] = STATE(1535),
    [sym_preproc_undef] = STATE(1535),
    [aux_sym_class_declaration_repeat1] = STATE(3843),
    [aux_sym_lambda_expression_repeat1] = STATE(4275),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1911),
    [anon_sym_ref] = ACTIONS(1913),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1915),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1919),
    [anon_sym_TILDE] = ACTIONS(1919),
    [anon_sym_PLUS_PLUS] = ACTIONS(1919),
    [anon_sym_DASH_DASH] = ACTIONS(1919),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1917),
    [anon_sym_DASH] = ACTIONS(1917),
    [anon_sym_STAR] = ACTIONS(1921),
    [anon_sym_CARET] = ACTIONS(1919),
    [anon_sym_AMP] = ACTIONS(1919),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1923),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1925),
    [anon_sym_DOT_DOT] = ACTIONS(1927),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1536] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6941),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2977),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7077),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5465),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4200),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7415),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9773),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1536),
    [sym_preproc_endregion] = STATE(1536),
    [sym_preproc_line] = STATE(1536),
    [sym_preproc_pragma] = STATE(1536),
    [sym_preproc_nullable] = STATE(1536),
    [sym_preproc_error] = STATE(1536),
    [sym_preproc_warning] = STATE(1536),
    [sym_preproc_define] = STATE(1536),
    [sym_preproc_undef] = STATE(1536),
    [aux_sym_class_declaration_repeat1] = STATE(3843),
    [aux_sym_lambda_expression_repeat1] = STATE(4275),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1911),
    [anon_sym_ref] = ACTIONS(1913),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1915),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1919),
    [anon_sym_TILDE] = ACTIONS(1919),
    [anon_sym_PLUS_PLUS] = ACTIONS(1919),
    [anon_sym_DASH_DASH] = ACTIONS(1919),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1917),
    [anon_sym_DASH] = ACTIONS(1917),
    [anon_sym_STAR] = ACTIONS(1921),
    [anon_sym_CARET] = ACTIONS(1919),
    [anon_sym_AMP] = ACTIONS(1919),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1923),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1925),
    [anon_sym_DOT_DOT] = ACTIONS(1927),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1537] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6927),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2912),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7057),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5319),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3960),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7439),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9222),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1537),
    [sym_preproc_endregion] = STATE(1537),
    [sym_preproc_line] = STATE(1537),
    [sym_preproc_pragma] = STATE(1537),
    [sym_preproc_nullable] = STATE(1537),
    [sym_preproc_error] = STATE(1537),
    [sym_preproc_warning] = STATE(1537),
    [sym_preproc_define] = STATE(1537),
    [sym_preproc_undef] = STATE(1537),
    [aux_sym_class_declaration_repeat1] = STATE(3837),
    [aux_sym_lambda_expression_repeat1] = STATE(4265),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1591),
    [anon_sym_ref] = ACTIONS(1593),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1595),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1599),
    [anon_sym_TILDE] = ACTIONS(1599),
    [anon_sym_PLUS_PLUS] = ACTIONS(1599),
    [anon_sym_DASH_DASH] = ACTIONS(1599),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1597),
    [anon_sym_DASH] = ACTIONS(1597),
    [anon_sym_STAR] = ACTIONS(1601),
    [anon_sym_CARET] = ACTIONS(1599),
    [anon_sym_AMP] = ACTIONS(1599),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1603),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1605),
    [anon_sym_DOT_DOT] = ACTIONS(1607),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1538] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6941),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2977),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7077),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3867),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4200),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7415),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9773),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1538),
    [sym_preproc_endregion] = STATE(1538),
    [sym_preproc_line] = STATE(1538),
    [sym_preproc_pragma] = STATE(1538),
    [sym_preproc_nullable] = STATE(1538),
    [sym_preproc_error] = STATE(1538),
    [sym_preproc_warning] = STATE(1538),
    [sym_preproc_define] = STATE(1538),
    [sym_preproc_undef] = STATE(1538),
    [aux_sym_class_declaration_repeat1] = STATE(3843),
    [aux_sym_lambda_expression_repeat1] = STATE(4275),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1911),
    [anon_sym_ref] = ACTIONS(1913),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1915),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1919),
    [anon_sym_TILDE] = ACTIONS(1919),
    [anon_sym_PLUS_PLUS] = ACTIONS(1919),
    [anon_sym_DASH_DASH] = ACTIONS(1919),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1917),
    [anon_sym_DASH] = ACTIONS(1917),
    [anon_sym_STAR] = ACTIONS(1921),
    [anon_sym_CARET] = ACTIONS(1919),
    [anon_sym_AMP] = ACTIONS(1919),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1923),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1925),
    [anon_sym_DOT_DOT] = ACTIONS(1927),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1539] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6927),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2912),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7057),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5245),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3960),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7439),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9222),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1539),
    [sym_preproc_endregion] = STATE(1539),
    [sym_preproc_line] = STATE(1539),
    [sym_preproc_pragma] = STATE(1539),
    [sym_preproc_nullable] = STATE(1539),
    [sym_preproc_error] = STATE(1539),
    [sym_preproc_warning] = STATE(1539),
    [sym_preproc_define] = STATE(1539),
    [sym_preproc_undef] = STATE(1539),
    [aux_sym_class_declaration_repeat1] = STATE(3837),
    [aux_sym_lambda_expression_repeat1] = STATE(4265),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1591),
    [anon_sym_ref] = ACTIONS(1593),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1595),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1599),
    [anon_sym_TILDE] = ACTIONS(1599),
    [anon_sym_PLUS_PLUS] = ACTIONS(1599),
    [anon_sym_DASH_DASH] = ACTIONS(1599),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1597),
    [anon_sym_DASH] = ACTIONS(1597),
    [anon_sym_STAR] = ACTIONS(1601),
    [anon_sym_CARET] = ACTIONS(1599),
    [anon_sym_AMP] = ACTIONS(1599),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1603),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1605),
    [anon_sym_DOT_DOT] = ACTIONS(1607),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1540] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6956),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6546),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9482),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1540),
    [sym_preproc_endregion] = STATE(1540),
    [sym_preproc_line] = STATE(1540),
    [sym_preproc_pragma] = STATE(1540),
    [sym_preproc_nullable] = STATE(1540),
    [sym_preproc_error] = STATE(1540),
    [sym_preproc_warning] = STATE(1540),
    [sym_preproc_define] = STATE(1540),
    [sym_preproc_undef] = STATE(1540),
    [aux_sym_class_declaration_repeat1] = STATE(3853),
    [aux_sym_lambda_expression_repeat1] = STATE(4299),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1497),
    [anon_sym_ref] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1505),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1507),
    [anon_sym_DOT_DOT] = ACTIONS(1509),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1541] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6948),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2940),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6999),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4951),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3857),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7444),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9574),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1541),
    [sym_preproc_endregion] = STATE(1541),
    [sym_preproc_line] = STATE(1541),
    [sym_preproc_pragma] = STATE(1541),
    [sym_preproc_nullable] = STATE(1541),
    [sym_preproc_error] = STATE(1541),
    [sym_preproc_warning] = STATE(1541),
    [sym_preproc_define] = STATE(1541),
    [sym_preproc_undef] = STATE(1541),
    [aux_sym_class_declaration_repeat1] = STATE(3854),
    [aux_sym_lambda_expression_repeat1] = STATE(4136),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2111),
    [anon_sym_ref] = ACTIONS(2113),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1897),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2117),
    [anon_sym_TILDE] = ACTIONS(2117),
    [anon_sym_PLUS_PLUS] = ACTIONS(2117),
    [anon_sym_DASH_DASH] = ACTIONS(2117),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2115),
    [anon_sym_DASH] = ACTIONS(2115),
    [anon_sym_STAR] = ACTIONS(1903),
    [anon_sym_CARET] = ACTIONS(2117),
    [anon_sym_AMP] = ACTIONS(2117),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2119),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2121),
    [anon_sym_DOT_DOT] = ACTIONS(2123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1542] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6920),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2942),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7105),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3056),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1542),
    [sym_preproc_endregion] = STATE(1542),
    [sym_preproc_line] = STATE(1542),
    [sym_preproc_pragma] = STATE(1542),
    [sym_preproc_nullable] = STATE(1542),
    [sym_preproc_error] = STATE(1542),
    [sym_preproc_warning] = STATE(1542),
    [sym_preproc_define] = STATE(1542),
    [sym_preproc_undef] = STATE(1542),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(2199),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1543] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7139),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6605),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1543),
    [sym_preproc_endregion] = STATE(1543),
    [sym_preproc_line] = STATE(1543),
    [sym_preproc_pragma] = STATE(1543),
    [sym_preproc_nullable] = STATE(1543),
    [sym_preproc_error] = STATE(1543),
    [sym_preproc_warning] = STATE(1543),
    [sym_preproc_define] = STATE(1543),
    [sym_preproc_undef] = STATE(1543),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2011),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1544] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7139),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4336),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1544),
    [sym_preproc_endregion] = STATE(1544),
    [sym_preproc_line] = STATE(1544),
    [sym_preproc_pragma] = STATE(1544),
    [sym_preproc_nullable] = STATE(1544),
    [sym_preproc_error] = STATE(1544),
    [sym_preproc_warning] = STATE(1544),
    [sym_preproc_define] = STATE(1544),
    [sym_preproc_undef] = STATE(1544),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2011),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1545] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7139),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6426),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1545),
    [sym_preproc_endregion] = STATE(1545),
    [sym_preproc_line] = STATE(1545),
    [sym_preproc_pragma] = STATE(1545),
    [sym_preproc_nullable] = STATE(1545),
    [sym_preproc_error] = STATE(1545),
    [sym_preproc_warning] = STATE(1545),
    [sym_preproc_define] = STATE(1545),
    [sym_preproc_undef] = STATE(1545),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2011),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1546] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7139),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6428),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1546),
    [sym_preproc_endregion] = STATE(1546),
    [sym_preproc_line] = STATE(1546),
    [sym_preproc_pragma] = STATE(1546),
    [sym_preproc_nullable] = STATE(1546),
    [sym_preproc_error] = STATE(1546),
    [sym_preproc_warning] = STATE(1546),
    [sym_preproc_define] = STATE(1546),
    [sym_preproc_undef] = STATE(1546),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2011),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1547] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7139),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6433),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1547),
    [sym_preproc_endregion] = STATE(1547),
    [sym_preproc_line] = STATE(1547),
    [sym_preproc_pragma] = STATE(1547),
    [sym_preproc_nullable] = STATE(1547),
    [sym_preproc_error] = STATE(1547),
    [sym_preproc_warning] = STATE(1547),
    [sym_preproc_define] = STATE(1547),
    [sym_preproc_undef] = STATE(1547),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2011),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1548] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7139),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6434),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1548),
    [sym_preproc_endregion] = STATE(1548),
    [sym_preproc_line] = STATE(1548),
    [sym_preproc_pragma] = STATE(1548),
    [sym_preproc_nullable] = STATE(1548),
    [sym_preproc_error] = STATE(1548),
    [sym_preproc_warning] = STATE(1548),
    [sym_preproc_define] = STATE(1548),
    [sym_preproc_undef] = STATE(1548),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2011),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1549] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7139),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6435),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1549),
    [sym_preproc_endregion] = STATE(1549),
    [sym_preproc_line] = STATE(1549),
    [sym_preproc_pragma] = STATE(1549),
    [sym_preproc_nullable] = STATE(1549),
    [sym_preproc_error] = STATE(1549),
    [sym_preproc_warning] = STATE(1549),
    [sym_preproc_define] = STATE(1549),
    [sym_preproc_undef] = STATE(1549),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2011),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1550] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7139),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6436),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1550),
    [sym_preproc_endregion] = STATE(1550),
    [sym_preproc_line] = STATE(1550),
    [sym_preproc_pragma] = STATE(1550),
    [sym_preproc_nullable] = STATE(1550),
    [sym_preproc_error] = STATE(1550),
    [sym_preproc_warning] = STATE(1550),
    [sym_preproc_define] = STATE(1550),
    [sym_preproc_undef] = STATE(1550),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2011),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1551] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7139),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6437),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1551),
    [sym_preproc_endregion] = STATE(1551),
    [sym_preproc_line] = STATE(1551),
    [sym_preproc_pragma] = STATE(1551),
    [sym_preproc_nullable] = STATE(1551),
    [sym_preproc_error] = STATE(1551),
    [sym_preproc_warning] = STATE(1551),
    [sym_preproc_define] = STATE(1551),
    [sym_preproc_undef] = STATE(1551),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2011),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1552] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7139),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6438),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1552),
    [sym_preproc_endregion] = STATE(1552),
    [sym_preproc_line] = STATE(1552),
    [sym_preproc_pragma] = STATE(1552),
    [sym_preproc_nullable] = STATE(1552),
    [sym_preproc_error] = STATE(1552),
    [sym_preproc_warning] = STATE(1552),
    [sym_preproc_define] = STATE(1552),
    [sym_preproc_undef] = STATE(1552),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2011),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1553] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7139),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6440),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1553),
    [sym_preproc_endregion] = STATE(1553),
    [sym_preproc_line] = STATE(1553),
    [sym_preproc_pragma] = STATE(1553),
    [sym_preproc_nullable] = STATE(1553),
    [sym_preproc_error] = STATE(1553),
    [sym_preproc_warning] = STATE(1553),
    [sym_preproc_define] = STATE(1553),
    [sym_preproc_undef] = STATE(1553),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2011),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1554] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7139),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6441),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1554),
    [sym_preproc_endregion] = STATE(1554),
    [sym_preproc_line] = STATE(1554),
    [sym_preproc_pragma] = STATE(1554),
    [sym_preproc_nullable] = STATE(1554),
    [sym_preproc_error] = STATE(1554),
    [sym_preproc_warning] = STATE(1554),
    [sym_preproc_define] = STATE(1554),
    [sym_preproc_undef] = STATE(1554),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2011),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1555] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7139),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6442),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1555),
    [sym_preproc_endregion] = STATE(1555),
    [sym_preproc_line] = STATE(1555),
    [sym_preproc_pragma] = STATE(1555),
    [sym_preproc_nullable] = STATE(1555),
    [sym_preproc_error] = STATE(1555),
    [sym_preproc_warning] = STATE(1555),
    [sym_preproc_define] = STATE(1555),
    [sym_preproc_undef] = STATE(1555),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2011),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1556] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7139),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6634),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1556),
    [sym_preproc_endregion] = STATE(1556),
    [sym_preproc_line] = STATE(1556),
    [sym_preproc_pragma] = STATE(1556),
    [sym_preproc_nullable] = STATE(1556),
    [sym_preproc_error] = STATE(1556),
    [sym_preproc_warning] = STATE(1556),
    [sym_preproc_define] = STATE(1556),
    [sym_preproc_undef] = STATE(1556),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2011),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1557] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6932),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2977),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6996),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6290),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4378),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7430),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9693),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1557),
    [sym_preproc_endregion] = STATE(1557),
    [sym_preproc_line] = STATE(1557),
    [sym_preproc_pragma] = STATE(1557),
    [sym_preproc_nullable] = STATE(1557),
    [sym_preproc_error] = STATE(1557),
    [sym_preproc_warning] = STATE(1557),
    [sym_preproc_define] = STATE(1557),
    [sym_preproc_undef] = STATE(1557),
    [aux_sym_class_declaration_repeat1] = STATE(3820),
    [aux_sym_lambda_expression_repeat1] = STATE(4234),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2127),
    [anon_sym_ref] = ACTIONS(2129),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2131),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2135),
    [anon_sym_TILDE] = ACTIONS(2135),
    [anon_sym_PLUS_PLUS] = ACTIONS(2135),
    [anon_sym_DASH_DASH] = ACTIONS(2135),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2133),
    [anon_sym_DASH] = ACTIONS(2133),
    [anon_sym_STAR] = ACTIONS(2137),
    [anon_sym_CARET] = ACTIONS(2135),
    [anon_sym_AMP] = ACTIONS(2135),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2139),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2141),
    [anon_sym_DOT_DOT] = ACTIONS(2143),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1558] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7139),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4338),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1558),
    [sym_preproc_endregion] = STATE(1558),
    [sym_preproc_line] = STATE(1558),
    [sym_preproc_pragma] = STATE(1558),
    [sym_preproc_nullable] = STATE(1558),
    [sym_preproc_error] = STATE(1558),
    [sym_preproc_warning] = STATE(1558),
    [sym_preproc_define] = STATE(1558),
    [sym_preproc_undef] = STATE(1558),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2011),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1559] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7014),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6038),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4335),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7428),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9866),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1559),
    [sym_preproc_endregion] = STATE(1559),
    [sym_preproc_line] = STATE(1559),
    [sym_preproc_pragma] = STATE(1559),
    [sym_preproc_nullable] = STATE(1559),
    [sym_preproc_error] = STATE(1559),
    [sym_preproc_warning] = STATE(1559),
    [sym_preproc_define] = STATE(1559),
    [sym_preproc_undef] = STATE(1559),
    [aux_sym_class_declaration_repeat1] = STATE(3824),
    [aux_sym_lambda_expression_repeat1] = STATE(4242),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1539),
    [anon_sym_ref] = ACTIONS(1541),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1545),
    [anon_sym_TILDE] = ACTIONS(1545),
    [anon_sym_PLUS_PLUS] = ACTIONS(1545),
    [anon_sym_DASH_DASH] = ACTIONS(1545),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1543),
    [anon_sym_DASH] = ACTIONS(1543),
    [anon_sym_STAR] = ACTIONS(1547),
    [anon_sym_CARET] = ACTIONS(1545),
    [anon_sym_AMP] = ACTIONS(1545),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1549),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1551),
    [anon_sym_DOT_DOT] = ACTIONS(1553),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1560] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6935),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6420),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4473),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9905),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1560),
    [sym_preproc_endregion] = STATE(1560),
    [sym_preproc_line] = STATE(1560),
    [sym_preproc_pragma] = STATE(1560),
    [sym_preproc_nullable] = STATE(1560),
    [sym_preproc_error] = STATE(1560),
    [sym_preproc_warning] = STATE(1560),
    [sym_preproc_define] = STATE(1560),
    [sym_preproc_undef] = STATE(1560),
    [aux_sym_class_declaration_repeat1] = STATE(3878),
    [aux_sym_lambda_expression_repeat1] = STATE(4331),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2055),
    [anon_sym_ref] = ACTIONS(2057),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2061),
    [anon_sym_TILDE] = ACTIONS(2061),
    [anon_sym_PLUS_PLUS] = ACTIONS(2061),
    [anon_sym_DASH_DASH] = ACTIONS(2061),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2059),
    [anon_sym_DASH] = ACTIONS(2059),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(2061),
    [anon_sym_AMP] = ACTIONS(2061),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2063),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2065),
    [anon_sym_DOT_DOT] = ACTIONS(2067),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1561] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7139),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6455),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1561),
    [sym_preproc_endregion] = STATE(1561),
    [sym_preproc_line] = STATE(1561),
    [sym_preproc_pragma] = STATE(1561),
    [sym_preproc_nullable] = STATE(1561),
    [sym_preproc_error] = STATE(1561),
    [sym_preproc_warning] = STATE(1561),
    [sym_preproc_define] = STATE(1561),
    [sym_preproc_undef] = STATE(1561),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2011),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1562] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6449),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1562),
    [sym_preproc_endregion] = STATE(1562),
    [sym_preproc_line] = STATE(1562),
    [sym_preproc_pragma] = STATE(1562),
    [sym_preproc_nullable] = STATE(1562),
    [sym_preproc_error] = STATE(1562),
    [sym_preproc_warning] = STATE(1562),
    [sym_preproc_define] = STATE(1562),
    [sym_preproc_undef] = STATE(1562),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1563] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6932),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2977),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6996),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6294),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4378),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7430),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9693),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1563),
    [sym_preproc_endregion] = STATE(1563),
    [sym_preproc_line] = STATE(1563),
    [sym_preproc_pragma] = STATE(1563),
    [sym_preproc_nullable] = STATE(1563),
    [sym_preproc_error] = STATE(1563),
    [sym_preproc_warning] = STATE(1563),
    [sym_preproc_define] = STATE(1563),
    [sym_preproc_undef] = STATE(1563),
    [aux_sym_class_declaration_repeat1] = STATE(3820),
    [aux_sym_lambda_expression_repeat1] = STATE(4234),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2127),
    [anon_sym_ref] = ACTIONS(2129),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2131),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2135),
    [anon_sym_TILDE] = ACTIONS(2135),
    [anon_sym_PLUS_PLUS] = ACTIONS(2135),
    [anon_sym_DASH_DASH] = ACTIONS(2135),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2133),
    [anon_sym_DASH] = ACTIONS(2133),
    [anon_sym_STAR] = ACTIONS(2137),
    [anon_sym_CARET] = ACTIONS(2135),
    [anon_sym_AMP] = ACTIONS(2135),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2139),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2141),
    [anon_sym_DOT_DOT] = ACTIONS(2143),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1564] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6917),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2905),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7006),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5480),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4199),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7447),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9823),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1564),
    [sym_preproc_endregion] = STATE(1564),
    [sym_preproc_line] = STATE(1564),
    [sym_preproc_pragma] = STATE(1564),
    [sym_preproc_nullable] = STATE(1564),
    [sym_preproc_error] = STATE(1564),
    [sym_preproc_warning] = STATE(1564),
    [sym_preproc_define] = STATE(1564),
    [sym_preproc_undef] = STATE(1564),
    [aux_sym_class_declaration_repeat1] = STATE(3822),
    [aux_sym_lambda_expression_repeat1] = STATE(4238),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1623),
    [anon_sym_ref] = ACTIONS(1625),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1577),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1629),
    [anon_sym_TILDE] = ACTIONS(1629),
    [anon_sym_PLUS_PLUS] = ACTIONS(1629),
    [anon_sym_DASH_DASH] = ACTIONS(1629),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1627),
    [anon_sym_DASH] = ACTIONS(1627),
    [anon_sym_STAR] = ACTIONS(1631),
    [anon_sym_CARET] = ACTIONS(1629),
    [anon_sym_AMP] = ACTIONS(1629),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1633),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1635),
    [anon_sym_DOT_DOT] = ACTIONS(1637),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1565] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6917),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2905),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7006),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5481),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4199),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7447),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9823),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1565),
    [sym_preproc_endregion] = STATE(1565),
    [sym_preproc_line] = STATE(1565),
    [sym_preproc_pragma] = STATE(1565),
    [sym_preproc_nullable] = STATE(1565),
    [sym_preproc_error] = STATE(1565),
    [sym_preproc_warning] = STATE(1565),
    [sym_preproc_define] = STATE(1565),
    [sym_preproc_undef] = STATE(1565),
    [aux_sym_class_declaration_repeat1] = STATE(3822),
    [aux_sym_lambda_expression_repeat1] = STATE(4238),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1623),
    [anon_sym_ref] = ACTIONS(1625),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1577),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1629),
    [anon_sym_TILDE] = ACTIONS(1629),
    [anon_sym_PLUS_PLUS] = ACTIONS(1629),
    [anon_sym_DASH_DASH] = ACTIONS(1629),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1627),
    [anon_sym_DASH] = ACTIONS(1627),
    [anon_sym_STAR] = ACTIONS(1631),
    [anon_sym_CARET] = ACTIONS(1629),
    [anon_sym_AMP] = ACTIONS(1629),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1633),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1635),
    [anon_sym_DOT_DOT] = ACTIONS(1637),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1566] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6917),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2905),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7006),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5709),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4199),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7447),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9823),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1566),
    [sym_preproc_endregion] = STATE(1566),
    [sym_preproc_line] = STATE(1566),
    [sym_preproc_pragma] = STATE(1566),
    [sym_preproc_nullable] = STATE(1566),
    [sym_preproc_error] = STATE(1566),
    [sym_preproc_warning] = STATE(1566),
    [sym_preproc_define] = STATE(1566),
    [sym_preproc_undef] = STATE(1566),
    [aux_sym_class_declaration_repeat1] = STATE(3822),
    [aux_sym_lambda_expression_repeat1] = STATE(4238),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1623),
    [anon_sym_ref] = ACTIONS(1625),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1577),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1629),
    [anon_sym_TILDE] = ACTIONS(1629),
    [anon_sym_PLUS_PLUS] = ACTIONS(1629),
    [anon_sym_DASH_DASH] = ACTIONS(1629),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1627),
    [anon_sym_DASH] = ACTIONS(1627),
    [anon_sym_STAR] = ACTIONS(1631),
    [anon_sym_CARET] = ACTIONS(1629),
    [anon_sym_AMP] = ACTIONS(1629),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1633),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1635),
    [anon_sym_DOT_DOT] = ACTIONS(1637),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1567] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6917),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2905),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7006),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5482),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4199),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7447),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9823),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1567),
    [sym_preproc_endregion] = STATE(1567),
    [sym_preproc_line] = STATE(1567),
    [sym_preproc_pragma] = STATE(1567),
    [sym_preproc_nullable] = STATE(1567),
    [sym_preproc_error] = STATE(1567),
    [sym_preproc_warning] = STATE(1567),
    [sym_preproc_define] = STATE(1567),
    [sym_preproc_undef] = STATE(1567),
    [aux_sym_class_declaration_repeat1] = STATE(3822),
    [aux_sym_lambda_expression_repeat1] = STATE(4238),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1623),
    [anon_sym_ref] = ACTIONS(1625),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1577),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1629),
    [anon_sym_TILDE] = ACTIONS(1629),
    [anon_sym_PLUS_PLUS] = ACTIONS(1629),
    [anon_sym_DASH_DASH] = ACTIONS(1629),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1627),
    [anon_sym_DASH] = ACTIONS(1627),
    [anon_sym_STAR] = ACTIONS(1631),
    [anon_sym_CARET] = ACTIONS(1629),
    [anon_sym_AMP] = ACTIONS(1629),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1633),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1635),
    [anon_sym_DOT_DOT] = ACTIONS(1637),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1568] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6917),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2905),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7006),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5483),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4199),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7447),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9823),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1568),
    [sym_preproc_endregion] = STATE(1568),
    [sym_preproc_line] = STATE(1568),
    [sym_preproc_pragma] = STATE(1568),
    [sym_preproc_nullable] = STATE(1568),
    [sym_preproc_error] = STATE(1568),
    [sym_preproc_warning] = STATE(1568),
    [sym_preproc_define] = STATE(1568),
    [sym_preproc_undef] = STATE(1568),
    [aux_sym_class_declaration_repeat1] = STATE(3822),
    [aux_sym_lambda_expression_repeat1] = STATE(4238),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1623),
    [anon_sym_ref] = ACTIONS(1625),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1577),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1629),
    [anon_sym_TILDE] = ACTIONS(1629),
    [anon_sym_PLUS_PLUS] = ACTIONS(1629),
    [anon_sym_DASH_DASH] = ACTIONS(1629),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1627),
    [anon_sym_DASH] = ACTIONS(1627),
    [anon_sym_STAR] = ACTIONS(1631),
    [anon_sym_CARET] = ACTIONS(1629),
    [anon_sym_AMP] = ACTIONS(1629),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1633),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1635),
    [anon_sym_DOT_DOT] = ACTIONS(1637),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1569] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6917),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2905),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7006),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5484),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4199),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7447),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9823),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1569),
    [sym_preproc_endregion] = STATE(1569),
    [sym_preproc_line] = STATE(1569),
    [sym_preproc_pragma] = STATE(1569),
    [sym_preproc_nullable] = STATE(1569),
    [sym_preproc_error] = STATE(1569),
    [sym_preproc_warning] = STATE(1569),
    [sym_preproc_define] = STATE(1569),
    [sym_preproc_undef] = STATE(1569),
    [aux_sym_class_declaration_repeat1] = STATE(3822),
    [aux_sym_lambda_expression_repeat1] = STATE(4238),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1623),
    [anon_sym_ref] = ACTIONS(1625),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1577),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1629),
    [anon_sym_TILDE] = ACTIONS(1629),
    [anon_sym_PLUS_PLUS] = ACTIONS(1629),
    [anon_sym_DASH_DASH] = ACTIONS(1629),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1627),
    [anon_sym_DASH] = ACTIONS(1627),
    [anon_sym_STAR] = ACTIONS(1631),
    [anon_sym_CARET] = ACTIONS(1629),
    [anon_sym_AMP] = ACTIONS(1629),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1633),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1635),
    [anon_sym_DOT_DOT] = ACTIONS(1637),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1570] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6917),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2905),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7006),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5485),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4199),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7447),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9823),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1570),
    [sym_preproc_endregion] = STATE(1570),
    [sym_preproc_line] = STATE(1570),
    [sym_preproc_pragma] = STATE(1570),
    [sym_preproc_nullable] = STATE(1570),
    [sym_preproc_error] = STATE(1570),
    [sym_preproc_warning] = STATE(1570),
    [sym_preproc_define] = STATE(1570),
    [sym_preproc_undef] = STATE(1570),
    [aux_sym_class_declaration_repeat1] = STATE(3822),
    [aux_sym_lambda_expression_repeat1] = STATE(4238),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1623),
    [anon_sym_ref] = ACTIONS(1625),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1577),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1629),
    [anon_sym_TILDE] = ACTIONS(1629),
    [anon_sym_PLUS_PLUS] = ACTIONS(1629),
    [anon_sym_DASH_DASH] = ACTIONS(1629),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1627),
    [anon_sym_DASH] = ACTIONS(1627),
    [anon_sym_STAR] = ACTIONS(1631),
    [anon_sym_CARET] = ACTIONS(1629),
    [anon_sym_AMP] = ACTIONS(1629),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1633),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1635),
    [anon_sym_DOT_DOT] = ACTIONS(1637),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1571] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6917),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2905),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7006),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5486),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4199),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7447),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9823),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1571),
    [sym_preproc_endregion] = STATE(1571),
    [sym_preproc_line] = STATE(1571),
    [sym_preproc_pragma] = STATE(1571),
    [sym_preproc_nullable] = STATE(1571),
    [sym_preproc_error] = STATE(1571),
    [sym_preproc_warning] = STATE(1571),
    [sym_preproc_define] = STATE(1571),
    [sym_preproc_undef] = STATE(1571),
    [aux_sym_class_declaration_repeat1] = STATE(3822),
    [aux_sym_lambda_expression_repeat1] = STATE(4238),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1623),
    [anon_sym_ref] = ACTIONS(1625),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1577),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1629),
    [anon_sym_TILDE] = ACTIONS(1629),
    [anon_sym_PLUS_PLUS] = ACTIONS(1629),
    [anon_sym_DASH_DASH] = ACTIONS(1629),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1627),
    [anon_sym_DASH] = ACTIONS(1627),
    [anon_sym_STAR] = ACTIONS(1631),
    [anon_sym_CARET] = ACTIONS(1629),
    [anon_sym_AMP] = ACTIONS(1629),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1633),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1635),
    [anon_sym_DOT_DOT] = ACTIONS(1637),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1572] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6917),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2905),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7006),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5487),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4199),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7447),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9823),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1572),
    [sym_preproc_endregion] = STATE(1572),
    [sym_preproc_line] = STATE(1572),
    [sym_preproc_pragma] = STATE(1572),
    [sym_preproc_nullable] = STATE(1572),
    [sym_preproc_error] = STATE(1572),
    [sym_preproc_warning] = STATE(1572),
    [sym_preproc_define] = STATE(1572),
    [sym_preproc_undef] = STATE(1572),
    [aux_sym_class_declaration_repeat1] = STATE(3822),
    [aux_sym_lambda_expression_repeat1] = STATE(4238),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1623),
    [anon_sym_ref] = ACTIONS(1625),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1577),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1629),
    [anon_sym_TILDE] = ACTIONS(1629),
    [anon_sym_PLUS_PLUS] = ACTIONS(1629),
    [anon_sym_DASH_DASH] = ACTIONS(1629),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1627),
    [anon_sym_DASH] = ACTIONS(1627),
    [anon_sym_STAR] = ACTIONS(1631),
    [anon_sym_CARET] = ACTIONS(1629),
    [anon_sym_AMP] = ACTIONS(1629),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1633),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1635),
    [anon_sym_DOT_DOT] = ACTIONS(1637),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1573] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6917),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2905),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7006),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5488),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4199),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7447),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9823),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1573),
    [sym_preproc_endregion] = STATE(1573),
    [sym_preproc_line] = STATE(1573),
    [sym_preproc_pragma] = STATE(1573),
    [sym_preproc_nullable] = STATE(1573),
    [sym_preproc_error] = STATE(1573),
    [sym_preproc_warning] = STATE(1573),
    [sym_preproc_define] = STATE(1573),
    [sym_preproc_undef] = STATE(1573),
    [aux_sym_class_declaration_repeat1] = STATE(3822),
    [aux_sym_lambda_expression_repeat1] = STATE(4238),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1623),
    [anon_sym_ref] = ACTIONS(1625),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1577),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1629),
    [anon_sym_TILDE] = ACTIONS(1629),
    [anon_sym_PLUS_PLUS] = ACTIONS(1629),
    [anon_sym_DASH_DASH] = ACTIONS(1629),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1627),
    [anon_sym_DASH] = ACTIONS(1627),
    [anon_sym_STAR] = ACTIONS(1631),
    [anon_sym_CARET] = ACTIONS(1629),
    [anon_sym_AMP] = ACTIONS(1629),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1633),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1635),
    [anon_sym_DOT_DOT] = ACTIONS(1637),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1574] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6917),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2905),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7006),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5489),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4199),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7447),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9823),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1574),
    [sym_preproc_endregion] = STATE(1574),
    [sym_preproc_line] = STATE(1574),
    [sym_preproc_pragma] = STATE(1574),
    [sym_preproc_nullable] = STATE(1574),
    [sym_preproc_error] = STATE(1574),
    [sym_preproc_warning] = STATE(1574),
    [sym_preproc_define] = STATE(1574),
    [sym_preproc_undef] = STATE(1574),
    [aux_sym_class_declaration_repeat1] = STATE(3822),
    [aux_sym_lambda_expression_repeat1] = STATE(4238),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1623),
    [anon_sym_ref] = ACTIONS(1625),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1577),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1629),
    [anon_sym_TILDE] = ACTIONS(1629),
    [anon_sym_PLUS_PLUS] = ACTIONS(1629),
    [anon_sym_DASH_DASH] = ACTIONS(1629),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1627),
    [anon_sym_DASH] = ACTIONS(1627),
    [anon_sym_STAR] = ACTIONS(1631),
    [anon_sym_CARET] = ACTIONS(1629),
    [anon_sym_AMP] = ACTIONS(1629),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1633),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1635),
    [anon_sym_DOT_DOT] = ACTIONS(1637),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1575] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6917),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2905),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7006),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3932),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4199),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7447),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9823),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1575),
    [sym_preproc_endregion] = STATE(1575),
    [sym_preproc_line] = STATE(1575),
    [sym_preproc_pragma] = STATE(1575),
    [sym_preproc_nullable] = STATE(1575),
    [sym_preproc_error] = STATE(1575),
    [sym_preproc_warning] = STATE(1575),
    [sym_preproc_define] = STATE(1575),
    [sym_preproc_undef] = STATE(1575),
    [aux_sym_class_declaration_repeat1] = STATE(3822),
    [aux_sym_lambda_expression_repeat1] = STATE(4238),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1623),
    [anon_sym_ref] = ACTIONS(1625),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1577),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1629),
    [anon_sym_TILDE] = ACTIONS(1629),
    [anon_sym_PLUS_PLUS] = ACTIONS(1629),
    [anon_sym_DASH_DASH] = ACTIONS(1629),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1627),
    [anon_sym_DASH] = ACTIONS(1627),
    [anon_sym_STAR] = ACTIONS(1631),
    [anon_sym_CARET] = ACTIONS(1629),
    [anon_sym_AMP] = ACTIONS(1629),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1633),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1635),
    [anon_sym_DOT_DOT] = ACTIONS(1637),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1576] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6914),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2960),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7049),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6182),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4399),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7440),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9013),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1576),
    [sym_preproc_endregion] = STATE(1576),
    [sym_preproc_line] = STATE(1576),
    [sym_preproc_pragma] = STATE(1576),
    [sym_preproc_nullable] = STATE(1576),
    [sym_preproc_error] = STATE(1576),
    [sym_preproc_warning] = STATE(1576),
    [sym_preproc_define] = STATE(1576),
    [sym_preproc_undef] = STATE(1576),
    [aux_sym_class_declaration_repeat1] = STATE(3833),
    [aux_sym_lambda_expression_repeat1] = STATE(4261),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2151),
    [anon_sym_ref] = ACTIONS(2153),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2155),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2159),
    [anon_sym_TILDE] = ACTIONS(2159),
    [anon_sym_PLUS_PLUS] = ACTIONS(2159),
    [anon_sym_DASH_DASH] = ACTIONS(2159),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2157),
    [anon_sym_DASH] = ACTIONS(2157),
    [anon_sym_STAR] = ACTIONS(2161),
    [anon_sym_CARET] = ACTIONS(2159),
    [anon_sym_AMP] = ACTIONS(2159),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2163),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2165),
    [anon_sym_DOT_DOT] = ACTIONS(2167),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1577] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6914),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2960),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7049),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3567),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4399),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7440),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9013),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1577),
    [sym_preproc_endregion] = STATE(1577),
    [sym_preproc_line] = STATE(1577),
    [sym_preproc_pragma] = STATE(1577),
    [sym_preproc_nullable] = STATE(1577),
    [sym_preproc_error] = STATE(1577),
    [sym_preproc_warning] = STATE(1577),
    [sym_preproc_define] = STATE(1577),
    [sym_preproc_undef] = STATE(1577),
    [aux_sym_class_declaration_repeat1] = STATE(3833),
    [aux_sym_lambda_expression_repeat1] = STATE(4261),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2151),
    [anon_sym_ref] = ACTIONS(2153),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2155),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2159),
    [anon_sym_TILDE] = ACTIONS(2159),
    [anon_sym_PLUS_PLUS] = ACTIONS(2159),
    [anon_sym_DASH_DASH] = ACTIONS(2159),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2157),
    [anon_sym_DASH] = ACTIONS(2157),
    [anon_sym_STAR] = ACTIONS(2161),
    [anon_sym_CARET] = ACTIONS(2159),
    [anon_sym_AMP] = ACTIONS(2159),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2163),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2165),
    [anon_sym_DOT_DOT] = ACTIONS(2167),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1578] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6914),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2960),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7049),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6187),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4399),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7440),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9013),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1578),
    [sym_preproc_endregion] = STATE(1578),
    [sym_preproc_line] = STATE(1578),
    [sym_preproc_pragma] = STATE(1578),
    [sym_preproc_nullable] = STATE(1578),
    [sym_preproc_error] = STATE(1578),
    [sym_preproc_warning] = STATE(1578),
    [sym_preproc_define] = STATE(1578),
    [sym_preproc_undef] = STATE(1578),
    [aux_sym_class_declaration_repeat1] = STATE(3833),
    [aux_sym_lambda_expression_repeat1] = STATE(4261),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2151),
    [anon_sym_ref] = ACTIONS(2153),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2155),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2159),
    [anon_sym_TILDE] = ACTIONS(2159),
    [anon_sym_PLUS_PLUS] = ACTIONS(2159),
    [anon_sym_DASH_DASH] = ACTIONS(2159),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2157),
    [anon_sym_DASH] = ACTIONS(2157),
    [anon_sym_STAR] = ACTIONS(2161),
    [anon_sym_CARET] = ACTIONS(2159),
    [anon_sym_AMP] = ACTIONS(2159),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2163),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2165),
    [anon_sym_DOT_DOT] = ACTIONS(2167),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1579] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6910),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2960),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7091),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5679),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4208),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7438),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9067),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1579),
    [sym_preproc_endregion] = STATE(1579),
    [sym_preproc_line] = STATE(1579),
    [sym_preproc_pragma] = STATE(1579),
    [sym_preproc_nullable] = STATE(1579),
    [sym_preproc_error] = STATE(1579),
    [sym_preproc_warning] = STATE(1579),
    [sym_preproc_define] = STATE(1579),
    [sym_preproc_undef] = STATE(1579),
    [aux_sym_class_declaration_repeat1] = STATE(3847),
    [aux_sym_lambda_expression_repeat1] = STATE(4280),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1819),
    [anon_sym_ref] = ACTIONS(1821),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1823),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1827),
    [anon_sym_TILDE] = ACTIONS(1827),
    [anon_sym_PLUS_PLUS] = ACTIONS(1827),
    [anon_sym_DASH_DASH] = ACTIONS(1827),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1825),
    [anon_sym_DASH] = ACTIONS(1825),
    [anon_sym_STAR] = ACTIONS(1829),
    [anon_sym_CARET] = ACTIONS(1827),
    [anon_sym_AMP] = ACTIONS(1827),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1831),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1833),
    [anon_sym_DOT_DOT] = ACTIONS(1835),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1580] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6914),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2960),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7049),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6193),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4399),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7440),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9013),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1580),
    [sym_preproc_endregion] = STATE(1580),
    [sym_preproc_line] = STATE(1580),
    [sym_preproc_pragma] = STATE(1580),
    [sym_preproc_nullable] = STATE(1580),
    [sym_preproc_error] = STATE(1580),
    [sym_preproc_warning] = STATE(1580),
    [sym_preproc_define] = STATE(1580),
    [sym_preproc_undef] = STATE(1580),
    [aux_sym_class_declaration_repeat1] = STATE(3833),
    [aux_sym_lambda_expression_repeat1] = STATE(4261),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2151),
    [anon_sym_ref] = ACTIONS(2153),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2155),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2159),
    [anon_sym_TILDE] = ACTIONS(2159),
    [anon_sym_PLUS_PLUS] = ACTIONS(2159),
    [anon_sym_DASH_DASH] = ACTIONS(2159),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2157),
    [anon_sym_DASH] = ACTIONS(2157),
    [anon_sym_STAR] = ACTIONS(2161),
    [anon_sym_CARET] = ACTIONS(2159),
    [anon_sym_AMP] = ACTIONS(2159),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2163),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2165),
    [anon_sym_DOT_DOT] = ACTIONS(2167),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1581] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6914),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2960),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7049),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6227),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4399),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7440),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9013),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1581),
    [sym_preproc_endregion] = STATE(1581),
    [sym_preproc_line] = STATE(1581),
    [sym_preproc_pragma] = STATE(1581),
    [sym_preproc_nullable] = STATE(1581),
    [sym_preproc_error] = STATE(1581),
    [sym_preproc_warning] = STATE(1581),
    [sym_preproc_define] = STATE(1581),
    [sym_preproc_undef] = STATE(1581),
    [aux_sym_class_declaration_repeat1] = STATE(3833),
    [aux_sym_lambda_expression_repeat1] = STATE(4261),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2151),
    [anon_sym_ref] = ACTIONS(2153),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2155),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2159),
    [anon_sym_TILDE] = ACTIONS(2159),
    [anon_sym_PLUS_PLUS] = ACTIONS(2159),
    [anon_sym_DASH_DASH] = ACTIONS(2159),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2157),
    [anon_sym_DASH] = ACTIONS(2157),
    [anon_sym_STAR] = ACTIONS(2161),
    [anon_sym_CARET] = ACTIONS(2159),
    [anon_sym_AMP] = ACTIONS(2159),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2163),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2165),
    [anon_sym_DOT_DOT] = ACTIONS(2167),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1582] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6914),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2960),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7049),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6232),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4399),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7440),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9013),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1582),
    [sym_preproc_endregion] = STATE(1582),
    [sym_preproc_line] = STATE(1582),
    [sym_preproc_pragma] = STATE(1582),
    [sym_preproc_nullable] = STATE(1582),
    [sym_preproc_error] = STATE(1582),
    [sym_preproc_warning] = STATE(1582),
    [sym_preproc_define] = STATE(1582),
    [sym_preproc_undef] = STATE(1582),
    [aux_sym_class_declaration_repeat1] = STATE(3833),
    [aux_sym_lambda_expression_repeat1] = STATE(4261),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2151),
    [anon_sym_ref] = ACTIONS(2153),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2155),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2159),
    [anon_sym_TILDE] = ACTIONS(2159),
    [anon_sym_PLUS_PLUS] = ACTIONS(2159),
    [anon_sym_DASH_DASH] = ACTIONS(2159),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2157),
    [anon_sym_DASH] = ACTIONS(2157),
    [anon_sym_STAR] = ACTIONS(2161),
    [anon_sym_CARET] = ACTIONS(2159),
    [anon_sym_AMP] = ACTIONS(2159),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2163),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2165),
    [anon_sym_DOT_DOT] = ACTIONS(2167),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1583] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6914),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2960),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7049),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6240),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4399),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7440),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9013),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1583),
    [sym_preproc_endregion] = STATE(1583),
    [sym_preproc_line] = STATE(1583),
    [sym_preproc_pragma] = STATE(1583),
    [sym_preproc_nullable] = STATE(1583),
    [sym_preproc_error] = STATE(1583),
    [sym_preproc_warning] = STATE(1583),
    [sym_preproc_define] = STATE(1583),
    [sym_preproc_undef] = STATE(1583),
    [aux_sym_class_declaration_repeat1] = STATE(3833),
    [aux_sym_lambda_expression_repeat1] = STATE(4261),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2151),
    [anon_sym_ref] = ACTIONS(2153),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2155),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2159),
    [anon_sym_TILDE] = ACTIONS(2159),
    [anon_sym_PLUS_PLUS] = ACTIONS(2159),
    [anon_sym_DASH_DASH] = ACTIONS(2159),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2157),
    [anon_sym_DASH] = ACTIONS(2157),
    [anon_sym_STAR] = ACTIONS(2161),
    [anon_sym_CARET] = ACTIONS(2159),
    [anon_sym_AMP] = ACTIONS(2159),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2163),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2165),
    [anon_sym_DOT_DOT] = ACTIONS(2167),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1584] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6914),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2960),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7049),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6247),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4399),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7440),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9013),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1584),
    [sym_preproc_endregion] = STATE(1584),
    [sym_preproc_line] = STATE(1584),
    [sym_preproc_pragma] = STATE(1584),
    [sym_preproc_nullable] = STATE(1584),
    [sym_preproc_error] = STATE(1584),
    [sym_preproc_warning] = STATE(1584),
    [sym_preproc_define] = STATE(1584),
    [sym_preproc_undef] = STATE(1584),
    [aux_sym_class_declaration_repeat1] = STATE(3833),
    [aux_sym_lambda_expression_repeat1] = STATE(4261),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2151),
    [anon_sym_ref] = ACTIONS(2153),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2155),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2159),
    [anon_sym_TILDE] = ACTIONS(2159),
    [anon_sym_PLUS_PLUS] = ACTIONS(2159),
    [anon_sym_DASH_DASH] = ACTIONS(2159),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2157),
    [anon_sym_DASH] = ACTIONS(2157),
    [anon_sym_STAR] = ACTIONS(2161),
    [anon_sym_CARET] = ACTIONS(2159),
    [anon_sym_AMP] = ACTIONS(2159),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2163),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2165),
    [anon_sym_DOT_DOT] = ACTIONS(2167),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1585] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6914),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2960),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7049),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6262),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4399),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7440),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9013),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1585),
    [sym_preproc_endregion] = STATE(1585),
    [sym_preproc_line] = STATE(1585),
    [sym_preproc_pragma] = STATE(1585),
    [sym_preproc_nullable] = STATE(1585),
    [sym_preproc_error] = STATE(1585),
    [sym_preproc_warning] = STATE(1585),
    [sym_preproc_define] = STATE(1585),
    [sym_preproc_undef] = STATE(1585),
    [aux_sym_class_declaration_repeat1] = STATE(3833),
    [aux_sym_lambda_expression_repeat1] = STATE(4261),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2151),
    [anon_sym_ref] = ACTIONS(2153),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2155),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2159),
    [anon_sym_TILDE] = ACTIONS(2159),
    [anon_sym_PLUS_PLUS] = ACTIONS(2159),
    [anon_sym_DASH_DASH] = ACTIONS(2159),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2157),
    [anon_sym_DASH] = ACTIONS(2157),
    [anon_sym_STAR] = ACTIONS(2161),
    [anon_sym_CARET] = ACTIONS(2159),
    [anon_sym_AMP] = ACTIONS(2159),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2163),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2165),
    [anon_sym_DOT_DOT] = ACTIONS(2167),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1586] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6914),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2960),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7049),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6277),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4399),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7440),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9013),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1586),
    [sym_preproc_endregion] = STATE(1586),
    [sym_preproc_line] = STATE(1586),
    [sym_preproc_pragma] = STATE(1586),
    [sym_preproc_nullable] = STATE(1586),
    [sym_preproc_error] = STATE(1586),
    [sym_preproc_warning] = STATE(1586),
    [sym_preproc_define] = STATE(1586),
    [sym_preproc_undef] = STATE(1586),
    [aux_sym_class_declaration_repeat1] = STATE(3833),
    [aux_sym_lambda_expression_repeat1] = STATE(4261),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2151),
    [anon_sym_ref] = ACTIONS(2153),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2155),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2159),
    [anon_sym_TILDE] = ACTIONS(2159),
    [anon_sym_PLUS_PLUS] = ACTIONS(2159),
    [anon_sym_DASH_DASH] = ACTIONS(2159),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2157),
    [anon_sym_DASH] = ACTIONS(2157),
    [anon_sym_STAR] = ACTIONS(2161),
    [anon_sym_CARET] = ACTIONS(2159),
    [anon_sym_AMP] = ACTIONS(2159),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2163),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2165),
    [anon_sym_DOT_DOT] = ACTIONS(2167),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1587] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6914),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2960),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7049),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6135),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4399),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7440),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9013),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1587),
    [sym_preproc_endregion] = STATE(1587),
    [sym_preproc_line] = STATE(1587),
    [sym_preproc_pragma] = STATE(1587),
    [sym_preproc_nullable] = STATE(1587),
    [sym_preproc_error] = STATE(1587),
    [sym_preproc_warning] = STATE(1587),
    [sym_preproc_define] = STATE(1587),
    [sym_preproc_undef] = STATE(1587),
    [aux_sym_class_declaration_repeat1] = STATE(3833),
    [aux_sym_lambda_expression_repeat1] = STATE(4261),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2151),
    [anon_sym_ref] = ACTIONS(2153),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2155),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2159),
    [anon_sym_TILDE] = ACTIONS(2159),
    [anon_sym_PLUS_PLUS] = ACTIONS(2159),
    [anon_sym_DASH_DASH] = ACTIONS(2159),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2157),
    [anon_sym_DASH] = ACTIONS(2157),
    [anon_sym_STAR] = ACTIONS(2161),
    [anon_sym_CARET] = ACTIONS(2159),
    [anon_sym_AMP] = ACTIONS(2159),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2163),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2165),
    [anon_sym_DOT_DOT] = ACTIONS(2167),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1588] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6914),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2960),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7049),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6136),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4399),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7440),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9013),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1588),
    [sym_preproc_endregion] = STATE(1588),
    [sym_preproc_line] = STATE(1588),
    [sym_preproc_pragma] = STATE(1588),
    [sym_preproc_nullable] = STATE(1588),
    [sym_preproc_error] = STATE(1588),
    [sym_preproc_warning] = STATE(1588),
    [sym_preproc_define] = STATE(1588),
    [sym_preproc_undef] = STATE(1588),
    [aux_sym_class_declaration_repeat1] = STATE(3833),
    [aux_sym_lambda_expression_repeat1] = STATE(4261),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2151),
    [anon_sym_ref] = ACTIONS(2153),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2155),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2159),
    [anon_sym_TILDE] = ACTIONS(2159),
    [anon_sym_PLUS_PLUS] = ACTIONS(2159),
    [anon_sym_DASH_DASH] = ACTIONS(2159),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2157),
    [anon_sym_DASH] = ACTIONS(2157),
    [anon_sym_STAR] = ACTIONS(2161),
    [anon_sym_CARET] = ACTIONS(2159),
    [anon_sym_AMP] = ACTIONS(2159),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2163),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2165),
    [anon_sym_DOT_DOT] = ACTIONS(2167),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1589] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6914),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2960),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7049),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6138),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4399),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7440),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9013),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1589),
    [sym_preproc_endregion] = STATE(1589),
    [sym_preproc_line] = STATE(1589),
    [sym_preproc_pragma] = STATE(1589),
    [sym_preproc_nullable] = STATE(1589),
    [sym_preproc_error] = STATE(1589),
    [sym_preproc_warning] = STATE(1589),
    [sym_preproc_define] = STATE(1589),
    [sym_preproc_undef] = STATE(1589),
    [aux_sym_class_declaration_repeat1] = STATE(3833),
    [aux_sym_lambda_expression_repeat1] = STATE(4261),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2151),
    [anon_sym_ref] = ACTIONS(2153),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2155),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2159),
    [anon_sym_TILDE] = ACTIONS(2159),
    [anon_sym_PLUS_PLUS] = ACTIONS(2159),
    [anon_sym_DASH_DASH] = ACTIONS(2159),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2157),
    [anon_sym_DASH] = ACTIONS(2157),
    [anon_sym_STAR] = ACTIONS(2161),
    [anon_sym_CARET] = ACTIONS(2159),
    [anon_sym_AMP] = ACTIONS(2159),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2163),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2165),
    [anon_sym_DOT_DOT] = ACTIONS(2167),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1590] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6914),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2960),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7049),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6140),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4399),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7440),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9013),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1590),
    [sym_preproc_endregion] = STATE(1590),
    [sym_preproc_line] = STATE(1590),
    [sym_preproc_pragma] = STATE(1590),
    [sym_preproc_nullable] = STATE(1590),
    [sym_preproc_error] = STATE(1590),
    [sym_preproc_warning] = STATE(1590),
    [sym_preproc_define] = STATE(1590),
    [sym_preproc_undef] = STATE(1590),
    [aux_sym_class_declaration_repeat1] = STATE(3833),
    [aux_sym_lambda_expression_repeat1] = STATE(4261),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2151),
    [anon_sym_ref] = ACTIONS(2153),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2155),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2159),
    [anon_sym_TILDE] = ACTIONS(2159),
    [anon_sym_PLUS_PLUS] = ACTIONS(2159),
    [anon_sym_DASH_DASH] = ACTIONS(2159),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2157),
    [anon_sym_DASH] = ACTIONS(2157),
    [anon_sym_STAR] = ACTIONS(2161),
    [anon_sym_CARET] = ACTIONS(2159),
    [anon_sym_AMP] = ACTIONS(2159),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2163),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2165),
    [anon_sym_DOT_DOT] = ACTIONS(2167),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1591] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6914),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2960),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7049),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6141),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4399),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7440),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9013),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1591),
    [sym_preproc_endregion] = STATE(1591),
    [sym_preproc_line] = STATE(1591),
    [sym_preproc_pragma] = STATE(1591),
    [sym_preproc_nullable] = STATE(1591),
    [sym_preproc_error] = STATE(1591),
    [sym_preproc_warning] = STATE(1591),
    [sym_preproc_define] = STATE(1591),
    [sym_preproc_undef] = STATE(1591),
    [aux_sym_class_declaration_repeat1] = STATE(3833),
    [aux_sym_lambda_expression_repeat1] = STATE(4261),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2151),
    [anon_sym_ref] = ACTIONS(2153),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2155),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2159),
    [anon_sym_TILDE] = ACTIONS(2159),
    [anon_sym_PLUS_PLUS] = ACTIONS(2159),
    [anon_sym_DASH_DASH] = ACTIONS(2159),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2157),
    [anon_sym_DASH] = ACTIONS(2157),
    [anon_sym_STAR] = ACTIONS(2161),
    [anon_sym_CARET] = ACTIONS(2159),
    [anon_sym_AMP] = ACTIONS(2159),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2163),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2165),
    [anon_sym_DOT_DOT] = ACTIONS(2167),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1592] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6914),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2960),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7049),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3582),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4399),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7440),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9013),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1592),
    [sym_preproc_endregion] = STATE(1592),
    [sym_preproc_line] = STATE(1592),
    [sym_preproc_pragma] = STATE(1592),
    [sym_preproc_nullable] = STATE(1592),
    [sym_preproc_error] = STATE(1592),
    [sym_preproc_warning] = STATE(1592),
    [sym_preproc_define] = STATE(1592),
    [sym_preproc_undef] = STATE(1592),
    [aux_sym_class_declaration_repeat1] = STATE(3833),
    [aux_sym_lambda_expression_repeat1] = STATE(4261),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2151),
    [anon_sym_ref] = ACTIONS(2153),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2155),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2159),
    [anon_sym_TILDE] = ACTIONS(2159),
    [anon_sym_PLUS_PLUS] = ACTIONS(2159),
    [anon_sym_DASH_DASH] = ACTIONS(2159),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2157),
    [anon_sym_DASH] = ACTIONS(2157),
    [anon_sym_STAR] = ACTIONS(2161),
    [anon_sym_CARET] = ACTIONS(2159),
    [anon_sym_AMP] = ACTIONS(2159),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2163),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2165),
    [anon_sym_DOT_DOT] = ACTIONS(2167),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1593] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6917),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2905),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7006),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5490),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4199),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7447),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9823),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1593),
    [sym_preproc_endregion] = STATE(1593),
    [sym_preproc_line] = STATE(1593),
    [sym_preproc_pragma] = STATE(1593),
    [sym_preproc_nullable] = STATE(1593),
    [sym_preproc_error] = STATE(1593),
    [sym_preproc_warning] = STATE(1593),
    [sym_preproc_define] = STATE(1593),
    [sym_preproc_undef] = STATE(1593),
    [aux_sym_class_declaration_repeat1] = STATE(3822),
    [aux_sym_lambda_expression_repeat1] = STATE(4238),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1623),
    [anon_sym_ref] = ACTIONS(1625),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1577),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1629),
    [anon_sym_TILDE] = ACTIONS(1629),
    [anon_sym_PLUS_PLUS] = ACTIONS(1629),
    [anon_sym_DASH_DASH] = ACTIONS(1629),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1627),
    [anon_sym_DASH] = ACTIONS(1627),
    [anon_sym_STAR] = ACTIONS(1631),
    [anon_sym_CARET] = ACTIONS(1629),
    [anon_sym_AMP] = ACTIONS(1629),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1633),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1635),
    [anon_sym_DOT_DOT] = ACTIONS(1637),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1594] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6917),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2905),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7006),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3926),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4199),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7447),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9823),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1594),
    [sym_preproc_endregion] = STATE(1594),
    [sym_preproc_line] = STATE(1594),
    [sym_preproc_pragma] = STATE(1594),
    [sym_preproc_nullable] = STATE(1594),
    [sym_preproc_error] = STATE(1594),
    [sym_preproc_warning] = STATE(1594),
    [sym_preproc_define] = STATE(1594),
    [sym_preproc_undef] = STATE(1594),
    [aux_sym_class_declaration_repeat1] = STATE(3822),
    [aux_sym_lambda_expression_repeat1] = STATE(4238),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1623),
    [anon_sym_ref] = ACTIONS(1625),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1577),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1629),
    [anon_sym_TILDE] = ACTIONS(1629),
    [anon_sym_PLUS_PLUS] = ACTIONS(1629),
    [anon_sym_DASH_DASH] = ACTIONS(1629),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1627),
    [anon_sym_DASH] = ACTIONS(1627),
    [anon_sym_STAR] = ACTIONS(1631),
    [anon_sym_CARET] = ACTIONS(1629),
    [anon_sym_AMP] = ACTIONS(1629),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1633),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1635),
    [anon_sym_DOT_DOT] = ACTIONS(1637),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1595] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6917),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2905),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7006),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5492),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4199),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7447),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9823),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1595),
    [sym_preproc_endregion] = STATE(1595),
    [sym_preproc_line] = STATE(1595),
    [sym_preproc_pragma] = STATE(1595),
    [sym_preproc_nullable] = STATE(1595),
    [sym_preproc_error] = STATE(1595),
    [sym_preproc_warning] = STATE(1595),
    [sym_preproc_define] = STATE(1595),
    [sym_preproc_undef] = STATE(1595),
    [aux_sym_class_declaration_repeat1] = STATE(3822),
    [aux_sym_lambda_expression_repeat1] = STATE(4238),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1623),
    [anon_sym_ref] = ACTIONS(1625),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1577),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1629),
    [anon_sym_TILDE] = ACTIONS(1629),
    [anon_sym_PLUS_PLUS] = ACTIONS(1629),
    [anon_sym_DASH_DASH] = ACTIONS(1629),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1627),
    [anon_sym_DASH] = ACTIONS(1627),
    [anon_sym_STAR] = ACTIONS(1631),
    [anon_sym_CARET] = ACTIONS(1629),
    [anon_sym_AMP] = ACTIONS(1629),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1633),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1635),
    [anon_sym_DOT_DOT] = ACTIONS(1637),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1596] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6917),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2905),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7006),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5496),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4199),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7447),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9823),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1596),
    [sym_preproc_endregion] = STATE(1596),
    [sym_preproc_line] = STATE(1596),
    [sym_preproc_pragma] = STATE(1596),
    [sym_preproc_nullable] = STATE(1596),
    [sym_preproc_error] = STATE(1596),
    [sym_preproc_warning] = STATE(1596),
    [sym_preproc_define] = STATE(1596),
    [sym_preproc_undef] = STATE(1596),
    [aux_sym_class_declaration_repeat1] = STATE(3822),
    [aux_sym_lambda_expression_repeat1] = STATE(4238),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1623),
    [anon_sym_ref] = ACTIONS(1625),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1577),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1629),
    [anon_sym_TILDE] = ACTIONS(1629),
    [anon_sym_PLUS_PLUS] = ACTIONS(1629),
    [anon_sym_DASH_DASH] = ACTIONS(1629),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1627),
    [anon_sym_DASH] = ACTIONS(1627),
    [anon_sym_STAR] = ACTIONS(1631),
    [anon_sym_CARET] = ACTIONS(1629),
    [anon_sym_AMP] = ACTIONS(1629),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1633),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1635),
    [anon_sym_DOT_DOT] = ACTIONS(1637),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1597] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6941),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2977),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7077),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5640),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4200),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7415),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9773),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1597),
    [sym_preproc_endregion] = STATE(1597),
    [sym_preproc_line] = STATE(1597),
    [sym_preproc_pragma] = STATE(1597),
    [sym_preproc_nullable] = STATE(1597),
    [sym_preproc_error] = STATE(1597),
    [sym_preproc_warning] = STATE(1597),
    [sym_preproc_define] = STATE(1597),
    [sym_preproc_undef] = STATE(1597),
    [aux_sym_class_declaration_repeat1] = STATE(3843),
    [aux_sym_lambda_expression_repeat1] = STATE(4275),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1911),
    [anon_sym_ref] = ACTIONS(1913),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1915),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1919),
    [anon_sym_TILDE] = ACTIONS(1919),
    [anon_sym_PLUS_PLUS] = ACTIONS(1919),
    [anon_sym_DASH_DASH] = ACTIONS(1919),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1917),
    [anon_sym_DASH] = ACTIONS(1917),
    [anon_sym_STAR] = ACTIONS(1921),
    [anon_sym_CARET] = ACTIONS(1919),
    [anon_sym_AMP] = ACTIONS(1919),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1923),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1925),
    [anon_sym_DOT_DOT] = ACTIONS(1927),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1598] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6941),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2977),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7077),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3838),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4200),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7415),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9773),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1598),
    [sym_preproc_endregion] = STATE(1598),
    [sym_preproc_line] = STATE(1598),
    [sym_preproc_pragma] = STATE(1598),
    [sym_preproc_nullable] = STATE(1598),
    [sym_preproc_error] = STATE(1598),
    [sym_preproc_warning] = STATE(1598),
    [sym_preproc_define] = STATE(1598),
    [sym_preproc_undef] = STATE(1598),
    [aux_sym_class_declaration_repeat1] = STATE(3843),
    [aux_sym_lambda_expression_repeat1] = STATE(4275),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1911),
    [anon_sym_ref] = ACTIONS(1913),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1915),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1919),
    [anon_sym_TILDE] = ACTIONS(1919),
    [anon_sym_PLUS_PLUS] = ACTIONS(1919),
    [anon_sym_DASH_DASH] = ACTIONS(1919),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1917),
    [anon_sym_DASH] = ACTIONS(1917),
    [anon_sym_STAR] = ACTIONS(1921),
    [anon_sym_CARET] = ACTIONS(1919),
    [anon_sym_AMP] = ACTIONS(1919),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1923),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1925),
    [anon_sym_DOT_DOT] = ACTIONS(1927),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1599] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6927),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2912),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7057),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5260),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3960),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7439),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9222),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1599),
    [sym_preproc_endregion] = STATE(1599),
    [sym_preproc_line] = STATE(1599),
    [sym_preproc_pragma] = STATE(1599),
    [sym_preproc_nullable] = STATE(1599),
    [sym_preproc_error] = STATE(1599),
    [sym_preproc_warning] = STATE(1599),
    [sym_preproc_define] = STATE(1599),
    [sym_preproc_undef] = STATE(1599),
    [aux_sym_class_declaration_repeat1] = STATE(3837),
    [aux_sym_lambda_expression_repeat1] = STATE(4265),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1591),
    [anon_sym_ref] = ACTIONS(1593),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1595),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1599),
    [anon_sym_TILDE] = ACTIONS(1599),
    [anon_sym_PLUS_PLUS] = ACTIONS(1599),
    [anon_sym_DASH_DASH] = ACTIONS(1599),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1597),
    [anon_sym_DASH] = ACTIONS(1597),
    [anon_sym_STAR] = ACTIONS(1601),
    [anon_sym_CARET] = ACTIONS(1599),
    [anon_sym_AMP] = ACTIONS(1599),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1603),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1605),
    [anon_sym_DOT_DOT] = ACTIONS(1607),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1600] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6927),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2912),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7057),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5265),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3960),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7439),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9222),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1600),
    [sym_preproc_endregion] = STATE(1600),
    [sym_preproc_line] = STATE(1600),
    [sym_preproc_pragma] = STATE(1600),
    [sym_preproc_nullable] = STATE(1600),
    [sym_preproc_error] = STATE(1600),
    [sym_preproc_warning] = STATE(1600),
    [sym_preproc_define] = STATE(1600),
    [sym_preproc_undef] = STATE(1600),
    [aux_sym_class_declaration_repeat1] = STATE(3837),
    [aux_sym_lambda_expression_repeat1] = STATE(4265),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1591),
    [anon_sym_ref] = ACTIONS(1593),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1595),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1599),
    [anon_sym_TILDE] = ACTIONS(1599),
    [anon_sym_PLUS_PLUS] = ACTIONS(1599),
    [anon_sym_DASH_DASH] = ACTIONS(1599),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1597),
    [anon_sym_DASH] = ACTIONS(1597),
    [anon_sym_STAR] = ACTIONS(1601),
    [anon_sym_CARET] = ACTIONS(1599),
    [anon_sym_AMP] = ACTIONS(1599),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1603),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1605),
    [anon_sym_DOT_DOT] = ACTIONS(1607),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1601] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6927),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2912),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7057),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5247),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3960),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7439),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9222),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1601),
    [sym_preproc_endregion] = STATE(1601),
    [sym_preproc_line] = STATE(1601),
    [sym_preproc_pragma] = STATE(1601),
    [sym_preproc_nullable] = STATE(1601),
    [sym_preproc_error] = STATE(1601),
    [sym_preproc_warning] = STATE(1601),
    [sym_preproc_define] = STATE(1601),
    [sym_preproc_undef] = STATE(1601),
    [aux_sym_class_declaration_repeat1] = STATE(3837),
    [aux_sym_lambda_expression_repeat1] = STATE(4265),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1591),
    [anon_sym_ref] = ACTIONS(1593),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1595),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1599),
    [anon_sym_TILDE] = ACTIONS(1599),
    [anon_sym_PLUS_PLUS] = ACTIONS(1599),
    [anon_sym_DASH_DASH] = ACTIONS(1599),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1597),
    [anon_sym_DASH] = ACTIONS(1597),
    [anon_sym_STAR] = ACTIONS(1601),
    [anon_sym_CARET] = ACTIONS(1599),
    [anon_sym_AMP] = ACTIONS(1599),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1603),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1605),
    [anon_sym_DOT_DOT] = ACTIONS(1607),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1602] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6927),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2912),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7057),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5386),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3960),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7439),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9222),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1602),
    [sym_preproc_endregion] = STATE(1602),
    [sym_preproc_line] = STATE(1602),
    [sym_preproc_pragma] = STATE(1602),
    [sym_preproc_nullable] = STATE(1602),
    [sym_preproc_error] = STATE(1602),
    [sym_preproc_warning] = STATE(1602),
    [sym_preproc_define] = STATE(1602),
    [sym_preproc_undef] = STATE(1602),
    [aux_sym_class_declaration_repeat1] = STATE(3837),
    [aux_sym_lambda_expression_repeat1] = STATE(4265),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1591),
    [anon_sym_ref] = ACTIONS(1593),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1595),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1599),
    [anon_sym_TILDE] = ACTIONS(1599),
    [anon_sym_PLUS_PLUS] = ACTIONS(1599),
    [anon_sym_DASH_DASH] = ACTIONS(1599),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1597),
    [anon_sym_DASH] = ACTIONS(1597),
    [anon_sym_STAR] = ACTIONS(1601),
    [anon_sym_CARET] = ACTIONS(1599),
    [anon_sym_AMP] = ACTIONS(1599),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1603),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1605),
    [anon_sym_DOT_DOT] = ACTIONS(1607),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1603] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6927),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2912),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7057),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5399),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3960),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7439),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9222),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1603),
    [sym_preproc_endregion] = STATE(1603),
    [sym_preproc_line] = STATE(1603),
    [sym_preproc_pragma] = STATE(1603),
    [sym_preproc_nullable] = STATE(1603),
    [sym_preproc_error] = STATE(1603),
    [sym_preproc_warning] = STATE(1603),
    [sym_preproc_define] = STATE(1603),
    [sym_preproc_undef] = STATE(1603),
    [aux_sym_class_declaration_repeat1] = STATE(3837),
    [aux_sym_lambda_expression_repeat1] = STATE(4265),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1591),
    [anon_sym_ref] = ACTIONS(1593),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1595),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1599),
    [anon_sym_TILDE] = ACTIONS(1599),
    [anon_sym_PLUS_PLUS] = ACTIONS(1599),
    [anon_sym_DASH_DASH] = ACTIONS(1599),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1597),
    [anon_sym_DASH] = ACTIONS(1597),
    [anon_sym_STAR] = ACTIONS(1601),
    [anon_sym_CARET] = ACTIONS(1599),
    [anon_sym_AMP] = ACTIONS(1599),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1603),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1605),
    [anon_sym_DOT_DOT] = ACTIONS(1607),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1604] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6927),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2912),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7057),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5401),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3960),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7439),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9222),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1604),
    [sym_preproc_endregion] = STATE(1604),
    [sym_preproc_line] = STATE(1604),
    [sym_preproc_pragma] = STATE(1604),
    [sym_preproc_nullable] = STATE(1604),
    [sym_preproc_error] = STATE(1604),
    [sym_preproc_warning] = STATE(1604),
    [sym_preproc_define] = STATE(1604),
    [sym_preproc_undef] = STATE(1604),
    [aux_sym_class_declaration_repeat1] = STATE(3837),
    [aux_sym_lambda_expression_repeat1] = STATE(4265),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1591),
    [anon_sym_ref] = ACTIONS(1593),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1595),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1599),
    [anon_sym_TILDE] = ACTIONS(1599),
    [anon_sym_PLUS_PLUS] = ACTIONS(1599),
    [anon_sym_DASH_DASH] = ACTIONS(1599),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1597),
    [anon_sym_DASH] = ACTIONS(1597),
    [anon_sym_STAR] = ACTIONS(1601),
    [anon_sym_CARET] = ACTIONS(1599),
    [anon_sym_AMP] = ACTIONS(1599),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1603),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1605),
    [anon_sym_DOT_DOT] = ACTIONS(1607),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1605] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6927),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2912),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7057),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5271),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3960),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7439),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9222),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1605),
    [sym_preproc_endregion] = STATE(1605),
    [sym_preproc_line] = STATE(1605),
    [sym_preproc_pragma] = STATE(1605),
    [sym_preproc_nullable] = STATE(1605),
    [sym_preproc_error] = STATE(1605),
    [sym_preproc_warning] = STATE(1605),
    [sym_preproc_define] = STATE(1605),
    [sym_preproc_undef] = STATE(1605),
    [aux_sym_class_declaration_repeat1] = STATE(3837),
    [aux_sym_lambda_expression_repeat1] = STATE(4265),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1591),
    [anon_sym_ref] = ACTIONS(1593),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1595),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1599),
    [anon_sym_TILDE] = ACTIONS(1599),
    [anon_sym_PLUS_PLUS] = ACTIONS(1599),
    [anon_sym_DASH_DASH] = ACTIONS(1599),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1597),
    [anon_sym_DASH] = ACTIONS(1597),
    [anon_sym_STAR] = ACTIONS(1601),
    [anon_sym_CARET] = ACTIONS(1599),
    [anon_sym_AMP] = ACTIONS(1599),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1603),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1605),
    [anon_sym_DOT_DOT] = ACTIONS(1607),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1606] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6927),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2912),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7057),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5411),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3960),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7439),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9222),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1606),
    [sym_preproc_endregion] = STATE(1606),
    [sym_preproc_line] = STATE(1606),
    [sym_preproc_pragma] = STATE(1606),
    [sym_preproc_nullable] = STATE(1606),
    [sym_preproc_error] = STATE(1606),
    [sym_preproc_warning] = STATE(1606),
    [sym_preproc_define] = STATE(1606),
    [sym_preproc_undef] = STATE(1606),
    [aux_sym_class_declaration_repeat1] = STATE(3837),
    [aux_sym_lambda_expression_repeat1] = STATE(4265),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1591),
    [anon_sym_ref] = ACTIONS(1593),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1595),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1599),
    [anon_sym_TILDE] = ACTIONS(1599),
    [anon_sym_PLUS_PLUS] = ACTIONS(1599),
    [anon_sym_DASH_DASH] = ACTIONS(1599),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1597),
    [anon_sym_DASH] = ACTIONS(1597),
    [anon_sym_STAR] = ACTIONS(1601),
    [anon_sym_CARET] = ACTIONS(1599),
    [anon_sym_AMP] = ACTIONS(1599),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1603),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1605),
    [anon_sym_DOT_DOT] = ACTIONS(1607),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1607] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6927),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2912),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7057),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5412),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3960),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7439),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9222),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1607),
    [sym_preproc_endregion] = STATE(1607),
    [sym_preproc_line] = STATE(1607),
    [sym_preproc_pragma] = STATE(1607),
    [sym_preproc_nullable] = STATE(1607),
    [sym_preproc_error] = STATE(1607),
    [sym_preproc_warning] = STATE(1607),
    [sym_preproc_define] = STATE(1607),
    [sym_preproc_undef] = STATE(1607),
    [aux_sym_class_declaration_repeat1] = STATE(3837),
    [aux_sym_lambda_expression_repeat1] = STATE(4265),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1591),
    [anon_sym_ref] = ACTIONS(1593),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1595),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1599),
    [anon_sym_TILDE] = ACTIONS(1599),
    [anon_sym_PLUS_PLUS] = ACTIONS(1599),
    [anon_sym_DASH_DASH] = ACTIONS(1599),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1597),
    [anon_sym_DASH] = ACTIONS(1597),
    [anon_sym_STAR] = ACTIONS(1601),
    [anon_sym_CARET] = ACTIONS(1599),
    [anon_sym_AMP] = ACTIONS(1599),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1603),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1605),
    [anon_sym_DOT_DOT] = ACTIONS(1607),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1608] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6927),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2912),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7057),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5358),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3960),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7439),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9222),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1608),
    [sym_preproc_endregion] = STATE(1608),
    [sym_preproc_line] = STATE(1608),
    [sym_preproc_pragma] = STATE(1608),
    [sym_preproc_nullable] = STATE(1608),
    [sym_preproc_error] = STATE(1608),
    [sym_preproc_warning] = STATE(1608),
    [sym_preproc_define] = STATE(1608),
    [sym_preproc_undef] = STATE(1608),
    [aux_sym_class_declaration_repeat1] = STATE(3837),
    [aux_sym_lambda_expression_repeat1] = STATE(4265),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1591),
    [anon_sym_ref] = ACTIONS(1593),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1595),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1599),
    [anon_sym_TILDE] = ACTIONS(1599),
    [anon_sym_PLUS_PLUS] = ACTIONS(1599),
    [anon_sym_DASH_DASH] = ACTIONS(1599),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1597),
    [anon_sym_DASH] = ACTIONS(1597),
    [anon_sym_STAR] = ACTIONS(1601),
    [anon_sym_CARET] = ACTIONS(1599),
    [anon_sym_AMP] = ACTIONS(1599),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1603),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1605),
    [anon_sym_DOT_DOT] = ACTIONS(1607),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1609] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6927),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2912),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7057),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5323),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3960),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7439),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9222),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1609),
    [sym_preproc_endregion] = STATE(1609),
    [sym_preproc_line] = STATE(1609),
    [sym_preproc_pragma] = STATE(1609),
    [sym_preproc_nullable] = STATE(1609),
    [sym_preproc_error] = STATE(1609),
    [sym_preproc_warning] = STATE(1609),
    [sym_preproc_define] = STATE(1609),
    [sym_preproc_undef] = STATE(1609),
    [aux_sym_class_declaration_repeat1] = STATE(3837),
    [aux_sym_lambda_expression_repeat1] = STATE(4265),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1591),
    [anon_sym_ref] = ACTIONS(1593),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1595),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1599),
    [anon_sym_TILDE] = ACTIONS(1599),
    [anon_sym_PLUS_PLUS] = ACTIONS(1599),
    [anon_sym_DASH_DASH] = ACTIONS(1599),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1597),
    [anon_sym_DASH] = ACTIONS(1597),
    [anon_sym_STAR] = ACTIONS(1601),
    [anon_sym_CARET] = ACTIONS(1599),
    [anon_sym_AMP] = ACTIONS(1599),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1603),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1605),
    [anon_sym_DOT_DOT] = ACTIONS(1607),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1610] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6941),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2977),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7077),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5641),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4200),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7415),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9773),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1610),
    [sym_preproc_endregion] = STATE(1610),
    [sym_preproc_line] = STATE(1610),
    [sym_preproc_pragma] = STATE(1610),
    [sym_preproc_nullable] = STATE(1610),
    [sym_preproc_error] = STATE(1610),
    [sym_preproc_warning] = STATE(1610),
    [sym_preproc_define] = STATE(1610),
    [sym_preproc_undef] = STATE(1610),
    [aux_sym_class_declaration_repeat1] = STATE(3843),
    [aux_sym_lambda_expression_repeat1] = STATE(4275),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1911),
    [anon_sym_ref] = ACTIONS(1913),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1915),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1919),
    [anon_sym_TILDE] = ACTIONS(1919),
    [anon_sym_PLUS_PLUS] = ACTIONS(1919),
    [anon_sym_DASH_DASH] = ACTIONS(1919),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1917),
    [anon_sym_DASH] = ACTIONS(1917),
    [anon_sym_STAR] = ACTIONS(1921),
    [anon_sym_CARET] = ACTIONS(1919),
    [anon_sym_AMP] = ACTIONS(1919),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1923),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1925),
    [anon_sym_DOT_DOT] = ACTIONS(1927),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1611] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6927),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2912),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7057),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3867),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3960),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7439),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9222),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1611),
    [sym_preproc_endregion] = STATE(1611),
    [sym_preproc_line] = STATE(1611),
    [sym_preproc_pragma] = STATE(1611),
    [sym_preproc_nullable] = STATE(1611),
    [sym_preproc_error] = STATE(1611),
    [sym_preproc_warning] = STATE(1611),
    [sym_preproc_define] = STATE(1611),
    [sym_preproc_undef] = STATE(1611),
    [aux_sym_class_declaration_repeat1] = STATE(3837),
    [aux_sym_lambda_expression_repeat1] = STATE(4265),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1591),
    [anon_sym_ref] = ACTIONS(1593),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1595),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1599),
    [anon_sym_TILDE] = ACTIONS(1599),
    [anon_sym_PLUS_PLUS] = ACTIONS(1599),
    [anon_sym_DASH_DASH] = ACTIONS(1599),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1597),
    [anon_sym_DASH] = ACTIONS(1597),
    [anon_sym_STAR] = ACTIONS(1601),
    [anon_sym_CARET] = ACTIONS(1599),
    [anon_sym_AMP] = ACTIONS(1599),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1603),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1605),
    [anon_sym_DOT_DOT] = ACTIONS(1607),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1612] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6941),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2977),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7077),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5645),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4200),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7415),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9773),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1612),
    [sym_preproc_endregion] = STATE(1612),
    [sym_preproc_line] = STATE(1612),
    [sym_preproc_pragma] = STATE(1612),
    [sym_preproc_nullable] = STATE(1612),
    [sym_preproc_error] = STATE(1612),
    [sym_preproc_warning] = STATE(1612),
    [sym_preproc_define] = STATE(1612),
    [sym_preproc_undef] = STATE(1612),
    [aux_sym_class_declaration_repeat1] = STATE(3843),
    [aux_sym_lambda_expression_repeat1] = STATE(4275),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1911),
    [anon_sym_ref] = ACTIONS(1913),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1915),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1919),
    [anon_sym_TILDE] = ACTIONS(1919),
    [anon_sym_PLUS_PLUS] = ACTIONS(1919),
    [anon_sym_DASH_DASH] = ACTIONS(1919),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1917),
    [anon_sym_DASH] = ACTIONS(1917),
    [anon_sym_STAR] = ACTIONS(1921),
    [anon_sym_CARET] = ACTIONS(1919),
    [anon_sym_AMP] = ACTIONS(1919),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1923),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1925),
    [anon_sym_DOT_DOT] = ACTIONS(1927),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1613] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6911),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2930),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7031),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4456),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3742),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7420),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9374),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(1613),
    [sym_preproc_endregion] = STATE(1613),
    [sym_preproc_line] = STATE(1613),
    [sym_preproc_pragma] = STATE(1613),
    [sym_preproc_nullable] = STATE(1613),
    [sym_preproc_error] = STATE(1613),
    [sym_preproc_warning] = STATE(1613),
    [sym_preproc_define] = STATE(1613),
    [sym_preproc_undef] = STATE(1613),
    [aux_sym_class_declaration_repeat1] = STATE(3861),
    [aux_sym_lambda_expression_repeat1] = STATE(4169),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(2089),
    [anon_sym_ref] = ACTIONS(2091),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1695),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(2095),
    [anon_sym_TILDE] = ACTIONS(2095),
    [anon_sym_PLUS_PLUS] = ACTIONS(2095),
    [anon_sym_DASH_DASH] = ACTIONS(2095),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(2093),
    [anon_sym_DASH] = ACTIONS(2093),
    [anon_sym_STAR] = ACTIONS(1705),
    [anon_sym_CARET] = ACTIONS(2095),
    [anon_sym_AMP] = ACTIONS(2095),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(2097),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2099),
    [anon_sym_DOT_DOT] = ACTIONS(2101),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [1614] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6916),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7105),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6717),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3016),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1614),
    [sym_preproc_endregion] = STATE(1614),
    [sym_preproc_line] = STATE(1614),
    [sym_preproc_pragma] = STATE(1614),
    [sym_preproc_nullable] = STATE(1614),
    [sym_preproc_error] = STATE(1614),
    [sym_preproc_warning] = STATE(1614),
    [sym_preproc_define] = STATE(1614),
    [sym_preproc_undef] = STATE(1614),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2981),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(1259),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1615] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6956),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6686),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9482),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1615),
    [sym_preproc_endregion] = STATE(1615),
    [sym_preproc_line] = STATE(1615),
    [sym_preproc_pragma] = STATE(1615),
    [sym_preproc_nullable] = STATE(1615),
    [sym_preproc_error] = STATE(1615),
    [sym_preproc_warning] = STATE(1615),
    [sym_preproc_define] = STATE(1615),
    [sym_preproc_undef] = STATE(1615),
    [aux_sym_class_declaration_repeat1] = STATE(3853),
    [aux_sym_lambda_expression_repeat1] = STATE(4299),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1497),
    [anon_sym_ref] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1505),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1507),
    [anon_sym_DOT_DOT] = ACTIONS(1509),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1616] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6920),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2942),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7143),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6540),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4489),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7426),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9002),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1616),
    [sym_preproc_endregion] = STATE(1616),
    [sym_preproc_line] = STATE(1616),
    [sym_preproc_pragma] = STATE(1616),
    [sym_preproc_nullable] = STATE(1616),
    [sym_preproc_error] = STATE(1616),
    [sym_preproc_warning] = STATE(1616),
    [sym_preproc_define] = STATE(1616),
    [sym_preproc_undef] = STATE(1616),
    [aux_sym_class_declaration_repeat1] = STATE(3809),
    [aux_sym_lambda_expression_repeat1] = STATE(4308),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2189),
    [anon_sym_ref] = ACTIONS(2191),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2193),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2197),
    [anon_sym_TILDE] = ACTIONS(2197),
    [anon_sym_PLUS_PLUS] = ACTIONS(2197),
    [anon_sym_DASH_DASH] = ACTIONS(2197),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2195),
    [anon_sym_DASH] = ACTIONS(2195),
    [anon_sym_STAR] = ACTIONS(2199),
    [anon_sym_CARET] = ACTIONS(2197),
    [anon_sym_AMP] = ACTIONS(2197),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2201),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2203),
    [anon_sym_DOT_DOT] = ACTIONS(2205),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1617] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6920),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2942),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7143),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4336),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4489),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7426),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9002),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1617),
    [sym_preproc_endregion] = STATE(1617),
    [sym_preproc_line] = STATE(1617),
    [sym_preproc_pragma] = STATE(1617),
    [sym_preproc_nullable] = STATE(1617),
    [sym_preproc_error] = STATE(1617),
    [sym_preproc_warning] = STATE(1617),
    [sym_preproc_define] = STATE(1617),
    [sym_preproc_undef] = STATE(1617),
    [aux_sym_class_declaration_repeat1] = STATE(3809),
    [aux_sym_lambda_expression_repeat1] = STATE(4308),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2189),
    [anon_sym_ref] = ACTIONS(2191),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2193),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2197),
    [anon_sym_TILDE] = ACTIONS(2197),
    [anon_sym_PLUS_PLUS] = ACTIONS(2197),
    [anon_sym_DASH_DASH] = ACTIONS(2197),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2195),
    [anon_sym_DASH] = ACTIONS(2195),
    [anon_sym_STAR] = ACTIONS(2199),
    [anon_sym_CARET] = ACTIONS(2197),
    [anon_sym_AMP] = ACTIONS(2197),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2201),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2203),
    [anon_sym_DOT_DOT] = ACTIONS(2205),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1618] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6920),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2942),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7143),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6661),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4489),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7426),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9002),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1618),
    [sym_preproc_endregion] = STATE(1618),
    [sym_preproc_line] = STATE(1618),
    [sym_preproc_pragma] = STATE(1618),
    [sym_preproc_nullable] = STATE(1618),
    [sym_preproc_error] = STATE(1618),
    [sym_preproc_warning] = STATE(1618),
    [sym_preproc_define] = STATE(1618),
    [sym_preproc_undef] = STATE(1618),
    [aux_sym_class_declaration_repeat1] = STATE(3809),
    [aux_sym_lambda_expression_repeat1] = STATE(4308),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2189),
    [anon_sym_ref] = ACTIONS(2191),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2193),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2197),
    [anon_sym_TILDE] = ACTIONS(2197),
    [anon_sym_PLUS_PLUS] = ACTIONS(2197),
    [anon_sym_DASH_DASH] = ACTIONS(2197),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2195),
    [anon_sym_DASH] = ACTIONS(2195),
    [anon_sym_STAR] = ACTIONS(2199),
    [anon_sym_CARET] = ACTIONS(2197),
    [anon_sym_AMP] = ACTIONS(2197),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2201),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2203),
    [anon_sym_DOT_DOT] = ACTIONS(2205),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1619] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6920),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2942),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7143),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6666),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4489),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7426),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9002),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1619),
    [sym_preproc_endregion] = STATE(1619),
    [sym_preproc_line] = STATE(1619),
    [sym_preproc_pragma] = STATE(1619),
    [sym_preproc_nullable] = STATE(1619),
    [sym_preproc_error] = STATE(1619),
    [sym_preproc_warning] = STATE(1619),
    [sym_preproc_define] = STATE(1619),
    [sym_preproc_undef] = STATE(1619),
    [aux_sym_class_declaration_repeat1] = STATE(3809),
    [aux_sym_lambda_expression_repeat1] = STATE(4308),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2189),
    [anon_sym_ref] = ACTIONS(2191),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2193),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2197),
    [anon_sym_TILDE] = ACTIONS(2197),
    [anon_sym_PLUS_PLUS] = ACTIONS(2197),
    [anon_sym_DASH_DASH] = ACTIONS(2197),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2195),
    [anon_sym_DASH] = ACTIONS(2195),
    [anon_sym_STAR] = ACTIONS(2199),
    [anon_sym_CARET] = ACTIONS(2197),
    [anon_sym_AMP] = ACTIONS(2197),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2201),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2203),
    [anon_sym_DOT_DOT] = ACTIONS(2205),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1620] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6920),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2942),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7143),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6667),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4489),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7426),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9002),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1620),
    [sym_preproc_endregion] = STATE(1620),
    [sym_preproc_line] = STATE(1620),
    [sym_preproc_pragma] = STATE(1620),
    [sym_preproc_nullable] = STATE(1620),
    [sym_preproc_error] = STATE(1620),
    [sym_preproc_warning] = STATE(1620),
    [sym_preproc_define] = STATE(1620),
    [sym_preproc_undef] = STATE(1620),
    [aux_sym_class_declaration_repeat1] = STATE(3809),
    [aux_sym_lambda_expression_repeat1] = STATE(4308),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2189),
    [anon_sym_ref] = ACTIONS(2191),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2193),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2197),
    [anon_sym_TILDE] = ACTIONS(2197),
    [anon_sym_PLUS_PLUS] = ACTIONS(2197),
    [anon_sym_DASH_DASH] = ACTIONS(2197),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2195),
    [anon_sym_DASH] = ACTIONS(2195),
    [anon_sym_STAR] = ACTIONS(2199),
    [anon_sym_CARET] = ACTIONS(2197),
    [anon_sym_AMP] = ACTIONS(2197),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2201),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2203),
    [anon_sym_DOT_DOT] = ACTIONS(2205),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1621] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6920),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2942),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7143),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6668),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4489),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7426),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9002),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1621),
    [sym_preproc_endregion] = STATE(1621),
    [sym_preproc_line] = STATE(1621),
    [sym_preproc_pragma] = STATE(1621),
    [sym_preproc_nullable] = STATE(1621),
    [sym_preproc_error] = STATE(1621),
    [sym_preproc_warning] = STATE(1621),
    [sym_preproc_define] = STATE(1621),
    [sym_preproc_undef] = STATE(1621),
    [aux_sym_class_declaration_repeat1] = STATE(3809),
    [aux_sym_lambda_expression_repeat1] = STATE(4308),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2189),
    [anon_sym_ref] = ACTIONS(2191),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2193),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2197),
    [anon_sym_TILDE] = ACTIONS(2197),
    [anon_sym_PLUS_PLUS] = ACTIONS(2197),
    [anon_sym_DASH_DASH] = ACTIONS(2197),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2195),
    [anon_sym_DASH] = ACTIONS(2195),
    [anon_sym_STAR] = ACTIONS(2199),
    [anon_sym_CARET] = ACTIONS(2197),
    [anon_sym_AMP] = ACTIONS(2197),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2201),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2203),
    [anon_sym_DOT_DOT] = ACTIONS(2205),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1622] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6920),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2942),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7143),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6669),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4489),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7426),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9002),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1622),
    [sym_preproc_endregion] = STATE(1622),
    [sym_preproc_line] = STATE(1622),
    [sym_preproc_pragma] = STATE(1622),
    [sym_preproc_nullable] = STATE(1622),
    [sym_preproc_error] = STATE(1622),
    [sym_preproc_warning] = STATE(1622),
    [sym_preproc_define] = STATE(1622),
    [sym_preproc_undef] = STATE(1622),
    [aux_sym_class_declaration_repeat1] = STATE(3809),
    [aux_sym_lambda_expression_repeat1] = STATE(4308),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2189),
    [anon_sym_ref] = ACTIONS(2191),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2193),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2197),
    [anon_sym_TILDE] = ACTIONS(2197),
    [anon_sym_PLUS_PLUS] = ACTIONS(2197),
    [anon_sym_DASH_DASH] = ACTIONS(2197),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2195),
    [anon_sym_DASH] = ACTIONS(2195),
    [anon_sym_STAR] = ACTIONS(2199),
    [anon_sym_CARET] = ACTIONS(2197),
    [anon_sym_AMP] = ACTIONS(2197),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2201),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2203),
    [anon_sym_DOT_DOT] = ACTIONS(2205),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1623] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6920),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2942),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7143),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6670),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4489),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7426),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9002),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1623),
    [sym_preproc_endregion] = STATE(1623),
    [sym_preproc_line] = STATE(1623),
    [sym_preproc_pragma] = STATE(1623),
    [sym_preproc_nullable] = STATE(1623),
    [sym_preproc_error] = STATE(1623),
    [sym_preproc_warning] = STATE(1623),
    [sym_preproc_define] = STATE(1623),
    [sym_preproc_undef] = STATE(1623),
    [aux_sym_class_declaration_repeat1] = STATE(3809),
    [aux_sym_lambda_expression_repeat1] = STATE(4308),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2189),
    [anon_sym_ref] = ACTIONS(2191),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2193),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2197),
    [anon_sym_TILDE] = ACTIONS(2197),
    [anon_sym_PLUS_PLUS] = ACTIONS(2197),
    [anon_sym_DASH_DASH] = ACTIONS(2197),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2195),
    [anon_sym_DASH] = ACTIONS(2195),
    [anon_sym_STAR] = ACTIONS(2199),
    [anon_sym_CARET] = ACTIONS(2197),
    [anon_sym_AMP] = ACTIONS(2197),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2201),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2203),
    [anon_sym_DOT_DOT] = ACTIONS(2205),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1624] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6920),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2942),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7143),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6671),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4489),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7426),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9002),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1624),
    [sym_preproc_endregion] = STATE(1624),
    [sym_preproc_line] = STATE(1624),
    [sym_preproc_pragma] = STATE(1624),
    [sym_preproc_nullable] = STATE(1624),
    [sym_preproc_error] = STATE(1624),
    [sym_preproc_warning] = STATE(1624),
    [sym_preproc_define] = STATE(1624),
    [sym_preproc_undef] = STATE(1624),
    [aux_sym_class_declaration_repeat1] = STATE(3809),
    [aux_sym_lambda_expression_repeat1] = STATE(4308),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2189),
    [anon_sym_ref] = ACTIONS(2191),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2193),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2197),
    [anon_sym_TILDE] = ACTIONS(2197),
    [anon_sym_PLUS_PLUS] = ACTIONS(2197),
    [anon_sym_DASH_DASH] = ACTIONS(2197),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2195),
    [anon_sym_DASH] = ACTIONS(2195),
    [anon_sym_STAR] = ACTIONS(2199),
    [anon_sym_CARET] = ACTIONS(2197),
    [anon_sym_AMP] = ACTIONS(2197),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2201),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2203),
    [anon_sym_DOT_DOT] = ACTIONS(2205),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1625] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6920),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2942),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7143),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6674),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4489),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7426),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9002),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1625),
    [sym_preproc_endregion] = STATE(1625),
    [sym_preproc_line] = STATE(1625),
    [sym_preproc_pragma] = STATE(1625),
    [sym_preproc_nullable] = STATE(1625),
    [sym_preproc_error] = STATE(1625),
    [sym_preproc_warning] = STATE(1625),
    [sym_preproc_define] = STATE(1625),
    [sym_preproc_undef] = STATE(1625),
    [aux_sym_class_declaration_repeat1] = STATE(3809),
    [aux_sym_lambda_expression_repeat1] = STATE(4308),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2189),
    [anon_sym_ref] = ACTIONS(2191),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2193),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2197),
    [anon_sym_TILDE] = ACTIONS(2197),
    [anon_sym_PLUS_PLUS] = ACTIONS(2197),
    [anon_sym_DASH_DASH] = ACTIONS(2197),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2195),
    [anon_sym_DASH] = ACTIONS(2195),
    [anon_sym_STAR] = ACTIONS(2199),
    [anon_sym_CARET] = ACTIONS(2197),
    [anon_sym_AMP] = ACTIONS(2197),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2201),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2203),
    [anon_sym_DOT_DOT] = ACTIONS(2205),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1626] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6920),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2942),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7143),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6677),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4489),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7426),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9002),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1626),
    [sym_preproc_endregion] = STATE(1626),
    [sym_preproc_line] = STATE(1626),
    [sym_preproc_pragma] = STATE(1626),
    [sym_preproc_nullable] = STATE(1626),
    [sym_preproc_error] = STATE(1626),
    [sym_preproc_warning] = STATE(1626),
    [sym_preproc_define] = STATE(1626),
    [sym_preproc_undef] = STATE(1626),
    [aux_sym_class_declaration_repeat1] = STATE(3809),
    [aux_sym_lambda_expression_repeat1] = STATE(4308),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2189),
    [anon_sym_ref] = ACTIONS(2191),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2193),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2197),
    [anon_sym_TILDE] = ACTIONS(2197),
    [anon_sym_PLUS_PLUS] = ACTIONS(2197),
    [anon_sym_DASH_DASH] = ACTIONS(2197),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2195),
    [anon_sym_DASH] = ACTIONS(2195),
    [anon_sym_STAR] = ACTIONS(2199),
    [anon_sym_CARET] = ACTIONS(2197),
    [anon_sym_AMP] = ACTIONS(2197),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2201),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2203),
    [anon_sym_DOT_DOT] = ACTIONS(2205),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1627] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6920),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2942),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7143),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6678),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4489),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7426),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9002),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1627),
    [sym_preproc_endregion] = STATE(1627),
    [sym_preproc_line] = STATE(1627),
    [sym_preproc_pragma] = STATE(1627),
    [sym_preproc_nullable] = STATE(1627),
    [sym_preproc_error] = STATE(1627),
    [sym_preproc_warning] = STATE(1627),
    [sym_preproc_define] = STATE(1627),
    [sym_preproc_undef] = STATE(1627),
    [aux_sym_class_declaration_repeat1] = STATE(3809),
    [aux_sym_lambda_expression_repeat1] = STATE(4308),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2189),
    [anon_sym_ref] = ACTIONS(2191),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2193),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2197),
    [anon_sym_TILDE] = ACTIONS(2197),
    [anon_sym_PLUS_PLUS] = ACTIONS(2197),
    [anon_sym_DASH_DASH] = ACTIONS(2197),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2195),
    [anon_sym_DASH] = ACTIONS(2195),
    [anon_sym_STAR] = ACTIONS(2199),
    [anon_sym_CARET] = ACTIONS(2197),
    [anon_sym_AMP] = ACTIONS(2197),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2201),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2203),
    [anon_sym_DOT_DOT] = ACTIONS(2205),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1628] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6920),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2942),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7143),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6680),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4489),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7426),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9002),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1628),
    [sym_preproc_endregion] = STATE(1628),
    [sym_preproc_line] = STATE(1628),
    [sym_preproc_pragma] = STATE(1628),
    [sym_preproc_nullable] = STATE(1628),
    [sym_preproc_error] = STATE(1628),
    [sym_preproc_warning] = STATE(1628),
    [sym_preproc_define] = STATE(1628),
    [sym_preproc_undef] = STATE(1628),
    [aux_sym_class_declaration_repeat1] = STATE(3809),
    [aux_sym_lambda_expression_repeat1] = STATE(4308),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2189),
    [anon_sym_ref] = ACTIONS(2191),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2193),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2197),
    [anon_sym_TILDE] = ACTIONS(2197),
    [anon_sym_PLUS_PLUS] = ACTIONS(2197),
    [anon_sym_DASH_DASH] = ACTIONS(2197),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2195),
    [anon_sym_DASH] = ACTIONS(2195),
    [anon_sym_STAR] = ACTIONS(2199),
    [anon_sym_CARET] = ACTIONS(2197),
    [anon_sym_AMP] = ACTIONS(2197),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2201),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2203),
    [anon_sym_DOT_DOT] = ACTIONS(2205),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1629] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6920),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2942),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7143),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6356),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4489),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7426),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9002),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1629),
    [sym_preproc_endregion] = STATE(1629),
    [sym_preproc_line] = STATE(1629),
    [sym_preproc_pragma] = STATE(1629),
    [sym_preproc_nullable] = STATE(1629),
    [sym_preproc_error] = STATE(1629),
    [sym_preproc_warning] = STATE(1629),
    [sym_preproc_define] = STATE(1629),
    [sym_preproc_undef] = STATE(1629),
    [aux_sym_class_declaration_repeat1] = STATE(3809),
    [aux_sym_lambda_expression_repeat1] = STATE(4308),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2189),
    [anon_sym_ref] = ACTIONS(2191),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2193),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2197),
    [anon_sym_TILDE] = ACTIONS(2197),
    [anon_sym_PLUS_PLUS] = ACTIONS(2197),
    [anon_sym_DASH_DASH] = ACTIONS(2197),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2195),
    [anon_sym_DASH] = ACTIONS(2195),
    [anon_sym_STAR] = ACTIONS(2199),
    [anon_sym_CARET] = ACTIONS(2197),
    [anon_sym_AMP] = ACTIONS(2197),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2201),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2203),
    [anon_sym_DOT_DOT] = ACTIONS(2205),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1630] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6915),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7018),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4463),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3585),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7418),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9926),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1630),
    [sym_preproc_endregion] = STATE(1630),
    [sym_preproc_line] = STATE(1630),
    [sym_preproc_pragma] = STATE(1630),
    [sym_preproc_nullable] = STATE(1630),
    [sym_preproc_error] = STATE(1630),
    [sym_preproc_warning] = STATE(1630),
    [sym_preproc_define] = STATE(1630),
    [sym_preproc_undef] = STATE(1630),
    [aux_sym_class_declaration_repeat1] = STATE(3825),
    [aux_sym_lambda_expression_repeat1] = STATE(4244),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1161),
    [anon_sym_ref] = ACTIONS(1163),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1177),
    [anon_sym_TILDE] = ACTIONS(1177),
    [anon_sym_PLUS_PLUS] = ACTIONS(1177),
    [anon_sym_DASH_DASH] = ACTIONS(1177),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1175),
    [anon_sym_DASH] = ACTIONS(1175),
    [anon_sym_STAR] = ACTIONS(1181),
    [anon_sym_CARET] = ACTIONS(1177),
    [anon_sym_AMP] = ACTIONS(1177),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1191),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1193),
    [anon_sym_DOT_DOT] = ACTIONS(1195),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1631] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6920),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2942),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7143),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4338),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4489),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7426),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9002),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1631),
    [sym_preproc_endregion] = STATE(1631),
    [sym_preproc_line] = STATE(1631),
    [sym_preproc_pragma] = STATE(1631),
    [sym_preproc_nullable] = STATE(1631),
    [sym_preproc_error] = STATE(1631),
    [sym_preproc_warning] = STATE(1631),
    [sym_preproc_define] = STATE(1631),
    [sym_preproc_undef] = STATE(1631),
    [aux_sym_class_declaration_repeat1] = STATE(3809),
    [aux_sym_lambda_expression_repeat1] = STATE(4308),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2189),
    [anon_sym_ref] = ACTIONS(2191),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2193),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2197),
    [anon_sym_TILDE] = ACTIONS(2197),
    [anon_sym_PLUS_PLUS] = ACTIONS(2197),
    [anon_sym_DASH_DASH] = ACTIONS(2197),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2195),
    [anon_sym_DASH] = ACTIONS(2195),
    [anon_sym_STAR] = ACTIONS(2199),
    [anon_sym_CARET] = ACTIONS(2197),
    [anon_sym_AMP] = ACTIONS(2197),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2201),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2203),
    [anon_sym_DOT_DOT] = ACTIONS(2205),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1632] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6956),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6478),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9482),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1632),
    [sym_preproc_endregion] = STATE(1632),
    [sym_preproc_line] = STATE(1632),
    [sym_preproc_pragma] = STATE(1632),
    [sym_preproc_nullable] = STATE(1632),
    [sym_preproc_error] = STATE(1632),
    [sym_preproc_warning] = STATE(1632),
    [sym_preproc_define] = STATE(1632),
    [sym_preproc_undef] = STATE(1632),
    [aux_sym_class_declaration_repeat1] = STATE(3853),
    [aux_sym_lambda_expression_repeat1] = STATE(4299),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1497),
    [anon_sym_ref] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1505),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1507),
    [anon_sym_DOT_DOT] = ACTIONS(1509),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1633] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6920),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2942),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7032),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6047),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4337),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7427),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9283),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1633),
    [sym_preproc_endregion] = STATE(1633),
    [sym_preproc_line] = STATE(1633),
    [sym_preproc_pragma] = STATE(1633),
    [sym_preproc_nullable] = STATE(1633),
    [sym_preproc_error] = STATE(1633),
    [sym_preproc_warning] = STATE(1633),
    [sym_preproc_define] = STATE(1633),
    [sym_preproc_undef] = STATE(1633),
    [aux_sym_class_declaration_repeat1] = STATE(3829),
    [aux_sym_lambda_expression_repeat1] = STATE(4252),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1801),
    [anon_sym_ref] = ACTIONS(1803),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1805),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1809),
    [anon_sym_TILDE] = ACTIONS(1809),
    [anon_sym_PLUS_PLUS] = ACTIONS(1809),
    [anon_sym_DASH_DASH] = ACTIONS(1809),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1807),
    [anon_sym_DASH] = ACTIONS(1807),
    [anon_sym_STAR] = ACTIONS(1811),
    [anon_sym_CARET] = ACTIONS(1809),
    [anon_sym_AMP] = ACTIONS(1809),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1813),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1815),
    [anon_sym_DOT_DOT] = ACTIONS(1817),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1634] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6920),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2942),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7143),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6329),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4489),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7426),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9002),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1634),
    [sym_preproc_endregion] = STATE(1634),
    [sym_preproc_line] = STATE(1634),
    [sym_preproc_pragma] = STATE(1634),
    [sym_preproc_nullable] = STATE(1634),
    [sym_preproc_error] = STATE(1634),
    [sym_preproc_warning] = STATE(1634),
    [sym_preproc_define] = STATE(1634),
    [sym_preproc_undef] = STATE(1634),
    [aux_sym_class_declaration_repeat1] = STATE(3809),
    [aux_sym_lambda_expression_repeat1] = STATE(4308),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2189),
    [anon_sym_ref] = ACTIONS(2191),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2193),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2197),
    [anon_sym_TILDE] = ACTIONS(2197),
    [anon_sym_PLUS_PLUS] = ACTIONS(2197),
    [anon_sym_DASH_DASH] = ACTIONS(2197),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2195),
    [anon_sym_DASH] = ACTIONS(2195),
    [anon_sym_STAR] = ACTIONS(2199),
    [anon_sym_CARET] = ACTIONS(2197),
    [anon_sym_AMP] = ACTIONS(2197),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2201),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2203),
    [anon_sym_DOT_DOT] = ACTIONS(2205),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1635] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6915),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7018),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4494),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3585),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7418),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9926),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1635),
    [sym_preproc_endregion] = STATE(1635),
    [sym_preproc_line] = STATE(1635),
    [sym_preproc_pragma] = STATE(1635),
    [sym_preproc_nullable] = STATE(1635),
    [sym_preproc_error] = STATE(1635),
    [sym_preproc_warning] = STATE(1635),
    [sym_preproc_define] = STATE(1635),
    [sym_preproc_undef] = STATE(1635),
    [aux_sym_class_declaration_repeat1] = STATE(3825),
    [aux_sym_lambda_expression_repeat1] = STATE(4244),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1161),
    [anon_sym_ref] = ACTIONS(1163),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1177),
    [anon_sym_TILDE] = ACTIONS(1177),
    [anon_sym_PLUS_PLUS] = ACTIONS(1177),
    [anon_sym_DASH_DASH] = ACTIONS(1177),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1175),
    [anon_sym_DASH] = ACTIONS(1175),
    [anon_sym_STAR] = ACTIONS(1181),
    [anon_sym_CARET] = ACTIONS(1177),
    [anon_sym_AMP] = ACTIONS(1177),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1191),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1193),
    [anon_sym_DOT_DOT] = ACTIONS(1195),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1636] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6480),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1636),
    [sym_preproc_endregion] = STATE(1636),
    [sym_preproc_line] = STATE(1636),
    [sym_preproc_pragma] = STATE(1636),
    [sym_preproc_nullable] = STATE(1636),
    [sym_preproc_error] = STATE(1636),
    [sym_preproc_warning] = STATE(1636),
    [sym_preproc_define] = STATE(1636),
    [sym_preproc_undef] = STATE(1636),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1637] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7014),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5988),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4335),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7428),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9866),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1637),
    [sym_preproc_endregion] = STATE(1637),
    [sym_preproc_line] = STATE(1637),
    [sym_preproc_pragma] = STATE(1637),
    [sym_preproc_nullable] = STATE(1637),
    [sym_preproc_error] = STATE(1637),
    [sym_preproc_warning] = STATE(1637),
    [sym_preproc_define] = STATE(1637),
    [sym_preproc_undef] = STATE(1637),
    [aux_sym_class_declaration_repeat1] = STATE(3824),
    [aux_sym_lambda_expression_repeat1] = STATE(4242),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1539),
    [anon_sym_ref] = ACTIONS(1541),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1545),
    [anon_sym_TILDE] = ACTIONS(1545),
    [anon_sym_PLUS_PLUS] = ACTIONS(1545),
    [anon_sym_DASH_DASH] = ACTIONS(1545),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1543),
    [anon_sym_DASH] = ACTIONS(1543),
    [anon_sym_STAR] = ACTIONS(1547),
    [anon_sym_CARET] = ACTIONS(1545),
    [anon_sym_AMP] = ACTIONS(1545),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1549),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1551),
    [anon_sym_DOT_DOT] = ACTIONS(1553),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1638] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7014),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5989),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4335),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7428),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9866),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1638),
    [sym_preproc_endregion] = STATE(1638),
    [sym_preproc_line] = STATE(1638),
    [sym_preproc_pragma] = STATE(1638),
    [sym_preproc_nullable] = STATE(1638),
    [sym_preproc_error] = STATE(1638),
    [sym_preproc_warning] = STATE(1638),
    [sym_preproc_define] = STATE(1638),
    [sym_preproc_undef] = STATE(1638),
    [aux_sym_class_declaration_repeat1] = STATE(3824),
    [aux_sym_lambda_expression_repeat1] = STATE(4242),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1539),
    [anon_sym_ref] = ACTIONS(1541),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1545),
    [anon_sym_TILDE] = ACTIONS(1545),
    [anon_sym_PLUS_PLUS] = ACTIONS(1545),
    [anon_sym_DASH_DASH] = ACTIONS(1545),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1543),
    [anon_sym_DASH] = ACTIONS(1543),
    [anon_sym_STAR] = ACTIONS(1547),
    [anon_sym_CARET] = ACTIONS(1545),
    [anon_sym_AMP] = ACTIONS(1545),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1549),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1551),
    [anon_sym_DOT_DOT] = ACTIONS(1553),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1639] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7014),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6040),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4335),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7428),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9866),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1639),
    [sym_preproc_endregion] = STATE(1639),
    [sym_preproc_line] = STATE(1639),
    [sym_preproc_pragma] = STATE(1639),
    [sym_preproc_nullable] = STATE(1639),
    [sym_preproc_error] = STATE(1639),
    [sym_preproc_warning] = STATE(1639),
    [sym_preproc_define] = STATE(1639),
    [sym_preproc_undef] = STATE(1639),
    [aux_sym_class_declaration_repeat1] = STATE(3824),
    [aux_sym_lambda_expression_repeat1] = STATE(4242),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1539),
    [anon_sym_ref] = ACTIONS(1541),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1545),
    [anon_sym_TILDE] = ACTIONS(1545),
    [anon_sym_PLUS_PLUS] = ACTIONS(1545),
    [anon_sym_DASH_DASH] = ACTIONS(1545),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1543),
    [anon_sym_DASH] = ACTIONS(1543),
    [anon_sym_STAR] = ACTIONS(1547),
    [anon_sym_CARET] = ACTIONS(1545),
    [anon_sym_AMP] = ACTIONS(1545),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1549),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1551),
    [anon_sym_DOT_DOT] = ACTIONS(1553),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1640] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7014),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5990),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4335),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7428),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9866),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1640),
    [sym_preproc_endregion] = STATE(1640),
    [sym_preproc_line] = STATE(1640),
    [sym_preproc_pragma] = STATE(1640),
    [sym_preproc_nullable] = STATE(1640),
    [sym_preproc_error] = STATE(1640),
    [sym_preproc_warning] = STATE(1640),
    [sym_preproc_define] = STATE(1640),
    [sym_preproc_undef] = STATE(1640),
    [aux_sym_class_declaration_repeat1] = STATE(3824),
    [aux_sym_lambda_expression_repeat1] = STATE(4242),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1539),
    [anon_sym_ref] = ACTIONS(1541),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1545),
    [anon_sym_TILDE] = ACTIONS(1545),
    [anon_sym_PLUS_PLUS] = ACTIONS(1545),
    [anon_sym_DASH_DASH] = ACTIONS(1545),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1543),
    [anon_sym_DASH] = ACTIONS(1543),
    [anon_sym_STAR] = ACTIONS(1547),
    [anon_sym_CARET] = ACTIONS(1545),
    [anon_sym_AMP] = ACTIONS(1545),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1549),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1551),
    [anon_sym_DOT_DOT] = ACTIONS(1553),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1641] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7014),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5991),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4335),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7428),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9866),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1641),
    [sym_preproc_endregion] = STATE(1641),
    [sym_preproc_line] = STATE(1641),
    [sym_preproc_pragma] = STATE(1641),
    [sym_preproc_nullable] = STATE(1641),
    [sym_preproc_error] = STATE(1641),
    [sym_preproc_warning] = STATE(1641),
    [sym_preproc_define] = STATE(1641),
    [sym_preproc_undef] = STATE(1641),
    [aux_sym_class_declaration_repeat1] = STATE(3824),
    [aux_sym_lambda_expression_repeat1] = STATE(4242),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1539),
    [anon_sym_ref] = ACTIONS(1541),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1545),
    [anon_sym_TILDE] = ACTIONS(1545),
    [anon_sym_PLUS_PLUS] = ACTIONS(1545),
    [anon_sym_DASH_DASH] = ACTIONS(1545),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1543),
    [anon_sym_DASH] = ACTIONS(1543),
    [anon_sym_STAR] = ACTIONS(1547),
    [anon_sym_CARET] = ACTIONS(1545),
    [anon_sym_AMP] = ACTIONS(1545),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1549),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1551),
    [anon_sym_DOT_DOT] = ACTIONS(1553),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1642] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7014),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5994),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4335),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7428),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9866),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1642),
    [sym_preproc_endregion] = STATE(1642),
    [sym_preproc_line] = STATE(1642),
    [sym_preproc_pragma] = STATE(1642),
    [sym_preproc_nullable] = STATE(1642),
    [sym_preproc_error] = STATE(1642),
    [sym_preproc_warning] = STATE(1642),
    [sym_preproc_define] = STATE(1642),
    [sym_preproc_undef] = STATE(1642),
    [aux_sym_class_declaration_repeat1] = STATE(3824),
    [aux_sym_lambda_expression_repeat1] = STATE(4242),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1539),
    [anon_sym_ref] = ACTIONS(1541),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1545),
    [anon_sym_TILDE] = ACTIONS(1545),
    [anon_sym_PLUS_PLUS] = ACTIONS(1545),
    [anon_sym_DASH_DASH] = ACTIONS(1545),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1543),
    [anon_sym_DASH] = ACTIONS(1543),
    [anon_sym_STAR] = ACTIONS(1547),
    [anon_sym_CARET] = ACTIONS(1545),
    [anon_sym_AMP] = ACTIONS(1545),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1549),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1551),
    [anon_sym_DOT_DOT] = ACTIONS(1553),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1643] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7014),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5995),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4335),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7428),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9866),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1643),
    [sym_preproc_endregion] = STATE(1643),
    [sym_preproc_line] = STATE(1643),
    [sym_preproc_pragma] = STATE(1643),
    [sym_preproc_nullable] = STATE(1643),
    [sym_preproc_error] = STATE(1643),
    [sym_preproc_warning] = STATE(1643),
    [sym_preproc_define] = STATE(1643),
    [sym_preproc_undef] = STATE(1643),
    [aux_sym_class_declaration_repeat1] = STATE(3824),
    [aux_sym_lambda_expression_repeat1] = STATE(4242),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1539),
    [anon_sym_ref] = ACTIONS(1541),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1545),
    [anon_sym_TILDE] = ACTIONS(1545),
    [anon_sym_PLUS_PLUS] = ACTIONS(1545),
    [anon_sym_DASH_DASH] = ACTIONS(1545),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1543),
    [anon_sym_DASH] = ACTIONS(1543),
    [anon_sym_STAR] = ACTIONS(1547),
    [anon_sym_CARET] = ACTIONS(1545),
    [anon_sym_AMP] = ACTIONS(1545),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1549),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1551),
    [anon_sym_DOT_DOT] = ACTIONS(1553),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1644] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7014),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5996),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4335),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7428),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9866),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1644),
    [sym_preproc_endregion] = STATE(1644),
    [sym_preproc_line] = STATE(1644),
    [sym_preproc_pragma] = STATE(1644),
    [sym_preproc_nullable] = STATE(1644),
    [sym_preproc_error] = STATE(1644),
    [sym_preproc_warning] = STATE(1644),
    [sym_preproc_define] = STATE(1644),
    [sym_preproc_undef] = STATE(1644),
    [aux_sym_class_declaration_repeat1] = STATE(3824),
    [aux_sym_lambda_expression_repeat1] = STATE(4242),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1539),
    [anon_sym_ref] = ACTIONS(1541),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1545),
    [anon_sym_TILDE] = ACTIONS(1545),
    [anon_sym_PLUS_PLUS] = ACTIONS(1545),
    [anon_sym_DASH_DASH] = ACTIONS(1545),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1543),
    [anon_sym_DASH] = ACTIONS(1543),
    [anon_sym_STAR] = ACTIONS(1547),
    [anon_sym_CARET] = ACTIONS(1545),
    [anon_sym_AMP] = ACTIONS(1545),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1549),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1551),
    [anon_sym_DOT_DOT] = ACTIONS(1553),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1645] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7014),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5997),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4335),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7428),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9866),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1645),
    [sym_preproc_endregion] = STATE(1645),
    [sym_preproc_line] = STATE(1645),
    [sym_preproc_pragma] = STATE(1645),
    [sym_preproc_nullable] = STATE(1645),
    [sym_preproc_error] = STATE(1645),
    [sym_preproc_warning] = STATE(1645),
    [sym_preproc_define] = STATE(1645),
    [sym_preproc_undef] = STATE(1645),
    [aux_sym_class_declaration_repeat1] = STATE(3824),
    [aux_sym_lambda_expression_repeat1] = STATE(4242),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1539),
    [anon_sym_ref] = ACTIONS(1541),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1545),
    [anon_sym_TILDE] = ACTIONS(1545),
    [anon_sym_PLUS_PLUS] = ACTIONS(1545),
    [anon_sym_DASH_DASH] = ACTIONS(1545),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1543),
    [anon_sym_DASH] = ACTIONS(1543),
    [anon_sym_STAR] = ACTIONS(1547),
    [anon_sym_CARET] = ACTIONS(1545),
    [anon_sym_AMP] = ACTIONS(1545),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1549),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1551),
    [anon_sym_DOT_DOT] = ACTIONS(1553),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1646] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7014),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5998),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4335),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7428),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9866),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1646),
    [sym_preproc_endregion] = STATE(1646),
    [sym_preproc_line] = STATE(1646),
    [sym_preproc_pragma] = STATE(1646),
    [sym_preproc_nullable] = STATE(1646),
    [sym_preproc_error] = STATE(1646),
    [sym_preproc_warning] = STATE(1646),
    [sym_preproc_define] = STATE(1646),
    [sym_preproc_undef] = STATE(1646),
    [aux_sym_class_declaration_repeat1] = STATE(3824),
    [aux_sym_lambda_expression_repeat1] = STATE(4242),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1539),
    [anon_sym_ref] = ACTIONS(1541),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1545),
    [anon_sym_TILDE] = ACTIONS(1545),
    [anon_sym_PLUS_PLUS] = ACTIONS(1545),
    [anon_sym_DASH_DASH] = ACTIONS(1545),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1543),
    [anon_sym_DASH] = ACTIONS(1543),
    [anon_sym_STAR] = ACTIONS(1547),
    [anon_sym_CARET] = ACTIONS(1545),
    [anon_sym_AMP] = ACTIONS(1545),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1549),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1551),
    [anon_sym_DOT_DOT] = ACTIONS(1553),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1647] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7014),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5999),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4335),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7428),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9866),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1647),
    [sym_preproc_endregion] = STATE(1647),
    [sym_preproc_line] = STATE(1647),
    [sym_preproc_pragma] = STATE(1647),
    [sym_preproc_nullable] = STATE(1647),
    [sym_preproc_error] = STATE(1647),
    [sym_preproc_warning] = STATE(1647),
    [sym_preproc_define] = STATE(1647),
    [sym_preproc_undef] = STATE(1647),
    [aux_sym_class_declaration_repeat1] = STATE(3824),
    [aux_sym_lambda_expression_repeat1] = STATE(4242),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1539),
    [anon_sym_ref] = ACTIONS(1541),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1545),
    [anon_sym_TILDE] = ACTIONS(1545),
    [anon_sym_PLUS_PLUS] = ACTIONS(1545),
    [anon_sym_DASH_DASH] = ACTIONS(1545),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1543),
    [anon_sym_DASH] = ACTIONS(1543),
    [anon_sym_STAR] = ACTIONS(1547),
    [anon_sym_CARET] = ACTIONS(1545),
    [anon_sym_AMP] = ACTIONS(1545),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1549),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1551),
    [anon_sym_DOT_DOT] = ACTIONS(1553),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1648] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7014),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3932),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4335),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7428),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9866),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1648),
    [sym_preproc_endregion] = STATE(1648),
    [sym_preproc_line] = STATE(1648),
    [sym_preproc_pragma] = STATE(1648),
    [sym_preproc_nullable] = STATE(1648),
    [sym_preproc_error] = STATE(1648),
    [sym_preproc_warning] = STATE(1648),
    [sym_preproc_define] = STATE(1648),
    [sym_preproc_undef] = STATE(1648),
    [aux_sym_class_declaration_repeat1] = STATE(3824),
    [aux_sym_lambda_expression_repeat1] = STATE(4242),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1539),
    [anon_sym_ref] = ACTIONS(1541),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1545),
    [anon_sym_TILDE] = ACTIONS(1545),
    [anon_sym_PLUS_PLUS] = ACTIONS(1545),
    [anon_sym_DASH_DASH] = ACTIONS(1545),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1543),
    [anon_sym_DASH] = ACTIONS(1543),
    [anon_sym_STAR] = ACTIONS(1547),
    [anon_sym_CARET] = ACTIONS(1545),
    [anon_sym_AMP] = ACTIONS(1545),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1549),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1551),
    [anon_sym_DOT_DOT] = ACTIONS(1553),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1649] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6482),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1649),
    [sym_preproc_endregion] = STATE(1649),
    [sym_preproc_line] = STATE(1649),
    [sym_preproc_pragma] = STATE(1649),
    [sym_preproc_nullable] = STATE(1649),
    [sym_preproc_error] = STATE(1649),
    [sym_preproc_warning] = STATE(1649),
    [sym_preproc_define] = STATE(1649),
    [sym_preproc_undef] = STATE(1649),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1650] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6926),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2950),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7053),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6264),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4458),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7431),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9158),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1650),
    [sym_preproc_endregion] = STATE(1650),
    [sym_preproc_line] = STATE(1650),
    [sym_preproc_pragma] = STATE(1650),
    [sym_preproc_nullable] = STATE(1650),
    [sym_preproc_error] = STATE(1650),
    [sym_preproc_warning] = STATE(1650),
    [sym_preproc_define] = STATE(1650),
    [sym_preproc_undef] = STATE(1650),
    [aux_sym_class_declaration_repeat1] = STATE(3835),
    [aux_sym_lambda_expression_repeat1] = STATE(4263),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2213),
    [anon_sym_ref] = ACTIONS(2215),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2217),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2221),
    [anon_sym_TILDE] = ACTIONS(2221),
    [anon_sym_PLUS_PLUS] = ACTIONS(2221),
    [anon_sym_DASH_DASH] = ACTIONS(2221),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2219),
    [anon_sym_DASH] = ACTIONS(2219),
    [anon_sym_STAR] = ACTIONS(2223),
    [anon_sym_CARET] = ACTIONS(2221),
    [anon_sym_AMP] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2225),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2227),
    [anon_sym_DOT_DOT] = ACTIONS(2229),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1651] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6926),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2950),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7053),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3567),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4458),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7431),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9158),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1651),
    [sym_preproc_endregion] = STATE(1651),
    [sym_preproc_line] = STATE(1651),
    [sym_preproc_pragma] = STATE(1651),
    [sym_preproc_nullable] = STATE(1651),
    [sym_preproc_error] = STATE(1651),
    [sym_preproc_warning] = STATE(1651),
    [sym_preproc_define] = STATE(1651),
    [sym_preproc_undef] = STATE(1651),
    [aux_sym_class_declaration_repeat1] = STATE(3835),
    [aux_sym_lambda_expression_repeat1] = STATE(4263),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2213),
    [anon_sym_ref] = ACTIONS(2215),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2217),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2221),
    [anon_sym_TILDE] = ACTIONS(2221),
    [anon_sym_PLUS_PLUS] = ACTIONS(2221),
    [anon_sym_DASH_DASH] = ACTIONS(2221),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2219),
    [anon_sym_DASH] = ACTIONS(2219),
    [anon_sym_STAR] = ACTIONS(2223),
    [anon_sym_CARET] = ACTIONS(2221),
    [anon_sym_AMP] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2225),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2227),
    [anon_sym_DOT_DOT] = ACTIONS(2229),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1652] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6926),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2950),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7053),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6266),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4458),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7431),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9158),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1652),
    [sym_preproc_endregion] = STATE(1652),
    [sym_preproc_line] = STATE(1652),
    [sym_preproc_pragma] = STATE(1652),
    [sym_preproc_nullable] = STATE(1652),
    [sym_preproc_error] = STATE(1652),
    [sym_preproc_warning] = STATE(1652),
    [sym_preproc_define] = STATE(1652),
    [sym_preproc_undef] = STATE(1652),
    [aux_sym_class_declaration_repeat1] = STATE(3835),
    [aux_sym_lambda_expression_repeat1] = STATE(4263),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2213),
    [anon_sym_ref] = ACTIONS(2215),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2217),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2221),
    [anon_sym_TILDE] = ACTIONS(2221),
    [anon_sym_PLUS_PLUS] = ACTIONS(2221),
    [anon_sym_DASH_DASH] = ACTIONS(2221),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2219),
    [anon_sym_DASH] = ACTIONS(2219),
    [anon_sym_STAR] = ACTIONS(2223),
    [anon_sym_CARET] = ACTIONS(2221),
    [anon_sym_AMP] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2225),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2227),
    [anon_sym_DOT_DOT] = ACTIONS(2229),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1653] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6492),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1653),
    [sym_preproc_endregion] = STATE(1653),
    [sym_preproc_line] = STATE(1653),
    [sym_preproc_pragma] = STATE(1653),
    [sym_preproc_nullable] = STATE(1653),
    [sym_preproc_error] = STATE(1653),
    [sym_preproc_warning] = STATE(1653),
    [sym_preproc_define] = STATE(1653),
    [sym_preproc_undef] = STATE(1653),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1654] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6933),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2950),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7095),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5711),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4215),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7446),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9108),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1654),
    [sym_preproc_endregion] = STATE(1654),
    [sym_preproc_line] = STATE(1654),
    [sym_preproc_pragma] = STATE(1654),
    [sym_preproc_nullable] = STATE(1654),
    [sym_preproc_error] = STATE(1654),
    [sym_preproc_warning] = STATE(1654),
    [sym_preproc_define] = STATE(1654),
    [sym_preproc_undef] = STATE(1654),
    [aux_sym_class_declaration_repeat1] = STATE(3848),
    [aux_sym_lambda_expression_repeat1] = STATE(4282),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1837),
    [anon_sym_ref] = ACTIONS(1839),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1841),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1845),
    [anon_sym_TILDE] = ACTIONS(1845),
    [anon_sym_PLUS_PLUS] = ACTIONS(1845),
    [anon_sym_DASH_DASH] = ACTIONS(1845),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1843),
    [anon_sym_DASH] = ACTIONS(1843),
    [anon_sym_STAR] = ACTIONS(1847),
    [anon_sym_CARET] = ACTIONS(1845),
    [anon_sym_AMP] = ACTIONS(1845),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1849),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1851),
    [anon_sym_DOT_DOT] = ACTIONS(1853),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1655] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6926),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2950),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7053),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6275),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4458),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7431),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9158),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1655),
    [sym_preproc_endregion] = STATE(1655),
    [sym_preproc_line] = STATE(1655),
    [sym_preproc_pragma] = STATE(1655),
    [sym_preproc_nullable] = STATE(1655),
    [sym_preproc_error] = STATE(1655),
    [sym_preproc_warning] = STATE(1655),
    [sym_preproc_define] = STATE(1655),
    [sym_preproc_undef] = STATE(1655),
    [aux_sym_class_declaration_repeat1] = STATE(3835),
    [aux_sym_lambda_expression_repeat1] = STATE(4263),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2213),
    [anon_sym_ref] = ACTIONS(2215),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2217),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2221),
    [anon_sym_TILDE] = ACTIONS(2221),
    [anon_sym_PLUS_PLUS] = ACTIONS(2221),
    [anon_sym_DASH_DASH] = ACTIONS(2221),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2219),
    [anon_sym_DASH] = ACTIONS(2219),
    [anon_sym_STAR] = ACTIONS(2223),
    [anon_sym_CARET] = ACTIONS(2221),
    [anon_sym_AMP] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2225),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2227),
    [anon_sym_DOT_DOT] = ACTIONS(2229),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1656] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6926),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2950),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7053),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6299),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4458),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7431),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9158),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1656),
    [sym_preproc_endregion] = STATE(1656),
    [sym_preproc_line] = STATE(1656),
    [sym_preproc_pragma] = STATE(1656),
    [sym_preproc_nullable] = STATE(1656),
    [sym_preproc_error] = STATE(1656),
    [sym_preproc_warning] = STATE(1656),
    [sym_preproc_define] = STATE(1656),
    [sym_preproc_undef] = STATE(1656),
    [aux_sym_class_declaration_repeat1] = STATE(3835),
    [aux_sym_lambda_expression_repeat1] = STATE(4263),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2213),
    [anon_sym_ref] = ACTIONS(2215),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2217),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2221),
    [anon_sym_TILDE] = ACTIONS(2221),
    [anon_sym_PLUS_PLUS] = ACTIONS(2221),
    [anon_sym_DASH_DASH] = ACTIONS(2221),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2219),
    [anon_sym_DASH] = ACTIONS(2219),
    [anon_sym_STAR] = ACTIONS(2223),
    [anon_sym_CARET] = ACTIONS(2221),
    [anon_sym_AMP] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2225),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2227),
    [anon_sym_DOT_DOT] = ACTIONS(2229),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1657] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6926),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2950),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7053),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6300),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4458),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7431),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9158),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1657),
    [sym_preproc_endregion] = STATE(1657),
    [sym_preproc_line] = STATE(1657),
    [sym_preproc_pragma] = STATE(1657),
    [sym_preproc_nullable] = STATE(1657),
    [sym_preproc_error] = STATE(1657),
    [sym_preproc_warning] = STATE(1657),
    [sym_preproc_define] = STATE(1657),
    [sym_preproc_undef] = STATE(1657),
    [aux_sym_class_declaration_repeat1] = STATE(3835),
    [aux_sym_lambda_expression_repeat1] = STATE(4263),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2213),
    [anon_sym_ref] = ACTIONS(2215),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2217),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2221),
    [anon_sym_TILDE] = ACTIONS(2221),
    [anon_sym_PLUS_PLUS] = ACTIONS(2221),
    [anon_sym_DASH_DASH] = ACTIONS(2221),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2219),
    [anon_sym_DASH] = ACTIONS(2219),
    [anon_sym_STAR] = ACTIONS(2223),
    [anon_sym_CARET] = ACTIONS(2221),
    [anon_sym_AMP] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2225),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2227),
    [anon_sym_DOT_DOT] = ACTIONS(2229),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1658] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6926),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2950),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7053),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6301),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4458),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7431),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9158),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1658),
    [sym_preproc_endregion] = STATE(1658),
    [sym_preproc_line] = STATE(1658),
    [sym_preproc_pragma] = STATE(1658),
    [sym_preproc_nullable] = STATE(1658),
    [sym_preproc_error] = STATE(1658),
    [sym_preproc_warning] = STATE(1658),
    [sym_preproc_define] = STATE(1658),
    [sym_preproc_undef] = STATE(1658),
    [aux_sym_class_declaration_repeat1] = STATE(3835),
    [aux_sym_lambda_expression_repeat1] = STATE(4263),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2213),
    [anon_sym_ref] = ACTIONS(2215),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2217),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2221),
    [anon_sym_TILDE] = ACTIONS(2221),
    [anon_sym_PLUS_PLUS] = ACTIONS(2221),
    [anon_sym_DASH_DASH] = ACTIONS(2221),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2219),
    [anon_sym_DASH] = ACTIONS(2219),
    [anon_sym_STAR] = ACTIONS(2223),
    [anon_sym_CARET] = ACTIONS(2221),
    [anon_sym_AMP] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2225),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2227),
    [anon_sym_DOT_DOT] = ACTIONS(2229),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1659] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6926),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2950),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7053),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6302),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4458),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7431),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9158),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1659),
    [sym_preproc_endregion] = STATE(1659),
    [sym_preproc_line] = STATE(1659),
    [sym_preproc_pragma] = STATE(1659),
    [sym_preproc_nullable] = STATE(1659),
    [sym_preproc_error] = STATE(1659),
    [sym_preproc_warning] = STATE(1659),
    [sym_preproc_define] = STATE(1659),
    [sym_preproc_undef] = STATE(1659),
    [aux_sym_class_declaration_repeat1] = STATE(3835),
    [aux_sym_lambda_expression_repeat1] = STATE(4263),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2213),
    [anon_sym_ref] = ACTIONS(2215),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2217),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2221),
    [anon_sym_TILDE] = ACTIONS(2221),
    [anon_sym_PLUS_PLUS] = ACTIONS(2221),
    [anon_sym_DASH_DASH] = ACTIONS(2221),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2219),
    [anon_sym_DASH] = ACTIONS(2219),
    [anon_sym_STAR] = ACTIONS(2223),
    [anon_sym_CARET] = ACTIONS(2221),
    [anon_sym_AMP] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2225),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2227),
    [anon_sym_DOT_DOT] = ACTIONS(2229),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1660] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6926),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2950),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7053),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6303),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4458),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7431),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9158),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1660),
    [sym_preproc_endregion] = STATE(1660),
    [sym_preproc_line] = STATE(1660),
    [sym_preproc_pragma] = STATE(1660),
    [sym_preproc_nullable] = STATE(1660),
    [sym_preproc_error] = STATE(1660),
    [sym_preproc_warning] = STATE(1660),
    [sym_preproc_define] = STATE(1660),
    [sym_preproc_undef] = STATE(1660),
    [aux_sym_class_declaration_repeat1] = STATE(3835),
    [aux_sym_lambda_expression_repeat1] = STATE(4263),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2213),
    [anon_sym_ref] = ACTIONS(2215),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2217),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2221),
    [anon_sym_TILDE] = ACTIONS(2221),
    [anon_sym_PLUS_PLUS] = ACTIONS(2221),
    [anon_sym_DASH_DASH] = ACTIONS(2221),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2219),
    [anon_sym_DASH] = ACTIONS(2219),
    [anon_sym_STAR] = ACTIONS(2223),
    [anon_sym_CARET] = ACTIONS(2221),
    [anon_sym_AMP] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2225),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2227),
    [anon_sym_DOT_DOT] = ACTIONS(2229),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1661] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6926),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2950),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7053),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6305),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4458),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7431),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9158),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1661),
    [sym_preproc_endregion] = STATE(1661),
    [sym_preproc_line] = STATE(1661),
    [sym_preproc_pragma] = STATE(1661),
    [sym_preproc_nullable] = STATE(1661),
    [sym_preproc_error] = STATE(1661),
    [sym_preproc_warning] = STATE(1661),
    [sym_preproc_define] = STATE(1661),
    [sym_preproc_undef] = STATE(1661),
    [aux_sym_class_declaration_repeat1] = STATE(3835),
    [aux_sym_lambda_expression_repeat1] = STATE(4263),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2213),
    [anon_sym_ref] = ACTIONS(2215),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2217),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2221),
    [anon_sym_TILDE] = ACTIONS(2221),
    [anon_sym_PLUS_PLUS] = ACTIONS(2221),
    [anon_sym_DASH_DASH] = ACTIONS(2221),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2219),
    [anon_sym_DASH] = ACTIONS(2219),
    [anon_sym_STAR] = ACTIONS(2223),
    [anon_sym_CARET] = ACTIONS(2221),
    [anon_sym_AMP] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2225),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2227),
    [anon_sym_DOT_DOT] = ACTIONS(2229),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1662] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6926),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2950),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7053),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6306),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4458),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7431),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9158),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1662),
    [sym_preproc_endregion] = STATE(1662),
    [sym_preproc_line] = STATE(1662),
    [sym_preproc_pragma] = STATE(1662),
    [sym_preproc_nullable] = STATE(1662),
    [sym_preproc_error] = STATE(1662),
    [sym_preproc_warning] = STATE(1662),
    [sym_preproc_define] = STATE(1662),
    [sym_preproc_undef] = STATE(1662),
    [aux_sym_class_declaration_repeat1] = STATE(3835),
    [aux_sym_lambda_expression_repeat1] = STATE(4263),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2213),
    [anon_sym_ref] = ACTIONS(2215),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2217),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2221),
    [anon_sym_TILDE] = ACTIONS(2221),
    [anon_sym_PLUS_PLUS] = ACTIONS(2221),
    [anon_sym_DASH_DASH] = ACTIONS(2221),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2219),
    [anon_sym_DASH] = ACTIONS(2219),
    [anon_sym_STAR] = ACTIONS(2223),
    [anon_sym_CARET] = ACTIONS(2221),
    [anon_sym_AMP] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2225),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2227),
    [anon_sym_DOT_DOT] = ACTIONS(2229),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1663] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6926),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2950),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7053),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6307),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4458),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7431),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9158),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1663),
    [sym_preproc_endregion] = STATE(1663),
    [sym_preproc_line] = STATE(1663),
    [sym_preproc_pragma] = STATE(1663),
    [sym_preproc_nullable] = STATE(1663),
    [sym_preproc_error] = STATE(1663),
    [sym_preproc_warning] = STATE(1663),
    [sym_preproc_define] = STATE(1663),
    [sym_preproc_undef] = STATE(1663),
    [aux_sym_class_declaration_repeat1] = STATE(3835),
    [aux_sym_lambda_expression_repeat1] = STATE(4263),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2213),
    [anon_sym_ref] = ACTIONS(2215),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2217),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2221),
    [anon_sym_TILDE] = ACTIONS(2221),
    [anon_sym_PLUS_PLUS] = ACTIONS(2221),
    [anon_sym_DASH_DASH] = ACTIONS(2221),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2219),
    [anon_sym_DASH] = ACTIONS(2219),
    [anon_sym_STAR] = ACTIONS(2223),
    [anon_sym_CARET] = ACTIONS(2221),
    [anon_sym_AMP] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2225),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2227),
    [anon_sym_DOT_DOT] = ACTIONS(2229),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1664] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6926),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2950),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7053),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6310),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4458),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7431),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9158),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1664),
    [sym_preproc_endregion] = STATE(1664),
    [sym_preproc_line] = STATE(1664),
    [sym_preproc_pragma] = STATE(1664),
    [sym_preproc_nullable] = STATE(1664),
    [sym_preproc_error] = STATE(1664),
    [sym_preproc_warning] = STATE(1664),
    [sym_preproc_define] = STATE(1664),
    [sym_preproc_undef] = STATE(1664),
    [aux_sym_class_declaration_repeat1] = STATE(3835),
    [aux_sym_lambda_expression_repeat1] = STATE(4263),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2213),
    [anon_sym_ref] = ACTIONS(2215),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2217),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2221),
    [anon_sym_TILDE] = ACTIONS(2221),
    [anon_sym_PLUS_PLUS] = ACTIONS(2221),
    [anon_sym_DASH_DASH] = ACTIONS(2221),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2219),
    [anon_sym_DASH] = ACTIONS(2219),
    [anon_sym_STAR] = ACTIONS(2223),
    [anon_sym_CARET] = ACTIONS(2221),
    [anon_sym_AMP] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2225),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2227),
    [anon_sym_DOT_DOT] = ACTIONS(2229),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1665] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6926),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2950),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7053),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6225),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4458),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7431),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9158),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1665),
    [sym_preproc_endregion] = STATE(1665),
    [sym_preproc_line] = STATE(1665),
    [sym_preproc_pragma] = STATE(1665),
    [sym_preproc_nullable] = STATE(1665),
    [sym_preproc_error] = STATE(1665),
    [sym_preproc_warning] = STATE(1665),
    [sym_preproc_define] = STATE(1665),
    [sym_preproc_undef] = STATE(1665),
    [aux_sym_class_declaration_repeat1] = STATE(3835),
    [aux_sym_lambda_expression_repeat1] = STATE(4263),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2213),
    [anon_sym_ref] = ACTIONS(2215),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2217),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2221),
    [anon_sym_TILDE] = ACTIONS(2221),
    [anon_sym_PLUS_PLUS] = ACTIONS(2221),
    [anon_sym_DASH_DASH] = ACTIONS(2221),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2219),
    [anon_sym_DASH] = ACTIONS(2219),
    [anon_sym_STAR] = ACTIONS(2223),
    [anon_sym_CARET] = ACTIONS(2221),
    [anon_sym_AMP] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2225),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2227),
    [anon_sym_DOT_DOT] = ACTIONS(2229),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1666] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6926),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2950),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7053),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6126),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4458),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7431),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9158),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1666),
    [sym_preproc_endregion] = STATE(1666),
    [sym_preproc_line] = STATE(1666),
    [sym_preproc_pragma] = STATE(1666),
    [sym_preproc_nullable] = STATE(1666),
    [sym_preproc_error] = STATE(1666),
    [sym_preproc_warning] = STATE(1666),
    [sym_preproc_define] = STATE(1666),
    [sym_preproc_undef] = STATE(1666),
    [aux_sym_class_declaration_repeat1] = STATE(3835),
    [aux_sym_lambda_expression_repeat1] = STATE(4263),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2213),
    [anon_sym_ref] = ACTIONS(2215),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2217),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2221),
    [anon_sym_TILDE] = ACTIONS(2221),
    [anon_sym_PLUS_PLUS] = ACTIONS(2221),
    [anon_sym_DASH_DASH] = ACTIONS(2221),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2219),
    [anon_sym_DASH] = ACTIONS(2219),
    [anon_sym_STAR] = ACTIONS(2223),
    [anon_sym_CARET] = ACTIONS(2221),
    [anon_sym_AMP] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2225),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2227),
    [anon_sym_DOT_DOT] = ACTIONS(2229),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1667] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6926),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2950),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7053),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3582),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4458),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7431),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9158),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1667),
    [sym_preproc_endregion] = STATE(1667),
    [sym_preproc_line] = STATE(1667),
    [sym_preproc_pragma] = STATE(1667),
    [sym_preproc_nullable] = STATE(1667),
    [sym_preproc_error] = STATE(1667),
    [sym_preproc_warning] = STATE(1667),
    [sym_preproc_define] = STATE(1667),
    [sym_preproc_undef] = STATE(1667),
    [aux_sym_class_declaration_repeat1] = STATE(3835),
    [aux_sym_lambda_expression_repeat1] = STATE(4263),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2213),
    [anon_sym_ref] = ACTIONS(2215),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2217),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2221),
    [anon_sym_TILDE] = ACTIONS(2221),
    [anon_sym_PLUS_PLUS] = ACTIONS(2221),
    [anon_sym_DASH_DASH] = ACTIONS(2221),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2219),
    [anon_sym_DASH] = ACTIONS(2219),
    [anon_sym_STAR] = ACTIONS(2223),
    [anon_sym_CARET] = ACTIONS(2221),
    [anon_sym_AMP] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2225),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2227),
    [anon_sym_DOT_DOT] = ACTIONS(2229),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1668] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7014),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6005),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4335),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7428),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9866),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1668),
    [sym_preproc_endregion] = STATE(1668),
    [sym_preproc_line] = STATE(1668),
    [sym_preproc_pragma] = STATE(1668),
    [sym_preproc_nullable] = STATE(1668),
    [sym_preproc_error] = STATE(1668),
    [sym_preproc_warning] = STATE(1668),
    [sym_preproc_define] = STATE(1668),
    [sym_preproc_undef] = STATE(1668),
    [aux_sym_class_declaration_repeat1] = STATE(3824),
    [aux_sym_lambda_expression_repeat1] = STATE(4242),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1539),
    [anon_sym_ref] = ACTIONS(1541),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1545),
    [anon_sym_TILDE] = ACTIONS(1545),
    [anon_sym_PLUS_PLUS] = ACTIONS(1545),
    [anon_sym_DASH_DASH] = ACTIONS(1545),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1543),
    [anon_sym_DASH] = ACTIONS(1543),
    [anon_sym_STAR] = ACTIONS(1547),
    [anon_sym_CARET] = ACTIONS(1545),
    [anon_sym_AMP] = ACTIONS(1545),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1549),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1551),
    [anon_sym_DOT_DOT] = ACTIONS(1553),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1669] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7014),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3926),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4335),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7428),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9866),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1669),
    [sym_preproc_endregion] = STATE(1669),
    [sym_preproc_line] = STATE(1669),
    [sym_preproc_pragma] = STATE(1669),
    [sym_preproc_nullable] = STATE(1669),
    [sym_preproc_error] = STATE(1669),
    [sym_preproc_warning] = STATE(1669),
    [sym_preproc_define] = STATE(1669),
    [sym_preproc_undef] = STATE(1669),
    [aux_sym_class_declaration_repeat1] = STATE(3824),
    [aux_sym_lambda_expression_repeat1] = STATE(4242),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1539),
    [anon_sym_ref] = ACTIONS(1541),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1545),
    [anon_sym_TILDE] = ACTIONS(1545),
    [anon_sym_PLUS_PLUS] = ACTIONS(1545),
    [anon_sym_DASH_DASH] = ACTIONS(1545),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1543),
    [anon_sym_DASH] = ACTIONS(1543),
    [anon_sym_STAR] = ACTIONS(1547),
    [anon_sym_CARET] = ACTIONS(1545),
    [anon_sym_AMP] = ACTIONS(1545),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1549),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1551),
    [anon_sym_DOT_DOT] = ACTIONS(1553),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1670] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7014),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6007),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4335),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7428),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9866),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1670),
    [sym_preproc_endregion] = STATE(1670),
    [sym_preproc_line] = STATE(1670),
    [sym_preproc_pragma] = STATE(1670),
    [sym_preproc_nullable] = STATE(1670),
    [sym_preproc_error] = STATE(1670),
    [sym_preproc_warning] = STATE(1670),
    [sym_preproc_define] = STATE(1670),
    [sym_preproc_undef] = STATE(1670),
    [aux_sym_class_declaration_repeat1] = STATE(3824),
    [aux_sym_lambda_expression_repeat1] = STATE(4242),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1539),
    [anon_sym_ref] = ACTIONS(1541),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1545),
    [anon_sym_TILDE] = ACTIONS(1545),
    [anon_sym_PLUS_PLUS] = ACTIONS(1545),
    [anon_sym_DASH_DASH] = ACTIONS(1545),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1543),
    [anon_sym_DASH] = ACTIONS(1543),
    [anon_sym_STAR] = ACTIONS(1547),
    [anon_sym_CARET] = ACTIONS(1545),
    [anon_sym_AMP] = ACTIONS(1545),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1549),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1551),
    [anon_sym_DOT_DOT] = ACTIONS(1553),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1671] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7014),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6011),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4335),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7428),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9866),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1671),
    [sym_preproc_endregion] = STATE(1671),
    [sym_preproc_line] = STATE(1671),
    [sym_preproc_pragma] = STATE(1671),
    [sym_preproc_nullable] = STATE(1671),
    [sym_preproc_error] = STATE(1671),
    [sym_preproc_warning] = STATE(1671),
    [sym_preproc_define] = STATE(1671),
    [sym_preproc_undef] = STATE(1671),
    [aux_sym_class_declaration_repeat1] = STATE(3824),
    [aux_sym_lambda_expression_repeat1] = STATE(4242),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1539),
    [anon_sym_ref] = ACTIONS(1541),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1545),
    [anon_sym_TILDE] = ACTIONS(1545),
    [anon_sym_PLUS_PLUS] = ACTIONS(1545),
    [anon_sym_DASH_DASH] = ACTIONS(1545),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1543),
    [anon_sym_DASH] = ACTIONS(1543),
    [anon_sym_STAR] = ACTIONS(1547),
    [anon_sym_CARET] = ACTIONS(1545),
    [anon_sym_AMP] = ACTIONS(1545),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1549),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1551),
    [anon_sym_DOT_DOT] = ACTIONS(1553),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1672] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6910),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2960),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7091),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5658),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4208),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7438),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9067),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1672),
    [sym_preproc_endregion] = STATE(1672),
    [sym_preproc_line] = STATE(1672),
    [sym_preproc_pragma] = STATE(1672),
    [sym_preproc_nullable] = STATE(1672),
    [sym_preproc_error] = STATE(1672),
    [sym_preproc_warning] = STATE(1672),
    [sym_preproc_define] = STATE(1672),
    [sym_preproc_undef] = STATE(1672),
    [aux_sym_class_declaration_repeat1] = STATE(3847),
    [aux_sym_lambda_expression_repeat1] = STATE(4280),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1819),
    [anon_sym_ref] = ACTIONS(1821),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1823),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1827),
    [anon_sym_TILDE] = ACTIONS(1827),
    [anon_sym_PLUS_PLUS] = ACTIONS(1827),
    [anon_sym_DASH_DASH] = ACTIONS(1827),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1825),
    [anon_sym_DASH] = ACTIONS(1825),
    [anon_sym_STAR] = ACTIONS(1829),
    [anon_sym_CARET] = ACTIONS(1827),
    [anon_sym_AMP] = ACTIONS(1827),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1831),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1833),
    [anon_sym_DOT_DOT] = ACTIONS(1835),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1673] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6910),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2960),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7091),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3838),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4208),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7438),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9067),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1673),
    [sym_preproc_endregion] = STATE(1673),
    [sym_preproc_line] = STATE(1673),
    [sym_preproc_pragma] = STATE(1673),
    [sym_preproc_nullable] = STATE(1673),
    [sym_preproc_error] = STATE(1673),
    [sym_preproc_warning] = STATE(1673),
    [sym_preproc_define] = STATE(1673),
    [sym_preproc_undef] = STATE(1673),
    [aux_sym_class_declaration_repeat1] = STATE(3847),
    [aux_sym_lambda_expression_repeat1] = STATE(4280),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1819),
    [anon_sym_ref] = ACTIONS(1821),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1823),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1827),
    [anon_sym_TILDE] = ACTIONS(1827),
    [anon_sym_PLUS_PLUS] = ACTIONS(1827),
    [anon_sym_DASH_DASH] = ACTIONS(1827),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1825),
    [anon_sym_DASH] = ACTIONS(1825),
    [anon_sym_STAR] = ACTIONS(1829),
    [anon_sym_CARET] = ACTIONS(1827),
    [anon_sym_AMP] = ACTIONS(1827),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1831),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1833),
    [anon_sym_DOT_DOT] = ACTIONS(1835),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1674] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6910),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2960),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7091),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5505),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4208),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7438),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9067),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1674),
    [sym_preproc_endregion] = STATE(1674),
    [sym_preproc_line] = STATE(1674),
    [sym_preproc_pragma] = STATE(1674),
    [sym_preproc_nullable] = STATE(1674),
    [sym_preproc_error] = STATE(1674),
    [sym_preproc_warning] = STATE(1674),
    [sym_preproc_define] = STATE(1674),
    [sym_preproc_undef] = STATE(1674),
    [aux_sym_class_declaration_repeat1] = STATE(3847),
    [aux_sym_lambda_expression_repeat1] = STATE(4280),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1819),
    [anon_sym_ref] = ACTIONS(1821),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1823),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1827),
    [anon_sym_TILDE] = ACTIONS(1827),
    [anon_sym_PLUS_PLUS] = ACTIONS(1827),
    [anon_sym_DASH_DASH] = ACTIONS(1827),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1825),
    [anon_sym_DASH] = ACTIONS(1825),
    [anon_sym_STAR] = ACTIONS(1829),
    [anon_sym_CARET] = ACTIONS(1827),
    [anon_sym_AMP] = ACTIONS(1827),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1831),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1833),
    [anon_sym_DOT_DOT] = ACTIONS(1835),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1675] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6910),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2960),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7091),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5506),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4208),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7438),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9067),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1675),
    [sym_preproc_endregion] = STATE(1675),
    [sym_preproc_line] = STATE(1675),
    [sym_preproc_pragma] = STATE(1675),
    [sym_preproc_nullable] = STATE(1675),
    [sym_preproc_error] = STATE(1675),
    [sym_preproc_warning] = STATE(1675),
    [sym_preproc_define] = STATE(1675),
    [sym_preproc_undef] = STATE(1675),
    [aux_sym_class_declaration_repeat1] = STATE(3847),
    [aux_sym_lambda_expression_repeat1] = STATE(4280),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1819),
    [anon_sym_ref] = ACTIONS(1821),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1823),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1827),
    [anon_sym_TILDE] = ACTIONS(1827),
    [anon_sym_PLUS_PLUS] = ACTIONS(1827),
    [anon_sym_DASH_DASH] = ACTIONS(1827),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1825),
    [anon_sym_DASH] = ACTIONS(1825),
    [anon_sym_STAR] = ACTIONS(1829),
    [anon_sym_CARET] = ACTIONS(1827),
    [anon_sym_AMP] = ACTIONS(1827),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1831),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1833),
    [anon_sym_DOT_DOT] = ACTIONS(1835),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1676] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6910),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2960),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7091),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5684),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4208),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7438),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9067),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1676),
    [sym_preproc_endregion] = STATE(1676),
    [sym_preproc_line] = STATE(1676),
    [sym_preproc_pragma] = STATE(1676),
    [sym_preproc_nullable] = STATE(1676),
    [sym_preproc_error] = STATE(1676),
    [sym_preproc_warning] = STATE(1676),
    [sym_preproc_define] = STATE(1676),
    [sym_preproc_undef] = STATE(1676),
    [aux_sym_class_declaration_repeat1] = STATE(3847),
    [aux_sym_lambda_expression_repeat1] = STATE(4280),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1819),
    [anon_sym_ref] = ACTIONS(1821),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1823),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1827),
    [anon_sym_TILDE] = ACTIONS(1827),
    [anon_sym_PLUS_PLUS] = ACTIONS(1827),
    [anon_sym_DASH_DASH] = ACTIONS(1827),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1825),
    [anon_sym_DASH] = ACTIONS(1825),
    [anon_sym_STAR] = ACTIONS(1829),
    [anon_sym_CARET] = ACTIONS(1827),
    [anon_sym_AMP] = ACTIONS(1827),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1831),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1833),
    [anon_sym_DOT_DOT] = ACTIONS(1835),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1677] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6910),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2960),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7091),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5659),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4208),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7438),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9067),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1677),
    [sym_preproc_endregion] = STATE(1677),
    [sym_preproc_line] = STATE(1677),
    [sym_preproc_pragma] = STATE(1677),
    [sym_preproc_nullable] = STATE(1677),
    [sym_preproc_error] = STATE(1677),
    [sym_preproc_warning] = STATE(1677),
    [sym_preproc_define] = STATE(1677),
    [sym_preproc_undef] = STATE(1677),
    [aux_sym_class_declaration_repeat1] = STATE(3847),
    [aux_sym_lambda_expression_repeat1] = STATE(4280),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1819),
    [anon_sym_ref] = ACTIONS(1821),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1823),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1827),
    [anon_sym_TILDE] = ACTIONS(1827),
    [anon_sym_PLUS_PLUS] = ACTIONS(1827),
    [anon_sym_DASH_DASH] = ACTIONS(1827),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1825),
    [anon_sym_DASH] = ACTIONS(1825),
    [anon_sym_STAR] = ACTIONS(1829),
    [anon_sym_CARET] = ACTIONS(1827),
    [anon_sym_AMP] = ACTIONS(1827),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1831),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1833),
    [anon_sym_DOT_DOT] = ACTIONS(1835),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1678] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6910),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2960),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7091),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5660),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4208),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7438),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9067),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1678),
    [sym_preproc_endregion] = STATE(1678),
    [sym_preproc_line] = STATE(1678),
    [sym_preproc_pragma] = STATE(1678),
    [sym_preproc_nullable] = STATE(1678),
    [sym_preproc_error] = STATE(1678),
    [sym_preproc_warning] = STATE(1678),
    [sym_preproc_define] = STATE(1678),
    [sym_preproc_undef] = STATE(1678),
    [aux_sym_class_declaration_repeat1] = STATE(3847),
    [aux_sym_lambda_expression_repeat1] = STATE(4280),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1819),
    [anon_sym_ref] = ACTIONS(1821),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1823),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1827),
    [anon_sym_TILDE] = ACTIONS(1827),
    [anon_sym_PLUS_PLUS] = ACTIONS(1827),
    [anon_sym_DASH_DASH] = ACTIONS(1827),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1825),
    [anon_sym_DASH] = ACTIONS(1825),
    [anon_sym_STAR] = ACTIONS(1829),
    [anon_sym_CARET] = ACTIONS(1827),
    [anon_sym_AMP] = ACTIONS(1827),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1831),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1833),
    [anon_sym_DOT_DOT] = ACTIONS(1835),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1679] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6910),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2960),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7091),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5415),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4208),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7438),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9067),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1679),
    [sym_preproc_endregion] = STATE(1679),
    [sym_preproc_line] = STATE(1679),
    [sym_preproc_pragma] = STATE(1679),
    [sym_preproc_nullable] = STATE(1679),
    [sym_preproc_error] = STATE(1679),
    [sym_preproc_warning] = STATE(1679),
    [sym_preproc_define] = STATE(1679),
    [sym_preproc_undef] = STATE(1679),
    [aux_sym_class_declaration_repeat1] = STATE(3847),
    [aux_sym_lambda_expression_repeat1] = STATE(4280),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1819),
    [anon_sym_ref] = ACTIONS(1821),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1823),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1827),
    [anon_sym_TILDE] = ACTIONS(1827),
    [anon_sym_PLUS_PLUS] = ACTIONS(1827),
    [anon_sym_DASH_DASH] = ACTIONS(1827),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1825),
    [anon_sym_DASH] = ACTIONS(1825),
    [anon_sym_STAR] = ACTIONS(1829),
    [anon_sym_CARET] = ACTIONS(1827),
    [anon_sym_AMP] = ACTIONS(1827),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1831),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1833),
    [anon_sym_DOT_DOT] = ACTIONS(1835),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1680] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6910),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2960),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7091),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5507),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4208),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7438),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9067),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1680),
    [sym_preproc_endregion] = STATE(1680),
    [sym_preproc_line] = STATE(1680),
    [sym_preproc_pragma] = STATE(1680),
    [sym_preproc_nullable] = STATE(1680),
    [sym_preproc_error] = STATE(1680),
    [sym_preproc_warning] = STATE(1680),
    [sym_preproc_define] = STATE(1680),
    [sym_preproc_undef] = STATE(1680),
    [aux_sym_class_declaration_repeat1] = STATE(3847),
    [aux_sym_lambda_expression_repeat1] = STATE(4280),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1819),
    [anon_sym_ref] = ACTIONS(1821),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1823),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1827),
    [anon_sym_TILDE] = ACTIONS(1827),
    [anon_sym_PLUS_PLUS] = ACTIONS(1827),
    [anon_sym_DASH_DASH] = ACTIONS(1827),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1825),
    [anon_sym_DASH] = ACTIONS(1825),
    [anon_sym_STAR] = ACTIONS(1829),
    [anon_sym_CARET] = ACTIONS(1827),
    [anon_sym_AMP] = ACTIONS(1827),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1831),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1833),
    [anon_sym_DOT_DOT] = ACTIONS(1835),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1681] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6910),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2960),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7091),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5661),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4208),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7438),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9067),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1681),
    [sym_preproc_endregion] = STATE(1681),
    [sym_preproc_line] = STATE(1681),
    [sym_preproc_pragma] = STATE(1681),
    [sym_preproc_nullable] = STATE(1681),
    [sym_preproc_error] = STATE(1681),
    [sym_preproc_warning] = STATE(1681),
    [sym_preproc_define] = STATE(1681),
    [sym_preproc_undef] = STATE(1681),
    [aux_sym_class_declaration_repeat1] = STATE(3847),
    [aux_sym_lambda_expression_repeat1] = STATE(4280),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1819),
    [anon_sym_ref] = ACTIONS(1821),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1823),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1827),
    [anon_sym_TILDE] = ACTIONS(1827),
    [anon_sym_PLUS_PLUS] = ACTIONS(1827),
    [anon_sym_DASH_DASH] = ACTIONS(1827),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1825),
    [anon_sym_DASH] = ACTIONS(1825),
    [anon_sym_STAR] = ACTIONS(1829),
    [anon_sym_CARET] = ACTIONS(1827),
    [anon_sym_AMP] = ACTIONS(1827),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1831),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1833),
    [anon_sym_DOT_DOT] = ACTIONS(1835),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1682] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6910),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2960),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7091),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5662),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4208),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7438),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9067),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1682),
    [sym_preproc_endregion] = STATE(1682),
    [sym_preproc_line] = STATE(1682),
    [sym_preproc_pragma] = STATE(1682),
    [sym_preproc_nullable] = STATE(1682),
    [sym_preproc_error] = STATE(1682),
    [sym_preproc_warning] = STATE(1682),
    [sym_preproc_define] = STATE(1682),
    [sym_preproc_undef] = STATE(1682),
    [aux_sym_class_declaration_repeat1] = STATE(3847),
    [aux_sym_lambda_expression_repeat1] = STATE(4280),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1819),
    [anon_sym_ref] = ACTIONS(1821),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1823),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1827),
    [anon_sym_TILDE] = ACTIONS(1827),
    [anon_sym_PLUS_PLUS] = ACTIONS(1827),
    [anon_sym_DASH_DASH] = ACTIONS(1827),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1825),
    [anon_sym_DASH] = ACTIONS(1825),
    [anon_sym_STAR] = ACTIONS(1829),
    [anon_sym_CARET] = ACTIONS(1827),
    [anon_sym_AMP] = ACTIONS(1827),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1831),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1833),
    [anon_sym_DOT_DOT] = ACTIONS(1835),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1683] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6910),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2960),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7091),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5663),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4208),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7438),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9067),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1683),
    [sym_preproc_endregion] = STATE(1683),
    [sym_preproc_line] = STATE(1683),
    [sym_preproc_pragma] = STATE(1683),
    [sym_preproc_nullable] = STATE(1683),
    [sym_preproc_error] = STATE(1683),
    [sym_preproc_warning] = STATE(1683),
    [sym_preproc_define] = STATE(1683),
    [sym_preproc_undef] = STATE(1683),
    [aux_sym_class_declaration_repeat1] = STATE(3847),
    [aux_sym_lambda_expression_repeat1] = STATE(4280),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1819),
    [anon_sym_ref] = ACTIONS(1821),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1823),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1827),
    [anon_sym_TILDE] = ACTIONS(1827),
    [anon_sym_PLUS_PLUS] = ACTIONS(1827),
    [anon_sym_DASH_DASH] = ACTIONS(1827),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1825),
    [anon_sym_DASH] = ACTIONS(1825),
    [anon_sym_STAR] = ACTIONS(1829),
    [anon_sym_CARET] = ACTIONS(1827),
    [anon_sym_AMP] = ACTIONS(1827),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1831),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1833),
    [anon_sym_DOT_DOT] = ACTIONS(1835),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1684] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6910),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2960),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7091),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5664),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4208),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7438),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9067),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1684),
    [sym_preproc_endregion] = STATE(1684),
    [sym_preproc_line] = STATE(1684),
    [sym_preproc_pragma] = STATE(1684),
    [sym_preproc_nullable] = STATE(1684),
    [sym_preproc_error] = STATE(1684),
    [sym_preproc_warning] = STATE(1684),
    [sym_preproc_define] = STATE(1684),
    [sym_preproc_undef] = STATE(1684),
    [aux_sym_class_declaration_repeat1] = STATE(3847),
    [aux_sym_lambda_expression_repeat1] = STATE(4280),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1819),
    [anon_sym_ref] = ACTIONS(1821),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1823),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1827),
    [anon_sym_TILDE] = ACTIONS(1827),
    [anon_sym_PLUS_PLUS] = ACTIONS(1827),
    [anon_sym_DASH_DASH] = ACTIONS(1827),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1825),
    [anon_sym_DASH] = ACTIONS(1825),
    [anon_sym_STAR] = ACTIONS(1829),
    [anon_sym_CARET] = ACTIONS(1827),
    [anon_sym_AMP] = ACTIONS(1827),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1831),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1833),
    [anon_sym_DOT_DOT] = ACTIONS(1835),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1685] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6910),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2960),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7091),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5665),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4208),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7438),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9067),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1685),
    [sym_preproc_endregion] = STATE(1685),
    [sym_preproc_line] = STATE(1685),
    [sym_preproc_pragma] = STATE(1685),
    [sym_preproc_nullable] = STATE(1685),
    [sym_preproc_error] = STATE(1685),
    [sym_preproc_warning] = STATE(1685),
    [sym_preproc_define] = STATE(1685),
    [sym_preproc_undef] = STATE(1685),
    [aux_sym_class_declaration_repeat1] = STATE(3847),
    [aux_sym_lambda_expression_repeat1] = STATE(4280),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1819),
    [anon_sym_ref] = ACTIONS(1821),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1823),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1827),
    [anon_sym_TILDE] = ACTIONS(1827),
    [anon_sym_PLUS_PLUS] = ACTIONS(1827),
    [anon_sym_DASH_DASH] = ACTIONS(1827),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1825),
    [anon_sym_DASH] = ACTIONS(1825),
    [anon_sym_STAR] = ACTIONS(1829),
    [anon_sym_CARET] = ACTIONS(1827),
    [anon_sym_AMP] = ACTIONS(1827),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1831),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1833),
    [anon_sym_DOT_DOT] = ACTIONS(1835),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1686] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6910),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2960),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7091),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3867),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4208),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7438),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9067),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1686),
    [sym_preproc_endregion] = STATE(1686),
    [sym_preproc_line] = STATE(1686),
    [sym_preproc_pragma] = STATE(1686),
    [sym_preproc_nullable] = STATE(1686),
    [sym_preproc_error] = STATE(1686),
    [sym_preproc_warning] = STATE(1686),
    [sym_preproc_define] = STATE(1686),
    [sym_preproc_undef] = STATE(1686),
    [aux_sym_class_declaration_repeat1] = STATE(3847),
    [aux_sym_lambda_expression_repeat1] = STATE(4280),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1819),
    [anon_sym_ref] = ACTIONS(1821),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1823),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1827),
    [anon_sym_TILDE] = ACTIONS(1827),
    [anon_sym_PLUS_PLUS] = ACTIONS(1827),
    [anon_sym_DASH_DASH] = ACTIONS(1827),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1825),
    [anon_sym_DASH] = ACTIONS(1825),
    [anon_sym_STAR] = ACTIONS(1829),
    [anon_sym_CARET] = ACTIONS(1827),
    [anon_sym_AMP] = ACTIONS(1827),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1831),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1833),
    [anon_sym_DOT_DOT] = ACTIONS(1835),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1687] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6910),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2960),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7091),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5669),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4208),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7438),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9067),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1687),
    [sym_preproc_endregion] = STATE(1687),
    [sym_preproc_line] = STATE(1687),
    [sym_preproc_pragma] = STATE(1687),
    [sym_preproc_nullable] = STATE(1687),
    [sym_preproc_error] = STATE(1687),
    [sym_preproc_warning] = STATE(1687),
    [sym_preproc_define] = STATE(1687),
    [sym_preproc_undef] = STATE(1687),
    [aux_sym_class_declaration_repeat1] = STATE(3847),
    [aux_sym_lambda_expression_repeat1] = STATE(4280),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1819),
    [anon_sym_ref] = ACTIONS(1821),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1823),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1827),
    [anon_sym_TILDE] = ACTIONS(1827),
    [anon_sym_PLUS_PLUS] = ACTIONS(1827),
    [anon_sym_DASH_DASH] = ACTIONS(1827),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1825),
    [anon_sym_DASH] = ACTIONS(1825),
    [anon_sym_STAR] = ACTIONS(1829),
    [anon_sym_CARET] = ACTIONS(1827),
    [anon_sym_AMP] = ACTIONS(1827),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1831),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1833),
    [anon_sym_DOT_DOT] = ACTIONS(1835),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1688] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6920),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2942),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7143),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4354),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4489),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7426),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9002),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1688),
    [sym_preproc_endregion] = STATE(1688),
    [sym_preproc_line] = STATE(1688),
    [sym_preproc_pragma] = STATE(1688),
    [sym_preproc_nullable] = STATE(1688),
    [sym_preproc_error] = STATE(1688),
    [sym_preproc_warning] = STATE(1688),
    [sym_preproc_define] = STATE(1688),
    [sym_preproc_undef] = STATE(1688),
    [aux_sym_class_declaration_repeat1] = STATE(3809),
    [aux_sym_lambda_expression_repeat1] = STATE(4308),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2189),
    [anon_sym_ref] = ACTIONS(2191),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2193),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2197),
    [anon_sym_TILDE] = ACTIONS(2197),
    [anon_sym_PLUS_PLUS] = ACTIONS(2197),
    [anon_sym_DASH_DASH] = ACTIONS(2197),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2195),
    [anon_sym_DASH] = ACTIONS(2195),
    [anon_sym_STAR] = ACTIONS(2199),
    [anon_sym_CARET] = ACTIONS(2197),
    [anon_sym_AMP] = ACTIONS(2197),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2201),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2203),
    [anon_sym_DOT_DOT] = ACTIONS(2205),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1689] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7105),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3056),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1689),
    [sym_preproc_endregion] = STATE(1689),
    [sym_preproc_line] = STATE(1689),
    [sym_preproc_pragma] = STATE(1689),
    [sym_preproc_nullable] = STATE(1689),
    [sym_preproc_error] = STATE(1689),
    [sym_preproc_warning] = STATE(1689),
    [sym_preproc_define] = STATE(1689),
    [sym_preproc_undef] = STATE(1689),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(1121),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1690] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7147),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5637),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4216),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9065),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1690),
    [sym_preproc_endregion] = STATE(1690),
    [sym_preproc_line] = STATE(1690),
    [sym_preproc_pragma] = STATE(1690),
    [sym_preproc_nullable] = STATE(1690),
    [sym_preproc_error] = STATE(1690),
    [sym_preproc_warning] = STATE(1690),
    [sym_preproc_define] = STATE(1690),
    [sym_preproc_undef] = STATE(1690),
    [aux_sym_class_declaration_repeat1] = STATE(3874),
    [aux_sym_lambda_expression_repeat1] = STATE(4311),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1531),
    [anon_sym_ref] = ACTIONS(1533),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1537),
    [anon_sym_TILDE] = ACTIONS(1537),
    [anon_sym_PLUS_PLUS] = ACTIONS(1537),
    [anon_sym_DASH_DASH] = ACTIONS(1537),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1535),
    [anon_sym_DASH] = ACTIONS(1535),
    [anon_sym_STAR] = ACTIONS(1121),
    [anon_sym_CARET] = ACTIONS(1537),
    [anon_sym_AMP] = ACTIONS(1537),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1129),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1131),
    [anon_sym_DOT_DOT] = ACTIONS(1135),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1691] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7147),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4336),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4216),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9065),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1691),
    [sym_preproc_endregion] = STATE(1691),
    [sym_preproc_line] = STATE(1691),
    [sym_preproc_pragma] = STATE(1691),
    [sym_preproc_nullable] = STATE(1691),
    [sym_preproc_error] = STATE(1691),
    [sym_preproc_warning] = STATE(1691),
    [sym_preproc_define] = STATE(1691),
    [sym_preproc_undef] = STATE(1691),
    [aux_sym_class_declaration_repeat1] = STATE(3874),
    [aux_sym_lambda_expression_repeat1] = STATE(4311),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1531),
    [anon_sym_ref] = ACTIONS(1533),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1537),
    [anon_sym_TILDE] = ACTIONS(1537),
    [anon_sym_PLUS_PLUS] = ACTIONS(1537),
    [anon_sym_DASH_DASH] = ACTIONS(1537),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1535),
    [anon_sym_DASH] = ACTIONS(1535),
    [anon_sym_STAR] = ACTIONS(1121),
    [anon_sym_CARET] = ACTIONS(1537),
    [anon_sym_AMP] = ACTIONS(1537),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1129),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1131),
    [anon_sym_DOT_DOT] = ACTIONS(1135),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1692] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7147),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5510),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4216),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9065),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1692),
    [sym_preproc_endregion] = STATE(1692),
    [sym_preproc_line] = STATE(1692),
    [sym_preproc_pragma] = STATE(1692),
    [sym_preproc_nullable] = STATE(1692),
    [sym_preproc_error] = STATE(1692),
    [sym_preproc_warning] = STATE(1692),
    [sym_preproc_define] = STATE(1692),
    [sym_preproc_undef] = STATE(1692),
    [aux_sym_class_declaration_repeat1] = STATE(3874),
    [aux_sym_lambda_expression_repeat1] = STATE(4311),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1531),
    [anon_sym_ref] = ACTIONS(1533),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1537),
    [anon_sym_TILDE] = ACTIONS(1537),
    [anon_sym_PLUS_PLUS] = ACTIONS(1537),
    [anon_sym_DASH_DASH] = ACTIONS(1537),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1535),
    [anon_sym_DASH] = ACTIONS(1535),
    [anon_sym_STAR] = ACTIONS(1121),
    [anon_sym_CARET] = ACTIONS(1537),
    [anon_sym_AMP] = ACTIONS(1537),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1129),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1131),
    [anon_sym_DOT_DOT] = ACTIONS(1135),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1693] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7147),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5511),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4216),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9065),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1693),
    [sym_preproc_endregion] = STATE(1693),
    [sym_preproc_line] = STATE(1693),
    [sym_preproc_pragma] = STATE(1693),
    [sym_preproc_nullable] = STATE(1693),
    [sym_preproc_error] = STATE(1693),
    [sym_preproc_warning] = STATE(1693),
    [sym_preproc_define] = STATE(1693),
    [sym_preproc_undef] = STATE(1693),
    [aux_sym_class_declaration_repeat1] = STATE(3874),
    [aux_sym_lambda_expression_repeat1] = STATE(4311),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1531),
    [anon_sym_ref] = ACTIONS(1533),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1537),
    [anon_sym_TILDE] = ACTIONS(1537),
    [anon_sym_PLUS_PLUS] = ACTIONS(1537),
    [anon_sym_DASH_DASH] = ACTIONS(1537),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1535),
    [anon_sym_DASH] = ACTIONS(1535),
    [anon_sym_STAR] = ACTIONS(1121),
    [anon_sym_CARET] = ACTIONS(1537),
    [anon_sym_AMP] = ACTIONS(1537),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1129),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1131),
    [anon_sym_DOT_DOT] = ACTIONS(1135),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1694] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7147),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5512),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4216),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9065),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1694),
    [sym_preproc_endregion] = STATE(1694),
    [sym_preproc_line] = STATE(1694),
    [sym_preproc_pragma] = STATE(1694),
    [sym_preproc_nullable] = STATE(1694),
    [sym_preproc_error] = STATE(1694),
    [sym_preproc_warning] = STATE(1694),
    [sym_preproc_define] = STATE(1694),
    [sym_preproc_undef] = STATE(1694),
    [aux_sym_class_declaration_repeat1] = STATE(3874),
    [aux_sym_lambda_expression_repeat1] = STATE(4311),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1531),
    [anon_sym_ref] = ACTIONS(1533),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1537),
    [anon_sym_TILDE] = ACTIONS(1537),
    [anon_sym_PLUS_PLUS] = ACTIONS(1537),
    [anon_sym_DASH_DASH] = ACTIONS(1537),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1535),
    [anon_sym_DASH] = ACTIONS(1535),
    [anon_sym_STAR] = ACTIONS(1121),
    [anon_sym_CARET] = ACTIONS(1537),
    [anon_sym_AMP] = ACTIONS(1537),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1129),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1131),
    [anon_sym_DOT_DOT] = ACTIONS(1135),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1695] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7147),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5513),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4216),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9065),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1695),
    [sym_preproc_endregion] = STATE(1695),
    [sym_preproc_line] = STATE(1695),
    [sym_preproc_pragma] = STATE(1695),
    [sym_preproc_nullable] = STATE(1695),
    [sym_preproc_error] = STATE(1695),
    [sym_preproc_warning] = STATE(1695),
    [sym_preproc_define] = STATE(1695),
    [sym_preproc_undef] = STATE(1695),
    [aux_sym_class_declaration_repeat1] = STATE(3874),
    [aux_sym_lambda_expression_repeat1] = STATE(4311),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1531),
    [anon_sym_ref] = ACTIONS(1533),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1537),
    [anon_sym_TILDE] = ACTIONS(1537),
    [anon_sym_PLUS_PLUS] = ACTIONS(1537),
    [anon_sym_DASH_DASH] = ACTIONS(1537),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1535),
    [anon_sym_DASH] = ACTIONS(1535),
    [anon_sym_STAR] = ACTIONS(1121),
    [anon_sym_CARET] = ACTIONS(1537),
    [anon_sym_AMP] = ACTIONS(1537),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1129),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1131),
    [anon_sym_DOT_DOT] = ACTIONS(1135),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1696] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7147),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5514),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4216),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9065),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1696),
    [sym_preproc_endregion] = STATE(1696),
    [sym_preproc_line] = STATE(1696),
    [sym_preproc_pragma] = STATE(1696),
    [sym_preproc_nullable] = STATE(1696),
    [sym_preproc_error] = STATE(1696),
    [sym_preproc_warning] = STATE(1696),
    [sym_preproc_define] = STATE(1696),
    [sym_preproc_undef] = STATE(1696),
    [aux_sym_class_declaration_repeat1] = STATE(3874),
    [aux_sym_lambda_expression_repeat1] = STATE(4311),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1531),
    [anon_sym_ref] = ACTIONS(1533),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1537),
    [anon_sym_TILDE] = ACTIONS(1537),
    [anon_sym_PLUS_PLUS] = ACTIONS(1537),
    [anon_sym_DASH_DASH] = ACTIONS(1537),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1535),
    [anon_sym_DASH] = ACTIONS(1535),
    [anon_sym_STAR] = ACTIONS(1121),
    [anon_sym_CARET] = ACTIONS(1537),
    [anon_sym_AMP] = ACTIONS(1537),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1129),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1131),
    [anon_sym_DOT_DOT] = ACTIONS(1135),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1697] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7147),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5515),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4216),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9065),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1697),
    [sym_preproc_endregion] = STATE(1697),
    [sym_preproc_line] = STATE(1697),
    [sym_preproc_pragma] = STATE(1697),
    [sym_preproc_nullable] = STATE(1697),
    [sym_preproc_error] = STATE(1697),
    [sym_preproc_warning] = STATE(1697),
    [sym_preproc_define] = STATE(1697),
    [sym_preproc_undef] = STATE(1697),
    [aux_sym_class_declaration_repeat1] = STATE(3874),
    [aux_sym_lambda_expression_repeat1] = STATE(4311),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1531),
    [anon_sym_ref] = ACTIONS(1533),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1537),
    [anon_sym_TILDE] = ACTIONS(1537),
    [anon_sym_PLUS_PLUS] = ACTIONS(1537),
    [anon_sym_DASH_DASH] = ACTIONS(1537),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1535),
    [anon_sym_DASH] = ACTIONS(1535),
    [anon_sym_STAR] = ACTIONS(1121),
    [anon_sym_CARET] = ACTIONS(1537),
    [anon_sym_AMP] = ACTIONS(1537),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1129),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1131),
    [anon_sym_DOT_DOT] = ACTIONS(1135),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1698] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7147),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5516),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4216),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9065),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1698),
    [sym_preproc_endregion] = STATE(1698),
    [sym_preproc_line] = STATE(1698),
    [sym_preproc_pragma] = STATE(1698),
    [sym_preproc_nullable] = STATE(1698),
    [sym_preproc_error] = STATE(1698),
    [sym_preproc_warning] = STATE(1698),
    [sym_preproc_define] = STATE(1698),
    [sym_preproc_undef] = STATE(1698),
    [aux_sym_class_declaration_repeat1] = STATE(3874),
    [aux_sym_lambda_expression_repeat1] = STATE(4311),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1531),
    [anon_sym_ref] = ACTIONS(1533),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1537),
    [anon_sym_TILDE] = ACTIONS(1537),
    [anon_sym_PLUS_PLUS] = ACTIONS(1537),
    [anon_sym_DASH_DASH] = ACTIONS(1537),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1535),
    [anon_sym_DASH] = ACTIONS(1535),
    [anon_sym_STAR] = ACTIONS(1121),
    [anon_sym_CARET] = ACTIONS(1537),
    [anon_sym_AMP] = ACTIONS(1537),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1129),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1131),
    [anon_sym_DOT_DOT] = ACTIONS(1135),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1699] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7147),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5517),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4216),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9065),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1699),
    [sym_preproc_endregion] = STATE(1699),
    [sym_preproc_line] = STATE(1699),
    [sym_preproc_pragma] = STATE(1699),
    [sym_preproc_nullable] = STATE(1699),
    [sym_preproc_error] = STATE(1699),
    [sym_preproc_warning] = STATE(1699),
    [sym_preproc_define] = STATE(1699),
    [sym_preproc_undef] = STATE(1699),
    [aux_sym_class_declaration_repeat1] = STATE(3874),
    [aux_sym_lambda_expression_repeat1] = STATE(4311),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1531),
    [anon_sym_ref] = ACTIONS(1533),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1537),
    [anon_sym_TILDE] = ACTIONS(1537),
    [anon_sym_PLUS_PLUS] = ACTIONS(1537),
    [anon_sym_DASH_DASH] = ACTIONS(1537),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1535),
    [anon_sym_DASH] = ACTIONS(1535),
    [anon_sym_STAR] = ACTIONS(1121),
    [anon_sym_CARET] = ACTIONS(1537),
    [anon_sym_AMP] = ACTIONS(1537),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1129),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1131),
    [anon_sym_DOT_DOT] = ACTIONS(1135),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1700] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7147),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5519),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4216),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9065),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1700),
    [sym_preproc_endregion] = STATE(1700),
    [sym_preproc_line] = STATE(1700),
    [sym_preproc_pragma] = STATE(1700),
    [sym_preproc_nullable] = STATE(1700),
    [sym_preproc_error] = STATE(1700),
    [sym_preproc_warning] = STATE(1700),
    [sym_preproc_define] = STATE(1700),
    [sym_preproc_undef] = STATE(1700),
    [aux_sym_class_declaration_repeat1] = STATE(3874),
    [aux_sym_lambda_expression_repeat1] = STATE(4311),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1531),
    [anon_sym_ref] = ACTIONS(1533),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1537),
    [anon_sym_TILDE] = ACTIONS(1537),
    [anon_sym_PLUS_PLUS] = ACTIONS(1537),
    [anon_sym_DASH_DASH] = ACTIONS(1537),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1535),
    [anon_sym_DASH] = ACTIONS(1535),
    [anon_sym_STAR] = ACTIONS(1121),
    [anon_sym_CARET] = ACTIONS(1537),
    [anon_sym_AMP] = ACTIONS(1537),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1129),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1131),
    [anon_sym_DOT_DOT] = ACTIONS(1135),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1701] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7147),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5520),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4216),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9065),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1701),
    [sym_preproc_endregion] = STATE(1701),
    [sym_preproc_line] = STATE(1701),
    [sym_preproc_pragma] = STATE(1701),
    [sym_preproc_nullable] = STATE(1701),
    [sym_preproc_error] = STATE(1701),
    [sym_preproc_warning] = STATE(1701),
    [sym_preproc_define] = STATE(1701),
    [sym_preproc_undef] = STATE(1701),
    [aux_sym_class_declaration_repeat1] = STATE(3874),
    [aux_sym_lambda_expression_repeat1] = STATE(4311),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1531),
    [anon_sym_ref] = ACTIONS(1533),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1537),
    [anon_sym_TILDE] = ACTIONS(1537),
    [anon_sym_PLUS_PLUS] = ACTIONS(1537),
    [anon_sym_DASH_DASH] = ACTIONS(1537),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1535),
    [anon_sym_DASH] = ACTIONS(1535),
    [anon_sym_STAR] = ACTIONS(1121),
    [anon_sym_CARET] = ACTIONS(1537),
    [anon_sym_AMP] = ACTIONS(1537),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1129),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1131),
    [anon_sym_DOT_DOT] = ACTIONS(1135),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1702] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7147),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5521),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4216),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9065),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1702),
    [sym_preproc_endregion] = STATE(1702),
    [sym_preproc_line] = STATE(1702),
    [sym_preproc_pragma] = STATE(1702),
    [sym_preproc_nullable] = STATE(1702),
    [sym_preproc_error] = STATE(1702),
    [sym_preproc_warning] = STATE(1702),
    [sym_preproc_define] = STATE(1702),
    [sym_preproc_undef] = STATE(1702),
    [aux_sym_class_declaration_repeat1] = STATE(3874),
    [aux_sym_lambda_expression_repeat1] = STATE(4311),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1531),
    [anon_sym_ref] = ACTIONS(1533),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1537),
    [anon_sym_TILDE] = ACTIONS(1537),
    [anon_sym_PLUS_PLUS] = ACTIONS(1537),
    [anon_sym_DASH_DASH] = ACTIONS(1537),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1535),
    [anon_sym_DASH] = ACTIONS(1535),
    [anon_sym_STAR] = ACTIONS(1121),
    [anon_sym_CARET] = ACTIONS(1537),
    [anon_sym_AMP] = ACTIONS(1537),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1129),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1131),
    [anon_sym_DOT_DOT] = ACTIONS(1135),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1703] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7147),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5638),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4216),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9065),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1703),
    [sym_preproc_endregion] = STATE(1703),
    [sym_preproc_line] = STATE(1703),
    [sym_preproc_pragma] = STATE(1703),
    [sym_preproc_nullable] = STATE(1703),
    [sym_preproc_error] = STATE(1703),
    [sym_preproc_warning] = STATE(1703),
    [sym_preproc_define] = STATE(1703),
    [sym_preproc_undef] = STATE(1703),
    [aux_sym_class_declaration_repeat1] = STATE(3874),
    [aux_sym_lambda_expression_repeat1] = STATE(4311),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1531),
    [anon_sym_ref] = ACTIONS(1533),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1537),
    [anon_sym_TILDE] = ACTIONS(1537),
    [anon_sym_PLUS_PLUS] = ACTIONS(1537),
    [anon_sym_DASH_DASH] = ACTIONS(1537),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1535),
    [anon_sym_DASH] = ACTIONS(1535),
    [anon_sym_STAR] = ACTIONS(1121),
    [anon_sym_CARET] = ACTIONS(1537),
    [anon_sym_AMP] = ACTIONS(1537),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1129),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1131),
    [anon_sym_DOT_DOT] = ACTIONS(1135),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1704] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6912),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2912),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7040),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5405),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3963),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7448),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9641),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1704),
    [sym_preproc_endregion] = STATE(1704),
    [sym_preproc_line] = STATE(1704),
    [sym_preproc_pragma] = STATE(1704),
    [sym_preproc_nullable] = STATE(1704),
    [sym_preproc_error] = STATE(1704),
    [sym_preproc_warning] = STATE(1704),
    [sym_preproc_define] = STATE(1704),
    [sym_preproc_undef] = STATE(1704),
    [aux_sym_class_declaration_repeat1] = STATE(3831),
    [aux_sym_lambda_expression_repeat1] = STATE(4257),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1785),
    [anon_sym_ref] = ACTIONS(1787),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1595),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1791),
    [anon_sym_TILDE] = ACTIONS(1791),
    [anon_sym_PLUS_PLUS] = ACTIONS(1791),
    [anon_sym_DASH_DASH] = ACTIONS(1791),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1789),
    [anon_sym_DASH] = ACTIONS(1789),
    [anon_sym_STAR] = ACTIONS(1793),
    [anon_sym_CARET] = ACTIONS(1791),
    [anon_sym_AMP] = ACTIONS(1791),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1795),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1797),
    [anon_sym_DOT_DOT] = ACTIONS(1799),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1705] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7147),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4338),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4216),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9065),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1705),
    [sym_preproc_endregion] = STATE(1705),
    [sym_preproc_line] = STATE(1705),
    [sym_preproc_pragma] = STATE(1705),
    [sym_preproc_nullable] = STATE(1705),
    [sym_preproc_error] = STATE(1705),
    [sym_preproc_warning] = STATE(1705),
    [sym_preproc_define] = STATE(1705),
    [sym_preproc_undef] = STATE(1705),
    [aux_sym_class_declaration_repeat1] = STATE(3874),
    [aux_sym_lambda_expression_repeat1] = STATE(4311),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1531),
    [anon_sym_ref] = ACTIONS(1533),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1537),
    [anon_sym_TILDE] = ACTIONS(1537),
    [anon_sym_PLUS_PLUS] = ACTIONS(1537),
    [anon_sym_DASH_DASH] = ACTIONS(1537),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1535),
    [anon_sym_DASH] = ACTIONS(1535),
    [anon_sym_STAR] = ACTIONS(1121),
    [anon_sym_CARET] = ACTIONS(1537),
    [anon_sym_AMP] = ACTIONS(1537),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1129),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1131),
    [anon_sym_DOT_DOT] = ACTIONS(1135),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1706] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6956),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6538),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9482),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1706),
    [sym_preproc_endregion] = STATE(1706),
    [sym_preproc_line] = STATE(1706),
    [sym_preproc_pragma] = STATE(1706),
    [sym_preproc_nullable] = STATE(1706),
    [sym_preproc_error] = STATE(1706),
    [sym_preproc_warning] = STATE(1706),
    [sym_preproc_define] = STATE(1706),
    [sym_preproc_undef] = STATE(1706),
    [aux_sym_class_declaration_repeat1] = STATE(3853),
    [aux_sym_lambda_expression_repeat1] = STATE(4299),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1497),
    [anon_sym_ref] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1505),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1507),
    [anon_sym_DOT_DOT] = ACTIONS(1509),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1707] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6984),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5241),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3903),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7428),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9348),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1707),
    [sym_preproc_endregion] = STATE(1707),
    [sym_preproc_line] = STATE(1707),
    [sym_preproc_pragma] = STATE(1707),
    [sym_preproc_nullable] = STATE(1707),
    [sym_preproc_error] = STATE(1707),
    [sym_preproc_warning] = STATE(1707),
    [sym_preproc_define] = STATE(1707),
    [sym_preproc_undef] = STATE(1707),
    [aux_sym_class_declaration_repeat1] = STATE(3817),
    [aux_sym_lambda_expression_repeat1] = STATE(4227),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1389),
    [anon_sym_ref] = ACTIONS(1391),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1117),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(1393),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_AMP] = ACTIONS(1117),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1395),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1397),
    [anon_sym_DOT_DOT] = ACTIONS(1399),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1708] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7147),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5525),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4216),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9065),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1708),
    [sym_preproc_endregion] = STATE(1708),
    [sym_preproc_line] = STATE(1708),
    [sym_preproc_pragma] = STATE(1708),
    [sym_preproc_nullable] = STATE(1708),
    [sym_preproc_error] = STATE(1708),
    [sym_preproc_warning] = STATE(1708),
    [sym_preproc_define] = STATE(1708),
    [sym_preproc_undef] = STATE(1708),
    [aux_sym_class_declaration_repeat1] = STATE(3874),
    [aux_sym_lambda_expression_repeat1] = STATE(4311),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1531),
    [anon_sym_ref] = ACTIONS(1533),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1537),
    [anon_sym_TILDE] = ACTIONS(1537),
    [anon_sym_PLUS_PLUS] = ACTIONS(1537),
    [anon_sym_DASH_DASH] = ACTIONS(1537),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1535),
    [anon_sym_DASH] = ACTIONS(1535),
    [anon_sym_STAR] = ACTIONS(1121),
    [anon_sym_CARET] = ACTIONS(1537),
    [anon_sym_AMP] = ACTIONS(1537),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1129),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1131),
    [anon_sym_DOT_DOT] = ACTIONS(1135),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1709] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6912),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2912),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7040),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5285),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3963),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7448),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9641),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1709),
    [sym_preproc_endregion] = STATE(1709),
    [sym_preproc_line] = STATE(1709),
    [sym_preproc_pragma] = STATE(1709),
    [sym_preproc_nullable] = STATE(1709),
    [sym_preproc_error] = STATE(1709),
    [sym_preproc_warning] = STATE(1709),
    [sym_preproc_define] = STATE(1709),
    [sym_preproc_undef] = STATE(1709),
    [aux_sym_class_declaration_repeat1] = STATE(3831),
    [aux_sym_lambda_expression_repeat1] = STATE(4257),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1785),
    [anon_sym_ref] = ACTIONS(1787),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1595),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1791),
    [anon_sym_TILDE] = ACTIONS(1791),
    [anon_sym_PLUS_PLUS] = ACTIONS(1791),
    [anon_sym_DASH_DASH] = ACTIONS(1791),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1789),
    [anon_sym_DASH] = ACTIONS(1789),
    [anon_sym_STAR] = ACTIONS(1793),
    [anon_sym_CARET] = ACTIONS(1791),
    [anon_sym_AMP] = ACTIONS(1791),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1795),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1797),
    [anon_sym_DOT_DOT] = ACTIONS(1799),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1710] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6920),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2942),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7032),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6068),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4337),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7427),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9283),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1710),
    [sym_preproc_endregion] = STATE(1710),
    [sym_preproc_line] = STATE(1710),
    [sym_preproc_pragma] = STATE(1710),
    [sym_preproc_nullable] = STATE(1710),
    [sym_preproc_error] = STATE(1710),
    [sym_preproc_warning] = STATE(1710),
    [sym_preproc_define] = STATE(1710),
    [sym_preproc_undef] = STATE(1710),
    [aux_sym_class_declaration_repeat1] = STATE(3829),
    [aux_sym_lambda_expression_repeat1] = STATE(4252),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1801),
    [anon_sym_ref] = ACTIONS(1803),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1805),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1809),
    [anon_sym_TILDE] = ACTIONS(1809),
    [anon_sym_PLUS_PLUS] = ACTIONS(1809),
    [anon_sym_DASH_DASH] = ACTIONS(1809),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1807),
    [anon_sym_DASH] = ACTIONS(1807),
    [anon_sym_STAR] = ACTIONS(1811),
    [anon_sym_CARET] = ACTIONS(1809),
    [anon_sym_AMP] = ACTIONS(1809),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1813),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1815),
    [anon_sym_DOT_DOT] = ACTIONS(1817),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1711] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6920),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2942),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7032),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6069),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4337),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7427),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9283),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1711),
    [sym_preproc_endregion] = STATE(1711),
    [sym_preproc_line] = STATE(1711),
    [sym_preproc_pragma] = STATE(1711),
    [sym_preproc_nullable] = STATE(1711),
    [sym_preproc_error] = STATE(1711),
    [sym_preproc_warning] = STATE(1711),
    [sym_preproc_define] = STATE(1711),
    [sym_preproc_undef] = STATE(1711),
    [aux_sym_class_declaration_repeat1] = STATE(3829),
    [aux_sym_lambda_expression_repeat1] = STATE(4252),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1801),
    [anon_sym_ref] = ACTIONS(1803),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1805),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1809),
    [anon_sym_TILDE] = ACTIONS(1809),
    [anon_sym_PLUS_PLUS] = ACTIONS(1809),
    [anon_sym_DASH_DASH] = ACTIONS(1809),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1807),
    [anon_sym_DASH] = ACTIONS(1807),
    [anon_sym_STAR] = ACTIONS(1811),
    [anon_sym_CARET] = ACTIONS(1809),
    [anon_sym_AMP] = ACTIONS(1809),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1813),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1815),
    [anon_sym_DOT_DOT] = ACTIONS(1817),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1712] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6920),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2942),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7032),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6048),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4337),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7427),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9283),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1712),
    [sym_preproc_endregion] = STATE(1712),
    [sym_preproc_line] = STATE(1712),
    [sym_preproc_pragma] = STATE(1712),
    [sym_preproc_nullable] = STATE(1712),
    [sym_preproc_error] = STATE(1712),
    [sym_preproc_warning] = STATE(1712),
    [sym_preproc_define] = STATE(1712),
    [sym_preproc_undef] = STATE(1712),
    [aux_sym_class_declaration_repeat1] = STATE(3829),
    [aux_sym_lambda_expression_repeat1] = STATE(4252),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1801),
    [anon_sym_ref] = ACTIONS(1803),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1805),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1809),
    [anon_sym_TILDE] = ACTIONS(1809),
    [anon_sym_PLUS_PLUS] = ACTIONS(1809),
    [anon_sym_DASH_DASH] = ACTIONS(1809),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1807),
    [anon_sym_DASH] = ACTIONS(1807),
    [anon_sym_STAR] = ACTIONS(1811),
    [anon_sym_CARET] = ACTIONS(1809),
    [anon_sym_AMP] = ACTIONS(1809),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1813),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1815),
    [anon_sym_DOT_DOT] = ACTIONS(1817),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1713] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6920),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2942),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7032),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6070),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4337),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7427),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9283),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1713),
    [sym_preproc_endregion] = STATE(1713),
    [sym_preproc_line] = STATE(1713),
    [sym_preproc_pragma] = STATE(1713),
    [sym_preproc_nullable] = STATE(1713),
    [sym_preproc_error] = STATE(1713),
    [sym_preproc_warning] = STATE(1713),
    [sym_preproc_define] = STATE(1713),
    [sym_preproc_undef] = STATE(1713),
    [aux_sym_class_declaration_repeat1] = STATE(3829),
    [aux_sym_lambda_expression_repeat1] = STATE(4252),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1801),
    [anon_sym_ref] = ACTIONS(1803),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1805),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1809),
    [anon_sym_TILDE] = ACTIONS(1809),
    [anon_sym_PLUS_PLUS] = ACTIONS(1809),
    [anon_sym_DASH_DASH] = ACTIONS(1809),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1807),
    [anon_sym_DASH] = ACTIONS(1807),
    [anon_sym_STAR] = ACTIONS(1811),
    [anon_sym_CARET] = ACTIONS(1809),
    [anon_sym_AMP] = ACTIONS(1809),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1813),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1815),
    [anon_sym_DOT_DOT] = ACTIONS(1817),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1714] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6920),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2942),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7032),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6071),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4337),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7427),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9283),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1714),
    [sym_preproc_endregion] = STATE(1714),
    [sym_preproc_line] = STATE(1714),
    [sym_preproc_pragma] = STATE(1714),
    [sym_preproc_nullable] = STATE(1714),
    [sym_preproc_error] = STATE(1714),
    [sym_preproc_warning] = STATE(1714),
    [sym_preproc_define] = STATE(1714),
    [sym_preproc_undef] = STATE(1714),
    [aux_sym_class_declaration_repeat1] = STATE(3829),
    [aux_sym_lambda_expression_repeat1] = STATE(4252),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1801),
    [anon_sym_ref] = ACTIONS(1803),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1805),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1809),
    [anon_sym_TILDE] = ACTIONS(1809),
    [anon_sym_PLUS_PLUS] = ACTIONS(1809),
    [anon_sym_DASH_DASH] = ACTIONS(1809),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1807),
    [anon_sym_DASH] = ACTIONS(1807),
    [anon_sym_STAR] = ACTIONS(1811),
    [anon_sym_CARET] = ACTIONS(1809),
    [anon_sym_AMP] = ACTIONS(1809),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1813),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1815),
    [anon_sym_DOT_DOT] = ACTIONS(1817),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1715] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6920),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2942),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7032),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6072),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4337),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7427),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9283),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1715),
    [sym_preproc_endregion] = STATE(1715),
    [sym_preproc_line] = STATE(1715),
    [sym_preproc_pragma] = STATE(1715),
    [sym_preproc_nullable] = STATE(1715),
    [sym_preproc_error] = STATE(1715),
    [sym_preproc_warning] = STATE(1715),
    [sym_preproc_define] = STATE(1715),
    [sym_preproc_undef] = STATE(1715),
    [aux_sym_class_declaration_repeat1] = STATE(3829),
    [aux_sym_lambda_expression_repeat1] = STATE(4252),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1801),
    [anon_sym_ref] = ACTIONS(1803),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1805),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1809),
    [anon_sym_TILDE] = ACTIONS(1809),
    [anon_sym_PLUS_PLUS] = ACTIONS(1809),
    [anon_sym_DASH_DASH] = ACTIONS(1809),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1807),
    [anon_sym_DASH] = ACTIONS(1807),
    [anon_sym_STAR] = ACTIONS(1811),
    [anon_sym_CARET] = ACTIONS(1809),
    [anon_sym_AMP] = ACTIONS(1809),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1813),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1815),
    [anon_sym_DOT_DOT] = ACTIONS(1817),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1716] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6920),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2942),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7032),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6073),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4337),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7427),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9283),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1716),
    [sym_preproc_endregion] = STATE(1716),
    [sym_preproc_line] = STATE(1716),
    [sym_preproc_pragma] = STATE(1716),
    [sym_preproc_nullable] = STATE(1716),
    [sym_preproc_error] = STATE(1716),
    [sym_preproc_warning] = STATE(1716),
    [sym_preproc_define] = STATE(1716),
    [sym_preproc_undef] = STATE(1716),
    [aux_sym_class_declaration_repeat1] = STATE(3829),
    [aux_sym_lambda_expression_repeat1] = STATE(4252),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1801),
    [anon_sym_ref] = ACTIONS(1803),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1805),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1809),
    [anon_sym_TILDE] = ACTIONS(1809),
    [anon_sym_PLUS_PLUS] = ACTIONS(1809),
    [anon_sym_DASH_DASH] = ACTIONS(1809),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1807),
    [anon_sym_DASH] = ACTIONS(1807),
    [anon_sym_STAR] = ACTIONS(1811),
    [anon_sym_CARET] = ACTIONS(1809),
    [anon_sym_AMP] = ACTIONS(1809),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1813),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1815),
    [anon_sym_DOT_DOT] = ACTIONS(1817),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1717] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6920),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2942),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7032),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6074),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4337),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7427),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9283),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1717),
    [sym_preproc_endregion] = STATE(1717),
    [sym_preproc_line] = STATE(1717),
    [sym_preproc_pragma] = STATE(1717),
    [sym_preproc_nullable] = STATE(1717),
    [sym_preproc_error] = STATE(1717),
    [sym_preproc_warning] = STATE(1717),
    [sym_preproc_define] = STATE(1717),
    [sym_preproc_undef] = STATE(1717),
    [aux_sym_class_declaration_repeat1] = STATE(3829),
    [aux_sym_lambda_expression_repeat1] = STATE(4252),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1801),
    [anon_sym_ref] = ACTIONS(1803),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1805),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1809),
    [anon_sym_TILDE] = ACTIONS(1809),
    [anon_sym_PLUS_PLUS] = ACTIONS(1809),
    [anon_sym_DASH_DASH] = ACTIONS(1809),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1807),
    [anon_sym_DASH] = ACTIONS(1807),
    [anon_sym_STAR] = ACTIONS(1811),
    [anon_sym_CARET] = ACTIONS(1809),
    [anon_sym_AMP] = ACTIONS(1809),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1813),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1815),
    [anon_sym_DOT_DOT] = ACTIONS(1817),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1718] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6920),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2942),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7032),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6078),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4337),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7427),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9283),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1718),
    [sym_preproc_endregion] = STATE(1718),
    [sym_preproc_line] = STATE(1718),
    [sym_preproc_pragma] = STATE(1718),
    [sym_preproc_nullable] = STATE(1718),
    [sym_preproc_error] = STATE(1718),
    [sym_preproc_warning] = STATE(1718),
    [sym_preproc_define] = STATE(1718),
    [sym_preproc_undef] = STATE(1718),
    [aux_sym_class_declaration_repeat1] = STATE(3829),
    [aux_sym_lambda_expression_repeat1] = STATE(4252),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1801),
    [anon_sym_ref] = ACTIONS(1803),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1805),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1809),
    [anon_sym_TILDE] = ACTIONS(1809),
    [anon_sym_PLUS_PLUS] = ACTIONS(1809),
    [anon_sym_DASH_DASH] = ACTIONS(1809),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1807),
    [anon_sym_DASH] = ACTIONS(1807),
    [anon_sym_STAR] = ACTIONS(1811),
    [anon_sym_CARET] = ACTIONS(1809),
    [anon_sym_AMP] = ACTIONS(1809),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1813),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1815),
    [anon_sym_DOT_DOT] = ACTIONS(1817),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1719] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6920),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2942),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7032),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6079),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4337),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7427),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9283),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1719),
    [sym_preproc_endregion] = STATE(1719),
    [sym_preproc_line] = STATE(1719),
    [sym_preproc_pragma] = STATE(1719),
    [sym_preproc_nullable] = STATE(1719),
    [sym_preproc_error] = STATE(1719),
    [sym_preproc_warning] = STATE(1719),
    [sym_preproc_define] = STATE(1719),
    [sym_preproc_undef] = STATE(1719),
    [aux_sym_class_declaration_repeat1] = STATE(3829),
    [aux_sym_lambda_expression_repeat1] = STATE(4252),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1801),
    [anon_sym_ref] = ACTIONS(1803),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1805),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1809),
    [anon_sym_TILDE] = ACTIONS(1809),
    [anon_sym_PLUS_PLUS] = ACTIONS(1809),
    [anon_sym_DASH_DASH] = ACTIONS(1809),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1807),
    [anon_sym_DASH] = ACTIONS(1807),
    [anon_sym_STAR] = ACTIONS(1811),
    [anon_sym_CARET] = ACTIONS(1809),
    [anon_sym_AMP] = ACTIONS(1809),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1813),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1815),
    [anon_sym_DOT_DOT] = ACTIONS(1817),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1720] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6920),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2942),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7032),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6080),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4337),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7427),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9283),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1720),
    [sym_preproc_endregion] = STATE(1720),
    [sym_preproc_line] = STATE(1720),
    [sym_preproc_pragma] = STATE(1720),
    [sym_preproc_nullable] = STATE(1720),
    [sym_preproc_error] = STATE(1720),
    [sym_preproc_warning] = STATE(1720),
    [sym_preproc_define] = STATE(1720),
    [sym_preproc_undef] = STATE(1720),
    [aux_sym_class_declaration_repeat1] = STATE(3829),
    [aux_sym_lambda_expression_repeat1] = STATE(4252),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1801),
    [anon_sym_ref] = ACTIONS(1803),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1805),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1809),
    [anon_sym_TILDE] = ACTIONS(1809),
    [anon_sym_PLUS_PLUS] = ACTIONS(1809),
    [anon_sym_DASH_DASH] = ACTIONS(1809),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1807),
    [anon_sym_DASH] = ACTIONS(1807),
    [anon_sym_STAR] = ACTIONS(1811),
    [anon_sym_CARET] = ACTIONS(1809),
    [anon_sym_AMP] = ACTIONS(1809),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1813),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1815),
    [anon_sym_DOT_DOT] = ACTIONS(1817),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1721] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6920),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2942),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7032),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3932),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4337),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7427),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9283),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1721),
    [sym_preproc_endregion] = STATE(1721),
    [sym_preproc_line] = STATE(1721),
    [sym_preproc_pragma] = STATE(1721),
    [sym_preproc_nullable] = STATE(1721),
    [sym_preproc_error] = STATE(1721),
    [sym_preproc_warning] = STATE(1721),
    [sym_preproc_define] = STATE(1721),
    [sym_preproc_undef] = STATE(1721),
    [aux_sym_class_declaration_repeat1] = STATE(3829),
    [aux_sym_lambda_expression_repeat1] = STATE(4252),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1801),
    [anon_sym_ref] = ACTIONS(1803),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1805),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1809),
    [anon_sym_TILDE] = ACTIONS(1809),
    [anon_sym_PLUS_PLUS] = ACTIONS(1809),
    [anon_sym_DASH_DASH] = ACTIONS(1809),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1807),
    [anon_sym_DASH] = ACTIONS(1807),
    [anon_sym_STAR] = ACTIONS(1811),
    [anon_sym_CARET] = ACTIONS(1809),
    [anon_sym_AMP] = ACTIONS(1809),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1813),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1815),
    [anon_sym_DOT_DOT] = ACTIONS(1817),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1722] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6956),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6349),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9482),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1722),
    [sym_preproc_endregion] = STATE(1722),
    [sym_preproc_line] = STATE(1722),
    [sym_preproc_pragma] = STATE(1722),
    [sym_preproc_nullable] = STATE(1722),
    [sym_preproc_error] = STATE(1722),
    [sym_preproc_warning] = STATE(1722),
    [sym_preproc_define] = STATE(1722),
    [sym_preproc_undef] = STATE(1722),
    [aux_sym_class_declaration_repeat1] = STATE(3853),
    [aux_sym_lambda_expression_repeat1] = STATE(4299),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1497),
    [anon_sym_ref] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1505),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1507),
    [anon_sym_DOT_DOT] = ACTIONS(1509),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1723] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6916),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7061),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6213),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4369),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7437),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9284),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1723),
    [sym_preproc_endregion] = STATE(1723),
    [sym_preproc_line] = STATE(1723),
    [sym_preproc_pragma] = STATE(1723),
    [sym_preproc_nullable] = STATE(1723),
    [sym_preproc_error] = STATE(1723),
    [sym_preproc_warning] = STATE(1723),
    [sym_preproc_define] = STATE(1723),
    [sym_preproc_undef] = STATE(1723),
    [aux_sym_class_declaration_repeat1] = STATE(3839),
    [aux_sym_lambda_expression_repeat1] = STATE(4267),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1963),
    [anon_sym_ref] = ACTIONS(1965),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1969),
    [anon_sym_TILDE] = ACTIONS(1969),
    [anon_sym_PLUS_PLUS] = ACTIONS(1969),
    [anon_sym_DASH_DASH] = ACTIONS(1969),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1967),
    [anon_sym_DASH] = ACTIONS(1967),
    [anon_sym_STAR] = ACTIONS(1971),
    [anon_sym_CARET] = ACTIONS(1969),
    [anon_sym_AMP] = ACTIONS(1969),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1973),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1975),
    [anon_sym_DOT_DOT] = ACTIONS(1977),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1724] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6916),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7061),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3567),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4369),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7437),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9284),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1724),
    [sym_preproc_endregion] = STATE(1724),
    [sym_preproc_line] = STATE(1724),
    [sym_preproc_pragma] = STATE(1724),
    [sym_preproc_nullable] = STATE(1724),
    [sym_preproc_error] = STATE(1724),
    [sym_preproc_warning] = STATE(1724),
    [sym_preproc_define] = STATE(1724),
    [sym_preproc_undef] = STATE(1724),
    [aux_sym_class_declaration_repeat1] = STATE(3839),
    [aux_sym_lambda_expression_repeat1] = STATE(4267),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1963),
    [anon_sym_ref] = ACTIONS(1965),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1969),
    [anon_sym_TILDE] = ACTIONS(1969),
    [anon_sym_PLUS_PLUS] = ACTIONS(1969),
    [anon_sym_DASH_DASH] = ACTIONS(1969),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1967),
    [anon_sym_DASH] = ACTIONS(1967),
    [anon_sym_STAR] = ACTIONS(1971),
    [anon_sym_CARET] = ACTIONS(1969),
    [anon_sym_AMP] = ACTIONS(1969),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1973),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1975),
    [anon_sym_DOT_DOT] = ACTIONS(1977),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1725] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6916),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7061),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6244),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4369),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7437),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9284),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1725),
    [sym_preproc_endregion] = STATE(1725),
    [sym_preproc_line] = STATE(1725),
    [sym_preproc_pragma] = STATE(1725),
    [sym_preproc_nullable] = STATE(1725),
    [sym_preproc_error] = STATE(1725),
    [sym_preproc_warning] = STATE(1725),
    [sym_preproc_define] = STATE(1725),
    [sym_preproc_undef] = STATE(1725),
    [aux_sym_class_declaration_repeat1] = STATE(3839),
    [aux_sym_lambda_expression_repeat1] = STATE(4267),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1963),
    [anon_sym_ref] = ACTIONS(1965),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1969),
    [anon_sym_TILDE] = ACTIONS(1969),
    [anon_sym_PLUS_PLUS] = ACTIONS(1969),
    [anon_sym_DASH_DASH] = ACTIONS(1969),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1967),
    [anon_sym_DASH] = ACTIONS(1967),
    [anon_sym_STAR] = ACTIONS(1971),
    [anon_sym_CARET] = ACTIONS(1969),
    [anon_sym_AMP] = ACTIONS(1969),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1973),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1975),
    [anon_sym_DOT_DOT] = ACTIONS(1977),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1726] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6927),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2912),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7057),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5301),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3960),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7439),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9222),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1726),
    [sym_preproc_endregion] = STATE(1726),
    [sym_preproc_line] = STATE(1726),
    [sym_preproc_pragma] = STATE(1726),
    [sym_preproc_nullable] = STATE(1726),
    [sym_preproc_error] = STATE(1726),
    [sym_preproc_warning] = STATE(1726),
    [sym_preproc_define] = STATE(1726),
    [sym_preproc_undef] = STATE(1726),
    [aux_sym_class_declaration_repeat1] = STATE(3837),
    [aux_sym_lambda_expression_repeat1] = STATE(4265),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1591),
    [anon_sym_ref] = ACTIONS(1593),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1595),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1599),
    [anon_sym_TILDE] = ACTIONS(1599),
    [anon_sym_PLUS_PLUS] = ACTIONS(1599),
    [anon_sym_DASH_DASH] = ACTIONS(1599),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1597),
    [anon_sym_DASH] = ACTIONS(1597),
    [anon_sym_STAR] = ACTIONS(1601),
    [anon_sym_CARET] = ACTIONS(1599),
    [anon_sym_AMP] = ACTIONS(1599),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1603),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1605),
    [anon_sym_DOT_DOT] = ACTIONS(1607),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1727] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6916),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7061),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6250),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4369),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7437),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9284),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1727),
    [sym_preproc_endregion] = STATE(1727),
    [sym_preproc_line] = STATE(1727),
    [sym_preproc_pragma] = STATE(1727),
    [sym_preproc_nullable] = STATE(1727),
    [sym_preproc_error] = STATE(1727),
    [sym_preproc_warning] = STATE(1727),
    [sym_preproc_define] = STATE(1727),
    [sym_preproc_undef] = STATE(1727),
    [aux_sym_class_declaration_repeat1] = STATE(3839),
    [aux_sym_lambda_expression_repeat1] = STATE(4267),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1963),
    [anon_sym_ref] = ACTIONS(1965),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1969),
    [anon_sym_TILDE] = ACTIONS(1969),
    [anon_sym_PLUS_PLUS] = ACTIONS(1969),
    [anon_sym_DASH_DASH] = ACTIONS(1969),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1967),
    [anon_sym_DASH] = ACTIONS(1967),
    [anon_sym_STAR] = ACTIONS(1971),
    [anon_sym_CARET] = ACTIONS(1969),
    [anon_sym_AMP] = ACTIONS(1969),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1973),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1975),
    [anon_sym_DOT_DOT] = ACTIONS(1977),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1728] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6916),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7061),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6254),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4369),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7437),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9284),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1728),
    [sym_preproc_endregion] = STATE(1728),
    [sym_preproc_line] = STATE(1728),
    [sym_preproc_pragma] = STATE(1728),
    [sym_preproc_nullable] = STATE(1728),
    [sym_preproc_error] = STATE(1728),
    [sym_preproc_warning] = STATE(1728),
    [sym_preproc_define] = STATE(1728),
    [sym_preproc_undef] = STATE(1728),
    [aux_sym_class_declaration_repeat1] = STATE(3839),
    [aux_sym_lambda_expression_repeat1] = STATE(4267),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1963),
    [anon_sym_ref] = ACTIONS(1965),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1969),
    [anon_sym_TILDE] = ACTIONS(1969),
    [anon_sym_PLUS_PLUS] = ACTIONS(1969),
    [anon_sym_DASH_DASH] = ACTIONS(1969),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1967),
    [anon_sym_DASH] = ACTIONS(1967),
    [anon_sym_STAR] = ACTIONS(1971),
    [anon_sym_CARET] = ACTIONS(1969),
    [anon_sym_AMP] = ACTIONS(1969),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1973),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1975),
    [anon_sym_DOT_DOT] = ACTIONS(1977),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1729] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6916),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7061),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6255),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4369),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7437),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9284),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1729),
    [sym_preproc_endregion] = STATE(1729),
    [sym_preproc_line] = STATE(1729),
    [sym_preproc_pragma] = STATE(1729),
    [sym_preproc_nullable] = STATE(1729),
    [sym_preproc_error] = STATE(1729),
    [sym_preproc_warning] = STATE(1729),
    [sym_preproc_define] = STATE(1729),
    [sym_preproc_undef] = STATE(1729),
    [aux_sym_class_declaration_repeat1] = STATE(3839),
    [aux_sym_lambda_expression_repeat1] = STATE(4267),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1963),
    [anon_sym_ref] = ACTIONS(1965),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1969),
    [anon_sym_TILDE] = ACTIONS(1969),
    [anon_sym_PLUS_PLUS] = ACTIONS(1969),
    [anon_sym_DASH_DASH] = ACTIONS(1969),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1967),
    [anon_sym_DASH] = ACTIONS(1967),
    [anon_sym_STAR] = ACTIONS(1971),
    [anon_sym_CARET] = ACTIONS(1969),
    [anon_sym_AMP] = ACTIONS(1969),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1973),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1975),
    [anon_sym_DOT_DOT] = ACTIONS(1977),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1730] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6916),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7061),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6256),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4369),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7437),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9284),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1730),
    [sym_preproc_endregion] = STATE(1730),
    [sym_preproc_line] = STATE(1730),
    [sym_preproc_pragma] = STATE(1730),
    [sym_preproc_nullable] = STATE(1730),
    [sym_preproc_error] = STATE(1730),
    [sym_preproc_warning] = STATE(1730),
    [sym_preproc_define] = STATE(1730),
    [sym_preproc_undef] = STATE(1730),
    [aux_sym_class_declaration_repeat1] = STATE(3839),
    [aux_sym_lambda_expression_repeat1] = STATE(4267),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1963),
    [anon_sym_ref] = ACTIONS(1965),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1969),
    [anon_sym_TILDE] = ACTIONS(1969),
    [anon_sym_PLUS_PLUS] = ACTIONS(1969),
    [anon_sym_DASH_DASH] = ACTIONS(1969),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1967),
    [anon_sym_DASH] = ACTIONS(1967),
    [anon_sym_STAR] = ACTIONS(1971),
    [anon_sym_CARET] = ACTIONS(1969),
    [anon_sym_AMP] = ACTIONS(1969),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1973),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1975),
    [anon_sym_DOT_DOT] = ACTIONS(1977),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1731] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6916),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7061),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6214),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4369),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7437),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9284),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1731),
    [sym_preproc_endregion] = STATE(1731),
    [sym_preproc_line] = STATE(1731),
    [sym_preproc_pragma] = STATE(1731),
    [sym_preproc_nullable] = STATE(1731),
    [sym_preproc_error] = STATE(1731),
    [sym_preproc_warning] = STATE(1731),
    [sym_preproc_define] = STATE(1731),
    [sym_preproc_undef] = STATE(1731),
    [aux_sym_class_declaration_repeat1] = STATE(3839),
    [aux_sym_lambda_expression_repeat1] = STATE(4267),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1963),
    [anon_sym_ref] = ACTIONS(1965),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1969),
    [anon_sym_TILDE] = ACTIONS(1969),
    [anon_sym_PLUS_PLUS] = ACTIONS(1969),
    [anon_sym_DASH_DASH] = ACTIONS(1969),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1967),
    [anon_sym_DASH] = ACTIONS(1967),
    [anon_sym_STAR] = ACTIONS(1971),
    [anon_sym_CARET] = ACTIONS(1969),
    [anon_sym_AMP] = ACTIONS(1969),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1973),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1975),
    [anon_sym_DOT_DOT] = ACTIONS(1977),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1732] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6916),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7061),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6215),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4369),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7437),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9284),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1732),
    [sym_preproc_endregion] = STATE(1732),
    [sym_preproc_line] = STATE(1732),
    [sym_preproc_pragma] = STATE(1732),
    [sym_preproc_nullable] = STATE(1732),
    [sym_preproc_error] = STATE(1732),
    [sym_preproc_warning] = STATE(1732),
    [sym_preproc_define] = STATE(1732),
    [sym_preproc_undef] = STATE(1732),
    [aux_sym_class_declaration_repeat1] = STATE(3839),
    [aux_sym_lambda_expression_repeat1] = STATE(4267),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1963),
    [anon_sym_ref] = ACTIONS(1965),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1969),
    [anon_sym_TILDE] = ACTIONS(1969),
    [anon_sym_PLUS_PLUS] = ACTIONS(1969),
    [anon_sym_DASH_DASH] = ACTIONS(1969),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1967),
    [anon_sym_DASH] = ACTIONS(1967),
    [anon_sym_STAR] = ACTIONS(1971),
    [anon_sym_CARET] = ACTIONS(1969),
    [anon_sym_AMP] = ACTIONS(1969),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1973),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1975),
    [anon_sym_DOT_DOT] = ACTIONS(1977),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1733] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6916),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7061),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6216),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4369),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7437),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9284),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1733),
    [sym_preproc_endregion] = STATE(1733),
    [sym_preproc_line] = STATE(1733),
    [sym_preproc_pragma] = STATE(1733),
    [sym_preproc_nullable] = STATE(1733),
    [sym_preproc_error] = STATE(1733),
    [sym_preproc_warning] = STATE(1733),
    [sym_preproc_define] = STATE(1733),
    [sym_preproc_undef] = STATE(1733),
    [aux_sym_class_declaration_repeat1] = STATE(3839),
    [aux_sym_lambda_expression_repeat1] = STATE(4267),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1963),
    [anon_sym_ref] = ACTIONS(1965),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1969),
    [anon_sym_TILDE] = ACTIONS(1969),
    [anon_sym_PLUS_PLUS] = ACTIONS(1969),
    [anon_sym_DASH_DASH] = ACTIONS(1969),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1967),
    [anon_sym_DASH] = ACTIONS(1967),
    [anon_sym_STAR] = ACTIONS(1971),
    [anon_sym_CARET] = ACTIONS(1969),
    [anon_sym_AMP] = ACTIONS(1969),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1973),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1975),
    [anon_sym_DOT_DOT] = ACTIONS(1977),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1734] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6916),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7061),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6257),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4369),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7437),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9284),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1734),
    [sym_preproc_endregion] = STATE(1734),
    [sym_preproc_line] = STATE(1734),
    [sym_preproc_pragma] = STATE(1734),
    [sym_preproc_nullable] = STATE(1734),
    [sym_preproc_error] = STATE(1734),
    [sym_preproc_warning] = STATE(1734),
    [sym_preproc_define] = STATE(1734),
    [sym_preproc_undef] = STATE(1734),
    [aux_sym_class_declaration_repeat1] = STATE(3839),
    [aux_sym_lambda_expression_repeat1] = STATE(4267),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1963),
    [anon_sym_ref] = ACTIONS(1965),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1969),
    [anon_sym_TILDE] = ACTIONS(1969),
    [anon_sym_PLUS_PLUS] = ACTIONS(1969),
    [anon_sym_DASH_DASH] = ACTIONS(1969),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1967),
    [anon_sym_DASH] = ACTIONS(1967),
    [anon_sym_STAR] = ACTIONS(1971),
    [anon_sym_CARET] = ACTIONS(1969),
    [anon_sym_AMP] = ACTIONS(1969),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1973),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1975),
    [anon_sym_DOT_DOT] = ACTIONS(1977),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1735] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6916),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7061),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6217),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4369),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7437),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9284),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1735),
    [sym_preproc_endregion] = STATE(1735),
    [sym_preproc_line] = STATE(1735),
    [sym_preproc_pragma] = STATE(1735),
    [sym_preproc_nullable] = STATE(1735),
    [sym_preproc_error] = STATE(1735),
    [sym_preproc_warning] = STATE(1735),
    [sym_preproc_define] = STATE(1735),
    [sym_preproc_undef] = STATE(1735),
    [aux_sym_class_declaration_repeat1] = STATE(3839),
    [aux_sym_lambda_expression_repeat1] = STATE(4267),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1963),
    [anon_sym_ref] = ACTIONS(1965),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1969),
    [anon_sym_TILDE] = ACTIONS(1969),
    [anon_sym_PLUS_PLUS] = ACTIONS(1969),
    [anon_sym_DASH_DASH] = ACTIONS(1969),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1967),
    [anon_sym_DASH] = ACTIONS(1967),
    [anon_sym_STAR] = ACTIONS(1971),
    [anon_sym_CARET] = ACTIONS(1969),
    [anon_sym_AMP] = ACTIONS(1969),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1973),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1975),
    [anon_sym_DOT_DOT] = ACTIONS(1977),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1736] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6916),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7061),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6218),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4369),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7437),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9284),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1736),
    [sym_preproc_endregion] = STATE(1736),
    [sym_preproc_line] = STATE(1736),
    [sym_preproc_pragma] = STATE(1736),
    [sym_preproc_nullable] = STATE(1736),
    [sym_preproc_error] = STATE(1736),
    [sym_preproc_warning] = STATE(1736),
    [sym_preproc_define] = STATE(1736),
    [sym_preproc_undef] = STATE(1736),
    [aux_sym_class_declaration_repeat1] = STATE(3839),
    [aux_sym_lambda_expression_repeat1] = STATE(4267),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1963),
    [anon_sym_ref] = ACTIONS(1965),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1969),
    [anon_sym_TILDE] = ACTIONS(1969),
    [anon_sym_PLUS_PLUS] = ACTIONS(1969),
    [anon_sym_DASH_DASH] = ACTIONS(1969),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1967),
    [anon_sym_DASH] = ACTIONS(1967),
    [anon_sym_STAR] = ACTIONS(1971),
    [anon_sym_CARET] = ACTIONS(1969),
    [anon_sym_AMP] = ACTIONS(1969),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1973),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1975),
    [anon_sym_DOT_DOT] = ACTIONS(1977),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1737] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6916),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7061),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6219),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4369),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7437),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9284),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1737),
    [sym_preproc_endregion] = STATE(1737),
    [sym_preproc_line] = STATE(1737),
    [sym_preproc_pragma] = STATE(1737),
    [sym_preproc_nullable] = STATE(1737),
    [sym_preproc_error] = STATE(1737),
    [sym_preproc_warning] = STATE(1737),
    [sym_preproc_define] = STATE(1737),
    [sym_preproc_undef] = STATE(1737),
    [aux_sym_class_declaration_repeat1] = STATE(3839),
    [aux_sym_lambda_expression_repeat1] = STATE(4267),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1963),
    [anon_sym_ref] = ACTIONS(1965),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1969),
    [anon_sym_TILDE] = ACTIONS(1969),
    [anon_sym_PLUS_PLUS] = ACTIONS(1969),
    [anon_sym_DASH_DASH] = ACTIONS(1969),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1967),
    [anon_sym_DASH] = ACTIONS(1967),
    [anon_sym_STAR] = ACTIONS(1971),
    [anon_sym_CARET] = ACTIONS(1969),
    [anon_sym_AMP] = ACTIONS(1969),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1973),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1975),
    [anon_sym_DOT_DOT] = ACTIONS(1977),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1738] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6916),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7061),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6220),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4369),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7437),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9284),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1738),
    [sym_preproc_endregion] = STATE(1738),
    [sym_preproc_line] = STATE(1738),
    [sym_preproc_pragma] = STATE(1738),
    [sym_preproc_nullable] = STATE(1738),
    [sym_preproc_error] = STATE(1738),
    [sym_preproc_warning] = STATE(1738),
    [sym_preproc_define] = STATE(1738),
    [sym_preproc_undef] = STATE(1738),
    [aux_sym_class_declaration_repeat1] = STATE(3839),
    [aux_sym_lambda_expression_repeat1] = STATE(4267),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1963),
    [anon_sym_ref] = ACTIONS(1965),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1969),
    [anon_sym_TILDE] = ACTIONS(1969),
    [anon_sym_PLUS_PLUS] = ACTIONS(1969),
    [anon_sym_DASH_DASH] = ACTIONS(1969),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1967),
    [anon_sym_DASH] = ACTIONS(1967),
    [anon_sym_STAR] = ACTIONS(1971),
    [anon_sym_CARET] = ACTIONS(1969),
    [anon_sym_AMP] = ACTIONS(1969),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1973),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1975),
    [anon_sym_DOT_DOT] = ACTIONS(1977),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1739] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6916),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7061),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3582),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4369),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7437),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9284),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1739),
    [sym_preproc_endregion] = STATE(1739),
    [sym_preproc_line] = STATE(1739),
    [sym_preproc_pragma] = STATE(1739),
    [sym_preproc_nullable] = STATE(1739),
    [sym_preproc_error] = STATE(1739),
    [sym_preproc_warning] = STATE(1739),
    [sym_preproc_define] = STATE(1739),
    [sym_preproc_undef] = STATE(1739),
    [aux_sym_class_declaration_repeat1] = STATE(3839),
    [aux_sym_lambda_expression_repeat1] = STATE(4267),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1963),
    [anon_sym_ref] = ACTIONS(1965),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1969),
    [anon_sym_TILDE] = ACTIONS(1969),
    [anon_sym_PLUS_PLUS] = ACTIONS(1969),
    [anon_sym_DASH_DASH] = ACTIONS(1969),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1967),
    [anon_sym_DASH] = ACTIONS(1967),
    [anon_sym_STAR] = ACTIONS(1971),
    [anon_sym_CARET] = ACTIONS(1969),
    [anon_sym_AMP] = ACTIONS(1969),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1973),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1975),
    [anon_sym_DOT_DOT] = ACTIONS(1977),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1740] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6920),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2942),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7032),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6086),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4337),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7427),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9283),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1740),
    [sym_preproc_endregion] = STATE(1740),
    [sym_preproc_line] = STATE(1740),
    [sym_preproc_pragma] = STATE(1740),
    [sym_preproc_nullable] = STATE(1740),
    [sym_preproc_error] = STATE(1740),
    [sym_preproc_warning] = STATE(1740),
    [sym_preproc_define] = STATE(1740),
    [sym_preproc_undef] = STATE(1740),
    [aux_sym_class_declaration_repeat1] = STATE(3829),
    [aux_sym_lambda_expression_repeat1] = STATE(4252),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1801),
    [anon_sym_ref] = ACTIONS(1803),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1805),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1809),
    [anon_sym_TILDE] = ACTIONS(1809),
    [anon_sym_PLUS_PLUS] = ACTIONS(1809),
    [anon_sym_DASH_DASH] = ACTIONS(1809),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1807),
    [anon_sym_DASH] = ACTIONS(1807),
    [anon_sym_STAR] = ACTIONS(1811),
    [anon_sym_CARET] = ACTIONS(1809),
    [anon_sym_AMP] = ACTIONS(1809),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1813),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1815),
    [anon_sym_DOT_DOT] = ACTIONS(1817),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1741] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6920),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2942),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7032),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3926),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4337),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7427),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9283),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1741),
    [sym_preproc_endregion] = STATE(1741),
    [sym_preproc_line] = STATE(1741),
    [sym_preproc_pragma] = STATE(1741),
    [sym_preproc_nullable] = STATE(1741),
    [sym_preproc_error] = STATE(1741),
    [sym_preproc_warning] = STATE(1741),
    [sym_preproc_define] = STATE(1741),
    [sym_preproc_undef] = STATE(1741),
    [aux_sym_class_declaration_repeat1] = STATE(3829),
    [aux_sym_lambda_expression_repeat1] = STATE(4252),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1801),
    [anon_sym_ref] = ACTIONS(1803),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1805),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1809),
    [anon_sym_TILDE] = ACTIONS(1809),
    [anon_sym_PLUS_PLUS] = ACTIONS(1809),
    [anon_sym_DASH_DASH] = ACTIONS(1809),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1807),
    [anon_sym_DASH] = ACTIONS(1807),
    [anon_sym_STAR] = ACTIONS(1811),
    [anon_sym_CARET] = ACTIONS(1809),
    [anon_sym_AMP] = ACTIONS(1809),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1813),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1815),
    [anon_sym_DOT_DOT] = ACTIONS(1817),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1742] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6920),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2942),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7032),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6088),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4337),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7427),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9283),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1742),
    [sym_preproc_endregion] = STATE(1742),
    [sym_preproc_line] = STATE(1742),
    [sym_preproc_pragma] = STATE(1742),
    [sym_preproc_nullable] = STATE(1742),
    [sym_preproc_error] = STATE(1742),
    [sym_preproc_warning] = STATE(1742),
    [sym_preproc_define] = STATE(1742),
    [sym_preproc_undef] = STATE(1742),
    [aux_sym_class_declaration_repeat1] = STATE(3829),
    [aux_sym_lambda_expression_repeat1] = STATE(4252),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1801),
    [anon_sym_ref] = ACTIONS(1803),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1805),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1809),
    [anon_sym_TILDE] = ACTIONS(1809),
    [anon_sym_PLUS_PLUS] = ACTIONS(1809),
    [anon_sym_DASH_DASH] = ACTIONS(1809),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1807),
    [anon_sym_DASH] = ACTIONS(1807),
    [anon_sym_STAR] = ACTIONS(1811),
    [anon_sym_CARET] = ACTIONS(1809),
    [anon_sym_AMP] = ACTIONS(1809),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1813),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1815),
    [anon_sym_DOT_DOT] = ACTIONS(1817),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1743] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6920),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2942),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7032),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6092),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4337),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7427),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9283),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1743),
    [sym_preproc_endregion] = STATE(1743),
    [sym_preproc_line] = STATE(1743),
    [sym_preproc_pragma] = STATE(1743),
    [sym_preproc_nullable] = STATE(1743),
    [sym_preproc_error] = STATE(1743),
    [sym_preproc_warning] = STATE(1743),
    [sym_preproc_define] = STATE(1743),
    [sym_preproc_undef] = STATE(1743),
    [aux_sym_class_declaration_repeat1] = STATE(3829),
    [aux_sym_lambda_expression_repeat1] = STATE(4252),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1801),
    [anon_sym_ref] = ACTIONS(1803),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1805),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1809),
    [anon_sym_TILDE] = ACTIONS(1809),
    [anon_sym_PLUS_PLUS] = ACTIONS(1809),
    [anon_sym_DASH_DASH] = ACTIONS(1809),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1807),
    [anon_sym_DASH] = ACTIONS(1807),
    [anon_sym_STAR] = ACTIONS(1811),
    [anon_sym_CARET] = ACTIONS(1809),
    [anon_sym_AMP] = ACTIONS(1809),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1813),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1815),
    [anon_sym_DOT_DOT] = ACTIONS(1817),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1744] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6933),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2950),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7095),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5686),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4215),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7446),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9108),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1744),
    [sym_preproc_endregion] = STATE(1744),
    [sym_preproc_line] = STATE(1744),
    [sym_preproc_pragma] = STATE(1744),
    [sym_preproc_nullable] = STATE(1744),
    [sym_preproc_error] = STATE(1744),
    [sym_preproc_warning] = STATE(1744),
    [sym_preproc_define] = STATE(1744),
    [sym_preproc_undef] = STATE(1744),
    [aux_sym_class_declaration_repeat1] = STATE(3848),
    [aux_sym_lambda_expression_repeat1] = STATE(4282),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1837),
    [anon_sym_ref] = ACTIONS(1839),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1841),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1845),
    [anon_sym_TILDE] = ACTIONS(1845),
    [anon_sym_PLUS_PLUS] = ACTIONS(1845),
    [anon_sym_DASH_DASH] = ACTIONS(1845),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1843),
    [anon_sym_DASH] = ACTIONS(1843),
    [anon_sym_STAR] = ACTIONS(1847),
    [anon_sym_CARET] = ACTIONS(1845),
    [anon_sym_AMP] = ACTIONS(1845),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1849),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1851),
    [anon_sym_DOT_DOT] = ACTIONS(1853),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1745] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6933),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2950),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7095),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3838),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4215),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7446),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9108),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1745),
    [sym_preproc_endregion] = STATE(1745),
    [sym_preproc_line] = STATE(1745),
    [sym_preproc_pragma] = STATE(1745),
    [sym_preproc_nullable] = STATE(1745),
    [sym_preproc_error] = STATE(1745),
    [sym_preproc_warning] = STATE(1745),
    [sym_preproc_define] = STATE(1745),
    [sym_preproc_undef] = STATE(1745),
    [aux_sym_class_declaration_repeat1] = STATE(3848),
    [aux_sym_lambda_expression_repeat1] = STATE(4282),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1837),
    [anon_sym_ref] = ACTIONS(1839),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1841),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1845),
    [anon_sym_TILDE] = ACTIONS(1845),
    [anon_sym_PLUS_PLUS] = ACTIONS(1845),
    [anon_sym_DASH_DASH] = ACTIONS(1845),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1843),
    [anon_sym_DASH] = ACTIONS(1843),
    [anon_sym_STAR] = ACTIONS(1847),
    [anon_sym_CARET] = ACTIONS(1845),
    [anon_sym_AMP] = ACTIONS(1845),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1849),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1851),
    [anon_sym_DOT_DOT] = ACTIONS(1853),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1746] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6933),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2950),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7095),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5532),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4215),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7446),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9108),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1746),
    [sym_preproc_endregion] = STATE(1746),
    [sym_preproc_line] = STATE(1746),
    [sym_preproc_pragma] = STATE(1746),
    [sym_preproc_nullable] = STATE(1746),
    [sym_preproc_error] = STATE(1746),
    [sym_preproc_warning] = STATE(1746),
    [sym_preproc_define] = STATE(1746),
    [sym_preproc_undef] = STATE(1746),
    [aux_sym_class_declaration_repeat1] = STATE(3848),
    [aux_sym_lambda_expression_repeat1] = STATE(4282),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1837),
    [anon_sym_ref] = ACTIONS(1839),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1841),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1845),
    [anon_sym_TILDE] = ACTIONS(1845),
    [anon_sym_PLUS_PLUS] = ACTIONS(1845),
    [anon_sym_DASH_DASH] = ACTIONS(1845),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1843),
    [anon_sym_DASH] = ACTIONS(1843),
    [anon_sym_STAR] = ACTIONS(1847),
    [anon_sym_CARET] = ACTIONS(1845),
    [anon_sym_AMP] = ACTIONS(1845),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1849),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1851),
    [anon_sym_DOT_DOT] = ACTIONS(1853),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1747] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6933),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2950),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7095),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5533),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4215),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7446),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9108),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1747),
    [sym_preproc_endregion] = STATE(1747),
    [sym_preproc_line] = STATE(1747),
    [sym_preproc_pragma] = STATE(1747),
    [sym_preproc_nullable] = STATE(1747),
    [sym_preproc_error] = STATE(1747),
    [sym_preproc_warning] = STATE(1747),
    [sym_preproc_define] = STATE(1747),
    [sym_preproc_undef] = STATE(1747),
    [aux_sym_class_declaration_repeat1] = STATE(3848),
    [aux_sym_lambda_expression_repeat1] = STATE(4282),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1837),
    [anon_sym_ref] = ACTIONS(1839),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1841),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1845),
    [anon_sym_TILDE] = ACTIONS(1845),
    [anon_sym_PLUS_PLUS] = ACTIONS(1845),
    [anon_sym_DASH_DASH] = ACTIONS(1845),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1843),
    [anon_sym_DASH] = ACTIONS(1843),
    [anon_sym_STAR] = ACTIONS(1847),
    [anon_sym_CARET] = ACTIONS(1845),
    [anon_sym_AMP] = ACTIONS(1845),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1849),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1851),
    [anon_sym_DOT_DOT] = ACTIONS(1853),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1748] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6933),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2950),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7095),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5715),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4215),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7446),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9108),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1748),
    [sym_preproc_endregion] = STATE(1748),
    [sym_preproc_line] = STATE(1748),
    [sym_preproc_pragma] = STATE(1748),
    [sym_preproc_nullable] = STATE(1748),
    [sym_preproc_error] = STATE(1748),
    [sym_preproc_warning] = STATE(1748),
    [sym_preproc_define] = STATE(1748),
    [sym_preproc_undef] = STATE(1748),
    [aux_sym_class_declaration_repeat1] = STATE(3848),
    [aux_sym_lambda_expression_repeat1] = STATE(4282),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1837),
    [anon_sym_ref] = ACTIONS(1839),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1841),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1845),
    [anon_sym_TILDE] = ACTIONS(1845),
    [anon_sym_PLUS_PLUS] = ACTIONS(1845),
    [anon_sym_DASH_DASH] = ACTIONS(1845),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1843),
    [anon_sym_DASH] = ACTIONS(1843),
    [anon_sym_STAR] = ACTIONS(1847),
    [anon_sym_CARET] = ACTIONS(1845),
    [anon_sym_AMP] = ACTIONS(1845),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1849),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1851),
    [anon_sym_DOT_DOT] = ACTIONS(1853),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1749] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6933),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2950),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7095),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5687),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4215),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7446),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9108),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1749),
    [sym_preproc_endregion] = STATE(1749),
    [sym_preproc_line] = STATE(1749),
    [sym_preproc_pragma] = STATE(1749),
    [sym_preproc_nullable] = STATE(1749),
    [sym_preproc_error] = STATE(1749),
    [sym_preproc_warning] = STATE(1749),
    [sym_preproc_define] = STATE(1749),
    [sym_preproc_undef] = STATE(1749),
    [aux_sym_class_declaration_repeat1] = STATE(3848),
    [aux_sym_lambda_expression_repeat1] = STATE(4282),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1837),
    [anon_sym_ref] = ACTIONS(1839),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1841),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1845),
    [anon_sym_TILDE] = ACTIONS(1845),
    [anon_sym_PLUS_PLUS] = ACTIONS(1845),
    [anon_sym_DASH_DASH] = ACTIONS(1845),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1843),
    [anon_sym_DASH] = ACTIONS(1843),
    [anon_sym_STAR] = ACTIONS(1847),
    [anon_sym_CARET] = ACTIONS(1845),
    [anon_sym_AMP] = ACTIONS(1845),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1849),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1851),
    [anon_sym_DOT_DOT] = ACTIONS(1853),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1750] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6933),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2950),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7095),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5688),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4215),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7446),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9108),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1750),
    [sym_preproc_endregion] = STATE(1750),
    [sym_preproc_line] = STATE(1750),
    [sym_preproc_pragma] = STATE(1750),
    [sym_preproc_nullable] = STATE(1750),
    [sym_preproc_error] = STATE(1750),
    [sym_preproc_warning] = STATE(1750),
    [sym_preproc_define] = STATE(1750),
    [sym_preproc_undef] = STATE(1750),
    [aux_sym_class_declaration_repeat1] = STATE(3848),
    [aux_sym_lambda_expression_repeat1] = STATE(4282),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1837),
    [anon_sym_ref] = ACTIONS(1839),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1841),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1845),
    [anon_sym_TILDE] = ACTIONS(1845),
    [anon_sym_PLUS_PLUS] = ACTIONS(1845),
    [anon_sym_DASH_DASH] = ACTIONS(1845),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1843),
    [anon_sym_DASH] = ACTIONS(1843),
    [anon_sym_STAR] = ACTIONS(1847),
    [anon_sym_CARET] = ACTIONS(1845),
    [anon_sym_AMP] = ACTIONS(1845),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1849),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1851),
    [anon_sym_DOT_DOT] = ACTIONS(1853),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1751] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6933),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2950),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7095),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5689),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4215),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7446),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9108),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1751),
    [sym_preproc_endregion] = STATE(1751),
    [sym_preproc_line] = STATE(1751),
    [sym_preproc_pragma] = STATE(1751),
    [sym_preproc_nullable] = STATE(1751),
    [sym_preproc_error] = STATE(1751),
    [sym_preproc_warning] = STATE(1751),
    [sym_preproc_define] = STATE(1751),
    [sym_preproc_undef] = STATE(1751),
    [aux_sym_class_declaration_repeat1] = STATE(3848),
    [aux_sym_lambda_expression_repeat1] = STATE(4282),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1837),
    [anon_sym_ref] = ACTIONS(1839),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1841),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1845),
    [anon_sym_TILDE] = ACTIONS(1845),
    [anon_sym_PLUS_PLUS] = ACTIONS(1845),
    [anon_sym_DASH_DASH] = ACTIONS(1845),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1843),
    [anon_sym_DASH] = ACTIONS(1843),
    [anon_sym_STAR] = ACTIONS(1847),
    [anon_sym_CARET] = ACTIONS(1845),
    [anon_sym_AMP] = ACTIONS(1845),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1849),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1851),
    [anon_sym_DOT_DOT] = ACTIONS(1853),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1752] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6933),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2950),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7095),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5534),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4215),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7446),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9108),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1752),
    [sym_preproc_endregion] = STATE(1752),
    [sym_preproc_line] = STATE(1752),
    [sym_preproc_pragma] = STATE(1752),
    [sym_preproc_nullable] = STATE(1752),
    [sym_preproc_error] = STATE(1752),
    [sym_preproc_warning] = STATE(1752),
    [sym_preproc_define] = STATE(1752),
    [sym_preproc_undef] = STATE(1752),
    [aux_sym_class_declaration_repeat1] = STATE(3848),
    [aux_sym_lambda_expression_repeat1] = STATE(4282),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1837),
    [anon_sym_ref] = ACTIONS(1839),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1841),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1845),
    [anon_sym_TILDE] = ACTIONS(1845),
    [anon_sym_PLUS_PLUS] = ACTIONS(1845),
    [anon_sym_DASH_DASH] = ACTIONS(1845),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1843),
    [anon_sym_DASH] = ACTIONS(1843),
    [anon_sym_STAR] = ACTIONS(1847),
    [anon_sym_CARET] = ACTIONS(1845),
    [anon_sym_AMP] = ACTIONS(1845),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1849),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1851),
    [anon_sym_DOT_DOT] = ACTIONS(1853),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1753] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6933),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2950),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7095),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5690),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4215),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7446),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9108),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1753),
    [sym_preproc_endregion] = STATE(1753),
    [sym_preproc_line] = STATE(1753),
    [sym_preproc_pragma] = STATE(1753),
    [sym_preproc_nullable] = STATE(1753),
    [sym_preproc_error] = STATE(1753),
    [sym_preproc_warning] = STATE(1753),
    [sym_preproc_define] = STATE(1753),
    [sym_preproc_undef] = STATE(1753),
    [aux_sym_class_declaration_repeat1] = STATE(3848),
    [aux_sym_lambda_expression_repeat1] = STATE(4282),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1837),
    [anon_sym_ref] = ACTIONS(1839),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1841),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1845),
    [anon_sym_TILDE] = ACTIONS(1845),
    [anon_sym_PLUS_PLUS] = ACTIONS(1845),
    [anon_sym_DASH_DASH] = ACTIONS(1845),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1843),
    [anon_sym_DASH] = ACTIONS(1843),
    [anon_sym_STAR] = ACTIONS(1847),
    [anon_sym_CARET] = ACTIONS(1845),
    [anon_sym_AMP] = ACTIONS(1845),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1849),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1851),
    [anon_sym_DOT_DOT] = ACTIONS(1853),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1754] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6933),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2950),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7095),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5691),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4215),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7446),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9108),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1754),
    [sym_preproc_endregion] = STATE(1754),
    [sym_preproc_line] = STATE(1754),
    [sym_preproc_pragma] = STATE(1754),
    [sym_preproc_nullable] = STATE(1754),
    [sym_preproc_error] = STATE(1754),
    [sym_preproc_warning] = STATE(1754),
    [sym_preproc_define] = STATE(1754),
    [sym_preproc_undef] = STATE(1754),
    [aux_sym_class_declaration_repeat1] = STATE(3848),
    [aux_sym_lambda_expression_repeat1] = STATE(4282),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1837),
    [anon_sym_ref] = ACTIONS(1839),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1841),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1845),
    [anon_sym_TILDE] = ACTIONS(1845),
    [anon_sym_PLUS_PLUS] = ACTIONS(1845),
    [anon_sym_DASH_DASH] = ACTIONS(1845),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1843),
    [anon_sym_DASH] = ACTIONS(1843),
    [anon_sym_STAR] = ACTIONS(1847),
    [anon_sym_CARET] = ACTIONS(1845),
    [anon_sym_AMP] = ACTIONS(1845),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1849),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1851),
    [anon_sym_DOT_DOT] = ACTIONS(1853),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1755] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6933),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2950),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7095),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5692),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4215),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7446),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9108),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1755),
    [sym_preproc_endregion] = STATE(1755),
    [sym_preproc_line] = STATE(1755),
    [sym_preproc_pragma] = STATE(1755),
    [sym_preproc_nullable] = STATE(1755),
    [sym_preproc_error] = STATE(1755),
    [sym_preproc_warning] = STATE(1755),
    [sym_preproc_define] = STATE(1755),
    [sym_preproc_undef] = STATE(1755),
    [aux_sym_class_declaration_repeat1] = STATE(3848),
    [aux_sym_lambda_expression_repeat1] = STATE(4282),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1837),
    [anon_sym_ref] = ACTIONS(1839),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1841),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1845),
    [anon_sym_TILDE] = ACTIONS(1845),
    [anon_sym_PLUS_PLUS] = ACTIONS(1845),
    [anon_sym_DASH_DASH] = ACTIONS(1845),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1843),
    [anon_sym_DASH] = ACTIONS(1843),
    [anon_sym_STAR] = ACTIONS(1847),
    [anon_sym_CARET] = ACTIONS(1845),
    [anon_sym_AMP] = ACTIONS(1845),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1849),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1851),
    [anon_sym_DOT_DOT] = ACTIONS(1853),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1756] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6933),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2950),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7095),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5693),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4215),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7446),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9108),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1756),
    [sym_preproc_endregion] = STATE(1756),
    [sym_preproc_line] = STATE(1756),
    [sym_preproc_pragma] = STATE(1756),
    [sym_preproc_nullable] = STATE(1756),
    [sym_preproc_error] = STATE(1756),
    [sym_preproc_warning] = STATE(1756),
    [sym_preproc_define] = STATE(1756),
    [sym_preproc_undef] = STATE(1756),
    [aux_sym_class_declaration_repeat1] = STATE(3848),
    [aux_sym_lambda_expression_repeat1] = STATE(4282),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1837),
    [anon_sym_ref] = ACTIONS(1839),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1841),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1845),
    [anon_sym_TILDE] = ACTIONS(1845),
    [anon_sym_PLUS_PLUS] = ACTIONS(1845),
    [anon_sym_DASH_DASH] = ACTIONS(1845),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1843),
    [anon_sym_DASH] = ACTIONS(1843),
    [anon_sym_STAR] = ACTIONS(1847),
    [anon_sym_CARET] = ACTIONS(1845),
    [anon_sym_AMP] = ACTIONS(1845),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1849),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1851),
    [anon_sym_DOT_DOT] = ACTIONS(1853),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1757] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6933),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2950),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7095),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5694),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4215),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7446),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9108),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1757),
    [sym_preproc_endregion] = STATE(1757),
    [sym_preproc_line] = STATE(1757),
    [sym_preproc_pragma] = STATE(1757),
    [sym_preproc_nullable] = STATE(1757),
    [sym_preproc_error] = STATE(1757),
    [sym_preproc_warning] = STATE(1757),
    [sym_preproc_define] = STATE(1757),
    [sym_preproc_undef] = STATE(1757),
    [aux_sym_class_declaration_repeat1] = STATE(3848),
    [aux_sym_lambda_expression_repeat1] = STATE(4282),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1837),
    [anon_sym_ref] = ACTIONS(1839),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1841),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1845),
    [anon_sym_TILDE] = ACTIONS(1845),
    [anon_sym_PLUS_PLUS] = ACTIONS(1845),
    [anon_sym_DASH_DASH] = ACTIONS(1845),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1843),
    [anon_sym_DASH] = ACTIONS(1843),
    [anon_sym_STAR] = ACTIONS(1847),
    [anon_sym_CARET] = ACTIONS(1845),
    [anon_sym_AMP] = ACTIONS(1845),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1849),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1851),
    [anon_sym_DOT_DOT] = ACTIONS(1853),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1758] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6933),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2950),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7095),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3867),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4215),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7446),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9108),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1758),
    [sym_preproc_endregion] = STATE(1758),
    [sym_preproc_line] = STATE(1758),
    [sym_preproc_pragma] = STATE(1758),
    [sym_preproc_nullable] = STATE(1758),
    [sym_preproc_error] = STATE(1758),
    [sym_preproc_warning] = STATE(1758),
    [sym_preproc_define] = STATE(1758),
    [sym_preproc_undef] = STATE(1758),
    [aux_sym_class_declaration_repeat1] = STATE(3848),
    [aux_sym_lambda_expression_repeat1] = STATE(4282),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1837),
    [anon_sym_ref] = ACTIONS(1839),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1841),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1845),
    [anon_sym_TILDE] = ACTIONS(1845),
    [anon_sym_PLUS_PLUS] = ACTIONS(1845),
    [anon_sym_DASH_DASH] = ACTIONS(1845),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1843),
    [anon_sym_DASH] = ACTIONS(1843),
    [anon_sym_STAR] = ACTIONS(1847),
    [anon_sym_CARET] = ACTIONS(1845),
    [anon_sym_AMP] = ACTIONS(1845),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1849),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1851),
    [anon_sym_DOT_DOT] = ACTIONS(1853),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1759] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6933),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2950),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7095),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5698),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4215),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7446),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9108),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1759),
    [sym_preproc_endregion] = STATE(1759),
    [sym_preproc_line] = STATE(1759),
    [sym_preproc_pragma] = STATE(1759),
    [sym_preproc_nullable] = STATE(1759),
    [sym_preproc_error] = STATE(1759),
    [sym_preproc_warning] = STATE(1759),
    [sym_preproc_define] = STATE(1759),
    [sym_preproc_undef] = STATE(1759),
    [aux_sym_class_declaration_repeat1] = STATE(3848),
    [aux_sym_lambda_expression_repeat1] = STATE(4282),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1837),
    [anon_sym_ref] = ACTIONS(1839),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1841),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1845),
    [anon_sym_TILDE] = ACTIONS(1845),
    [anon_sym_PLUS_PLUS] = ACTIONS(1845),
    [anon_sym_DASH_DASH] = ACTIONS(1845),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1843),
    [anon_sym_DASH] = ACTIONS(1843),
    [anon_sym_STAR] = ACTIONS(1847),
    [anon_sym_CARET] = ACTIONS(1845),
    [anon_sym_AMP] = ACTIONS(1845),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1849),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1851),
    [anon_sym_DOT_DOT] = ACTIONS(1853),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1760] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6916),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7128),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3561),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3752),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7413),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9092),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1760),
    [sym_preproc_endregion] = STATE(1760),
    [sym_preproc_line] = STATE(1760),
    [sym_preproc_pragma] = STATE(1760),
    [sym_preproc_nullable] = STATE(1760),
    [sym_preproc_error] = STATE(1760),
    [sym_preproc_warning] = STATE(1760),
    [sym_preproc_define] = STATE(1760),
    [sym_preproc_undef] = STATE(1760),
    [aux_sym_class_declaration_repeat1] = STATE(3845),
    [aux_sym_lambda_expression_repeat1] = STATE(4181),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1241),
    [anon_sym_ref] = ACTIONS(1243),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1255),
    [anon_sym_TILDE] = ACTIONS(1255),
    [anon_sym_PLUS_PLUS] = ACTIONS(1255),
    [anon_sym_DASH_DASH] = ACTIONS(1255),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1253),
    [anon_sym_DASH] = ACTIONS(1253),
    [anon_sym_STAR] = ACTIONS(1259),
    [anon_sym_CARET] = ACTIONS(1255),
    [anon_sym_AMP] = ACTIONS(1255),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1269),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1271),
    [anon_sym_DOT_DOT] = ACTIONS(1273),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1761] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7105),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6713),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3500),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1761),
    [sym_preproc_endregion] = STATE(1761),
    [sym_preproc_line] = STATE(1761),
    [sym_preproc_pragma] = STATE(1761),
    [sym_preproc_nullable] = STATE(1761),
    [sym_preproc_error] = STATE(1761),
    [sym_preproc_warning] = STATE(1761),
    [sym_preproc_define] = STATE(1761),
    [sym_preproc_undef] = STATE(1761),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(2983),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(1381),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1762] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6943),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2986),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7151),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6418),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4518),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7441),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9110),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1762),
    [sym_preproc_endregion] = STATE(1762),
    [sym_preproc_line] = STATE(1762),
    [sym_preproc_pragma] = STATE(1762),
    [sym_preproc_nullable] = STATE(1762),
    [sym_preproc_error] = STATE(1762),
    [sym_preproc_warning] = STATE(1762),
    [sym_preproc_define] = STATE(1762),
    [sym_preproc_undef] = STATE(1762),
    [aux_sym_class_declaration_repeat1] = STATE(3875),
    [aux_sym_lambda_expression_repeat1] = STATE(4315),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2169),
    [anon_sym_ref] = ACTIONS(2171),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2173),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2177),
    [anon_sym_TILDE] = ACTIONS(2177),
    [anon_sym_PLUS_PLUS] = ACTIONS(2177),
    [anon_sym_DASH_DASH] = ACTIONS(2177),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2175),
    [anon_sym_DASH] = ACTIONS(2175),
    [anon_sym_STAR] = ACTIONS(2179),
    [anon_sym_CARET] = ACTIONS(2177),
    [anon_sym_AMP] = ACTIONS(2177),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2181),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2183),
    [anon_sym_DOT_DOT] = ACTIONS(2185),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1763] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6943),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2986),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7151),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4336),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4518),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7441),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9110),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1763),
    [sym_preproc_endregion] = STATE(1763),
    [sym_preproc_line] = STATE(1763),
    [sym_preproc_pragma] = STATE(1763),
    [sym_preproc_nullable] = STATE(1763),
    [sym_preproc_error] = STATE(1763),
    [sym_preproc_warning] = STATE(1763),
    [sym_preproc_define] = STATE(1763),
    [sym_preproc_undef] = STATE(1763),
    [aux_sym_class_declaration_repeat1] = STATE(3875),
    [aux_sym_lambda_expression_repeat1] = STATE(4315),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2169),
    [anon_sym_ref] = ACTIONS(2171),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2173),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2177),
    [anon_sym_TILDE] = ACTIONS(2177),
    [anon_sym_PLUS_PLUS] = ACTIONS(2177),
    [anon_sym_DASH_DASH] = ACTIONS(2177),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2175),
    [anon_sym_DASH] = ACTIONS(2175),
    [anon_sym_STAR] = ACTIONS(2179),
    [anon_sym_CARET] = ACTIONS(2177),
    [anon_sym_AMP] = ACTIONS(2177),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2181),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2183),
    [anon_sym_DOT_DOT] = ACTIONS(2185),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1764] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6943),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2986),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7151),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6501),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4518),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7441),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9110),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1764),
    [sym_preproc_endregion] = STATE(1764),
    [sym_preproc_line] = STATE(1764),
    [sym_preproc_pragma] = STATE(1764),
    [sym_preproc_nullable] = STATE(1764),
    [sym_preproc_error] = STATE(1764),
    [sym_preproc_warning] = STATE(1764),
    [sym_preproc_define] = STATE(1764),
    [sym_preproc_undef] = STATE(1764),
    [aux_sym_class_declaration_repeat1] = STATE(3875),
    [aux_sym_lambda_expression_repeat1] = STATE(4315),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2169),
    [anon_sym_ref] = ACTIONS(2171),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2173),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2177),
    [anon_sym_TILDE] = ACTIONS(2177),
    [anon_sym_PLUS_PLUS] = ACTIONS(2177),
    [anon_sym_DASH_DASH] = ACTIONS(2177),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2175),
    [anon_sym_DASH] = ACTIONS(2175),
    [anon_sym_STAR] = ACTIONS(2179),
    [anon_sym_CARET] = ACTIONS(2177),
    [anon_sym_AMP] = ACTIONS(2177),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2181),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2183),
    [anon_sym_DOT_DOT] = ACTIONS(2185),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1765] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6943),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2986),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7151),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6503),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4518),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7441),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9110),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1765),
    [sym_preproc_endregion] = STATE(1765),
    [sym_preproc_line] = STATE(1765),
    [sym_preproc_pragma] = STATE(1765),
    [sym_preproc_nullable] = STATE(1765),
    [sym_preproc_error] = STATE(1765),
    [sym_preproc_warning] = STATE(1765),
    [sym_preproc_define] = STATE(1765),
    [sym_preproc_undef] = STATE(1765),
    [aux_sym_class_declaration_repeat1] = STATE(3875),
    [aux_sym_lambda_expression_repeat1] = STATE(4315),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2169),
    [anon_sym_ref] = ACTIONS(2171),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2173),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2177),
    [anon_sym_TILDE] = ACTIONS(2177),
    [anon_sym_PLUS_PLUS] = ACTIONS(2177),
    [anon_sym_DASH_DASH] = ACTIONS(2177),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2175),
    [anon_sym_DASH] = ACTIONS(2175),
    [anon_sym_STAR] = ACTIONS(2179),
    [anon_sym_CARET] = ACTIONS(2177),
    [anon_sym_AMP] = ACTIONS(2177),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2181),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2183),
    [anon_sym_DOT_DOT] = ACTIONS(2185),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1766] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6943),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2986),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7151),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6504),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4518),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7441),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9110),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1766),
    [sym_preproc_endregion] = STATE(1766),
    [sym_preproc_line] = STATE(1766),
    [sym_preproc_pragma] = STATE(1766),
    [sym_preproc_nullable] = STATE(1766),
    [sym_preproc_error] = STATE(1766),
    [sym_preproc_warning] = STATE(1766),
    [sym_preproc_define] = STATE(1766),
    [sym_preproc_undef] = STATE(1766),
    [aux_sym_class_declaration_repeat1] = STATE(3875),
    [aux_sym_lambda_expression_repeat1] = STATE(4315),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2169),
    [anon_sym_ref] = ACTIONS(2171),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2173),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2177),
    [anon_sym_TILDE] = ACTIONS(2177),
    [anon_sym_PLUS_PLUS] = ACTIONS(2177),
    [anon_sym_DASH_DASH] = ACTIONS(2177),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2175),
    [anon_sym_DASH] = ACTIONS(2175),
    [anon_sym_STAR] = ACTIONS(2179),
    [anon_sym_CARET] = ACTIONS(2177),
    [anon_sym_AMP] = ACTIONS(2177),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2181),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2183),
    [anon_sym_DOT_DOT] = ACTIONS(2185),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1767] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6943),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2986),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7151),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6505),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4518),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7441),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9110),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1767),
    [sym_preproc_endregion] = STATE(1767),
    [sym_preproc_line] = STATE(1767),
    [sym_preproc_pragma] = STATE(1767),
    [sym_preproc_nullable] = STATE(1767),
    [sym_preproc_error] = STATE(1767),
    [sym_preproc_warning] = STATE(1767),
    [sym_preproc_define] = STATE(1767),
    [sym_preproc_undef] = STATE(1767),
    [aux_sym_class_declaration_repeat1] = STATE(3875),
    [aux_sym_lambda_expression_repeat1] = STATE(4315),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2169),
    [anon_sym_ref] = ACTIONS(2171),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2173),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2177),
    [anon_sym_TILDE] = ACTIONS(2177),
    [anon_sym_PLUS_PLUS] = ACTIONS(2177),
    [anon_sym_DASH_DASH] = ACTIONS(2177),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2175),
    [anon_sym_DASH] = ACTIONS(2175),
    [anon_sym_STAR] = ACTIONS(2179),
    [anon_sym_CARET] = ACTIONS(2177),
    [anon_sym_AMP] = ACTIONS(2177),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2181),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2183),
    [anon_sym_DOT_DOT] = ACTIONS(2185),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1768] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6943),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2986),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7151),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6506),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4518),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7441),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9110),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1768),
    [sym_preproc_endregion] = STATE(1768),
    [sym_preproc_line] = STATE(1768),
    [sym_preproc_pragma] = STATE(1768),
    [sym_preproc_nullable] = STATE(1768),
    [sym_preproc_error] = STATE(1768),
    [sym_preproc_warning] = STATE(1768),
    [sym_preproc_define] = STATE(1768),
    [sym_preproc_undef] = STATE(1768),
    [aux_sym_class_declaration_repeat1] = STATE(3875),
    [aux_sym_lambda_expression_repeat1] = STATE(4315),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2169),
    [anon_sym_ref] = ACTIONS(2171),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2173),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2177),
    [anon_sym_TILDE] = ACTIONS(2177),
    [anon_sym_PLUS_PLUS] = ACTIONS(2177),
    [anon_sym_DASH_DASH] = ACTIONS(2177),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2175),
    [anon_sym_DASH] = ACTIONS(2175),
    [anon_sym_STAR] = ACTIONS(2179),
    [anon_sym_CARET] = ACTIONS(2177),
    [anon_sym_AMP] = ACTIONS(2177),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2181),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2183),
    [anon_sym_DOT_DOT] = ACTIONS(2185),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1769] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6943),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2986),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7151),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6507),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4518),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7441),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9110),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1769),
    [sym_preproc_endregion] = STATE(1769),
    [sym_preproc_line] = STATE(1769),
    [sym_preproc_pragma] = STATE(1769),
    [sym_preproc_nullable] = STATE(1769),
    [sym_preproc_error] = STATE(1769),
    [sym_preproc_warning] = STATE(1769),
    [sym_preproc_define] = STATE(1769),
    [sym_preproc_undef] = STATE(1769),
    [aux_sym_class_declaration_repeat1] = STATE(3875),
    [aux_sym_lambda_expression_repeat1] = STATE(4315),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2169),
    [anon_sym_ref] = ACTIONS(2171),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2173),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2177),
    [anon_sym_TILDE] = ACTIONS(2177),
    [anon_sym_PLUS_PLUS] = ACTIONS(2177),
    [anon_sym_DASH_DASH] = ACTIONS(2177),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2175),
    [anon_sym_DASH] = ACTIONS(2175),
    [anon_sym_STAR] = ACTIONS(2179),
    [anon_sym_CARET] = ACTIONS(2177),
    [anon_sym_AMP] = ACTIONS(2177),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2181),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2183),
    [anon_sym_DOT_DOT] = ACTIONS(2185),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1770] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6943),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2986),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7151),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6508),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4518),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7441),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9110),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1770),
    [sym_preproc_endregion] = STATE(1770),
    [sym_preproc_line] = STATE(1770),
    [sym_preproc_pragma] = STATE(1770),
    [sym_preproc_nullable] = STATE(1770),
    [sym_preproc_error] = STATE(1770),
    [sym_preproc_warning] = STATE(1770),
    [sym_preproc_define] = STATE(1770),
    [sym_preproc_undef] = STATE(1770),
    [aux_sym_class_declaration_repeat1] = STATE(3875),
    [aux_sym_lambda_expression_repeat1] = STATE(4315),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2169),
    [anon_sym_ref] = ACTIONS(2171),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2173),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2177),
    [anon_sym_TILDE] = ACTIONS(2177),
    [anon_sym_PLUS_PLUS] = ACTIONS(2177),
    [anon_sym_DASH_DASH] = ACTIONS(2177),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2175),
    [anon_sym_DASH] = ACTIONS(2175),
    [anon_sym_STAR] = ACTIONS(2179),
    [anon_sym_CARET] = ACTIONS(2177),
    [anon_sym_AMP] = ACTIONS(2177),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2181),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2183),
    [anon_sym_DOT_DOT] = ACTIONS(2185),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1771] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6943),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2986),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7151),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6509),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4518),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7441),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9110),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1771),
    [sym_preproc_endregion] = STATE(1771),
    [sym_preproc_line] = STATE(1771),
    [sym_preproc_pragma] = STATE(1771),
    [sym_preproc_nullable] = STATE(1771),
    [sym_preproc_error] = STATE(1771),
    [sym_preproc_warning] = STATE(1771),
    [sym_preproc_define] = STATE(1771),
    [sym_preproc_undef] = STATE(1771),
    [aux_sym_class_declaration_repeat1] = STATE(3875),
    [aux_sym_lambda_expression_repeat1] = STATE(4315),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2169),
    [anon_sym_ref] = ACTIONS(2171),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2173),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2177),
    [anon_sym_TILDE] = ACTIONS(2177),
    [anon_sym_PLUS_PLUS] = ACTIONS(2177),
    [anon_sym_DASH_DASH] = ACTIONS(2177),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2175),
    [anon_sym_DASH] = ACTIONS(2175),
    [anon_sym_STAR] = ACTIONS(2179),
    [anon_sym_CARET] = ACTIONS(2177),
    [anon_sym_AMP] = ACTIONS(2177),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2181),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2183),
    [anon_sym_DOT_DOT] = ACTIONS(2185),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1772] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6943),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2986),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7151),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6511),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4518),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7441),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9110),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1772),
    [sym_preproc_endregion] = STATE(1772),
    [sym_preproc_line] = STATE(1772),
    [sym_preproc_pragma] = STATE(1772),
    [sym_preproc_nullable] = STATE(1772),
    [sym_preproc_error] = STATE(1772),
    [sym_preproc_warning] = STATE(1772),
    [sym_preproc_define] = STATE(1772),
    [sym_preproc_undef] = STATE(1772),
    [aux_sym_class_declaration_repeat1] = STATE(3875),
    [aux_sym_lambda_expression_repeat1] = STATE(4315),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2169),
    [anon_sym_ref] = ACTIONS(2171),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2173),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2177),
    [anon_sym_TILDE] = ACTIONS(2177),
    [anon_sym_PLUS_PLUS] = ACTIONS(2177),
    [anon_sym_DASH_DASH] = ACTIONS(2177),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2175),
    [anon_sym_DASH] = ACTIONS(2175),
    [anon_sym_STAR] = ACTIONS(2179),
    [anon_sym_CARET] = ACTIONS(2177),
    [anon_sym_AMP] = ACTIONS(2177),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2181),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2183),
    [anon_sym_DOT_DOT] = ACTIONS(2185),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1773] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6943),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2986),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7151),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6512),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4518),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7441),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9110),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1773),
    [sym_preproc_endregion] = STATE(1773),
    [sym_preproc_line] = STATE(1773),
    [sym_preproc_pragma] = STATE(1773),
    [sym_preproc_nullable] = STATE(1773),
    [sym_preproc_error] = STATE(1773),
    [sym_preproc_warning] = STATE(1773),
    [sym_preproc_define] = STATE(1773),
    [sym_preproc_undef] = STATE(1773),
    [aux_sym_class_declaration_repeat1] = STATE(3875),
    [aux_sym_lambda_expression_repeat1] = STATE(4315),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2169),
    [anon_sym_ref] = ACTIONS(2171),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2173),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2177),
    [anon_sym_TILDE] = ACTIONS(2177),
    [anon_sym_PLUS_PLUS] = ACTIONS(2177),
    [anon_sym_DASH_DASH] = ACTIONS(2177),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2175),
    [anon_sym_DASH] = ACTIONS(2175),
    [anon_sym_STAR] = ACTIONS(2179),
    [anon_sym_CARET] = ACTIONS(2177),
    [anon_sym_AMP] = ACTIONS(2177),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2181),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2183),
    [anon_sym_DOT_DOT] = ACTIONS(2185),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1774] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6943),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2986),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7151),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6513),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4518),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7441),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9110),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1774),
    [sym_preproc_endregion] = STATE(1774),
    [sym_preproc_line] = STATE(1774),
    [sym_preproc_pragma] = STATE(1774),
    [sym_preproc_nullable] = STATE(1774),
    [sym_preproc_error] = STATE(1774),
    [sym_preproc_warning] = STATE(1774),
    [sym_preproc_define] = STATE(1774),
    [sym_preproc_undef] = STATE(1774),
    [aux_sym_class_declaration_repeat1] = STATE(3875),
    [aux_sym_lambda_expression_repeat1] = STATE(4315),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2169),
    [anon_sym_ref] = ACTIONS(2171),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2173),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2177),
    [anon_sym_TILDE] = ACTIONS(2177),
    [anon_sym_PLUS_PLUS] = ACTIONS(2177),
    [anon_sym_DASH_DASH] = ACTIONS(2177),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2175),
    [anon_sym_DASH] = ACTIONS(2175),
    [anon_sym_STAR] = ACTIONS(2179),
    [anon_sym_CARET] = ACTIONS(2177),
    [anon_sym_AMP] = ACTIONS(2177),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2181),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2183),
    [anon_sym_DOT_DOT] = ACTIONS(2185),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1775] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6943),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2986),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7151),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6447),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4518),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7441),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9110),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1775),
    [sym_preproc_endregion] = STATE(1775),
    [sym_preproc_line] = STATE(1775),
    [sym_preproc_pragma] = STATE(1775),
    [sym_preproc_nullable] = STATE(1775),
    [sym_preproc_error] = STATE(1775),
    [sym_preproc_warning] = STATE(1775),
    [sym_preproc_define] = STATE(1775),
    [sym_preproc_undef] = STATE(1775),
    [aux_sym_class_declaration_repeat1] = STATE(3875),
    [aux_sym_lambda_expression_repeat1] = STATE(4315),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2169),
    [anon_sym_ref] = ACTIONS(2171),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2173),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2177),
    [anon_sym_TILDE] = ACTIONS(2177),
    [anon_sym_PLUS_PLUS] = ACTIONS(2177),
    [anon_sym_DASH_DASH] = ACTIONS(2177),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2175),
    [anon_sym_DASH] = ACTIONS(2175),
    [anon_sym_STAR] = ACTIONS(2179),
    [anon_sym_CARET] = ACTIONS(2177),
    [anon_sym_AMP] = ACTIONS(2177),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2181),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2183),
    [anon_sym_DOT_DOT] = ACTIONS(2185),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1776] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6950),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7044),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5104),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3868),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7432),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9127),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1776),
    [sym_preproc_endregion] = STATE(1776),
    [sym_preproc_line] = STATE(1776),
    [sym_preproc_pragma] = STATE(1776),
    [sym_preproc_nullable] = STATE(1776),
    [sym_preproc_error] = STATE(1776),
    [sym_preproc_warning] = STATE(1776),
    [sym_preproc_define] = STATE(1776),
    [sym_preproc_undef] = STATE(1776),
    [aux_sym_class_declaration_repeat1] = STATE(3832),
    [aux_sym_lambda_expression_repeat1] = STATE(4259),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1357),
    [anon_sym_ref] = ACTIONS(1359),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1363),
    [anon_sym_TILDE] = ACTIONS(1363),
    [anon_sym_PLUS_PLUS] = ACTIONS(1363),
    [anon_sym_DASH_DASH] = ACTIONS(1363),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1361),
    [anon_sym_DASH] = ACTIONS(1361),
    [anon_sym_STAR] = ACTIONS(1365),
    [anon_sym_CARET] = ACTIONS(1363),
    [anon_sym_AMP] = ACTIONS(1363),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1367),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1369),
    [anon_sym_DOT_DOT] = ACTIONS(1371),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1777] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6943),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2986),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7151),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4338),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4518),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7441),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9110),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1777),
    [sym_preproc_endregion] = STATE(1777),
    [sym_preproc_line] = STATE(1777),
    [sym_preproc_pragma] = STATE(1777),
    [sym_preproc_nullable] = STATE(1777),
    [sym_preproc_error] = STATE(1777),
    [sym_preproc_warning] = STATE(1777),
    [sym_preproc_define] = STATE(1777),
    [sym_preproc_undef] = STATE(1777),
    [aux_sym_class_declaration_repeat1] = STATE(3875),
    [aux_sym_lambda_expression_repeat1] = STATE(4315),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2169),
    [anon_sym_ref] = ACTIONS(2171),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2173),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2177),
    [anon_sym_TILDE] = ACTIONS(2177),
    [anon_sym_PLUS_PLUS] = ACTIONS(2177),
    [anon_sym_DASH_DASH] = ACTIONS(2177),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2175),
    [anon_sym_DASH] = ACTIONS(2175),
    [anon_sym_STAR] = ACTIONS(2179),
    [anon_sym_CARET] = ACTIONS(2177),
    [anon_sym_AMP] = ACTIONS(2177),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2181),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2183),
    [anon_sym_DOT_DOT] = ACTIONS(2185),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1778] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6943),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2986),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7065),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6056),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4342),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7419),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9334),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1778),
    [sym_preproc_endregion] = STATE(1778),
    [sym_preproc_line] = STATE(1778),
    [sym_preproc_pragma] = STATE(1778),
    [sym_preproc_nullable] = STATE(1778),
    [sym_preproc_error] = STATE(1778),
    [sym_preproc_warning] = STATE(1778),
    [sym_preproc_define] = STATE(1778),
    [sym_preproc_undef] = STATE(1778),
    [aux_sym_class_declaration_repeat1] = STATE(3840),
    [aux_sym_lambda_expression_repeat1] = STATE(4269),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1855),
    [anon_sym_ref] = ACTIONS(1857),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1859),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1863),
    [anon_sym_TILDE] = ACTIONS(1863),
    [anon_sym_PLUS_PLUS] = ACTIONS(1863),
    [anon_sym_DASH_DASH] = ACTIONS(1863),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1861),
    [anon_sym_DASH] = ACTIONS(1861),
    [anon_sym_STAR] = ACTIONS(1865),
    [anon_sym_CARET] = ACTIONS(1863),
    [anon_sym_AMP] = ACTIONS(1863),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1867),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1869),
    [anon_sym_DOT_DOT] = ACTIONS(1871),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1779] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6943),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2986),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7151),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6520),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4518),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7441),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9110),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1779),
    [sym_preproc_endregion] = STATE(1779),
    [sym_preproc_line] = STATE(1779),
    [sym_preproc_pragma] = STATE(1779),
    [sym_preproc_nullable] = STATE(1779),
    [sym_preproc_error] = STATE(1779),
    [sym_preproc_warning] = STATE(1779),
    [sym_preproc_define] = STATE(1779),
    [sym_preproc_undef] = STATE(1779),
    [aux_sym_class_declaration_repeat1] = STATE(3875),
    [aux_sym_lambda_expression_repeat1] = STATE(4315),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2169),
    [anon_sym_ref] = ACTIONS(2171),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2173),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2177),
    [anon_sym_TILDE] = ACTIONS(2177),
    [anon_sym_PLUS_PLUS] = ACTIONS(2177),
    [anon_sym_DASH_DASH] = ACTIONS(2177),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2175),
    [anon_sym_DASH] = ACTIONS(2175),
    [anon_sym_STAR] = ACTIONS(2179),
    [anon_sym_CARET] = ACTIONS(2177),
    [anon_sym_AMP] = ACTIONS(2177),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2181),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2183),
    [anon_sym_DOT_DOT] = ACTIONS(2185),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1780] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6950),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7044),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5106),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3868),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7432),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9127),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1780),
    [sym_preproc_endregion] = STATE(1780),
    [sym_preproc_line] = STATE(1780),
    [sym_preproc_pragma] = STATE(1780),
    [sym_preproc_nullable] = STATE(1780),
    [sym_preproc_error] = STATE(1780),
    [sym_preproc_warning] = STATE(1780),
    [sym_preproc_define] = STATE(1780),
    [sym_preproc_undef] = STATE(1780),
    [aux_sym_class_declaration_repeat1] = STATE(3832),
    [aux_sym_lambda_expression_repeat1] = STATE(4259),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1357),
    [anon_sym_ref] = ACTIONS(1359),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1363),
    [anon_sym_TILDE] = ACTIONS(1363),
    [anon_sym_PLUS_PLUS] = ACTIONS(1363),
    [anon_sym_DASH_DASH] = ACTIONS(1363),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1361),
    [anon_sym_DASH] = ACTIONS(1361),
    [anon_sym_STAR] = ACTIONS(1365),
    [anon_sym_CARET] = ACTIONS(1363),
    [anon_sym_AMP] = ACTIONS(1363),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1367),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1369),
    [anon_sym_DOT_DOT] = ACTIONS(1371),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1781] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6956),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6479),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9482),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1781),
    [sym_preproc_endregion] = STATE(1781),
    [sym_preproc_line] = STATE(1781),
    [sym_preproc_pragma] = STATE(1781),
    [sym_preproc_nullable] = STATE(1781),
    [sym_preproc_error] = STATE(1781),
    [sym_preproc_warning] = STATE(1781),
    [sym_preproc_define] = STATE(1781),
    [sym_preproc_undef] = STATE(1781),
    [aux_sym_class_declaration_repeat1] = STATE(3853),
    [aux_sym_lambda_expression_repeat1] = STATE(4299),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1497),
    [anon_sym_ref] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1505),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1507),
    [anon_sym_DOT_DOT] = ACTIONS(1509),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1782] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6943),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2986),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7065),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5797),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4342),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7419),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9334),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1782),
    [sym_preproc_endregion] = STATE(1782),
    [sym_preproc_line] = STATE(1782),
    [sym_preproc_pragma] = STATE(1782),
    [sym_preproc_nullable] = STATE(1782),
    [sym_preproc_error] = STATE(1782),
    [sym_preproc_warning] = STATE(1782),
    [sym_preproc_define] = STATE(1782),
    [sym_preproc_undef] = STATE(1782),
    [aux_sym_class_declaration_repeat1] = STATE(3840),
    [aux_sym_lambda_expression_repeat1] = STATE(4269),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1855),
    [anon_sym_ref] = ACTIONS(1857),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1859),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1863),
    [anon_sym_TILDE] = ACTIONS(1863),
    [anon_sym_PLUS_PLUS] = ACTIONS(1863),
    [anon_sym_DASH_DASH] = ACTIONS(1863),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1861),
    [anon_sym_DASH] = ACTIONS(1861),
    [anon_sym_STAR] = ACTIONS(1865),
    [anon_sym_CARET] = ACTIONS(1863),
    [anon_sym_AMP] = ACTIONS(1863),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1867),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1869),
    [anon_sym_DOT_DOT] = ACTIONS(1871),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1783] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6943),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2986),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7065),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5798),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4342),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7419),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9334),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1783),
    [sym_preproc_endregion] = STATE(1783),
    [sym_preproc_line] = STATE(1783),
    [sym_preproc_pragma] = STATE(1783),
    [sym_preproc_nullable] = STATE(1783),
    [sym_preproc_error] = STATE(1783),
    [sym_preproc_warning] = STATE(1783),
    [sym_preproc_define] = STATE(1783),
    [sym_preproc_undef] = STATE(1783),
    [aux_sym_class_declaration_repeat1] = STATE(3840),
    [aux_sym_lambda_expression_repeat1] = STATE(4269),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1855),
    [anon_sym_ref] = ACTIONS(1857),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1859),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1863),
    [anon_sym_TILDE] = ACTIONS(1863),
    [anon_sym_PLUS_PLUS] = ACTIONS(1863),
    [anon_sym_DASH_DASH] = ACTIONS(1863),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1861),
    [anon_sym_DASH] = ACTIONS(1861),
    [anon_sym_STAR] = ACTIONS(1865),
    [anon_sym_CARET] = ACTIONS(1863),
    [anon_sym_AMP] = ACTIONS(1863),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1867),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1869),
    [anon_sym_DOT_DOT] = ACTIONS(1871),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1784] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6943),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2986),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7065),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6053),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4342),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7419),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9334),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1784),
    [sym_preproc_endregion] = STATE(1784),
    [sym_preproc_line] = STATE(1784),
    [sym_preproc_pragma] = STATE(1784),
    [sym_preproc_nullable] = STATE(1784),
    [sym_preproc_error] = STATE(1784),
    [sym_preproc_warning] = STATE(1784),
    [sym_preproc_define] = STATE(1784),
    [sym_preproc_undef] = STATE(1784),
    [aux_sym_class_declaration_repeat1] = STATE(3840),
    [aux_sym_lambda_expression_repeat1] = STATE(4269),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1855),
    [anon_sym_ref] = ACTIONS(1857),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1859),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1863),
    [anon_sym_TILDE] = ACTIONS(1863),
    [anon_sym_PLUS_PLUS] = ACTIONS(1863),
    [anon_sym_DASH_DASH] = ACTIONS(1863),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1861),
    [anon_sym_DASH] = ACTIONS(1861),
    [anon_sym_STAR] = ACTIONS(1865),
    [anon_sym_CARET] = ACTIONS(1863),
    [anon_sym_AMP] = ACTIONS(1863),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1867),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1869),
    [anon_sym_DOT_DOT] = ACTIONS(1871),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1785] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6943),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2986),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7065),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5799),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4342),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7419),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9334),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1785),
    [sym_preproc_endregion] = STATE(1785),
    [sym_preproc_line] = STATE(1785),
    [sym_preproc_pragma] = STATE(1785),
    [sym_preproc_nullable] = STATE(1785),
    [sym_preproc_error] = STATE(1785),
    [sym_preproc_warning] = STATE(1785),
    [sym_preproc_define] = STATE(1785),
    [sym_preproc_undef] = STATE(1785),
    [aux_sym_class_declaration_repeat1] = STATE(3840),
    [aux_sym_lambda_expression_repeat1] = STATE(4269),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1855),
    [anon_sym_ref] = ACTIONS(1857),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1859),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1863),
    [anon_sym_TILDE] = ACTIONS(1863),
    [anon_sym_PLUS_PLUS] = ACTIONS(1863),
    [anon_sym_DASH_DASH] = ACTIONS(1863),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1861),
    [anon_sym_DASH] = ACTIONS(1861),
    [anon_sym_STAR] = ACTIONS(1865),
    [anon_sym_CARET] = ACTIONS(1863),
    [anon_sym_AMP] = ACTIONS(1863),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1867),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1869),
    [anon_sym_DOT_DOT] = ACTIONS(1871),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1786] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6943),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2986),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7065),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5800),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4342),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7419),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9334),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1786),
    [sym_preproc_endregion] = STATE(1786),
    [sym_preproc_line] = STATE(1786),
    [sym_preproc_pragma] = STATE(1786),
    [sym_preproc_nullable] = STATE(1786),
    [sym_preproc_error] = STATE(1786),
    [sym_preproc_warning] = STATE(1786),
    [sym_preproc_define] = STATE(1786),
    [sym_preproc_undef] = STATE(1786),
    [aux_sym_class_declaration_repeat1] = STATE(3840),
    [aux_sym_lambda_expression_repeat1] = STATE(4269),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1855),
    [anon_sym_ref] = ACTIONS(1857),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1859),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1863),
    [anon_sym_TILDE] = ACTIONS(1863),
    [anon_sym_PLUS_PLUS] = ACTIONS(1863),
    [anon_sym_DASH_DASH] = ACTIONS(1863),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1861),
    [anon_sym_DASH] = ACTIONS(1861),
    [anon_sym_STAR] = ACTIONS(1865),
    [anon_sym_CARET] = ACTIONS(1863),
    [anon_sym_AMP] = ACTIONS(1863),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1867),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1869),
    [anon_sym_DOT_DOT] = ACTIONS(1871),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1787] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6943),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2986),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7065),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5801),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4342),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7419),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9334),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1787),
    [sym_preproc_endregion] = STATE(1787),
    [sym_preproc_line] = STATE(1787),
    [sym_preproc_pragma] = STATE(1787),
    [sym_preproc_nullable] = STATE(1787),
    [sym_preproc_error] = STATE(1787),
    [sym_preproc_warning] = STATE(1787),
    [sym_preproc_define] = STATE(1787),
    [sym_preproc_undef] = STATE(1787),
    [aux_sym_class_declaration_repeat1] = STATE(3840),
    [aux_sym_lambda_expression_repeat1] = STATE(4269),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1855),
    [anon_sym_ref] = ACTIONS(1857),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1859),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1863),
    [anon_sym_TILDE] = ACTIONS(1863),
    [anon_sym_PLUS_PLUS] = ACTIONS(1863),
    [anon_sym_DASH_DASH] = ACTIONS(1863),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1861),
    [anon_sym_DASH] = ACTIONS(1861),
    [anon_sym_STAR] = ACTIONS(1865),
    [anon_sym_CARET] = ACTIONS(1863),
    [anon_sym_AMP] = ACTIONS(1863),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1867),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1869),
    [anon_sym_DOT_DOT] = ACTIONS(1871),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1788] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6943),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2986),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7065),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5802),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4342),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7419),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9334),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1788),
    [sym_preproc_endregion] = STATE(1788),
    [sym_preproc_line] = STATE(1788),
    [sym_preproc_pragma] = STATE(1788),
    [sym_preproc_nullable] = STATE(1788),
    [sym_preproc_error] = STATE(1788),
    [sym_preproc_warning] = STATE(1788),
    [sym_preproc_define] = STATE(1788),
    [sym_preproc_undef] = STATE(1788),
    [aux_sym_class_declaration_repeat1] = STATE(3840),
    [aux_sym_lambda_expression_repeat1] = STATE(4269),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1855),
    [anon_sym_ref] = ACTIONS(1857),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1859),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1863),
    [anon_sym_TILDE] = ACTIONS(1863),
    [anon_sym_PLUS_PLUS] = ACTIONS(1863),
    [anon_sym_DASH_DASH] = ACTIONS(1863),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1861),
    [anon_sym_DASH] = ACTIONS(1861),
    [anon_sym_STAR] = ACTIONS(1865),
    [anon_sym_CARET] = ACTIONS(1863),
    [anon_sym_AMP] = ACTIONS(1863),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1867),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1869),
    [anon_sym_DOT_DOT] = ACTIONS(1871),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1789] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6943),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2986),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7065),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5803),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4342),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7419),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9334),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1789),
    [sym_preproc_endregion] = STATE(1789),
    [sym_preproc_line] = STATE(1789),
    [sym_preproc_pragma] = STATE(1789),
    [sym_preproc_nullable] = STATE(1789),
    [sym_preproc_error] = STATE(1789),
    [sym_preproc_warning] = STATE(1789),
    [sym_preproc_define] = STATE(1789),
    [sym_preproc_undef] = STATE(1789),
    [aux_sym_class_declaration_repeat1] = STATE(3840),
    [aux_sym_lambda_expression_repeat1] = STATE(4269),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1855),
    [anon_sym_ref] = ACTIONS(1857),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1859),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1863),
    [anon_sym_TILDE] = ACTIONS(1863),
    [anon_sym_PLUS_PLUS] = ACTIONS(1863),
    [anon_sym_DASH_DASH] = ACTIONS(1863),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1861),
    [anon_sym_DASH] = ACTIONS(1861),
    [anon_sym_STAR] = ACTIONS(1865),
    [anon_sym_CARET] = ACTIONS(1863),
    [anon_sym_AMP] = ACTIONS(1863),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1867),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1869),
    [anon_sym_DOT_DOT] = ACTIONS(1871),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1790] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6943),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2986),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7065),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5804),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4342),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7419),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9334),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1790),
    [sym_preproc_endregion] = STATE(1790),
    [sym_preproc_line] = STATE(1790),
    [sym_preproc_pragma] = STATE(1790),
    [sym_preproc_nullable] = STATE(1790),
    [sym_preproc_error] = STATE(1790),
    [sym_preproc_warning] = STATE(1790),
    [sym_preproc_define] = STATE(1790),
    [sym_preproc_undef] = STATE(1790),
    [aux_sym_class_declaration_repeat1] = STATE(3840),
    [aux_sym_lambda_expression_repeat1] = STATE(4269),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1855),
    [anon_sym_ref] = ACTIONS(1857),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1859),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1863),
    [anon_sym_TILDE] = ACTIONS(1863),
    [anon_sym_PLUS_PLUS] = ACTIONS(1863),
    [anon_sym_DASH_DASH] = ACTIONS(1863),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1861),
    [anon_sym_DASH] = ACTIONS(1861),
    [anon_sym_STAR] = ACTIONS(1865),
    [anon_sym_CARET] = ACTIONS(1863),
    [anon_sym_AMP] = ACTIONS(1863),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1867),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1869),
    [anon_sym_DOT_DOT] = ACTIONS(1871),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1791] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6943),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2986),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7065),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5805),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4342),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7419),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9334),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1791),
    [sym_preproc_endregion] = STATE(1791),
    [sym_preproc_line] = STATE(1791),
    [sym_preproc_pragma] = STATE(1791),
    [sym_preproc_nullable] = STATE(1791),
    [sym_preproc_error] = STATE(1791),
    [sym_preproc_warning] = STATE(1791),
    [sym_preproc_define] = STATE(1791),
    [sym_preproc_undef] = STATE(1791),
    [aux_sym_class_declaration_repeat1] = STATE(3840),
    [aux_sym_lambda_expression_repeat1] = STATE(4269),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1855),
    [anon_sym_ref] = ACTIONS(1857),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1859),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1863),
    [anon_sym_TILDE] = ACTIONS(1863),
    [anon_sym_PLUS_PLUS] = ACTIONS(1863),
    [anon_sym_DASH_DASH] = ACTIONS(1863),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1861),
    [anon_sym_DASH] = ACTIONS(1861),
    [anon_sym_STAR] = ACTIONS(1865),
    [anon_sym_CARET] = ACTIONS(1863),
    [anon_sym_AMP] = ACTIONS(1863),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1867),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1869),
    [anon_sym_DOT_DOT] = ACTIONS(1871),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1792] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6943),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2986),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7065),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5806),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4342),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7419),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9334),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1792),
    [sym_preproc_endregion] = STATE(1792),
    [sym_preproc_line] = STATE(1792),
    [sym_preproc_pragma] = STATE(1792),
    [sym_preproc_nullable] = STATE(1792),
    [sym_preproc_error] = STATE(1792),
    [sym_preproc_warning] = STATE(1792),
    [sym_preproc_define] = STATE(1792),
    [sym_preproc_undef] = STATE(1792),
    [aux_sym_class_declaration_repeat1] = STATE(3840),
    [aux_sym_lambda_expression_repeat1] = STATE(4269),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1855),
    [anon_sym_ref] = ACTIONS(1857),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1859),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1863),
    [anon_sym_TILDE] = ACTIONS(1863),
    [anon_sym_PLUS_PLUS] = ACTIONS(1863),
    [anon_sym_DASH_DASH] = ACTIONS(1863),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1861),
    [anon_sym_DASH] = ACTIONS(1861),
    [anon_sym_STAR] = ACTIONS(1865),
    [anon_sym_CARET] = ACTIONS(1863),
    [anon_sym_AMP] = ACTIONS(1863),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1867),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1869),
    [anon_sym_DOT_DOT] = ACTIONS(1871),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1793] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6943),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2986),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7065),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3932),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4342),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7419),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9334),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1793),
    [sym_preproc_endregion] = STATE(1793),
    [sym_preproc_line] = STATE(1793),
    [sym_preproc_pragma] = STATE(1793),
    [sym_preproc_nullable] = STATE(1793),
    [sym_preproc_error] = STATE(1793),
    [sym_preproc_warning] = STATE(1793),
    [sym_preproc_define] = STATE(1793),
    [sym_preproc_undef] = STATE(1793),
    [aux_sym_class_declaration_repeat1] = STATE(3840),
    [aux_sym_lambda_expression_repeat1] = STATE(4269),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1855),
    [anon_sym_ref] = ACTIONS(1857),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1859),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1863),
    [anon_sym_TILDE] = ACTIONS(1863),
    [anon_sym_PLUS_PLUS] = ACTIONS(1863),
    [anon_sym_DASH_DASH] = ACTIONS(1863),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1861),
    [anon_sym_DASH] = ACTIONS(1861),
    [anon_sym_STAR] = ACTIONS(1865),
    [anon_sym_CARET] = ACTIONS(1863),
    [anon_sym_AMP] = ACTIONS(1863),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1867),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1869),
    [anon_sym_DOT_DOT] = ACTIONS(1871),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1794] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6915),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7099),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5732),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4224),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7442),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9174),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1794),
    [sym_preproc_endregion] = STATE(1794),
    [sym_preproc_line] = STATE(1794),
    [sym_preproc_pragma] = STATE(1794),
    [sym_preproc_nullable] = STATE(1794),
    [sym_preproc_error] = STATE(1794),
    [sym_preproc_warning] = STATE(1794),
    [sym_preproc_define] = STATE(1794),
    [sym_preproc_undef] = STATE(1794),
    [aux_sym_class_declaration_repeat1] = STATE(3849),
    [aux_sym_lambda_expression_repeat1] = STATE(4284),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1653),
    [anon_sym_ref] = ACTIONS(1655),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1659),
    [anon_sym_TILDE] = ACTIONS(1659),
    [anon_sym_PLUS_PLUS] = ACTIONS(1659),
    [anon_sym_DASH_DASH] = ACTIONS(1659),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1657),
    [anon_sym_DASH] = ACTIONS(1657),
    [anon_sym_STAR] = ACTIONS(1661),
    [anon_sym_CARET] = ACTIONS(1659),
    [anon_sym_AMP] = ACTIONS(1659),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1663),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1665),
    [anon_sym_DOT_DOT] = ACTIONS(1667),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1795] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6943),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2986),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7065),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5810),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4342),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7419),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9334),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1795),
    [sym_preproc_endregion] = STATE(1795),
    [sym_preproc_line] = STATE(1795),
    [sym_preproc_pragma] = STATE(1795),
    [sym_preproc_nullable] = STATE(1795),
    [sym_preproc_error] = STATE(1795),
    [sym_preproc_warning] = STATE(1795),
    [sym_preproc_define] = STATE(1795),
    [sym_preproc_undef] = STATE(1795),
    [aux_sym_class_declaration_repeat1] = STATE(3840),
    [aux_sym_lambda_expression_repeat1] = STATE(4269),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1855),
    [anon_sym_ref] = ACTIONS(1857),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1859),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1863),
    [anon_sym_TILDE] = ACTIONS(1863),
    [anon_sym_PLUS_PLUS] = ACTIONS(1863),
    [anon_sym_DASH_DASH] = ACTIONS(1863),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1861),
    [anon_sym_DASH] = ACTIONS(1861),
    [anon_sym_STAR] = ACTIONS(1865),
    [anon_sym_CARET] = ACTIONS(1863),
    [anon_sym_AMP] = ACTIONS(1863),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1867),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1869),
    [anon_sym_DOT_DOT] = ACTIONS(1871),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1796] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6943),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2986),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7065),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3926),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4342),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7419),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9334),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1796),
    [sym_preproc_endregion] = STATE(1796),
    [sym_preproc_line] = STATE(1796),
    [sym_preproc_pragma] = STATE(1796),
    [sym_preproc_nullable] = STATE(1796),
    [sym_preproc_error] = STATE(1796),
    [sym_preproc_warning] = STATE(1796),
    [sym_preproc_define] = STATE(1796),
    [sym_preproc_undef] = STATE(1796),
    [aux_sym_class_declaration_repeat1] = STATE(3840),
    [aux_sym_lambda_expression_repeat1] = STATE(4269),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1855),
    [anon_sym_ref] = ACTIONS(1857),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1859),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1863),
    [anon_sym_TILDE] = ACTIONS(1863),
    [anon_sym_PLUS_PLUS] = ACTIONS(1863),
    [anon_sym_DASH_DASH] = ACTIONS(1863),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1861),
    [anon_sym_DASH] = ACTIONS(1861),
    [anon_sym_STAR] = ACTIONS(1865),
    [anon_sym_CARET] = ACTIONS(1863),
    [anon_sym_AMP] = ACTIONS(1863),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1867),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1869),
    [anon_sym_DOT_DOT] = ACTIONS(1871),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1797] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6943),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2986),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7065),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5812),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4342),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7419),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9334),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1797),
    [sym_preproc_endregion] = STATE(1797),
    [sym_preproc_line] = STATE(1797),
    [sym_preproc_pragma] = STATE(1797),
    [sym_preproc_nullable] = STATE(1797),
    [sym_preproc_error] = STATE(1797),
    [sym_preproc_warning] = STATE(1797),
    [sym_preproc_define] = STATE(1797),
    [sym_preproc_undef] = STATE(1797),
    [aux_sym_class_declaration_repeat1] = STATE(3840),
    [aux_sym_lambda_expression_repeat1] = STATE(4269),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1855),
    [anon_sym_ref] = ACTIONS(1857),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1859),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1863),
    [anon_sym_TILDE] = ACTIONS(1863),
    [anon_sym_PLUS_PLUS] = ACTIONS(1863),
    [anon_sym_DASH_DASH] = ACTIONS(1863),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1861),
    [anon_sym_DASH] = ACTIONS(1861),
    [anon_sym_STAR] = ACTIONS(1865),
    [anon_sym_CARET] = ACTIONS(1863),
    [anon_sym_AMP] = ACTIONS(1863),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1867),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1869),
    [anon_sym_DOT_DOT] = ACTIONS(1871),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1798] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6943),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2986),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7065),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5816),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4342),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7419),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9334),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1798),
    [sym_preproc_endregion] = STATE(1798),
    [sym_preproc_line] = STATE(1798),
    [sym_preproc_pragma] = STATE(1798),
    [sym_preproc_nullable] = STATE(1798),
    [sym_preproc_error] = STATE(1798),
    [sym_preproc_warning] = STATE(1798),
    [sym_preproc_define] = STATE(1798),
    [sym_preproc_undef] = STATE(1798),
    [aux_sym_class_declaration_repeat1] = STATE(3840),
    [aux_sym_lambda_expression_repeat1] = STATE(4269),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1855),
    [anon_sym_ref] = ACTIONS(1857),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1859),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1863),
    [anon_sym_TILDE] = ACTIONS(1863),
    [anon_sym_PLUS_PLUS] = ACTIONS(1863),
    [anon_sym_DASH_DASH] = ACTIONS(1863),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1861),
    [anon_sym_DASH] = ACTIONS(1861),
    [anon_sym_STAR] = ACTIONS(1865),
    [anon_sym_CARET] = ACTIONS(1863),
    [anon_sym_AMP] = ACTIONS(1863),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1867),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1869),
    [anon_sym_DOT_DOT] = ACTIONS(1871),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1799] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6915),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7099),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5733),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4224),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7442),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9174),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1799),
    [sym_preproc_endregion] = STATE(1799),
    [sym_preproc_line] = STATE(1799),
    [sym_preproc_pragma] = STATE(1799),
    [sym_preproc_nullable] = STATE(1799),
    [sym_preproc_error] = STATE(1799),
    [sym_preproc_warning] = STATE(1799),
    [sym_preproc_define] = STATE(1799),
    [sym_preproc_undef] = STATE(1799),
    [aux_sym_class_declaration_repeat1] = STATE(3849),
    [aux_sym_lambda_expression_repeat1] = STATE(4284),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1653),
    [anon_sym_ref] = ACTIONS(1655),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1659),
    [anon_sym_TILDE] = ACTIONS(1659),
    [anon_sym_PLUS_PLUS] = ACTIONS(1659),
    [anon_sym_DASH_DASH] = ACTIONS(1659),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1657),
    [anon_sym_DASH] = ACTIONS(1657),
    [anon_sym_STAR] = ACTIONS(1661),
    [anon_sym_CARET] = ACTIONS(1659),
    [anon_sym_AMP] = ACTIONS(1659),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1663),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1665),
    [anon_sym_DOT_DOT] = ACTIONS(1667),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1800] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6915),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7099),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3838),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4224),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7442),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9174),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1800),
    [sym_preproc_endregion] = STATE(1800),
    [sym_preproc_line] = STATE(1800),
    [sym_preproc_pragma] = STATE(1800),
    [sym_preproc_nullable] = STATE(1800),
    [sym_preproc_error] = STATE(1800),
    [sym_preproc_warning] = STATE(1800),
    [sym_preproc_define] = STATE(1800),
    [sym_preproc_undef] = STATE(1800),
    [aux_sym_class_declaration_repeat1] = STATE(3849),
    [aux_sym_lambda_expression_repeat1] = STATE(4284),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1653),
    [anon_sym_ref] = ACTIONS(1655),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1659),
    [anon_sym_TILDE] = ACTIONS(1659),
    [anon_sym_PLUS_PLUS] = ACTIONS(1659),
    [anon_sym_DASH_DASH] = ACTIONS(1659),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1657),
    [anon_sym_DASH] = ACTIONS(1657),
    [anon_sym_STAR] = ACTIONS(1661),
    [anon_sym_CARET] = ACTIONS(1659),
    [anon_sym_AMP] = ACTIONS(1659),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1663),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1665),
    [anon_sym_DOT_DOT] = ACTIONS(1667),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1801] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6915),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7099),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5553),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4224),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7442),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9174),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1801),
    [sym_preproc_endregion] = STATE(1801),
    [sym_preproc_line] = STATE(1801),
    [sym_preproc_pragma] = STATE(1801),
    [sym_preproc_nullable] = STATE(1801),
    [sym_preproc_error] = STATE(1801),
    [sym_preproc_warning] = STATE(1801),
    [sym_preproc_define] = STATE(1801),
    [sym_preproc_undef] = STATE(1801),
    [aux_sym_class_declaration_repeat1] = STATE(3849),
    [aux_sym_lambda_expression_repeat1] = STATE(4284),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1653),
    [anon_sym_ref] = ACTIONS(1655),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1659),
    [anon_sym_TILDE] = ACTIONS(1659),
    [anon_sym_PLUS_PLUS] = ACTIONS(1659),
    [anon_sym_DASH_DASH] = ACTIONS(1659),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1657),
    [anon_sym_DASH] = ACTIONS(1657),
    [anon_sym_STAR] = ACTIONS(1661),
    [anon_sym_CARET] = ACTIONS(1659),
    [anon_sym_AMP] = ACTIONS(1659),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1663),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1665),
    [anon_sym_DOT_DOT] = ACTIONS(1667),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1802] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6915),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7099),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5554),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4224),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7442),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9174),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1802),
    [sym_preproc_endregion] = STATE(1802),
    [sym_preproc_line] = STATE(1802),
    [sym_preproc_pragma] = STATE(1802),
    [sym_preproc_nullable] = STATE(1802),
    [sym_preproc_error] = STATE(1802),
    [sym_preproc_warning] = STATE(1802),
    [sym_preproc_define] = STATE(1802),
    [sym_preproc_undef] = STATE(1802),
    [aux_sym_class_declaration_repeat1] = STATE(3849),
    [aux_sym_lambda_expression_repeat1] = STATE(4284),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1653),
    [anon_sym_ref] = ACTIONS(1655),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1659),
    [anon_sym_TILDE] = ACTIONS(1659),
    [anon_sym_PLUS_PLUS] = ACTIONS(1659),
    [anon_sym_DASH_DASH] = ACTIONS(1659),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1657),
    [anon_sym_DASH] = ACTIONS(1657),
    [anon_sym_STAR] = ACTIONS(1661),
    [anon_sym_CARET] = ACTIONS(1659),
    [anon_sym_AMP] = ACTIONS(1659),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1663),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1665),
    [anon_sym_DOT_DOT] = ACTIONS(1667),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1803] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6915),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7099),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5725),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4224),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7442),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9174),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1803),
    [sym_preproc_endregion] = STATE(1803),
    [sym_preproc_line] = STATE(1803),
    [sym_preproc_pragma] = STATE(1803),
    [sym_preproc_nullable] = STATE(1803),
    [sym_preproc_error] = STATE(1803),
    [sym_preproc_warning] = STATE(1803),
    [sym_preproc_define] = STATE(1803),
    [sym_preproc_undef] = STATE(1803),
    [aux_sym_class_declaration_repeat1] = STATE(3849),
    [aux_sym_lambda_expression_repeat1] = STATE(4284),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1653),
    [anon_sym_ref] = ACTIONS(1655),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1659),
    [anon_sym_TILDE] = ACTIONS(1659),
    [anon_sym_PLUS_PLUS] = ACTIONS(1659),
    [anon_sym_DASH_DASH] = ACTIONS(1659),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1657),
    [anon_sym_DASH] = ACTIONS(1657),
    [anon_sym_STAR] = ACTIONS(1661),
    [anon_sym_CARET] = ACTIONS(1659),
    [anon_sym_AMP] = ACTIONS(1659),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1663),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1665),
    [anon_sym_DOT_DOT] = ACTIONS(1667),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1804] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6915),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7099),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5734),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4224),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7442),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9174),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1804),
    [sym_preproc_endregion] = STATE(1804),
    [sym_preproc_line] = STATE(1804),
    [sym_preproc_pragma] = STATE(1804),
    [sym_preproc_nullable] = STATE(1804),
    [sym_preproc_error] = STATE(1804),
    [sym_preproc_warning] = STATE(1804),
    [sym_preproc_define] = STATE(1804),
    [sym_preproc_undef] = STATE(1804),
    [aux_sym_class_declaration_repeat1] = STATE(3849),
    [aux_sym_lambda_expression_repeat1] = STATE(4284),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1653),
    [anon_sym_ref] = ACTIONS(1655),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1659),
    [anon_sym_TILDE] = ACTIONS(1659),
    [anon_sym_PLUS_PLUS] = ACTIONS(1659),
    [anon_sym_DASH_DASH] = ACTIONS(1659),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1657),
    [anon_sym_DASH] = ACTIONS(1657),
    [anon_sym_STAR] = ACTIONS(1661),
    [anon_sym_CARET] = ACTIONS(1659),
    [anon_sym_AMP] = ACTIONS(1659),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1663),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1665),
    [anon_sym_DOT_DOT] = ACTIONS(1667),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1805] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6915),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7099),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5735),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4224),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7442),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9174),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1805),
    [sym_preproc_endregion] = STATE(1805),
    [sym_preproc_line] = STATE(1805),
    [sym_preproc_pragma] = STATE(1805),
    [sym_preproc_nullable] = STATE(1805),
    [sym_preproc_error] = STATE(1805),
    [sym_preproc_warning] = STATE(1805),
    [sym_preproc_define] = STATE(1805),
    [sym_preproc_undef] = STATE(1805),
    [aux_sym_class_declaration_repeat1] = STATE(3849),
    [aux_sym_lambda_expression_repeat1] = STATE(4284),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1653),
    [anon_sym_ref] = ACTIONS(1655),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1659),
    [anon_sym_TILDE] = ACTIONS(1659),
    [anon_sym_PLUS_PLUS] = ACTIONS(1659),
    [anon_sym_DASH_DASH] = ACTIONS(1659),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1657),
    [anon_sym_DASH] = ACTIONS(1657),
    [anon_sym_STAR] = ACTIONS(1661),
    [anon_sym_CARET] = ACTIONS(1659),
    [anon_sym_AMP] = ACTIONS(1659),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1663),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1665),
    [anon_sym_DOT_DOT] = ACTIONS(1667),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1806] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6915),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7099),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5736),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4224),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7442),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9174),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1806),
    [sym_preproc_endregion] = STATE(1806),
    [sym_preproc_line] = STATE(1806),
    [sym_preproc_pragma] = STATE(1806),
    [sym_preproc_nullable] = STATE(1806),
    [sym_preproc_error] = STATE(1806),
    [sym_preproc_warning] = STATE(1806),
    [sym_preproc_define] = STATE(1806),
    [sym_preproc_undef] = STATE(1806),
    [aux_sym_class_declaration_repeat1] = STATE(3849),
    [aux_sym_lambda_expression_repeat1] = STATE(4284),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1653),
    [anon_sym_ref] = ACTIONS(1655),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1659),
    [anon_sym_TILDE] = ACTIONS(1659),
    [anon_sym_PLUS_PLUS] = ACTIONS(1659),
    [anon_sym_DASH_DASH] = ACTIONS(1659),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1657),
    [anon_sym_DASH] = ACTIONS(1657),
    [anon_sym_STAR] = ACTIONS(1661),
    [anon_sym_CARET] = ACTIONS(1659),
    [anon_sym_AMP] = ACTIONS(1659),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1663),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1665),
    [anon_sym_DOT_DOT] = ACTIONS(1667),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1807] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6915),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7099),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5555),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4224),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7442),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9174),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1807),
    [sym_preproc_endregion] = STATE(1807),
    [sym_preproc_line] = STATE(1807),
    [sym_preproc_pragma] = STATE(1807),
    [sym_preproc_nullable] = STATE(1807),
    [sym_preproc_error] = STATE(1807),
    [sym_preproc_warning] = STATE(1807),
    [sym_preproc_define] = STATE(1807),
    [sym_preproc_undef] = STATE(1807),
    [aux_sym_class_declaration_repeat1] = STATE(3849),
    [aux_sym_lambda_expression_repeat1] = STATE(4284),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1653),
    [anon_sym_ref] = ACTIONS(1655),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1659),
    [anon_sym_TILDE] = ACTIONS(1659),
    [anon_sym_PLUS_PLUS] = ACTIONS(1659),
    [anon_sym_DASH_DASH] = ACTIONS(1659),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1657),
    [anon_sym_DASH] = ACTIONS(1657),
    [anon_sym_STAR] = ACTIONS(1661),
    [anon_sym_CARET] = ACTIONS(1659),
    [anon_sym_AMP] = ACTIONS(1659),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1663),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1665),
    [anon_sym_DOT_DOT] = ACTIONS(1667),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1808] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6915),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7099),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5737),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4224),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7442),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9174),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1808),
    [sym_preproc_endregion] = STATE(1808),
    [sym_preproc_line] = STATE(1808),
    [sym_preproc_pragma] = STATE(1808),
    [sym_preproc_nullable] = STATE(1808),
    [sym_preproc_error] = STATE(1808),
    [sym_preproc_warning] = STATE(1808),
    [sym_preproc_define] = STATE(1808),
    [sym_preproc_undef] = STATE(1808),
    [aux_sym_class_declaration_repeat1] = STATE(3849),
    [aux_sym_lambda_expression_repeat1] = STATE(4284),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1653),
    [anon_sym_ref] = ACTIONS(1655),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1659),
    [anon_sym_TILDE] = ACTIONS(1659),
    [anon_sym_PLUS_PLUS] = ACTIONS(1659),
    [anon_sym_DASH_DASH] = ACTIONS(1659),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1657),
    [anon_sym_DASH] = ACTIONS(1657),
    [anon_sym_STAR] = ACTIONS(1661),
    [anon_sym_CARET] = ACTIONS(1659),
    [anon_sym_AMP] = ACTIONS(1659),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1663),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1665),
    [anon_sym_DOT_DOT] = ACTIONS(1667),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1809] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6915),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7099),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5738),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4224),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7442),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9174),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1809),
    [sym_preproc_endregion] = STATE(1809),
    [sym_preproc_line] = STATE(1809),
    [sym_preproc_pragma] = STATE(1809),
    [sym_preproc_nullable] = STATE(1809),
    [sym_preproc_error] = STATE(1809),
    [sym_preproc_warning] = STATE(1809),
    [sym_preproc_define] = STATE(1809),
    [sym_preproc_undef] = STATE(1809),
    [aux_sym_class_declaration_repeat1] = STATE(3849),
    [aux_sym_lambda_expression_repeat1] = STATE(4284),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1653),
    [anon_sym_ref] = ACTIONS(1655),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1659),
    [anon_sym_TILDE] = ACTIONS(1659),
    [anon_sym_PLUS_PLUS] = ACTIONS(1659),
    [anon_sym_DASH_DASH] = ACTIONS(1659),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1657),
    [anon_sym_DASH] = ACTIONS(1657),
    [anon_sym_STAR] = ACTIONS(1661),
    [anon_sym_CARET] = ACTIONS(1659),
    [anon_sym_AMP] = ACTIONS(1659),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1663),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1665),
    [anon_sym_DOT_DOT] = ACTIONS(1667),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1810] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6915),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7099),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5739),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4224),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7442),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9174),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1810),
    [sym_preproc_endregion] = STATE(1810),
    [sym_preproc_line] = STATE(1810),
    [sym_preproc_pragma] = STATE(1810),
    [sym_preproc_nullable] = STATE(1810),
    [sym_preproc_error] = STATE(1810),
    [sym_preproc_warning] = STATE(1810),
    [sym_preproc_define] = STATE(1810),
    [sym_preproc_undef] = STATE(1810),
    [aux_sym_class_declaration_repeat1] = STATE(3849),
    [aux_sym_lambda_expression_repeat1] = STATE(4284),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1653),
    [anon_sym_ref] = ACTIONS(1655),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1659),
    [anon_sym_TILDE] = ACTIONS(1659),
    [anon_sym_PLUS_PLUS] = ACTIONS(1659),
    [anon_sym_DASH_DASH] = ACTIONS(1659),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1657),
    [anon_sym_DASH] = ACTIONS(1657),
    [anon_sym_STAR] = ACTIONS(1661),
    [anon_sym_CARET] = ACTIONS(1659),
    [anon_sym_AMP] = ACTIONS(1659),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1663),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1665),
    [anon_sym_DOT_DOT] = ACTIONS(1667),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1811] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6915),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7099),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5740),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4224),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7442),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9174),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1811),
    [sym_preproc_endregion] = STATE(1811),
    [sym_preproc_line] = STATE(1811),
    [sym_preproc_pragma] = STATE(1811),
    [sym_preproc_nullable] = STATE(1811),
    [sym_preproc_error] = STATE(1811),
    [sym_preproc_warning] = STATE(1811),
    [sym_preproc_define] = STATE(1811),
    [sym_preproc_undef] = STATE(1811),
    [aux_sym_class_declaration_repeat1] = STATE(3849),
    [aux_sym_lambda_expression_repeat1] = STATE(4284),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1653),
    [anon_sym_ref] = ACTIONS(1655),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1659),
    [anon_sym_TILDE] = ACTIONS(1659),
    [anon_sym_PLUS_PLUS] = ACTIONS(1659),
    [anon_sym_DASH_DASH] = ACTIONS(1659),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1657),
    [anon_sym_DASH] = ACTIONS(1657),
    [anon_sym_STAR] = ACTIONS(1661),
    [anon_sym_CARET] = ACTIONS(1659),
    [anon_sym_AMP] = ACTIONS(1659),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1663),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1665),
    [anon_sym_DOT_DOT] = ACTIONS(1667),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1812] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6915),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7099),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5741),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4224),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7442),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9174),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1812),
    [sym_preproc_endregion] = STATE(1812),
    [sym_preproc_line] = STATE(1812),
    [sym_preproc_pragma] = STATE(1812),
    [sym_preproc_nullable] = STATE(1812),
    [sym_preproc_error] = STATE(1812),
    [sym_preproc_warning] = STATE(1812),
    [sym_preproc_define] = STATE(1812),
    [sym_preproc_undef] = STATE(1812),
    [aux_sym_class_declaration_repeat1] = STATE(3849),
    [aux_sym_lambda_expression_repeat1] = STATE(4284),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1653),
    [anon_sym_ref] = ACTIONS(1655),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1659),
    [anon_sym_TILDE] = ACTIONS(1659),
    [anon_sym_PLUS_PLUS] = ACTIONS(1659),
    [anon_sym_DASH_DASH] = ACTIONS(1659),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1657),
    [anon_sym_DASH] = ACTIONS(1657),
    [anon_sym_STAR] = ACTIONS(1661),
    [anon_sym_CARET] = ACTIONS(1659),
    [anon_sym_AMP] = ACTIONS(1659),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1663),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1665),
    [anon_sym_DOT_DOT] = ACTIONS(1667),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1813] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6915),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7099),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3867),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4224),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7442),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9174),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1813),
    [sym_preproc_endregion] = STATE(1813),
    [sym_preproc_line] = STATE(1813),
    [sym_preproc_pragma] = STATE(1813),
    [sym_preproc_nullable] = STATE(1813),
    [sym_preproc_error] = STATE(1813),
    [sym_preproc_warning] = STATE(1813),
    [sym_preproc_define] = STATE(1813),
    [sym_preproc_undef] = STATE(1813),
    [aux_sym_class_declaration_repeat1] = STATE(3849),
    [aux_sym_lambda_expression_repeat1] = STATE(4284),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1653),
    [anon_sym_ref] = ACTIONS(1655),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1659),
    [anon_sym_TILDE] = ACTIONS(1659),
    [anon_sym_PLUS_PLUS] = ACTIONS(1659),
    [anon_sym_DASH_DASH] = ACTIONS(1659),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1657),
    [anon_sym_DASH] = ACTIONS(1657),
    [anon_sym_STAR] = ACTIONS(1661),
    [anon_sym_CARET] = ACTIONS(1659),
    [anon_sym_AMP] = ACTIONS(1659),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1663),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1665),
    [anon_sym_DOT_DOT] = ACTIONS(1667),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1814] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6915),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7099),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5746),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4224),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7442),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9174),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1814),
    [sym_preproc_endregion] = STATE(1814),
    [sym_preproc_line] = STATE(1814),
    [sym_preproc_pragma] = STATE(1814),
    [sym_preproc_nullable] = STATE(1814),
    [sym_preproc_error] = STATE(1814),
    [sym_preproc_warning] = STATE(1814),
    [sym_preproc_define] = STATE(1814),
    [sym_preproc_undef] = STATE(1814),
    [aux_sym_class_declaration_repeat1] = STATE(3849),
    [aux_sym_lambda_expression_repeat1] = STATE(4284),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1653),
    [anon_sym_ref] = ACTIONS(1655),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1659),
    [anon_sym_TILDE] = ACTIONS(1659),
    [anon_sym_PLUS_PLUS] = ACTIONS(1659),
    [anon_sym_DASH_DASH] = ACTIONS(1659),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1657),
    [anon_sym_DASH] = ACTIONS(1657),
    [anon_sym_STAR] = ACTIONS(1661),
    [anon_sym_CARET] = ACTIONS(1659),
    [anon_sym_AMP] = ACTIONS(1659),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1663),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1665),
    [anon_sym_DOT_DOT] = ACTIONS(1667),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1815] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6967),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3917),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3813),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9209),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1815),
    [sym_preproc_endregion] = STATE(1815),
    [sym_preproc_line] = STATE(1815),
    [sym_preproc_pragma] = STATE(1815),
    [sym_preproc_nullable] = STATE(1815),
    [sym_preproc_error] = STATE(1815),
    [sym_preproc_warning] = STATE(1815),
    [sym_preproc_define] = STATE(1815),
    [sym_preproc_undef] = STATE(1815),
    [aux_sym_class_declaration_repeat1] = STATE(3814),
    [aux_sym_lambda_expression_repeat1] = STATE(4209),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1323),
    [anon_sym_ref] = ACTIONS(1325),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1083),
    [anon_sym_TILDE] = ACTIONS(1083),
    [anon_sym_PLUS_PLUS] = ACTIONS(1083),
    [anon_sym_DASH_DASH] = ACTIONS(1083),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1085),
    [anon_sym_DASH] = ACTIONS(1085),
    [anon_sym_STAR] = ACTIONS(1335),
    [anon_sym_CARET] = ACTIONS(1083),
    [anon_sym_AMP] = ACTIONS(1083),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1341),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1343),
    [anon_sym_DOT_DOT] = ACTIONS(1345),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1816] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7105),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6713),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3500),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1816),
    [sym_preproc_endregion] = STATE(1816),
    [sym_preproc_line] = STATE(1816),
    [sym_preproc_pragma] = STATE(1816),
    [sym_preproc_nullable] = STATE(1816),
    [sym_preproc_error] = STATE(1816),
    [sym_preproc_warning] = STATE(1816),
    [sym_preproc_define] = STATE(1816),
    [sym_preproc_undef] = STATE(1816),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(2983),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(1335),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1817] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6922),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2984),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7155),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6457),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4541),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7435),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9148),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1817),
    [sym_preproc_endregion] = STATE(1817),
    [sym_preproc_line] = STATE(1817),
    [sym_preproc_pragma] = STATE(1817),
    [sym_preproc_nullable] = STATE(1817),
    [sym_preproc_error] = STATE(1817),
    [sym_preproc_warning] = STATE(1817),
    [sym_preproc_define] = STATE(1817),
    [sym_preproc_undef] = STATE(1817),
    [aux_sym_class_declaration_repeat1] = STATE(3876),
    [aux_sym_lambda_expression_repeat1] = STATE(4317),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2231),
    [anon_sym_ref] = ACTIONS(2233),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2235),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2239),
    [anon_sym_TILDE] = ACTIONS(2239),
    [anon_sym_PLUS_PLUS] = ACTIONS(2239),
    [anon_sym_DASH_DASH] = ACTIONS(2239),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2237),
    [anon_sym_DASH] = ACTIONS(2237),
    [anon_sym_STAR] = ACTIONS(2241),
    [anon_sym_CARET] = ACTIONS(2239),
    [anon_sym_AMP] = ACTIONS(2239),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2243),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2245),
    [anon_sym_DOT_DOT] = ACTIONS(2247),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1818] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6922),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2984),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7155),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4336),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4541),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7435),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9148),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1818),
    [sym_preproc_endregion] = STATE(1818),
    [sym_preproc_line] = STATE(1818),
    [sym_preproc_pragma] = STATE(1818),
    [sym_preproc_nullable] = STATE(1818),
    [sym_preproc_error] = STATE(1818),
    [sym_preproc_warning] = STATE(1818),
    [sym_preproc_define] = STATE(1818),
    [sym_preproc_undef] = STATE(1818),
    [aux_sym_class_declaration_repeat1] = STATE(3876),
    [aux_sym_lambda_expression_repeat1] = STATE(4317),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2231),
    [anon_sym_ref] = ACTIONS(2233),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2235),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2239),
    [anon_sym_TILDE] = ACTIONS(2239),
    [anon_sym_PLUS_PLUS] = ACTIONS(2239),
    [anon_sym_DASH_DASH] = ACTIONS(2239),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2237),
    [anon_sym_DASH] = ACTIONS(2237),
    [anon_sym_STAR] = ACTIONS(2241),
    [anon_sym_CARET] = ACTIONS(2239),
    [anon_sym_AMP] = ACTIONS(2239),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2243),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2245),
    [anon_sym_DOT_DOT] = ACTIONS(2247),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1819] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6922),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2984),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7155),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6584),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4541),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7435),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9148),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1819),
    [sym_preproc_endregion] = STATE(1819),
    [sym_preproc_line] = STATE(1819),
    [sym_preproc_pragma] = STATE(1819),
    [sym_preproc_nullable] = STATE(1819),
    [sym_preproc_error] = STATE(1819),
    [sym_preproc_warning] = STATE(1819),
    [sym_preproc_define] = STATE(1819),
    [sym_preproc_undef] = STATE(1819),
    [aux_sym_class_declaration_repeat1] = STATE(3876),
    [aux_sym_lambda_expression_repeat1] = STATE(4317),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2231),
    [anon_sym_ref] = ACTIONS(2233),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2235),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2239),
    [anon_sym_TILDE] = ACTIONS(2239),
    [anon_sym_PLUS_PLUS] = ACTIONS(2239),
    [anon_sym_DASH_DASH] = ACTIONS(2239),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2237),
    [anon_sym_DASH] = ACTIONS(2237),
    [anon_sym_STAR] = ACTIONS(2241),
    [anon_sym_CARET] = ACTIONS(2239),
    [anon_sym_AMP] = ACTIONS(2239),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2243),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2245),
    [anon_sym_DOT_DOT] = ACTIONS(2247),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1820] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6922),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2984),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7155),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6589),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4541),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7435),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9148),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1820),
    [sym_preproc_endregion] = STATE(1820),
    [sym_preproc_line] = STATE(1820),
    [sym_preproc_pragma] = STATE(1820),
    [sym_preproc_nullable] = STATE(1820),
    [sym_preproc_error] = STATE(1820),
    [sym_preproc_warning] = STATE(1820),
    [sym_preproc_define] = STATE(1820),
    [sym_preproc_undef] = STATE(1820),
    [aux_sym_class_declaration_repeat1] = STATE(3876),
    [aux_sym_lambda_expression_repeat1] = STATE(4317),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2231),
    [anon_sym_ref] = ACTIONS(2233),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2235),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2239),
    [anon_sym_TILDE] = ACTIONS(2239),
    [anon_sym_PLUS_PLUS] = ACTIONS(2239),
    [anon_sym_DASH_DASH] = ACTIONS(2239),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2237),
    [anon_sym_DASH] = ACTIONS(2237),
    [anon_sym_STAR] = ACTIONS(2241),
    [anon_sym_CARET] = ACTIONS(2239),
    [anon_sym_AMP] = ACTIONS(2239),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2243),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2245),
    [anon_sym_DOT_DOT] = ACTIONS(2247),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1821] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6922),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2984),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7155),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6591),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4541),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7435),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9148),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1821),
    [sym_preproc_endregion] = STATE(1821),
    [sym_preproc_line] = STATE(1821),
    [sym_preproc_pragma] = STATE(1821),
    [sym_preproc_nullable] = STATE(1821),
    [sym_preproc_error] = STATE(1821),
    [sym_preproc_warning] = STATE(1821),
    [sym_preproc_define] = STATE(1821),
    [sym_preproc_undef] = STATE(1821),
    [aux_sym_class_declaration_repeat1] = STATE(3876),
    [aux_sym_lambda_expression_repeat1] = STATE(4317),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2231),
    [anon_sym_ref] = ACTIONS(2233),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2235),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2239),
    [anon_sym_TILDE] = ACTIONS(2239),
    [anon_sym_PLUS_PLUS] = ACTIONS(2239),
    [anon_sym_DASH_DASH] = ACTIONS(2239),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2237),
    [anon_sym_DASH] = ACTIONS(2237),
    [anon_sym_STAR] = ACTIONS(2241),
    [anon_sym_CARET] = ACTIONS(2239),
    [anon_sym_AMP] = ACTIONS(2239),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2243),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2245),
    [anon_sym_DOT_DOT] = ACTIONS(2247),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1822] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6922),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2984),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7155),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6592),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4541),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7435),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9148),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1822),
    [sym_preproc_endregion] = STATE(1822),
    [sym_preproc_line] = STATE(1822),
    [sym_preproc_pragma] = STATE(1822),
    [sym_preproc_nullable] = STATE(1822),
    [sym_preproc_error] = STATE(1822),
    [sym_preproc_warning] = STATE(1822),
    [sym_preproc_define] = STATE(1822),
    [sym_preproc_undef] = STATE(1822),
    [aux_sym_class_declaration_repeat1] = STATE(3876),
    [aux_sym_lambda_expression_repeat1] = STATE(4317),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2231),
    [anon_sym_ref] = ACTIONS(2233),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2235),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2239),
    [anon_sym_TILDE] = ACTIONS(2239),
    [anon_sym_PLUS_PLUS] = ACTIONS(2239),
    [anon_sym_DASH_DASH] = ACTIONS(2239),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2237),
    [anon_sym_DASH] = ACTIONS(2237),
    [anon_sym_STAR] = ACTIONS(2241),
    [anon_sym_CARET] = ACTIONS(2239),
    [anon_sym_AMP] = ACTIONS(2239),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2243),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2245),
    [anon_sym_DOT_DOT] = ACTIONS(2247),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1823] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6922),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2984),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7155),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6593),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4541),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7435),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9148),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1823),
    [sym_preproc_endregion] = STATE(1823),
    [sym_preproc_line] = STATE(1823),
    [sym_preproc_pragma] = STATE(1823),
    [sym_preproc_nullable] = STATE(1823),
    [sym_preproc_error] = STATE(1823),
    [sym_preproc_warning] = STATE(1823),
    [sym_preproc_define] = STATE(1823),
    [sym_preproc_undef] = STATE(1823),
    [aux_sym_class_declaration_repeat1] = STATE(3876),
    [aux_sym_lambda_expression_repeat1] = STATE(4317),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2231),
    [anon_sym_ref] = ACTIONS(2233),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2235),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2239),
    [anon_sym_TILDE] = ACTIONS(2239),
    [anon_sym_PLUS_PLUS] = ACTIONS(2239),
    [anon_sym_DASH_DASH] = ACTIONS(2239),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2237),
    [anon_sym_DASH] = ACTIONS(2237),
    [anon_sym_STAR] = ACTIONS(2241),
    [anon_sym_CARET] = ACTIONS(2239),
    [anon_sym_AMP] = ACTIONS(2239),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2243),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2245),
    [anon_sym_DOT_DOT] = ACTIONS(2247),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1824] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6922),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2984),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7155),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6594),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4541),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7435),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9148),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1824),
    [sym_preproc_endregion] = STATE(1824),
    [sym_preproc_line] = STATE(1824),
    [sym_preproc_pragma] = STATE(1824),
    [sym_preproc_nullable] = STATE(1824),
    [sym_preproc_error] = STATE(1824),
    [sym_preproc_warning] = STATE(1824),
    [sym_preproc_define] = STATE(1824),
    [sym_preproc_undef] = STATE(1824),
    [aux_sym_class_declaration_repeat1] = STATE(3876),
    [aux_sym_lambda_expression_repeat1] = STATE(4317),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2231),
    [anon_sym_ref] = ACTIONS(2233),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2235),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2239),
    [anon_sym_TILDE] = ACTIONS(2239),
    [anon_sym_PLUS_PLUS] = ACTIONS(2239),
    [anon_sym_DASH_DASH] = ACTIONS(2239),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2237),
    [anon_sym_DASH] = ACTIONS(2237),
    [anon_sym_STAR] = ACTIONS(2241),
    [anon_sym_CARET] = ACTIONS(2239),
    [anon_sym_AMP] = ACTIONS(2239),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2243),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2245),
    [anon_sym_DOT_DOT] = ACTIONS(2247),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1825] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6922),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2984),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7155),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6604),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4541),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7435),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9148),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1825),
    [sym_preproc_endregion] = STATE(1825),
    [sym_preproc_line] = STATE(1825),
    [sym_preproc_pragma] = STATE(1825),
    [sym_preproc_nullable] = STATE(1825),
    [sym_preproc_error] = STATE(1825),
    [sym_preproc_warning] = STATE(1825),
    [sym_preproc_define] = STATE(1825),
    [sym_preproc_undef] = STATE(1825),
    [aux_sym_class_declaration_repeat1] = STATE(3876),
    [aux_sym_lambda_expression_repeat1] = STATE(4317),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2231),
    [anon_sym_ref] = ACTIONS(2233),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2235),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2239),
    [anon_sym_TILDE] = ACTIONS(2239),
    [anon_sym_PLUS_PLUS] = ACTIONS(2239),
    [anon_sym_DASH_DASH] = ACTIONS(2239),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2237),
    [anon_sym_DASH] = ACTIONS(2237),
    [anon_sym_STAR] = ACTIONS(2241),
    [anon_sym_CARET] = ACTIONS(2239),
    [anon_sym_AMP] = ACTIONS(2239),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2243),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2245),
    [anon_sym_DOT_DOT] = ACTIONS(2247),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1826] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6922),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2984),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7155),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6606),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4541),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7435),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9148),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1826),
    [sym_preproc_endregion] = STATE(1826),
    [sym_preproc_line] = STATE(1826),
    [sym_preproc_pragma] = STATE(1826),
    [sym_preproc_nullable] = STATE(1826),
    [sym_preproc_error] = STATE(1826),
    [sym_preproc_warning] = STATE(1826),
    [sym_preproc_define] = STATE(1826),
    [sym_preproc_undef] = STATE(1826),
    [aux_sym_class_declaration_repeat1] = STATE(3876),
    [aux_sym_lambda_expression_repeat1] = STATE(4317),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2231),
    [anon_sym_ref] = ACTIONS(2233),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2235),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2239),
    [anon_sym_TILDE] = ACTIONS(2239),
    [anon_sym_PLUS_PLUS] = ACTIONS(2239),
    [anon_sym_DASH_DASH] = ACTIONS(2239),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2237),
    [anon_sym_DASH] = ACTIONS(2237),
    [anon_sym_STAR] = ACTIONS(2241),
    [anon_sym_CARET] = ACTIONS(2239),
    [anon_sym_AMP] = ACTIONS(2239),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2243),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2245),
    [anon_sym_DOT_DOT] = ACTIONS(2247),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1827] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6922),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2984),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7155),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6608),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4541),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7435),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9148),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1827),
    [sym_preproc_endregion] = STATE(1827),
    [sym_preproc_line] = STATE(1827),
    [sym_preproc_pragma] = STATE(1827),
    [sym_preproc_nullable] = STATE(1827),
    [sym_preproc_error] = STATE(1827),
    [sym_preproc_warning] = STATE(1827),
    [sym_preproc_define] = STATE(1827),
    [sym_preproc_undef] = STATE(1827),
    [aux_sym_class_declaration_repeat1] = STATE(3876),
    [aux_sym_lambda_expression_repeat1] = STATE(4317),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2231),
    [anon_sym_ref] = ACTIONS(2233),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2235),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2239),
    [anon_sym_TILDE] = ACTIONS(2239),
    [anon_sym_PLUS_PLUS] = ACTIONS(2239),
    [anon_sym_DASH_DASH] = ACTIONS(2239),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2237),
    [anon_sym_DASH] = ACTIONS(2237),
    [anon_sym_STAR] = ACTIONS(2241),
    [anon_sym_CARET] = ACTIONS(2239),
    [anon_sym_AMP] = ACTIONS(2239),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2243),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2245),
    [anon_sym_DOT_DOT] = ACTIONS(2247),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1828] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6922),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2984),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7155),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6609),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4541),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7435),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9148),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1828),
    [sym_preproc_endregion] = STATE(1828),
    [sym_preproc_line] = STATE(1828),
    [sym_preproc_pragma] = STATE(1828),
    [sym_preproc_nullable] = STATE(1828),
    [sym_preproc_error] = STATE(1828),
    [sym_preproc_warning] = STATE(1828),
    [sym_preproc_define] = STATE(1828),
    [sym_preproc_undef] = STATE(1828),
    [aux_sym_class_declaration_repeat1] = STATE(3876),
    [aux_sym_lambda_expression_repeat1] = STATE(4317),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2231),
    [anon_sym_ref] = ACTIONS(2233),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2235),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2239),
    [anon_sym_TILDE] = ACTIONS(2239),
    [anon_sym_PLUS_PLUS] = ACTIONS(2239),
    [anon_sym_DASH_DASH] = ACTIONS(2239),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2237),
    [anon_sym_DASH] = ACTIONS(2237),
    [anon_sym_STAR] = ACTIONS(2241),
    [anon_sym_CARET] = ACTIONS(2239),
    [anon_sym_AMP] = ACTIONS(2239),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2243),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2245),
    [anon_sym_DOT_DOT] = ACTIONS(2247),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1829] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6922),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2984),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7155),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6610),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4541),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7435),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9148),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1829),
    [sym_preproc_endregion] = STATE(1829),
    [sym_preproc_line] = STATE(1829),
    [sym_preproc_pragma] = STATE(1829),
    [sym_preproc_nullable] = STATE(1829),
    [sym_preproc_error] = STATE(1829),
    [sym_preproc_warning] = STATE(1829),
    [sym_preproc_define] = STATE(1829),
    [sym_preproc_undef] = STATE(1829),
    [aux_sym_class_declaration_repeat1] = STATE(3876),
    [aux_sym_lambda_expression_repeat1] = STATE(4317),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2231),
    [anon_sym_ref] = ACTIONS(2233),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2235),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2239),
    [anon_sym_TILDE] = ACTIONS(2239),
    [anon_sym_PLUS_PLUS] = ACTIONS(2239),
    [anon_sym_DASH_DASH] = ACTIONS(2239),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2237),
    [anon_sym_DASH] = ACTIONS(2237),
    [anon_sym_STAR] = ACTIONS(2241),
    [anon_sym_CARET] = ACTIONS(2239),
    [anon_sym_AMP] = ACTIONS(2239),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2243),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2245),
    [anon_sym_DOT_DOT] = ACTIONS(2247),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1830] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6922),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2984),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7155),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6459),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4541),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7435),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9148),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1830),
    [sym_preproc_endregion] = STATE(1830),
    [sym_preproc_line] = STATE(1830),
    [sym_preproc_pragma] = STATE(1830),
    [sym_preproc_nullable] = STATE(1830),
    [sym_preproc_error] = STATE(1830),
    [sym_preproc_warning] = STATE(1830),
    [sym_preproc_define] = STATE(1830),
    [sym_preproc_undef] = STATE(1830),
    [aux_sym_class_declaration_repeat1] = STATE(3876),
    [aux_sym_lambda_expression_repeat1] = STATE(4317),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2231),
    [anon_sym_ref] = ACTIONS(2233),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2235),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2239),
    [anon_sym_TILDE] = ACTIONS(2239),
    [anon_sym_PLUS_PLUS] = ACTIONS(2239),
    [anon_sym_DASH_DASH] = ACTIONS(2239),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2237),
    [anon_sym_DASH] = ACTIONS(2237),
    [anon_sym_STAR] = ACTIONS(2241),
    [anon_sym_CARET] = ACTIONS(2239),
    [anon_sym_AMP] = ACTIONS(2239),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2243),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2245),
    [anon_sym_DOT_DOT] = ACTIONS(2247),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1831] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6914),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2960),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7049),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6148),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4399),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7440),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9013),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1831),
    [sym_preproc_endregion] = STATE(1831),
    [sym_preproc_line] = STATE(1831),
    [sym_preproc_pragma] = STATE(1831),
    [sym_preproc_nullable] = STATE(1831),
    [sym_preproc_error] = STATE(1831),
    [sym_preproc_warning] = STATE(1831),
    [sym_preproc_define] = STATE(1831),
    [sym_preproc_undef] = STATE(1831),
    [aux_sym_class_declaration_repeat1] = STATE(3833),
    [aux_sym_lambda_expression_repeat1] = STATE(4261),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2151),
    [anon_sym_ref] = ACTIONS(2153),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2155),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2159),
    [anon_sym_TILDE] = ACTIONS(2159),
    [anon_sym_PLUS_PLUS] = ACTIONS(2159),
    [anon_sym_DASH_DASH] = ACTIONS(2159),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2157),
    [anon_sym_DASH] = ACTIONS(2157),
    [anon_sym_STAR] = ACTIONS(2161),
    [anon_sym_CARET] = ACTIONS(2159),
    [anon_sym_AMP] = ACTIONS(2159),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2163),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2165),
    [anon_sym_DOT_DOT] = ACTIONS(2167),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1832] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6922),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2984),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7155),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4338),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4541),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7435),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9148),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1832),
    [sym_preproc_endregion] = STATE(1832),
    [sym_preproc_line] = STATE(1832),
    [sym_preproc_pragma] = STATE(1832),
    [sym_preproc_nullable] = STATE(1832),
    [sym_preproc_error] = STATE(1832),
    [sym_preproc_warning] = STATE(1832),
    [sym_preproc_define] = STATE(1832),
    [sym_preproc_undef] = STATE(1832),
    [aux_sym_class_declaration_repeat1] = STATE(3876),
    [aux_sym_lambda_expression_repeat1] = STATE(4317),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2231),
    [anon_sym_ref] = ACTIONS(2233),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2235),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2239),
    [anon_sym_TILDE] = ACTIONS(2239),
    [anon_sym_PLUS_PLUS] = ACTIONS(2239),
    [anon_sym_DASH_DASH] = ACTIONS(2239),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2237),
    [anon_sym_DASH] = ACTIONS(2237),
    [anon_sym_STAR] = ACTIONS(2241),
    [anon_sym_CARET] = ACTIONS(2239),
    [anon_sym_AMP] = ACTIONS(2239),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2243),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2245),
    [anon_sym_DOT_DOT] = ACTIONS(2247),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1833] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6922),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2984),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7069),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6060),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4344),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7423),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9604),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1833),
    [sym_preproc_endregion] = STATE(1833),
    [sym_preproc_line] = STATE(1833),
    [sym_preproc_pragma] = STATE(1833),
    [sym_preproc_nullable] = STATE(1833),
    [sym_preproc_error] = STATE(1833),
    [sym_preproc_warning] = STATE(1833),
    [sym_preproc_define] = STATE(1833),
    [sym_preproc_undef] = STATE(1833),
    [aux_sym_class_declaration_repeat1] = STATE(3841),
    [aux_sym_lambda_expression_repeat1] = STATE(4271),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1875),
    [anon_sym_ref] = ACTIONS(1877),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1879),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1883),
    [anon_sym_TILDE] = ACTIONS(1883),
    [anon_sym_PLUS_PLUS] = ACTIONS(1883),
    [anon_sym_DASH_DASH] = ACTIONS(1883),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1881),
    [anon_sym_DASH] = ACTIONS(1881),
    [anon_sym_STAR] = ACTIONS(1885),
    [anon_sym_CARET] = ACTIONS(1883),
    [anon_sym_AMP] = ACTIONS(1883),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1887),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1889),
    [anon_sym_DOT_DOT] = ACTIONS(1891),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1834] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6922),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2984),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7155),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6626),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4541),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7435),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9148),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1834),
    [sym_preproc_endregion] = STATE(1834),
    [sym_preproc_line] = STATE(1834),
    [sym_preproc_pragma] = STATE(1834),
    [sym_preproc_nullable] = STATE(1834),
    [sym_preproc_error] = STATE(1834),
    [sym_preproc_warning] = STATE(1834),
    [sym_preproc_define] = STATE(1834),
    [sym_preproc_undef] = STATE(1834),
    [aux_sym_class_declaration_repeat1] = STATE(3876),
    [aux_sym_lambda_expression_repeat1] = STATE(4317),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2231),
    [anon_sym_ref] = ACTIONS(2233),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2235),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2239),
    [anon_sym_TILDE] = ACTIONS(2239),
    [anon_sym_PLUS_PLUS] = ACTIONS(2239),
    [anon_sym_DASH_DASH] = ACTIONS(2239),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2237),
    [anon_sym_DASH] = ACTIONS(2237),
    [anon_sym_STAR] = ACTIONS(2241),
    [anon_sym_CARET] = ACTIONS(2239),
    [anon_sym_AMP] = ACTIONS(2239),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2243),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2245),
    [anon_sym_DOT_DOT] = ACTIONS(2247),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1835] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6914),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2960),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7049),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6151),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4399),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7440),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9013),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1835),
    [sym_preproc_endregion] = STATE(1835),
    [sym_preproc_line] = STATE(1835),
    [sym_preproc_pragma] = STATE(1835),
    [sym_preproc_nullable] = STATE(1835),
    [sym_preproc_error] = STATE(1835),
    [sym_preproc_warning] = STATE(1835),
    [sym_preproc_define] = STATE(1835),
    [sym_preproc_undef] = STATE(1835),
    [aux_sym_class_declaration_repeat1] = STATE(3833),
    [aux_sym_lambda_expression_repeat1] = STATE(4261),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2151),
    [anon_sym_ref] = ACTIONS(2153),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2155),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2159),
    [anon_sym_TILDE] = ACTIONS(2159),
    [anon_sym_PLUS_PLUS] = ACTIONS(2159),
    [anon_sym_DASH_DASH] = ACTIONS(2159),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2157),
    [anon_sym_DASH] = ACTIONS(2157),
    [anon_sym_STAR] = ACTIONS(2161),
    [anon_sym_CARET] = ACTIONS(2159),
    [anon_sym_AMP] = ACTIONS(2159),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2163),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2165),
    [anon_sym_DOT_DOT] = ACTIONS(2167),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1836] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6922),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2984),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7069),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5841),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4344),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7423),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9604),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1836),
    [sym_preproc_endregion] = STATE(1836),
    [sym_preproc_line] = STATE(1836),
    [sym_preproc_pragma] = STATE(1836),
    [sym_preproc_nullable] = STATE(1836),
    [sym_preproc_error] = STATE(1836),
    [sym_preproc_warning] = STATE(1836),
    [sym_preproc_define] = STATE(1836),
    [sym_preproc_undef] = STATE(1836),
    [aux_sym_class_declaration_repeat1] = STATE(3841),
    [aux_sym_lambda_expression_repeat1] = STATE(4271),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1875),
    [anon_sym_ref] = ACTIONS(1877),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1879),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1883),
    [anon_sym_TILDE] = ACTIONS(1883),
    [anon_sym_PLUS_PLUS] = ACTIONS(1883),
    [anon_sym_DASH_DASH] = ACTIONS(1883),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1881),
    [anon_sym_DASH] = ACTIONS(1881),
    [anon_sym_STAR] = ACTIONS(1885),
    [anon_sym_CARET] = ACTIONS(1883),
    [anon_sym_AMP] = ACTIONS(1883),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1887),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1889),
    [anon_sym_DOT_DOT] = ACTIONS(1891),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1837] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6922),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2984),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7069),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5842),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4344),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7423),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9604),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1837),
    [sym_preproc_endregion] = STATE(1837),
    [sym_preproc_line] = STATE(1837),
    [sym_preproc_pragma] = STATE(1837),
    [sym_preproc_nullable] = STATE(1837),
    [sym_preproc_error] = STATE(1837),
    [sym_preproc_warning] = STATE(1837),
    [sym_preproc_define] = STATE(1837),
    [sym_preproc_undef] = STATE(1837),
    [aux_sym_class_declaration_repeat1] = STATE(3841),
    [aux_sym_lambda_expression_repeat1] = STATE(4271),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1875),
    [anon_sym_ref] = ACTIONS(1877),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1879),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1883),
    [anon_sym_TILDE] = ACTIONS(1883),
    [anon_sym_PLUS_PLUS] = ACTIONS(1883),
    [anon_sym_DASH_DASH] = ACTIONS(1883),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1881),
    [anon_sym_DASH] = ACTIONS(1881),
    [anon_sym_STAR] = ACTIONS(1885),
    [anon_sym_CARET] = ACTIONS(1883),
    [anon_sym_AMP] = ACTIONS(1883),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1887),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1889),
    [anon_sym_DOT_DOT] = ACTIONS(1891),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1838] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6922),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2984),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7069),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6057),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4344),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7423),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9604),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1838),
    [sym_preproc_endregion] = STATE(1838),
    [sym_preproc_line] = STATE(1838),
    [sym_preproc_pragma] = STATE(1838),
    [sym_preproc_nullable] = STATE(1838),
    [sym_preproc_error] = STATE(1838),
    [sym_preproc_warning] = STATE(1838),
    [sym_preproc_define] = STATE(1838),
    [sym_preproc_undef] = STATE(1838),
    [aux_sym_class_declaration_repeat1] = STATE(3841),
    [aux_sym_lambda_expression_repeat1] = STATE(4271),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1875),
    [anon_sym_ref] = ACTIONS(1877),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1879),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1883),
    [anon_sym_TILDE] = ACTIONS(1883),
    [anon_sym_PLUS_PLUS] = ACTIONS(1883),
    [anon_sym_DASH_DASH] = ACTIONS(1883),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1881),
    [anon_sym_DASH] = ACTIONS(1881),
    [anon_sym_STAR] = ACTIONS(1885),
    [anon_sym_CARET] = ACTIONS(1883),
    [anon_sym_AMP] = ACTIONS(1883),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1887),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1889),
    [anon_sym_DOT_DOT] = ACTIONS(1891),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1839] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6922),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2984),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7069),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5843),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4344),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7423),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9604),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1839),
    [sym_preproc_endregion] = STATE(1839),
    [sym_preproc_line] = STATE(1839),
    [sym_preproc_pragma] = STATE(1839),
    [sym_preproc_nullable] = STATE(1839),
    [sym_preproc_error] = STATE(1839),
    [sym_preproc_warning] = STATE(1839),
    [sym_preproc_define] = STATE(1839),
    [sym_preproc_undef] = STATE(1839),
    [aux_sym_class_declaration_repeat1] = STATE(3841),
    [aux_sym_lambda_expression_repeat1] = STATE(4271),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1875),
    [anon_sym_ref] = ACTIONS(1877),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1879),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1883),
    [anon_sym_TILDE] = ACTIONS(1883),
    [anon_sym_PLUS_PLUS] = ACTIONS(1883),
    [anon_sym_DASH_DASH] = ACTIONS(1883),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1881),
    [anon_sym_DASH] = ACTIONS(1881),
    [anon_sym_STAR] = ACTIONS(1885),
    [anon_sym_CARET] = ACTIONS(1883),
    [anon_sym_AMP] = ACTIONS(1883),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1887),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1889),
    [anon_sym_DOT_DOT] = ACTIONS(1891),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1840] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6922),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2984),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7069),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5844),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4344),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7423),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9604),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1840),
    [sym_preproc_endregion] = STATE(1840),
    [sym_preproc_line] = STATE(1840),
    [sym_preproc_pragma] = STATE(1840),
    [sym_preproc_nullable] = STATE(1840),
    [sym_preproc_error] = STATE(1840),
    [sym_preproc_warning] = STATE(1840),
    [sym_preproc_define] = STATE(1840),
    [sym_preproc_undef] = STATE(1840),
    [aux_sym_class_declaration_repeat1] = STATE(3841),
    [aux_sym_lambda_expression_repeat1] = STATE(4271),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1875),
    [anon_sym_ref] = ACTIONS(1877),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1879),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1883),
    [anon_sym_TILDE] = ACTIONS(1883),
    [anon_sym_PLUS_PLUS] = ACTIONS(1883),
    [anon_sym_DASH_DASH] = ACTIONS(1883),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1881),
    [anon_sym_DASH] = ACTIONS(1881),
    [anon_sym_STAR] = ACTIONS(1885),
    [anon_sym_CARET] = ACTIONS(1883),
    [anon_sym_AMP] = ACTIONS(1883),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1887),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1889),
    [anon_sym_DOT_DOT] = ACTIONS(1891),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1841] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6922),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2984),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7069),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5845),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4344),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7423),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9604),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1841),
    [sym_preproc_endregion] = STATE(1841),
    [sym_preproc_line] = STATE(1841),
    [sym_preproc_pragma] = STATE(1841),
    [sym_preproc_nullable] = STATE(1841),
    [sym_preproc_error] = STATE(1841),
    [sym_preproc_warning] = STATE(1841),
    [sym_preproc_define] = STATE(1841),
    [sym_preproc_undef] = STATE(1841),
    [aux_sym_class_declaration_repeat1] = STATE(3841),
    [aux_sym_lambda_expression_repeat1] = STATE(4271),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1875),
    [anon_sym_ref] = ACTIONS(1877),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1879),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1883),
    [anon_sym_TILDE] = ACTIONS(1883),
    [anon_sym_PLUS_PLUS] = ACTIONS(1883),
    [anon_sym_DASH_DASH] = ACTIONS(1883),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1881),
    [anon_sym_DASH] = ACTIONS(1881),
    [anon_sym_STAR] = ACTIONS(1885),
    [anon_sym_CARET] = ACTIONS(1883),
    [anon_sym_AMP] = ACTIONS(1883),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1887),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1889),
    [anon_sym_DOT_DOT] = ACTIONS(1891),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1842] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6922),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2984),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7069),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5846),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4344),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7423),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9604),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1842),
    [sym_preproc_endregion] = STATE(1842),
    [sym_preproc_line] = STATE(1842),
    [sym_preproc_pragma] = STATE(1842),
    [sym_preproc_nullable] = STATE(1842),
    [sym_preproc_error] = STATE(1842),
    [sym_preproc_warning] = STATE(1842),
    [sym_preproc_define] = STATE(1842),
    [sym_preproc_undef] = STATE(1842),
    [aux_sym_class_declaration_repeat1] = STATE(3841),
    [aux_sym_lambda_expression_repeat1] = STATE(4271),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1875),
    [anon_sym_ref] = ACTIONS(1877),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1879),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1883),
    [anon_sym_TILDE] = ACTIONS(1883),
    [anon_sym_PLUS_PLUS] = ACTIONS(1883),
    [anon_sym_DASH_DASH] = ACTIONS(1883),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1881),
    [anon_sym_DASH] = ACTIONS(1881),
    [anon_sym_STAR] = ACTIONS(1885),
    [anon_sym_CARET] = ACTIONS(1883),
    [anon_sym_AMP] = ACTIONS(1883),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1887),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1889),
    [anon_sym_DOT_DOT] = ACTIONS(1891),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1843] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6922),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2984),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7069),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5847),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4344),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7423),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9604),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1843),
    [sym_preproc_endregion] = STATE(1843),
    [sym_preproc_line] = STATE(1843),
    [sym_preproc_pragma] = STATE(1843),
    [sym_preproc_nullable] = STATE(1843),
    [sym_preproc_error] = STATE(1843),
    [sym_preproc_warning] = STATE(1843),
    [sym_preproc_define] = STATE(1843),
    [sym_preproc_undef] = STATE(1843),
    [aux_sym_class_declaration_repeat1] = STATE(3841),
    [aux_sym_lambda_expression_repeat1] = STATE(4271),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1875),
    [anon_sym_ref] = ACTIONS(1877),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1879),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1883),
    [anon_sym_TILDE] = ACTIONS(1883),
    [anon_sym_PLUS_PLUS] = ACTIONS(1883),
    [anon_sym_DASH_DASH] = ACTIONS(1883),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1881),
    [anon_sym_DASH] = ACTIONS(1881),
    [anon_sym_STAR] = ACTIONS(1885),
    [anon_sym_CARET] = ACTIONS(1883),
    [anon_sym_AMP] = ACTIONS(1883),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1887),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1889),
    [anon_sym_DOT_DOT] = ACTIONS(1891),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1844] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6922),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2984),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7069),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5848),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4344),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7423),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9604),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1844),
    [sym_preproc_endregion] = STATE(1844),
    [sym_preproc_line] = STATE(1844),
    [sym_preproc_pragma] = STATE(1844),
    [sym_preproc_nullable] = STATE(1844),
    [sym_preproc_error] = STATE(1844),
    [sym_preproc_warning] = STATE(1844),
    [sym_preproc_define] = STATE(1844),
    [sym_preproc_undef] = STATE(1844),
    [aux_sym_class_declaration_repeat1] = STATE(3841),
    [aux_sym_lambda_expression_repeat1] = STATE(4271),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1875),
    [anon_sym_ref] = ACTIONS(1877),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1879),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1883),
    [anon_sym_TILDE] = ACTIONS(1883),
    [anon_sym_PLUS_PLUS] = ACTIONS(1883),
    [anon_sym_DASH_DASH] = ACTIONS(1883),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1881),
    [anon_sym_DASH] = ACTIONS(1881),
    [anon_sym_STAR] = ACTIONS(1885),
    [anon_sym_CARET] = ACTIONS(1883),
    [anon_sym_AMP] = ACTIONS(1883),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1887),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1889),
    [anon_sym_DOT_DOT] = ACTIONS(1891),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1845] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6922),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2984),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7069),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5849),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4344),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7423),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9604),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1845),
    [sym_preproc_endregion] = STATE(1845),
    [sym_preproc_line] = STATE(1845),
    [sym_preproc_pragma] = STATE(1845),
    [sym_preproc_nullable] = STATE(1845),
    [sym_preproc_error] = STATE(1845),
    [sym_preproc_warning] = STATE(1845),
    [sym_preproc_define] = STATE(1845),
    [sym_preproc_undef] = STATE(1845),
    [aux_sym_class_declaration_repeat1] = STATE(3841),
    [aux_sym_lambda_expression_repeat1] = STATE(4271),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1875),
    [anon_sym_ref] = ACTIONS(1877),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1879),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1883),
    [anon_sym_TILDE] = ACTIONS(1883),
    [anon_sym_PLUS_PLUS] = ACTIONS(1883),
    [anon_sym_DASH_DASH] = ACTIONS(1883),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1881),
    [anon_sym_DASH] = ACTIONS(1881),
    [anon_sym_STAR] = ACTIONS(1885),
    [anon_sym_CARET] = ACTIONS(1883),
    [anon_sym_AMP] = ACTIONS(1883),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1887),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1889),
    [anon_sym_DOT_DOT] = ACTIONS(1891),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1846] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6922),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2984),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7069),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5850),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4344),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7423),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9604),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1846),
    [sym_preproc_endregion] = STATE(1846),
    [sym_preproc_line] = STATE(1846),
    [sym_preproc_pragma] = STATE(1846),
    [sym_preproc_nullable] = STATE(1846),
    [sym_preproc_error] = STATE(1846),
    [sym_preproc_warning] = STATE(1846),
    [sym_preproc_define] = STATE(1846),
    [sym_preproc_undef] = STATE(1846),
    [aux_sym_class_declaration_repeat1] = STATE(3841),
    [aux_sym_lambda_expression_repeat1] = STATE(4271),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1875),
    [anon_sym_ref] = ACTIONS(1877),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1879),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1883),
    [anon_sym_TILDE] = ACTIONS(1883),
    [anon_sym_PLUS_PLUS] = ACTIONS(1883),
    [anon_sym_DASH_DASH] = ACTIONS(1883),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1881),
    [anon_sym_DASH] = ACTIONS(1881),
    [anon_sym_STAR] = ACTIONS(1885),
    [anon_sym_CARET] = ACTIONS(1883),
    [anon_sym_AMP] = ACTIONS(1883),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1887),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1889),
    [anon_sym_DOT_DOT] = ACTIONS(1891),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1847] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6922),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2984),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7069),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3932),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4344),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7423),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9604),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1847),
    [sym_preproc_endregion] = STATE(1847),
    [sym_preproc_line] = STATE(1847),
    [sym_preproc_pragma] = STATE(1847),
    [sym_preproc_nullable] = STATE(1847),
    [sym_preproc_error] = STATE(1847),
    [sym_preproc_warning] = STATE(1847),
    [sym_preproc_define] = STATE(1847),
    [sym_preproc_undef] = STATE(1847),
    [aux_sym_class_declaration_repeat1] = STATE(3841),
    [aux_sym_lambda_expression_repeat1] = STATE(4271),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1875),
    [anon_sym_ref] = ACTIONS(1877),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1879),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1883),
    [anon_sym_TILDE] = ACTIONS(1883),
    [anon_sym_PLUS_PLUS] = ACTIONS(1883),
    [anon_sym_DASH_DASH] = ACTIONS(1883),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1881),
    [anon_sym_DASH] = ACTIONS(1881),
    [anon_sym_STAR] = ACTIONS(1885),
    [anon_sym_CARET] = ACTIONS(1883),
    [anon_sym_AMP] = ACTIONS(1883),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1887),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1889),
    [anon_sym_DOT_DOT] = ACTIONS(1891),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1848] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6922),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2984),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7069),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5855),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4344),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7423),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9604),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1848),
    [sym_preproc_endregion] = STATE(1848),
    [sym_preproc_line] = STATE(1848),
    [sym_preproc_pragma] = STATE(1848),
    [sym_preproc_nullable] = STATE(1848),
    [sym_preproc_error] = STATE(1848),
    [sym_preproc_warning] = STATE(1848),
    [sym_preproc_define] = STATE(1848),
    [sym_preproc_undef] = STATE(1848),
    [aux_sym_class_declaration_repeat1] = STATE(3841),
    [aux_sym_lambda_expression_repeat1] = STATE(4271),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1875),
    [anon_sym_ref] = ACTIONS(1877),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1879),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1883),
    [anon_sym_TILDE] = ACTIONS(1883),
    [anon_sym_PLUS_PLUS] = ACTIONS(1883),
    [anon_sym_DASH_DASH] = ACTIONS(1883),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1881),
    [anon_sym_DASH] = ACTIONS(1881),
    [anon_sym_STAR] = ACTIONS(1885),
    [anon_sym_CARET] = ACTIONS(1883),
    [anon_sym_AMP] = ACTIONS(1883),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1887),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1889),
    [anon_sym_DOT_DOT] = ACTIONS(1891),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1849] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6922),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2984),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7069),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3926),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4344),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7423),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9604),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1849),
    [sym_preproc_endregion] = STATE(1849),
    [sym_preproc_line] = STATE(1849),
    [sym_preproc_pragma] = STATE(1849),
    [sym_preproc_nullable] = STATE(1849),
    [sym_preproc_error] = STATE(1849),
    [sym_preproc_warning] = STATE(1849),
    [sym_preproc_define] = STATE(1849),
    [sym_preproc_undef] = STATE(1849),
    [aux_sym_class_declaration_repeat1] = STATE(3841),
    [aux_sym_lambda_expression_repeat1] = STATE(4271),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1875),
    [anon_sym_ref] = ACTIONS(1877),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1879),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1883),
    [anon_sym_TILDE] = ACTIONS(1883),
    [anon_sym_PLUS_PLUS] = ACTIONS(1883),
    [anon_sym_DASH_DASH] = ACTIONS(1883),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1881),
    [anon_sym_DASH] = ACTIONS(1881),
    [anon_sym_STAR] = ACTIONS(1885),
    [anon_sym_CARET] = ACTIONS(1883),
    [anon_sym_AMP] = ACTIONS(1883),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1887),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1889),
    [anon_sym_DOT_DOT] = ACTIONS(1891),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1850] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6922),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2984),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7069),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5857),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4344),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7423),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9604),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1850),
    [sym_preproc_endregion] = STATE(1850),
    [sym_preproc_line] = STATE(1850),
    [sym_preproc_pragma] = STATE(1850),
    [sym_preproc_nullable] = STATE(1850),
    [sym_preproc_error] = STATE(1850),
    [sym_preproc_warning] = STATE(1850),
    [sym_preproc_define] = STATE(1850),
    [sym_preproc_undef] = STATE(1850),
    [aux_sym_class_declaration_repeat1] = STATE(3841),
    [aux_sym_lambda_expression_repeat1] = STATE(4271),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1875),
    [anon_sym_ref] = ACTIONS(1877),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1879),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1883),
    [anon_sym_TILDE] = ACTIONS(1883),
    [anon_sym_PLUS_PLUS] = ACTIONS(1883),
    [anon_sym_DASH_DASH] = ACTIONS(1883),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1881),
    [anon_sym_DASH] = ACTIONS(1881),
    [anon_sym_STAR] = ACTIONS(1885),
    [anon_sym_CARET] = ACTIONS(1883),
    [anon_sym_AMP] = ACTIONS(1883),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1887),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1889),
    [anon_sym_DOT_DOT] = ACTIONS(1891),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1851] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6921),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2873),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(6957),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5165),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4346),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7445),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9875),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(1851),
    [sym_preproc_endregion] = STATE(1851),
    [sym_preproc_line] = STATE(1851),
    [sym_preproc_pragma] = STATE(1851),
    [sym_preproc_nullable] = STATE(1851),
    [sym_preproc_error] = STATE(1851),
    [sym_preproc_warning] = STATE(1851),
    [sym_preproc_define] = STATE(1851),
    [sym_preproc_undef] = STATE(1851),
    [aux_sym_class_declaration_repeat1] = STATE(3810),
    [aux_sym_lambda_expression_repeat1] = STATE(4192),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1639),
    [anon_sym_ref] = ACTIONS(1641),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1415),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1645),
    [anon_sym_TILDE] = ACTIONS(1645),
    [anon_sym_PLUS_PLUS] = ACTIONS(1645),
    [anon_sym_DASH_DASH] = ACTIONS(1645),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1643),
    [anon_sym_DASH] = ACTIONS(1643),
    [anon_sym_STAR] = ACTIONS(1425),
    [anon_sym_CARET] = ACTIONS(1645),
    [anon_sym_AMP] = ACTIONS(1645),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1647),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1649),
    [anon_sym_DOT_DOT] = ACTIONS(1651),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [1852] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6921),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2873),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7105),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6726),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3938),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1852),
    [sym_preproc_endregion] = STATE(1852),
    [sym_preproc_line] = STATE(1852),
    [sym_preproc_pragma] = STATE(1852),
    [sym_preproc_nullable] = STATE(1852),
    [sym_preproc_error] = STATE(1852),
    [sym_preproc_warning] = STATE(1852),
    [sym_preproc_define] = STATE(1852),
    [sym_preproc_undef] = STATE(1852),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(2975),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(1425),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1853] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6922),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2984),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7069),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5861),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4344),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7423),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9604),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1853),
    [sym_preproc_endregion] = STATE(1853),
    [sym_preproc_line] = STATE(1853),
    [sym_preproc_pragma] = STATE(1853),
    [sym_preproc_nullable] = STATE(1853),
    [sym_preproc_error] = STATE(1853),
    [sym_preproc_warning] = STATE(1853),
    [sym_preproc_define] = STATE(1853),
    [sym_preproc_undef] = STATE(1853),
    [aux_sym_class_declaration_repeat1] = STATE(3841),
    [aux_sym_lambda_expression_repeat1] = STATE(4271),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1875),
    [anon_sym_ref] = ACTIONS(1877),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1879),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1883),
    [anon_sym_TILDE] = ACTIONS(1883),
    [anon_sym_PLUS_PLUS] = ACTIONS(1883),
    [anon_sym_DASH_DASH] = ACTIONS(1883),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1881),
    [anon_sym_DASH] = ACTIONS(1881),
    [anon_sym_STAR] = ACTIONS(1885),
    [anon_sym_CARET] = ACTIONS(1883),
    [anon_sym_AMP] = ACTIONS(1883),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1887),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1889),
    [anon_sym_DOT_DOT] = ACTIONS(1891),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1854] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6913),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2905),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6979),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3917),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4178),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7433),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9183),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1854),
    [sym_preproc_endregion] = STATE(1854),
    [sym_preproc_line] = STATE(1854),
    [sym_preproc_pragma] = STATE(1854),
    [sym_preproc_nullable] = STATE(1854),
    [sym_preproc_error] = STATE(1854),
    [sym_preproc_warning] = STATE(1854),
    [sym_preproc_define] = STATE(1854),
    [sym_preproc_undef] = STATE(1854),
    [aux_sym_class_declaration_repeat1] = STATE(3816),
    [aux_sym_lambda_expression_repeat1] = STATE(4225),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1573),
    [anon_sym_ref] = ACTIONS(1575),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1577),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1581),
    [anon_sym_TILDE] = ACTIONS(1581),
    [anon_sym_PLUS_PLUS] = ACTIONS(1581),
    [anon_sym_DASH_DASH] = ACTIONS(1581),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1579),
    [anon_sym_DASH] = ACTIONS(1579),
    [anon_sym_STAR] = ACTIONS(1583),
    [anon_sym_CARET] = ACTIONS(1581),
    [anon_sym_AMP] = ACTIONS(1581),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1585),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1587),
    [anon_sym_DOT_DOT] = ACTIONS(1589),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1855] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6918),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7105),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6717),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3016),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1855),
    [sym_preproc_endregion] = STATE(1855),
    [sym_preproc_line] = STATE(1855),
    [sym_preproc_pragma] = STATE(1855),
    [sym_preproc_nullable] = STATE(1855),
    [sym_preproc_error] = STATE(1855),
    [sym_preproc_warning] = STATE(1855),
    [sym_preproc_define] = STATE(1855),
    [sym_preproc_undef] = STATE(1855),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2981),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(1523),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1856] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7159),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6653),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4487),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7422),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9176),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1856),
    [sym_preproc_endregion] = STATE(1856),
    [sym_preproc_line] = STATE(1856),
    [sym_preproc_pragma] = STATE(1856),
    [sym_preproc_nullable] = STATE(1856),
    [sym_preproc_error] = STATE(1856),
    [sym_preproc_warning] = STATE(1856),
    [sym_preproc_define] = STATE(1856),
    [sym_preproc_undef] = STATE(1856),
    [aux_sym_class_declaration_repeat1] = STATE(3877),
    [aux_sym_lambda_expression_repeat1] = STATE(4320),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1979),
    [anon_sym_ref] = ACTIONS(1981),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1985),
    [anon_sym_TILDE] = ACTIONS(1985),
    [anon_sym_PLUS_PLUS] = ACTIONS(1985),
    [anon_sym_DASH_DASH] = ACTIONS(1985),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1983),
    [anon_sym_DASH] = ACTIONS(1983),
    [anon_sym_STAR] = ACTIONS(1987),
    [anon_sym_CARET] = ACTIONS(1985),
    [anon_sym_AMP] = ACTIONS(1985),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1989),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1991),
    [anon_sym_DOT_DOT] = ACTIONS(1993),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1857] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7159),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4336),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4487),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7422),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9176),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1857),
    [sym_preproc_endregion] = STATE(1857),
    [sym_preproc_line] = STATE(1857),
    [sym_preproc_pragma] = STATE(1857),
    [sym_preproc_nullable] = STATE(1857),
    [sym_preproc_error] = STATE(1857),
    [sym_preproc_warning] = STATE(1857),
    [sym_preproc_define] = STATE(1857),
    [sym_preproc_undef] = STATE(1857),
    [aux_sym_class_declaration_repeat1] = STATE(3877),
    [aux_sym_lambda_expression_repeat1] = STATE(4320),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1979),
    [anon_sym_ref] = ACTIONS(1981),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1985),
    [anon_sym_TILDE] = ACTIONS(1985),
    [anon_sym_PLUS_PLUS] = ACTIONS(1985),
    [anon_sym_DASH_DASH] = ACTIONS(1985),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1983),
    [anon_sym_DASH] = ACTIONS(1983),
    [anon_sym_STAR] = ACTIONS(1987),
    [anon_sym_CARET] = ACTIONS(1985),
    [anon_sym_AMP] = ACTIONS(1985),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1989),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1991),
    [anon_sym_DOT_DOT] = ACTIONS(1993),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1858] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7159),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6316),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4487),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7422),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9176),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1858),
    [sym_preproc_endregion] = STATE(1858),
    [sym_preproc_line] = STATE(1858),
    [sym_preproc_pragma] = STATE(1858),
    [sym_preproc_nullable] = STATE(1858),
    [sym_preproc_error] = STATE(1858),
    [sym_preproc_warning] = STATE(1858),
    [sym_preproc_define] = STATE(1858),
    [sym_preproc_undef] = STATE(1858),
    [aux_sym_class_declaration_repeat1] = STATE(3877),
    [aux_sym_lambda_expression_repeat1] = STATE(4320),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1979),
    [anon_sym_ref] = ACTIONS(1981),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1985),
    [anon_sym_TILDE] = ACTIONS(1985),
    [anon_sym_PLUS_PLUS] = ACTIONS(1985),
    [anon_sym_DASH_DASH] = ACTIONS(1985),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1983),
    [anon_sym_DASH] = ACTIONS(1983),
    [anon_sym_STAR] = ACTIONS(1987),
    [anon_sym_CARET] = ACTIONS(1985),
    [anon_sym_AMP] = ACTIONS(1985),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1989),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1991),
    [anon_sym_DOT_DOT] = ACTIONS(1993),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1859] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7159),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6318),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4487),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7422),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9176),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1859),
    [sym_preproc_endregion] = STATE(1859),
    [sym_preproc_line] = STATE(1859),
    [sym_preproc_pragma] = STATE(1859),
    [sym_preproc_nullable] = STATE(1859),
    [sym_preproc_error] = STATE(1859),
    [sym_preproc_warning] = STATE(1859),
    [sym_preproc_define] = STATE(1859),
    [sym_preproc_undef] = STATE(1859),
    [aux_sym_class_declaration_repeat1] = STATE(3877),
    [aux_sym_lambda_expression_repeat1] = STATE(4320),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1979),
    [anon_sym_ref] = ACTIONS(1981),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1985),
    [anon_sym_TILDE] = ACTIONS(1985),
    [anon_sym_PLUS_PLUS] = ACTIONS(1985),
    [anon_sym_DASH_DASH] = ACTIONS(1985),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1983),
    [anon_sym_DASH] = ACTIONS(1983),
    [anon_sym_STAR] = ACTIONS(1987),
    [anon_sym_CARET] = ACTIONS(1985),
    [anon_sym_AMP] = ACTIONS(1985),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1989),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1991),
    [anon_sym_DOT_DOT] = ACTIONS(1993),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1860] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7159),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6319),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4487),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7422),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9176),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1860),
    [sym_preproc_endregion] = STATE(1860),
    [sym_preproc_line] = STATE(1860),
    [sym_preproc_pragma] = STATE(1860),
    [sym_preproc_nullable] = STATE(1860),
    [sym_preproc_error] = STATE(1860),
    [sym_preproc_warning] = STATE(1860),
    [sym_preproc_define] = STATE(1860),
    [sym_preproc_undef] = STATE(1860),
    [aux_sym_class_declaration_repeat1] = STATE(3877),
    [aux_sym_lambda_expression_repeat1] = STATE(4320),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1979),
    [anon_sym_ref] = ACTIONS(1981),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1985),
    [anon_sym_TILDE] = ACTIONS(1985),
    [anon_sym_PLUS_PLUS] = ACTIONS(1985),
    [anon_sym_DASH_DASH] = ACTIONS(1985),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1983),
    [anon_sym_DASH] = ACTIONS(1983),
    [anon_sym_STAR] = ACTIONS(1987),
    [anon_sym_CARET] = ACTIONS(1985),
    [anon_sym_AMP] = ACTIONS(1985),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1989),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1991),
    [anon_sym_DOT_DOT] = ACTIONS(1993),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1861] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7159),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6320),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4487),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7422),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9176),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1861),
    [sym_preproc_endregion] = STATE(1861),
    [sym_preproc_line] = STATE(1861),
    [sym_preproc_pragma] = STATE(1861),
    [sym_preproc_nullable] = STATE(1861),
    [sym_preproc_error] = STATE(1861),
    [sym_preproc_warning] = STATE(1861),
    [sym_preproc_define] = STATE(1861),
    [sym_preproc_undef] = STATE(1861),
    [aux_sym_class_declaration_repeat1] = STATE(3877),
    [aux_sym_lambda_expression_repeat1] = STATE(4320),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1979),
    [anon_sym_ref] = ACTIONS(1981),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1985),
    [anon_sym_TILDE] = ACTIONS(1985),
    [anon_sym_PLUS_PLUS] = ACTIONS(1985),
    [anon_sym_DASH_DASH] = ACTIONS(1985),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1983),
    [anon_sym_DASH] = ACTIONS(1983),
    [anon_sym_STAR] = ACTIONS(1987),
    [anon_sym_CARET] = ACTIONS(1985),
    [anon_sym_AMP] = ACTIONS(1985),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1989),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1991),
    [anon_sym_DOT_DOT] = ACTIONS(1993),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1862] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7159),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6321),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4487),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7422),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9176),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1862),
    [sym_preproc_endregion] = STATE(1862),
    [sym_preproc_line] = STATE(1862),
    [sym_preproc_pragma] = STATE(1862),
    [sym_preproc_nullable] = STATE(1862),
    [sym_preproc_error] = STATE(1862),
    [sym_preproc_warning] = STATE(1862),
    [sym_preproc_define] = STATE(1862),
    [sym_preproc_undef] = STATE(1862),
    [aux_sym_class_declaration_repeat1] = STATE(3877),
    [aux_sym_lambda_expression_repeat1] = STATE(4320),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1979),
    [anon_sym_ref] = ACTIONS(1981),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1985),
    [anon_sym_TILDE] = ACTIONS(1985),
    [anon_sym_PLUS_PLUS] = ACTIONS(1985),
    [anon_sym_DASH_DASH] = ACTIONS(1985),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1983),
    [anon_sym_DASH] = ACTIONS(1983),
    [anon_sym_STAR] = ACTIONS(1987),
    [anon_sym_CARET] = ACTIONS(1985),
    [anon_sym_AMP] = ACTIONS(1985),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1989),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1991),
    [anon_sym_DOT_DOT] = ACTIONS(1993),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1863] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7159),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6322),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4487),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7422),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9176),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1863),
    [sym_preproc_endregion] = STATE(1863),
    [sym_preproc_line] = STATE(1863),
    [sym_preproc_pragma] = STATE(1863),
    [sym_preproc_nullable] = STATE(1863),
    [sym_preproc_error] = STATE(1863),
    [sym_preproc_warning] = STATE(1863),
    [sym_preproc_define] = STATE(1863),
    [sym_preproc_undef] = STATE(1863),
    [aux_sym_class_declaration_repeat1] = STATE(3877),
    [aux_sym_lambda_expression_repeat1] = STATE(4320),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1979),
    [anon_sym_ref] = ACTIONS(1981),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1985),
    [anon_sym_TILDE] = ACTIONS(1985),
    [anon_sym_PLUS_PLUS] = ACTIONS(1985),
    [anon_sym_DASH_DASH] = ACTIONS(1985),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1983),
    [anon_sym_DASH] = ACTIONS(1983),
    [anon_sym_STAR] = ACTIONS(1987),
    [anon_sym_CARET] = ACTIONS(1985),
    [anon_sym_AMP] = ACTIONS(1985),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1989),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1991),
    [anon_sym_DOT_DOT] = ACTIONS(1993),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1864] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7159),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6323),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4487),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7422),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9176),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1864),
    [sym_preproc_endregion] = STATE(1864),
    [sym_preproc_line] = STATE(1864),
    [sym_preproc_pragma] = STATE(1864),
    [sym_preproc_nullable] = STATE(1864),
    [sym_preproc_error] = STATE(1864),
    [sym_preproc_warning] = STATE(1864),
    [sym_preproc_define] = STATE(1864),
    [sym_preproc_undef] = STATE(1864),
    [aux_sym_class_declaration_repeat1] = STATE(3877),
    [aux_sym_lambda_expression_repeat1] = STATE(4320),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1979),
    [anon_sym_ref] = ACTIONS(1981),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1985),
    [anon_sym_TILDE] = ACTIONS(1985),
    [anon_sym_PLUS_PLUS] = ACTIONS(1985),
    [anon_sym_DASH_DASH] = ACTIONS(1985),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1983),
    [anon_sym_DASH] = ACTIONS(1983),
    [anon_sym_STAR] = ACTIONS(1987),
    [anon_sym_CARET] = ACTIONS(1985),
    [anon_sym_AMP] = ACTIONS(1985),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1989),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1991),
    [anon_sym_DOT_DOT] = ACTIONS(1993),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1865] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7159),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6324),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4487),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7422),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9176),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1865),
    [sym_preproc_endregion] = STATE(1865),
    [sym_preproc_line] = STATE(1865),
    [sym_preproc_pragma] = STATE(1865),
    [sym_preproc_nullable] = STATE(1865),
    [sym_preproc_error] = STATE(1865),
    [sym_preproc_warning] = STATE(1865),
    [sym_preproc_define] = STATE(1865),
    [sym_preproc_undef] = STATE(1865),
    [aux_sym_class_declaration_repeat1] = STATE(3877),
    [aux_sym_lambda_expression_repeat1] = STATE(4320),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1979),
    [anon_sym_ref] = ACTIONS(1981),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1985),
    [anon_sym_TILDE] = ACTIONS(1985),
    [anon_sym_PLUS_PLUS] = ACTIONS(1985),
    [anon_sym_DASH_DASH] = ACTIONS(1985),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1983),
    [anon_sym_DASH] = ACTIONS(1983),
    [anon_sym_STAR] = ACTIONS(1987),
    [anon_sym_CARET] = ACTIONS(1985),
    [anon_sym_AMP] = ACTIONS(1985),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1989),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1991),
    [anon_sym_DOT_DOT] = ACTIONS(1993),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1866] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7159),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6326),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4487),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7422),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9176),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1866),
    [sym_preproc_endregion] = STATE(1866),
    [sym_preproc_line] = STATE(1866),
    [sym_preproc_pragma] = STATE(1866),
    [sym_preproc_nullable] = STATE(1866),
    [sym_preproc_error] = STATE(1866),
    [sym_preproc_warning] = STATE(1866),
    [sym_preproc_define] = STATE(1866),
    [sym_preproc_undef] = STATE(1866),
    [aux_sym_class_declaration_repeat1] = STATE(3877),
    [aux_sym_lambda_expression_repeat1] = STATE(4320),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1979),
    [anon_sym_ref] = ACTIONS(1981),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1985),
    [anon_sym_TILDE] = ACTIONS(1985),
    [anon_sym_PLUS_PLUS] = ACTIONS(1985),
    [anon_sym_DASH_DASH] = ACTIONS(1985),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1983),
    [anon_sym_DASH] = ACTIONS(1983),
    [anon_sym_STAR] = ACTIONS(1987),
    [anon_sym_CARET] = ACTIONS(1985),
    [anon_sym_AMP] = ACTIONS(1985),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1989),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1991),
    [anon_sym_DOT_DOT] = ACTIONS(1993),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1867] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7159),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6327),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4487),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7422),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9176),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1867),
    [sym_preproc_endregion] = STATE(1867),
    [sym_preproc_line] = STATE(1867),
    [sym_preproc_pragma] = STATE(1867),
    [sym_preproc_nullable] = STATE(1867),
    [sym_preproc_error] = STATE(1867),
    [sym_preproc_warning] = STATE(1867),
    [sym_preproc_define] = STATE(1867),
    [sym_preproc_undef] = STATE(1867),
    [aux_sym_class_declaration_repeat1] = STATE(3877),
    [aux_sym_lambda_expression_repeat1] = STATE(4320),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1979),
    [anon_sym_ref] = ACTIONS(1981),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1985),
    [anon_sym_TILDE] = ACTIONS(1985),
    [anon_sym_PLUS_PLUS] = ACTIONS(1985),
    [anon_sym_DASH_DASH] = ACTIONS(1985),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1983),
    [anon_sym_DASH] = ACTIONS(1983),
    [anon_sym_STAR] = ACTIONS(1987),
    [anon_sym_CARET] = ACTIONS(1985),
    [anon_sym_AMP] = ACTIONS(1985),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1989),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1991),
    [anon_sym_DOT_DOT] = ACTIONS(1993),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1868] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7159),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6328),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4487),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7422),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9176),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1868),
    [sym_preproc_endregion] = STATE(1868),
    [sym_preproc_line] = STATE(1868),
    [sym_preproc_pragma] = STATE(1868),
    [sym_preproc_nullable] = STATE(1868),
    [sym_preproc_error] = STATE(1868),
    [sym_preproc_warning] = STATE(1868),
    [sym_preproc_define] = STATE(1868),
    [sym_preproc_undef] = STATE(1868),
    [aux_sym_class_declaration_repeat1] = STATE(3877),
    [aux_sym_lambda_expression_repeat1] = STATE(4320),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1979),
    [anon_sym_ref] = ACTIONS(1981),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1985),
    [anon_sym_TILDE] = ACTIONS(1985),
    [anon_sym_PLUS_PLUS] = ACTIONS(1985),
    [anon_sym_DASH_DASH] = ACTIONS(1985),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1983),
    [anon_sym_DASH] = ACTIONS(1983),
    [anon_sym_STAR] = ACTIONS(1987),
    [anon_sym_CARET] = ACTIONS(1985),
    [anon_sym_AMP] = ACTIONS(1985),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1989),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1991),
    [anon_sym_DOT_DOT] = ACTIONS(1993),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1869] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7159),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6681),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4487),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7422),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9176),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1869),
    [sym_preproc_endregion] = STATE(1869),
    [sym_preproc_line] = STATE(1869),
    [sym_preproc_pragma] = STATE(1869),
    [sym_preproc_nullable] = STATE(1869),
    [sym_preproc_error] = STATE(1869),
    [sym_preproc_warning] = STATE(1869),
    [sym_preproc_define] = STATE(1869),
    [sym_preproc_undef] = STATE(1869),
    [aux_sym_class_declaration_repeat1] = STATE(3877),
    [aux_sym_lambda_expression_repeat1] = STATE(4320),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1979),
    [anon_sym_ref] = ACTIONS(1981),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1985),
    [anon_sym_TILDE] = ACTIONS(1985),
    [anon_sym_PLUS_PLUS] = ACTIONS(1985),
    [anon_sym_DASH_DASH] = ACTIONS(1985),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1983),
    [anon_sym_DASH] = ACTIONS(1983),
    [anon_sym_STAR] = ACTIONS(1987),
    [anon_sym_CARET] = ACTIONS(1985),
    [anon_sym_AMP] = ACTIONS(1985),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1989),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1991),
    [anon_sym_DOT_DOT] = ACTIONS(1993),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1870] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6926),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2950),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7053),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6169),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4458),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7431),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9158),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1870),
    [sym_preproc_endregion] = STATE(1870),
    [sym_preproc_line] = STATE(1870),
    [sym_preproc_pragma] = STATE(1870),
    [sym_preproc_nullable] = STATE(1870),
    [sym_preproc_error] = STATE(1870),
    [sym_preproc_warning] = STATE(1870),
    [sym_preproc_define] = STATE(1870),
    [sym_preproc_undef] = STATE(1870),
    [aux_sym_class_declaration_repeat1] = STATE(3835),
    [aux_sym_lambda_expression_repeat1] = STATE(4263),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2213),
    [anon_sym_ref] = ACTIONS(2215),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2217),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2221),
    [anon_sym_TILDE] = ACTIONS(2221),
    [anon_sym_PLUS_PLUS] = ACTIONS(2221),
    [anon_sym_DASH_DASH] = ACTIONS(2221),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2219),
    [anon_sym_DASH] = ACTIONS(2219),
    [anon_sym_STAR] = ACTIONS(2223),
    [anon_sym_CARET] = ACTIONS(2221),
    [anon_sym_AMP] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2225),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2227),
    [anon_sym_DOT_DOT] = ACTIONS(2229),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1871] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7159),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4338),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4487),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7422),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9176),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1871),
    [sym_preproc_endregion] = STATE(1871),
    [sym_preproc_line] = STATE(1871),
    [sym_preproc_pragma] = STATE(1871),
    [sym_preproc_nullable] = STATE(1871),
    [sym_preproc_error] = STATE(1871),
    [sym_preproc_warning] = STATE(1871),
    [sym_preproc_define] = STATE(1871),
    [sym_preproc_undef] = STATE(1871),
    [aux_sym_class_declaration_repeat1] = STATE(3877),
    [aux_sym_lambda_expression_repeat1] = STATE(4320),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1979),
    [anon_sym_ref] = ACTIONS(1981),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1985),
    [anon_sym_TILDE] = ACTIONS(1985),
    [anon_sym_PLUS_PLUS] = ACTIONS(1985),
    [anon_sym_DASH_DASH] = ACTIONS(1985),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1983),
    [anon_sym_DASH] = ACTIONS(1983),
    [anon_sym_STAR] = ACTIONS(1987),
    [anon_sym_CARET] = ACTIONS(1985),
    [anon_sym_AMP] = ACTIONS(1985),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1989),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1991),
    [anon_sym_DOT_DOT] = ACTIONS(1993),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1872] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7085),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6064),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4345),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7436),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9001),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1872),
    [sym_preproc_endregion] = STATE(1872),
    [sym_preproc_line] = STATE(1872),
    [sym_preproc_pragma] = STATE(1872),
    [sym_preproc_nullable] = STATE(1872),
    [sym_preproc_error] = STATE(1872),
    [sym_preproc_warning] = STATE(1872),
    [sym_preproc_define] = STATE(1872),
    [sym_preproc_undef] = STATE(1872),
    [aux_sym_class_declaration_repeat1] = STATE(3846),
    [aux_sym_lambda_expression_repeat1] = STATE(4278),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1669),
    [anon_sym_ref] = ACTIONS(1671),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1675),
    [anon_sym_TILDE] = ACTIONS(1675),
    [anon_sym_PLUS_PLUS] = ACTIONS(1675),
    [anon_sym_DASH_DASH] = ACTIONS(1675),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_STAR] = ACTIONS(1677),
    [anon_sym_CARET] = ACTIONS(1675),
    [anon_sym_AMP] = ACTIONS(1675),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1679),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1681),
    [anon_sym_DOT_DOT] = ACTIONS(1683),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1873] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7159),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6334),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4487),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7422),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9176),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1873),
    [sym_preproc_endregion] = STATE(1873),
    [sym_preproc_line] = STATE(1873),
    [sym_preproc_pragma] = STATE(1873),
    [sym_preproc_nullable] = STATE(1873),
    [sym_preproc_error] = STATE(1873),
    [sym_preproc_warning] = STATE(1873),
    [sym_preproc_define] = STATE(1873),
    [sym_preproc_undef] = STATE(1873),
    [aux_sym_class_declaration_repeat1] = STATE(3877),
    [aux_sym_lambda_expression_repeat1] = STATE(4320),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1979),
    [anon_sym_ref] = ACTIONS(1981),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1985),
    [anon_sym_TILDE] = ACTIONS(1985),
    [anon_sym_PLUS_PLUS] = ACTIONS(1985),
    [anon_sym_DASH_DASH] = ACTIONS(1985),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1983),
    [anon_sym_DASH] = ACTIONS(1983),
    [anon_sym_STAR] = ACTIONS(1987),
    [anon_sym_CARET] = ACTIONS(1985),
    [anon_sym_AMP] = ACTIONS(1985),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1989),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1991),
    [anon_sym_DOT_DOT] = ACTIONS(1993),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1874] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6926),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2950),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7053),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6174),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4458),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7431),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9158),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1874),
    [sym_preproc_endregion] = STATE(1874),
    [sym_preproc_line] = STATE(1874),
    [sym_preproc_pragma] = STATE(1874),
    [sym_preproc_nullable] = STATE(1874),
    [sym_preproc_error] = STATE(1874),
    [sym_preproc_warning] = STATE(1874),
    [sym_preproc_define] = STATE(1874),
    [sym_preproc_undef] = STATE(1874),
    [aux_sym_class_declaration_repeat1] = STATE(3835),
    [aux_sym_lambda_expression_repeat1] = STATE(4263),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2213),
    [anon_sym_ref] = ACTIONS(2215),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2217),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2221),
    [anon_sym_TILDE] = ACTIONS(2221),
    [anon_sym_PLUS_PLUS] = ACTIONS(2221),
    [anon_sym_DASH_DASH] = ACTIONS(2221),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2219),
    [anon_sym_DASH] = ACTIONS(2219),
    [anon_sym_STAR] = ACTIONS(2223),
    [anon_sym_CARET] = ACTIONS(2221),
    [anon_sym_AMP] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2225),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2227),
    [anon_sym_DOT_DOT] = ACTIONS(2229),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1875] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7085),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5876),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4345),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7436),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9001),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1875),
    [sym_preproc_endregion] = STATE(1875),
    [sym_preproc_line] = STATE(1875),
    [sym_preproc_pragma] = STATE(1875),
    [sym_preproc_nullable] = STATE(1875),
    [sym_preproc_error] = STATE(1875),
    [sym_preproc_warning] = STATE(1875),
    [sym_preproc_define] = STATE(1875),
    [sym_preproc_undef] = STATE(1875),
    [aux_sym_class_declaration_repeat1] = STATE(3846),
    [aux_sym_lambda_expression_repeat1] = STATE(4278),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1669),
    [anon_sym_ref] = ACTIONS(1671),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1675),
    [anon_sym_TILDE] = ACTIONS(1675),
    [anon_sym_PLUS_PLUS] = ACTIONS(1675),
    [anon_sym_DASH_DASH] = ACTIONS(1675),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_STAR] = ACTIONS(1677),
    [anon_sym_CARET] = ACTIONS(1675),
    [anon_sym_AMP] = ACTIONS(1675),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1679),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1681),
    [anon_sym_DOT_DOT] = ACTIONS(1683),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1876] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7085),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5877),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4345),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7436),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9001),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1876),
    [sym_preproc_endregion] = STATE(1876),
    [sym_preproc_line] = STATE(1876),
    [sym_preproc_pragma] = STATE(1876),
    [sym_preproc_nullable] = STATE(1876),
    [sym_preproc_error] = STATE(1876),
    [sym_preproc_warning] = STATE(1876),
    [sym_preproc_define] = STATE(1876),
    [sym_preproc_undef] = STATE(1876),
    [aux_sym_class_declaration_repeat1] = STATE(3846),
    [aux_sym_lambda_expression_repeat1] = STATE(4278),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1669),
    [anon_sym_ref] = ACTIONS(1671),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1675),
    [anon_sym_TILDE] = ACTIONS(1675),
    [anon_sym_PLUS_PLUS] = ACTIONS(1675),
    [anon_sym_DASH_DASH] = ACTIONS(1675),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_STAR] = ACTIONS(1677),
    [anon_sym_CARET] = ACTIONS(1675),
    [anon_sym_AMP] = ACTIONS(1675),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1679),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1681),
    [anon_sym_DOT_DOT] = ACTIONS(1683),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1877] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7085),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6061),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4345),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7436),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9001),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1877),
    [sym_preproc_endregion] = STATE(1877),
    [sym_preproc_line] = STATE(1877),
    [sym_preproc_pragma] = STATE(1877),
    [sym_preproc_nullable] = STATE(1877),
    [sym_preproc_error] = STATE(1877),
    [sym_preproc_warning] = STATE(1877),
    [sym_preproc_define] = STATE(1877),
    [sym_preproc_undef] = STATE(1877),
    [aux_sym_class_declaration_repeat1] = STATE(3846),
    [aux_sym_lambda_expression_repeat1] = STATE(4278),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1669),
    [anon_sym_ref] = ACTIONS(1671),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1675),
    [anon_sym_TILDE] = ACTIONS(1675),
    [anon_sym_PLUS_PLUS] = ACTIONS(1675),
    [anon_sym_DASH_DASH] = ACTIONS(1675),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_STAR] = ACTIONS(1677),
    [anon_sym_CARET] = ACTIONS(1675),
    [anon_sym_AMP] = ACTIONS(1675),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1679),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1681),
    [anon_sym_DOT_DOT] = ACTIONS(1683),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1878] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7085),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5878),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4345),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7436),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9001),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1878),
    [sym_preproc_endregion] = STATE(1878),
    [sym_preproc_line] = STATE(1878),
    [sym_preproc_pragma] = STATE(1878),
    [sym_preproc_nullable] = STATE(1878),
    [sym_preproc_error] = STATE(1878),
    [sym_preproc_warning] = STATE(1878),
    [sym_preproc_define] = STATE(1878),
    [sym_preproc_undef] = STATE(1878),
    [aux_sym_class_declaration_repeat1] = STATE(3846),
    [aux_sym_lambda_expression_repeat1] = STATE(4278),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1669),
    [anon_sym_ref] = ACTIONS(1671),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1675),
    [anon_sym_TILDE] = ACTIONS(1675),
    [anon_sym_PLUS_PLUS] = ACTIONS(1675),
    [anon_sym_DASH_DASH] = ACTIONS(1675),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_STAR] = ACTIONS(1677),
    [anon_sym_CARET] = ACTIONS(1675),
    [anon_sym_AMP] = ACTIONS(1675),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1679),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1681),
    [anon_sym_DOT_DOT] = ACTIONS(1683),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1879] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7085),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5879),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4345),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7436),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9001),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1879),
    [sym_preproc_endregion] = STATE(1879),
    [sym_preproc_line] = STATE(1879),
    [sym_preproc_pragma] = STATE(1879),
    [sym_preproc_nullable] = STATE(1879),
    [sym_preproc_error] = STATE(1879),
    [sym_preproc_warning] = STATE(1879),
    [sym_preproc_define] = STATE(1879),
    [sym_preproc_undef] = STATE(1879),
    [aux_sym_class_declaration_repeat1] = STATE(3846),
    [aux_sym_lambda_expression_repeat1] = STATE(4278),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1669),
    [anon_sym_ref] = ACTIONS(1671),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1675),
    [anon_sym_TILDE] = ACTIONS(1675),
    [anon_sym_PLUS_PLUS] = ACTIONS(1675),
    [anon_sym_DASH_DASH] = ACTIONS(1675),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_STAR] = ACTIONS(1677),
    [anon_sym_CARET] = ACTIONS(1675),
    [anon_sym_AMP] = ACTIONS(1675),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1679),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1681),
    [anon_sym_DOT_DOT] = ACTIONS(1683),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1880] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7085),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5880),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4345),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7436),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9001),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1880),
    [sym_preproc_endregion] = STATE(1880),
    [sym_preproc_line] = STATE(1880),
    [sym_preproc_pragma] = STATE(1880),
    [sym_preproc_nullable] = STATE(1880),
    [sym_preproc_error] = STATE(1880),
    [sym_preproc_warning] = STATE(1880),
    [sym_preproc_define] = STATE(1880),
    [sym_preproc_undef] = STATE(1880),
    [aux_sym_class_declaration_repeat1] = STATE(3846),
    [aux_sym_lambda_expression_repeat1] = STATE(4278),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1669),
    [anon_sym_ref] = ACTIONS(1671),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1675),
    [anon_sym_TILDE] = ACTIONS(1675),
    [anon_sym_PLUS_PLUS] = ACTIONS(1675),
    [anon_sym_DASH_DASH] = ACTIONS(1675),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_STAR] = ACTIONS(1677),
    [anon_sym_CARET] = ACTIONS(1675),
    [anon_sym_AMP] = ACTIONS(1675),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1679),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1681),
    [anon_sym_DOT_DOT] = ACTIONS(1683),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1881] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7085),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5881),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4345),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7436),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9001),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1881),
    [sym_preproc_endregion] = STATE(1881),
    [sym_preproc_line] = STATE(1881),
    [sym_preproc_pragma] = STATE(1881),
    [sym_preproc_nullable] = STATE(1881),
    [sym_preproc_error] = STATE(1881),
    [sym_preproc_warning] = STATE(1881),
    [sym_preproc_define] = STATE(1881),
    [sym_preproc_undef] = STATE(1881),
    [aux_sym_class_declaration_repeat1] = STATE(3846),
    [aux_sym_lambda_expression_repeat1] = STATE(4278),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1669),
    [anon_sym_ref] = ACTIONS(1671),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1675),
    [anon_sym_TILDE] = ACTIONS(1675),
    [anon_sym_PLUS_PLUS] = ACTIONS(1675),
    [anon_sym_DASH_DASH] = ACTIONS(1675),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_STAR] = ACTIONS(1677),
    [anon_sym_CARET] = ACTIONS(1675),
    [anon_sym_AMP] = ACTIONS(1675),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1679),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1681),
    [anon_sym_DOT_DOT] = ACTIONS(1683),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1882] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7085),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5882),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4345),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7436),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9001),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1882),
    [sym_preproc_endregion] = STATE(1882),
    [sym_preproc_line] = STATE(1882),
    [sym_preproc_pragma] = STATE(1882),
    [sym_preproc_nullable] = STATE(1882),
    [sym_preproc_error] = STATE(1882),
    [sym_preproc_warning] = STATE(1882),
    [sym_preproc_define] = STATE(1882),
    [sym_preproc_undef] = STATE(1882),
    [aux_sym_class_declaration_repeat1] = STATE(3846),
    [aux_sym_lambda_expression_repeat1] = STATE(4278),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1669),
    [anon_sym_ref] = ACTIONS(1671),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1675),
    [anon_sym_TILDE] = ACTIONS(1675),
    [anon_sym_PLUS_PLUS] = ACTIONS(1675),
    [anon_sym_DASH_DASH] = ACTIONS(1675),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_STAR] = ACTIONS(1677),
    [anon_sym_CARET] = ACTIONS(1675),
    [anon_sym_AMP] = ACTIONS(1675),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1679),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1681),
    [anon_sym_DOT_DOT] = ACTIONS(1683),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1883] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7085),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5883),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4345),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7436),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9001),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1883),
    [sym_preproc_endregion] = STATE(1883),
    [sym_preproc_line] = STATE(1883),
    [sym_preproc_pragma] = STATE(1883),
    [sym_preproc_nullable] = STATE(1883),
    [sym_preproc_error] = STATE(1883),
    [sym_preproc_warning] = STATE(1883),
    [sym_preproc_define] = STATE(1883),
    [sym_preproc_undef] = STATE(1883),
    [aux_sym_class_declaration_repeat1] = STATE(3846),
    [aux_sym_lambda_expression_repeat1] = STATE(4278),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1669),
    [anon_sym_ref] = ACTIONS(1671),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1675),
    [anon_sym_TILDE] = ACTIONS(1675),
    [anon_sym_PLUS_PLUS] = ACTIONS(1675),
    [anon_sym_DASH_DASH] = ACTIONS(1675),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_STAR] = ACTIONS(1677),
    [anon_sym_CARET] = ACTIONS(1675),
    [anon_sym_AMP] = ACTIONS(1675),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1679),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1681),
    [anon_sym_DOT_DOT] = ACTIONS(1683),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1884] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7085),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5884),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4345),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7436),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9001),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1884),
    [sym_preproc_endregion] = STATE(1884),
    [sym_preproc_line] = STATE(1884),
    [sym_preproc_pragma] = STATE(1884),
    [sym_preproc_nullable] = STATE(1884),
    [sym_preproc_error] = STATE(1884),
    [sym_preproc_warning] = STATE(1884),
    [sym_preproc_define] = STATE(1884),
    [sym_preproc_undef] = STATE(1884),
    [aux_sym_class_declaration_repeat1] = STATE(3846),
    [aux_sym_lambda_expression_repeat1] = STATE(4278),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1669),
    [anon_sym_ref] = ACTIONS(1671),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1675),
    [anon_sym_TILDE] = ACTIONS(1675),
    [anon_sym_PLUS_PLUS] = ACTIONS(1675),
    [anon_sym_DASH_DASH] = ACTIONS(1675),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_STAR] = ACTIONS(1677),
    [anon_sym_CARET] = ACTIONS(1675),
    [anon_sym_AMP] = ACTIONS(1675),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1679),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1681),
    [anon_sym_DOT_DOT] = ACTIONS(1683),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1885] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7085),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5885),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4345),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7436),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9001),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1885),
    [sym_preproc_endregion] = STATE(1885),
    [sym_preproc_line] = STATE(1885),
    [sym_preproc_pragma] = STATE(1885),
    [sym_preproc_nullable] = STATE(1885),
    [sym_preproc_error] = STATE(1885),
    [sym_preproc_warning] = STATE(1885),
    [sym_preproc_define] = STATE(1885),
    [sym_preproc_undef] = STATE(1885),
    [aux_sym_class_declaration_repeat1] = STATE(3846),
    [aux_sym_lambda_expression_repeat1] = STATE(4278),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1669),
    [anon_sym_ref] = ACTIONS(1671),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1675),
    [anon_sym_TILDE] = ACTIONS(1675),
    [anon_sym_PLUS_PLUS] = ACTIONS(1675),
    [anon_sym_DASH_DASH] = ACTIONS(1675),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_STAR] = ACTIONS(1677),
    [anon_sym_CARET] = ACTIONS(1675),
    [anon_sym_AMP] = ACTIONS(1675),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1679),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1681),
    [anon_sym_DOT_DOT] = ACTIONS(1683),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1886] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7085),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3932),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4345),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7436),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9001),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1886),
    [sym_preproc_endregion] = STATE(1886),
    [sym_preproc_line] = STATE(1886),
    [sym_preproc_pragma] = STATE(1886),
    [sym_preproc_nullable] = STATE(1886),
    [sym_preproc_error] = STATE(1886),
    [sym_preproc_warning] = STATE(1886),
    [sym_preproc_define] = STATE(1886),
    [sym_preproc_undef] = STATE(1886),
    [aux_sym_class_declaration_repeat1] = STATE(3846),
    [aux_sym_lambda_expression_repeat1] = STATE(4278),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1669),
    [anon_sym_ref] = ACTIONS(1671),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1675),
    [anon_sym_TILDE] = ACTIONS(1675),
    [anon_sym_PLUS_PLUS] = ACTIONS(1675),
    [anon_sym_DASH_DASH] = ACTIONS(1675),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_STAR] = ACTIONS(1677),
    [anon_sym_CARET] = ACTIONS(1675),
    [anon_sym_AMP] = ACTIONS(1675),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1679),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1681),
    [anon_sym_DOT_DOT] = ACTIONS(1683),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1887] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7085),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5790),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4345),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7436),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9001),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1887),
    [sym_preproc_endregion] = STATE(1887),
    [sym_preproc_line] = STATE(1887),
    [sym_preproc_pragma] = STATE(1887),
    [sym_preproc_nullable] = STATE(1887),
    [sym_preproc_error] = STATE(1887),
    [sym_preproc_warning] = STATE(1887),
    [sym_preproc_define] = STATE(1887),
    [sym_preproc_undef] = STATE(1887),
    [aux_sym_class_declaration_repeat1] = STATE(3846),
    [aux_sym_lambda_expression_repeat1] = STATE(4278),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1669),
    [anon_sym_ref] = ACTIONS(1671),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1675),
    [anon_sym_TILDE] = ACTIONS(1675),
    [anon_sym_PLUS_PLUS] = ACTIONS(1675),
    [anon_sym_DASH_DASH] = ACTIONS(1675),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_STAR] = ACTIONS(1677),
    [anon_sym_CARET] = ACTIONS(1675),
    [anon_sym_AMP] = ACTIONS(1675),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1679),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1681),
    [anon_sym_DOT_DOT] = ACTIONS(1683),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1888] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7085),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3926),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4345),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7436),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9001),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1888),
    [sym_preproc_endregion] = STATE(1888),
    [sym_preproc_line] = STATE(1888),
    [sym_preproc_pragma] = STATE(1888),
    [sym_preproc_nullable] = STATE(1888),
    [sym_preproc_error] = STATE(1888),
    [sym_preproc_warning] = STATE(1888),
    [sym_preproc_define] = STATE(1888),
    [sym_preproc_undef] = STATE(1888),
    [aux_sym_class_declaration_repeat1] = STATE(3846),
    [aux_sym_lambda_expression_repeat1] = STATE(4278),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1669),
    [anon_sym_ref] = ACTIONS(1671),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1675),
    [anon_sym_TILDE] = ACTIONS(1675),
    [anon_sym_PLUS_PLUS] = ACTIONS(1675),
    [anon_sym_DASH_DASH] = ACTIONS(1675),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_STAR] = ACTIONS(1677),
    [anon_sym_CARET] = ACTIONS(1675),
    [anon_sym_AMP] = ACTIONS(1675),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1679),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1681),
    [anon_sym_DOT_DOT] = ACTIONS(1683),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1889] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7085),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5889),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4345),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7436),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9001),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1889),
    [sym_preproc_endregion] = STATE(1889),
    [sym_preproc_line] = STATE(1889),
    [sym_preproc_pragma] = STATE(1889),
    [sym_preproc_nullable] = STATE(1889),
    [sym_preproc_error] = STATE(1889),
    [sym_preproc_warning] = STATE(1889),
    [sym_preproc_define] = STATE(1889),
    [sym_preproc_undef] = STATE(1889),
    [aux_sym_class_declaration_repeat1] = STATE(3846),
    [aux_sym_lambda_expression_repeat1] = STATE(4278),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1669),
    [anon_sym_ref] = ACTIONS(1671),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1675),
    [anon_sym_TILDE] = ACTIONS(1675),
    [anon_sym_PLUS_PLUS] = ACTIONS(1675),
    [anon_sym_DASH_DASH] = ACTIONS(1675),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_STAR] = ACTIONS(1677),
    [anon_sym_CARET] = ACTIONS(1675),
    [anon_sym_AMP] = ACTIONS(1675),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1679),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1681),
    [anon_sym_DOT_DOT] = ACTIONS(1683),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1890] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7085),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5893),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4345),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7436),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9001),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1890),
    [sym_preproc_endregion] = STATE(1890),
    [sym_preproc_line] = STATE(1890),
    [sym_preproc_pragma] = STATE(1890),
    [sym_preproc_nullable] = STATE(1890),
    [sym_preproc_error] = STATE(1890),
    [sym_preproc_warning] = STATE(1890),
    [sym_preproc_define] = STATE(1890),
    [sym_preproc_undef] = STATE(1890),
    [aux_sym_class_declaration_repeat1] = STATE(3846),
    [aux_sym_lambda_expression_repeat1] = STATE(4278),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1669),
    [anon_sym_ref] = ACTIONS(1671),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1675),
    [anon_sym_TILDE] = ACTIONS(1675),
    [anon_sym_PLUS_PLUS] = ACTIONS(1675),
    [anon_sym_DASH_DASH] = ACTIONS(1675),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_STAR] = ACTIONS(1677),
    [anon_sym_CARET] = ACTIONS(1675),
    [anon_sym_AMP] = ACTIONS(1675),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1679),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1681),
    [anon_sym_DOT_DOT] = ACTIONS(1683),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1891] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7105),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5827),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1891),
    [sym_preproc_endregion] = STATE(1891),
    [sym_preproc_line] = STATE(1891),
    [sym_preproc_pragma] = STATE(1891),
    [sym_preproc_nullable] = STATE(1891),
    [sym_preproc_error] = STATE(1891),
    [sym_preproc_warning] = STATE(1891),
    [sym_preproc_define] = STATE(1891),
    [sym_preproc_undef] = STATE(1891),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1892] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6948),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2940),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6999),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5067),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3857),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7444),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9574),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1892),
    [sym_preproc_endregion] = STATE(1892),
    [sym_preproc_line] = STATE(1892),
    [sym_preproc_pragma] = STATE(1892),
    [sym_preproc_nullable] = STATE(1892),
    [sym_preproc_error] = STATE(1892),
    [sym_preproc_warning] = STATE(1892),
    [sym_preproc_define] = STATE(1892),
    [sym_preproc_undef] = STATE(1892),
    [aux_sym_class_declaration_repeat1] = STATE(3854),
    [aux_sym_lambda_expression_repeat1] = STATE(4136),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2111),
    [anon_sym_ref] = ACTIONS(2113),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1897),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2117),
    [anon_sym_TILDE] = ACTIONS(2117),
    [anon_sym_PLUS_PLUS] = ACTIONS(2117),
    [anon_sym_DASH_DASH] = ACTIONS(2117),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2115),
    [anon_sym_DASH] = ACTIONS(2115),
    [anon_sym_STAR] = ACTIONS(1903),
    [anon_sym_CARET] = ACTIONS(2117),
    [anon_sym_AMP] = ACTIONS(2117),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2119),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2121),
    [anon_sym_DOT_DOT] = ACTIONS(2123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1893] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6984),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3917),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3903),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7428),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9348),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1893),
    [sym_preproc_endregion] = STATE(1893),
    [sym_preproc_line] = STATE(1893),
    [sym_preproc_pragma] = STATE(1893),
    [sym_preproc_nullable] = STATE(1893),
    [sym_preproc_error] = STATE(1893),
    [sym_preproc_warning] = STATE(1893),
    [sym_preproc_define] = STATE(1893),
    [sym_preproc_undef] = STATE(1893),
    [aux_sym_class_declaration_repeat1] = STATE(3817),
    [aux_sym_lambda_expression_repeat1] = STATE(4227),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1389),
    [anon_sym_ref] = ACTIONS(1391),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1117),
    [anon_sym_TILDE] = ACTIONS(1117),
    [anon_sym_PLUS_PLUS] = ACTIONS(1117),
    [anon_sym_DASH_DASH] = ACTIONS(1117),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1119),
    [anon_sym_DASH] = ACTIONS(1119),
    [anon_sym_STAR] = ACTIONS(1393),
    [anon_sym_CARET] = ACTIONS(1117),
    [anon_sym_AMP] = ACTIONS(1117),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1395),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1397),
    [anon_sym_DOT_DOT] = ACTIONS(1399),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1894] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6913),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2905),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7105),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6713),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3500),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1894),
    [sym_preproc_endregion] = STATE(1894),
    [sym_preproc_line] = STATE(1894),
    [sym_preproc_pragma] = STATE(1894),
    [sym_preproc_nullable] = STATE(1894),
    [sym_preproc_error] = STATE(1894),
    [sym_preproc_warning] = STATE(1894),
    [sym_preproc_define] = STATE(1894),
    [sym_preproc_undef] = STATE(1894),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(2983),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(1583),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1895] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6948),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2940),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6999),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4976),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3857),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7444),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9574),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1895),
    [sym_preproc_endregion] = STATE(1895),
    [sym_preproc_line] = STATE(1895),
    [sym_preproc_pragma] = STATE(1895),
    [sym_preproc_nullable] = STATE(1895),
    [sym_preproc_error] = STATE(1895),
    [sym_preproc_warning] = STATE(1895),
    [sym_preproc_define] = STATE(1895),
    [sym_preproc_undef] = STATE(1895),
    [aux_sym_class_declaration_repeat1] = STATE(3854),
    [aux_sym_lambda_expression_repeat1] = STATE(4136),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2111),
    [anon_sym_ref] = ACTIONS(2113),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1897),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2117),
    [anon_sym_TILDE] = ACTIONS(2117),
    [anon_sym_PLUS_PLUS] = ACTIONS(2117),
    [anon_sym_DASH_DASH] = ACTIONS(2117),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2115),
    [anon_sym_DASH] = ACTIONS(2115),
    [anon_sym_STAR] = ACTIONS(1903),
    [anon_sym_CARET] = ACTIONS(2117),
    [anon_sym_AMP] = ACTIONS(2117),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2119),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2121),
    [anon_sym_DOT_DOT] = ACTIONS(2123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1896] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6927),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2912),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7057),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5340),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3960),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7439),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9222),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1896),
    [sym_preproc_endregion] = STATE(1896),
    [sym_preproc_line] = STATE(1896),
    [sym_preproc_pragma] = STATE(1896),
    [sym_preproc_nullable] = STATE(1896),
    [sym_preproc_error] = STATE(1896),
    [sym_preproc_warning] = STATE(1896),
    [sym_preproc_define] = STATE(1896),
    [sym_preproc_undef] = STATE(1896),
    [aux_sym_class_declaration_repeat1] = STATE(3837),
    [aux_sym_lambda_expression_repeat1] = STATE(4265),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1591),
    [anon_sym_ref] = ACTIONS(1593),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1595),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1599),
    [anon_sym_TILDE] = ACTIONS(1599),
    [anon_sym_PLUS_PLUS] = ACTIONS(1599),
    [anon_sym_DASH_DASH] = ACTIONS(1599),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1597),
    [anon_sym_DASH] = ACTIONS(1597),
    [anon_sym_STAR] = ACTIONS(1601),
    [anon_sym_CARET] = ACTIONS(1599),
    [anon_sym_AMP] = ACTIONS(1599),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1603),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1605),
    [anon_sym_DOT_DOT] = ACTIONS(1607),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1897] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6927),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2912),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7057),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5350),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3960),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7439),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9222),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1897),
    [sym_preproc_endregion] = STATE(1897),
    [sym_preproc_line] = STATE(1897),
    [sym_preproc_pragma] = STATE(1897),
    [sym_preproc_nullable] = STATE(1897),
    [sym_preproc_error] = STATE(1897),
    [sym_preproc_warning] = STATE(1897),
    [sym_preproc_define] = STATE(1897),
    [sym_preproc_undef] = STATE(1897),
    [aux_sym_class_declaration_repeat1] = STATE(3837),
    [aux_sym_lambda_expression_repeat1] = STATE(4265),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1591),
    [anon_sym_ref] = ACTIONS(1593),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1595),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1599),
    [anon_sym_TILDE] = ACTIONS(1599),
    [anon_sym_PLUS_PLUS] = ACTIONS(1599),
    [anon_sym_DASH_DASH] = ACTIONS(1599),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1597),
    [anon_sym_DASH] = ACTIONS(1597),
    [anon_sym_STAR] = ACTIONS(1601),
    [anon_sym_CARET] = ACTIONS(1599),
    [anon_sym_AMP] = ACTIONS(1599),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1603),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1605),
    [anon_sym_DOT_DOT] = ACTIONS(1607),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1898] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6917),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2905),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7006),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3917),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4199),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7447),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9823),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1898),
    [sym_preproc_endregion] = STATE(1898),
    [sym_preproc_line] = STATE(1898),
    [sym_preproc_pragma] = STATE(1898),
    [sym_preproc_nullable] = STATE(1898),
    [sym_preproc_error] = STATE(1898),
    [sym_preproc_warning] = STATE(1898),
    [sym_preproc_define] = STATE(1898),
    [sym_preproc_undef] = STATE(1898),
    [aux_sym_class_declaration_repeat1] = STATE(3822),
    [aux_sym_lambda_expression_repeat1] = STATE(4238),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1623),
    [anon_sym_ref] = ACTIONS(1625),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1577),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1629),
    [anon_sym_TILDE] = ACTIONS(1629),
    [anon_sym_PLUS_PLUS] = ACTIONS(1629),
    [anon_sym_DASH_DASH] = ACTIONS(1629),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1627),
    [anon_sym_DASH] = ACTIONS(1627),
    [anon_sym_STAR] = ACTIONS(1631),
    [anon_sym_CARET] = ACTIONS(1629),
    [anon_sym_AMP] = ACTIONS(1629),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1633),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1635),
    [anon_sym_DOT_DOT] = ACTIONS(1637),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1899] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7105),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6713),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3500),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1899),
    [sym_preproc_endregion] = STATE(1899),
    [sym_preproc_line] = STATE(1899),
    [sym_preproc_pragma] = STATE(1899),
    [sym_preproc_nullable] = STATE(1899),
    [sym_preproc_error] = STATE(1899),
    [sym_preproc_warning] = STATE(1899),
    [sym_preproc_define] = STATE(1899),
    [sym_preproc_undef] = STATE(1899),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(2983),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(1393),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1900] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6916),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7061),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6200),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4369),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7437),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9284),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1900),
    [sym_preproc_endregion] = STATE(1900),
    [sym_preproc_line] = STATE(1900),
    [sym_preproc_pragma] = STATE(1900),
    [sym_preproc_nullable] = STATE(1900),
    [sym_preproc_error] = STATE(1900),
    [sym_preproc_warning] = STATE(1900),
    [sym_preproc_define] = STATE(1900),
    [sym_preproc_undef] = STATE(1900),
    [aux_sym_class_declaration_repeat1] = STATE(3839),
    [aux_sym_lambda_expression_repeat1] = STATE(4267),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1963),
    [anon_sym_ref] = ACTIONS(1965),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1969),
    [anon_sym_TILDE] = ACTIONS(1969),
    [anon_sym_PLUS_PLUS] = ACTIONS(1969),
    [anon_sym_DASH_DASH] = ACTIONS(1969),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1967),
    [anon_sym_DASH] = ACTIONS(1967),
    [anon_sym_STAR] = ACTIONS(1971),
    [anon_sym_CARET] = ACTIONS(1969),
    [anon_sym_AMP] = ACTIONS(1969),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1973),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1975),
    [anon_sym_DOT_DOT] = ACTIONS(1977),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1901] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6916),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7061),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6144),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4369),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7437),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9284),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1901),
    [sym_preproc_endregion] = STATE(1901),
    [sym_preproc_line] = STATE(1901),
    [sym_preproc_pragma] = STATE(1901),
    [sym_preproc_nullable] = STATE(1901),
    [sym_preproc_error] = STATE(1901),
    [sym_preproc_warning] = STATE(1901),
    [sym_preproc_define] = STATE(1901),
    [sym_preproc_undef] = STATE(1901),
    [aux_sym_class_declaration_repeat1] = STATE(3839),
    [aux_sym_lambda_expression_repeat1] = STATE(4267),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1963),
    [anon_sym_ref] = ACTIONS(1965),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1969),
    [anon_sym_TILDE] = ACTIONS(1969),
    [anon_sym_PLUS_PLUS] = ACTIONS(1969),
    [anon_sym_DASH_DASH] = ACTIONS(1969),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1967),
    [anon_sym_DASH] = ACTIONS(1967),
    [anon_sym_STAR] = ACTIONS(1971),
    [anon_sym_CARET] = ACTIONS(1969),
    [anon_sym_AMP] = ACTIONS(1969),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1973),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1975),
    [anon_sym_DOT_DOT] = ACTIONS(1977),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1902] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7014),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3917),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4335),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7428),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9866),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1902),
    [sym_preproc_endregion] = STATE(1902),
    [sym_preproc_line] = STATE(1902),
    [sym_preproc_pragma] = STATE(1902),
    [sym_preproc_nullable] = STATE(1902),
    [sym_preproc_error] = STATE(1902),
    [sym_preproc_warning] = STATE(1902),
    [sym_preproc_define] = STATE(1902),
    [sym_preproc_undef] = STATE(1902),
    [aux_sym_class_declaration_repeat1] = STATE(3824),
    [aux_sym_lambda_expression_repeat1] = STATE(4242),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1539),
    [anon_sym_ref] = ACTIONS(1541),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1545),
    [anon_sym_TILDE] = ACTIONS(1545),
    [anon_sym_PLUS_PLUS] = ACTIONS(1545),
    [anon_sym_DASH_DASH] = ACTIONS(1545),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1543),
    [anon_sym_DASH] = ACTIONS(1543),
    [anon_sym_STAR] = ACTIONS(1547),
    [anon_sym_CARET] = ACTIONS(1545),
    [anon_sym_AMP] = ACTIONS(1545),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1549),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1551),
    [anon_sym_DOT_DOT] = ACTIONS(1553),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1903] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6955),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2975),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7105),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6717),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3016),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1903),
    [sym_preproc_endregion] = STATE(1903),
    [sym_preproc_line] = STATE(1903),
    [sym_preproc_pragma] = STATE(1903),
    [sym_preproc_nullable] = STATE(1903),
    [sym_preproc_error] = STATE(1903),
    [sym_preproc_warning] = STATE(1903),
    [sym_preproc_define] = STATE(1903),
    [sym_preproc_undef] = STATE(1903),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2981),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(1939),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1904] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6941),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2977),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7077),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5678),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4200),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7415),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9773),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1904),
    [sym_preproc_endregion] = STATE(1904),
    [sym_preproc_line] = STATE(1904),
    [sym_preproc_pragma] = STATE(1904),
    [sym_preproc_nullable] = STATE(1904),
    [sym_preproc_error] = STATE(1904),
    [sym_preproc_warning] = STATE(1904),
    [sym_preproc_define] = STATE(1904),
    [sym_preproc_undef] = STATE(1904),
    [aux_sym_class_declaration_repeat1] = STATE(3843),
    [aux_sym_lambda_expression_repeat1] = STATE(4275),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1911),
    [anon_sym_ref] = ACTIONS(1913),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1915),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1919),
    [anon_sym_TILDE] = ACTIONS(1919),
    [anon_sym_PLUS_PLUS] = ACTIONS(1919),
    [anon_sym_DASH_DASH] = ACTIONS(1919),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1917),
    [anon_sym_DASH] = ACTIONS(1917),
    [anon_sym_STAR] = ACTIONS(1921),
    [anon_sym_CARET] = ACTIONS(1919),
    [anon_sym_AMP] = ACTIONS(1919),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1923),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1925),
    [anon_sym_DOT_DOT] = ACTIONS(1927),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1905] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6941),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2977),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7077),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5680),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4200),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7415),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9773),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1905),
    [sym_preproc_endregion] = STATE(1905),
    [sym_preproc_line] = STATE(1905),
    [sym_preproc_pragma] = STATE(1905),
    [sym_preproc_nullable] = STATE(1905),
    [sym_preproc_error] = STATE(1905),
    [sym_preproc_warning] = STATE(1905),
    [sym_preproc_define] = STATE(1905),
    [sym_preproc_undef] = STATE(1905),
    [aux_sym_class_declaration_repeat1] = STATE(3843),
    [aux_sym_lambda_expression_repeat1] = STATE(4275),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1911),
    [anon_sym_ref] = ACTIONS(1913),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1915),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1919),
    [anon_sym_TILDE] = ACTIONS(1919),
    [anon_sym_PLUS_PLUS] = ACTIONS(1919),
    [anon_sym_DASH_DASH] = ACTIONS(1919),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1917),
    [anon_sym_DASH] = ACTIONS(1917),
    [anon_sym_STAR] = ACTIONS(1921),
    [anon_sym_CARET] = ACTIONS(1919),
    [anon_sym_AMP] = ACTIONS(1919),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1923),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1925),
    [anon_sym_DOT_DOT] = ACTIONS(1927),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1906] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6918),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6973),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3561),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4069),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7443),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9676),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1906),
    [sym_preproc_endregion] = STATE(1906),
    [sym_preproc_line] = STATE(1906),
    [sym_preproc_pragma] = STATE(1906),
    [sym_preproc_nullable] = STATE(1906),
    [sym_preproc_error] = STATE(1906),
    [sym_preproc_warning] = STATE(1906),
    [sym_preproc_define] = STATE(1906),
    [sym_preproc_undef] = STATE(1906),
    [aux_sym_class_declaration_repeat1] = STATE(3815),
    [aux_sym_lambda_expression_repeat1] = STATE(4217),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1515),
    [anon_sym_ref] = ACTIONS(1517),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1521),
    [anon_sym_TILDE] = ACTIONS(1521),
    [anon_sym_PLUS_PLUS] = ACTIONS(1521),
    [anon_sym_DASH_DASH] = ACTIONS(1521),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1519),
    [anon_sym_DASH] = ACTIONS(1519),
    [anon_sym_STAR] = ACTIONS(1523),
    [anon_sym_CARET] = ACTIONS(1521),
    [anon_sym_AMP] = ACTIONS(1521),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1525),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1527),
    [anon_sym_DOT_DOT] = ACTIONS(1529),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1907] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6943),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2986),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7105),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3056),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1907),
    [sym_preproc_endregion] = STATE(1907),
    [sym_preproc_line] = STATE(1907),
    [sym_preproc_pragma] = STATE(1907),
    [sym_preproc_nullable] = STATE(1907),
    [sym_preproc_error] = STATE(1907),
    [sym_preproc_warning] = STATE(1907),
    [sym_preproc_define] = STATE(1907),
    [sym_preproc_undef] = STATE(1907),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(2179),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1908] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6910),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2960),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7091),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5710),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4208),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7438),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9067),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1908),
    [sym_preproc_endregion] = STATE(1908),
    [sym_preproc_line] = STATE(1908),
    [sym_preproc_pragma] = STATE(1908),
    [sym_preproc_nullable] = STATE(1908),
    [sym_preproc_error] = STATE(1908),
    [sym_preproc_warning] = STATE(1908),
    [sym_preproc_define] = STATE(1908),
    [sym_preproc_undef] = STATE(1908),
    [aux_sym_class_declaration_repeat1] = STATE(3847),
    [aux_sym_lambda_expression_repeat1] = STATE(4280),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1819),
    [anon_sym_ref] = ACTIONS(1821),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1823),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1827),
    [anon_sym_TILDE] = ACTIONS(1827),
    [anon_sym_PLUS_PLUS] = ACTIONS(1827),
    [anon_sym_DASH_DASH] = ACTIONS(1827),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1825),
    [anon_sym_DASH] = ACTIONS(1825),
    [anon_sym_STAR] = ACTIONS(1829),
    [anon_sym_CARET] = ACTIONS(1827),
    [anon_sym_AMP] = ACTIONS(1827),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1831),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1833),
    [anon_sym_DOT_DOT] = ACTIONS(1835),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1909] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6910),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2960),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7091),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5712),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4208),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7438),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9067),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1909),
    [sym_preproc_endregion] = STATE(1909),
    [sym_preproc_line] = STATE(1909),
    [sym_preproc_pragma] = STATE(1909),
    [sym_preproc_nullable] = STATE(1909),
    [sym_preproc_error] = STATE(1909),
    [sym_preproc_warning] = STATE(1909),
    [sym_preproc_define] = STATE(1909),
    [sym_preproc_undef] = STATE(1909),
    [aux_sym_class_declaration_repeat1] = STATE(3847),
    [aux_sym_lambda_expression_repeat1] = STATE(4280),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1819),
    [anon_sym_ref] = ACTIONS(1821),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1823),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1827),
    [anon_sym_TILDE] = ACTIONS(1827),
    [anon_sym_PLUS_PLUS] = ACTIONS(1827),
    [anon_sym_DASH_DASH] = ACTIONS(1827),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1825),
    [anon_sym_DASH] = ACTIONS(1825),
    [anon_sym_STAR] = ACTIONS(1829),
    [anon_sym_CARET] = ACTIONS(1827),
    [anon_sym_AMP] = ACTIONS(1827),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1831),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1833),
    [anon_sym_DOT_DOT] = ACTIONS(1835),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1910] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7147),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4354),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4216),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9065),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1910),
    [sym_preproc_endregion] = STATE(1910),
    [sym_preproc_line] = STATE(1910),
    [sym_preproc_pragma] = STATE(1910),
    [sym_preproc_nullable] = STATE(1910),
    [sym_preproc_error] = STATE(1910),
    [sym_preproc_warning] = STATE(1910),
    [sym_preproc_define] = STATE(1910),
    [sym_preproc_undef] = STATE(1910),
    [aux_sym_class_declaration_repeat1] = STATE(3874),
    [aux_sym_lambda_expression_repeat1] = STATE(4311),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1531),
    [anon_sym_ref] = ACTIONS(1533),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1537),
    [anon_sym_TILDE] = ACTIONS(1537),
    [anon_sym_PLUS_PLUS] = ACTIONS(1537),
    [anon_sym_DASH_DASH] = ACTIONS(1537),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1535),
    [anon_sym_DASH] = ACTIONS(1535),
    [anon_sym_STAR] = ACTIONS(1121),
    [anon_sym_CARET] = ACTIONS(1537),
    [anon_sym_AMP] = ACTIONS(1537),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1129),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1131),
    [anon_sym_DOT_DOT] = ACTIONS(1135),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1911] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6922),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2984),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7105),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3056),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1911),
    [sym_preproc_endregion] = STATE(1911),
    [sym_preproc_line] = STATE(1911),
    [sym_preproc_pragma] = STATE(1911),
    [sym_preproc_nullable] = STATE(1911),
    [sym_preproc_error] = STATE(1911),
    [sym_preproc_warning] = STATE(1911),
    [sym_preproc_define] = STATE(1911),
    [sym_preproc_undef] = STATE(1911),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(2241),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1912] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6933),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2950),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7095),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5722),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4215),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7446),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9108),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1912),
    [sym_preproc_endregion] = STATE(1912),
    [sym_preproc_line] = STATE(1912),
    [sym_preproc_pragma] = STATE(1912),
    [sym_preproc_nullable] = STATE(1912),
    [sym_preproc_error] = STATE(1912),
    [sym_preproc_warning] = STATE(1912),
    [sym_preproc_define] = STATE(1912),
    [sym_preproc_undef] = STATE(1912),
    [aux_sym_class_declaration_repeat1] = STATE(3848),
    [aux_sym_lambda_expression_repeat1] = STATE(4282),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1837),
    [anon_sym_ref] = ACTIONS(1839),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1841),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1845),
    [anon_sym_TILDE] = ACTIONS(1845),
    [anon_sym_PLUS_PLUS] = ACTIONS(1845),
    [anon_sym_DASH_DASH] = ACTIONS(1845),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1843),
    [anon_sym_DASH] = ACTIONS(1843),
    [anon_sym_STAR] = ACTIONS(1847),
    [anon_sym_CARET] = ACTIONS(1845),
    [anon_sym_AMP] = ACTIONS(1845),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1849),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1851),
    [anon_sym_DOT_DOT] = ACTIONS(1853),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1913] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6933),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2950),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7095),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5723),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4215),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7446),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9108),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1913),
    [sym_preproc_endregion] = STATE(1913),
    [sym_preproc_line] = STATE(1913),
    [sym_preproc_pragma] = STATE(1913),
    [sym_preproc_nullable] = STATE(1913),
    [sym_preproc_error] = STATE(1913),
    [sym_preproc_warning] = STATE(1913),
    [sym_preproc_define] = STATE(1913),
    [sym_preproc_undef] = STATE(1913),
    [aux_sym_class_declaration_repeat1] = STATE(3848),
    [aux_sym_lambda_expression_repeat1] = STATE(4282),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1837),
    [anon_sym_ref] = ACTIONS(1839),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1841),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1845),
    [anon_sym_TILDE] = ACTIONS(1845),
    [anon_sym_PLUS_PLUS] = ACTIONS(1845),
    [anon_sym_DASH_DASH] = ACTIONS(1845),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1843),
    [anon_sym_DASH] = ACTIONS(1843),
    [anon_sym_STAR] = ACTIONS(1847),
    [anon_sym_CARET] = ACTIONS(1845),
    [anon_sym_AMP] = ACTIONS(1845),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1849),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1851),
    [anon_sym_DOT_DOT] = ACTIONS(1853),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1914] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6955),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2975),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6988),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3561),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3800),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7425),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9573),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1914),
    [sym_preproc_endregion] = STATE(1914),
    [sym_preproc_line] = STATE(1914),
    [sym_preproc_pragma] = STATE(1914),
    [sym_preproc_nullable] = STATE(1914),
    [sym_preproc_error] = STATE(1914),
    [sym_preproc_warning] = STATE(1914),
    [sym_preproc_define] = STATE(1914),
    [sym_preproc_undef] = STATE(1914),
    [aux_sym_class_declaration_repeat1] = STATE(3818),
    [aux_sym_lambda_expression_repeat1] = STATE(4229),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2259),
    [anon_sym_ref] = ACTIONS(2261),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1933),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2265),
    [anon_sym_TILDE] = ACTIONS(2265),
    [anon_sym_PLUS_PLUS] = ACTIONS(2265),
    [anon_sym_DASH_DASH] = ACTIONS(2265),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2263),
    [anon_sym_DASH] = ACTIONS(2263),
    [anon_sym_STAR] = ACTIONS(1939),
    [anon_sym_CARET] = ACTIONS(2265),
    [anon_sym_AMP] = ACTIONS(2265),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2267),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2269),
    [anon_sym_DOT_DOT] = ACTIONS(2271),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1915] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6925),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2932),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7105),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6723),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3569),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1915),
    [sym_preproc_endregion] = STATE(1915),
    [sym_preproc_line] = STATE(1915),
    [sym_preproc_pragma] = STATE(1915),
    [sym_preproc_nullable] = STATE(1915),
    [sym_preproc_error] = STATE(1915),
    [sym_preproc_warning] = STATE(1915),
    [sym_preproc_define] = STATE(1915),
    [sym_preproc_undef] = STATE(1915),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(2979),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(1777),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1916] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6915),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7099),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5682),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4224),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7442),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9174),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1916),
    [sym_preproc_endregion] = STATE(1916),
    [sym_preproc_line] = STATE(1916),
    [sym_preproc_pragma] = STATE(1916),
    [sym_preproc_nullable] = STATE(1916),
    [sym_preproc_error] = STATE(1916),
    [sym_preproc_warning] = STATE(1916),
    [sym_preproc_define] = STATE(1916),
    [sym_preproc_undef] = STATE(1916),
    [aux_sym_class_declaration_repeat1] = STATE(3849),
    [aux_sym_lambda_expression_repeat1] = STATE(4284),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1653),
    [anon_sym_ref] = ACTIONS(1655),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1659),
    [anon_sym_TILDE] = ACTIONS(1659),
    [anon_sym_PLUS_PLUS] = ACTIONS(1659),
    [anon_sym_DASH_DASH] = ACTIONS(1659),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1657),
    [anon_sym_DASH] = ACTIONS(1657),
    [anon_sym_STAR] = ACTIONS(1661),
    [anon_sym_CARET] = ACTIONS(1659),
    [anon_sym_AMP] = ACTIONS(1659),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1663),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1665),
    [anon_sym_DOT_DOT] = ACTIONS(1667),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1917] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6915),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7099),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5705),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4224),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7442),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9174),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1917),
    [sym_preproc_endregion] = STATE(1917),
    [sym_preproc_line] = STATE(1917),
    [sym_preproc_pragma] = STATE(1917),
    [sym_preproc_nullable] = STATE(1917),
    [sym_preproc_error] = STATE(1917),
    [sym_preproc_warning] = STATE(1917),
    [sym_preproc_define] = STATE(1917),
    [sym_preproc_undef] = STATE(1917),
    [aux_sym_class_declaration_repeat1] = STATE(3849),
    [aux_sym_lambda_expression_repeat1] = STATE(4284),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1653),
    [anon_sym_ref] = ACTIONS(1655),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1659),
    [anon_sym_TILDE] = ACTIONS(1659),
    [anon_sym_PLUS_PLUS] = ACTIONS(1659),
    [anon_sym_DASH_DASH] = ACTIONS(1659),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1657),
    [anon_sym_DASH] = ACTIONS(1657),
    [anon_sym_STAR] = ACTIONS(1661),
    [anon_sym_CARET] = ACTIONS(1659),
    [anon_sym_AMP] = ACTIONS(1659),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1663),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1665),
    [anon_sym_DOT_DOT] = ACTIONS(1667),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1918] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6943),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2986),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7151),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4354),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4518),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7441),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9110),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1918),
    [sym_preproc_endregion] = STATE(1918),
    [sym_preproc_line] = STATE(1918),
    [sym_preproc_pragma] = STATE(1918),
    [sym_preproc_nullable] = STATE(1918),
    [sym_preproc_error] = STATE(1918),
    [sym_preproc_warning] = STATE(1918),
    [sym_preproc_define] = STATE(1918),
    [sym_preproc_undef] = STATE(1918),
    [aux_sym_class_declaration_repeat1] = STATE(3875),
    [aux_sym_lambda_expression_repeat1] = STATE(4315),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2169),
    [anon_sym_ref] = ACTIONS(2171),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2173),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2177),
    [anon_sym_TILDE] = ACTIONS(2177),
    [anon_sym_PLUS_PLUS] = ACTIONS(2177),
    [anon_sym_DASH_DASH] = ACTIONS(2177),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2175),
    [anon_sym_DASH] = ACTIONS(2175),
    [anon_sym_STAR] = ACTIONS(2179),
    [anon_sym_CARET] = ACTIONS(2177),
    [anon_sym_AMP] = ACTIONS(2177),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2181),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2183),
    [anon_sym_DOT_DOT] = ACTIONS(2185),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1919] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6932),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2977),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7105),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6717),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3016),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1919),
    [sym_preproc_endregion] = STATE(1919),
    [sym_preproc_line] = STATE(1919),
    [sym_preproc_pragma] = STATE(1919),
    [sym_preproc_nullable] = STATE(1919),
    [sym_preproc_error] = STATE(1919),
    [sym_preproc_warning] = STATE(1919),
    [sym_preproc_define] = STATE(1919),
    [sym_preproc_undef] = STATE(1919),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2981),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(2137),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1920] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6922),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2984),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7155),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4354),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4541),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7435),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9148),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1920),
    [sym_preproc_endregion] = STATE(1920),
    [sym_preproc_line] = STATE(1920),
    [sym_preproc_pragma] = STATE(1920),
    [sym_preproc_nullable] = STATE(1920),
    [sym_preproc_error] = STATE(1920),
    [sym_preproc_warning] = STATE(1920),
    [sym_preproc_define] = STATE(1920),
    [sym_preproc_undef] = STATE(1920),
    [aux_sym_class_declaration_repeat1] = STATE(3876),
    [aux_sym_lambda_expression_repeat1] = STATE(4317),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2231),
    [anon_sym_ref] = ACTIONS(2233),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2235),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2239),
    [anon_sym_TILDE] = ACTIONS(2239),
    [anon_sym_PLUS_PLUS] = ACTIONS(2239),
    [anon_sym_DASH_DASH] = ACTIONS(2239),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2237),
    [anon_sym_DASH] = ACTIONS(2237),
    [anon_sym_STAR] = ACTIONS(2241),
    [anon_sym_CARET] = ACTIONS(2239),
    [anon_sym_AMP] = ACTIONS(2239),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2243),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2245),
    [anon_sym_DOT_DOT] = ACTIONS(2247),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1921] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6917),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2905),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7105),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6713),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3500),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1921),
    [sym_preproc_endregion] = STATE(1921),
    [sym_preproc_line] = STATE(1921),
    [sym_preproc_pragma] = STATE(1921),
    [sym_preproc_nullable] = STATE(1921),
    [sym_preproc_error] = STATE(1921),
    [sym_preproc_warning] = STATE(1921),
    [sym_preproc_define] = STATE(1921),
    [sym_preproc_undef] = STATE(1921),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(2983),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(1631),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1922] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6925),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2932),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6992),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4456),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3702),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7420),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9634),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(1922),
    [sym_preproc_endregion] = STATE(1922),
    [sym_preproc_line] = STATE(1922),
    [sym_preproc_pragma] = STATE(1922),
    [sym_preproc_nullable] = STATE(1922),
    [sym_preproc_error] = STATE(1922),
    [sym_preproc_warning] = STATE(1922),
    [sym_preproc_define] = STATE(1922),
    [sym_preproc_undef] = STATE(1922),
    [aux_sym_class_declaration_repeat1] = STATE(3819),
    [aux_sym_lambda_expression_repeat1] = STATE(4232),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1995),
    [anon_sym_ref] = ACTIONS(1997),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1771),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(2001),
    [anon_sym_TILDE] = ACTIONS(2001),
    [anon_sym_PLUS_PLUS] = ACTIONS(2001),
    [anon_sym_DASH_DASH] = ACTIONS(2001),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1999),
    [anon_sym_DASH] = ACTIONS(1999),
    [anon_sym_STAR] = ACTIONS(1777),
    [anon_sym_CARET] = ACTIONS(2001),
    [anon_sym_AMP] = ACTIONS(2001),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(2003),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2005),
    [anon_sym_DOT_DOT] = ACTIONS(2007),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [1923] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6928),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7105),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6713),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3500),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1923),
    [sym_preproc_endregion] = STATE(1923),
    [sym_preproc_line] = STATE(1923),
    [sym_preproc_pragma] = STATE(1923),
    [sym_preproc_nullable] = STATE(1923),
    [sym_preproc_error] = STATE(1923),
    [sym_preproc_warning] = STATE(1923),
    [sym_preproc_define] = STATE(1923),
    [sym_preproc_undef] = STATE(1923),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(2983),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(1547),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1924] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6920),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2942),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7032),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3917),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4337),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7427),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9283),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1924),
    [sym_preproc_endregion] = STATE(1924),
    [sym_preproc_line] = STATE(1924),
    [sym_preproc_pragma] = STATE(1924),
    [sym_preproc_nullable] = STATE(1924),
    [sym_preproc_error] = STATE(1924),
    [sym_preproc_warning] = STATE(1924),
    [sym_preproc_define] = STATE(1924),
    [sym_preproc_undef] = STATE(1924),
    [aux_sym_class_declaration_repeat1] = STATE(3829),
    [aux_sym_lambda_expression_repeat1] = STATE(4252),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1801),
    [anon_sym_ref] = ACTIONS(1803),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1805),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1809),
    [anon_sym_TILDE] = ACTIONS(1809),
    [anon_sym_PLUS_PLUS] = ACTIONS(1809),
    [anon_sym_DASH_DASH] = ACTIONS(1809),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1807),
    [anon_sym_DASH] = ACTIONS(1807),
    [anon_sym_STAR] = ACTIONS(1811),
    [anon_sym_CARET] = ACTIONS(1809),
    [anon_sym_AMP] = ACTIONS(1809),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1813),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1815),
    [anon_sym_DOT_DOT] = ACTIONS(1817),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1925] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7105),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3056),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1925),
    [sym_preproc_endregion] = STATE(1925),
    [sym_preproc_line] = STATE(1925),
    [sym_preproc_pragma] = STATE(1925),
    [sym_preproc_nullable] = STATE(1925),
    [sym_preproc_error] = STATE(1925),
    [sym_preproc_warning] = STATE(1925),
    [sym_preproc_define] = STATE(1925),
    [sym_preproc_undef] = STATE(1925),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(1987),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1926] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6932),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2977),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6996),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3561),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4378),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7430),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9693),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1926),
    [sym_preproc_endregion] = STATE(1926),
    [sym_preproc_line] = STATE(1926),
    [sym_preproc_pragma] = STATE(1926),
    [sym_preproc_nullable] = STATE(1926),
    [sym_preproc_error] = STATE(1926),
    [sym_preproc_warning] = STATE(1926),
    [sym_preproc_define] = STATE(1926),
    [sym_preproc_undef] = STATE(1926),
    [aux_sym_class_declaration_repeat1] = STATE(3820),
    [aux_sym_lambda_expression_repeat1] = STATE(4234),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2127),
    [anon_sym_ref] = ACTIONS(2129),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2131),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2135),
    [anon_sym_TILDE] = ACTIONS(2135),
    [anon_sym_PLUS_PLUS] = ACTIONS(2135),
    [anon_sym_DASH_DASH] = ACTIONS(2135),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2133),
    [anon_sym_DASH] = ACTIONS(2133),
    [anon_sym_STAR] = ACTIONS(2137),
    [anon_sym_CARET] = ACTIONS(2135),
    [anon_sym_AMP] = ACTIONS(2135),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2139),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2141),
    [anon_sym_DOT_DOT] = ACTIONS(2143),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1927] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6915),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7105),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6734),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3180),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1927),
    [sym_preproc_endregion] = STATE(1927),
    [sym_preproc_line] = STATE(1927),
    [sym_preproc_pragma] = STATE(1927),
    [sym_preproc_nullable] = STATE(1927),
    [sym_preproc_error] = STATE(1927),
    [sym_preproc_warning] = STATE(1927),
    [sym_preproc_define] = STATE(1927),
    [sym_preproc_undef] = STATE(1927),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(2985),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(1181),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1928] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6915),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7018),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3836),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3585),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7418),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9926),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1928),
    [sym_preproc_endregion] = STATE(1928),
    [sym_preproc_line] = STATE(1928),
    [sym_preproc_pragma] = STATE(1928),
    [sym_preproc_nullable] = STATE(1928),
    [sym_preproc_error] = STATE(1928),
    [sym_preproc_warning] = STATE(1928),
    [sym_preproc_define] = STATE(1928),
    [sym_preproc_undef] = STATE(1928),
    [aux_sym_class_declaration_repeat1] = STATE(3825),
    [aux_sym_lambda_expression_repeat1] = STATE(4244),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1161),
    [anon_sym_ref] = ACTIONS(1163),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1177),
    [anon_sym_TILDE] = ACTIONS(1177),
    [anon_sym_PLUS_PLUS] = ACTIONS(1177),
    [anon_sym_DASH_DASH] = ACTIONS(1177),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1175),
    [anon_sym_DASH] = ACTIONS(1175),
    [anon_sym_STAR] = ACTIONS(1181),
    [anon_sym_CARET] = ACTIONS(1177),
    [anon_sym_AMP] = ACTIONS(1177),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1191),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1193),
    [anon_sym_DOT_DOT] = ACTIONS(1195),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1929] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6920),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2942),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7105),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6713),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3500),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1929),
    [sym_preproc_endregion] = STATE(1929),
    [sym_preproc_line] = STATE(1929),
    [sym_preproc_pragma] = STATE(1929),
    [sym_preproc_nullable] = STATE(1929),
    [sym_preproc_error] = STATE(1929),
    [sym_preproc_warning] = STATE(1929),
    [sym_preproc_define] = STATE(1929),
    [sym_preproc_undef] = STATE(1929),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(2983),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(1811),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1930] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7159),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4354),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4487),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7422),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9176),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1930),
    [sym_preproc_endregion] = STATE(1930),
    [sym_preproc_line] = STATE(1930),
    [sym_preproc_pragma] = STATE(1930),
    [sym_preproc_nullable] = STATE(1930),
    [sym_preproc_error] = STATE(1930),
    [sym_preproc_warning] = STATE(1930),
    [sym_preproc_define] = STATE(1930),
    [sym_preproc_undef] = STATE(1930),
    [aux_sym_class_declaration_repeat1] = STATE(3877),
    [aux_sym_lambda_expression_repeat1] = STATE(4320),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1979),
    [anon_sym_ref] = ACTIONS(1981),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1985),
    [anon_sym_TILDE] = ACTIONS(1985),
    [anon_sym_PLUS_PLUS] = ACTIONS(1985),
    [anon_sym_DASH_DASH] = ACTIONS(1985),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1983),
    [anon_sym_DASH] = ACTIONS(1983),
    [anon_sym_STAR] = ACTIONS(1987),
    [anon_sym_CARET] = ACTIONS(1985),
    [anon_sym_AMP] = ACTIONS(1985),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1989),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1991),
    [anon_sym_DOT_DOT] = ACTIONS(1993),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1931] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6912),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2912),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7105),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6734),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3180),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1931),
    [sym_preproc_endregion] = STATE(1931),
    [sym_preproc_line] = STATE(1931),
    [sym_preproc_pragma] = STATE(1931),
    [sym_preproc_nullable] = STATE(1931),
    [sym_preproc_error] = STATE(1931),
    [sym_preproc_warning] = STATE(1931),
    [sym_preproc_define] = STATE(1931),
    [sym_preproc_undef] = STATE(1931),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(2985),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(1793),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1932] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6950),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7044),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3836),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3868),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7432),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9127),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1932),
    [sym_preproc_endregion] = STATE(1932),
    [sym_preproc_line] = STATE(1932),
    [sym_preproc_pragma] = STATE(1932),
    [sym_preproc_nullable] = STATE(1932),
    [sym_preproc_error] = STATE(1932),
    [sym_preproc_warning] = STATE(1932),
    [sym_preproc_define] = STATE(1932),
    [sym_preproc_undef] = STATE(1932),
    [aux_sym_class_declaration_repeat1] = STATE(3832),
    [aux_sym_lambda_expression_repeat1] = STATE(4259),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1357),
    [anon_sym_ref] = ACTIONS(1359),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1363),
    [anon_sym_TILDE] = ACTIONS(1363),
    [anon_sym_PLUS_PLUS] = ACTIONS(1363),
    [anon_sym_DASH_DASH] = ACTIONS(1363),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1361),
    [anon_sym_DASH] = ACTIONS(1361),
    [anon_sym_STAR] = ACTIONS(1365),
    [anon_sym_CARET] = ACTIONS(1363),
    [anon_sym_AMP] = ACTIONS(1363),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1367),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1369),
    [anon_sym_DOT_DOT] = ACTIONS(1371),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1933] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6950),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7105),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6734),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3180),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1933),
    [sym_preproc_endregion] = STATE(1933),
    [sym_preproc_line] = STATE(1933),
    [sym_preproc_pragma] = STATE(1933),
    [sym_preproc_nullable] = STATE(1933),
    [sym_preproc_error] = STATE(1933),
    [sym_preproc_warning] = STATE(1933),
    [sym_preproc_define] = STATE(1933),
    [sym_preproc_undef] = STATE(1933),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(2985),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(1365),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1934] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6912),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2912),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7040),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3836),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3963),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7448),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9641),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1934),
    [sym_preproc_endregion] = STATE(1934),
    [sym_preproc_line] = STATE(1934),
    [sym_preproc_pragma] = STATE(1934),
    [sym_preproc_nullable] = STATE(1934),
    [sym_preproc_error] = STATE(1934),
    [sym_preproc_warning] = STATE(1934),
    [sym_preproc_define] = STATE(1934),
    [sym_preproc_undef] = STATE(1934),
    [aux_sym_class_declaration_repeat1] = STATE(3831),
    [aux_sym_lambda_expression_repeat1] = STATE(4257),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1785),
    [anon_sym_ref] = ACTIONS(1787),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1595),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1791),
    [anon_sym_TILDE] = ACTIONS(1791),
    [anon_sym_PLUS_PLUS] = ACTIONS(1791),
    [anon_sym_DASH_DASH] = ACTIONS(1791),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1789),
    [anon_sym_DASH] = ACTIONS(1789),
    [anon_sym_STAR] = ACTIONS(1793),
    [anon_sym_CARET] = ACTIONS(1791),
    [anon_sym_AMP] = ACTIONS(1791),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1795),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1797),
    [anon_sym_DOT_DOT] = ACTIONS(1799),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1935] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6914),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2960),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7105),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6717),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3016),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1935),
    [sym_preproc_endregion] = STATE(1935),
    [sym_preproc_line] = STATE(1935),
    [sym_preproc_pragma] = STATE(1935),
    [sym_preproc_nullable] = STATE(1935),
    [sym_preproc_error] = STATE(1935),
    [sym_preproc_warning] = STATE(1935),
    [sym_preproc_define] = STATE(1935),
    [sym_preproc_undef] = STATE(1935),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2981),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(2161),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1936] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6943),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2986),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7065),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3917),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4342),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7419),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9334),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1936),
    [sym_preproc_endregion] = STATE(1936),
    [sym_preproc_line] = STATE(1936),
    [sym_preproc_pragma] = STATE(1936),
    [sym_preproc_nullable] = STATE(1936),
    [sym_preproc_error] = STATE(1936),
    [sym_preproc_warning] = STATE(1936),
    [sym_preproc_define] = STATE(1936),
    [sym_preproc_undef] = STATE(1936),
    [aux_sym_class_declaration_repeat1] = STATE(3840),
    [aux_sym_lambda_expression_repeat1] = STATE(4269),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1855),
    [anon_sym_ref] = ACTIONS(1857),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1859),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1863),
    [anon_sym_TILDE] = ACTIONS(1863),
    [anon_sym_PLUS_PLUS] = ACTIONS(1863),
    [anon_sym_DASH_DASH] = ACTIONS(1863),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1861),
    [anon_sym_DASH] = ACTIONS(1861),
    [anon_sym_STAR] = ACTIONS(1865),
    [anon_sym_CARET] = ACTIONS(1863),
    [anon_sym_AMP] = ACTIONS(1863),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1867),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1869),
    [anon_sym_DOT_DOT] = ACTIONS(1871),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1937] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6926),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2950),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7105),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6717),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3016),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1937),
    [sym_preproc_endregion] = STATE(1937),
    [sym_preproc_line] = STATE(1937),
    [sym_preproc_pragma] = STATE(1937),
    [sym_preproc_nullable] = STATE(1937),
    [sym_preproc_error] = STATE(1937),
    [sym_preproc_warning] = STATE(1937),
    [sym_preproc_define] = STATE(1937),
    [sym_preproc_undef] = STATE(1937),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2981),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(2223),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1938] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6914),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2960),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7049),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3561),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4399),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7440),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9013),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1938),
    [sym_preproc_endregion] = STATE(1938),
    [sym_preproc_line] = STATE(1938),
    [sym_preproc_pragma] = STATE(1938),
    [sym_preproc_nullable] = STATE(1938),
    [sym_preproc_error] = STATE(1938),
    [sym_preproc_warning] = STATE(1938),
    [sym_preproc_define] = STATE(1938),
    [sym_preproc_undef] = STATE(1938),
    [aux_sym_class_declaration_repeat1] = STATE(3833),
    [aux_sym_lambda_expression_repeat1] = STATE(4261),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2151),
    [anon_sym_ref] = ACTIONS(2153),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2155),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2159),
    [anon_sym_TILDE] = ACTIONS(2159),
    [anon_sym_PLUS_PLUS] = ACTIONS(2159),
    [anon_sym_DASH_DASH] = ACTIONS(2159),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2157),
    [anon_sym_DASH] = ACTIONS(2157),
    [anon_sym_STAR] = ACTIONS(2161),
    [anon_sym_CARET] = ACTIONS(2159),
    [anon_sym_AMP] = ACTIONS(2159),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2163),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2165),
    [anon_sym_DOT_DOT] = ACTIONS(2167),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1939] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6927),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2912),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7105),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6734),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3180),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1939),
    [sym_preproc_endregion] = STATE(1939),
    [sym_preproc_line] = STATE(1939),
    [sym_preproc_pragma] = STATE(1939),
    [sym_preproc_nullable] = STATE(1939),
    [sym_preproc_error] = STATE(1939),
    [sym_preproc_warning] = STATE(1939),
    [sym_preproc_define] = STATE(1939),
    [sym_preproc_undef] = STATE(1939),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(2985),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(1601),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1940] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6922),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2984),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7069),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3917),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4344),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7423),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9604),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1940),
    [sym_preproc_endregion] = STATE(1940),
    [sym_preproc_line] = STATE(1940),
    [sym_preproc_pragma] = STATE(1940),
    [sym_preproc_nullable] = STATE(1940),
    [sym_preproc_error] = STATE(1940),
    [sym_preproc_warning] = STATE(1940),
    [sym_preproc_define] = STATE(1940),
    [sym_preproc_undef] = STATE(1940),
    [aux_sym_class_declaration_repeat1] = STATE(3841),
    [aux_sym_lambda_expression_repeat1] = STATE(4271),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1875),
    [anon_sym_ref] = ACTIONS(1877),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1879),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1883),
    [anon_sym_TILDE] = ACTIONS(1883),
    [anon_sym_PLUS_PLUS] = ACTIONS(1883),
    [anon_sym_DASH_DASH] = ACTIONS(1883),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1881),
    [anon_sym_DASH] = ACTIONS(1881),
    [anon_sym_STAR] = ACTIONS(1885),
    [anon_sym_CARET] = ACTIONS(1883),
    [anon_sym_AMP] = ACTIONS(1883),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1887),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1889),
    [anon_sym_DOT_DOT] = ACTIONS(1891),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1941] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6916),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7105),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6717),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3016),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1941),
    [sym_preproc_endregion] = STATE(1941),
    [sym_preproc_line] = STATE(1941),
    [sym_preproc_pragma] = STATE(1941),
    [sym_preproc_nullable] = STATE(1941),
    [sym_preproc_error] = STATE(1941),
    [sym_preproc_warning] = STATE(1941),
    [sym_preproc_define] = STATE(1941),
    [sym_preproc_undef] = STATE(1941),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2981),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(1971),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1942] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6926),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2950),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7053),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3561),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4458),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7431),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9158),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1942),
    [sym_preproc_endregion] = STATE(1942),
    [sym_preproc_line] = STATE(1942),
    [sym_preproc_pragma] = STATE(1942),
    [sym_preproc_nullable] = STATE(1942),
    [sym_preproc_error] = STATE(1942),
    [sym_preproc_warning] = STATE(1942),
    [sym_preproc_define] = STATE(1942),
    [sym_preproc_undef] = STATE(1942),
    [aux_sym_class_declaration_repeat1] = STATE(3835),
    [aux_sym_lambda_expression_repeat1] = STATE(4263),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(2213),
    [anon_sym_ref] = ACTIONS(2215),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2217),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(2221),
    [anon_sym_TILDE] = ACTIONS(2221),
    [anon_sym_PLUS_PLUS] = ACTIONS(2221),
    [anon_sym_DASH_DASH] = ACTIONS(2221),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2219),
    [anon_sym_DASH] = ACTIONS(2219),
    [anon_sym_STAR] = ACTIONS(2223),
    [anon_sym_CARET] = ACTIONS(2221),
    [anon_sym_AMP] = ACTIONS(2221),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2225),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2227),
    [anon_sym_DOT_DOT] = ACTIONS(2229),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1943] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6943),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2986),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7105),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6713),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3500),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1943),
    [sym_preproc_endregion] = STATE(1943),
    [sym_preproc_line] = STATE(1943),
    [sym_preproc_pragma] = STATE(1943),
    [sym_preproc_nullable] = STATE(1943),
    [sym_preproc_error] = STATE(1943),
    [sym_preproc_warning] = STATE(1943),
    [sym_preproc_define] = STATE(1943),
    [sym_preproc_undef] = STATE(1943),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(2983),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(1865),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1944] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6941),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2977),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7077),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3836),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4200),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7415),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9773),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1944),
    [sym_preproc_endregion] = STATE(1944),
    [sym_preproc_line] = STATE(1944),
    [sym_preproc_pragma] = STATE(1944),
    [sym_preproc_nullable] = STATE(1944),
    [sym_preproc_error] = STATE(1944),
    [sym_preproc_warning] = STATE(1944),
    [sym_preproc_define] = STATE(1944),
    [sym_preproc_undef] = STATE(1944),
    [aux_sym_class_declaration_repeat1] = STATE(3843),
    [aux_sym_lambda_expression_repeat1] = STATE(4275),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1911),
    [anon_sym_ref] = ACTIONS(1913),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1915),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1919),
    [anon_sym_TILDE] = ACTIONS(1919),
    [anon_sym_PLUS_PLUS] = ACTIONS(1919),
    [anon_sym_DASH_DASH] = ACTIONS(1919),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1917),
    [anon_sym_DASH] = ACTIONS(1917),
    [anon_sym_STAR] = ACTIONS(1921),
    [anon_sym_CARET] = ACTIONS(1919),
    [anon_sym_AMP] = ACTIONS(1919),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1923),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1925),
    [anon_sym_DOT_DOT] = ACTIONS(1927),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1945] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6922),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2984),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7105),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6713),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3500),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1945),
    [sym_preproc_endregion] = STATE(1945),
    [sym_preproc_line] = STATE(1945),
    [sym_preproc_pragma] = STATE(1945),
    [sym_preproc_nullable] = STATE(1945),
    [sym_preproc_error] = STATE(1945),
    [sym_preproc_warning] = STATE(1945),
    [sym_preproc_define] = STATE(1945),
    [sym_preproc_undef] = STATE(1945),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(2983),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(1885),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1946] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6927),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2912),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7057),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3836),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(3960),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7439),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9222),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1946),
    [sym_preproc_endregion] = STATE(1946),
    [sym_preproc_line] = STATE(1946),
    [sym_preproc_pragma] = STATE(1946),
    [sym_preproc_nullable] = STATE(1946),
    [sym_preproc_error] = STATE(1946),
    [sym_preproc_warning] = STATE(1946),
    [sym_preproc_define] = STATE(1946),
    [sym_preproc_undef] = STATE(1946),
    [aux_sym_class_declaration_repeat1] = STATE(3837),
    [aux_sym_lambda_expression_repeat1] = STATE(4265),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1591),
    [anon_sym_ref] = ACTIONS(1593),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1595),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1599),
    [anon_sym_TILDE] = ACTIONS(1599),
    [anon_sym_PLUS_PLUS] = ACTIONS(1599),
    [anon_sym_DASH_DASH] = ACTIONS(1599),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1597),
    [anon_sym_DASH] = ACTIONS(1597),
    [anon_sym_STAR] = ACTIONS(1601),
    [anon_sym_CARET] = ACTIONS(1599),
    [anon_sym_AMP] = ACTIONS(1599),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1603),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1605),
    [anon_sym_DOT_DOT] = ACTIONS(1607),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1947] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6941),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2977),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7105),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6734),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3180),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1947),
    [sym_preproc_endregion] = STATE(1947),
    [sym_preproc_line] = STATE(1947),
    [sym_preproc_pragma] = STATE(1947),
    [sym_preproc_nullable] = STATE(1947),
    [sym_preproc_error] = STATE(1947),
    [sym_preproc_warning] = STATE(1947),
    [sym_preproc_define] = STATE(1947),
    [sym_preproc_undef] = STATE(1947),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(2985),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(1921),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1948] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7085),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3917),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4345),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7436),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9001),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1948),
    [sym_preproc_endregion] = STATE(1948),
    [sym_preproc_line] = STATE(1948),
    [sym_preproc_pragma] = STATE(1948),
    [sym_preproc_nullable] = STATE(1948),
    [sym_preproc_error] = STATE(1948),
    [sym_preproc_warning] = STATE(1948),
    [sym_preproc_define] = STATE(1948),
    [sym_preproc_undef] = STATE(1948),
    [aux_sym_class_declaration_repeat1] = STATE(3846),
    [aux_sym_lambda_expression_repeat1] = STATE(4278),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1669),
    [anon_sym_ref] = ACTIONS(1671),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1675),
    [anon_sym_TILDE] = ACTIONS(1675),
    [anon_sym_PLUS_PLUS] = ACTIONS(1675),
    [anon_sym_DASH_DASH] = ACTIONS(1675),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_STAR] = ACTIONS(1677),
    [anon_sym_CARET] = ACTIONS(1675),
    [anon_sym_AMP] = ACTIONS(1675),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1679),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1681),
    [anon_sym_DOT_DOT] = ACTIONS(1683),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1949] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7105),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6713),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3500),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1949),
    [sym_preproc_endregion] = STATE(1949),
    [sym_preproc_line] = STATE(1949),
    [sym_preproc_pragma] = STATE(1949),
    [sym_preproc_nullable] = STATE(1949),
    [sym_preproc_error] = STATE(1949),
    [sym_preproc_warning] = STATE(1949),
    [sym_preproc_define] = STATE(1949),
    [sym_preproc_undef] = STATE(1949),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(2983),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(1677),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1950] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6916),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7061),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3561),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(4369),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7437),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9284),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(1950),
    [sym_preproc_endregion] = STATE(1950),
    [sym_preproc_line] = STATE(1950),
    [sym_preproc_pragma] = STATE(1950),
    [sym_preproc_nullable] = STATE(1950),
    [sym_preproc_error] = STATE(1950),
    [sym_preproc_warning] = STATE(1950),
    [sym_preproc_define] = STATE(1950),
    [sym_preproc_undef] = STATE(1950),
    [aux_sym_class_declaration_repeat1] = STATE(3839),
    [aux_sym_lambda_expression_repeat1] = STATE(4267),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1963),
    [anon_sym_ref] = ACTIONS(1965),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1249),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1969),
    [anon_sym_TILDE] = ACTIONS(1969),
    [anon_sym_PLUS_PLUS] = ACTIONS(1969),
    [anon_sym_DASH_DASH] = ACTIONS(1969),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1967),
    [anon_sym_DASH] = ACTIONS(1967),
    [anon_sym_STAR] = ACTIONS(1971),
    [anon_sym_CARET] = ACTIONS(1969),
    [anon_sym_AMP] = ACTIONS(1969),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1973),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1975),
    [anon_sym_DOT_DOT] = ACTIONS(1977),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1951] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6910),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2960),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7105),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6734),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3180),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1951),
    [sym_preproc_endregion] = STATE(1951),
    [sym_preproc_line] = STATE(1951),
    [sym_preproc_pragma] = STATE(1951),
    [sym_preproc_nullable] = STATE(1951),
    [sym_preproc_error] = STATE(1951),
    [sym_preproc_warning] = STATE(1951),
    [sym_preproc_define] = STATE(1951),
    [sym_preproc_undef] = STATE(1951),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(2985),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(1829),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1952] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6910),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2960),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7091),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3836),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4208),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7438),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9067),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1952),
    [sym_preproc_endregion] = STATE(1952),
    [sym_preproc_line] = STATE(1952),
    [sym_preproc_pragma] = STATE(1952),
    [sym_preproc_nullable] = STATE(1952),
    [sym_preproc_error] = STATE(1952),
    [sym_preproc_warning] = STATE(1952),
    [sym_preproc_define] = STATE(1952),
    [sym_preproc_undef] = STATE(1952),
    [aux_sym_class_declaration_repeat1] = STATE(3847),
    [aux_sym_lambda_expression_repeat1] = STATE(4280),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1819),
    [anon_sym_ref] = ACTIONS(1821),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1823),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1827),
    [anon_sym_TILDE] = ACTIONS(1827),
    [anon_sym_PLUS_PLUS] = ACTIONS(1827),
    [anon_sym_DASH_DASH] = ACTIONS(1827),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1825),
    [anon_sym_DASH] = ACTIONS(1825),
    [anon_sym_STAR] = ACTIONS(1829),
    [anon_sym_CARET] = ACTIONS(1827),
    [anon_sym_AMP] = ACTIONS(1827),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1831),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1833),
    [anon_sym_DOT_DOT] = ACTIONS(1835),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1953] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6933),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2950),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7105),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6734),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3180),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1953),
    [sym_preproc_endregion] = STATE(1953),
    [sym_preproc_line] = STATE(1953),
    [sym_preproc_pragma] = STATE(1953),
    [sym_preproc_nullable] = STATE(1953),
    [sym_preproc_error] = STATE(1953),
    [sym_preproc_warning] = STATE(1953),
    [sym_preproc_define] = STATE(1953),
    [sym_preproc_undef] = STATE(1953),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(2985),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(1847),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1954] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6933),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2950),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7095),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3836),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4215),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7446),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9108),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1954),
    [sym_preproc_endregion] = STATE(1954),
    [sym_preproc_line] = STATE(1954),
    [sym_preproc_pragma] = STATE(1954),
    [sym_preproc_nullable] = STATE(1954),
    [sym_preproc_error] = STATE(1954),
    [sym_preproc_warning] = STATE(1954),
    [sym_preproc_define] = STATE(1954),
    [sym_preproc_undef] = STATE(1954),
    [aux_sym_class_declaration_repeat1] = STATE(3848),
    [aux_sym_lambda_expression_repeat1] = STATE(4282),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1837),
    [anon_sym_ref] = ACTIONS(1839),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1841),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1845),
    [anon_sym_TILDE] = ACTIONS(1845),
    [anon_sym_PLUS_PLUS] = ACTIONS(1845),
    [anon_sym_DASH_DASH] = ACTIONS(1845),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1843),
    [anon_sym_DASH] = ACTIONS(1843),
    [anon_sym_STAR] = ACTIONS(1847),
    [anon_sym_CARET] = ACTIONS(1845),
    [anon_sym_AMP] = ACTIONS(1845),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1849),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1851),
    [anon_sym_DOT_DOT] = ACTIONS(1853),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1955] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6915),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7105),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6734),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3180),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1955),
    [sym_preproc_endregion] = STATE(1955),
    [sym_preproc_line] = STATE(1955),
    [sym_preproc_pragma] = STATE(1955),
    [sym_preproc_nullable] = STATE(1955),
    [sym_preproc_error] = STATE(1955),
    [sym_preproc_warning] = STATE(1955),
    [sym_preproc_define] = STATE(1955),
    [sym_preproc_undef] = STATE(1955),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(2985),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(1661),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1956] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6915),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2765),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7099),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3836),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4224),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7442),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9174),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2823),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(1956),
    [sym_preproc_endregion] = STATE(1956),
    [sym_preproc_line] = STATE(1956),
    [sym_preproc_pragma] = STATE(1956),
    [sym_preproc_nullable] = STATE(1956),
    [sym_preproc_error] = STATE(1956),
    [sym_preproc_warning] = STATE(1956),
    [sym_preproc_define] = STATE(1956),
    [sym_preproc_undef] = STATE(1956),
    [aux_sym_class_declaration_repeat1] = STATE(3849),
    [aux_sym_lambda_expression_repeat1] = STATE(4284),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1653),
    [anon_sym_ref] = ACTIONS(1655),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1169),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1659),
    [anon_sym_TILDE] = ACTIONS(1659),
    [anon_sym_PLUS_PLUS] = ACTIONS(1659),
    [anon_sym_DASH_DASH] = ACTIONS(1659),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1657),
    [anon_sym_DASH] = ACTIONS(1657),
    [anon_sym_STAR] = ACTIONS(1661),
    [anon_sym_CARET] = ACTIONS(1659),
    [anon_sym_AMP] = ACTIONS(1659),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1663),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1665),
    [anon_sym_DOT_DOT] = ACTIONS(1667),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [1957] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7105),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4354),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1957),
    [sym_preproc_endregion] = STATE(1957),
    [sym_preproc_line] = STATE(1957),
    [sym_preproc_pragma] = STATE(1957),
    [sym_preproc_nullable] = STATE(1957),
    [sym_preproc_error] = STATE(1957),
    [sym_preproc_warning] = STATE(1957),
    [sym_preproc_define] = STATE(1957),
    [sym_preproc_undef] = STATE(1957),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1958] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7105),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6742),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3056),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1958),
    [sym_preproc_endregion] = STATE(1958),
    [sym_preproc_line] = STATE(1958),
    [sym_preproc_pragma] = STATE(1958),
    [sym_preproc_nullable] = STATE(1958),
    [sym_preproc_error] = STATE(1958),
    [sym_preproc_warning] = STATE(1958),
    [sym_preproc_define] = STATE(1958),
    [sym_preproc_undef] = STATE(1958),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1959] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6376),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1959),
    [sym_preproc_endregion] = STATE(1959),
    [sym_preproc_line] = STATE(1959),
    [sym_preproc_pragma] = STATE(1959),
    [sym_preproc_nullable] = STATE(1959),
    [sym_preproc_error] = STATE(1959),
    [sym_preproc_warning] = STATE(1959),
    [sym_preproc_define] = STATE(1959),
    [sym_preproc_undef] = STATE(1959),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1960] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6377),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1960),
    [sym_preproc_endregion] = STATE(1960),
    [sym_preproc_line] = STATE(1960),
    [sym_preproc_pragma] = STATE(1960),
    [sym_preproc_nullable] = STATE(1960),
    [sym_preproc_error] = STATE(1960),
    [sym_preproc_warning] = STATE(1960),
    [sym_preproc_define] = STATE(1960),
    [sym_preproc_undef] = STATE(1960),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1961] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6379),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1961),
    [sym_preproc_endregion] = STATE(1961),
    [sym_preproc_line] = STATE(1961),
    [sym_preproc_pragma] = STATE(1961),
    [sym_preproc_nullable] = STATE(1961),
    [sym_preproc_error] = STATE(1961),
    [sym_preproc_warning] = STATE(1961),
    [sym_preproc_define] = STATE(1961),
    [sym_preproc_undef] = STATE(1961),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1962] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6956),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6380),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9482),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1962),
    [sym_preproc_endregion] = STATE(1962),
    [sym_preproc_line] = STATE(1962),
    [sym_preproc_pragma] = STATE(1962),
    [sym_preproc_nullable] = STATE(1962),
    [sym_preproc_error] = STATE(1962),
    [sym_preproc_warning] = STATE(1962),
    [sym_preproc_define] = STATE(1962),
    [sym_preproc_undef] = STATE(1962),
    [aux_sym_class_declaration_repeat1] = STATE(3853),
    [aux_sym_lambda_expression_repeat1] = STATE(4299),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1497),
    [anon_sym_ref] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1505),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1507),
    [anon_sym_DOT_DOT] = ACTIONS(1509),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1963] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6383),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1963),
    [sym_preproc_endregion] = STATE(1963),
    [sym_preproc_line] = STATE(1963),
    [sym_preproc_pragma] = STATE(1963),
    [sym_preproc_nullable] = STATE(1963),
    [sym_preproc_error] = STATE(1963),
    [sym_preproc_warning] = STATE(1963),
    [sym_preproc_define] = STATE(1963),
    [sym_preproc_undef] = STATE(1963),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1964] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6384),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1964),
    [sym_preproc_endregion] = STATE(1964),
    [sym_preproc_line] = STATE(1964),
    [sym_preproc_pragma] = STATE(1964),
    [sym_preproc_nullable] = STATE(1964),
    [sym_preproc_error] = STATE(1964),
    [sym_preproc_warning] = STATE(1964),
    [sym_preproc_define] = STATE(1964),
    [sym_preproc_undef] = STATE(1964),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1965] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6385),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1965),
    [sym_preproc_endregion] = STATE(1965),
    [sym_preproc_line] = STATE(1965),
    [sym_preproc_pragma] = STATE(1965),
    [sym_preproc_nullable] = STATE(1965),
    [sym_preproc_error] = STATE(1965),
    [sym_preproc_warning] = STATE(1965),
    [sym_preproc_define] = STATE(1965),
    [sym_preproc_undef] = STATE(1965),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1966] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6920),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2942),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7143),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6392),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4489),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7426),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9002),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1966),
    [sym_preproc_endregion] = STATE(1966),
    [sym_preproc_line] = STATE(1966),
    [sym_preproc_pragma] = STATE(1966),
    [sym_preproc_nullable] = STATE(1966),
    [sym_preproc_error] = STATE(1966),
    [sym_preproc_warning] = STATE(1966),
    [sym_preproc_define] = STATE(1966),
    [sym_preproc_undef] = STATE(1966),
    [aux_sym_class_declaration_repeat1] = STATE(3809),
    [aux_sym_lambda_expression_repeat1] = STATE(4308),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2189),
    [anon_sym_ref] = ACTIONS(2191),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2193),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2197),
    [anon_sym_TILDE] = ACTIONS(2197),
    [anon_sym_PLUS_PLUS] = ACTIONS(2197),
    [anon_sym_DASH_DASH] = ACTIONS(2197),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2195),
    [anon_sym_DASH] = ACTIONS(2195),
    [anon_sym_STAR] = ACTIONS(2199),
    [anon_sym_CARET] = ACTIONS(2197),
    [anon_sym_AMP] = ACTIONS(2197),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2201),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2203),
    [anon_sym_DOT_DOT] = ACTIONS(2205),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1967] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7010),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6025),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4334),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9265),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1967),
    [sym_preproc_endregion] = STATE(1967),
    [sym_preproc_line] = STATE(1967),
    [sym_preproc_pragma] = STATE(1967),
    [sym_preproc_nullable] = STATE(1967),
    [sym_preproc_error] = STATE(1967),
    [sym_preproc_warning] = STATE(1967),
    [sym_preproc_define] = STATE(1967),
    [sym_preproc_undef] = STATE(1967),
    [aux_sym_class_declaration_repeat1] = STATE(3823),
    [aux_sym_lambda_expression_repeat1] = STATE(4240),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1751),
    [anon_sym_ref] = ACTIONS(1753),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1755),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1759),
    [anon_sym_TILDE] = ACTIONS(1759),
    [anon_sym_PLUS_PLUS] = ACTIONS(1759),
    [anon_sym_DASH_DASH] = ACTIONS(1759),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1757),
    [anon_sym_DASH] = ACTIONS(1757),
    [anon_sym_STAR] = ACTIONS(1381),
    [anon_sym_CARET] = ACTIONS(1759),
    [anon_sym_AMP] = ACTIONS(1759),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1761),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1763),
    [anon_sym_DOT_DOT] = ACTIONS(1765),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1968] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6962),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5231),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3931),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9818),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1968),
    [sym_preproc_endregion] = STATE(1968),
    [sym_preproc_line] = STATE(1968),
    [sym_preproc_pragma] = STATE(1968),
    [sym_preproc_nullable] = STATE(1968),
    [sym_preproc_error] = STATE(1968),
    [sym_preproc_warning] = STATE(1968),
    [sym_preproc_define] = STATE(1968),
    [sym_preproc_undef] = STATE(1968),
    [aux_sym_class_declaration_repeat1] = STATE(3811),
    [aux_sym_lambda_expression_repeat1] = STATE(4201),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1373),
    [anon_sym_ref] = ACTIONS(1375),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1379),
    [anon_sym_TILDE] = ACTIONS(1379),
    [anon_sym_PLUS_PLUS] = ACTIONS(1379),
    [anon_sym_DASH_DASH] = ACTIONS(1379),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1377),
    [anon_sym_DASH] = ACTIONS(1377),
    [anon_sym_STAR] = ACTIONS(1381),
    [anon_sym_CARET] = ACTIONS(1379),
    [anon_sym_AMP] = ACTIONS(1379),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1383),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1385),
    [anon_sym_DOT_DOT] = ACTIONS(1387),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1969] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6421),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1969),
    [sym_preproc_endregion] = STATE(1969),
    [sym_preproc_line] = STATE(1969),
    [sym_preproc_pragma] = STATE(1969),
    [sym_preproc_nullable] = STATE(1969),
    [sym_preproc_error] = STATE(1969),
    [sym_preproc_warning] = STATE(1969),
    [sym_preproc_define] = STATE(1969),
    [sym_preproc_undef] = STATE(1969),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1970] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6962),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5144),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3931),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9818),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1970),
    [sym_preproc_endregion] = STATE(1970),
    [sym_preproc_line] = STATE(1970),
    [sym_preproc_pragma] = STATE(1970),
    [sym_preproc_nullable] = STATE(1970),
    [sym_preproc_error] = STATE(1970),
    [sym_preproc_warning] = STATE(1970),
    [sym_preproc_define] = STATE(1970),
    [sym_preproc_undef] = STATE(1970),
    [aux_sym_class_declaration_repeat1] = STATE(3811),
    [aux_sym_lambda_expression_repeat1] = STATE(4201),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1373),
    [anon_sym_ref] = ACTIONS(1375),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1379),
    [anon_sym_TILDE] = ACTIONS(1379),
    [anon_sym_PLUS_PLUS] = ACTIONS(1379),
    [anon_sym_DASH_DASH] = ACTIONS(1379),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1377),
    [anon_sym_DASH] = ACTIONS(1377),
    [anon_sym_STAR] = ACTIONS(1381),
    [anon_sym_CARET] = ACTIONS(1379),
    [anon_sym_AMP] = ACTIONS(1379),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1383),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1385),
    [anon_sym_DOT_DOT] = ACTIONS(1387),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1971] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6429),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1971),
    [sym_preproc_endregion] = STATE(1971),
    [sym_preproc_line] = STATE(1971),
    [sym_preproc_pragma] = STATE(1971),
    [sym_preproc_nullable] = STATE(1971),
    [sym_preproc_error] = STATE(1971),
    [sym_preproc_warning] = STATE(1971),
    [sym_preproc_define] = STATE(1971),
    [sym_preproc_undef] = STATE(1971),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1972] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6431),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1972),
    [sym_preproc_endregion] = STATE(1972),
    [sym_preproc_line] = STATE(1972),
    [sym_preproc_pragma] = STATE(1972),
    [sym_preproc_nullable] = STATE(1972),
    [sym_preproc_error] = STATE(1972),
    [sym_preproc_warning] = STATE(1972),
    [sym_preproc_define] = STATE(1972),
    [sym_preproc_undef] = STATE(1972),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1973] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6962),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5145),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3931),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9818),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1973),
    [sym_preproc_endregion] = STATE(1973),
    [sym_preproc_line] = STATE(1973),
    [sym_preproc_pragma] = STATE(1973),
    [sym_preproc_nullable] = STATE(1973),
    [sym_preproc_error] = STATE(1973),
    [sym_preproc_warning] = STATE(1973),
    [sym_preproc_define] = STATE(1973),
    [sym_preproc_undef] = STATE(1973),
    [aux_sym_class_declaration_repeat1] = STATE(3811),
    [aux_sym_lambda_expression_repeat1] = STATE(4201),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1373),
    [anon_sym_ref] = ACTIONS(1375),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1379),
    [anon_sym_TILDE] = ACTIONS(1379),
    [anon_sym_PLUS_PLUS] = ACTIONS(1379),
    [anon_sym_DASH_DASH] = ACTIONS(1379),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1377),
    [anon_sym_DASH] = ACTIONS(1377),
    [anon_sym_STAR] = ACTIONS(1381),
    [anon_sym_CARET] = ACTIONS(1379),
    [anon_sym_AMP] = ACTIONS(1379),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1383),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1385),
    [anon_sym_DOT_DOT] = ACTIONS(1387),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1974] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6962),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5146),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3931),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9818),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1974),
    [sym_preproc_endregion] = STATE(1974),
    [sym_preproc_line] = STATE(1974),
    [sym_preproc_pragma] = STATE(1974),
    [sym_preproc_nullable] = STATE(1974),
    [sym_preproc_error] = STATE(1974),
    [sym_preproc_warning] = STATE(1974),
    [sym_preproc_define] = STATE(1974),
    [sym_preproc_undef] = STATE(1974),
    [aux_sym_class_declaration_repeat1] = STATE(3811),
    [aux_sym_lambda_expression_repeat1] = STATE(4201),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1373),
    [anon_sym_ref] = ACTIONS(1375),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1379),
    [anon_sym_TILDE] = ACTIONS(1379),
    [anon_sym_PLUS_PLUS] = ACTIONS(1379),
    [anon_sym_DASH_DASH] = ACTIONS(1379),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1377),
    [anon_sym_DASH] = ACTIONS(1377),
    [anon_sym_STAR] = ACTIONS(1381),
    [anon_sym_CARET] = ACTIONS(1379),
    [anon_sym_AMP] = ACTIONS(1379),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1383),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1385),
    [anon_sym_DOT_DOT] = ACTIONS(1387),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1975] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6313),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1975),
    [sym_preproc_endregion] = STATE(1975),
    [sym_preproc_line] = STATE(1975),
    [sym_preproc_pragma] = STATE(1975),
    [sym_preproc_nullable] = STATE(1975),
    [sym_preproc_error] = STATE(1975),
    [sym_preproc_warning] = STATE(1975),
    [sym_preproc_define] = STATE(1975),
    [sym_preproc_undef] = STATE(1975),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1976] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6948),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2940),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7022),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4983),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3795),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7417),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9004),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1976),
    [sym_preproc_endregion] = STATE(1976),
    [sym_preproc_line] = STATE(1976),
    [sym_preproc_pragma] = STATE(1976),
    [sym_preproc_nullable] = STATE(1976),
    [sym_preproc_error] = STATE(1976),
    [sym_preproc_warning] = STATE(1976),
    [sym_preproc_define] = STATE(1976),
    [sym_preproc_undef] = STATE(1976),
    [aux_sym_class_declaration_repeat1] = STATE(3827),
    [aux_sym_lambda_expression_repeat1] = STATE(4246),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1893),
    [anon_sym_ref] = ACTIONS(1895),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1897),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1901),
    [anon_sym_TILDE] = ACTIONS(1901),
    [anon_sym_PLUS_PLUS] = ACTIONS(1901),
    [anon_sym_DASH_DASH] = ACTIONS(1901),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1899),
    [anon_sym_DASH] = ACTIONS(1899),
    [anon_sym_STAR] = ACTIONS(1903),
    [anon_sym_CARET] = ACTIONS(1901),
    [anon_sym_AMP] = ACTIONS(1901),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1905),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1907),
    [anon_sym_DOT_DOT] = ACTIONS(1909),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1977] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6948),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2940),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7022),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4976),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3795),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7417),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9004),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1977),
    [sym_preproc_endregion] = STATE(1977),
    [sym_preproc_line] = STATE(1977),
    [sym_preproc_pragma] = STATE(1977),
    [sym_preproc_nullable] = STATE(1977),
    [sym_preproc_error] = STATE(1977),
    [sym_preproc_warning] = STATE(1977),
    [sym_preproc_define] = STATE(1977),
    [sym_preproc_undef] = STATE(1977),
    [aux_sym_class_declaration_repeat1] = STATE(3827),
    [aux_sym_lambda_expression_repeat1] = STATE(4246),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1893),
    [anon_sym_ref] = ACTIONS(1895),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1897),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1901),
    [anon_sym_TILDE] = ACTIONS(1901),
    [anon_sym_PLUS_PLUS] = ACTIONS(1901),
    [anon_sym_DASH_DASH] = ACTIONS(1901),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1899),
    [anon_sym_DASH] = ACTIONS(1899),
    [anon_sym_STAR] = ACTIONS(1903),
    [anon_sym_CARET] = ACTIONS(1901),
    [anon_sym_AMP] = ACTIONS(1901),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1905),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1907),
    [anon_sym_DOT_DOT] = ACTIONS(1909),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1978] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7010),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5938),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4334),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9265),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1978),
    [sym_preproc_endregion] = STATE(1978),
    [sym_preproc_line] = STATE(1978),
    [sym_preproc_pragma] = STATE(1978),
    [sym_preproc_nullable] = STATE(1978),
    [sym_preproc_error] = STATE(1978),
    [sym_preproc_warning] = STATE(1978),
    [sym_preproc_define] = STATE(1978),
    [sym_preproc_undef] = STATE(1978),
    [aux_sym_class_declaration_repeat1] = STATE(3823),
    [aux_sym_lambda_expression_repeat1] = STATE(4240),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1751),
    [anon_sym_ref] = ACTIONS(1753),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1755),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1759),
    [anon_sym_TILDE] = ACTIONS(1759),
    [anon_sym_PLUS_PLUS] = ACTIONS(1759),
    [anon_sym_DASH_DASH] = ACTIONS(1759),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1757),
    [anon_sym_DASH] = ACTIONS(1757),
    [anon_sym_STAR] = ACTIONS(1381),
    [anon_sym_CARET] = ACTIONS(1759),
    [anon_sym_AMP] = ACTIONS(1759),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1761),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1763),
    [anon_sym_DOT_DOT] = ACTIONS(1765),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1979] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7010),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5939),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4334),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9265),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1979),
    [sym_preproc_endregion] = STATE(1979),
    [sym_preproc_line] = STATE(1979),
    [sym_preproc_pragma] = STATE(1979),
    [sym_preproc_nullable] = STATE(1979),
    [sym_preproc_error] = STATE(1979),
    [sym_preproc_warning] = STATE(1979),
    [sym_preproc_define] = STATE(1979),
    [sym_preproc_undef] = STATE(1979),
    [aux_sym_class_declaration_repeat1] = STATE(3823),
    [aux_sym_lambda_expression_repeat1] = STATE(4240),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1751),
    [anon_sym_ref] = ACTIONS(1753),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1755),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1759),
    [anon_sym_TILDE] = ACTIONS(1759),
    [anon_sym_PLUS_PLUS] = ACTIONS(1759),
    [anon_sym_DASH_DASH] = ACTIONS(1759),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1757),
    [anon_sym_DASH] = ACTIONS(1757),
    [anon_sym_STAR] = ACTIONS(1381),
    [anon_sym_CARET] = ACTIONS(1759),
    [anon_sym_AMP] = ACTIONS(1759),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1761),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1763),
    [anon_sym_DOT_DOT] = ACTIONS(1765),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1980] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7010),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6083),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4334),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9265),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1980),
    [sym_preproc_endregion] = STATE(1980),
    [sym_preproc_line] = STATE(1980),
    [sym_preproc_pragma] = STATE(1980),
    [sym_preproc_nullable] = STATE(1980),
    [sym_preproc_error] = STATE(1980),
    [sym_preproc_warning] = STATE(1980),
    [sym_preproc_define] = STATE(1980),
    [sym_preproc_undef] = STATE(1980),
    [aux_sym_class_declaration_repeat1] = STATE(3823),
    [aux_sym_lambda_expression_repeat1] = STATE(4240),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1751),
    [anon_sym_ref] = ACTIONS(1753),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1755),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1759),
    [anon_sym_TILDE] = ACTIONS(1759),
    [anon_sym_PLUS_PLUS] = ACTIONS(1759),
    [anon_sym_DASH_DASH] = ACTIONS(1759),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1757),
    [anon_sym_DASH] = ACTIONS(1757),
    [anon_sym_STAR] = ACTIONS(1381),
    [anon_sym_CARET] = ACTIONS(1759),
    [anon_sym_AMP] = ACTIONS(1759),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1761),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1763),
    [anon_sym_DOT_DOT] = ACTIONS(1765),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1981] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7010),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5940),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4334),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9265),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1981),
    [sym_preproc_endregion] = STATE(1981),
    [sym_preproc_line] = STATE(1981),
    [sym_preproc_pragma] = STATE(1981),
    [sym_preproc_nullable] = STATE(1981),
    [sym_preproc_error] = STATE(1981),
    [sym_preproc_warning] = STATE(1981),
    [sym_preproc_define] = STATE(1981),
    [sym_preproc_undef] = STATE(1981),
    [aux_sym_class_declaration_repeat1] = STATE(3823),
    [aux_sym_lambda_expression_repeat1] = STATE(4240),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1751),
    [anon_sym_ref] = ACTIONS(1753),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1755),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1759),
    [anon_sym_TILDE] = ACTIONS(1759),
    [anon_sym_PLUS_PLUS] = ACTIONS(1759),
    [anon_sym_DASH_DASH] = ACTIONS(1759),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1757),
    [anon_sym_DASH] = ACTIONS(1757),
    [anon_sym_STAR] = ACTIONS(1381),
    [anon_sym_CARET] = ACTIONS(1759),
    [anon_sym_AMP] = ACTIONS(1759),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1761),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1763),
    [anon_sym_DOT_DOT] = ACTIONS(1765),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1982] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7010),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5941),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4334),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9265),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1982),
    [sym_preproc_endregion] = STATE(1982),
    [sym_preproc_line] = STATE(1982),
    [sym_preproc_pragma] = STATE(1982),
    [sym_preproc_nullable] = STATE(1982),
    [sym_preproc_error] = STATE(1982),
    [sym_preproc_warning] = STATE(1982),
    [sym_preproc_define] = STATE(1982),
    [sym_preproc_undef] = STATE(1982),
    [aux_sym_class_declaration_repeat1] = STATE(3823),
    [aux_sym_lambda_expression_repeat1] = STATE(4240),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1751),
    [anon_sym_ref] = ACTIONS(1753),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1755),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1759),
    [anon_sym_TILDE] = ACTIONS(1759),
    [anon_sym_PLUS_PLUS] = ACTIONS(1759),
    [anon_sym_DASH_DASH] = ACTIONS(1759),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1757),
    [anon_sym_DASH] = ACTIONS(1757),
    [anon_sym_STAR] = ACTIONS(1381),
    [anon_sym_CARET] = ACTIONS(1759),
    [anon_sym_AMP] = ACTIONS(1759),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1761),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1763),
    [anon_sym_DOT_DOT] = ACTIONS(1765),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1983] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7010),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5942),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4334),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9265),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1983),
    [sym_preproc_endregion] = STATE(1983),
    [sym_preproc_line] = STATE(1983),
    [sym_preproc_pragma] = STATE(1983),
    [sym_preproc_nullable] = STATE(1983),
    [sym_preproc_error] = STATE(1983),
    [sym_preproc_warning] = STATE(1983),
    [sym_preproc_define] = STATE(1983),
    [sym_preproc_undef] = STATE(1983),
    [aux_sym_class_declaration_repeat1] = STATE(3823),
    [aux_sym_lambda_expression_repeat1] = STATE(4240),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1751),
    [anon_sym_ref] = ACTIONS(1753),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1755),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1759),
    [anon_sym_TILDE] = ACTIONS(1759),
    [anon_sym_PLUS_PLUS] = ACTIONS(1759),
    [anon_sym_DASH_DASH] = ACTIONS(1759),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1757),
    [anon_sym_DASH] = ACTIONS(1757),
    [anon_sym_STAR] = ACTIONS(1381),
    [anon_sym_CARET] = ACTIONS(1759),
    [anon_sym_AMP] = ACTIONS(1759),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1761),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1763),
    [anon_sym_DOT_DOT] = ACTIONS(1765),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1984] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7010),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5943),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4334),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9265),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1984),
    [sym_preproc_endregion] = STATE(1984),
    [sym_preproc_line] = STATE(1984),
    [sym_preproc_pragma] = STATE(1984),
    [sym_preproc_nullable] = STATE(1984),
    [sym_preproc_error] = STATE(1984),
    [sym_preproc_warning] = STATE(1984),
    [sym_preproc_define] = STATE(1984),
    [sym_preproc_undef] = STATE(1984),
    [aux_sym_class_declaration_repeat1] = STATE(3823),
    [aux_sym_lambda_expression_repeat1] = STATE(4240),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1751),
    [anon_sym_ref] = ACTIONS(1753),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1755),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1759),
    [anon_sym_TILDE] = ACTIONS(1759),
    [anon_sym_PLUS_PLUS] = ACTIONS(1759),
    [anon_sym_DASH_DASH] = ACTIONS(1759),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1757),
    [anon_sym_DASH] = ACTIONS(1757),
    [anon_sym_STAR] = ACTIONS(1381),
    [anon_sym_CARET] = ACTIONS(1759),
    [anon_sym_AMP] = ACTIONS(1759),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1761),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1763),
    [anon_sym_DOT_DOT] = ACTIONS(1765),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1985] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7010),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5944),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4334),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9265),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1985),
    [sym_preproc_endregion] = STATE(1985),
    [sym_preproc_line] = STATE(1985),
    [sym_preproc_pragma] = STATE(1985),
    [sym_preproc_nullable] = STATE(1985),
    [sym_preproc_error] = STATE(1985),
    [sym_preproc_warning] = STATE(1985),
    [sym_preproc_define] = STATE(1985),
    [sym_preproc_undef] = STATE(1985),
    [aux_sym_class_declaration_repeat1] = STATE(3823),
    [aux_sym_lambda_expression_repeat1] = STATE(4240),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1751),
    [anon_sym_ref] = ACTIONS(1753),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1755),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1759),
    [anon_sym_TILDE] = ACTIONS(1759),
    [anon_sym_PLUS_PLUS] = ACTIONS(1759),
    [anon_sym_DASH_DASH] = ACTIONS(1759),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1757),
    [anon_sym_DASH] = ACTIONS(1757),
    [anon_sym_STAR] = ACTIONS(1381),
    [anon_sym_CARET] = ACTIONS(1759),
    [anon_sym_AMP] = ACTIONS(1759),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1761),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1763),
    [anon_sym_DOT_DOT] = ACTIONS(1765),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1986] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6962),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5152),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3931),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9818),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1986),
    [sym_preproc_endregion] = STATE(1986),
    [sym_preproc_line] = STATE(1986),
    [sym_preproc_pragma] = STATE(1986),
    [sym_preproc_nullable] = STATE(1986),
    [sym_preproc_error] = STATE(1986),
    [sym_preproc_warning] = STATE(1986),
    [sym_preproc_define] = STATE(1986),
    [sym_preproc_undef] = STATE(1986),
    [aux_sym_class_declaration_repeat1] = STATE(3811),
    [aux_sym_lambda_expression_repeat1] = STATE(4201),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1373),
    [anon_sym_ref] = ACTIONS(1375),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1379),
    [anon_sym_TILDE] = ACTIONS(1379),
    [anon_sym_PLUS_PLUS] = ACTIONS(1379),
    [anon_sym_DASH_DASH] = ACTIONS(1379),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1377),
    [anon_sym_DASH] = ACTIONS(1377),
    [anon_sym_STAR] = ACTIONS(1381),
    [anon_sym_CARET] = ACTIONS(1379),
    [anon_sym_AMP] = ACTIONS(1379),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1383),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1385),
    [anon_sym_DOT_DOT] = ACTIONS(1387),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1987] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7010),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5945),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4334),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9265),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1987),
    [sym_preproc_endregion] = STATE(1987),
    [sym_preproc_line] = STATE(1987),
    [sym_preproc_pragma] = STATE(1987),
    [sym_preproc_nullable] = STATE(1987),
    [sym_preproc_error] = STATE(1987),
    [sym_preproc_warning] = STATE(1987),
    [sym_preproc_define] = STATE(1987),
    [sym_preproc_undef] = STATE(1987),
    [aux_sym_class_declaration_repeat1] = STATE(3823),
    [aux_sym_lambda_expression_repeat1] = STATE(4240),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1751),
    [anon_sym_ref] = ACTIONS(1753),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1755),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1759),
    [anon_sym_TILDE] = ACTIONS(1759),
    [anon_sym_PLUS_PLUS] = ACTIONS(1759),
    [anon_sym_DASH_DASH] = ACTIONS(1759),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1757),
    [anon_sym_DASH] = ACTIONS(1757),
    [anon_sym_STAR] = ACTIONS(1381),
    [anon_sym_CARET] = ACTIONS(1759),
    [anon_sym_AMP] = ACTIONS(1759),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1761),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1763),
    [anon_sym_DOT_DOT] = ACTIONS(1765),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1988] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7010),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5946),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4334),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9265),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1988),
    [sym_preproc_endregion] = STATE(1988),
    [sym_preproc_line] = STATE(1988),
    [sym_preproc_pragma] = STATE(1988),
    [sym_preproc_nullable] = STATE(1988),
    [sym_preproc_error] = STATE(1988),
    [sym_preproc_warning] = STATE(1988),
    [sym_preproc_define] = STATE(1988),
    [sym_preproc_undef] = STATE(1988),
    [aux_sym_class_declaration_repeat1] = STATE(3823),
    [aux_sym_lambda_expression_repeat1] = STATE(4240),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1751),
    [anon_sym_ref] = ACTIONS(1753),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1755),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1759),
    [anon_sym_TILDE] = ACTIONS(1759),
    [anon_sym_PLUS_PLUS] = ACTIONS(1759),
    [anon_sym_DASH_DASH] = ACTIONS(1759),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1757),
    [anon_sym_DASH] = ACTIONS(1757),
    [anon_sym_STAR] = ACTIONS(1381),
    [anon_sym_CARET] = ACTIONS(1759),
    [anon_sym_AMP] = ACTIONS(1759),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1761),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1763),
    [anon_sym_DOT_DOT] = ACTIONS(1765),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1989] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7010),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5947),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4334),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9265),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1989),
    [sym_preproc_endregion] = STATE(1989),
    [sym_preproc_line] = STATE(1989),
    [sym_preproc_pragma] = STATE(1989),
    [sym_preproc_nullable] = STATE(1989),
    [sym_preproc_error] = STATE(1989),
    [sym_preproc_warning] = STATE(1989),
    [sym_preproc_define] = STATE(1989),
    [sym_preproc_undef] = STATE(1989),
    [aux_sym_class_declaration_repeat1] = STATE(3823),
    [aux_sym_lambda_expression_repeat1] = STATE(4240),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1751),
    [anon_sym_ref] = ACTIONS(1753),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1755),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1759),
    [anon_sym_TILDE] = ACTIONS(1759),
    [anon_sym_PLUS_PLUS] = ACTIONS(1759),
    [anon_sym_DASH_DASH] = ACTIONS(1759),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1757),
    [anon_sym_DASH] = ACTIONS(1757),
    [anon_sym_STAR] = ACTIONS(1381),
    [anon_sym_CARET] = ACTIONS(1759),
    [anon_sym_AMP] = ACTIONS(1759),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1761),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1763),
    [anon_sym_DOT_DOT] = ACTIONS(1765),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1990] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6948),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2940),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7022),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4952),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3795),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7417),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9004),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1990),
    [sym_preproc_endregion] = STATE(1990),
    [sym_preproc_line] = STATE(1990),
    [sym_preproc_pragma] = STATE(1990),
    [sym_preproc_nullable] = STATE(1990),
    [sym_preproc_error] = STATE(1990),
    [sym_preproc_warning] = STATE(1990),
    [sym_preproc_define] = STATE(1990),
    [sym_preproc_undef] = STATE(1990),
    [aux_sym_class_declaration_repeat1] = STATE(3827),
    [aux_sym_lambda_expression_repeat1] = STATE(4246),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1893),
    [anon_sym_ref] = ACTIONS(1895),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1897),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1901),
    [anon_sym_TILDE] = ACTIONS(1901),
    [anon_sym_PLUS_PLUS] = ACTIONS(1901),
    [anon_sym_DASH_DASH] = ACTIONS(1901),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1899),
    [anon_sym_DASH] = ACTIONS(1899),
    [anon_sym_STAR] = ACTIONS(1903),
    [anon_sym_CARET] = ACTIONS(1901),
    [anon_sym_AMP] = ACTIONS(1901),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1905),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1907),
    [anon_sym_DOT_DOT] = ACTIONS(1909),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1991] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6962),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5154),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3931),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9818),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1991),
    [sym_preproc_endregion] = STATE(1991),
    [sym_preproc_line] = STATE(1991),
    [sym_preproc_pragma] = STATE(1991),
    [sym_preproc_nullable] = STATE(1991),
    [sym_preproc_error] = STATE(1991),
    [sym_preproc_warning] = STATE(1991),
    [sym_preproc_define] = STATE(1991),
    [sym_preproc_undef] = STATE(1991),
    [aux_sym_class_declaration_repeat1] = STATE(3811),
    [aux_sym_lambda_expression_repeat1] = STATE(4201),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1373),
    [anon_sym_ref] = ACTIONS(1375),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1379),
    [anon_sym_TILDE] = ACTIONS(1379),
    [anon_sym_PLUS_PLUS] = ACTIONS(1379),
    [anon_sym_DASH_DASH] = ACTIONS(1379),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1377),
    [anon_sym_DASH] = ACTIONS(1377),
    [anon_sym_STAR] = ACTIONS(1381),
    [anon_sym_CARET] = ACTIONS(1379),
    [anon_sym_AMP] = ACTIONS(1379),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1383),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1385),
    [anon_sym_DOT_DOT] = ACTIONS(1387),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1992] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7010),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3932),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4334),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9265),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1992),
    [sym_preproc_endregion] = STATE(1992),
    [sym_preproc_line] = STATE(1992),
    [sym_preproc_pragma] = STATE(1992),
    [sym_preproc_nullable] = STATE(1992),
    [sym_preproc_error] = STATE(1992),
    [sym_preproc_warning] = STATE(1992),
    [sym_preproc_define] = STATE(1992),
    [sym_preproc_undef] = STATE(1992),
    [aux_sym_class_declaration_repeat1] = STATE(3823),
    [aux_sym_lambda_expression_repeat1] = STATE(4240),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1751),
    [anon_sym_ref] = ACTIONS(1753),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1755),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1759),
    [anon_sym_TILDE] = ACTIONS(1759),
    [anon_sym_PLUS_PLUS] = ACTIONS(1759),
    [anon_sym_DASH_DASH] = ACTIONS(1759),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1757),
    [anon_sym_DASH] = ACTIONS(1757),
    [anon_sym_STAR] = ACTIONS(1381),
    [anon_sym_CARET] = ACTIONS(1759),
    [anon_sym_AMP] = ACTIONS(1759),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1761),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1763),
    [anon_sym_DOT_DOT] = ACTIONS(1765),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1993] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6962),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5157),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3931),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9818),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1993),
    [sym_preproc_endregion] = STATE(1993),
    [sym_preproc_line] = STATE(1993),
    [sym_preproc_pragma] = STATE(1993),
    [sym_preproc_nullable] = STATE(1993),
    [sym_preproc_error] = STATE(1993),
    [sym_preproc_warning] = STATE(1993),
    [sym_preproc_define] = STATE(1993),
    [sym_preproc_undef] = STATE(1993),
    [aux_sym_class_declaration_repeat1] = STATE(3811),
    [aux_sym_lambda_expression_repeat1] = STATE(4201),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1373),
    [anon_sym_ref] = ACTIONS(1375),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1379),
    [anon_sym_TILDE] = ACTIONS(1379),
    [anon_sym_PLUS_PLUS] = ACTIONS(1379),
    [anon_sym_DASH_DASH] = ACTIONS(1379),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1377),
    [anon_sym_DASH] = ACTIONS(1377),
    [anon_sym_STAR] = ACTIONS(1381),
    [anon_sym_CARET] = ACTIONS(1379),
    [anon_sym_AMP] = ACTIONS(1379),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1383),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1385),
    [anon_sym_DOT_DOT] = ACTIONS(1387),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1994] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6962),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5159),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3931),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9818),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1994),
    [sym_preproc_endregion] = STATE(1994),
    [sym_preproc_line] = STATE(1994),
    [sym_preproc_pragma] = STATE(1994),
    [sym_preproc_nullable] = STATE(1994),
    [sym_preproc_error] = STATE(1994),
    [sym_preproc_warning] = STATE(1994),
    [sym_preproc_define] = STATE(1994),
    [sym_preproc_undef] = STATE(1994),
    [aux_sym_class_declaration_repeat1] = STATE(3811),
    [aux_sym_lambda_expression_repeat1] = STATE(4201),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1373),
    [anon_sym_ref] = ACTIONS(1375),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1379),
    [anon_sym_TILDE] = ACTIONS(1379),
    [anon_sym_PLUS_PLUS] = ACTIONS(1379),
    [anon_sym_DASH_DASH] = ACTIONS(1379),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1377),
    [anon_sym_DASH] = ACTIONS(1377),
    [anon_sym_STAR] = ACTIONS(1381),
    [anon_sym_CARET] = ACTIONS(1379),
    [anon_sym_AMP] = ACTIONS(1379),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1383),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1385),
    [anon_sym_DOT_DOT] = ACTIONS(1387),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1995] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6948),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2940),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7022),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4974),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3795),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7417),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9004),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(1995),
    [sym_preproc_endregion] = STATE(1995),
    [sym_preproc_line] = STATE(1995),
    [sym_preproc_pragma] = STATE(1995),
    [sym_preproc_nullable] = STATE(1995),
    [sym_preproc_error] = STATE(1995),
    [sym_preproc_warning] = STATE(1995),
    [sym_preproc_define] = STATE(1995),
    [sym_preproc_undef] = STATE(1995),
    [aux_sym_class_declaration_repeat1] = STATE(3827),
    [aux_sym_lambda_expression_repeat1] = STATE(4246),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1893),
    [anon_sym_ref] = ACTIONS(1895),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1897),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1901),
    [anon_sym_TILDE] = ACTIONS(1901),
    [anon_sym_PLUS_PLUS] = ACTIONS(1901),
    [anon_sym_DASH_DASH] = ACTIONS(1901),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1899),
    [anon_sym_DASH] = ACTIONS(1899),
    [anon_sym_STAR] = ACTIONS(1903),
    [anon_sym_CARET] = ACTIONS(1901),
    [anon_sym_AMP] = ACTIONS(1901),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1905),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1907),
    [anon_sym_DOT_DOT] = ACTIONS(1909),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [1996] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6962),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5180),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3931),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9818),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1996),
    [sym_preproc_endregion] = STATE(1996),
    [sym_preproc_line] = STATE(1996),
    [sym_preproc_pragma] = STATE(1996),
    [sym_preproc_nullable] = STATE(1996),
    [sym_preproc_error] = STATE(1996),
    [sym_preproc_warning] = STATE(1996),
    [sym_preproc_define] = STATE(1996),
    [sym_preproc_undef] = STATE(1996),
    [aux_sym_class_declaration_repeat1] = STATE(3811),
    [aux_sym_lambda_expression_repeat1] = STATE(4201),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1373),
    [anon_sym_ref] = ACTIONS(1375),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1379),
    [anon_sym_TILDE] = ACTIONS(1379),
    [anon_sym_PLUS_PLUS] = ACTIONS(1379),
    [anon_sym_DASH_DASH] = ACTIONS(1379),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1377),
    [anon_sym_DASH] = ACTIONS(1377),
    [anon_sym_STAR] = ACTIONS(1381),
    [anon_sym_CARET] = ACTIONS(1379),
    [anon_sym_AMP] = ACTIONS(1379),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1383),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1385),
    [anon_sym_DOT_DOT] = ACTIONS(1387),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1997] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6962),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5197),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3931),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9818),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(1997),
    [sym_preproc_endregion] = STATE(1997),
    [sym_preproc_line] = STATE(1997),
    [sym_preproc_pragma] = STATE(1997),
    [sym_preproc_nullable] = STATE(1997),
    [sym_preproc_error] = STATE(1997),
    [sym_preproc_warning] = STATE(1997),
    [sym_preproc_define] = STATE(1997),
    [sym_preproc_undef] = STATE(1997),
    [aux_sym_class_declaration_repeat1] = STATE(3811),
    [aux_sym_lambda_expression_repeat1] = STATE(4201),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1373),
    [anon_sym_ref] = ACTIONS(1375),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1379),
    [anon_sym_TILDE] = ACTIONS(1379),
    [anon_sym_PLUS_PLUS] = ACTIONS(1379),
    [anon_sym_DASH_DASH] = ACTIONS(1379),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1377),
    [anon_sym_DASH] = ACTIONS(1377),
    [anon_sym_STAR] = ACTIONS(1381),
    [anon_sym_CARET] = ACTIONS(1379),
    [anon_sym_AMP] = ACTIONS(1379),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1383),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1385),
    [anon_sym_DOT_DOT] = ACTIONS(1387),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [1998] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6911),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2930),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7027),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4536),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3605),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7434),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9856),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(1998),
    [sym_preproc_endregion] = STATE(1998),
    [sym_preproc_line] = STATE(1998),
    [sym_preproc_pragma] = STATE(1998),
    [sym_preproc_nullable] = STATE(1998),
    [sym_preproc_error] = STATE(1998),
    [sym_preproc_warning] = STATE(1998),
    [sym_preproc_define] = STATE(1998),
    [sym_preproc_undef] = STATE(1998),
    [aux_sym_class_declaration_repeat1] = STATE(3828),
    [aux_sym_lambda_expression_repeat1] = STATE(4248),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1687),
    [anon_sym_ref] = ACTIONS(1689),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1695),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1701),
    [anon_sym_TILDE] = ACTIONS(1701),
    [anon_sym_PLUS_PLUS] = ACTIONS(1701),
    [anon_sym_DASH_DASH] = ACTIONS(1701),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1699),
    [anon_sym_DASH] = ACTIONS(1699),
    [anon_sym_STAR] = ACTIONS(1705),
    [anon_sym_CARET] = ACTIONS(1701),
    [anon_sym_AMP] = ACTIONS(1701),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(1715),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1717),
    [anon_sym_DOT_DOT] = ACTIONS(1719),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [1999] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6911),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2930),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7027),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4373),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3605),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7434),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9856),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(1999),
    [sym_preproc_endregion] = STATE(1999),
    [sym_preproc_line] = STATE(1999),
    [sym_preproc_pragma] = STATE(1999),
    [sym_preproc_nullable] = STATE(1999),
    [sym_preproc_error] = STATE(1999),
    [sym_preproc_warning] = STATE(1999),
    [sym_preproc_define] = STATE(1999),
    [sym_preproc_undef] = STATE(1999),
    [aux_sym_class_declaration_repeat1] = STATE(3828),
    [aux_sym_lambda_expression_repeat1] = STATE(4248),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1687),
    [anon_sym_ref] = ACTIONS(1689),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1695),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1701),
    [anon_sym_TILDE] = ACTIONS(1701),
    [anon_sym_PLUS_PLUS] = ACTIONS(1701),
    [anon_sym_DASH_DASH] = ACTIONS(1701),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1699),
    [anon_sym_DASH] = ACTIONS(1699),
    [anon_sym_STAR] = ACTIONS(1705),
    [anon_sym_CARET] = ACTIONS(1701),
    [anon_sym_AMP] = ACTIONS(1701),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(1715),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1717),
    [anon_sym_DOT_DOT] = ACTIONS(1719),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [2000] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6948),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2940),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7022),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4969),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3795),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7417),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9004),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2000),
    [sym_preproc_endregion] = STATE(2000),
    [sym_preproc_line] = STATE(2000),
    [sym_preproc_pragma] = STATE(2000),
    [sym_preproc_nullable] = STATE(2000),
    [sym_preproc_error] = STATE(2000),
    [sym_preproc_warning] = STATE(2000),
    [sym_preproc_define] = STATE(2000),
    [sym_preproc_undef] = STATE(2000),
    [aux_sym_class_declaration_repeat1] = STATE(3827),
    [aux_sym_lambda_expression_repeat1] = STATE(4246),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1893),
    [anon_sym_ref] = ACTIONS(1895),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1897),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1901),
    [anon_sym_TILDE] = ACTIONS(1901),
    [anon_sym_PLUS_PLUS] = ACTIONS(1901),
    [anon_sym_DASH_DASH] = ACTIONS(1901),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1899),
    [anon_sym_DASH] = ACTIONS(1899),
    [anon_sym_STAR] = ACTIONS(1903),
    [anon_sym_CARET] = ACTIONS(1901),
    [anon_sym_AMP] = ACTIONS(1901),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1905),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1907),
    [anon_sym_DOT_DOT] = ACTIONS(1909),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [2001] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6948),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2940),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7022),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4970),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3795),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7417),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9004),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2001),
    [sym_preproc_endregion] = STATE(2001),
    [sym_preproc_line] = STATE(2001),
    [sym_preproc_pragma] = STATE(2001),
    [sym_preproc_nullable] = STATE(2001),
    [sym_preproc_error] = STATE(2001),
    [sym_preproc_warning] = STATE(2001),
    [sym_preproc_define] = STATE(2001),
    [sym_preproc_undef] = STATE(2001),
    [aux_sym_class_declaration_repeat1] = STATE(3827),
    [aux_sym_lambda_expression_repeat1] = STATE(4246),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1893),
    [anon_sym_ref] = ACTIONS(1895),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1897),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1901),
    [anon_sym_TILDE] = ACTIONS(1901),
    [anon_sym_PLUS_PLUS] = ACTIONS(1901),
    [anon_sym_DASH_DASH] = ACTIONS(1901),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1899),
    [anon_sym_DASH] = ACTIONS(1899),
    [anon_sym_STAR] = ACTIONS(1903),
    [anon_sym_CARET] = ACTIONS(1901),
    [anon_sym_AMP] = ACTIONS(1901),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1905),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1907),
    [anon_sym_DOT_DOT] = ACTIONS(1909),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [2002] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6948),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2940),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7022),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4975),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3795),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7417),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9004),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2002),
    [sym_preproc_endregion] = STATE(2002),
    [sym_preproc_line] = STATE(2002),
    [sym_preproc_pragma] = STATE(2002),
    [sym_preproc_nullable] = STATE(2002),
    [sym_preproc_error] = STATE(2002),
    [sym_preproc_warning] = STATE(2002),
    [sym_preproc_define] = STATE(2002),
    [sym_preproc_undef] = STATE(2002),
    [aux_sym_class_declaration_repeat1] = STATE(3827),
    [aux_sym_lambda_expression_repeat1] = STATE(4246),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1893),
    [anon_sym_ref] = ACTIONS(1895),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1897),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1901),
    [anon_sym_TILDE] = ACTIONS(1901),
    [anon_sym_PLUS_PLUS] = ACTIONS(1901),
    [anon_sym_DASH_DASH] = ACTIONS(1901),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1899),
    [anon_sym_DASH] = ACTIONS(1899),
    [anon_sym_STAR] = ACTIONS(1903),
    [anon_sym_CARET] = ACTIONS(1901),
    [anon_sym_AMP] = ACTIONS(1901),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1905),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1907),
    [anon_sym_DOT_DOT] = ACTIONS(1909),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [2003] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6948),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2940),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7022),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4977),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3795),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7417),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9004),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2003),
    [sym_preproc_endregion] = STATE(2003),
    [sym_preproc_line] = STATE(2003),
    [sym_preproc_pragma] = STATE(2003),
    [sym_preproc_nullable] = STATE(2003),
    [sym_preproc_error] = STATE(2003),
    [sym_preproc_warning] = STATE(2003),
    [sym_preproc_define] = STATE(2003),
    [sym_preproc_undef] = STATE(2003),
    [aux_sym_class_declaration_repeat1] = STATE(3827),
    [aux_sym_lambda_expression_repeat1] = STATE(4246),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1893),
    [anon_sym_ref] = ACTIONS(1895),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1897),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1901),
    [anon_sym_TILDE] = ACTIONS(1901),
    [anon_sym_PLUS_PLUS] = ACTIONS(1901),
    [anon_sym_DASH_DASH] = ACTIONS(1901),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1899),
    [anon_sym_DASH] = ACTIONS(1899),
    [anon_sym_STAR] = ACTIONS(1903),
    [anon_sym_CARET] = ACTIONS(1901),
    [anon_sym_AMP] = ACTIONS(1901),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1905),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1907),
    [anon_sym_DOT_DOT] = ACTIONS(1909),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [2004] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6948),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2940),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7022),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4980),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3795),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7417),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9004),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2004),
    [sym_preproc_endregion] = STATE(2004),
    [sym_preproc_line] = STATE(2004),
    [sym_preproc_pragma] = STATE(2004),
    [sym_preproc_nullable] = STATE(2004),
    [sym_preproc_error] = STATE(2004),
    [sym_preproc_warning] = STATE(2004),
    [sym_preproc_define] = STATE(2004),
    [sym_preproc_undef] = STATE(2004),
    [aux_sym_class_declaration_repeat1] = STATE(3827),
    [aux_sym_lambda_expression_repeat1] = STATE(4246),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1893),
    [anon_sym_ref] = ACTIONS(1895),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1897),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1901),
    [anon_sym_TILDE] = ACTIONS(1901),
    [anon_sym_PLUS_PLUS] = ACTIONS(1901),
    [anon_sym_DASH_DASH] = ACTIONS(1901),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1899),
    [anon_sym_DASH] = ACTIONS(1899),
    [anon_sym_STAR] = ACTIONS(1903),
    [anon_sym_CARET] = ACTIONS(1901),
    [anon_sym_AMP] = ACTIONS(1901),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1905),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1907),
    [anon_sym_DOT_DOT] = ACTIONS(1909),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [2005] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6948),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2940),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7022),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4981),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3795),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7417),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9004),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2005),
    [sym_preproc_endregion] = STATE(2005),
    [sym_preproc_line] = STATE(2005),
    [sym_preproc_pragma] = STATE(2005),
    [sym_preproc_nullable] = STATE(2005),
    [sym_preproc_error] = STATE(2005),
    [sym_preproc_warning] = STATE(2005),
    [sym_preproc_define] = STATE(2005),
    [sym_preproc_undef] = STATE(2005),
    [aux_sym_class_declaration_repeat1] = STATE(3827),
    [aux_sym_lambda_expression_repeat1] = STATE(4246),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1893),
    [anon_sym_ref] = ACTIONS(1895),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1897),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1901),
    [anon_sym_TILDE] = ACTIONS(1901),
    [anon_sym_PLUS_PLUS] = ACTIONS(1901),
    [anon_sym_DASH_DASH] = ACTIONS(1901),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1899),
    [anon_sym_DASH] = ACTIONS(1899),
    [anon_sym_STAR] = ACTIONS(1903),
    [anon_sym_CARET] = ACTIONS(1901),
    [anon_sym_AMP] = ACTIONS(1901),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1905),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1907),
    [anon_sym_DOT_DOT] = ACTIONS(1909),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [2006] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6948),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2940),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7022),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4982),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3795),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7417),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9004),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2006),
    [sym_preproc_endregion] = STATE(2006),
    [sym_preproc_line] = STATE(2006),
    [sym_preproc_pragma] = STATE(2006),
    [sym_preproc_nullable] = STATE(2006),
    [sym_preproc_error] = STATE(2006),
    [sym_preproc_warning] = STATE(2006),
    [sym_preproc_define] = STATE(2006),
    [sym_preproc_undef] = STATE(2006),
    [aux_sym_class_declaration_repeat1] = STATE(3827),
    [aux_sym_lambda_expression_repeat1] = STATE(4246),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1893),
    [anon_sym_ref] = ACTIONS(1895),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1897),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1901),
    [anon_sym_TILDE] = ACTIONS(1901),
    [anon_sym_PLUS_PLUS] = ACTIONS(1901),
    [anon_sym_DASH_DASH] = ACTIONS(1901),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1899),
    [anon_sym_DASH] = ACTIONS(1899),
    [anon_sym_STAR] = ACTIONS(1903),
    [anon_sym_CARET] = ACTIONS(1901),
    [anon_sym_AMP] = ACTIONS(1901),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1905),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1907),
    [anon_sym_DOT_DOT] = ACTIONS(1909),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [2007] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6948),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2940),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7022),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4987),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3795),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7417),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9004),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2007),
    [sym_preproc_endregion] = STATE(2007),
    [sym_preproc_line] = STATE(2007),
    [sym_preproc_pragma] = STATE(2007),
    [sym_preproc_nullable] = STATE(2007),
    [sym_preproc_error] = STATE(2007),
    [sym_preproc_warning] = STATE(2007),
    [sym_preproc_define] = STATE(2007),
    [sym_preproc_undef] = STATE(2007),
    [aux_sym_class_declaration_repeat1] = STATE(3827),
    [aux_sym_lambda_expression_repeat1] = STATE(4246),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1893),
    [anon_sym_ref] = ACTIONS(1895),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1897),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1901),
    [anon_sym_TILDE] = ACTIONS(1901),
    [anon_sym_PLUS_PLUS] = ACTIONS(1901),
    [anon_sym_DASH_DASH] = ACTIONS(1901),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1899),
    [anon_sym_DASH] = ACTIONS(1899),
    [anon_sym_STAR] = ACTIONS(1903),
    [anon_sym_CARET] = ACTIONS(1901),
    [anon_sym_AMP] = ACTIONS(1901),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1905),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1907),
    [anon_sym_DOT_DOT] = ACTIONS(1909),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [2008] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6962),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5199),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3931),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9818),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(2008),
    [sym_preproc_endregion] = STATE(2008),
    [sym_preproc_line] = STATE(2008),
    [sym_preproc_pragma] = STATE(2008),
    [sym_preproc_nullable] = STATE(2008),
    [sym_preproc_error] = STATE(2008),
    [sym_preproc_warning] = STATE(2008),
    [sym_preproc_define] = STATE(2008),
    [sym_preproc_undef] = STATE(2008),
    [aux_sym_class_declaration_repeat1] = STATE(3811),
    [aux_sym_lambda_expression_repeat1] = STATE(4201),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1373),
    [anon_sym_ref] = ACTIONS(1375),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1379),
    [anon_sym_TILDE] = ACTIONS(1379),
    [anon_sym_PLUS_PLUS] = ACTIONS(1379),
    [anon_sym_DASH_DASH] = ACTIONS(1379),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1377),
    [anon_sym_DASH] = ACTIONS(1377),
    [anon_sym_STAR] = ACTIONS(1381),
    [anon_sym_CARET] = ACTIONS(1379),
    [anon_sym_AMP] = ACTIONS(1379),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1383),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1385),
    [anon_sym_DOT_DOT] = ACTIONS(1387),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2009] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6948),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2940),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7022),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4950),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3795),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7417),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9004),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2009),
    [sym_preproc_endregion] = STATE(2009),
    [sym_preproc_line] = STATE(2009),
    [sym_preproc_pragma] = STATE(2009),
    [sym_preproc_nullable] = STATE(2009),
    [sym_preproc_error] = STATE(2009),
    [sym_preproc_warning] = STATE(2009),
    [sym_preproc_define] = STATE(2009),
    [sym_preproc_undef] = STATE(2009),
    [aux_sym_class_declaration_repeat1] = STATE(3827),
    [aux_sym_lambda_expression_repeat1] = STATE(4246),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1893),
    [anon_sym_ref] = ACTIONS(1895),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1897),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1901),
    [anon_sym_TILDE] = ACTIONS(1901),
    [anon_sym_PLUS_PLUS] = ACTIONS(1901),
    [anon_sym_DASH_DASH] = ACTIONS(1901),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1899),
    [anon_sym_DASH] = ACTIONS(1899),
    [anon_sym_STAR] = ACTIONS(1903),
    [anon_sym_CARET] = ACTIONS(1901),
    [anon_sym_AMP] = ACTIONS(1901),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1905),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1907),
    [anon_sym_DOT_DOT] = ACTIONS(1909),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [2010] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6948),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2940),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7022),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4955),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3795),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7417),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9004),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2010),
    [sym_preproc_endregion] = STATE(2010),
    [sym_preproc_line] = STATE(2010),
    [sym_preproc_pragma] = STATE(2010),
    [sym_preproc_nullable] = STATE(2010),
    [sym_preproc_error] = STATE(2010),
    [sym_preproc_warning] = STATE(2010),
    [sym_preproc_define] = STATE(2010),
    [sym_preproc_undef] = STATE(2010),
    [aux_sym_class_declaration_repeat1] = STATE(3827),
    [aux_sym_lambda_expression_repeat1] = STATE(4246),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1893),
    [anon_sym_ref] = ACTIONS(1895),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1897),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1901),
    [anon_sym_TILDE] = ACTIONS(1901),
    [anon_sym_PLUS_PLUS] = ACTIONS(1901),
    [anon_sym_DASH_DASH] = ACTIONS(1901),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1899),
    [anon_sym_DASH] = ACTIONS(1899),
    [anon_sym_STAR] = ACTIONS(1903),
    [anon_sym_CARET] = ACTIONS(1901),
    [anon_sym_AMP] = ACTIONS(1901),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1905),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1907),
    [anon_sym_DOT_DOT] = ACTIONS(1909),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [2011] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6948),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2940),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7022),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4956),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3795),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7417),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9004),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2011),
    [sym_preproc_endregion] = STATE(2011),
    [sym_preproc_line] = STATE(2011),
    [sym_preproc_pragma] = STATE(2011),
    [sym_preproc_nullable] = STATE(2011),
    [sym_preproc_error] = STATE(2011),
    [sym_preproc_warning] = STATE(2011),
    [sym_preproc_define] = STATE(2011),
    [sym_preproc_undef] = STATE(2011),
    [aux_sym_class_declaration_repeat1] = STATE(3827),
    [aux_sym_lambda_expression_repeat1] = STATE(4246),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1893),
    [anon_sym_ref] = ACTIONS(1895),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1897),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1901),
    [anon_sym_TILDE] = ACTIONS(1901),
    [anon_sym_PLUS_PLUS] = ACTIONS(1901),
    [anon_sym_DASH_DASH] = ACTIONS(1901),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1899),
    [anon_sym_DASH] = ACTIONS(1899),
    [anon_sym_STAR] = ACTIONS(1903),
    [anon_sym_CARET] = ACTIONS(1901),
    [anon_sym_AMP] = ACTIONS(1901),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1905),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1907),
    [anon_sym_DOT_DOT] = ACTIONS(1909),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [2012] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6911),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2930),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7027),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4504),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3605),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7434),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9856),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(2012),
    [sym_preproc_endregion] = STATE(2012),
    [sym_preproc_line] = STATE(2012),
    [sym_preproc_pragma] = STATE(2012),
    [sym_preproc_nullable] = STATE(2012),
    [sym_preproc_error] = STATE(2012),
    [sym_preproc_warning] = STATE(2012),
    [sym_preproc_define] = STATE(2012),
    [sym_preproc_undef] = STATE(2012),
    [aux_sym_class_declaration_repeat1] = STATE(3828),
    [aux_sym_lambda_expression_repeat1] = STATE(4248),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1687),
    [anon_sym_ref] = ACTIONS(1689),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1695),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1701),
    [anon_sym_TILDE] = ACTIONS(1701),
    [anon_sym_PLUS_PLUS] = ACTIONS(1701),
    [anon_sym_DASH_DASH] = ACTIONS(1701),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1699),
    [anon_sym_DASH] = ACTIONS(1699),
    [anon_sym_STAR] = ACTIONS(1705),
    [anon_sym_CARET] = ACTIONS(1701),
    [anon_sym_AMP] = ACTIONS(1701),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(1715),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1717),
    [anon_sym_DOT_DOT] = ACTIONS(1719),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [2013] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7105),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5829),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2013),
    [sym_preproc_endregion] = STATE(2013),
    [sym_preproc_line] = STATE(2013),
    [sym_preproc_pragma] = STATE(2013),
    [sym_preproc_nullable] = STATE(2013),
    [sym_preproc_error] = STATE(2013),
    [sym_preproc_warning] = STATE(2013),
    [sym_preproc_define] = STATE(2013),
    [sym_preproc_undef] = STATE(2013),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2014] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6948),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2940),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7022),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4972),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3795),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7417),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9004),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2014),
    [sym_preproc_endregion] = STATE(2014),
    [sym_preproc_line] = STATE(2014),
    [sym_preproc_pragma] = STATE(2014),
    [sym_preproc_nullable] = STATE(2014),
    [sym_preproc_error] = STATE(2014),
    [sym_preproc_warning] = STATE(2014),
    [sym_preproc_define] = STATE(2014),
    [sym_preproc_undef] = STATE(2014),
    [aux_sym_class_declaration_repeat1] = STATE(3827),
    [aux_sym_lambda_expression_repeat1] = STATE(4246),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1893),
    [anon_sym_ref] = ACTIONS(1895),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1897),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1901),
    [anon_sym_TILDE] = ACTIONS(1901),
    [anon_sym_PLUS_PLUS] = ACTIONS(1901),
    [anon_sym_DASH_DASH] = ACTIONS(1901),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1899),
    [anon_sym_DASH] = ACTIONS(1899),
    [anon_sym_STAR] = ACTIONS(1903),
    [anon_sym_CARET] = ACTIONS(1901),
    [anon_sym_AMP] = ACTIONS(1901),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1905),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1907),
    [anon_sym_DOT_DOT] = ACTIONS(1909),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [2015] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6948),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2940),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6999),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5063),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3857),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7444),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9574),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2015),
    [sym_preproc_endregion] = STATE(2015),
    [sym_preproc_line] = STATE(2015),
    [sym_preproc_pragma] = STATE(2015),
    [sym_preproc_nullable] = STATE(2015),
    [sym_preproc_error] = STATE(2015),
    [sym_preproc_warning] = STATE(2015),
    [sym_preproc_define] = STATE(2015),
    [sym_preproc_undef] = STATE(2015),
    [aux_sym_class_declaration_repeat1] = STATE(3854),
    [aux_sym_lambda_expression_repeat1] = STATE(4136),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2111),
    [anon_sym_ref] = ACTIONS(2113),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1897),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2117),
    [anon_sym_TILDE] = ACTIONS(2117),
    [anon_sym_PLUS_PLUS] = ACTIONS(2117),
    [anon_sym_DASH_DASH] = ACTIONS(2117),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2115),
    [anon_sym_DASH] = ACTIONS(2115),
    [anon_sym_STAR] = ACTIONS(1903),
    [anon_sym_CARET] = ACTIONS(2117),
    [anon_sym_AMP] = ACTIONS(2117),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2119),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2121),
    [anon_sym_DOT_DOT] = ACTIONS(2123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [2016] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6911),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2930),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7027),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4524),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3605),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7434),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9856),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(2016),
    [sym_preproc_endregion] = STATE(2016),
    [sym_preproc_line] = STATE(2016),
    [sym_preproc_pragma] = STATE(2016),
    [sym_preproc_nullable] = STATE(2016),
    [sym_preproc_error] = STATE(2016),
    [sym_preproc_warning] = STATE(2016),
    [sym_preproc_define] = STATE(2016),
    [sym_preproc_undef] = STATE(2016),
    [aux_sym_class_declaration_repeat1] = STATE(3828),
    [aux_sym_lambda_expression_repeat1] = STATE(4248),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1687),
    [anon_sym_ref] = ACTIONS(1689),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1695),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1701),
    [anon_sym_TILDE] = ACTIONS(1701),
    [anon_sym_PLUS_PLUS] = ACTIONS(1701),
    [anon_sym_DASH_DASH] = ACTIONS(1701),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1699),
    [anon_sym_DASH] = ACTIONS(1699),
    [anon_sym_STAR] = ACTIONS(1705),
    [anon_sym_CARET] = ACTIONS(1701),
    [anon_sym_AMP] = ACTIONS(1701),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(1715),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1717),
    [anon_sym_DOT_DOT] = ACTIONS(1719),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [2017] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6937),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2861),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7001),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5560),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4149),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7445),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9763),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(2017),
    [sym_preproc_endregion] = STATE(2017),
    [sym_preproc_line] = STATE(2017),
    [sym_preproc_pragma] = STATE(2017),
    [sym_preproc_nullable] = STATE(2017),
    [sym_preproc_error] = STATE(2017),
    [sym_preproc_warning] = STATE(2017),
    [sym_preproc_define] = STATE(2017),
    [sym_preproc_undef] = STATE(2017),
    [aux_sym_class_declaration_repeat1] = STATE(3821),
    [aux_sym_lambda_expression_repeat1] = STATE(4236),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1609),
    [anon_sym_ref] = ACTIONS(1611),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1481),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1615),
    [anon_sym_TILDE] = ACTIONS(1615),
    [anon_sym_PLUS_PLUS] = ACTIONS(1615),
    [anon_sym_DASH_DASH] = ACTIONS(1615),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1613),
    [anon_sym_DASH] = ACTIONS(1613),
    [anon_sym_STAR] = ACTIONS(1487),
    [anon_sym_CARET] = ACTIONS(1615),
    [anon_sym_AMP] = ACTIONS(1615),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1617),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1619),
    [anon_sym_DOT_DOT] = ACTIONS(1621),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [2018] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7105),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5830),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2018),
    [sym_preproc_endregion] = STATE(2018),
    [sym_preproc_line] = STATE(2018),
    [sym_preproc_pragma] = STATE(2018),
    [sym_preproc_nullable] = STATE(2018),
    [sym_preproc_error] = STATE(2018),
    [sym_preproc_warning] = STATE(2018),
    [sym_preproc_define] = STATE(2018),
    [sym_preproc_undef] = STATE(2018),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2019] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6911),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2930),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7027),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4483),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3605),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7434),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9856),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(2019),
    [sym_preproc_endregion] = STATE(2019),
    [sym_preproc_line] = STATE(2019),
    [sym_preproc_pragma] = STATE(2019),
    [sym_preproc_nullable] = STATE(2019),
    [sym_preproc_error] = STATE(2019),
    [sym_preproc_warning] = STATE(2019),
    [sym_preproc_define] = STATE(2019),
    [sym_preproc_undef] = STATE(2019),
    [aux_sym_class_declaration_repeat1] = STATE(3828),
    [aux_sym_lambda_expression_repeat1] = STATE(4248),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1687),
    [anon_sym_ref] = ACTIONS(1689),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1695),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1701),
    [anon_sym_TILDE] = ACTIONS(1701),
    [anon_sym_PLUS_PLUS] = ACTIONS(1701),
    [anon_sym_DASH_DASH] = ACTIONS(1701),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1699),
    [anon_sym_DASH] = ACTIONS(1699),
    [anon_sym_STAR] = ACTIONS(1705),
    [anon_sym_CARET] = ACTIONS(1701),
    [anon_sym_AMP] = ACTIONS(1701),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(1715),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1717),
    [anon_sym_DOT_DOT] = ACTIONS(1719),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [2020] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6911),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2930),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7027),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4484),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3605),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7434),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9856),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(2020),
    [sym_preproc_endregion] = STATE(2020),
    [sym_preproc_line] = STATE(2020),
    [sym_preproc_pragma] = STATE(2020),
    [sym_preproc_nullable] = STATE(2020),
    [sym_preproc_error] = STATE(2020),
    [sym_preproc_warning] = STATE(2020),
    [sym_preproc_define] = STATE(2020),
    [sym_preproc_undef] = STATE(2020),
    [aux_sym_class_declaration_repeat1] = STATE(3828),
    [aux_sym_lambda_expression_repeat1] = STATE(4248),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1687),
    [anon_sym_ref] = ACTIONS(1689),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1695),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1701),
    [anon_sym_TILDE] = ACTIONS(1701),
    [anon_sym_PLUS_PLUS] = ACTIONS(1701),
    [anon_sym_DASH_DASH] = ACTIONS(1701),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1699),
    [anon_sym_DASH] = ACTIONS(1699),
    [anon_sym_STAR] = ACTIONS(1705),
    [anon_sym_CARET] = ACTIONS(1701),
    [anon_sym_AMP] = ACTIONS(1701),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(1715),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1717),
    [anon_sym_DOT_DOT] = ACTIONS(1719),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [2021] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6911),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2930),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7027),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4485),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3605),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7434),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9856),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(2021),
    [sym_preproc_endregion] = STATE(2021),
    [sym_preproc_line] = STATE(2021),
    [sym_preproc_pragma] = STATE(2021),
    [sym_preproc_nullable] = STATE(2021),
    [sym_preproc_error] = STATE(2021),
    [sym_preproc_warning] = STATE(2021),
    [sym_preproc_define] = STATE(2021),
    [sym_preproc_undef] = STATE(2021),
    [aux_sym_class_declaration_repeat1] = STATE(3828),
    [aux_sym_lambda_expression_repeat1] = STATE(4248),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1687),
    [anon_sym_ref] = ACTIONS(1689),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1695),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1701),
    [anon_sym_TILDE] = ACTIONS(1701),
    [anon_sym_PLUS_PLUS] = ACTIONS(1701),
    [anon_sym_DASH_DASH] = ACTIONS(1701),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1699),
    [anon_sym_DASH] = ACTIONS(1699),
    [anon_sym_STAR] = ACTIONS(1705),
    [anon_sym_CARET] = ACTIONS(1701),
    [anon_sym_AMP] = ACTIONS(1701),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(1715),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1717),
    [anon_sym_DOT_DOT] = ACTIONS(1719),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [2022] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6911),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2930),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7027),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4499),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3605),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7434),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9856),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(2022),
    [sym_preproc_endregion] = STATE(2022),
    [sym_preproc_line] = STATE(2022),
    [sym_preproc_pragma] = STATE(2022),
    [sym_preproc_nullable] = STATE(2022),
    [sym_preproc_error] = STATE(2022),
    [sym_preproc_warning] = STATE(2022),
    [sym_preproc_define] = STATE(2022),
    [sym_preproc_undef] = STATE(2022),
    [aux_sym_class_declaration_repeat1] = STATE(3828),
    [aux_sym_lambda_expression_repeat1] = STATE(4248),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1687),
    [anon_sym_ref] = ACTIONS(1689),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1695),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1701),
    [anon_sym_TILDE] = ACTIONS(1701),
    [anon_sym_PLUS_PLUS] = ACTIONS(1701),
    [anon_sym_DASH_DASH] = ACTIONS(1701),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1699),
    [anon_sym_DASH] = ACTIONS(1699),
    [anon_sym_STAR] = ACTIONS(1705),
    [anon_sym_CARET] = ACTIONS(1701),
    [anon_sym_AMP] = ACTIONS(1701),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(1715),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1717),
    [anon_sym_DOT_DOT] = ACTIONS(1719),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [2023] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6911),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2930),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7027),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4501),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3605),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7434),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9856),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(2023),
    [sym_preproc_endregion] = STATE(2023),
    [sym_preproc_line] = STATE(2023),
    [sym_preproc_pragma] = STATE(2023),
    [sym_preproc_nullable] = STATE(2023),
    [sym_preproc_error] = STATE(2023),
    [sym_preproc_warning] = STATE(2023),
    [sym_preproc_define] = STATE(2023),
    [sym_preproc_undef] = STATE(2023),
    [aux_sym_class_declaration_repeat1] = STATE(3828),
    [aux_sym_lambda_expression_repeat1] = STATE(4248),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1687),
    [anon_sym_ref] = ACTIONS(1689),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1695),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1701),
    [anon_sym_TILDE] = ACTIONS(1701),
    [anon_sym_PLUS_PLUS] = ACTIONS(1701),
    [anon_sym_DASH_DASH] = ACTIONS(1701),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1699),
    [anon_sym_DASH] = ACTIONS(1699),
    [anon_sym_STAR] = ACTIONS(1705),
    [anon_sym_CARET] = ACTIONS(1701),
    [anon_sym_AMP] = ACTIONS(1701),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(1715),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1717),
    [anon_sym_DOT_DOT] = ACTIONS(1719),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [2024] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6911),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2930),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7027),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4460),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3605),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7434),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9856),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(2024),
    [sym_preproc_endregion] = STATE(2024),
    [sym_preproc_line] = STATE(2024),
    [sym_preproc_pragma] = STATE(2024),
    [sym_preproc_nullable] = STATE(2024),
    [sym_preproc_error] = STATE(2024),
    [sym_preproc_warning] = STATE(2024),
    [sym_preproc_define] = STATE(2024),
    [sym_preproc_undef] = STATE(2024),
    [aux_sym_class_declaration_repeat1] = STATE(3828),
    [aux_sym_lambda_expression_repeat1] = STATE(4248),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1687),
    [anon_sym_ref] = ACTIONS(1689),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1695),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1701),
    [anon_sym_TILDE] = ACTIONS(1701),
    [anon_sym_PLUS_PLUS] = ACTIONS(1701),
    [anon_sym_DASH_DASH] = ACTIONS(1701),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1699),
    [anon_sym_DASH] = ACTIONS(1699),
    [anon_sym_STAR] = ACTIONS(1705),
    [anon_sym_CARET] = ACTIONS(1701),
    [anon_sym_AMP] = ACTIONS(1701),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(1715),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1717),
    [anon_sym_DOT_DOT] = ACTIONS(1719),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [2025] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6911),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2930),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7027),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4486),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3605),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7434),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9856),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(2025),
    [sym_preproc_endregion] = STATE(2025),
    [sym_preproc_line] = STATE(2025),
    [sym_preproc_pragma] = STATE(2025),
    [sym_preproc_nullable] = STATE(2025),
    [sym_preproc_error] = STATE(2025),
    [sym_preproc_warning] = STATE(2025),
    [sym_preproc_define] = STATE(2025),
    [sym_preproc_undef] = STATE(2025),
    [aux_sym_class_declaration_repeat1] = STATE(3828),
    [aux_sym_lambda_expression_repeat1] = STATE(4248),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1687),
    [anon_sym_ref] = ACTIONS(1689),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1695),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1701),
    [anon_sym_TILDE] = ACTIONS(1701),
    [anon_sym_PLUS_PLUS] = ACTIONS(1701),
    [anon_sym_DASH_DASH] = ACTIONS(1701),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1699),
    [anon_sym_DASH] = ACTIONS(1699),
    [anon_sym_STAR] = ACTIONS(1705),
    [anon_sym_CARET] = ACTIONS(1701),
    [anon_sym_AMP] = ACTIONS(1701),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(1715),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1717),
    [anon_sym_DOT_DOT] = ACTIONS(1719),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [2026] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6911),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2930),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7027),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4545),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3605),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7434),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9856),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(2026),
    [sym_preproc_endregion] = STATE(2026),
    [sym_preproc_line] = STATE(2026),
    [sym_preproc_pragma] = STATE(2026),
    [sym_preproc_nullable] = STATE(2026),
    [sym_preproc_error] = STATE(2026),
    [sym_preproc_warning] = STATE(2026),
    [sym_preproc_define] = STATE(2026),
    [sym_preproc_undef] = STATE(2026),
    [aux_sym_class_declaration_repeat1] = STATE(3828),
    [aux_sym_lambda_expression_repeat1] = STATE(4248),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1687),
    [anon_sym_ref] = ACTIONS(1689),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1695),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1701),
    [anon_sym_TILDE] = ACTIONS(1701),
    [anon_sym_PLUS_PLUS] = ACTIONS(1701),
    [anon_sym_DASH_DASH] = ACTIONS(1701),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1699),
    [anon_sym_DASH] = ACTIONS(1699),
    [anon_sym_STAR] = ACTIONS(1705),
    [anon_sym_CARET] = ACTIONS(1701),
    [anon_sym_AMP] = ACTIONS(1701),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(1715),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1717),
    [anon_sym_DOT_DOT] = ACTIONS(1719),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [2027] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6911),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2930),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7027),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4505),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3605),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7434),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9856),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(2027),
    [sym_preproc_endregion] = STATE(2027),
    [sym_preproc_line] = STATE(2027),
    [sym_preproc_pragma] = STATE(2027),
    [sym_preproc_nullable] = STATE(2027),
    [sym_preproc_error] = STATE(2027),
    [sym_preproc_warning] = STATE(2027),
    [sym_preproc_define] = STATE(2027),
    [sym_preproc_undef] = STATE(2027),
    [aux_sym_class_declaration_repeat1] = STATE(3828),
    [aux_sym_lambda_expression_repeat1] = STATE(4248),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1687),
    [anon_sym_ref] = ACTIONS(1689),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1695),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1701),
    [anon_sym_TILDE] = ACTIONS(1701),
    [anon_sym_PLUS_PLUS] = ACTIONS(1701),
    [anon_sym_DASH_DASH] = ACTIONS(1701),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1699),
    [anon_sym_DASH] = ACTIONS(1699),
    [anon_sym_STAR] = ACTIONS(1705),
    [anon_sym_CARET] = ACTIONS(1701),
    [anon_sym_AMP] = ACTIONS(1701),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(1715),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1717),
    [anon_sym_DOT_DOT] = ACTIONS(1719),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [2028] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6911),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2930),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7027),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4506),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3605),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7434),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9856),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(2028),
    [sym_preproc_endregion] = STATE(2028),
    [sym_preproc_line] = STATE(2028),
    [sym_preproc_pragma] = STATE(2028),
    [sym_preproc_nullable] = STATE(2028),
    [sym_preproc_error] = STATE(2028),
    [sym_preproc_warning] = STATE(2028),
    [sym_preproc_define] = STATE(2028),
    [sym_preproc_undef] = STATE(2028),
    [aux_sym_class_declaration_repeat1] = STATE(3828),
    [aux_sym_lambda_expression_repeat1] = STATE(4248),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1687),
    [anon_sym_ref] = ACTIONS(1689),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1695),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1701),
    [anon_sym_TILDE] = ACTIONS(1701),
    [anon_sym_PLUS_PLUS] = ACTIONS(1701),
    [anon_sym_DASH_DASH] = ACTIONS(1701),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1699),
    [anon_sym_DASH] = ACTIONS(1699),
    [anon_sym_STAR] = ACTIONS(1705),
    [anon_sym_CARET] = ACTIONS(1701),
    [anon_sym_AMP] = ACTIONS(1701),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(1715),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1717),
    [anon_sym_DOT_DOT] = ACTIONS(1719),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [2029] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6911),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2930),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7027),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4508),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3605),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7434),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9856),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(2029),
    [sym_preproc_endregion] = STATE(2029),
    [sym_preproc_line] = STATE(2029),
    [sym_preproc_pragma] = STATE(2029),
    [sym_preproc_nullable] = STATE(2029),
    [sym_preproc_error] = STATE(2029),
    [sym_preproc_warning] = STATE(2029),
    [sym_preproc_define] = STATE(2029),
    [sym_preproc_undef] = STATE(2029),
    [aux_sym_class_declaration_repeat1] = STATE(3828),
    [aux_sym_lambda_expression_repeat1] = STATE(4248),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1687),
    [anon_sym_ref] = ACTIONS(1689),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1695),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1701),
    [anon_sym_TILDE] = ACTIONS(1701),
    [anon_sym_PLUS_PLUS] = ACTIONS(1701),
    [anon_sym_DASH_DASH] = ACTIONS(1701),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1699),
    [anon_sym_DASH] = ACTIONS(1699),
    [anon_sym_STAR] = ACTIONS(1705),
    [anon_sym_CARET] = ACTIONS(1701),
    [anon_sym_AMP] = ACTIONS(1701),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(1715),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1717),
    [anon_sym_DOT_DOT] = ACTIONS(1719),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [2030] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6911),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2930),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7027),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4389),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3605),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7434),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9856),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(2030),
    [sym_preproc_endregion] = STATE(2030),
    [sym_preproc_line] = STATE(2030),
    [sym_preproc_pragma] = STATE(2030),
    [sym_preproc_nullable] = STATE(2030),
    [sym_preproc_error] = STATE(2030),
    [sym_preproc_warning] = STATE(2030),
    [sym_preproc_define] = STATE(2030),
    [sym_preproc_undef] = STATE(2030),
    [aux_sym_class_declaration_repeat1] = STATE(3828),
    [aux_sym_lambda_expression_repeat1] = STATE(4248),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1687),
    [anon_sym_ref] = ACTIONS(1689),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1695),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1701),
    [anon_sym_TILDE] = ACTIONS(1701),
    [anon_sym_PLUS_PLUS] = ACTIONS(1701),
    [anon_sym_DASH_DASH] = ACTIONS(1701),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1699),
    [anon_sym_DASH] = ACTIONS(1699),
    [anon_sym_STAR] = ACTIONS(1705),
    [anon_sym_CARET] = ACTIONS(1701),
    [anon_sym_AMP] = ACTIONS(1701),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(1715),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1717),
    [anon_sym_DOT_DOT] = ACTIONS(1719),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [2031] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6921),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2873),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7036),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5413),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4038),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7429),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9220),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(2031),
    [sym_preproc_endregion] = STATE(2031),
    [sym_preproc_line] = STATE(2031),
    [sym_preproc_pragma] = STATE(2031),
    [sym_preproc_nullable] = STATE(2031),
    [sym_preproc_error] = STATE(2031),
    [sym_preproc_warning] = STATE(2031),
    [sym_preproc_define] = STATE(2031),
    [sym_preproc_undef] = STATE(2031),
    [aux_sym_class_declaration_repeat1] = STATE(3830),
    [aux_sym_lambda_expression_repeat1] = STATE(4255),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1407),
    [anon_sym_ref] = ACTIONS(1409),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1415),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1421),
    [anon_sym_TILDE] = ACTIONS(1421),
    [anon_sym_PLUS_PLUS] = ACTIONS(1421),
    [anon_sym_DASH_DASH] = ACTIONS(1421),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1419),
    [anon_sym_DASH] = ACTIONS(1419),
    [anon_sym_STAR] = ACTIONS(1425),
    [anon_sym_CARET] = ACTIONS(1421),
    [anon_sym_AMP] = ACTIONS(1421),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1439),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1441),
    [anon_sym_DOT_DOT] = ACTIONS(1443),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [2032] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6921),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2873),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7036),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5156),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4038),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7429),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9220),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(2032),
    [sym_preproc_endregion] = STATE(2032),
    [sym_preproc_line] = STATE(2032),
    [sym_preproc_pragma] = STATE(2032),
    [sym_preproc_nullable] = STATE(2032),
    [sym_preproc_error] = STATE(2032),
    [sym_preproc_warning] = STATE(2032),
    [sym_preproc_define] = STATE(2032),
    [sym_preproc_undef] = STATE(2032),
    [aux_sym_class_declaration_repeat1] = STATE(3830),
    [aux_sym_lambda_expression_repeat1] = STATE(4255),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1407),
    [anon_sym_ref] = ACTIONS(1409),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1415),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1421),
    [anon_sym_TILDE] = ACTIONS(1421),
    [anon_sym_PLUS_PLUS] = ACTIONS(1421),
    [anon_sym_DASH_DASH] = ACTIONS(1421),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1419),
    [anon_sym_DASH] = ACTIONS(1419),
    [anon_sym_STAR] = ACTIONS(1425),
    [anon_sym_CARET] = ACTIONS(1421),
    [anon_sym_AMP] = ACTIONS(1421),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1439),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1441),
    [anon_sym_DOT_DOT] = ACTIONS(1443),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [2033] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7105),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5831),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2033),
    [sym_preproc_endregion] = STATE(2033),
    [sym_preproc_line] = STATE(2033),
    [sym_preproc_pragma] = STATE(2033),
    [sym_preproc_nullable] = STATE(2033),
    [sym_preproc_error] = STATE(2033),
    [sym_preproc_warning] = STATE(2033),
    [sym_preproc_define] = STATE(2033),
    [sym_preproc_undef] = STATE(2033),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2034] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6921),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2873),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7036),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5320),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4038),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7429),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9220),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(2034),
    [sym_preproc_endregion] = STATE(2034),
    [sym_preproc_line] = STATE(2034),
    [sym_preproc_pragma] = STATE(2034),
    [sym_preproc_nullable] = STATE(2034),
    [sym_preproc_error] = STATE(2034),
    [sym_preproc_warning] = STATE(2034),
    [sym_preproc_define] = STATE(2034),
    [sym_preproc_undef] = STATE(2034),
    [aux_sym_class_declaration_repeat1] = STATE(3830),
    [aux_sym_lambda_expression_repeat1] = STATE(4255),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1407),
    [anon_sym_ref] = ACTIONS(1409),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1415),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1421),
    [anon_sym_TILDE] = ACTIONS(1421),
    [anon_sym_PLUS_PLUS] = ACTIONS(1421),
    [anon_sym_DASH_DASH] = ACTIONS(1421),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1419),
    [anon_sym_DASH] = ACTIONS(1419),
    [anon_sym_STAR] = ACTIONS(1425),
    [anon_sym_CARET] = ACTIONS(1421),
    [anon_sym_AMP] = ACTIONS(1421),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1439),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1441),
    [anon_sym_DOT_DOT] = ACTIONS(1443),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [2035] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6921),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2873),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7036),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5294),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4038),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7429),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9220),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(2035),
    [sym_preproc_endregion] = STATE(2035),
    [sym_preproc_line] = STATE(2035),
    [sym_preproc_pragma] = STATE(2035),
    [sym_preproc_nullable] = STATE(2035),
    [sym_preproc_error] = STATE(2035),
    [sym_preproc_warning] = STATE(2035),
    [sym_preproc_define] = STATE(2035),
    [sym_preproc_undef] = STATE(2035),
    [aux_sym_class_declaration_repeat1] = STATE(3830),
    [aux_sym_lambda_expression_repeat1] = STATE(4255),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1407),
    [anon_sym_ref] = ACTIONS(1409),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1415),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1421),
    [anon_sym_TILDE] = ACTIONS(1421),
    [anon_sym_PLUS_PLUS] = ACTIONS(1421),
    [anon_sym_DASH_DASH] = ACTIONS(1421),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1419),
    [anon_sym_DASH] = ACTIONS(1419),
    [anon_sym_STAR] = ACTIONS(1425),
    [anon_sym_CARET] = ACTIONS(1421),
    [anon_sym_AMP] = ACTIONS(1421),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1439),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1441),
    [anon_sym_DOT_DOT] = ACTIONS(1443),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [2036] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7010),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5959),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4334),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9265),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(2036),
    [sym_preproc_endregion] = STATE(2036),
    [sym_preproc_line] = STATE(2036),
    [sym_preproc_pragma] = STATE(2036),
    [sym_preproc_nullable] = STATE(2036),
    [sym_preproc_error] = STATE(2036),
    [sym_preproc_warning] = STATE(2036),
    [sym_preproc_define] = STATE(2036),
    [sym_preproc_undef] = STATE(2036),
    [aux_sym_class_declaration_repeat1] = STATE(3823),
    [aux_sym_lambda_expression_repeat1] = STATE(4240),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1751),
    [anon_sym_ref] = ACTIONS(1753),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1755),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1759),
    [anon_sym_TILDE] = ACTIONS(1759),
    [anon_sym_PLUS_PLUS] = ACTIONS(1759),
    [anon_sym_DASH_DASH] = ACTIONS(1759),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1757),
    [anon_sym_DASH] = ACTIONS(1757),
    [anon_sym_STAR] = ACTIONS(1381),
    [anon_sym_CARET] = ACTIONS(1759),
    [anon_sym_AMP] = ACTIONS(1759),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1761),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1763),
    [anon_sym_DOT_DOT] = ACTIONS(1765),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2037] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7010),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3926),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4334),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9265),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(2037),
    [sym_preproc_endregion] = STATE(2037),
    [sym_preproc_line] = STATE(2037),
    [sym_preproc_pragma] = STATE(2037),
    [sym_preproc_nullable] = STATE(2037),
    [sym_preproc_error] = STATE(2037),
    [sym_preproc_warning] = STATE(2037),
    [sym_preproc_define] = STATE(2037),
    [sym_preproc_undef] = STATE(2037),
    [aux_sym_class_declaration_repeat1] = STATE(3823),
    [aux_sym_lambda_expression_repeat1] = STATE(4240),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1751),
    [anon_sym_ref] = ACTIONS(1753),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1755),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1759),
    [anon_sym_TILDE] = ACTIONS(1759),
    [anon_sym_PLUS_PLUS] = ACTIONS(1759),
    [anon_sym_DASH_DASH] = ACTIONS(1759),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1757),
    [anon_sym_DASH] = ACTIONS(1757),
    [anon_sym_STAR] = ACTIONS(1381),
    [anon_sym_CARET] = ACTIONS(1759),
    [anon_sym_AMP] = ACTIONS(1759),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1761),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1763),
    [anon_sym_DOT_DOT] = ACTIONS(1765),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2038] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6921),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2873),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7036),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5299),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4038),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7429),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9220),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(2038),
    [sym_preproc_endregion] = STATE(2038),
    [sym_preproc_line] = STATE(2038),
    [sym_preproc_pragma] = STATE(2038),
    [sym_preproc_nullable] = STATE(2038),
    [sym_preproc_error] = STATE(2038),
    [sym_preproc_warning] = STATE(2038),
    [sym_preproc_define] = STATE(2038),
    [sym_preproc_undef] = STATE(2038),
    [aux_sym_class_declaration_repeat1] = STATE(3830),
    [aux_sym_lambda_expression_repeat1] = STATE(4255),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1407),
    [anon_sym_ref] = ACTIONS(1409),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1415),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1421),
    [anon_sym_TILDE] = ACTIONS(1421),
    [anon_sym_PLUS_PLUS] = ACTIONS(1421),
    [anon_sym_DASH_DASH] = ACTIONS(1421),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1419),
    [anon_sym_DASH] = ACTIONS(1419),
    [anon_sym_STAR] = ACTIONS(1425),
    [anon_sym_CARET] = ACTIONS(1421),
    [anon_sym_AMP] = ACTIONS(1421),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1439),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1441),
    [anon_sym_DOT_DOT] = ACTIONS(1443),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [2039] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6921),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2873),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7036),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5375),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4038),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7429),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9220),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(2039),
    [sym_preproc_endregion] = STATE(2039),
    [sym_preproc_line] = STATE(2039),
    [sym_preproc_pragma] = STATE(2039),
    [sym_preproc_nullable] = STATE(2039),
    [sym_preproc_error] = STATE(2039),
    [sym_preproc_warning] = STATE(2039),
    [sym_preproc_define] = STATE(2039),
    [sym_preproc_undef] = STATE(2039),
    [aux_sym_class_declaration_repeat1] = STATE(3830),
    [aux_sym_lambda_expression_repeat1] = STATE(4255),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1407),
    [anon_sym_ref] = ACTIONS(1409),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1415),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1421),
    [anon_sym_TILDE] = ACTIONS(1421),
    [anon_sym_PLUS_PLUS] = ACTIONS(1421),
    [anon_sym_DASH_DASH] = ACTIONS(1421),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1419),
    [anon_sym_DASH] = ACTIONS(1419),
    [anon_sym_STAR] = ACTIONS(1425),
    [anon_sym_CARET] = ACTIONS(1421),
    [anon_sym_AMP] = ACTIONS(1421),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1439),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1441),
    [anon_sym_DOT_DOT] = ACTIONS(1443),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [2040] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6921),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2873),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7036),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5279),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4038),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7429),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9220),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(2040),
    [sym_preproc_endregion] = STATE(2040),
    [sym_preproc_line] = STATE(2040),
    [sym_preproc_pragma] = STATE(2040),
    [sym_preproc_nullable] = STATE(2040),
    [sym_preproc_error] = STATE(2040),
    [sym_preproc_warning] = STATE(2040),
    [sym_preproc_define] = STATE(2040),
    [sym_preproc_undef] = STATE(2040),
    [aux_sym_class_declaration_repeat1] = STATE(3830),
    [aux_sym_lambda_expression_repeat1] = STATE(4255),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1407),
    [anon_sym_ref] = ACTIONS(1409),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1415),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1421),
    [anon_sym_TILDE] = ACTIONS(1421),
    [anon_sym_PLUS_PLUS] = ACTIONS(1421),
    [anon_sym_DASH_DASH] = ACTIONS(1421),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1419),
    [anon_sym_DASH] = ACTIONS(1419),
    [anon_sym_STAR] = ACTIONS(1425),
    [anon_sym_CARET] = ACTIONS(1421),
    [anon_sym_AMP] = ACTIONS(1421),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1439),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1441),
    [anon_sym_DOT_DOT] = ACTIONS(1443),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [2041] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6921),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2873),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7036),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5313),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4038),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7429),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9220),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(2041),
    [sym_preproc_endregion] = STATE(2041),
    [sym_preproc_line] = STATE(2041),
    [sym_preproc_pragma] = STATE(2041),
    [sym_preproc_nullable] = STATE(2041),
    [sym_preproc_error] = STATE(2041),
    [sym_preproc_warning] = STATE(2041),
    [sym_preproc_define] = STATE(2041),
    [sym_preproc_undef] = STATE(2041),
    [aux_sym_class_declaration_repeat1] = STATE(3830),
    [aux_sym_lambda_expression_repeat1] = STATE(4255),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1407),
    [anon_sym_ref] = ACTIONS(1409),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1415),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1421),
    [anon_sym_TILDE] = ACTIONS(1421),
    [anon_sym_PLUS_PLUS] = ACTIONS(1421),
    [anon_sym_DASH_DASH] = ACTIONS(1421),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1419),
    [anon_sym_DASH] = ACTIONS(1419),
    [anon_sym_STAR] = ACTIONS(1425),
    [anon_sym_CARET] = ACTIONS(1421),
    [anon_sym_AMP] = ACTIONS(1421),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1439),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1441),
    [anon_sym_DOT_DOT] = ACTIONS(1443),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [2042] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6921),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2873),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7036),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5314),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4038),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7429),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9220),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(2042),
    [sym_preproc_endregion] = STATE(2042),
    [sym_preproc_line] = STATE(2042),
    [sym_preproc_pragma] = STATE(2042),
    [sym_preproc_nullable] = STATE(2042),
    [sym_preproc_error] = STATE(2042),
    [sym_preproc_warning] = STATE(2042),
    [sym_preproc_define] = STATE(2042),
    [sym_preproc_undef] = STATE(2042),
    [aux_sym_class_declaration_repeat1] = STATE(3830),
    [aux_sym_lambda_expression_repeat1] = STATE(4255),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1407),
    [anon_sym_ref] = ACTIONS(1409),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1415),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1421),
    [anon_sym_TILDE] = ACTIONS(1421),
    [anon_sym_PLUS_PLUS] = ACTIONS(1421),
    [anon_sym_DASH_DASH] = ACTIONS(1421),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1419),
    [anon_sym_DASH] = ACTIONS(1419),
    [anon_sym_STAR] = ACTIONS(1425),
    [anon_sym_CARET] = ACTIONS(1421),
    [anon_sym_AMP] = ACTIONS(1421),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1439),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1441),
    [anon_sym_DOT_DOT] = ACTIONS(1443),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [2043] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6921),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2873),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7036),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5316),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4038),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7429),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9220),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(2043),
    [sym_preproc_endregion] = STATE(2043),
    [sym_preproc_line] = STATE(2043),
    [sym_preproc_pragma] = STATE(2043),
    [sym_preproc_nullable] = STATE(2043),
    [sym_preproc_error] = STATE(2043),
    [sym_preproc_warning] = STATE(2043),
    [sym_preproc_define] = STATE(2043),
    [sym_preproc_undef] = STATE(2043),
    [aux_sym_class_declaration_repeat1] = STATE(3830),
    [aux_sym_lambda_expression_repeat1] = STATE(4255),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1407),
    [anon_sym_ref] = ACTIONS(1409),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1415),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1421),
    [anon_sym_TILDE] = ACTIONS(1421),
    [anon_sym_PLUS_PLUS] = ACTIONS(1421),
    [anon_sym_DASH_DASH] = ACTIONS(1421),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1419),
    [anon_sym_DASH] = ACTIONS(1419),
    [anon_sym_STAR] = ACTIONS(1425),
    [anon_sym_CARET] = ACTIONS(1421),
    [anon_sym_AMP] = ACTIONS(1421),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1439),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1441),
    [anon_sym_DOT_DOT] = ACTIONS(1443),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [2044] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6921),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2873),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7036),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5283),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4038),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7429),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9220),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(2044),
    [sym_preproc_endregion] = STATE(2044),
    [sym_preproc_line] = STATE(2044),
    [sym_preproc_pragma] = STATE(2044),
    [sym_preproc_nullable] = STATE(2044),
    [sym_preproc_error] = STATE(2044),
    [sym_preproc_warning] = STATE(2044),
    [sym_preproc_define] = STATE(2044),
    [sym_preproc_undef] = STATE(2044),
    [aux_sym_class_declaration_repeat1] = STATE(3830),
    [aux_sym_lambda_expression_repeat1] = STATE(4255),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1407),
    [anon_sym_ref] = ACTIONS(1409),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1415),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1421),
    [anon_sym_TILDE] = ACTIONS(1421),
    [anon_sym_PLUS_PLUS] = ACTIONS(1421),
    [anon_sym_DASH_DASH] = ACTIONS(1421),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1419),
    [anon_sym_DASH] = ACTIONS(1419),
    [anon_sym_STAR] = ACTIONS(1425),
    [anon_sym_CARET] = ACTIONS(1421),
    [anon_sym_AMP] = ACTIONS(1421),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1439),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1441),
    [anon_sym_DOT_DOT] = ACTIONS(1443),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [2045] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6921),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2873),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7036),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5318),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4038),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7429),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9220),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(2045),
    [sym_preproc_endregion] = STATE(2045),
    [sym_preproc_line] = STATE(2045),
    [sym_preproc_pragma] = STATE(2045),
    [sym_preproc_nullable] = STATE(2045),
    [sym_preproc_error] = STATE(2045),
    [sym_preproc_warning] = STATE(2045),
    [sym_preproc_define] = STATE(2045),
    [sym_preproc_undef] = STATE(2045),
    [aux_sym_class_declaration_repeat1] = STATE(3830),
    [aux_sym_lambda_expression_repeat1] = STATE(4255),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1407),
    [anon_sym_ref] = ACTIONS(1409),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1415),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1421),
    [anon_sym_TILDE] = ACTIONS(1421),
    [anon_sym_PLUS_PLUS] = ACTIONS(1421),
    [anon_sym_DASH_DASH] = ACTIONS(1421),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1419),
    [anon_sym_DASH] = ACTIONS(1419),
    [anon_sym_STAR] = ACTIONS(1425),
    [anon_sym_CARET] = ACTIONS(1421),
    [anon_sym_AMP] = ACTIONS(1421),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1439),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1441),
    [anon_sym_DOT_DOT] = ACTIONS(1443),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [2046] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6921),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2873),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7036),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5326),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4038),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7429),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9220),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(2046),
    [sym_preproc_endregion] = STATE(2046),
    [sym_preproc_line] = STATE(2046),
    [sym_preproc_pragma] = STATE(2046),
    [sym_preproc_nullable] = STATE(2046),
    [sym_preproc_error] = STATE(2046),
    [sym_preproc_warning] = STATE(2046),
    [sym_preproc_define] = STATE(2046),
    [sym_preproc_undef] = STATE(2046),
    [aux_sym_class_declaration_repeat1] = STATE(3830),
    [aux_sym_lambda_expression_repeat1] = STATE(4255),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1407),
    [anon_sym_ref] = ACTIONS(1409),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1415),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1421),
    [anon_sym_TILDE] = ACTIONS(1421),
    [anon_sym_PLUS_PLUS] = ACTIONS(1421),
    [anon_sym_DASH_DASH] = ACTIONS(1421),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1419),
    [anon_sym_DASH] = ACTIONS(1419),
    [anon_sym_STAR] = ACTIONS(1425),
    [anon_sym_CARET] = ACTIONS(1421),
    [anon_sym_AMP] = ACTIONS(1421),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1439),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1441),
    [anon_sym_DOT_DOT] = ACTIONS(1443),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [2047] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6921),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2873),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7036),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5327),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4038),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7429),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9220),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(2047),
    [sym_preproc_endregion] = STATE(2047),
    [sym_preproc_line] = STATE(2047),
    [sym_preproc_pragma] = STATE(2047),
    [sym_preproc_nullable] = STATE(2047),
    [sym_preproc_error] = STATE(2047),
    [sym_preproc_warning] = STATE(2047),
    [sym_preproc_define] = STATE(2047),
    [sym_preproc_undef] = STATE(2047),
    [aux_sym_class_declaration_repeat1] = STATE(3830),
    [aux_sym_lambda_expression_repeat1] = STATE(4255),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1407),
    [anon_sym_ref] = ACTIONS(1409),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1415),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1421),
    [anon_sym_TILDE] = ACTIONS(1421),
    [anon_sym_PLUS_PLUS] = ACTIONS(1421),
    [anon_sym_DASH_DASH] = ACTIONS(1421),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1419),
    [anon_sym_DASH] = ACTIONS(1419),
    [anon_sym_STAR] = ACTIONS(1425),
    [anon_sym_CARET] = ACTIONS(1421),
    [anon_sym_AMP] = ACTIONS(1421),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1439),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1441),
    [anon_sym_DOT_DOT] = ACTIONS(1443),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [2048] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6921),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2873),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7036),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5332),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4038),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7429),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9220),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(2048),
    [sym_preproc_endregion] = STATE(2048),
    [sym_preproc_line] = STATE(2048),
    [sym_preproc_pragma] = STATE(2048),
    [sym_preproc_nullable] = STATE(2048),
    [sym_preproc_error] = STATE(2048),
    [sym_preproc_warning] = STATE(2048),
    [sym_preproc_define] = STATE(2048),
    [sym_preproc_undef] = STATE(2048),
    [aux_sym_class_declaration_repeat1] = STATE(3830),
    [aux_sym_lambda_expression_repeat1] = STATE(4255),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1407),
    [anon_sym_ref] = ACTIONS(1409),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1415),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1421),
    [anon_sym_TILDE] = ACTIONS(1421),
    [anon_sym_PLUS_PLUS] = ACTIONS(1421),
    [anon_sym_DASH_DASH] = ACTIONS(1421),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1419),
    [anon_sym_DASH] = ACTIONS(1419),
    [anon_sym_STAR] = ACTIONS(1425),
    [anon_sym_CARET] = ACTIONS(1421),
    [anon_sym_AMP] = ACTIONS(1421),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1439),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1441),
    [anon_sym_DOT_DOT] = ACTIONS(1443),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [2049] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7010),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5961),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4334),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9265),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(2049),
    [sym_preproc_endregion] = STATE(2049),
    [sym_preproc_line] = STATE(2049),
    [sym_preproc_pragma] = STATE(2049),
    [sym_preproc_nullable] = STATE(2049),
    [sym_preproc_error] = STATE(2049),
    [sym_preproc_warning] = STATE(2049),
    [sym_preproc_define] = STATE(2049),
    [sym_preproc_undef] = STATE(2049),
    [aux_sym_class_declaration_repeat1] = STATE(3823),
    [aux_sym_lambda_expression_repeat1] = STATE(4240),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1751),
    [anon_sym_ref] = ACTIONS(1753),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1755),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1759),
    [anon_sym_TILDE] = ACTIONS(1759),
    [anon_sym_PLUS_PLUS] = ACTIONS(1759),
    [anon_sym_DASH_DASH] = ACTIONS(1759),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1757),
    [anon_sym_DASH] = ACTIONS(1757),
    [anon_sym_STAR] = ACTIONS(1381),
    [anon_sym_CARET] = ACTIONS(1759),
    [anon_sym_AMP] = ACTIONS(1759),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1761),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1763),
    [anon_sym_DOT_DOT] = ACTIONS(1765),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2050] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6921),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2873),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7036),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5210),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4038),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7429),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9220),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(2050),
    [sym_preproc_endregion] = STATE(2050),
    [sym_preproc_line] = STATE(2050),
    [sym_preproc_pragma] = STATE(2050),
    [sym_preproc_nullable] = STATE(2050),
    [sym_preproc_error] = STATE(2050),
    [sym_preproc_warning] = STATE(2050),
    [sym_preproc_define] = STATE(2050),
    [sym_preproc_undef] = STATE(2050),
    [aux_sym_class_declaration_repeat1] = STATE(3830),
    [aux_sym_lambda_expression_repeat1] = STATE(4255),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1407),
    [anon_sym_ref] = ACTIONS(1409),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1415),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1421),
    [anon_sym_TILDE] = ACTIONS(1421),
    [anon_sym_PLUS_PLUS] = ACTIONS(1421),
    [anon_sym_DASH_DASH] = ACTIONS(1421),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1419),
    [anon_sym_DASH] = ACTIONS(1419),
    [anon_sym_STAR] = ACTIONS(1425),
    [anon_sym_CARET] = ACTIONS(1421),
    [anon_sym_AMP] = ACTIONS(1421),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1439),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1441),
    [anon_sym_DOT_DOT] = ACTIONS(1443),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [2051] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7010),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5965),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4334),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9265),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(2051),
    [sym_preproc_endregion] = STATE(2051),
    [sym_preproc_line] = STATE(2051),
    [sym_preproc_pragma] = STATE(2051),
    [sym_preproc_nullable] = STATE(2051),
    [sym_preproc_error] = STATE(2051),
    [sym_preproc_warning] = STATE(2051),
    [sym_preproc_define] = STATE(2051),
    [sym_preproc_undef] = STATE(2051),
    [aux_sym_class_declaration_repeat1] = STATE(3823),
    [aux_sym_lambda_expression_repeat1] = STATE(4240),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1751),
    [anon_sym_ref] = ACTIONS(1753),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1755),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1759),
    [anon_sym_TILDE] = ACTIONS(1759),
    [anon_sym_PLUS_PLUS] = ACTIONS(1759),
    [anon_sym_DASH_DASH] = ACTIONS(1759),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1757),
    [anon_sym_DASH] = ACTIONS(1757),
    [anon_sym_STAR] = ACTIONS(1381),
    [anon_sym_CARET] = ACTIONS(1759),
    [anon_sym_AMP] = ACTIONS(1759),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1761),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1763),
    [anon_sym_DOT_DOT] = ACTIONS(1765),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2052] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6962),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3932),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(3931),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9818),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(2052),
    [sym_preproc_endregion] = STATE(2052),
    [sym_preproc_line] = STATE(2052),
    [sym_preproc_pragma] = STATE(2052),
    [sym_preproc_nullable] = STATE(2052),
    [sym_preproc_error] = STATE(2052),
    [sym_preproc_warning] = STATE(2052),
    [sym_preproc_define] = STATE(2052),
    [sym_preproc_undef] = STATE(2052),
    [aux_sym_class_declaration_repeat1] = STATE(3811),
    [aux_sym_lambda_expression_repeat1] = STATE(4201),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1373),
    [anon_sym_ref] = ACTIONS(1375),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1331),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1379),
    [anon_sym_TILDE] = ACTIONS(1379),
    [anon_sym_PLUS_PLUS] = ACTIONS(1379),
    [anon_sym_DASH_DASH] = ACTIONS(1379),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1377),
    [anon_sym_DASH] = ACTIONS(1377),
    [anon_sym_STAR] = ACTIONS(1381),
    [anon_sym_CARET] = ACTIONS(1379),
    [anon_sym_AMP] = ACTIONS(1379),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1383),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1385),
    [anon_sym_DOT_DOT] = ACTIONS(1387),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2053] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6925),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2932),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7073),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4408),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3565),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7434),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9324),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(2053),
    [sym_preproc_endregion] = STATE(2053),
    [sym_preproc_line] = STATE(2053),
    [sym_preproc_pragma] = STATE(2053),
    [sym_preproc_nullable] = STATE(2053),
    [sym_preproc_error] = STATE(2053),
    [sym_preproc_warning] = STATE(2053),
    [sym_preproc_define] = STATE(2053),
    [sym_preproc_undef] = STATE(2053),
    [aux_sym_class_declaration_repeat1] = STATE(3842),
    [aux_sym_lambda_expression_repeat1] = STATE(4273),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1767),
    [anon_sym_ref] = ACTIONS(1769),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1771),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1775),
    [anon_sym_TILDE] = ACTIONS(1775),
    [anon_sym_PLUS_PLUS] = ACTIONS(1775),
    [anon_sym_DASH_DASH] = ACTIONS(1775),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1773),
    [anon_sym_DASH] = ACTIONS(1773),
    [anon_sym_STAR] = ACTIONS(1777),
    [anon_sym_CARET] = ACTIONS(1775),
    [anon_sym_AMP] = ACTIONS(1775),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(1779),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1781),
    [anon_sym_DOT_DOT] = ACTIONS(1783),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [2054] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6925),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2932),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7073),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4373),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3565),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7434),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9324),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(2054),
    [sym_preproc_endregion] = STATE(2054),
    [sym_preproc_line] = STATE(2054),
    [sym_preproc_pragma] = STATE(2054),
    [sym_preproc_nullable] = STATE(2054),
    [sym_preproc_error] = STATE(2054),
    [sym_preproc_warning] = STATE(2054),
    [sym_preproc_define] = STATE(2054),
    [sym_preproc_undef] = STATE(2054),
    [aux_sym_class_declaration_repeat1] = STATE(3842),
    [aux_sym_lambda_expression_repeat1] = STATE(4273),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1767),
    [anon_sym_ref] = ACTIONS(1769),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1771),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1775),
    [anon_sym_TILDE] = ACTIONS(1775),
    [anon_sym_PLUS_PLUS] = ACTIONS(1775),
    [anon_sym_DASH_DASH] = ACTIONS(1775),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1773),
    [anon_sym_DASH] = ACTIONS(1773),
    [anon_sym_STAR] = ACTIONS(1777),
    [anon_sym_CARET] = ACTIONS(1775),
    [anon_sym_AMP] = ACTIONS(1775),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(1779),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1781),
    [anon_sym_DOT_DOT] = ACTIONS(1783),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [2055] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6925),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2932),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7073),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4409),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3565),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7434),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9324),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(2055),
    [sym_preproc_endregion] = STATE(2055),
    [sym_preproc_line] = STATE(2055),
    [sym_preproc_pragma] = STATE(2055),
    [sym_preproc_nullable] = STATE(2055),
    [sym_preproc_error] = STATE(2055),
    [sym_preproc_warning] = STATE(2055),
    [sym_preproc_define] = STATE(2055),
    [sym_preproc_undef] = STATE(2055),
    [aux_sym_class_declaration_repeat1] = STATE(3842),
    [aux_sym_lambda_expression_repeat1] = STATE(4273),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1767),
    [anon_sym_ref] = ACTIONS(1769),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1771),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1775),
    [anon_sym_TILDE] = ACTIONS(1775),
    [anon_sym_PLUS_PLUS] = ACTIONS(1775),
    [anon_sym_DASH_DASH] = ACTIONS(1775),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1773),
    [anon_sym_DASH] = ACTIONS(1773),
    [anon_sym_STAR] = ACTIONS(1777),
    [anon_sym_CARET] = ACTIONS(1775),
    [anon_sym_AMP] = ACTIONS(1775),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(1779),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1781),
    [anon_sym_DOT_DOT] = ACTIONS(1783),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [2056] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6925),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2932),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7073),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4417),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3565),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7434),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9324),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(2056),
    [sym_preproc_endregion] = STATE(2056),
    [sym_preproc_line] = STATE(2056),
    [sym_preproc_pragma] = STATE(2056),
    [sym_preproc_nullable] = STATE(2056),
    [sym_preproc_error] = STATE(2056),
    [sym_preproc_warning] = STATE(2056),
    [sym_preproc_define] = STATE(2056),
    [sym_preproc_undef] = STATE(2056),
    [aux_sym_class_declaration_repeat1] = STATE(3842),
    [aux_sym_lambda_expression_repeat1] = STATE(4273),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1767),
    [anon_sym_ref] = ACTIONS(1769),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1771),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1775),
    [anon_sym_TILDE] = ACTIONS(1775),
    [anon_sym_PLUS_PLUS] = ACTIONS(1775),
    [anon_sym_DASH_DASH] = ACTIONS(1775),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1773),
    [anon_sym_DASH] = ACTIONS(1773),
    [anon_sym_STAR] = ACTIONS(1777),
    [anon_sym_CARET] = ACTIONS(1775),
    [anon_sym_AMP] = ACTIONS(1775),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(1779),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1781),
    [anon_sym_DOT_DOT] = ACTIONS(1783),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [2057] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6925),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2932),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7073),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4422),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3565),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7434),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9324),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(2057),
    [sym_preproc_endregion] = STATE(2057),
    [sym_preproc_line] = STATE(2057),
    [sym_preproc_pragma] = STATE(2057),
    [sym_preproc_nullable] = STATE(2057),
    [sym_preproc_error] = STATE(2057),
    [sym_preproc_warning] = STATE(2057),
    [sym_preproc_define] = STATE(2057),
    [sym_preproc_undef] = STATE(2057),
    [aux_sym_class_declaration_repeat1] = STATE(3842),
    [aux_sym_lambda_expression_repeat1] = STATE(4273),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1767),
    [anon_sym_ref] = ACTIONS(1769),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1771),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1775),
    [anon_sym_TILDE] = ACTIONS(1775),
    [anon_sym_PLUS_PLUS] = ACTIONS(1775),
    [anon_sym_DASH_DASH] = ACTIONS(1775),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1773),
    [anon_sym_DASH] = ACTIONS(1773),
    [anon_sym_STAR] = ACTIONS(1777),
    [anon_sym_CARET] = ACTIONS(1775),
    [anon_sym_AMP] = ACTIONS(1775),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(1779),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1781),
    [anon_sym_DOT_DOT] = ACTIONS(1783),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [2058] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6925),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2932),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7073),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4423),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3565),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7434),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9324),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(2058),
    [sym_preproc_endregion] = STATE(2058),
    [sym_preproc_line] = STATE(2058),
    [sym_preproc_pragma] = STATE(2058),
    [sym_preproc_nullable] = STATE(2058),
    [sym_preproc_error] = STATE(2058),
    [sym_preproc_warning] = STATE(2058),
    [sym_preproc_define] = STATE(2058),
    [sym_preproc_undef] = STATE(2058),
    [aux_sym_class_declaration_repeat1] = STATE(3842),
    [aux_sym_lambda_expression_repeat1] = STATE(4273),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1767),
    [anon_sym_ref] = ACTIONS(1769),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1771),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1775),
    [anon_sym_TILDE] = ACTIONS(1775),
    [anon_sym_PLUS_PLUS] = ACTIONS(1775),
    [anon_sym_DASH_DASH] = ACTIONS(1775),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1773),
    [anon_sym_DASH] = ACTIONS(1773),
    [anon_sym_STAR] = ACTIONS(1777),
    [anon_sym_CARET] = ACTIONS(1775),
    [anon_sym_AMP] = ACTIONS(1775),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(1779),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1781),
    [anon_sym_DOT_DOT] = ACTIONS(1783),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [2059] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6925),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2932),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7073),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4424),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3565),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7434),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9324),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(2059),
    [sym_preproc_endregion] = STATE(2059),
    [sym_preproc_line] = STATE(2059),
    [sym_preproc_pragma] = STATE(2059),
    [sym_preproc_nullable] = STATE(2059),
    [sym_preproc_error] = STATE(2059),
    [sym_preproc_warning] = STATE(2059),
    [sym_preproc_define] = STATE(2059),
    [sym_preproc_undef] = STATE(2059),
    [aux_sym_class_declaration_repeat1] = STATE(3842),
    [aux_sym_lambda_expression_repeat1] = STATE(4273),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1767),
    [anon_sym_ref] = ACTIONS(1769),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1771),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1775),
    [anon_sym_TILDE] = ACTIONS(1775),
    [anon_sym_PLUS_PLUS] = ACTIONS(1775),
    [anon_sym_DASH_DASH] = ACTIONS(1775),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1773),
    [anon_sym_DASH] = ACTIONS(1773),
    [anon_sym_STAR] = ACTIONS(1777),
    [anon_sym_CARET] = ACTIONS(1775),
    [anon_sym_AMP] = ACTIONS(1775),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(1779),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1781),
    [anon_sym_DOT_DOT] = ACTIONS(1783),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [2060] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6925),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2932),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7073),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4430),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3565),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7434),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9324),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(2060),
    [sym_preproc_endregion] = STATE(2060),
    [sym_preproc_line] = STATE(2060),
    [sym_preproc_pragma] = STATE(2060),
    [sym_preproc_nullable] = STATE(2060),
    [sym_preproc_error] = STATE(2060),
    [sym_preproc_warning] = STATE(2060),
    [sym_preproc_define] = STATE(2060),
    [sym_preproc_undef] = STATE(2060),
    [aux_sym_class_declaration_repeat1] = STATE(3842),
    [aux_sym_lambda_expression_repeat1] = STATE(4273),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1767),
    [anon_sym_ref] = ACTIONS(1769),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1771),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1775),
    [anon_sym_TILDE] = ACTIONS(1775),
    [anon_sym_PLUS_PLUS] = ACTIONS(1775),
    [anon_sym_DASH_DASH] = ACTIONS(1775),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1773),
    [anon_sym_DASH] = ACTIONS(1773),
    [anon_sym_STAR] = ACTIONS(1777),
    [anon_sym_CARET] = ACTIONS(1775),
    [anon_sym_AMP] = ACTIONS(1775),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(1779),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1781),
    [anon_sym_DOT_DOT] = ACTIONS(1783),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [2061] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6925),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2932),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7073),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4431),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3565),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7434),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9324),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(2061),
    [sym_preproc_endregion] = STATE(2061),
    [sym_preproc_line] = STATE(2061),
    [sym_preproc_pragma] = STATE(2061),
    [sym_preproc_nullable] = STATE(2061),
    [sym_preproc_error] = STATE(2061),
    [sym_preproc_warning] = STATE(2061),
    [sym_preproc_define] = STATE(2061),
    [sym_preproc_undef] = STATE(2061),
    [aux_sym_class_declaration_repeat1] = STATE(3842),
    [aux_sym_lambda_expression_repeat1] = STATE(4273),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1767),
    [anon_sym_ref] = ACTIONS(1769),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1771),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1775),
    [anon_sym_TILDE] = ACTIONS(1775),
    [anon_sym_PLUS_PLUS] = ACTIONS(1775),
    [anon_sym_DASH_DASH] = ACTIONS(1775),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1773),
    [anon_sym_DASH] = ACTIONS(1773),
    [anon_sym_STAR] = ACTIONS(1777),
    [anon_sym_CARET] = ACTIONS(1775),
    [anon_sym_AMP] = ACTIONS(1775),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(1779),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1781),
    [anon_sym_DOT_DOT] = ACTIONS(1783),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [2062] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6925),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2932),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7073),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4432),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3565),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7434),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9324),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(2062),
    [sym_preproc_endregion] = STATE(2062),
    [sym_preproc_line] = STATE(2062),
    [sym_preproc_pragma] = STATE(2062),
    [sym_preproc_nullable] = STATE(2062),
    [sym_preproc_error] = STATE(2062),
    [sym_preproc_warning] = STATE(2062),
    [sym_preproc_define] = STATE(2062),
    [sym_preproc_undef] = STATE(2062),
    [aux_sym_class_declaration_repeat1] = STATE(3842),
    [aux_sym_lambda_expression_repeat1] = STATE(4273),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1767),
    [anon_sym_ref] = ACTIONS(1769),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1771),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1775),
    [anon_sym_TILDE] = ACTIONS(1775),
    [anon_sym_PLUS_PLUS] = ACTIONS(1775),
    [anon_sym_DASH_DASH] = ACTIONS(1775),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1773),
    [anon_sym_DASH] = ACTIONS(1773),
    [anon_sym_STAR] = ACTIONS(1777),
    [anon_sym_CARET] = ACTIONS(1775),
    [anon_sym_AMP] = ACTIONS(1775),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(1779),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1781),
    [anon_sym_DOT_DOT] = ACTIONS(1783),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [2063] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6925),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2932),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7073),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4426),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3565),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7434),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9324),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(2063),
    [sym_preproc_endregion] = STATE(2063),
    [sym_preproc_line] = STATE(2063),
    [sym_preproc_pragma] = STATE(2063),
    [sym_preproc_nullable] = STATE(2063),
    [sym_preproc_error] = STATE(2063),
    [sym_preproc_warning] = STATE(2063),
    [sym_preproc_define] = STATE(2063),
    [sym_preproc_undef] = STATE(2063),
    [aux_sym_class_declaration_repeat1] = STATE(3842),
    [aux_sym_lambda_expression_repeat1] = STATE(4273),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1767),
    [anon_sym_ref] = ACTIONS(1769),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1771),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1775),
    [anon_sym_TILDE] = ACTIONS(1775),
    [anon_sym_PLUS_PLUS] = ACTIONS(1775),
    [anon_sym_DASH_DASH] = ACTIONS(1775),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1773),
    [anon_sym_DASH] = ACTIONS(1773),
    [anon_sym_STAR] = ACTIONS(1777),
    [anon_sym_CARET] = ACTIONS(1775),
    [anon_sym_AMP] = ACTIONS(1775),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(1779),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1781),
    [anon_sym_DOT_DOT] = ACTIONS(1783),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [2064] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6925),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2932),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7073),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4433),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3565),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7434),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9324),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(2064),
    [sym_preproc_endregion] = STATE(2064),
    [sym_preproc_line] = STATE(2064),
    [sym_preproc_pragma] = STATE(2064),
    [sym_preproc_nullable] = STATE(2064),
    [sym_preproc_error] = STATE(2064),
    [sym_preproc_warning] = STATE(2064),
    [sym_preproc_define] = STATE(2064),
    [sym_preproc_undef] = STATE(2064),
    [aux_sym_class_declaration_repeat1] = STATE(3842),
    [aux_sym_lambda_expression_repeat1] = STATE(4273),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1767),
    [anon_sym_ref] = ACTIONS(1769),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1771),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1775),
    [anon_sym_TILDE] = ACTIONS(1775),
    [anon_sym_PLUS_PLUS] = ACTIONS(1775),
    [anon_sym_DASH_DASH] = ACTIONS(1775),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1773),
    [anon_sym_DASH] = ACTIONS(1773),
    [anon_sym_STAR] = ACTIONS(1777),
    [anon_sym_CARET] = ACTIONS(1775),
    [anon_sym_AMP] = ACTIONS(1775),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(1779),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1781),
    [anon_sym_DOT_DOT] = ACTIONS(1783),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [2065] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6925),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2932),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7073),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4434),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3565),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7434),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9324),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(2065),
    [sym_preproc_endregion] = STATE(2065),
    [sym_preproc_line] = STATE(2065),
    [sym_preproc_pragma] = STATE(2065),
    [sym_preproc_nullable] = STATE(2065),
    [sym_preproc_error] = STATE(2065),
    [sym_preproc_warning] = STATE(2065),
    [sym_preproc_define] = STATE(2065),
    [sym_preproc_undef] = STATE(2065),
    [aux_sym_class_declaration_repeat1] = STATE(3842),
    [aux_sym_lambda_expression_repeat1] = STATE(4273),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1767),
    [anon_sym_ref] = ACTIONS(1769),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1771),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1775),
    [anon_sym_TILDE] = ACTIONS(1775),
    [anon_sym_PLUS_PLUS] = ACTIONS(1775),
    [anon_sym_DASH_DASH] = ACTIONS(1775),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1773),
    [anon_sym_DASH] = ACTIONS(1773),
    [anon_sym_STAR] = ACTIONS(1777),
    [anon_sym_CARET] = ACTIONS(1775),
    [anon_sym_AMP] = ACTIONS(1775),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(1779),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1781),
    [anon_sym_DOT_DOT] = ACTIONS(1783),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [2066] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6925),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2932),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7073),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4437),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3565),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7434),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9324),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(2066),
    [sym_preproc_endregion] = STATE(2066),
    [sym_preproc_line] = STATE(2066),
    [sym_preproc_pragma] = STATE(2066),
    [sym_preproc_nullable] = STATE(2066),
    [sym_preproc_error] = STATE(2066),
    [sym_preproc_warning] = STATE(2066),
    [sym_preproc_define] = STATE(2066),
    [sym_preproc_undef] = STATE(2066),
    [aux_sym_class_declaration_repeat1] = STATE(3842),
    [aux_sym_lambda_expression_repeat1] = STATE(4273),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1767),
    [anon_sym_ref] = ACTIONS(1769),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1771),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1775),
    [anon_sym_TILDE] = ACTIONS(1775),
    [anon_sym_PLUS_PLUS] = ACTIONS(1775),
    [anon_sym_DASH_DASH] = ACTIONS(1775),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1773),
    [anon_sym_DASH] = ACTIONS(1773),
    [anon_sym_STAR] = ACTIONS(1777),
    [anon_sym_CARET] = ACTIONS(1775),
    [anon_sym_AMP] = ACTIONS(1775),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(1779),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1781),
    [anon_sym_DOT_DOT] = ACTIONS(1783),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [2067] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6925),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2932),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7073),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4438),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3565),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7434),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9324),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(2067),
    [sym_preproc_endregion] = STATE(2067),
    [sym_preproc_line] = STATE(2067),
    [sym_preproc_pragma] = STATE(2067),
    [sym_preproc_nullable] = STATE(2067),
    [sym_preproc_error] = STATE(2067),
    [sym_preproc_warning] = STATE(2067),
    [sym_preproc_define] = STATE(2067),
    [sym_preproc_undef] = STATE(2067),
    [aux_sym_class_declaration_repeat1] = STATE(3842),
    [aux_sym_lambda_expression_repeat1] = STATE(4273),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1767),
    [anon_sym_ref] = ACTIONS(1769),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1771),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1775),
    [anon_sym_TILDE] = ACTIONS(1775),
    [anon_sym_PLUS_PLUS] = ACTIONS(1775),
    [anon_sym_DASH_DASH] = ACTIONS(1775),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1773),
    [anon_sym_DASH] = ACTIONS(1773),
    [anon_sym_STAR] = ACTIONS(1777),
    [anon_sym_CARET] = ACTIONS(1775),
    [anon_sym_AMP] = ACTIONS(1775),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(1779),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1781),
    [anon_sym_DOT_DOT] = ACTIONS(1783),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [2068] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6925),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2932),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7073),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4389),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3565),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7434),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9324),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(2068),
    [sym_preproc_endregion] = STATE(2068),
    [sym_preproc_line] = STATE(2068),
    [sym_preproc_pragma] = STATE(2068),
    [sym_preproc_nullable] = STATE(2068),
    [sym_preproc_error] = STATE(2068),
    [sym_preproc_warning] = STATE(2068),
    [sym_preproc_define] = STATE(2068),
    [sym_preproc_undef] = STATE(2068),
    [aux_sym_class_declaration_repeat1] = STATE(3842),
    [aux_sym_lambda_expression_repeat1] = STATE(4273),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1767),
    [anon_sym_ref] = ACTIONS(1769),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1771),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1775),
    [anon_sym_TILDE] = ACTIONS(1775),
    [anon_sym_PLUS_PLUS] = ACTIONS(1775),
    [anon_sym_DASH_DASH] = ACTIONS(1775),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1773),
    [anon_sym_DASH] = ACTIONS(1773),
    [anon_sym_STAR] = ACTIONS(1777),
    [anon_sym_CARET] = ACTIONS(1775),
    [anon_sym_AMP] = ACTIONS(1775),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(1779),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1781),
    [anon_sym_DOT_DOT] = ACTIONS(1783),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [2069] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6937),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2861),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7081),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5212),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(3898),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7429),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9350),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(2069),
    [sym_preproc_endregion] = STATE(2069),
    [sym_preproc_line] = STATE(2069),
    [sym_preproc_pragma] = STATE(2069),
    [sym_preproc_nullable] = STATE(2069),
    [sym_preproc_error] = STATE(2069),
    [sym_preproc_warning] = STATE(2069),
    [sym_preproc_define] = STATE(2069),
    [sym_preproc_undef] = STATE(2069),
    [aux_sym_class_declaration_repeat1] = STATE(3879),
    [aux_sym_lambda_expression_repeat1] = STATE(4092),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1477),
    [anon_sym_ref] = ACTIONS(1479),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1481),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1485),
    [anon_sym_TILDE] = ACTIONS(1485),
    [anon_sym_PLUS_PLUS] = ACTIONS(1485),
    [anon_sym_DASH_DASH] = ACTIONS(1485),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1483),
    [anon_sym_DASH] = ACTIONS(1483),
    [anon_sym_STAR] = ACTIONS(1487),
    [anon_sym_CARET] = ACTIONS(1485),
    [anon_sym_AMP] = ACTIONS(1485),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1489),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1491),
    [anon_sym_DOT_DOT] = ACTIONS(1493),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [2070] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6937),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2861),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7081),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5156),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(3898),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7429),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9350),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(2070),
    [sym_preproc_endregion] = STATE(2070),
    [sym_preproc_line] = STATE(2070),
    [sym_preproc_pragma] = STATE(2070),
    [sym_preproc_nullable] = STATE(2070),
    [sym_preproc_error] = STATE(2070),
    [sym_preproc_warning] = STATE(2070),
    [sym_preproc_define] = STATE(2070),
    [sym_preproc_undef] = STATE(2070),
    [aux_sym_class_declaration_repeat1] = STATE(3879),
    [aux_sym_lambda_expression_repeat1] = STATE(4092),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1477),
    [anon_sym_ref] = ACTIONS(1479),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1481),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1485),
    [anon_sym_TILDE] = ACTIONS(1485),
    [anon_sym_PLUS_PLUS] = ACTIONS(1485),
    [anon_sym_DASH_DASH] = ACTIONS(1485),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1483),
    [anon_sym_DASH] = ACTIONS(1483),
    [anon_sym_STAR] = ACTIONS(1487),
    [anon_sym_CARET] = ACTIONS(1485),
    [anon_sym_AMP] = ACTIONS(1485),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1489),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1491),
    [anon_sym_DOT_DOT] = ACTIONS(1493),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [2071] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6937),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2861),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7081),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5216),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(3898),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7429),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9350),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(2071),
    [sym_preproc_endregion] = STATE(2071),
    [sym_preproc_line] = STATE(2071),
    [sym_preproc_pragma] = STATE(2071),
    [sym_preproc_nullable] = STATE(2071),
    [sym_preproc_error] = STATE(2071),
    [sym_preproc_warning] = STATE(2071),
    [sym_preproc_define] = STATE(2071),
    [sym_preproc_undef] = STATE(2071),
    [aux_sym_class_declaration_repeat1] = STATE(3879),
    [aux_sym_lambda_expression_repeat1] = STATE(4092),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1477),
    [anon_sym_ref] = ACTIONS(1479),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1481),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1485),
    [anon_sym_TILDE] = ACTIONS(1485),
    [anon_sym_PLUS_PLUS] = ACTIONS(1485),
    [anon_sym_DASH_DASH] = ACTIONS(1485),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1483),
    [anon_sym_DASH] = ACTIONS(1483),
    [anon_sym_STAR] = ACTIONS(1487),
    [anon_sym_CARET] = ACTIONS(1485),
    [anon_sym_AMP] = ACTIONS(1485),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1489),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1491),
    [anon_sym_DOT_DOT] = ACTIONS(1493),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [2072] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6937),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2861),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7081),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5226),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(3898),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7429),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9350),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(2072),
    [sym_preproc_endregion] = STATE(2072),
    [sym_preproc_line] = STATE(2072),
    [sym_preproc_pragma] = STATE(2072),
    [sym_preproc_nullable] = STATE(2072),
    [sym_preproc_error] = STATE(2072),
    [sym_preproc_warning] = STATE(2072),
    [sym_preproc_define] = STATE(2072),
    [sym_preproc_undef] = STATE(2072),
    [aux_sym_class_declaration_repeat1] = STATE(3879),
    [aux_sym_lambda_expression_repeat1] = STATE(4092),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1477),
    [anon_sym_ref] = ACTIONS(1479),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1481),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1485),
    [anon_sym_TILDE] = ACTIONS(1485),
    [anon_sym_PLUS_PLUS] = ACTIONS(1485),
    [anon_sym_DASH_DASH] = ACTIONS(1485),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1483),
    [anon_sym_DASH] = ACTIONS(1483),
    [anon_sym_STAR] = ACTIONS(1487),
    [anon_sym_CARET] = ACTIONS(1485),
    [anon_sym_AMP] = ACTIONS(1485),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1489),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1491),
    [anon_sym_DOT_DOT] = ACTIONS(1493),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [2073] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6937),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2861),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7081),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5174),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(3898),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7429),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9350),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(2073),
    [sym_preproc_endregion] = STATE(2073),
    [sym_preproc_line] = STATE(2073),
    [sym_preproc_pragma] = STATE(2073),
    [sym_preproc_nullable] = STATE(2073),
    [sym_preproc_error] = STATE(2073),
    [sym_preproc_warning] = STATE(2073),
    [sym_preproc_define] = STATE(2073),
    [sym_preproc_undef] = STATE(2073),
    [aux_sym_class_declaration_repeat1] = STATE(3879),
    [aux_sym_lambda_expression_repeat1] = STATE(4092),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1477),
    [anon_sym_ref] = ACTIONS(1479),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1481),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1485),
    [anon_sym_TILDE] = ACTIONS(1485),
    [anon_sym_PLUS_PLUS] = ACTIONS(1485),
    [anon_sym_DASH_DASH] = ACTIONS(1485),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1483),
    [anon_sym_DASH] = ACTIONS(1483),
    [anon_sym_STAR] = ACTIONS(1487),
    [anon_sym_CARET] = ACTIONS(1485),
    [anon_sym_AMP] = ACTIONS(1485),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1489),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1491),
    [anon_sym_DOT_DOT] = ACTIONS(1493),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [2074] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6937),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2861),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7081),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5176),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(3898),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7429),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9350),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(2074),
    [sym_preproc_endregion] = STATE(2074),
    [sym_preproc_line] = STATE(2074),
    [sym_preproc_pragma] = STATE(2074),
    [sym_preproc_nullable] = STATE(2074),
    [sym_preproc_error] = STATE(2074),
    [sym_preproc_warning] = STATE(2074),
    [sym_preproc_define] = STATE(2074),
    [sym_preproc_undef] = STATE(2074),
    [aux_sym_class_declaration_repeat1] = STATE(3879),
    [aux_sym_lambda_expression_repeat1] = STATE(4092),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1477),
    [anon_sym_ref] = ACTIONS(1479),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1481),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1485),
    [anon_sym_TILDE] = ACTIONS(1485),
    [anon_sym_PLUS_PLUS] = ACTIONS(1485),
    [anon_sym_DASH_DASH] = ACTIONS(1485),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1483),
    [anon_sym_DASH] = ACTIONS(1483),
    [anon_sym_STAR] = ACTIONS(1487),
    [anon_sym_CARET] = ACTIONS(1485),
    [anon_sym_AMP] = ACTIONS(1485),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1489),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1491),
    [anon_sym_DOT_DOT] = ACTIONS(1493),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [2075] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6937),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2861),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7081),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5183),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(3898),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7429),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9350),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(2075),
    [sym_preproc_endregion] = STATE(2075),
    [sym_preproc_line] = STATE(2075),
    [sym_preproc_pragma] = STATE(2075),
    [sym_preproc_nullable] = STATE(2075),
    [sym_preproc_error] = STATE(2075),
    [sym_preproc_warning] = STATE(2075),
    [sym_preproc_define] = STATE(2075),
    [sym_preproc_undef] = STATE(2075),
    [aux_sym_class_declaration_repeat1] = STATE(3879),
    [aux_sym_lambda_expression_repeat1] = STATE(4092),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1477),
    [anon_sym_ref] = ACTIONS(1479),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1481),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1485),
    [anon_sym_TILDE] = ACTIONS(1485),
    [anon_sym_PLUS_PLUS] = ACTIONS(1485),
    [anon_sym_DASH_DASH] = ACTIONS(1485),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1483),
    [anon_sym_DASH] = ACTIONS(1483),
    [anon_sym_STAR] = ACTIONS(1487),
    [anon_sym_CARET] = ACTIONS(1485),
    [anon_sym_AMP] = ACTIONS(1485),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1489),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1491),
    [anon_sym_DOT_DOT] = ACTIONS(1493),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [2076] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6937),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2861),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7081),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5201),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(3898),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7429),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9350),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(2076),
    [sym_preproc_endregion] = STATE(2076),
    [sym_preproc_line] = STATE(2076),
    [sym_preproc_pragma] = STATE(2076),
    [sym_preproc_nullable] = STATE(2076),
    [sym_preproc_error] = STATE(2076),
    [sym_preproc_warning] = STATE(2076),
    [sym_preproc_define] = STATE(2076),
    [sym_preproc_undef] = STATE(2076),
    [aux_sym_class_declaration_repeat1] = STATE(3879),
    [aux_sym_lambda_expression_repeat1] = STATE(4092),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1477),
    [anon_sym_ref] = ACTIONS(1479),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1481),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1485),
    [anon_sym_TILDE] = ACTIONS(1485),
    [anon_sym_PLUS_PLUS] = ACTIONS(1485),
    [anon_sym_DASH_DASH] = ACTIONS(1485),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1483),
    [anon_sym_DASH] = ACTIONS(1483),
    [anon_sym_STAR] = ACTIONS(1487),
    [anon_sym_CARET] = ACTIONS(1485),
    [anon_sym_AMP] = ACTIONS(1485),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1489),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1491),
    [anon_sym_DOT_DOT] = ACTIONS(1493),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [2077] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6937),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2861),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7081),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5214),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(3898),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7429),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9350),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(2077),
    [sym_preproc_endregion] = STATE(2077),
    [sym_preproc_line] = STATE(2077),
    [sym_preproc_pragma] = STATE(2077),
    [sym_preproc_nullable] = STATE(2077),
    [sym_preproc_error] = STATE(2077),
    [sym_preproc_warning] = STATE(2077),
    [sym_preproc_define] = STATE(2077),
    [sym_preproc_undef] = STATE(2077),
    [aux_sym_class_declaration_repeat1] = STATE(3879),
    [aux_sym_lambda_expression_repeat1] = STATE(4092),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1477),
    [anon_sym_ref] = ACTIONS(1479),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1481),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1485),
    [anon_sym_TILDE] = ACTIONS(1485),
    [anon_sym_PLUS_PLUS] = ACTIONS(1485),
    [anon_sym_DASH_DASH] = ACTIONS(1485),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1483),
    [anon_sym_DASH] = ACTIONS(1483),
    [anon_sym_STAR] = ACTIONS(1487),
    [anon_sym_CARET] = ACTIONS(1485),
    [anon_sym_AMP] = ACTIONS(1485),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1489),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1491),
    [anon_sym_DOT_DOT] = ACTIONS(1493),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [2078] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6937),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2861),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7081),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5178),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(3898),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7429),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9350),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(2078),
    [sym_preproc_endregion] = STATE(2078),
    [sym_preproc_line] = STATE(2078),
    [sym_preproc_pragma] = STATE(2078),
    [sym_preproc_nullable] = STATE(2078),
    [sym_preproc_error] = STATE(2078),
    [sym_preproc_warning] = STATE(2078),
    [sym_preproc_define] = STATE(2078),
    [sym_preproc_undef] = STATE(2078),
    [aux_sym_class_declaration_repeat1] = STATE(3879),
    [aux_sym_lambda_expression_repeat1] = STATE(4092),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1477),
    [anon_sym_ref] = ACTIONS(1479),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1481),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1485),
    [anon_sym_TILDE] = ACTIONS(1485),
    [anon_sym_PLUS_PLUS] = ACTIONS(1485),
    [anon_sym_DASH_DASH] = ACTIONS(1485),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1483),
    [anon_sym_DASH] = ACTIONS(1483),
    [anon_sym_STAR] = ACTIONS(1487),
    [anon_sym_CARET] = ACTIONS(1485),
    [anon_sym_AMP] = ACTIONS(1485),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1489),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1491),
    [anon_sym_DOT_DOT] = ACTIONS(1493),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [2079] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6937),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2861),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7081),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5202),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(3898),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7429),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9350),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(2079),
    [sym_preproc_endregion] = STATE(2079),
    [sym_preproc_line] = STATE(2079),
    [sym_preproc_pragma] = STATE(2079),
    [sym_preproc_nullable] = STATE(2079),
    [sym_preproc_error] = STATE(2079),
    [sym_preproc_warning] = STATE(2079),
    [sym_preproc_define] = STATE(2079),
    [sym_preproc_undef] = STATE(2079),
    [aux_sym_class_declaration_repeat1] = STATE(3879),
    [aux_sym_lambda_expression_repeat1] = STATE(4092),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1477),
    [anon_sym_ref] = ACTIONS(1479),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1481),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1485),
    [anon_sym_TILDE] = ACTIONS(1485),
    [anon_sym_PLUS_PLUS] = ACTIONS(1485),
    [anon_sym_DASH_DASH] = ACTIONS(1485),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1483),
    [anon_sym_DASH] = ACTIONS(1483),
    [anon_sym_STAR] = ACTIONS(1487),
    [anon_sym_CARET] = ACTIONS(1485),
    [anon_sym_AMP] = ACTIONS(1485),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1489),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1491),
    [anon_sym_DOT_DOT] = ACTIONS(1493),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [2080] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6937),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2861),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7081),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5234),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(3898),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7429),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9350),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(2080),
    [sym_preproc_endregion] = STATE(2080),
    [sym_preproc_line] = STATE(2080),
    [sym_preproc_pragma] = STATE(2080),
    [sym_preproc_nullable] = STATE(2080),
    [sym_preproc_error] = STATE(2080),
    [sym_preproc_warning] = STATE(2080),
    [sym_preproc_define] = STATE(2080),
    [sym_preproc_undef] = STATE(2080),
    [aux_sym_class_declaration_repeat1] = STATE(3879),
    [aux_sym_lambda_expression_repeat1] = STATE(4092),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1477),
    [anon_sym_ref] = ACTIONS(1479),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1481),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1485),
    [anon_sym_TILDE] = ACTIONS(1485),
    [anon_sym_PLUS_PLUS] = ACTIONS(1485),
    [anon_sym_DASH_DASH] = ACTIONS(1485),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1483),
    [anon_sym_DASH] = ACTIONS(1483),
    [anon_sym_STAR] = ACTIONS(1487),
    [anon_sym_CARET] = ACTIONS(1485),
    [anon_sym_AMP] = ACTIONS(1485),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1489),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1491),
    [anon_sym_DOT_DOT] = ACTIONS(1493),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [2081] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6937),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2861),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7081),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5168),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(3898),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7429),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9350),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(2081),
    [sym_preproc_endregion] = STATE(2081),
    [sym_preproc_line] = STATE(2081),
    [sym_preproc_pragma] = STATE(2081),
    [sym_preproc_nullable] = STATE(2081),
    [sym_preproc_error] = STATE(2081),
    [sym_preproc_warning] = STATE(2081),
    [sym_preproc_define] = STATE(2081),
    [sym_preproc_undef] = STATE(2081),
    [aux_sym_class_declaration_repeat1] = STATE(3879),
    [aux_sym_lambda_expression_repeat1] = STATE(4092),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1477),
    [anon_sym_ref] = ACTIONS(1479),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1481),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1485),
    [anon_sym_TILDE] = ACTIONS(1485),
    [anon_sym_PLUS_PLUS] = ACTIONS(1485),
    [anon_sym_DASH_DASH] = ACTIONS(1485),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1483),
    [anon_sym_DASH] = ACTIONS(1483),
    [anon_sym_STAR] = ACTIONS(1487),
    [anon_sym_CARET] = ACTIONS(1485),
    [anon_sym_AMP] = ACTIONS(1485),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1489),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1491),
    [anon_sym_DOT_DOT] = ACTIONS(1493),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [2082] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6937),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2861),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7081),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5242),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(3898),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7429),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9350),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(2082),
    [sym_preproc_endregion] = STATE(2082),
    [sym_preproc_line] = STATE(2082),
    [sym_preproc_pragma] = STATE(2082),
    [sym_preproc_nullable] = STATE(2082),
    [sym_preproc_error] = STATE(2082),
    [sym_preproc_warning] = STATE(2082),
    [sym_preproc_define] = STATE(2082),
    [sym_preproc_undef] = STATE(2082),
    [aux_sym_class_declaration_repeat1] = STATE(3879),
    [aux_sym_lambda_expression_repeat1] = STATE(4092),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1477),
    [anon_sym_ref] = ACTIONS(1479),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1481),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1485),
    [anon_sym_TILDE] = ACTIONS(1485),
    [anon_sym_PLUS_PLUS] = ACTIONS(1485),
    [anon_sym_DASH_DASH] = ACTIONS(1485),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1483),
    [anon_sym_DASH] = ACTIONS(1483),
    [anon_sym_STAR] = ACTIONS(1487),
    [anon_sym_CARET] = ACTIONS(1485),
    [anon_sym_AMP] = ACTIONS(1485),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1489),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1491),
    [anon_sym_DOT_DOT] = ACTIONS(1493),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [2083] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6937),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2861),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7081),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5207),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(3898),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7429),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9350),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(2083),
    [sym_preproc_endregion] = STATE(2083),
    [sym_preproc_line] = STATE(2083),
    [sym_preproc_pragma] = STATE(2083),
    [sym_preproc_nullable] = STATE(2083),
    [sym_preproc_error] = STATE(2083),
    [sym_preproc_warning] = STATE(2083),
    [sym_preproc_define] = STATE(2083),
    [sym_preproc_undef] = STATE(2083),
    [aux_sym_class_declaration_repeat1] = STATE(3879),
    [aux_sym_lambda_expression_repeat1] = STATE(4092),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1477),
    [anon_sym_ref] = ACTIONS(1479),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1481),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1485),
    [anon_sym_TILDE] = ACTIONS(1485),
    [anon_sym_PLUS_PLUS] = ACTIONS(1485),
    [anon_sym_DASH_DASH] = ACTIONS(1485),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1483),
    [anon_sym_DASH] = ACTIONS(1483),
    [anon_sym_STAR] = ACTIONS(1487),
    [anon_sym_CARET] = ACTIONS(1485),
    [anon_sym_AMP] = ACTIONS(1485),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1489),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1491),
    [anon_sym_DOT_DOT] = ACTIONS(1493),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [2084] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6937),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2861),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7081),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5210),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(3898),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7429),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9350),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(2084),
    [sym_preproc_endregion] = STATE(2084),
    [sym_preproc_line] = STATE(2084),
    [sym_preproc_pragma] = STATE(2084),
    [sym_preproc_nullable] = STATE(2084),
    [sym_preproc_error] = STATE(2084),
    [sym_preproc_warning] = STATE(2084),
    [sym_preproc_define] = STATE(2084),
    [sym_preproc_undef] = STATE(2084),
    [aux_sym_class_declaration_repeat1] = STATE(3879),
    [aux_sym_lambda_expression_repeat1] = STATE(4092),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1477),
    [anon_sym_ref] = ACTIONS(1479),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1481),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1485),
    [anon_sym_TILDE] = ACTIONS(1485),
    [anon_sym_PLUS_PLUS] = ACTIONS(1485),
    [anon_sym_DASH_DASH] = ACTIONS(1485),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1483),
    [anon_sym_DASH] = ACTIONS(1483),
    [anon_sym_STAR] = ACTIONS(1487),
    [anon_sym_CARET] = ACTIONS(1485),
    [anon_sym_AMP] = ACTIONS(1485),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1489),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1491),
    [anon_sym_DOT_DOT] = ACTIONS(1493),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [2085] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7163),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6444),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4473),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9905),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2085),
    [sym_preproc_endregion] = STATE(2085),
    [sym_preproc_line] = STATE(2085),
    [sym_preproc_pragma] = STATE(2085),
    [sym_preproc_nullable] = STATE(2085),
    [sym_preproc_error] = STATE(2085),
    [sym_preproc_warning] = STATE(2085),
    [sym_preproc_define] = STATE(2085),
    [sym_preproc_undef] = STATE(2085),
    [aux_sym_class_declaration_repeat1] = STATE(3878),
    [aux_sym_lambda_expression_repeat1] = STATE(4331),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2055),
    [anon_sym_ref] = ACTIONS(2057),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2061),
    [anon_sym_TILDE] = ACTIONS(2061),
    [anon_sym_PLUS_PLUS] = ACTIONS(2061),
    [anon_sym_DASH_DASH] = ACTIONS(2061),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2059),
    [anon_sym_DASH] = ACTIONS(2059),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(2061),
    [anon_sym_AMP] = ACTIONS(2061),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2063),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2065),
    [anon_sym_DOT_DOT] = ACTIONS(2067),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2086] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7163),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4336),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4473),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9905),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2086),
    [sym_preproc_endregion] = STATE(2086),
    [sym_preproc_line] = STATE(2086),
    [sym_preproc_pragma] = STATE(2086),
    [sym_preproc_nullable] = STATE(2086),
    [sym_preproc_error] = STATE(2086),
    [sym_preproc_warning] = STATE(2086),
    [sym_preproc_define] = STATE(2086),
    [sym_preproc_undef] = STATE(2086),
    [aux_sym_class_declaration_repeat1] = STATE(3878),
    [aux_sym_lambda_expression_repeat1] = STATE(4331),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2055),
    [anon_sym_ref] = ACTIONS(2057),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2061),
    [anon_sym_TILDE] = ACTIONS(2061),
    [anon_sym_PLUS_PLUS] = ACTIONS(2061),
    [anon_sym_DASH_DASH] = ACTIONS(2061),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2059),
    [anon_sym_DASH] = ACTIONS(2059),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(2061),
    [anon_sym_AMP] = ACTIONS(2061),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2063),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2065),
    [anon_sym_DOT_DOT] = ACTIONS(2067),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2087] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7163),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6446),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4473),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9905),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2087),
    [sym_preproc_endregion] = STATE(2087),
    [sym_preproc_line] = STATE(2087),
    [sym_preproc_pragma] = STATE(2087),
    [sym_preproc_nullable] = STATE(2087),
    [sym_preproc_error] = STATE(2087),
    [sym_preproc_warning] = STATE(2087),
    [sym_preproc_define] = STATE(2087),
    [sym_preproc_undef] = STATE(2087),
    [aux_sym_class_declaration_repeat1] = STATE(3878),
    [aux_sym_lambda_expression_repeat1] = STATE(4331),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2055),
    [anon_sym_ref] = ACTIONS(2057),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2061),
    [anon_sym_TILDE] = ACTIONS(2061),
    [anon_sym_PLUS_PLUS] = ACTIONS(2061),
    [anon_sym_DASH_DASH] = ACTIONS(2061),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2059),
    [anon_sym_DASH] = ACTIONS(2059),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(2061),
    [anon_sym_AMP] = ACTIONS(2061),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2063),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2065),
    [anon_sym_DOT_DOT] = ACTIONS(2067),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2088] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3484),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7010),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3917),
    [sym_non_lvalue_expression] = STATE(4183),
    [sym_lvalue_expression] = STATE(4334),
    [sym__expression_statement_expression] = STATE(4170),
    [sym_assignment_expression] = STATE(4184),
    [sym_binary_expression] = STATE(4170),
    [sym_postfix_unary_expression] = STATE(4184),
    [sym_prefix_unary_expression] = STATE(4184),
    [sym__pointer_indirection_expression] = STATE(3480),
    [sym_query_expression] = STATE(4170),
    [sym_from_clause] = STATE(7424),
    [sym_conditional_expression] = STATE(4170),
    [sym_conditional_access_expression] = STATE(4170),
    [sym_as_expression] = STATE(4170),
    [sym_is_expression] = STATE(4170),
    [sym_is_pattern_expression] = STATE(4170),
    [sym_cast_expression] = STATE(4170),
    [sym_checked_expression] = STATE(4170),
    [sym_invocation_expression] = STATE(4184),
    [sym_switch_expression] = STATE(4170),
    [sym_await_expression] = STATE(4184),
    [sym_throw_expression] = STATE(4170),
    [sym_element_access_expression] = STATE(3480),
    [sym_interpolated_string_expression] = STATE(4170),
    [sym_member_access_expression] = STATE(3480),
    [sym_object_creation_expression] = STATE(4184),
    [sym_parenthesized_expression] = STATE(4184),
    [sym__parenthesized_lvalue_expression] = STATE(3480),
    [sym_lambda_expression] = STATE(4170),
    [sym__lambda_parameters] = STATE(9265),
    [sym_array_creation_expression] = STATE(4170),
    [sym_anonymous_method_expression] = STATE(4170),
    [sym_anonymous_object_creation_expression] = STATE(4170),
    [sym_implicit_array_creation_expression] = STATE(4170),
    [sym_implicit_object_creation_expression] = STATE(4170),
    [sym_implicit_stackalloc_expression] = STATE(4170),
    [sym_initializer_expression] = STATE(4170),
    [sym_default_expression] = STATE(4170),
    [sym_with_expression] = STATE(4170),
    [sym_sizeof_expression] = STATE(4170),
    [sym_typeof_expression] = STATE(4170),
    [sym_makeref_expression] = STATE(4170),
    [sym_ref_expression] = STATE(4170),
    [sym_reftype_expression] = STATE(4170),
    [sym_refvalue_expression] = STATE(4170),
    [sym_stackalloc_expression] = STATE(4170),
    [sym_range_expression] = STATE(4170),
    [sym_tuple_expression] = STATE(3480),
    [sym_literal] = STATE(4170),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4170),
    [sym_preproc_region] = STATE(2088),
    [sym_preproc_endregion] = STATE(2088),
    [sym_preproc_line] = STATE(2088),
    [sym_preproc_pragma] = STATE(2088),
    [sym_preproc_nullable] = STATE(2088),
    [sym_preproc_error] = STATE(2088),
    [sym_preproc_warning] = STATE(2088),
    [sym_preproc_define] = STATE(2088),
    [sym_preproc_undef] = STATE(2088),
    [aux_sym_class_declaration_repeat1] = STATE(3823),
    [aux_sym_lambda_expression_repeat1] = STATE(4240),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1751),
    [anon_sym_ref] = ACTIONS(1753),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_delegate] = ACTIONS(1329),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1755),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1333),
    [anon_sym_BANG] = ACTIONS(1759),
    [anon_sym_TILDE] = ACTIONS(1759),
    [anon_sym_PLUS_PLUS] = ACTIONS(1759),
    [anon_sym_DASH_DASH] = ACTIONS(1759),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1757),
    [anon_sym_DASH] = ACTIONS(1757),
    [anon_sym_STAR] = ACTIONS(1381),
    [anon_sym_CARET] = ACTIONS(1759),
    [anon_sym_AMP] = ACTIONS(1759),
    [anon_sym_this] = ACTIONS(1337),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1339),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1333),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1761),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1763),
    [anon_sym_DOT_DOT] = ACTIONS(1765),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1347),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(1349),
    [anon_sym___reftype] = ACTIONS(1351),
    [anon_sym___refvalue] = ACTIONS(1353),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2089] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6925),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2932),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7073),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4391),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3565),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7434),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9324),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(2089),
    [sym_preproc_endregion] = STATE(2089),
    [sym_preproc_line] = STATE(2089),
    [sym_preproc_pragma] = STATE(2089),
    [sym_preproc_nullable] = STATE(2089),
    [sym_preproc_error] = STATE(2089),
    [sym_preproc_warning] = STATE(2089),
    [sym_preproc_define] = STATE(2089),
    [sym_preproc_undef] = STATE(2089),
    [aux_sym_class_declaration_repeat1] = STATE(3842),
    [aux_sym_lambda_expression_repeat1] = STATE(4273),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1767),
    [anon_sym_ref] = ACTIONS(1769),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1771),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1775),
    [anon_sym_TILDE] = ACTIONS(1775),
    [anon_sym_PLUS_PLUS] = ACTIONS(1775),
    [anon_sym_DASH_DASH] = ACTIONS(1775),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1773),
    [anon_sym_DASH] = ACTIONS(1773),
    [anon_sym_STAR] = ACTIONS(1777),
    [anon_sym_CARET] = ACTIONS(1775),
    [anon_sym_AMP] = ACTIONS(1775),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(1779),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1781),
    [anon_sym_DOT_DOT] = ACTIONS(1783),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [2090] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7105),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5832),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2090),
    [sym_preproc_endregion] = STATE(2090),
    [sym_preproc_line] = STATE(2090),
    [sym_preproc_pragma] = STATE(2090),
    [sym_preproc_nullable] = STATE(2090),
    [sym_preproc_error] = STATE(2090),
    [sym_preproc_warning] = STATE(2090),
    [sym_preproc_define] = STATE(2090),
    [sym_preproc_undef] = STATE(2090),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2091] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6925),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2932),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7073),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4392),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3565),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7434),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9324),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(2091),
    [sym_preproc_endregion] = STATE(2091),
    [sym_preproc_line] = STATE(2091),
    [sym_preproc_pragma] = STATE(2091),
    [sym_preproc_nullable] = STATE(2091),
    [sym_preproc_error] = STATE(2091),
    [sym_preproc_warning] = STATE(2091),
    [sym_preproc_define] = STATE(2091),
    [sym_preproc_undef] = STATE(2091),
    [aux_sym_class_declaration_repeat1] = STATE(3842),
    [aux_sym_lambda_expression_repeat1] = STATE(4273),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1767),
    [anon_sym_ref] = ACTIONS(1769),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1771),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1775),
    [anon_sym_TILDE] = ACTIONS(1775),
    [anon_sym_PLUS_PLUS] = ACTIONS(1775),
    [anon_sym_DASH_DASH] = ACTIONS(1775),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1773),
    [anon_sym_DASH] = ACTIONS(1773),
    [anon_sym_STAR] = ACTIONS(1777),
    [anon_sym_CARET] = ACTIONS(1775),
    [anon_sym_AMP] = ACTIONS(1775),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(1779),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1781),
    [anon_sym_DOT_DOT] = ACTIONS(1783),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [2092] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6948),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2940),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7022),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4951),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3795),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7417),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9004),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2092),
    [sym_preproc_endregion] = STATE(2092),
    [sym_preproc_line] = STATE(2092),
    [sym_preproc_pragma] = STATE(2092),
    [sym_preproc_nullable] = STATE(2092),
    [sym_preproc_error] = STATE(2092),
    [sym_preproc_warning] = STATE(2092),
    [sym_preproc_define] = STATE(2092),
    [sym_preproc_undef] = STATE(2092),
    [aux_sym_class_declaration_repeat1] = STATE(3827),
    [aux_sym_lambda_expression_repeat1] = STATE(4246),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1893),
    [anon_sym_ref] = ACTIONS(1895),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1897),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1901),
    [anon_sym_TILDE] = ACTIONS(1901),
    [anon_sym_PLUS_PLUS] = ACTIONS(1901),
    [anon_sym_DASH_DASH] = ACTIONS(1901),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1899),
    [anon_sym_DASH] = ACTIONS(1899),
    [anon_sym_STAR] = ACTIONS(1903),
    [anon_sym_CARET] = ACTIONS(1901),
    [anon_sym_AMP] = ACTIONS(1901),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1905),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1907),
    [anon_sym_DOT_DOT] = ACTIONS(1909),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [2093] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6911),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2930),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7027),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4456),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3605),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7434),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9856),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(2093),
    [sym_preproc_endregion] = STATE(2093),
    [sym_preproc_line] = STATE(2093),
    [sym_preproc_pragma] = STATE(2093),
    [sym_preproc_nullable] = STATE(2093),
    [sym_preproc_error] = STATE(2093),
    [sym_preproc_warning] = STATE(2093),
    [sym_preproc_define] = STATE(2093),
    [sym_preproc_undef] = STATE(2093),
    [aux_sym_class_declaration_repeat1] = STATE(3828),
    [aux_sym_lambda_expression_repeat1] = STATE(4248),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1687),
    [anon_sym_ref] = ACTIONS(1689),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1695),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1701),
    [anon_sym_TILDE] = ACTIONS(1701),
    [anon_sym_PLUS_PLUS] = ACTIONS(1701),
    [anon_sym_DASH_DASH] = ACTIONS(1701),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1699),
    [anon_sym_DASH] = ACTIONS(1699),
    [anon_sym_STAR] = ACTIONS(1705),
    [anon_sym_CARET] = ACTIONS(1701),
    [anon_sym_AMP] = ACTIONS(1701),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(1715),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1717),
    [anon_sym_DOT_DOT] = ACTIONS(1719),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [2094] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3566),
    [sym__name] = STATE(6925),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2932),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7073),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4456),
    [sym_non_lvalue_expression] = STATE(4657),
    [sym_lvalue_expression] = STATE(3565),
    [sym__expression_statement_expression] = STATE(4616),
    [sym_assignment_expression] = STATE(4749),
    [sym_binary_expression] = STATE(4616),
    [sym_postfix_unary_expression] = STATE(4749),
    [sym_prefix_unary_expression] = STATE(4749),
    [sym__pointer_indirection_expression] = STATE(3579),
    [sym_query_expression] = STATE(4616),
    [sym_from_clause] = STATE(7434),
    [sym_conditional_expression] = STATE(4616),
    [sym_conditional_access_expression] = STATE(4616),
    [sym_as_expression] = STATE(4616),
    [sym_is_expression] = STATE(4616),
    [sym_is_pattern_expression] = STATE(4616),
    [sym_cast_expression] = STATE(4616),
    [sym_checked_expression] = STATE(4616),
    [sym_invocation_expression] = STATE(4749),
    [sym_switch_expression] = STATE(4616),
    [sym_await_expression] = STATE(4749),
    [sym_throw_expression] = STATE(4616),
    [sym_element_access_expression] = STATE(3579),
    [sym_interpolated_string_expression] = STATE(4616),
    [sym_member_access_expression] = STATE(3579),
    [sym_object_creation_expression] = STATE(4749),
    [sym_parenthesized_expression] = STATE(4749),
    [sym__parenthesized_lvalue_expression] = STATE(3579),
    [sym_lambda_expression] = STATE(4616),
    [sym__lambda_parameters] = STATE(9324),
    [sym_array_creation_expression] = STATE(4616),
    [sym_anonymous_method_expression] = STATE(4616),
    [sym_anonymous_object_creation_expression] = STATE(4616),
    [sym_implicit_array_creation_expression] = STATE(4616),
    [sym_implicit_object_creation_expression] = STATE(4616),
    [sym_implicit_stackalloc_expression] = STATE(4616),
    [sym_initializer_expression] = STATE(4616),
    [sym_default_expression] = STATE(4616),
    [sym_with_expression] = STATE(4616),
    [sym_sizeof_expression] = STATE(4616),
    [sym_typeof_expression] = STATE(4616),
    [sym_makeref_expression] = STATE(4616),
    [sym_ref_expression] = STATE(4616),
    [sym_reftype_expression] = STATE(4616),
    [sym_refvalue_expression] = STATE(4616),
    [sym_stackalloc_expression] = STATE(4616),
    [sym_range_expression] = STATE(4616),
    [sym_tuple_expression] = STATE(3579),
    [sym_literal] = STATE(4616),
    [sym_character_literal] = STATE(4626),
    [sym_string_literal] = STATE(4626),
    [sym_raw_string_literal] = STATE(4626),
    [sym_boolean_literal] = STATE(4626),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4616),
    [sym_preproc_region] = STATE(2094),
    [sym_preproc_endregion] = STATE(2094),
    [sym_preproc_line] = STATE(2094),
    [sym_preproc_pragma] = STATE(2094),
    [sym_preproc_nullable] = STATE(2094),
    [sym_preproc_error] = STATE(2094),
    [sym_preproc_warning] = STATE(2094),
    [sym_preproc_define] = STATE(2094),
    [sym_preproc_undef] = STATE(2094),
    [aux_sym_class_declaration_repeat1] = STATE(3842),
    [aux_sym_lambda_expression_repeat1] = STATE(4273),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1767),
    [anon_sym_ref] = ACTIONS(1769),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_delegate] = ACTIONS(1693),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1771),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1775),
    [anon_sym_TILDE] = ACTIONS(1775),
    [anon_sym_PLUS_PLUS] = ACTIONS(1775),
    [anon_sym_DASH_DASH] = ACTIONS(1775),
    [anon_sym_true] = ACTIONS(1703),
    [anon_sym_false] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1773),
    [anon_sym_DASH] = ACTIONS(1773),
    [anon_sym_STAR] = ACTIONS(1777),
    [anon_sym_CARET] = ACTIONS(1775),
    [anon_sym_AMP] = ACTIONS(1775),
    [anon_sym_this] = ACTIONS(1707),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1709),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1711),
    [anon_sym_unchecked] = ACTIONS(1697),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1713),
    [anon_sym_throw] = ACTIONS(1779),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1781),
    [anon_sym_DOT_DOT] = ACTIONS(1783),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1721),
    [anon_sym_sizeof] = ACTIONS(1723),
    [anon_sym_typeof] = ACTIONS(1725),
    [anon_sym___makeref] = ACTIONS(1727),
    [anon_sym___reftype] = ACTIONS(1729),
    [anon_sym___refvalue] = ACTIONS(1731),
    [sym_null_literal] = ACTIONS(1733),
    [anon_sym_SQUOTE] = ACTIONS(1735),
    [sym_integer_literal] = ACTIONS(1733),
    [sym_real_literal] = ACTIONS(1737),
    [anon_sym_DQUOTE] = ACTIONS(1739),
    [sym_verbatim_string_literal] = ACTIONS(1737),
    [aux_sym_preproc_if_token1] = ACTIONS(1741),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1743),
    [sym_interpolation_verbatim_start] = ACTIONS(1745),
    [sym_interpolation_raw_start] = ACTIONS(1747),
    [sym_raw_string_start] = ACTIONS(1749),
  },
  [2095] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7163),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4354),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4473),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9905),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2095),
    [sym_preproc_endregion] = STATE(2095),
    [sym_preproc_line] = STATE(2095),
    [sym_preproc_pragma] = STATE(2095),
    [sym_preproc_nullable] = STATE(2095),
    [sym_preproc_error] = STATE(2095),
    [sym_preproc_warning] = STATE(2095),
    [sym_preproc_define] = STATE(2095),
    [sym_preproc_undef] = STATE(2095),
    [aux_sym_class_declaration_repeat1] = STATE(3878),
    [aux_sym_lambda_expression_repeat1] = STATE(4331),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2055),
    [anon_sym_ref] = ACTIONS(2057),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2061),
    [anon_sym_TILDE] = ACTIONS(2061),
    [anon_sym_PLUS_PLUS] = ACTIONS(2061),
    [anon_sym_DASH_DASH] = ACTIONS(2061),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2059),
    [anon_sym_DASH] = ACTIONS(2059),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(2061),
    [anon_sym_AMP] = ACTIONS(2061),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2063),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2065),
    [anon_sym_DOT_DOT] = ACTIONS(2067),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2096] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6612),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2096),
    [sym_preproc_endregion] = STATE(2096),
    [sym_preproc_line] = STATE(2096),
    [sym_preproc_pragma] = STATE(2096),
    [sym_preproc_nullable] = STATE(2096),
    [sym_preproc_error] = STATE(2096),
    [sym_preproc_warning] = STATE(2096),
    [sym_preproc_define] = STATE(2096),
    [sym_preproc_undef] = STATE(2096),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2097] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6613),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2097),
    [sym_preproc_endregion] = STATE(2097),
    [sym_preproc_line] = STATE(2097),
    [sym_preproc_pragma] = STATE(2097),
    [sym_preproc_nullable] = STATE(2097),
    [sym_preproc_error] = STATE(2097),
    [sym_preproc_warning] = STATE(2097),
    [sym_preproc_define] = STATE(2097),
    [sym_preproc_undef] = STATE(2097),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2098] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6615),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2098),
    [sym_preproc_endregion] = STATE(2098),
    [sym_preproc_line] = STATE(2098),
    [sym_preproc_pragma] = STATE(2098),
    [sym_preproc_nullable] = STATE(2098),
    [sym_preproc_error] = STATE(2098),
    [sym_preproc_warning] = STATE(2098),
    [sym_preproc_define] = STATE(2098),
    [sym_preproc_undef] = STATE(2098),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2099] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6956),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6616),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9482),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2099),
    [sym_preproc_endregion] = STATE(2099),
    [sym_preproc_line] = STATE(2099),
    [sym_preproc_pragma] = STATE(2099),
    [sym_preproc_nullable] = STATE(2099),
    [sym_preproc_error] = STATE(2099),
    [sym_preproc_warning] = STATE(2099),
    [sym_preproc_define] = STATE(2099),
    [sym_preproc_undef] = STATE(2099),
    [aux_sym_class_declaration_repeat1] = STATE(3853),
    [aux_sym_lambda_expression_repeat1] = STATE(4299),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1497),
    [anon_sym_ref] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1505),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1507),
    [anon_sym_DOT_DOT] = ACTIONS(1509),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2100] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6618),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2100),
    [sym_preproc_endregion] = STATE(2100),
    [sym_preproc_line] = STATE(2100),
    [sym_preproc_pragma] = STATE(2100),
    [sym_preproc_nullable] = STATE(2100),
    [sym_preproc_error] = STATE(2100),
    [sym_preproc_warning] = STATE(2100),
    [sym_preproc_define] = STATE(2100),
    [sym_preproc_undef] = STATE(2100),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2101] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6619),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2101),
    [sym_preproc_endregion] = STATE(2101),
    [sym_preproc_line] = STATE(2101),
    [sym_preproc_pragma] = STATE(2101),
    [sym_preproc_nullable] = STATE(2101),
    [sym_preproc_error] = STATE(2101),
    [sym_preproc_warning] = STATE(2101),
    [sym_preproc_define] = STATE(2101),
    [sym_preproc_undef] = STATE(2101),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2102] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6620),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2102),
    [sym_preproc_endregion] = STATE(2102),
    [sym_preproc_line] = STATE(2102),
    [sym_preproc_pragma] = STATE(2102),
    [sym_preproc_nullable] = STATE(2102),
    [sym_preproc_error] = STATE(2102),
    [sym_preproc_warning] = STATE(2102),
    [sym_preproc_define] = STATE(2102),
    [sym_preproc_undef] = STATE(2102),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2103] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6684),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2103),
    [sym_preproc_endregion] = STATE(2103),
    [sym_preproc_line] = STATE(2103),
    [sym_preproc_pragma] = STATE(2103),
    [sym_preproc_nullable] = STATE(2103),
    [sym_preproc_error] = STATE(2103),
    [sym_preproc_warning] = STATE(2103),
    [sym_preproc_define] = STATE(2103),
    [sym_preproc_undef] = STATE(2103),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2104] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6948),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2940),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7022),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4949),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3795),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7417),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9004),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2104),
    [sym_preproc_endregion] = STATE(2104),
    [sym_preproc_line] = STATE(2104),
    [sym_preproc_pragma] = STATE(2104),
    [sym_preproc_nullable] = STATE(2104),
    [sym_preproc_error] = STATE(2104),
    [sym_preproc_warning] = STATE(2104),
    [sym_preproc_define] = STATE(2104),
    [sym_preproc_undef] = STATE(2104),
    [aux_sym_class_declaration_repeat1] = STATE(3827),
    [aux_sym_lambda_expression_repeat1] = STATE(4246),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1893),
    [anon_sym_ref] = ACTIONS(1895),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1897),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1901),
    [anon_sym_TILDE] = ACTIONS(1901),
    [anon_sym_PLUS_PLUS] = ACTIONS(1901),
    [anon_sym_DASH_DASH] = ACTIONS(1901),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1899),
    [anon_sym_DASH] = ACTIONS(1899),
    [anon_sym_STAR] = ACTIONS(1903),
    [anon_sym_CARET] = ACTIONS(1901),
    [anon_sym_AMP] = ACTIONS(1901),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1905),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1907),
    [anon_sym_DOT_DOT] = ACTIONS(1909),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [2105] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6536),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2105),
    [sym_preproc_endregion] = STATE(2105),
    [sym_preproc_line] = STATE(2105),
    [sym_preproc_pragma] = STATE(2105),
    [sym_preproc_nullable] = STATE(2105),
    [sym_preproc_error] = STATE(2105),
    [sym_preproc_warning] = STATE(2105),
    [sym_preproc_define] = STATE(2105),
    [sym_preproc_undef] = STATE(2105),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2106] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6537),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2106),
    [sym_preproc_endregion] = STATE(2106),
    [sym_preproc_line] = STATE(2106),
    [sym_preproc_pragma] = STATE(2106),
    [sym_preproc_nullable] = STATE(2106),
    [sym_preproc_error] = STATE(2106),
    [sym_preproc_warning] = STATE(2106),
    [sym_preproc_define] = STATE(2106),
    [sym_preproc_undef] = STATE(2106),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2107] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6342),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2107),
    [sym_preproc_endregion] = STATE(2107),
    [sym_preproc_line] = STATE(2107),
    [sym_preproc_pragma] = STATE(2107),
    [sym_preproc_nullable] = STATE(2107),
    [sym_preproc_error] = STATE(2107),
    [sym_preproc_warning] = STATE(2107),
    [sym_preproc_define] = STATE(2107),
    [sym_preproc_undef] = STATE(2107),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2108] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7105),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5834),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2108),
    [sym_preproc_endregion] = STATE(2108),
    [sym_preproc_line] = STATE(2108),
    [sym_preproc_pragma] = STATE(2108),
    [sym_preproc_nullable] = STATE(2108),
    [sym_preproc_error] = STATE(2108),
    [sym_preproc_warning] = STATE(2108),
    [sym_preproc_define] = STATE(2108),
    [sym_preproc_undef] = STATE(2108),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2109] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6344),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7139),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4354),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4468),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7421),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9768),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2109),
    [sym_preproc_endregion] = STATE(2109),
    [sym_preproc_line] = STATE(2109),
    [sym_preproc_pragma] = STATE(2109),
    [sym_preproc_nullable] = STATE(2109),
    [sym_preproc_error] = STATE(2109),
    [sym_preproc_warning] = STATE(2109),
    [sym_preproc_define] = STATE(2109),
    [sym_preproc_undef] = STATE(2109),
    [aux_sym_class_declaration_repeat1] = STATE(3872),
    [aux_sym_lambda_expression_repeat1] = STATE(4306),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2009),
    [anon_sym_ref] = ACTIONS(2011),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1111),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2015),
    [anon_sym_TILDE] = ACTIONS(2015),
    [anon_sym_PLUS_PLUS] = ACTIONS(2015),
    [anon_sym_DASH_DASH] = ACTIONS(2015),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2013),
    [anon_sym_DASH] = ACTIONS(2013),
    [anon_sym_STAR] = ACTIONS(1309),
    [anon_sym_CARET] = ACTIONS(2015),
    [anon_sym_AMP] = ACTIONS(2015),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1313),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1315),
    [anon_sym_DOT_DOT] = ACTIONS(1317),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2110] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6545),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2110),
    [sym_preproc_endregion] = STATE(2110),
    [sym_preproc_line] = STATE(2110),
    [sym_preproc_pragma] = STATE(2110),
    [sym_preproc_nullable] = STATE(2110),
    [sym_preproc_error] = STATE(2110),
    [sym_preproc_warning] = STATE(2110),
    [sym_preproc_define] = STATE(2110),
    [sym_preproc_undef] = STATE(2110),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2111] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6558),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2111),
    [sym_preproc_endregion] = STATE(2111),
    [sym_preproc_line] = STATE(2111),
    [sym_preproc_pragma] = STATE(2111),
    [sym_preproc_nullable] = STATE(2111),
    [sym_preproc_error] = STATE(2111),
    [sym_preproc_warning] = STATE(2111),
    [sym_preproc_define] = STATE(2111),
    [sym_preproc_undef] = STATE(2111),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2112] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6565),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2112),
    [sym_preproc_endregion] = STATE(2112),
    [sym_preproc_line] = STATE(2112),
    [sym_preproc_pragma] = STATE(2112),
    [sym_preproc_nullable] = STATE(2112),
    [sym_preproc_error] = STATE(2112),
    [sym_preproc_warning] = STATE(2112),
    [sym_preproc_define] = STATE(2112),
    [sym_preproc_undef] = STATE(2112),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2113] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6956),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6574),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9482),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2113),
    [sym_preproc_endregion] = STATE(2113),
    [sym_preproc_line] = STATE(2113),
    [sym_preproc_pragma] = STATE(2113),
    [sym_preproc_nullable] = STATE(2113),
    [sym_preproc_error] = STATE(2113),
    [sym_preproc_warning] = STATE(2113),
    [sym_preproc_define] = STATE(2113),
    [sym_preproc_undef] = STATE(2113),
    [aux_sym_class_declaration_repeat1] = STATE(3853),
    [aux_sym_lambda_expression_repeat1] = STATE(4299),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1497),
    [anon_sym_ref] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1505),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1507),
    [anon_sym_DOT_DOT] = ACTIONS(1509),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2114] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6628),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2114),
    [sym_preproc_endregion] = STATE(2114),
    [sym_preproc_line] = STATE(2114),
    [sym_preproc_pragma] = STATE(2114),
    [sym_preproc_nullable] = STATE(2114),
    [sym_preproc_error] = STATE(2114),
    [sym_preproc_warning] = STATE(2114),
    [sym_preproc_define] = STATE(2114),
    [sym_preproc_undef] = STATE(2114),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2115] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6631),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2115),
    [sym_preproc_endregion] = STATE(2115),
    [sym_preproc_line] = STATE(2115),
    [sym_preproc_pragma] = STATE(2115),
    [sym_preproc_nullable] = STATE(2115),
    [sym_preproc_error] = STATE(2115),
    [sym_preproc_warning] = STATE(2115),
    [sym_preproc_define] = STATE(2115),
    [sym_preproc_undef] = STATE(2115),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2116] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6635),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2116),
    [sym_preproc_endregion] = STATE(2116),
    [sym_preproc_line] = STATE(2116),
    [sym_preproc_pragma] = STATE(2116),
    [sym_preproc_nullable] = STATE(2116),
    [sym_preproc_error] = STATE(2116),
    [sym_preproc_warning] = STATE(2116),
    [sym_preproc_define] = STATE(2116),
    [sym_preproc_undef] = STATE(2116),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2117] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6456),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2117),
    [sym_preproc_endregion] = STATE(2117),
    [sym_preproc_line] = STATE(2117),
    [sym_preproc_pragma] = STATE(2117),
    [sym_preproc_nullable] = STATE(2117),
    [sym_preproc_error] = STATE(2117),
    [sym_preproc_warning] = STATE(2117),
    [sym_preproc_define] = STATE(2117),
    [sym_preproc_undef] = STATE(2117),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2118] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6481),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2118),
    [sym_preproc_endregion] = STATE(2118),
    [sym_preproc_line] = STATE(2118),
    [sym_preproc_pragma] = STATE(2118),
    [sym_preproc_nullable] = STATE(2118),
    [sym_preproc_error] = STATE(2118),
    [sym_preproc_warning] = STATE(2118),
    [sym_preproc_define] = STATE(2118),
    [sym_preproc_undef] = STATE(2118),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2119] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6483),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2119),
    [sym_preproc_endregion] = STATE(2119),
    [sym_preproc_line] = STATE(2119),
    [sym_preproc_pragma] = STATE(2119),
    [sym_preproc_nullable] = STATE(2119),
    [sym_preproc_error] = STATE(2119),
    [sym_preproc_warning] = STATE(2119),
    [sym_preproc_define] = STATE(2119),
    [sym_preproc_undef] = STATE(2119),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2120] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6486),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2120),
    [sym_preproc_endregion] = STATE(2120),
    [sym_preproc_line] = STATE(2120),
    [sym_preproc_pragma] = STATE(2120),
    [sym_preproc_nullable] = STATE(2120),
    [sym_preproc_error] = STATE(2120),
    [sym_preproc_warning] = STATE(2120),
    [sym_preproc_define] = STATE(2120),
    [sym_preproc_undef] = STATE(2120),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2121] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7105),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5837),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2121),
    [sym_preproc_endregion] = STATE(2121),
    [sym_preproc_line] = STATE(2121),
    [sym_preproc_pragma] = STATE(2121),
    [sym_preproc_nullable] = STATE(2121),
    [sym_preproc_error] = STATE(2121),
    [sym_preproc_warning] = STATE(2121),
    [sym_preproc_define] = STATE(2121),
    [sym_preproc_undef] = STATE(2121),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2122] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6422),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2122),
    [sym_preproc_endregion] = STATE(2122),
    [sym_preproc_line] = STATE(2122),
    [sym_preproc_pragma] = STATE(2122),
    [sym_preproc_nullable] = STATE(2122),
    [sym_preproc_error] = STATE(2122),
    [sym_preproc_warning] = STATE(2122),
    [sym_preproc_define] = STATE(2122),
    [sym_preproc_undef] = STATE(2122),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2123] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6423),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2123),
    [sym_preproc_endregion] = STATE(2123),
    [sym_preproc_line] = STATE(2123),
    [sym_preproc_pragma] = STATE(2123),
    [sym_preproc_nullable] = STATE(2123),
    [sym_preproc_error] = STATE(2123),
    [sym_preproc_warning] = STATE(2123),
    [sym_preproc_define] = STATE(2123),
    [sym_preproc_undef] = STATE(2123),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2124] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6425),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2124),
    [sym_preproc_endregion] = STATE(2124),
    [sym_preproc_line] = STATE(2124),
    [sym_preproc_pragma] = STATE(2124),
    [sym_preproc_nullable] = STATE(2124),
    [sym_preproc_error] = STATE(2124),
    [sym_preproc_warning] = STATE(2124),
    [sym_preproc_define] = STATE(2124),
    [sym_preproc_undef] = STATE(2124),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2125] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7105),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5840),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2125),
    [sym_preproc_endregion] = STATE(2125),
    [sym_preproc_line] = STATE(2125),
    [sym_preproc_pragma] = STATE(2125),
    [sym_preproc_nullable] = STATE(2125),
    [sym_preproc_error] = STATE(2125),
    [sym_preproc_warning] = STATE(2125),
    [sym_preproc_define] = STATE(2125),
    [sym_preproc_undef] = STATE(2125),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2126] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6654),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2126),
    [sym_preproc_endregion] = STATE(2126),
    [sym_preproc_line] = STATE(2126),
    [sym_preproc_pragma] = STATE(2126),
    [sym_preproc_nullable] = STATE(2126),
    [sym_preproc_error] = STATE(2126),
    [sym_preproc_warning] = STATE(2126),
    [sym_preproc_define] = STATE(2126),
    [sym_preproc_undef] = STATE(2126),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2127] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6655),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2127),
    [sym_preproc_endregion] = STATE(2127),
    [sym_preproc_line] = STATE(2127),
    [sym_preproc_pragma] = STATE(2127),
    [sym_preproc_nullable] = STATE(2127),
    [sym_preproc_error] = STATE(2127),
    [sym_preproc_warning] = STATE(2127),
    [sym_preproc_define] = STATE(2127),
    [sym_preproc_undef] = STATE(2127),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2128] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6656),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2128),
    [sym_preproc_endregion] = STATE(2128),
    [sym_preproc_line] = STATE(2128),
    [sym_preproc_pragma] = STATE(2128),
    [sym_preproc_nullable] = STATE(2128),
    [sym_preproc_error] = STATE(2128),
    [sym_preproc_warning] = STATE(2128),
    [sym_preproc_define] = STATE(2128),
    [sym_preproc_undef] = STATE(2128),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2129] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7105),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5852),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2129),
    [sym_preproc_endregion] = STATE(2129),
    [sym_preproc_line] = STATE(2129),
    [sym_preproc_pragma] = STATE(2129),
    [sym_preproc_nullable] = STATE(2129),
    [sym_preproc_error] = STATE(2129),
    [sym_preproc_warning] = STATE(2129),
    [sym_preproc_define] = STATE(2129),
    [sym_preproc_undef] = STATE(2129),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2130] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7105),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5853),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2130),
    [sym_preproc_endregion] = STATE(2130),
    [sym_preproc_line] = STATE(2130),
    [sym_preproc_pragma] = STATE(2130),
    [sym_preproc_nullable] = STATE(2130),
    [sym_preproc_error] = STATE(2130),
    [sym_preproc_warning] = STATE(2130),
    [sym_preproc_define] = STATE(2130),
    [sym_preproc_undef] = STATE(2130),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2131] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7105),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5854),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4360),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9692),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2131),
    [sym_preproc_endregion] = STATE(2131),
    [sym_preproc_line] = STATE(2131),
    [sym_preproc_pragma] = STATE(2131),
    [sym_preproc_nullable] = STATE(2131),
    [sym_preproc_error] = STATE(2131),
    [sym_preproc_warning] = STATE(2131),
    [sym_preproc_define] = STATE(2131),
    [sym_preproc_undef] = STATE(2131),
    [aux_sym_class_declaration_repeat1] = STATE(3865),
    [aux_sym_lambda_expression_repeat1] = STATE(4095),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(43),
    [anon_sym_ref] = ACTIONS(733),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1567),
    [anon_sym_TILDE] = ACTIONS(1567),
    [anon_sym_PLUS_PLUS] = ACTIONS(1567),
    [anon_sym_DASH_DASH] = ACTIONS(1567),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1565),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(1567),
    [anon_sym_AMP] = ACTIONS(1567),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1569),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1571),
    [anon_sym_DOT_DOT] = ACTIONS(123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2132] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6948),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2940),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6999),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5135),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(3857),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7444),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9574),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2132),
    [sym_preproc_endregion] = STATE(2132),
    [sym_preproc_line] = STATE(2132),
    [sym_preproc_pragma] = STATE(2132),
    [sym_preproc_nullable] = STATE(2132),
    [sym_preproc_error] = STATE(2132),
    [sym_preproc_warning] = STATE(2132),
    [sym_preproc_define] = STATE(2132),
    [sym_preproc_undef] = STATE(2132),
    [aux_sym_class_declaration_repeat1] = STATE(3854),
    [aux_sym_lambda_expression_repeat1] = STATE(4136),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2111),
    [anon_sym_ref] = ACTIONS(2113),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1897),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2117),
    [anon_sym_TILDE] = ACTIONS(2117),
    [anon_sym_PLUS_PLUS] = ACTIONS(2117),
    [anon_sym_DASH_DASH] = ACTIONS(2117),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(2115),
    [anon_sym_DASH] = ACTIONS(2115),
    [anon_sym_STAR] = ACTIONS(1903),
    [anon_sym_CARET] = ACTIONS(2117),
    [anon_sym_AMP] = ACTIONS(2117),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(2119),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2121),
    [anon_sym_DOT_DOT] = ACTIONS(2123),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [2133] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7163),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6597),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4473),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9905),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2133),
    [sym_preproc_endregion] = STATE(2133),
    [sym_preproc_line] = STATE(2133),
    [sym_preproc_pragma] = STATE(2133),
    [sym_preproc_nullable] = STATE(2133),
    [sym_preproc_error] = STATE(2133),
    [sym_preproc_warning] = STATE(2133),
    [sym_preproc_define] = STATE(2133),
    [sym_preproc_undef] = STATE(2133),
    [aux_sym_class_declaration_repeat1] = STATE(3878),
    [aux_sym_lambda_expression_repeat1] = STATE(4331),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2055),
    [anon_sym_ref] = ACTIONS(2057),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2061),
    [anon_sym_TILDE] = ACTIONS(2061),
    [anon_sym_PLUS_PLUS] = ACTIONS(2061),
    [anon_sym_DASH_DASH] = ACTIONS(2061),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2059),
    [anon_sym_DASH] = ACTIONS(2059),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(2061),
    [anon_sym_AMP] = ACTIONS(2061),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2063),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2065),
    [anon_sym_DOT_DOT] = ACTIONS(2067),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2134] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7163),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6598),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4473),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9905),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2134),
    [sym_preproc_endregion] = STATE(2134),
    [sym_preproc_line] = STATE(2134),
    [sym_preproc_pragma] = STATE(2134),
    [sym_preproc_nullable] = STATE(2134),
    [sym_preproc_error] = STATE(2134),
    [sym_preproc_warning] = STATE(2134),
    [sym_preproc_define] = STATE(2134),
    [sym_preproc_undef] = STATE(2134),
    [aux_sym_class_declaration_repeat1] = STATE(3878),
    [aux_sym_lambda_expression_repeat1] = STATE(4331),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2055),
    [anon_sym_ref] = ACTIONS(2057),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2061),
    [anon_sym_TILDE] = ACTIONS(2061),
    [anon_sym_PLUS_PLUS] = ACTIONS(2061),
    [anon_sym_DASH_DASH] = ACTIONS(2061),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2059),
    [anon_sym_DASH] = ACTIONS(2059),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(2061),
    [anon_sym_AMP] = ACTIONS(2061),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2063),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2065),
    [anon_sym_DOT_DOT] = ACTIONS(2067),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2135] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7163),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6599),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4473),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9905),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2135),
    [sym_preproc_endregion] = STATE(2135),
    [sym_preproc_line] = STATE(2135),
    [sym_preproc_pragma] = STATE(2135),
    [sym_preproc_nullable] = STATE(2135),
    [sym_preproc_error] = STATE(2135),
    [sym_preproc_warning] = STATE(2135),
    [sym_preproc_define] = STATE(2135),
    [sym_preproc_undef] = STATE(2135),
    [aux_sym_class_declaration_repeat1] = STATE(3878),
    [aux_sym_lambda_expression_repeat1] = STATE(4331),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2055),
    [anon_sym_ref] = ACTIONS(2057),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2061),
    [anon_sym_TILDE] = ACTIONS(2061),
    [anon_sym_PLUS_PLUS] = ACTIONS(2061),
    [anon_sym_DASH_DASH] = ACTIONS(2061),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2059),
    [anon_sym_DASH] = ACTIONS(2059),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(2061),
    [anon_sym_AMP] = ACTIONS(2061),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2063),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2065),
    [anon_sym_DOT_DOT] = ACTIONS(2067),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2136] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7163),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6395),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4473),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9905),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2136),
    [sym_preproc_endregion] = STATE(2136),
    [sym_preproc_line] = STATE(2136),
    [sym_preproc_pragma] = STATE(2136),
    [sym_preproc_nullable] = STATE(2136),
    [sym_preproc_error] = STATE(2136),
    [sym_preproc_warning] = STATE(2136),
    [sym_preproc_define] = STATE(2136),
    [sym_preproc_undef] = STATE(2136),
    [aux_sym_class_declaration_repeat1] = STATE(3878),
    [aux_sym_lambda_expression_repeat1] = STATE(4331),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2055),
    [anon_sym_ref] = ACTIONS(2057),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2061),
    [anon_sym_TILDE] = ACTIONS(2061),
    [anon_sym_PLUS_PLUS] = ACTIONS(2061),
    [anon_sym_DASH_DASH] = ACTIONS(2061),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2059),
    [anon_sym_DASH] = ACTIONS(2059),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(2061),
    [anon_sym_AMP] = ACTIONS(2061),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2063),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2065),
    [anon_sym_DOT_DOT] = ACTIONS(2067),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2137] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7163),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6396),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4473),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9905),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2137),
    [sym_preproc_endregion] = STATE(2137),
    [sym_preproc_line] = STATE(2137),
    [sym_preproc_pragma] = STATE(2137),
    [sym_preproc_nullable] = STATE(2137),
    [sym_preproc_error] = STATE(2137),
    [sym_preproc_warning] = STATE(2137),
    [sym_preproc_define] = STATE(2137),
    [sym_preproc_undef] = STATE(2137),
    [aux_sym_class_declaration_repeat1] = STATE(3878),
    [aux_sym_lambda_expression_repeat1] = STATE(4331),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2055),
    [anon_sym_ref] = ACTIONS(2057),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2061),
    [anon_sym_TILDE] = ACTIONS(2061),
    [anon_sym_PLUS_PLUS] = ACTIONS(2061),
    [anon_sym_DASH_DASH] = ACTIONS(2061),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2059),
    [anon_sym_DASH] = ACTIONS(2059),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(2061),
    [anon_sym_AMP] = ACTIONS(2061),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2063),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2065),
    [anon_sym_DOT_DOT] = ACTIONS(2067),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2138] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7163),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6397),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4473),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9905),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2138),
    [sym_preproc_endregion] = STATE(2138),
    [sym_preproc_line] = STATE(2138),
    [sym_preproc_pragma] = STATE(2138),
    [sym_preproc_nullable] = STATE(2138),
    [sym_preproc_error] = STATE(2138),
    [sym_preproc_warning] = STATE(2138),
    [sym_preproc_define] = STATE(2138),
    [sym_preproc_undef] = STATE(2138),
    [aux_sym_class_declaration_repeat1] = STATE(3878),
    [aux_sym_lambda_expression_repeat1] = STATE(4331),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2055),
    [anon_sym_ref] = ACTIONS(2057),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2061),
    [anon_sym_TILDE] = ACTIONS(2061),
    [anon_sym_PLUS_PLUS] = ACTIONS(2061),
    [anon_sym_DASH_DASH] = ACTIONS(2061),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2059),
    [anon_sym_DASH] = ACTIONS(2059),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(2061),
    [anon_sym_AMP] = ACTIONS(2061),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2063),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2065),
    [anon_sym_DOT_DOT] = ACTIONS(2067),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2139] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7163),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6600),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4473),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9905),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2139),
    [sym_preproc_endregion] = STATE(2139),
    [sym_preproc_line] = STATE(2139),
    [sym_preproc_pragma] = STATE(2139),
    [sym_preproc_nullable] = STATE(2139),
    [sym_preproc_error] = STATE(2139),
    [sym_preproc_warning] = STATE(2139),
    [sym_preproc_define] = STATE(2139),
    [sym_preproc_undef] = STATE(2139),
    [aux_sym_class_declaration_repeat1] = STATE(3878),
    [aux_sym_lambda_expression_repeat1] = STATE(4331),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2055),
    [anon_sym_ref] = ACTIONS(2057),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2061),
    [anon_sym_TILDE] = ACTIONS(2061),
    [anon_sym_PLUS_PLUS] = ACTIONS(2061),
    [anon_sym_DASH_DASH] = ACTIONS(2061),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2059),
    [anon_sym_DASH] = ACTIONS(2059),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(2061),
    [anon_sym_AMP] = ACTIONS(2061),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2063),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2065),
    [anon_sym_DOT_DOT] = ACTIONS(2067),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2140] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7163),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6398),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4473),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9905),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2140),
    [sym_preproc_endregion] = STATE(2140),
    [sym_preproc_line] = STATE(2140),
    [sym_preproc_pragma] = STATE(2140),
    [sym_preproc_nullable] = STATE(2140),
    [sym_preproc_error] = STATE(2140),
    [sym_preproc_warning] = STATE(2140),
    [sym_preproc_define] = STATE(2140),
    [sym_preproc_undef] = STATE(2140),
    [aux_sym_class_declaration_repeat1] = STATE(3878),
    [aux_sym_lambda_expression_repeat1] = STATE(4331),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2055),
    [anon_sym_ref] = ACTIONS(2057),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2061),
    [anon_sym_TILDE] = ACTIONS(2061),
    [anon_sym_PLUS_PLUS] = ACTIONS(2061),
    [anon_sym_DASH_DASH] = ACTIONS(2061),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2059),
    [anon_sym_DASH] = ACTIONS(2059),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(2061),
    [anon_sym_AMP] = ACTIONS(2061),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2063),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2065),
    [anon_sym_DOT_DOT] = ACTIONS(2067),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2141] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7163),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6399),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4473),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9905),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2141),
    [sym_preproc_endregion] = STATE(2141),
    [sym_preproc_line] = STATE(2141),
    [sym_preproc_pragma] = STATE(2141),
    [sym_preproc_nullable] = STATE(2141),
    [sym_preproc_error] = STATE(2141),
    [sym_preproc_warning] = STATE(2141),
    [sym_preproc_define] = STATE(2141),
    [sym_preproc_undef] = STATE(2141),
    [aux_sym_class_declaration_repeat1] = STATE(3878),
    [aux_sym_lambda_expression_repeat1] = STATE(4331),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2055),
    [anon_sym_ref] = ACTIONS(2057),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2061),
    [anon_sym_TILDE] = ACTIONS(2061),
    [anon_sym_PLUS_PLUS] = ACTIONS(2061),
    [anon_sym_DASH_DASH] = ACTIONS(2061),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2059),
    [anon_sym_DASH] = ACTIONS(2059),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(2061),
    [anon_sym_AMP] = ACTIONS(2061),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2063),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2065),
    [anon_sym_DOT_DOT] = ACTIONS(2067),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2142] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7163),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6400),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4473),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9905),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2142),
    [sym_preproc_endregion] = STATE(2142),
    [sym_preproc_line] = STATE(2142),
    [sym_preproc_pragma] = STATE(2142),
    [sym_preproc_nullable] = STATE(2142),
    [sym_preproc_error] = STATE(2142),
    [sym_preproc_warning] = STATE(2142),
    [sym_preproc_define] = STATE(2142),
    [sym_preproc_undef] = STATE(2142),
    [aux_sym_class_declaration_repeat1] = STATE(3878),
    [aux_sym_lambda_expression_repeat1] = STATE(4331),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2055),
    [anon_sym_ref] = ACTIONS(2057),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2061),
    [anon_sym_TILDE] = ACTIONS(2061),
    [anon_sym_PLUS_PLUS] = ACTIONS(2061),
    [anon_sym_DASH_DASH] = ACTIONS(2061),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2059),
    [anon_sym_DASH] = ACTIONS(2059),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(2061),
    [anon_sym_AMP] = ACTIONS(2061),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2063),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2065),
    [anon_sym_DOT_DOT] = ACTIONS(2067),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2143] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7163),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6401),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4473),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9905),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2143),
    [sym_preproc_endregion] = STATE(2143),
    [sym_preproc_line] = STATE(2143),
    [sym_preproc_pragma] = STATE(2143),
    [sym_preproc_nullable] = STATE(2143),
    [sym_preproc_error] = STATE(2143),
    [sym_preproc_warning] = STATE(2143),
    [sym_preproc_define] = STATE(2143),
    [sym_preproc_undef] = STATE(2143),
    [aux_sym_class_declaration_repeat1] = STATE(3878),
    [aux_sym_lambda_expression_repeat1] = STATE(4331),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2055),
    [anon_sym_ref] = ACTIONS(2057),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2061),
    [anon_sym_TILDE] = ACTIONS(2061),
    [anon_sym_PLUS_PLUS] = ACTIONS(2061),
    [anon_sym_DASH_DASH] = ACTIONS(2061),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2059),
    [anon_sym_DASH] = ACTIONS(2059),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(2061),
    [anon_sym_AMP] = ACTIONS(2061),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2063),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2065),
    [anon_sym_DOT_DOT] = ACTIONS(2067),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2144] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6920),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2942),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7143),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6402),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4489),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7426),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9002),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2144),
    [sym_preproc_endregion] = STATE(2144),
    [sym_preproc_line] = STATE(2144),
    [sym_preproc_pragma] = STATE(2144),
    [sym_preproc_nullable] = STATE(2144),
    [sym_preproc_error] = STATE(2144),
    [sym_preproc_warning] = STATE(2144),
    [sym_preproc_define] = STATE(2144),
    [sym_preproc_undef] = STATE(2144),
    [aux_sym_class_declaration_repeat1] = STATE(3809),
    [aux_sym_lambda_expression_repeat1] = STATE(4308),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2189),
    [anon_sym_ref] = ACTIONS(2191),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2193),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2197),
    [anon_sym_TILDE] = ACTIONS(2197),
    [anon_sym_PLUS_PLUS] = ACTIONS(2197),
    [anon_sym_DASH_DASH] = ACTIONS(2197),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2195),
    [anon_sym_DASH] = ACTIONS(2195),
    [anon_sym_STAR] = ACTIONS(2199),
    [anon_sym_CARET] = ACTIONS(2197),
    [anon_sym_AMP] = ACTIONS(2197),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2201),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2203),
    [anon_sym_DOT_DOT] = ACTIONS(2205),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2145] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7163),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4338),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4473),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9905),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2145),
    [sym_preproc_endregion] = STATE(2145),
    [sym_preproc_line] = STATE(2145),
    [sym_preproc_pragma] = STATE(2145),
    [sym_preproc_nullable] = STATE(2145),
    [sym_preproc_error] = STATE(2145),
    [sym_preproc_warning] = STATE(2145),
    [sym_preproc_define] = STATE(2145),
    [sym_preproc_undef] = STATE(2145),
    [aux_sym_class_declaration_repeat1] = STATE(3878),
    [aux_sym_lambda_expression_repeat1] = STATE(4331),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2055),
    [anon_sym_ref] = ACTIONS(2057),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2061),
    [anon_sym_TILDE] = ACTIONS(2061),
    [anon_sym_PLUS_PLUS] = ACTIONS(2061),
    [anon_sym_DASH_DASH] = ACTIONS(2061),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2059),
    [anon_sym_DASH] = ACTIONS(2059),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(2061),
    [anon_sym_AMP] = ACTIONS(2061),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2063),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2065),
    [anon_sym_DOT_DOT] = ACTIONS(2067),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2146] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6407),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2146),
    [sym_preproc_endregion] = STATE(2146),
    [sym_preproc_line] = STATE(2146),
    [sym_preproc_pragma] = STATE(2146),
    [sym_preproc_nullable] = STATE(2146),
    [sym_preproc_error] = STATE(2146),
    [sym_preproc_warning] = STATE(2146),
    [sym_preproc_define] = STATE(2146),
    [sym_preproc_undef] = STATE(2146),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2147] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7163),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6409),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4473),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9905),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2147),
    [sym_preproc_endregion] = STATE(2147),
    [sym_preproc_line] = STATE(2147),
    [sym_preproc_pragma] = STATE(2147),
    [sym_preproc_nullable] = STATE(2147),
    [sym_preproc_error] = STATE(2147),
    [sym_preproc_warning] = STATE(2147),
    [sym_preproc_define] = STATE(2147),
    [sym_preproc_undef] = STATE(2147),
    [aux_sym_class_declaration_repeat1] = STATE(3878),
    [aux_sym_lambda_expression_repeat1] = STATE(4331),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2055),
    [anon_sym_ref] = ACTIONS(2057),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2061),
    [anon_sym_TILDE] = ACTIONS(2061),
    [anon_sym_PLUS_PLUS] = ACTIONS(2061),
    [anon_sym_DASH_DASH] = ACTIONS(2061),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2059),
    [anon_sym_DASH] = ACTIONS(2059),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(2061),
    [anon_sym_AMP] = ACTIONS(2061),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2063),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2065),
    [anon_sym_DOT_DOT] = ACTIONS(2067),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2148] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6921),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2873),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7036),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5165),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4038),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7429),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9220),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(2148),
    [sym_preproc_endregion] = STATE(2148),
    [sym_preproc_line] = STATE(2148),
    [sym_preproc_pragma] = STATE(2148),
    [sym_preproc_nullable] = STATE(2148),
    [sym_preproc_error] = STATE(2148),
    [sym_preproc_warning] = STATE(2148),
    [sym_preproc_define] = STATE(2148),
    [sym_preproc_undef] = STATE(2148),
    [aux_sym_class_declaration_repeat1] = STATE(3830),
    [aux_sym_lambda_expression_repeat1] = STATE(4255),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1407),
    [anon_sym_ref] = ACTIONS(1409),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1415),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1421),
    [anon_sym_TILDE] = ACTIONS(1421),
    [anon_sym_PLUS_PLUS] = ACTIONS(1421),
    [anon_sym_DASH_DASH] = ACTIONS(1421),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1419),
    [anon_sym_DASH] = ACTIONS(1419),
    [anon_sym_STAR] = ACTIONS(1425),
    [anon_sym_CARET] = ACTIONS(1421),
    [anon_sym_AMP] = ACTIONS(1421),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1439),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1441),
    [anon_sym_DOT_DOT] = ACTIONS(1443),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [2149] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6937),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2861),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7081),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5182),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(3898),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7429),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9350),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(2149),
    [sym_preproc_endregion] = STATE(2149),
    [sym_preproc_line] = STATE(2149),
    [sym_preproc_pragma] = STATE(2149),
    [sym_preproc_nullable] = STATE(2149),
    [sym_preproc_error] = STATE(2149),
    [sym_preproc_warning] = STATE(2149),
    [sym_preproc_define] = STATE(2149),
    [sym_preproc_undef] = STATE(2149),
    [aux_sym_class_declaration_repeat1] = STATE(3879),
    [aux_sym_lambda_expression_repeat1] = STATE(4092),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1477),
    [anon_sym_ref] = ACTIONS(1479),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1481),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1485),
    [anon_sym_TILDE] = ACTIONS(1485),
    [anon_sym_PLUS_PLUS] = ACTIONS(1485),
    [anon_sym_DASH_DASH] = ACTIONS(1485),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1483),
    [anon_sym_DASH] = ACTIONS(1483),
    [anon_sym_STAR] = ACTIONS(1487),
    [anon_sym_CARET] = ACTIONS(1485),
    [anon_sym_AMP] = ACTIONS(1485),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1489),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1491),
    [anon_sym_DOT_DOT] = ACTIONS(1493),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [2150] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6937),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2861),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7081),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5229),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(3898),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7429),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9350),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(2150),
    [sym_preproc_endregion] = STATE(2150),
    [sym_preproc_line] = STATE(2150),
    [sym_preproc_pragma] = STATE(2150),
    [sym_preproc_nullable] = STATE(2150),
    [sym_preproc_error] = STATE(2150),
    [sym_preproc_warning] = STATE(2150),
    [sym_preproc_define] = STATE(2150),
    [sym_preproc_undef] = STATE(2150),
    [aux_sym_class_declaration_repeat1] = STATE(3879),
    [aux_sym_lambda_expression_repeat1] = STATE(4092),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1477),
    [anon_sym_ref] = ACTIONS(1479),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1481),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1485),
    [anon_sym_TILDE] = ACTIONS(1485),
    [anon_sym_PLUS_PLUS] = ACTIONS(1485),
    [anon_sym_DASH_DASH] = ACTIONS(1485),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1483),
    [anon_sym_DASH] = ACTIONS(1483),
    [anon_sym_STAR] = ACTIONS(1487),
    [anon_sym_CARET] = ACTIONS(1485),
    [anon_sym_AMP] = ACTIONS(1485),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1489),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1491),
    [anon_sym_DOT_DOT] = ACTIONS(1493),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [2151] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6937),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2861),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7001),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5606),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(4149),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7445),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9763),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(2151),
    [sym_preproc_endregion] = STATE(2151),
    [sym_preproc_line] = STATE(2151),
    [sym_preproc_pragma] = STATE(2151),
    [sym_preproc_nullable] = STATE(2151),
    [sym_preproc_error] = STATE(2151),
    [sym_preproc_warning] = STATE(2151),
    [sym_preproc_define] = STATE(2151),
    [sym_preproc_undef] = STATE(2151),
    [aux_sym_class_declaration_repeat1] = STATE(3821),
    [aux_sym_lambda_expression_repeat1] = STATE(4236),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1609),
    [anon_sym_ref] = ACTIONS(1611),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1481),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1615),
    [anon_sym_TILDE] = ACTIONS(1615),
    [anon_sym_PLUS_PLUS] = ACTIONS(1615),
    [anon_sym_DASH_DASH] = ACTIONS(1615),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1613),
    [anon_sym_DASH] = ACTIONS(1613),
    [anon_sym_STAR] = ACTIONS(1487),
    [anon_sym_CARET] = ACTIONS(1615),
    [anon_sym_AMP] = ACTIONS(1615),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1617),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1619),
    [anon_sym_DOT_DOT] = ACTIONS(1621),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [2152] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3906),
    [sym__name] = STATE(6937),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2861),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2822),
    [sym_type] = STATE(7081),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5165),
    [sym_non_lvalue_expression] = STATE(5536),
    [sym_lvalue_expression] = STATE(3898),
    [sym__expression_statement_expression] = STATE(5529),
    [sym_assignment_expression] = STATE(5537),
    [sym_binary_expression] = STATE(5529),
    [sym_postfix_unary_expression] = STATE(5537),
    [sym_prefix_unary_expression] = STATE(5537),
    [sym__pointer_indirection_expression] = STATE(3922),
    [sym_query_expression] = STATE(5529),
    [sym_from_clause] = STATE(7429),
    [sym_conditional_expression] = STATE(5529),
    [sym_conditional_access_expression] = STATE(5529),
    [sym_as_expression] = STATE(5529),
    [sym_is_expression] = STATE(5529),
    [sym_is_pattern_expression] = STATE(5529),
    [sym_cast_expression] = STATE(5529),
    [sym_checked_expression] = STATE(5529),
    [sym_invocation_expression] = STATE(5537),
    [sym_switch_expression] = STATE(5529),
    [sym_await_expression] = STATE(5537),
    [sym_throw_expression] = STATE(5529),
    [sym_element_access_expression] = STATE(3922),
    [sym_interpolated_string_expression] = STATE(5529),
    [sym_member_access_expression] = STATE(3922),
    [sym_object_creation_expression] = STATE(5537),
    [sym_parenthesized_expression] = STATE(5537),
    [sym__parenthesized_lvalue_expression] = STATE(3922),
    [sym_lambda_expression] = STATE(5529),
    [sym__lambda_parameters] = STATE(9350),
    [sym_array_creation_expression] = STATE(5529),
    [sym_anonymous_method_expression] = STATE(5529),
    [sym_anonymous_object_creation_expression] = STATE(5529),
    [sym_implicit_array_creation_expression] = STATE(5529),
    [sym_implicit_object_creation_expression] = STATE(5529),
    [sym_implicit_stackalloc_expression] = STATE(5529),
    [sym_initializer_expression] = STATE(5529),
    [sym_default_expression] = STATE(5529),
    [sym_with_expression] = STATE(5529),
    [sym_sizeof_expression] = STATE(5529),
    [sym_typeof_expression] = STATE(5529),
    [sym_makeref_expression] = STATE(5529),
    [sym_ref_expression] = STATE(5529),
    [sym_reftype_expression] = STATE(5529),
    [sym_refvalue_expression] = STATE(5529),
    [sym_stackalloc_expression] = STATE(5529),
    [sym_range_expression] = STATE(5529),
    [sym_tuple_expression] = STATE(3922),
    [sym_literal] = STATE(5529),
    [sym_character_literal] = STATE(5531),
    [sym_string_literal] = STATE(5531),
    [sym_raw_string_literal] = STATE(5531),
    [sym_boolean_literal] = STATE(5531),
    [sym_identifier] = STATE(2807),
    [sym__reserved_identifier] = STATE(2804),
    [sym_preproc_if_in_expression] = STATE(5529),
    [sym_preproc_region] = STATE(2152),
    [sym_preproc_endregion] = STATE(2152),
    [sym_preproc_line] = STATE(2152),
    [sym_preproc_pragma] = STATE(2152),
    [sym_preproc_nullable] = STATE(2152),
    [sym_preproc_error] = STATE(2152),
    [sym_preproc_warning] = STATE(2152),
    [sym_preproc_define] = STATE(2152),
    [sym_preproc_undef] = STATE(2152),
    [aux_sym_class_declaration_repeat1] = STATE(3879),
    [aux_sym_lambda_expression_repeat1] = STATE(4092),
    [sym__identifier_token] = ACTIONS(1401),
    [anon_sym_alias] = ACTIONS(1403),
    [anon_sym_global] = ACTIONS(1403),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_LPAREN] = ACTIONS(1477),
    [anon_sym_ref] = ACTIONS(1479),
    [anon_sym_LBRACE] = ACTIONS(1411),
    [anon_sym_delegate] = ACTIONS(1413),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(1403),
    [anon_sym_new] = ACTIONS(1481),
    [anon_sym_where] = ACTIONS(1403),
    [anon_sym_notnull] = ACTIONS(1403),
    [anon_sym_unmanaged] = ACTIONS(1403),
    [anon_sym_checked] = ACTIONS(1417),
    [anon_sym_BANG] = ACTIONS(1485),
    [anon_sym_TILDE] = ACTIONS(1485),
    [anon_sym_PLUS_PLUS] = ACTIONS(1485),
    [anon_sym_DASH_DASH] = ACTIONS(1485),
    [anon_sym_true] = ACTIONS(1423),
    [anon_sym_false] = ACTIONS(1423),
    [anon_sym_PLUS] = ACTIONS(1483),
    [anon_sym_DASH] = ACTIONS(1483),
    [anon_sym_STAR] = ACTIONS(1487),
    [anon_sym_CARET] = ACTIONS(1485),
    [anon_sym_AMP] = ACTIONS(1485),
    [anon_sym_this] = ACTIONS(1427),
    [anon_sym_scoped] = ACTIONS(1429),
    [anon_sym_base] = ACTIONS(1431),
    [anon_sym_var] = ACTIONS(1433),
    [sym_predefined_type] = ACTIONS(1435),
    [anon_sym_unchecked] = ACTIONS(1417),
    [anon_sym_yield] = ACTIONS(1403),
    [anon_sym_default] = ACTIONS(1437),
    [anon_sym_throw] = ACTIONS(1489),
    [anon_sym_when] = ACTIONS(1403),
    [anon_sym_await] = ACTIONS(1491),
    [anon_sym_DOT_DOT] = ACTIONS(1493),
    [anon_sym_from] = ACTIONS(1445),
    [anon_sym_into] = ACTIONS(1403),
    [anon_sym_join] = ACTIONS(1403),
    [anon_sym_on] = ACTIONS(1403),
    [anon_sym_equals] = ACTIONS(1403),
    [anon_sym_let] = ACTIONS(1403),
    [anon_sym_orderby] = ACTIONS(1403),
    [anon_sym_ascending] = ACTIONS(1403),
    [anon_sym_descending] = ACTIONS(1403),
    [anon_sym_group] = ACTIONS(1403),
    [anon_sym_by] = ACTIONS(1403),
    [anon_sym_select] = ACTIONS(1403),
    [anon_sym_stackalloc] = ACTIONS(1447),
    [anon_sym_sizeof] = ACTIONS(1449),
    [anon_sym_typeof] = ACTIONS(1451),
    [anon_sym___makeref] = ACTIONS(1453),
    [anon_sym___reftype] = ACTIONS(1455),
    [anon_sym___refvalue] = ACTIONS(1457),
    [sym_null_literal] = ACTIONS(1459),
    [anon_sym_SQUOTE] = ACTIONS(1461),
    [sym_integer_literal] = ACTIONS(1459),
    [sym_real_literal] = ACTIONS(1463),
    [anon_sym_DQUOTE] = ACTIONS(1465),
    [sym_verbatim_string_literal] = ACTIONS(1463),
    [aux_sym_preproc_if_token1] = ACTIONS(1467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1469),
    [sym_interpolation_verbatim_start] = ACTIONS(1471),
    [sym_interpolation_raw_start] = ACTIONS(1473),
    [sym_raw_string_start] = ACTIONS(1475),
  },
  [2153] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6955),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2975),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7120),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4832),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3789),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7416),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9625),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(2153),
    [sym_preproc_endregion] = STATE(2153),
    [sym_preproc_line] = STATE(2153),
    [sym_preproc_pragma] = STATE(2153),
    [sym_preproc_nullable] = STATE(2153),
    [sym_preproc_error] = STATE(2153),
    [sym_preproc_warning] = STATE(2153),
    [sym_preproc_define] = STATE(2153),
    [sym_preproc_undef] = STATE(2153),
    [aux_sym_class_declaration_repeat1] = STATE(3864),
    [aux_sym_lambda_expression_repeat1] = STATE(4297),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1929),
    [anon_sym_ref] = ACTIONS(1931),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1933),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1937),
    [anon_sym_TILDE] = ACTIONS(1937),
    [anon_sym_PLUS_PLUS] = ACTIONS(1937),
    [anon_sym_DASH_DASH] = ACTIONS(1937),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1935),
    [anon_sym_DASH] = ACTIONS(1935),
    [anon_sym_STAR] = ACTIONS(1939),
    [anon_sym_CARET] = ACTIONS(1937),
    [anon_sym_AMP] = ACTIONS(1937),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1941),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1943),
    [anon_sym_DOT_DOT] = ACTIONS(1945),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [2154] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6955),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2975),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7120),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4834),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3789),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7416),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9625),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(2154),
    [sym_preproc_endregion] = STATE(2154),
    [sym_preproc_line] = STATE(2154),
    [sym_preproc_pragma] = STATE(2154),
    [sym_preproc_nullable] = STATE(2154),
    [sym_preproc_error] = STATE(2154),
    [sym_preproc_warning] = STATE(2154),
    [sym_preproc_define] = STATE(2154),
    [sym_preproc_undef] = STATE(2154),
    [aux_sym_class_declaration_repeat1] = STATE(3864),
    [aux_sym_lambda_expression_repeat1] = STATE(4297),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1929),
    [anon_sym_ref] = ACTIONS(1931),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1933),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1937),
    [anon_sym_TILDE] = ACTIONS(1937),
    [anon_sym_PLUS_PLUS] = ACTIONS(1937),
    [anon_sym_DASH_DASH] = ACTIONS(1937),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1935),
    [anon_sym_DASH] = ACTIONS(1935),
    [anon_sym_STAR] = ACTIONS(1939),
    [anon_sym_CARET] = ACTIONS(1937),
    [anon_sym_AMP] = ACTIONS(1937),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1941),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1943),
    [anon_sym_DOT_DOT] = ACTIONS(1945),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [2155] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6955),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2975),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7120),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4767),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3789),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7416),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9625),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(2155),
    [sym_preproc_endregion] = STATE(2155),
    [sym_preproc_line] = STATE(2155),
    [sym_preproc_pragma] = STATE(2155),
    [sym_preproc_nullable] = STATE(2155),
    [sym_preproc_error] = STATE(2155),
    [sym_preproc_warning] = STATE(2155),
    [sym_preproc_define] = STATE(2155),
    [sym_preproc_undef] = STATE(2155),
    [aux_sym_class_declaration_repeat1] = STATE(3864),
    [aux_sym_lambda_expression_repeat1] = STATE(4297),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1929),
    [anon_sym_ref] = ACTIONS(1931),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1933),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1937),
    [anon_sym_TILDE] = ACTIONS(1937),
    [anon_sym_PLUS_PLUS] = ACTIONS(1937),
    [anon_sym_DASH_DASH] = ACTIONS(1937),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1935),
    [anon_sym_DASH] = ACTIONS(1935),
    [anon_sym_STAR] = ACTIONS(1939),
    [anon_sym_CARET] = ACTIONS(1937),
    [anon_sym_AMP] = ACTIONS(1937),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1941),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1943),
    [anon_sym_DOT_DOT] = ACTIONS(1945),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [2156] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6955),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2975),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7120),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3567),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3789),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7416),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9625),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(2156),
    [sym_preproc_endregion] = STATE(2156),
    [sym_preproc_line] = STATE(2156),
    [sym_preproc_pragma] = STATE(2156),
    [sym_preproc_nullable] = STATE(2156),
    [sym_preproc_error] = STATE(2156),
    [sym_preproc_warning] = STATE(2156),
    [sym_preproc_define] = STATE(2156),
    [sym_preproc_undef] = STATE(2156),
    [aux_sym_class_declaration_repeat1] = STATE(3864),
    [aux_sym_lambda_expression_repeat1] = STATE(4297),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1929),
    [anon_sym_ref] = ACTIONS(1931),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1933),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1937),
    [anon_sym_TILDE] = ACTIONS(1937),
    [anon_sym_PLUS_PLUS] = ACTIONS(1937),
    [anon_sym_DASH_DASH] = ACTIONS(1937),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1935),
    [anon_sym_DASH] = ACTIONS(1935),
    [anon_sym_STAR] = ACTIONS(1939),
    [anon_sym_CARET] = ACTIONS(1937),
    [anon_sym_AMP] = ACTIONS(1937),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1941),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1943),
    [anon_sym_DOT_DOT] = ACTIONS(1945),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [2157] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6955),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2975),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7120),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4768),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3789),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7416),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9625),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(2157),
    [sym_preproc_endregion] = STATE(2157),
    [sym_preproc_line] = STATE(2157),
    [sym_preproc_pragma] = STATE(2157),
    [sym_preproc_nullable] = STATE(2157),
    [sym_preproc_error] = STATE(2157),
    [sym_preproc_warning] = STATE(2157),
    [sym_preproc_define] = STATE(2157),
    [sym_preproc_undef] = STATE(2157),
    [aux_sym_class_declaration_repeat1] = STATE(3864),
    [aux_sym_lambda_expression_repeat1] = STATE(4297),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1929),
    [anon_sym_ref] = ACTIONS(1931),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1933),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1937),
    [anon_sym_TILDE] = ACTIONS(1937),
    [anon_sym_PLUS_PLUS] = ACTIONS(1937),
    [anon_sym_DASH_DASH] = ACTIONS(1937),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1935),
    [anon_sym_DASH] = ACTIONS(1935),
    [anon_sym_STAR] = ACTIONS(1939),
    [anon_sym_CARET] = ACTIONS(1937),
    [anon_sym_AMP] = ACTIONS(1937),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1941),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1943),
    [anon_sym_DOT_DOT] = ACTIONS(1945),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [2158] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6955),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2975),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7120),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4772),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3789),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7416),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9625),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(2158),
    [sym_preproc_endregion] = STATE(2158),
    [sym_preproc_line] = STATE(2158),
    [sym_preproc_pragma] = STATE(2158),
    [sym_preproc_nullable] = STATE(2158),
    [sym_preproc_error] = STATE(2158),
    [sym_preproc_warning] = STATE(2158),
    [sym_preproc_define] = STATE(2158),
    [sym_preproc_undef] = STATE(2158),
    [aux_sym_class_declaration_repeat1] = STATE(3864),
    [aux_sym_lambda_expression_repeat1] = STATE(4297),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1929),
    [anon_sym_ref] = ACTIONS(1931),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1933),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1937),
    [anon_sym_TILDE] = ACTIONS(1937),
    [anon_sym_PLUS_PLUS] = ACTIONS(1937),
    [anon_sym_DASH_DASH] = ACTIONS(1937),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1935),
    [anon_sym_DASH] = ACTIONS(1935),
    [anon_sym_STAR] = ACTIONS(1939),
    [anon_sym_CARET] = ACTIONS(1937),
    [anon_sym_AMP] = ACTIONS(1937),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1941),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1943),
    [anon_sym_DOT_DOT] = ACTIONS(1945),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [2159] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6955),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2975),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7120),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4906),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3789),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7416),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9625),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(2159),
    [sym_preproc_endregion] = STATE(2159),
    [sym_preproc_line] = STATE(2159),
    [sym_preproc_pragma] = STATE(2159),
    [sym_preproc_nullable] = STATE(2159),
    [sym_preproc_error] = STATE(2159),
    [sym_preproc_warning] = STATE(2159),
    [sym_preproc_define] = STATE(2159),
    [sym_preproc_undef] = STATE(2159),
    [aux_sym_class_declaration_repeat1] = STATE(3864),
    [aux_sym_lambda_expression_repeat1] = STATE(4297),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1929),
    [anon_sym_ref] = ACTIONS(1931),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1933),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1937),
    [anon_sym_TILDE] = ACTIONS(1937),
    [anon_sym_PLUS_PLUS] = ACTIONS(1937),
    [anon_sym_DASH_DASH] = ACTIONS(1937),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1935),
    [anon_sym_DASH] = ACTIONS(1935),
    [anon_sym_STAR] = ACTIONS(1939),
    [anon_sym_CARET] = ACTIONS(1937),
    [anon_sym_AMP] = ACTIONS(1937),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1941),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1943),
    [anon_sym_DOT_DOT] = ACTIONS(1945),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [2160] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6955),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2975),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7120),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4907),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3789),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7416),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9625),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(2160),
    [sym_preproc_endregion] = STATE(2160),
    [sym_preproc_line] = STATE(2160),
    [sym_preproc_pragma] = STATE(2160),
    [sym_preproc_nullable] = STATE(2160),
    [sym_preproc_error] = STATE(2160),
    [sym_preproc_warning] = STATE(2160),
    [sym_preproc_define] = STATE(2160),
    [sym_preproc_undef] = STATE(2160),
    [aux_sym_class_declaration_repeat1] = STATE(3864),
    [aux_sym_lambda_expression_repeat1] = STATE(4297),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1929),
    [anon_sym_ref] = ACTIONS(1931),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1933),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1937),
    [anon_sym_TILDE] = ACTIONS(1937),
    [anon_sym_PLUS_PLUS] = ACTIONS(1937),
    [anon_sym_DASH_DASH] = ACTIONS(1937),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1935),
    [anon_sym_DASH] = ACTIONS(1935),
    [anon_sym_STAR] = ACTIONS(1939),
    [anon_sym_CARET] = ACTIONS(1937),
    [anon_sym_AMP] = ACTIONS(1937),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1941),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1943),
    [anon_sym_DOT_DOT] = ACTIONS(1945),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [2161] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6955),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2975),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7120),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4908),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3789),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7416),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9625),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(2161),
    [sym_preproc_endregion] = STATE(2161),
    [sym_preproc_line] = STATE(2161),
    [sym_preproc_pragma] = STATE(2161),
    [sym_preproc_nullable] = STATE(2161),
    [sym_preproc_error] = STATE(2161),
    [sym_preproc_warning] = STATE(2161),
    [sym_preproc_define] = STATE(2161),
    [sym_preproc_undef] = STATE(2161),
    [aux_sym_class_declaration_repeat1] = STATE(3864),
    [aux_sym_lambda_expression_repeat1] = STATE(4297),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1929),
    [anon_sym_ref] = ACTIONS(1931),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1933),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1937),
    [anon_sym_TILDE] = ACTIONS(1937),
    [anon_sym_PLUS_PLUS] = ACTIONS(1937),
    [anon_sym_DASH_DASH] = ACTIONS(1937),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1935),
    [anon_sym_DASH] = ACTIONS(1935),
    [anon_sym_STAR] = ACTIONS(1939),
    [anon_sym_CARET] = ACTIONS(1937),
    [anon_sym_AMP] = ACTIONS(1937),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1941),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1943),
    [anon_sym_DOT_DOT] = ACTIONS(1945),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [2162] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6955),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2975),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7120),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4776),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3789),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7416),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9625),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(2162),
    [sym_preproc_endregion] = STATE(2162),
    [sym_preproc_line] = STATE(2162),
    [sym_preproc_pragma] = STATE(2162),
    [sym_preproc_nullable] = STATE(2162),
    [sym_preproc_error] = STATE(2162),
    [sym_preproc_warning] = STATE(2162),
    [sym_preproc_define] = STATE(2162),
    [sym_preproc_undef] = STATE(2162),
    [aux_sym_class_declaration_repeat1] = STATE(3864),
    [aux_sym_lambda_expression_repeat1] = STATE(4297),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1929),
    [anon_sym_ref] = ACTIONS(1931),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1933),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1937),
    [anon_sym_TILDE] = ACTIONS(1937),
    [anon_sym_PLUS_PLUS] = ACTIONS(1937),
    [anon_sym_DASH_DASH] = ACTIONS(1937),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1935),
    [anon_sym_DASH] = ACTIONS(1935),
    [anon_sym_STAR] = ACTIONS(1939),
    [anon_sym_CARET] = ACTIONS(1937),
    [anon_sym_AMP] = ACTIONS(1937),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1941),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1943),
    [anon_sym_DOT_DOT] = ACTIONS(1945),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [2163] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6955),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2975),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7120),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4777),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3789),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7416),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9625),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(2163),
    [sym_preproc_endregion] = STATE(2163),
    [sym_preproc_line] = STATE(2163),
    [sym_preproc_pragma] = STATE(2163),
    [sym_preproc_nullable] = STATE(2163),
    [sym_preproc_error] = STATE(2163),
    [sym_preproc_warning] = STATE(2163),
    [sym_preproc_define] = STATE(2163),
    [sym_preproc_undef] = STATE(2163),
    [aux_sym_class_declaration_repeat1] = STATE(3864),
    [aux_sym_lambda_expression_repeat1] = STATE(4297),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1929),
    [anon_sym_ref] = ACTIONS(1931),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1933),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1937),
    [anon_sym_TILDE] = ACTIONS(1937),
    [anon_sym_PLUS_PLUS] = ACTIONS(1937),
    [anon_sym_DASH_DASH] = ACTIONS(1937),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1935),
    [anon_sym_DASH] = ACTIONS(1935),
    [anon_sym_STAR] = ACTIONS(1939),
    [anon_sym_CARET] = ACTIONS(1937),
    [anon_sym_AMP] = ACTIONS(1937),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1941),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1943),
    [anon_sym_DOT_DOT] = ACTIONS(1945),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [2164] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6955),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2975),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7120),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4778),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3789),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7416),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9625),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(2164),
    [sym_preproc_endregion] = STATE(2164),
    [sym_preproc_line] = STATE(2164),
    [sym_preproc_pragma] = STATE(2164),
    [sym_preproc_nullable] = STATE(2164),
    [sym_preproc_error] = STATE(2164),
    [sym_preproc_warning] = STATE(2164),
    [sym_preproc_define] = STATE(2164),
    [sym_preproc_undef] = STATE(2164),
    [aux_sym_class_declaration_repeat1] = STATE(3864),
    [aux_sym_lambda_expression_repeat1] = STATE(4297),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1929),
    [anon_sym_ref] = ACTIONS(1931),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1933),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1937),
    [anon_sym_TILDE] = ACTIONS(1937),
    [anon_sym_PLUS_PLUS] = ACTIONS(1937),
    [anon_sym_DASH_DASH] = ACTIONS(1937),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1935),
    [anon_sym_DASH] = ACTIONS(1935),
    [anon_sym_STAR] = ACTIONS(1939),
    [anon_sym_CARET] = ACTIONS(1937),
    [anon_sym_AMP] = ACTIONS(1937),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1941),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1943),
    [anon_sym_DOT_DOT] = ACTIONS(1945),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [2165] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6955),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2975),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7120),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4909),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3789),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7416),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9625),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(2165),
    [sym_preproc_endregion] = STATE(2165),
    [sym_preproc_line] = STATE(2165),
    [sym_preproc_pragma] = STATE(2165),
    [sym_preproc_nullable] = STATE(2165),
    [sym_preproc_error] = STATE(2165),
    [sym_preproc_warning] = STATE(2165),
    [sym_preproc_define] = STATE(2165),
    [sym_preproc_undef] = STATE(2165),
    [aux_sym_class_declaration_repeat1] = STATE(3864),
    [aux_sym_lambda_expression_repeat1] = STATE(4297),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1929),
    [anon_sym_ref] = ACTIONS(1931),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1933),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1937),
    [anon_sym_TILDE] = ACTIONS(1937),
    [anon_sym_PLUS_PLUS] = ACTIONS(1937),
    [anon_sym_DASH_DASH] = ACTIONS(1937),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1935),
    [anon_sym_DASH] = ACTIONS(1935),
    [anon_sym_STAR] = ACTIONS(1939),
    [anon_sym_CARET] = ACTIONS(1937),
    [anon_sym_AMP] = ACTIONS(1937),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1941),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1943),
    [anon_sym_DOT_DOT] = ACTIONS(1945),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [2166] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6955),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2975),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7120),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4779),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3789),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7416),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9625),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(2166),
    [sym_preproc_endregion] = STATE(2166),
    [sym_preproc_line] = STATE(2166),
    [sym_preproc_pragma] = STATE(2166),
    [sym_preproc_nullable] = STATE(2166),
    [sym_preproc_error] = STATE(2166),
    [sym_preproc_warning] = STATE(2166),
    [sym_preproc_define] = STATE(2166),
    [sym_preproc_undef] = STATE(2166),
    [aux_sym_class_declaration_repeat1] = STATE(3864),
    [aux_sym_lambda_expression_repeat1] = STATE(4297),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1929),
    [anon_sym_ref] = ACTIONS(1931),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1933),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1937),
    [anon_sym_TILDE] = ACTIONS(1937),
    [anon_sym_PLUS_PLUS] = ACTIONS(1937),
    [anon_sym_DASH_DASH] = ACTIONS(1937),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1935),
    [anon_sym_DASH] = ACTIONS(1935),
    [anon_sym_STAR] = ACTIONS(1939),
    [anon_sym_CARET] = ACTIONS(1937),
    [anon_sym_AMP] = ACTIONS(1937),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1941),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1943),
    [anon_sym_DOT_DOT] = ACTIONS(1945),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [2167] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6955),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2975),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7120),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4780),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3789),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7416),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9625),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(2167),
    [sym_preproc_endregion] = STATE(2167),
    [sym_preproc_line] = STATE(2167),
    [sym_preproc_pragma] = STATE(2167),
    [sym_preproc_nullable] = STATE(2167),
    [sym_preproc_error] = STATE(2167),
    [sym_preproc_warning] = STATE(2167),
    [sym_preproc_define] = STATE(2167),
    [sym_preproc_undef] = STATE(2167),
    [aux_sym_class_declaration_repeat1] = STATE(3864),
    [aux_sym_lambda_expression_repeat1] = STATE(4297),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1929),
    [anon_sym_ref] = ACTIONS(1931),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1933),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1937),
    [anon_sym_TILDE] = ACTIONS(1937),
    [anon_sym_PLUS_PLUS] = ACTIONS(1937),
    [anon_sym_DASH_DASH] = ACTIONS(1937),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1935),
    [anon_sym_DASH] = ACTIONS(1935),
    [anon_sym_STAR] = ACTIONS(1939),
    [anon_sym_CARET] = ACTIONS(1937),
    [anon_sym_AMP] = ACTIONS(1937),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1941),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1943),
    [anon_sym_DOT_DOT] = ACTIONS(1945),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [2168] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6955),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2975),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7120),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4781),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3789),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7416),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9625),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(2168),
    [sym_preproc_endregion] = STATE(2168),
    [sym_preproc_line] = STATE(2168),
    [sym_preproc_pragma] = STATE(2168),
    [sym_preproc_nullable] = STATE(2168),
    [sym_preproc_error] = STATE(2168),
    [sym_preproc_warning] = STATE(2168),
    [sym_preproc_define] = STATE(2168),
    [sym_preproc_undef] = STATE(2168),
    [aux_sym_class_declaration_repeat1] = STATE(3864),
    [aux_sym_lambda_expression_repeat1] = STATE(4297),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1929),
    [anon_sym_ref] = ACTIONS(1931),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1933),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1937),
    [anon_sym_TILDE] = ACTIONS(1937),
    [anon_sym_PLUS_PLUS] = ACTIONS(1937),
    [anon_sym_DASH_DASH] = ACTIONS(1937),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1935),
    [anon_sym_DASH] = ACTIONS(1935),
    [anon_sym_STAR] = ACTIONS(1939),
    [anon_sym_CARET] = ACTIONS(1937),
    [anon_sym_AMP] = ACTIONS(1937),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1941),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1943),
    [anon_sym_DOT_DOT] = ACTIONS(1945),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [2169] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6955),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2975),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7120),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(4782),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3789),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7416),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9625),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(2169),
    [sym_preproc_endregion] = STATE(2169),
    [sym_preproc_line] = STATE(2169),
    [sym_preproc_pragma] = STATE(2169),
    [sym_preproc_nullable] = STATE(2169),
    [sym_preproc_error] = STATE(2169),
    [sym_preproc_warning] = STATE(2169),
    [sym_preproc_define] = STATE(2169),
    [sym_preproc_undef] = STATE(2169),
    [aux_sym_class_declaration_repeat1] = STATE(3864),
    [aux_sym_lambda_expression_repeat1] = STATE(4297),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1929),
    [anon_sym_ref] = ACTIONS(1931),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1933),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1937),
    [anon_sym_TILDE] = ACTIONS(1937),
    [anon_sym_PLUS_PLUS] = ACTIONS(1937),
    [anon_sym_DASH_DASH] = ACTIONS(1937),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1935),
    [anon_sym_DASH] = ACTIONS(1935),
    [anon_sym_STAR] = ACTIONS(1939),
    [anon_sym_CARET] = ACTIONS(1937),
    [anon_sym_AMP] = ACTIONS(1937),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1941),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1943),
    [anon_sym_DOT_DOT] = ACTIONS(1945),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [2170] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6955),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2975),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7120),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3582),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3789),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7416),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9625),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(2170),
    [sym_preproc_endregion] = STATE(2170),
    [sym_preproc_line] = STATE(2170),
    [sym_preproc_pragma] = STATE(2170),
    [sym_preproc_nullable] = STATE(2170),
    [sym_preproc_error] = STATE(2170),
    [sym_preproc_warning] = STATE(2170),
    [sym_preproc_define] = STATE(2170),
    [sym_preproc_undef] = STATE(2170),
    [aux_sym_class_declaration_repeat1] = STATE(3864),
    [aux_sym_lambda_expression_repeat1] = STATE(4297),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1929),
    [anon_sym_ref] = ACTIONS(1931),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1933),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1937),
    [anon_sym_TILDE] = ACTIONS(1937),
    [anon_sym_PLUS_PLUS] = ACTIONS(1937),
    [anon_sym_DASH_DASH] = ACTIONS(1937),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1935),
    [anon_sym_DASH] = ACTIONS(1935),
    [anon_sym_STAR] = ACTIONS(1939),
    [anon_sym_CARET] = ACTIONS(1937),
    [anon_sym_AMP] = ACTIONS(1937),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1941),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1943),
    [anon_sym_DOT_DOT] = ACTIONS(1945),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [2171] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3002),
    [sym__name] = STATE(6955),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2975),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7120),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(3561),
    [sym_non_lvalue_expression] = STATE(3688),
    [sym_lvalue_expression] = STATE(3789),
    [sym__expression_statement_expression] = STATE(3717),
    [sym_assignment_expression] = STATE(3709),
    [sym_binary_expression] = STATE(3717),
    [sym_postfix_unary_expression] = STATE(3709),
    [sym_prefix_unary_expression] = STATE(3709),
    [sym__pointer_indirection_expression] = STATE(3020),
    [sym_query_expression] = STATE(3717),
    [sym_from_clause] = STATE(7416),
    [sym_conditional_expression] = STATE(3717),
    [sym_conditional_access_expression] = STATE(3717),
    [sym_as_expression] = STATE(3717),
    [sym_is_expression] = STATE(3717),
    [sym_is_pattern_expression] = STATE(3717),
    [sym_cast_expression] = STATE(3717),
    [sym_checked_expression] = STATE(3717),
    [sym_invocation_expression] = STATE(3709),
    [sym_switch_expression] = STATE(3717),
    [sym_await_expression] = STATE(3709),
    [sym_throw_expression] = STATE(3717),
    [sym_element_access_expression] = STATE(3020),
    [sym_interpolated_string_expression] = STATE(3717),
    [sym_member_access_expression] = STATE(3020),
    [sym_object_creation_expression] = STATE(3709),
    [sym_parenthesized_expression] = STATE(3709),
    [sym__parenthesized_lvalue_expression] = STATE(3020),
    [sym_lambda_expression] = STATE(3717),
    [sym__lambda_parameters] = STATE(9625),
    [sym_array_creation_expression] = STATE(3717),
    [sym_anonymous_method_expression] = STATE(3717),
    [sym_anonymous_object_creation_expression] = STATE(3717),
    [sym_implicit_array_creation_expression] = STATE(3717),
    [sym_implicit_object_creation_expression] = STATE(3717),
    [sym_implicit_stackalloc_expression] = STATE(3717),
    [sym_initializer_expression] = STATE(3717),
    [sym_default_expression] = STATE(3717),
    [sym_with_expression] = STATE(3717),
    [sym_sizeof_expression] = STATE(3717),
    [sym_typeof_expression] = STATE(3717),
    [sym_makeref_expression] = STATE(3717),
    [sym_ref_expression] = STATE(3717),
    [sym_reftype_expression] = STATE(3717),
    [sym_refvalue_expression] = STATE(3717),
    [sym_stackalloc_expression] = STATE(3717),
    [sym_range_expression] = STATE(3717),
    [sym_tuple_expression] = STATE(3020),
    [sym_literal] = STATE(3717),
    [sym_character_literal] = STATE(3727),
    [sym_string_literal] = STATE(3727),
    [sym_raw_string_literal] = STATE(3727),
    [sym_boolean_literal] = STATE(3727),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3717),
    [sym_preproc_region] = STATE(2171),
    [sym_preproc_endregion] = STATE(2171),
    [sym_preproc_line] = STATE(2171),
    [sym_preproc_pragma] = STATE(2171),
    [sym_preproc_nullable] = STATE(2171),
    [sym_preproc_error] = STATE(2171),
    [sym_preproc_warning] = STATE(2171),
    [sym_preproc_define] = STATE(2171),
    [sym_preproc_undef] = STATE(2171),
    [aux_sym_class_declaration_repeat1] = STATE(3864),
    [aux_sym_lambda_expression_repeat1] = STATE(4297),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1239),
    [anon_sym_LPAREN] = ACTIONS(1929),
    [anon_sym_ref] = ACTIONS(1931),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_delegate] = ACTIONS(1247),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1933),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1251),
    [anon_sym_BANG] = ACTIONS(1937),
    [anon_sym_TILDE] = ACTIONS(1937),
    [anon_sym_PLUS_PLUS] = ACTIONS(1937),
    [anon_sym_DASH_DASH] = ACTIONS(1937),
    [anon_sym_true] = ACTIONS(1257),
    [anon_sym_false] = ACTIONS(1257),
    [anon_sym_PLUS] = ACTIONS(1935),
    [anon_sym_DASH] = ACTIONS(1935),
    [anon_sym_STAR] = ACTIONS(1939),
    [anon_sym_CARET] = ACTIONS(1937),
    [anon_sym_AMP] = ACTIONS(1937),
    [anon_sym_this] = ACTIONS(1261),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1263),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1265),
    [anon_sym_unchecked] = ACTIONS(1251),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1267),
    [anon_sym_throw] = ACTIONS(1941),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1943),
    [anon_sym_DOT_DOT] = ACTIONS(1945),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1275),
    [anon_sym_sizeof] = ACTIONS(1277),
    [anon_sym_typeof] = ACTIONS(1279),
    [anon_sym___makeref] = ACTIONS(1281),
    [anon_sym___reftype] = ACTIONS(1283),
    [anon_sym___refvalue] = ACTIONS(1285),
    [sym_null_literal] = ACTIONS(1287),
    [anon_sym_SQUOTE] = ACTIONS(1289),
    [sym_integer_literal] = ACTIONS(1287),
    [sym_real_literal] = ACTIONS(1291),
    [anon_sym_DQUOTE] = ACTIONS(1293),
    [sym_verbatim_string_literal] = ACTIONS(1291),
    [aux_sym_preproc_if_token1] = ACTIONS(1295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1297),
    [sym_interpolation_verbatim_start] = ACTIONS(1299),
    [sym_interpolation_raw_start] = ACTIONS(1301),
    [sym_raw_string_start] = ACTIONS(1303),
  },
  [2172] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6920),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2942),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7143),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6614),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4489),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7426),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9002),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2172),
    [sym_preproc_endregion] = STATE(2172),
    [sym_preproc_line] = STATE(2172),
    [sym_preproc_pragma] = STATE(2172),
    [sym_preproc_nullable] = STATE(2172),
    [sym_preproc_error] = STATE(2172),
    [sym_preproc_warning] = STATE(2172),
    [sym_preproc_define] = STATE(2172),
    [sym_preproc_undef] = STATE(2172),
    [aux_sym_class_declaration_repeat1] = STATE(3809),
    [aux_sym_lambda_expression_repeat1] = STATE(4308),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2189),
    [anon_sym_ref] = ACTIONS(2191),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2193),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2197),
    [anon_sym_TILDE] = ACTIONS(2197),
    [anon_sym_PLUS_PLUS] = ACTIONS(2197),
    [anon_sym_DASH_DASH] = ACTIONS(2197),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2195),
    [anon_sym_DASH] = ACTIONS(2195),
    [anon_sym_STAR] = ACTIONS(2199),
    [anon_sym_CARET] = ACTIONS(2197),
    [anon_sym_AMP] = ACTIONS(2197),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2201),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2203),
    [anon_sym_DOT_DOT] = ACTIONS(2205),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2173] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6920),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2942),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7143),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6471),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4489),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7426),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9002),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2173),
    [sym_preproc_endregion] = STATE(2173),
    [sym_preproc_line] = STATE(2173),
    [sym_preproc_pragma] = STATE(2173),
    [sym_preproc_nullable] = STATE(2173),
    [sym_preproc_error] = STATE(2173),
    [sym_preproc_warning] = STATE(2173),
    [sym_preproc_define] = STATE(2173),
    [sym_preproc_undef] = STATE(2173),
    [aux_sym_class_declaration_repeat1] = STATE(3809),
    [aux_sym_lambda_expression_repeat1] = STATE(4308),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2189),
    [anon_sym_ref] = ACTIONS(2191),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2193),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2197),
    [anon_sym_TILDE] = ACTIONS(2197),
    [anon_sym_PLUS_PLUS] = ACTIONS(2197),
    [anon_sym_DASH_DASH] = ACTIONS(2197),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2195),
    [anon_sym_DASH] = ACTIONS(2195),
    [anon_sym_STAR] = ACTIONS(2199),
    [anon_sym_CARET] = ACTIONS(2197),
    [anon_sym_AMP] = ACTIONS(2197),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2201),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2203),
    [anon_sym_DOT_DOT] = ACTIONS(2205),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2174] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6475),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2174),
    [sym_preproc_endregion] = STATE(2174),
    [sym_preproc_line] = STATE(2174),
    [sym_preproc_pragma] = STATE(2174),
    [sym_preproc_nullable] = STATE(2174),
    [sym_preproc_error] = STATE(2174),
    [sym_preproc_warning] = STATE(2174),
    [sym_preproc_define] = STATE(2174),
    [sym_preproc_undef] = STATE(2174),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2175] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6920),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2942),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7143),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6489),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4489),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7426),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9002),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2175),
    [sym_preproc_endregion] = STATE(2175),
    [sym_preproc_line] = STATE(2175),
    [sym_preproc_pragma] = STATE(2175),
    [sym_preproc_nullable] = STATE(2175),
    [sym_preproc_error] = STATE(2175),
    [sym_preproc_warning] = STATE(2175),
    [sym_preproc_define] = STATE(2175),
    [sym_preproc_undef] = STATE(2175),
    [aux_sym_class_declaration_repeat1] = STATE(3809),
    [aux_sym_lambda_expression_repeat1] = STATE(4308),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2189),
    [anon_sym_ref] = ACTIONS(2191),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2193),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2197),
    [anon_sym_TILDE] = ACTIONS(2197),
    [anon_sym_PLUS_PLUS] = ACTIONS(2197),
    [anon_sym_DASH_DASH] = ACTIONS(2197),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2195),
    [anon_sym_DASH] = ACTIONS(2195),
    [anon_sym_STAR] = ACTIONS(2199),
    [anon_sym_CARET] = ACTIONS(2197),
    [anon_sym_AMP] = ACTIONS(2197),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2201),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2203),
    [anon_sym_DOT_DOT] = ACTIONS(2205),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2176] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6497),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2176),
    [sym_preproc_endregion] = STATE(2176),
    [sym_preproc_line] = STATE(2176),
    [sym_preproc_pragma] = STATE(2176),
    [sym_preproc_nullable] = STATE(2176),
    [sym_preproc_error] = STATE(2176),
    [sym_preproc_warning] = STATE(2176),
    [sym_preproc_define] = STATE(2176),
    [sym_preproc_undef] = STATE(2176),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2177] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6920),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2942),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7143),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6524),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4489),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7426),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9002),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2177),
    [sym_preproc_endregion] = STATE(2177),
    [sym_preproc_line] = STATE(2177),
    [sym_preproc_pragma] = STATE(2177),
    [sym_preproc_nullable] = STATE(2177),
    [sym_preproc_error] = STATE(2177),
    [sym_preproc_warning] = STATE(2177),
    [sym_preproc_define] = STATE(2177),
    [sym_preproc_undef] = STATE(2177),
    [aux_sym_class_declaration_repeat1] = STATE(3809),
    [aux_sym_lambda_expression_repeat1] = STATE(4308),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2189),
    [anon_sym_ref] = ACTIONS(2191),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2193),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2197),
    [anon_sym_TILDE] = ACTIONS(2197),
    [anon_sym_PLUS_PLUS] = ACTIONS(2197),
    [anon_sym_DASH_DASH] = ACTIONS(2197),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2195),
    [anon_sym_DASH] = ACTIONS(2195),
    [anon_sym_STAR] = ACTIONS(2199),
    [anon_sym_CARET] = ACTIONS(2197),
    [anon_sym_AMP] = ACTIONS(2197),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2201),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2203),
    [anon_sym_DOT_DOT] = ACTIONS(2205),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2178] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6956),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5609),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4146),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9482),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2178),
    [sym_preproc_endregion] = STATE(2178),
    [sym_preproc_line] = STATE(2178),
    [sym_preproc_pragma] = STATE(2178),
    [sym_preproc_nullable] = STATE(2178),
    [sym_preproc_error] = STATE(2178),
    [sym_preproc_warning] = STATE(2178),
    [sym_preproc_define] = STATE(2178),
    [sym_preproc_undef] = STATE(2178),
    [aux_sym_class_declaration_repeat1] = STATE(3853),
    [aux_sym_lambda_expression_repeat1] = STATE(4299),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1497),
    [anon_sym_ref] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1503),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(75),
    [anon_sym_TILDE] = ACTIONS(75),
    [anon_sym_PLUS_PLUS] = ACTIONS(75),
    [anon_sym_DASH_DASH] = ACTIONS(75),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(79),
    [anon_sym_DASH] = ACTIONS(79),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(75),
    [anon_sym_AMP] = ACTIONS(75),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1505),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1507),
    [anon_sym_DOT_DOT] = ACTIONS(1509),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2179] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6920),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2942),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7143),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6535),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4489),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7426),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9002),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2179),
    [sym_preproc_endregion] = STATE(2179),
    [sym_preproc_line] = STATE(2179),
    [sym_preproc_pragma] = STATE(2179),
    [sym_preproc_nullable] = STATE(2179),
    [sym_preproc_error] = STATE(2179),
    [sym_preproc_warning] = STATE(2179),
    [sym_preproc_define] = STATE(2179),
    [sym_preproc_undef] = STATE(2179),
    [aux_sym_class_declaration_repeat1] = STATE(3809),
    [aux_sym_lambda_expression_repeat1] = STATE(4308),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2189),
    [anon_sym_ref] = ACTIONS(2191),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2193),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2197),
    [anon_sym_TILDE] = ACTIONS(2197),
    [anon_sym_PLUS_PLUS] = ACTIONS(2197),
    [anon_sym_DASH_DASH] = ACTIONS(2197),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2195),
    [anon_sym_DASH] = ACTIONS(2195),
    [anon_sym_STAR] = ACTIONS(2199),
    [anon_sym_CARET] = ACTIONS(2197),
    [anon_sym_AMP] = ACTIONS(2197),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2201),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2203),
    [anon_sym_DOT_DOT] = ACTIONS(2205),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2180] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6920),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2942),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7143),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6543),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4489),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7426),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9002),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2180),
    [sym_preproc_endregion] = STATE(2180),
    [sym_preproc_line] = STATE(2180),
    [sym_preproc_pragma] = STATE(2180),
    [sym_preproc_nullable] = STATE(2180),
    [sym_preproc_error] = STATE(2180),
    [sym_preproc_warning] = STATE(2180),
    [sym_preproc_define] = STATE(2180),
    [sym_preproc_undef] = STATE(2180),
    [aux_sym_class_declaration_repeat1] = STATE(3809),
    [aux_sym_lambda_expression_repeat1] = STATE(4308),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2189),
    [anon_sym_ref] = ACTIONS(2191),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2193),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2197),
    [anon_sym_TILDE] = ACTIONS(2197),
    [anon_sym_PLUS_PLUS] = ACTIONS(2197),
    [anon_sym_DASH_DASH] = ACTIONS(2197),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2195),
    [anon_sym_DASH] = ACTIONS(2195),
    [anon_sym_STAR] = ACTIONS(2199),
    [anon_sym_CARET] = ACTIONS(2197),
    [anon_sym_AMP] = ACTIONS(2197),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2201),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2203),
    [anon_sym_DOT_DOT] = ACTIONS(2205),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2181] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6920),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2942),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7143),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6551),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4489),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7426),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9002),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2181),
    [sym_preproc_endregion] = STATE(2181),
    [sym_preproc_line] = STATE(2181),
    [sym_preproc_pragma] = STATE(2181),
    [sym_preproc_nullable] = STATE(2181),
    [sym_preproc_error] = STATE(2181),
    [sym_preproc_warning] = STATE(2181),
    [sym_preproc_define] = STATE(2181),
    [sym_preproc_undef] = STATE(2181),
    [aux_sym_class_declaration_repeat1] = STATE(3809),
    [aux_sym_lambda_expression_repeat1] = STATE(4308),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2189),
    [anon_sym_ref] = ACTIONS(2191),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2193),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2197),
    [anon_sym_TILDE] = ACTIONS(2197),
    [anon_sym_PLUS_PLUS] = ACTIONS(2197),
    [anon_sym_DASH_DASH] = ACTIONS(2197),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2195),
    [anon_sym_DASH] = ACTIONS(2195),
    [anon_sym_STAR] = ACTIONS(2199),
    [anon_sym_CARET] = ACTIONS(2197),
    [anon_sym_AMP] = ACTIONS(2197),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2201),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2203),
    [anon_sym_DOT_DOT] = ACTIONS(2205),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2182] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6920),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2942),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7143),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6557),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4489),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7426),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9002),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2182),
    [sym_preproc_endregion] = STATE(2182),
    [sym_preproc_line] = STATE(2182),
    [sym_preproc_pragma] = STATE(2182),
    [sym_preproc_nullable] = STATE(2182),
    [sym_preproc_error] = STATE(2182),
    [sym_preproc_warning] = STATE(2182),
    [sym_preproc_define] = STATE(2182),
    [sym_preproc_undef] = STATE(2182),
    [aux_sym_class_declaration_repeat1] = STATE(3809),
    [aux_sym_lambda_expression_repeat1] = STATE(4308),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2189),
    [anon_sym_ref] = ACTIONS(2191),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2193),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2197),
    [anon_sym_TILDE] = ACTIONS(2197),
    [anon_sym_PLUS_PLUS] = ACTIONS(2197),
    [anon_sym_DASH_DASH] = ACTIONS(2197),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2195),
    [anon_sym_DASH] = ACTIONS(2195),
    [anon_sym_STAR] = ACTIONS(2199),
    [anon_sym_CARET] = ACTIONS(2197),
    [anon_sym_AMP] = ACTIONS(2197),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2201),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2203),
    [anon_sym_DOT_DOT] = ACTIONS(2205),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2183] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6920),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2942),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7143),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6563),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4489),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7426),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9002),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2183),
    [sym_preproc_endregion] = STATE(2183),
    [sym_preproc_line] = STATE(2183),
    [sym_preproc_pragma] = STATE(2183),
    [sym_preproc_nullable] = STATE(2183),
    [sym_preproc_error] = STATE(2183),
    [sym_preproc_warning] = STATE(2183),
    [sym_preproc_define] = STATE(2183),
    [sym_preproc_undef] = STATE(2183),
    [aux_sym_class_declaration_repeat1] = STATE(3809),
    [aux_sym_lambda_expression_repeat1] = STATE(4308),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2189),
    [anon_sym_ref] = ACTIONS(2191),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2193),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2197),
    [anon_sym_TILDE] = ACTIONS(2197),
    [anon_sym_PLUS_PLUS] = ACTIONS(2197),
    [anon_sym_DASH_DASH] = ACTIONS(2197),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2195),
    [anon_sym_DASH] = ACTIONS(2195),
    [anon_sym_STAR] = ACTIONS(2199),
    [anon_sym_CARET] = ACTIONS(2197),
    [anon_sym_AMP] = ACTIONS(2197),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2201),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2203),
    [anon_sym_DOT_DOT] = ACTIONS(2205),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2184] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6920),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2942),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7143),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6567),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4489),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7426),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9002),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2184),
    [sym_preproc_endregion] = STATE(2184),
    [sym_preproc_line] = STATE(2184),
    [sym_preproc_pragma] = STATE(2184),
    [sym_preproc_nullable] = STATE(2184),
    [sym_preproc_error] = STATE(2184),
    [sym_preproc_warning] = STATE(2184),
    [sym_preproc_define] = STATE(2184),
    [sym_preproc_undef] = STATE(2184),
    [aux_sym_class_declaration_repeat1] = STATE(3809),
    [aux_sym_lambda_expression_repeat1] = STATE(4308),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2189),
    [anon_sym_ref] = ACTIONS(2191),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2193),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2197),
    [anon_sym_TILDE] = ACTIONS(2197),
    [anon_sym_PLUS_PLUS] = ACTIONS(2197),
    [anon_sym_DASH_DASH] = ACTIONS(2197),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2195),
    [anon_sym_DASH] = ACTIONS(2195),
    [anon_sym_STAR] = ACTIONS(2199),
    [anon_sym_CARET] = ACTIONS(2197),
    [anon_sym_AMP] = ACTIONS(2197),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2201),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2203),
    [anon_sym_DOT_DOT] = ACTIONS(2205),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2185] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6920),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2942),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7143),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6568),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4489),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7426),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9002),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2185),
    [sym_preproc_endregion] = STATE(2185),
    [sym_preproc_line] = STATE(2185),
    [sym_preproc_pragma] = STATE(2185),
    [sym_preproc_nullable] = STATE(2185),
    [sym_preproc_error] = STATE(2185),
    [sym_preproc_warning] = STATE(2185),
    [sym_preproc_define] = STATE(2185),
    [sym_preproc_undef] = STATE(2185),
    [aux_sym_class_declaration_repeat1] = STATE(3809),
    [aux_sym_lambda_expression_repeat1] = STATE(4308),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2189),
    [anon_sym_ref] = ACTIONS(2191),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2193),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2197),
    [anon_sym_TILDE] = ACTIONS(2197),
    [anon_sym_PLUS_PLUS] = ACTIONS(2197),
    [anon_sym_DASH_DASH] = ACTIONS(2197),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2195),
    [anon_sym_DASH] = ACTIONS(2195),
    [anon_sym_STAR] = ACTIONS(2199),
    [anon_sym_CARET] = ACTIONS(2197),
    [anon_sym_AMP] = ACTIONS(2197),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2201),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2203),
    [anon_sym_DOT_DOT] = ACTIONS(2205),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2186] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6920),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2942),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7143),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6633),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4489),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7426),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9002),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2186),
    [sym_preproc_endregion] = STATE(2186),
    [sym_preproc_line] = STATE(2186),
    [sym_preproc_pragma] = STATE(2186),
    [sym_preproc_nullable] = STATE(2186),
    [sym_preproc_error] = STATE(2186),
    [sym_preproc_warning] = STATE(2186),
    [sym_preproc_define] = STATE(2186),
    [sym_preproc_undef] = STATE(2186),
    [aux_sym_class_declaration_repeat1] = STATE(3809),
    [aux_sym_lambda_expression_repeat1] = STATE(4308),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2189),
    [anon_sym_ref] = ACTIONS(2191),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2193),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2197),
    [anon_sym_TILDE] = ACTIONS(2197),
    [anon_sym_PLUS_PLUS] = ACTIONS(2197),
    [anon_sym_DASH_DASH] = ACTIONS(2197),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2195),
    [anon_sym_DASH] = ACTIONS(2195),
    [anon_sym_STAR] = ACTIONS(2199),
    [anon_sym_CARET] = ACTIONS(2197),
    [anon_sym_AMP] = ACTIONS(2197),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2201),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2203),
    [anon_sym_DOT_DOT] = ACTIONS(2205),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2187] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6920),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2942),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7143),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6569),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4489),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7426),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9002),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2187),
    [sym_preproc_endregion] = STATE(2187),
    [sym_preproc_line] = STATE(2187),
    [sym_preproc_pragma] = STATE(2187),
    [sym_preproc_nullable] = STATE(2187),
    [sym_preproc_error] = STATE(2187),
    [sym_preproc_warning] = STATE(2187),
    [sym_preproc_define] = STATE(2187),
    [sym_preproc_undef] = STATE(2187),
    [aux_sym_class_declaration_repeat1] = STATE(3809),
    [aux_sym_lambda_expression_repeat1] = STATE(4308),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2189),
    [anon_sym_ref] = ACTIONS(2191),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2193),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2197),
    [anon_sym_TILDE] = ACTIONS(2197),
    [anon_sym_PLUS_PLUS] = ACTIONS(2197),
    [anon_sym_DASH_DASH] = ACTIONS(2197),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2195),
    [anon_sym_DASH] = ACTIONS(2195),
    [anon_sym_STAR] = ACTIONS(2199),
    [anon_sym_CARET] = ACTIONS(2197),
    [anon_sym_AMP] = ACTIONS(2197),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2201),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2203),
    [anon_sym_DOT_DOT] = ACTIONS(2205),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2188] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6920),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2942),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7143),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6570),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4489),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7426),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9002),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2188),
    [sym_preproc_endregion] = STATE(2188),
    [sym_preproc_line] = STATE(2188),
    [sym_preproc_pragma] = STATE(2188),
    [sym_preproc_nullable] = STATE(2188),
    [sym_preproc_error] = STATE(2188),
    [sym_preproc_warning] = STATE(2188),
    [sym_preproc_define] = STATE(2188),
    [sym_preproc_undef] = STATE(2188),
    [aux_sym_class_declaration_repeat1] = STATE(3809),
    [aux_sym_lambda_expression_repeat1] = STATE(4308),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2189),
    [anon_sym_ref] = ACTIONS(2191),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2193),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2197),
    [anon_sym_TILDE] = ACTIONS(2197),
    [anon_sym_PLUS_PLUS] = ACTIONS(2197),
    [anon_sym_DASH_DASH] = ACTIONS(2197),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2195),
    [anon_sym_DASH] = ACTIONS(2195),
    [anon_sym_STAR] = ACTIONS(2199),
    [anon_sym_CARET] = ACTIONS(2197),
    [anon_sym_AMP] = ACTIONS(2197),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2201),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2203),
    [anon_sym_DOT_DOT] = ACTIONS(2205),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2189] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6920),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2942),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7143),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6571),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4489),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7426),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9002),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2189),
    [sym_preproc_endregion] = STATE(2189),
    [sym_preproc_line] = STATE(2189),
    [sym_preproc_pragma] = STATE(2189),
    [sym_preproc_nullable] = STATE(2189),
    [sym_preproc_error] = STATE(2189),
    [sym_preproc_warning] = STATE(2189),
    [sym_preproc_define] = STATE(2189),
    [sym_preproc_undef] = STATE(2189),
    [aux_sym_class_declaration_repeat1] = STATE(3809),
    [aux_sym_lambda_expression_repeat1] = STATE(4308),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2189),
    [anon_sym_ref] = ACTIONS(2191),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2193),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2197),
    [anon_sym_TILDE] = ACTIONS(2197),
    [anon_sym_PLUS_PLUS] = ACTIONS(2197),
    [anon_sym_DASH_DASH] = ACTIONS(2197),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2195),
    [anon_sym_DASH] = ACTIONS(2195),
    [anon_sym_STAR] = ACTIONS(2199),
    [anon_sym_CARET] = ACTIONS(2197),
    [anon_sym_AMP] = ACTIONS(2197),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2201),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2203),
    [anon_sym_DOT_DOT] = ACTIONS(2205),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2190] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6920),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2942),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7143),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6573),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4489),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7426),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9002),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2190),
    [sym_preproc_endregion] = STATE(2190),
    [sym_preproc_line] = STATE(2190),
    [sym_preproc_pragma] = STATE(2190),
    [sym_preproc_nullable] = STATE(2190),
    [sym_preproc_error] = STATE(2190),
    [sym_preproc_warning] = STATE(2190),
    [sym_preproc_define] = STATE(2190),
    [sym_preproc_undef] = STATE(2190),
    [aux_sym_class_declaration_repeat1] = STATE(3809),
    [aux_sym_lambda_expression_repeat1] = STATE(4308),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2189),
    [anon_sym_ref] = ACTIONS(2191),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2193),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2197),
    [anon_sym_TILDE] = ACTIONS(2197),
    [anon_sym_PLUS_PLUS] = ACTIONS(2197),
    [anon_sym_DASH_DASH] = ACTIONS(2197),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2195),
    [anon_sym_DASH] = ACTIONS(2195),
    [anon_sym_STAR] = ACTIONS(2199),
    [anon_sym_CARET] = ACTIONS(2197),
    [anon_sym_AMP] = ACTIONS(2197),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2201),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2203),
    [anon_sym_DOT_DOT] = ACTIONS(2205),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2191] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6920),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2942),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7143),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6577),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4489),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7426),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9002),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2191),
    [sym_preproc_endregion] = STATE(2191),
    [sym_preproc_line] = STATE(2191),
    [sym_preproc_pragma] = STATE(2191),
    [sym_preproc_nullable] = STATE(2191),
    [sym_preproc_error] = STATE(2191),
    [sym_preproc_warning] = STATE(2191),
    [sym_preproc_define] = STATE(2191),
    [sym_preproc_undef] = STATE(2191),
    [aux_sym_class_declaration_repeat1] = STATE(3809),
    [aux_sym_lambda_expression_repeat1] = STATE(4308),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2189),
    [anon_sym_ref] = ACTIONS(2191),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(2193),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2197),
    [anon_sym_TILDE] = ACTIONS(2197),
    [anon_sym_PLUS_PLUS] = ACTIONS(2197),
    [anon_sym_DASH_DASH] = ACTIONS(2197),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2195),
    [anon_sym_DASH] = ACTIONS(2195),
    [anon_sym_STAR] = ACTIONS(2199),
    [anon_sym_CARET] = ACTIONS(2197),
    [anon_sym_AMP] = ACTIONS(2197),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2201),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2203),
    [anon_sym_DOT_DOT] = ACTIONS(2205),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2192] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6946),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6595),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4473),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9905),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2192),
    [sym_preproc_endregion] = STATE(2192),
    [sym_preproc_line] = STATE(2192),
    [sym_preproc_pragma] = STATE(2192),
    [sym_preproc_nullable] = STATE(2192),
    [sym_preproc_error] = STATE(2192),
    [sym_preproc_warning] = STATE(2192),
    [sym_preproc_define] = STATE(2192),
    [sym_preproc_undef] = STATE(2192),
    [aux_sym_class_declaration_repeat1] = STATE(3878),
    [aux_sym_lambda_expression_repeat1] = STATE(4331),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2055),
    [anon_sym_ref] = ACTIONS(2057),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2061),
    [anon_sym_TILDE] = ACTIONS(2061),
    [anon_sym_PLUS_PLUS] = ACTIONS(2061),
    [anon_sym_DASH_DASH] = ACTIONS(2061),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2059),
    [anon_sym_DASH] = ACTIONS(2059),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(2061),
    [anon_sym_AMP] = ACTIONS(2061),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2063),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2065),
    [anon_sym_DOT_DOT] = ACTIONS(2067),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2193] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6596),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2193),
    [sym_preproc_endregion] = STATE(2193),
    [sym_preproc_line] = STATE(2193),
    [sym_preproc_pragma] = STATE(2193),
    [sym_preproc_nullable] = STATE(2193),
    [sym_preproc_error] = STATE(2193),
    [sym_preproc_warning] = STATE(2193),
    [sym_preproc_define] = STATE(2193),
    [sym_preproc_undef] = STATE(2193),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2194] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6949),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6603),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4473),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9905),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2194),
    [sym_preproc_endregion] = STATE(2194),
    [sym_preproc_line] = STATE(2194),
    [sym_preproc_pragma] = STATE(2194),
    [sym_preproc_nullable] = STATE(2194),
    [sym_preproc_error] = STATE(2194),
    [sym_preproc_warning] = STATE(2194),
    [sym_preproc_define] = STATE(2194),
    [sym_preproc_undef] = STATE(2194),
    [aux_sym_class_declaration_repeat1] = STATE(3878),
    [aux_sym_lambda_expression_repeat1] = STATE(4331),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2055),
    [anon_sym_ref] = ACTIONS(2057),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2061),
    [anon_sym_TILDE] = ACTIONS(2061),
    [anon_sym_PLUS_PLUS] = ACTIONS(2061),
    [anon_sym_DASH_DASH] = ACTIONS(2061),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2059),
    [anon_sym_DASH] = ACTIONS(2059),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(2061),
    [anon_sym_AMP] = ACTIONS(2061),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2063),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2065),
    [anon_sym_DOT_DOT] = ACTIONS(2067),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2195] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6951),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6641),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4473),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9905),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2195),
    [sym_preproc_endregion] = STATE(2195),
    [sym_preproc_line] = STATE(2195),
    [sym_preproc_pragma] = STATE(2195),
    [sym_preproc_nullable] = STATE(2195),
    [sym_preproc_error] = STATE(2195),
    [sym_preproc_warning] = STATE(2195),
    [sym_preproc_define] = STATE(2195),
    [sym_preproc_undef] = STATE(2195),
    [aux_sym_class_declaration_repeat1] = STATE(3878),
    [aux_sym_lambda_expression_repeat1] = STATE(4331),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2055),
    [anon_sym_ref] = ACTIONS(2057),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2061),
    [anon_sym_TILDE] = ACTIONS(2061),
    [anon_sym_PLUS_PLUS] = ACTIONS(2061),
    [anon_sym_DASH_DASH] = ACTIONS(2061),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2059),
    [anon_sym_DASH] = ACTIONS(2059),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(2061),
    [anon_sym_AMP] = ACTIONS(2061),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2063),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2065),
    [anon_sym_DOT_DOT] = ACTIONS(2067),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2196] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6642),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2196),
    [sym_preproc_endregion] = STATE(2196),
    [sym_preproc_line] = STATE(2196),
    [sym_preproc_pragma] = STATE(2196),
    [sym_preproc_nullable] = STATE(2196),
    [sym_preproc_error] = STATE(2196),
    [sym_preproc_warning] = STATE(2196),
    [sym_preproc_define] = STATE(2196),
    [sym_preproc_undef] = STATE(2196),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2197] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6952),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6643),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4473),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9905),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2197),
    [sym_preproc_endregion] = STATE(2197),
    [sym_preproc_line] = STATE(2197),
    [sym_preproc_pragma] = STATE(2197),
    [sym_preproc_nullable] = STATE(2197),
    [sym_preproc_error] = STATE(2197),
    [sym_preproc_warning] = STATE(2197),
    [sym_preproc_define] = STATE(2197),
    [sym_preproc_undef] = STATE(2197),
    [aux_sym_class_declaration_repeat1] = STATE(3878),
    [aux_sym_lambda_expression_repeat1] = STATE(4331),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2055),
    [anon_sym_ref] = ACTIONS(2057),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2061),
    [anon_sym_TILDE] = ACTIONS(2061),
    [anon_sym_PLUS_PLUS] = ACTIONS(2061),
    [anon_sym_DASH_DASH] = ACTIONS(2061),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2059),
    [anon_sym_DASH] = ACTIONS(2059),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(2061),
    [anon_sym_AMP] = ACTIONS(2061),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2063),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2065),
    [anon_sym_DOT_DOT] = ACTIONS(2067),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2198] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6954),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6650),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4473),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9905),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2198),
    [sym_preproc_endregion] = STATE(2198),
    [sym_preproc_line] = STATE(2198),
    [sym_preproc_pragma] = STATE(2198),
    [sym_preproc_nullable] = STATE(2198),
    [sym_preproc_error] = STATE(2198),
    [sym_preproc_warning] = STATE(2198),
    [sym_preproc_define] = STATE(2198),
    [sym_preproc_undef] = STATE(2198),
    [aux_sym_class_declaration_repeat1] = STATE(3878),
    [aux_sym_lambda_expression_repeat1] = STATE(4331),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2055),
    [anon_sym_ref] = ACTIONS(2057),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2061),
    [anon_sym_TILDE] = ACTIONS(2061),
    [anon_sym_PLUS_PLUS] = ACTIONS(2061),
    [anon_sym_DASH_DASH] = ACTIONS(2061),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2059),
    [anon_sym_DASH] = ACTIONS(2059),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(2061),
    [anon_sym_AMP] = ACTIONS(2061),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2063),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2065),
    [anon_sym_DOT_DOT] = ACTIONS(2067),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2199] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6651),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2199),
    [sym_preproc_endregion] = STATE(2199),
    [sym_preproc_line] = STATE(2199),
    [sym_preproc_pragma] = STATE(2199),
    [sym_preproc_nullable] = STATE(2199),
    [sym_preproc_error] = STATE(2199),
    [sym_preproc_warning] = STATE(2199),
    [sym_preproc_define] = STATE(2199),
    [sym_preproc_undef] = STATE(2199),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2200] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6261),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2772),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(6931),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6652),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4473),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9905),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2200),
    [sym_preproc_endregion] = STATE(2200),
    [sym_preproc_line] = STATE(2200),
    [sym_preproc_pragma] = STATE(2200),
    [sym_preproc_nullable] = STATE(2200),
    [sym_preproc_error] = STATE(2200),
    [sym_preproc_warning] = STATE(2200),
    [sym_preproc_define] = STATE(2200),
    [sym_preproc_undef] = STATE(2200),
    [aux_sym_class_declaration_repeat1] = STATE(3878),
    [aux_sym_lambda_expression_repeat1] = STATE(4331),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(2055),
    [anon_sym_ref] = ACTIONS(2057),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(2061),
    [anon_sym_TILDE] = ACTIONS(2061),
    [anon_sym_PLUS_PLUS] = ACTIONS(2061),
    [anon_sym_DASH_DASH] = ACTIONS(2061),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(2059),
    [anon_sym_DASH] = ACTIONS(2059),
    [anon_sym_STAR] = ACTIONS(81),
    [anon_sym_CARET] = ACTIONS(2061),
    [anon_sym_AMP] = ACTIONS(2061),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(2063),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(2065),
    [anon_sym_DOT_DOT] = ACTIONS(2067),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2201] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3030),
    [sym__name] = STATE(6934),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2806),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7125),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(6664),
    [sym_non_lvalue_expression] = STATE(3762),
    [sym_lvalue_expression] = STATE(4135),
    [sym__expression_statement_expression] = STATE(3765),
    [sym_assignment_expression] = STATE(3771),
    [sym_binary_expression] = STATE(3765),
    [sym_postfix_unary_expression] = STATE(3771),
    [sym_prefix_unary_expression] = STATE(3771),
    [sym__pointer_indirection_expression] = STATE(3049),
    [sym_query_expression] = STATE(3765),
    [sym_from_clause] = STATE(7414),
    [sym_conditional_expression] = STATE(3765),
    [sym_conditional_access_expression] = STATE(3765),
    [sym_as_expression] = STATE(3765),
    [sym_is_expression] = STATE(3765),
    [sym_is_pattern_expression] = STATE(3765),
    [sym_cast_expression] = STATE(3765),
    [sym_checked_expression] = STATE(3765),
    [sym_invocation_expression] = STATE(3771),
    [sym_switch_expression] = STATE(3765),
    [sym_await_expression] = STATE(3771),
    [sym_throw_expression] = STATE(3765),
    [sym_element_access_expression] = STATE(3049),
    [sym_interpolated_string_expression] = STATE(3765),
    [sym_member_access_expression] = STATE(3049),
    [sym_object_creation_expression] = STATE(3771),
    [sym_parenthesized_expression] = STATE(3771),
    [sym__parenthesized_lvalue_expression] = STATE(3049),
    [sym_lambda_expression] = STATE(3765),
    [sym__lambda_parameters] = STATE(9817),
    [sym_array_creation_expression] = STATE(3765),
    [sym_anonymous_method_expression] = STATE(3765),
    [sym_anonymous_object_creation_expression] = STATE(3765),
    [sym_implicit_array_creation_expression] = STATE(3765),
    [sym_implicit_object_creation_expression] = STATE(3765),
    [sym_implicit_stackalloc_expression] = STATE(3765),
    [sym_initializer_expression] = STATE(3765),
    [sym_default_expression] = STATE(3765),
    [sym_with_expression] = STATE(3765),
    [sym_sizeof_expression] = STATE(3765),
    [sym_typeof_expression] = STATE(3765),
    [sym_makeref_expression] = STATE(3765),
    [sym_ref_expression] = STATE(3765),
    [sym_reftype_expression] = STATE(3765),
    [sym_refvalue_expression] = STATE(3765),
    [sym_stackalloc_expression] = STATE(3765),
    [sym_range_expression] = STATE(3765),
    [sym_tuple_expression] = STATE(3049),
    [sym_literal] = STATE(3765),
    [sym_character_literal] = STATE(4127),
    [sym_string_literal] = STATE(4127),
    [sym_raw_string_literal] = STATE(4127),
    [sym_boolean_literal] = STATE(4127),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(3765),
    [sym_preproc_region] = STATE(2201),
    [sym_preproc_endregion] = STATE(2201),
    [sym_preproc_line] = STATE(2201),
    [sym_preproc_pragma] = STATE(2201),
    [sym_preproc_nullable] = STATE(2201),
    [sym_preproc_error] = STATE(2201),
    [sym_preproc_warning] = STATE(2201),
    [sym_preproc_define] = STATE(2201),
    [sym_preproc_undef] = STATE(2201),
    [aux_sym_class_declaration_repeat1] = STATE(3859),
    [aux_sym_lambda_expression_repeat1] = STATE(4286),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(675),
    [anon_sym_ref] = ACTIONS(679),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_delegate] = ACTIONS(685),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1075),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1081),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_true] = ACTIONS(77),
    [anon_sym_false] = ACTIONS(77),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_STAR] = ACTIONS(699),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1513),
    [anon_sym_this] = ACTIONS(83),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(87),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(91),
    [anon_sym_unchecked] = ACTIONS(1081),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(109),
    [anon_sym_throw] = ACTIONS(1093),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1095),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(127),
    [anon_sym_sizeof] = ACTIONS(129),
    [anon_sym_typeof] = ACTIONS(131),
    [anon_sym___makeref] = ACTIONS(133),
    [anon_sym___reftype] = ACTIONS(135),
    [anon_sym___refvalue] = ACTIONS(137),
    [sym_null_literal] = ACTIONS(139),
    [anon_sym_SQUOTE] = ACTIONS(141),
    [sym_integer_literal] = ACTIONS(139),
    [sym_real_literal] = ACTIONS(143),
    [anon_sym_DQUOTE] = ACTIONS(145),
    [sym_verbatim_string_literal] = ACTIONS(143),
    [aux_sym_preproc_if_token1] = ACTIONS(1103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(151),
    [sym_interpolation_verbatim_start] = ACTIONS(153),
    [sym_interpolation_raw_start] = ACTIONS(155),
    [sym_raw_string_start] = ACTIONS(157),
  },
  [2202] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym_bracketed_argument_list] = STATE(3190),
    [sym__name] = STATE(6941),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(2977),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_type] = STATE(7077),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_expression] = STATE(5475),
    [sym_non_lvalue_expression] = STATE(4001),
    [sym_lvalue_expression] = STATE(4200),
    [sym__expression_statement_expression] = STATE(4018),
    [sym_assignment_expression] = STATE(4053),
    [sym_binary_expression] = STATE(4018),
    [sym_postfix_unary_expression] = STATE(4053),
    [sym_prefix_unary_expression] = STATE(4053),
    [sym__pointer_indirection_expression] = STATE(3194),
    [sym_query_expression] = STATE(4018),
    [sym_from_clause] = STATE(7415),
    [sym_conditional_expression] = STATE(4018),
    [sym_conditional_access_expression] = STATE(4018),
    [sym_as_expression] = STATE(4018),
    [sym_is_expression] = STATE(4018),
    [sym_is_pattern_expression] = STATE(4018),
    [sym_cast_expression] = STATE(4018),
    [sym_checked_expression] = STATE(4018),
    [sym_invocation_expression] = STATE(4053),
    [sym_switch_expression] = STATE(4018),
    [sym_await_expression] = STATE(4053),
    [sym_throw_expression] = STATE(4018),
    [sym_element_access_expression] = STATE(3194),
    [sym_interpolated_string_expression] = STATE(4018),
    [sym_member_access_expression] = STATE(3194),
    [sym_object_creation_expression] = STATE(4053),
    [sym_parenthesized_expression] = STATE(4053),
    [sym__parenthesized_lvalue_expression] = STATE(3194),
    [sym_lambda_expression] = STATE(4018),
    [sym__lambda_parameters] = STATE(9773),
    [sym_array_creation_expression] = STATE(4018),
    [sym_anonymous_method_expression] = STATE(4018),
    [sym_anonymous_object_creation_expression] = STATE(4018),
    [sym_implicit_array_creation_expression] = STATE(4018),
    [sym_implicit_object_creation_expression] = STATE(4018),
    [sym_implicit_stackalloc_expression] = STATE(4018),
    [sym_initializer_expression] = STATE(4018),
    [sym_default_expression] = STATE(4018),
    [sym_with_expression] = STATE(4018),
    [sym_sizeof_expression] = STATE(4018),
    [sym_typeof_expression] = STATE(4018),
    [sym_makeref_expression] = STATE(4018),
    [sym_ref_expression] = STATE(4018),
    [sym_reftype_expression] = STATE(4018),
    [sym_refvalue_expression] = STATE(4018),
    [sym_stackalloc_expression] = STATE(4018),
    [sym_range_expression] = STATE(4018),
    [sym_tuple_expression] = STATE(3194),
    [sym_literal] = STATE(4018),
    [sym_character_literal] = STATE(4062),
    [sym_string_literal] = STATE(4062),
    [sym_raw_string_literal] = STATE(4062),
    [sym_boolean_literal] = STATE(4062),
    [sym_identifier] = STATE(2748),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_if_in_expression] = STATE(4018),
    [sym_preproc_region] = STATE(2202),
    [sym_preproc_endregion] = STATE(2202),
    [sym_preproc_line] = STATE(2202),
    [sym_preproc_pragma] = STATE(2202),
    [sym_preproc_nullable] = STATE(2202),
    [sym_preproc_error] = STATE(2202),
    [sym_preproc_warning] = STATE(2202),
    [sym_preproc_define] = STATE(2202),
    [sym_preproc_undef] = STATE(2202),
    [aux_sym_class_declaration_repeat1] = STATE(3843),
    [aux_sym_lambda_expression_repeat1] = STATE(4275),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(1159),
    [anon_sym_LPAREN] = ACTIONS(1911),
    [anon_sym_ref] = ACTIONS(1913),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_delegate] = ACTIONS(1167),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_new] = ACTIONS(1915),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_checked] = ACTIONS(1173),
    [anon_sym_BANG] = ACTIONS(1919),
    [anon_sym_TILDE] = ACTIONS(1919),
    [anon_sym_PLUS_PLUS] = ACTIONS(1919),
    [anon_sym_DASH_DASH] = ACTIONS(1919),
    [anon_sym_true] = ACTIONS(1179),
    [anon_sym_false] = ACTIONS(1179),
    [anon_sym_PLUS] = ACTIONS(1917),
    [anon_sym_DASH] = ACTIONS(1917),
    [anon_sym_STAR] = ACTIONS(1921),
    [anon_sym_CARET] = ACTIONS(1919),
    [anon_sym_AMP] = ACTIONS(1919),
    [anon_sym_this] = ACTIONS(1183),
    [anon_sym_scoped] = ACTIONS(85),
    [anon_sym_base] = ACTIONS(1185),
    [anon_sym_var] = ACTIONS(89),
    [sym_predefined_type] = ACTIONS(1187),
    [anon_sym_unchecked] = ACTIONS(1173),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_default] = ACTIONS(1189),
    [anon_sym_throw] = ACTIONS(1923),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_await] = ACTIONS(1925),
    [anon_sym_DOT_DOT] = ACTIONS(1927),
    [anon_sym_from] = ACTIONS(125),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [anon_sym_stackalloc] = ACTIONS(1197),
    [anon_sym_sizeof] = ACTIONS(1199),
    [anon_sym_typeof] = ACTIONS(1201),
    [anon_sym___makeref] = ACTIONS(1203),
    [anon_sym___reftype] = ACTIONS(1205),
    [anon_sym___refvalue] = ACTIONS(1207),
    [sym_null_literal] = ACTIONS(1209),
    [anon_sym_SQUOTE] = ACTIONS(1211),
    [sym_integer_literal] = ACTIONS(1209),
    [sym_real_literal] = ACTIONS(1213),
    [anon_sym_DQUOTE] = ACTIONS(1215),
    [sym_verbatim_string_literal] = ACTIONS(1213),
    [aux_sym_preproc_if_token1] = ACTIONS(1217),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(1219),
    [sym_interpolation_verbatim_start] = ACTIONS(1221),
    [sym_interpolation_raw_start] = ACTIONS(1223),
    [sym_raw_string_start] = ACTIONS(1225),
  },
  [2203] = {
    [sym_preproc_region] = STATE(2203),
    [sym_preproc_endregion] = STATE(2203),
    [sym_preproc_line] = STATE(2203),
    [sym_preproc_pragma] = STATE(2203),
    [sym_preproc_nullable] = STATE(2203),
    [sym_preproc_error] = STATE(2203),
    [sym_preproc_warning] = STATE(2203),
    [sym_preproc_define] = STATE(2203),
    [sym_preproc_undef] = STATE(2203),
    [sym__identifier_token] = ACTIONS(2987),
    [anon_sym_extern] = ACTIONS(2987),
    [anon_sym_alias] = ACTIONS(2987),
    [anon_sym_SEMI] = ACTIONS(2989),
    [anon_sym_global] = ACTIONS(2987),
    [anon_sym_using] = ACTIONS(2987),
    [anon_sym_unsafe] = ACTIONS(2987),
    [anon_sym_static] = ACTIONS(2987),
    [anon_sym_LBRACK] = ACTIONS(2989),
    [anon_sym_LPAREN] = ACTIONS(2989),
    [anon_sym_return] = ACTIONS(2987),
    [anon_sym_namespace] = ACTIONS(2987),
    [anon_sym_class] = ACTIONS(2987),
    [anon_sym_ref] = ACTIONS(2987),
    [anon_sym_struct] = ACTIONS(2987),
    [anon_sym_enum] = ACTIONS(2987),
    [anon_sym_LBRACE] = ACTIONS(2989),
    [anon_sym_interface] = ACTIONS(2987),
    [anon_sym_delegate] = ACTIONS(2987),
    [anon_sym_record] = ACTIONS(2987),
    [anon_sym_abstract] = ACTIONS(2987),
    [anon_sym_async] = ACTIONS(2987),
    [anon_sym_const] = ACTIONS(2987),
    [anon_sym_file] = ACTIONS(2987),
    [anon_sym_fixed] = ACTIONS(2987),
    [anon_sym_internal] = ACTIONS(2987),
    [anon_sym_new] = ACTIONS(2987),
    [anon_sym_override] = ACTIONS(2987),
    [anon_sym_partial] = ACTIONS(2987),
    [anon_sym_private] = ACTIONS(2987),
    [anon_sym_protected] = ACTIONS(2987),
    [anon_sym_public] = ACTIONS(2987),
    [anon_sym_readonly] = ACTIONS(2987),
    [anon_sym_required] = ACTIONS(2987),
    [anon_sym_sealed] = ACTIONS(2987),
    [anon_sym_virtual] = ACTIONS(2987),
    [anon_sym_volatile] = ACTIONS(2987),
    [anon_sym_LT] = ACTIONS(2991),
    [anon_sym_GT] = ACTIONS(2991),
    [anon_sym_where] = ACTIONS(2987),
    [anon_sym_QMARK] = ACTIONS(2991),
    [anon_sym_notnull] = ACTIONS(2987),
    [anon_sym_unmanaged] = ACTIONS(2987),
    [anon_sym_checked] = ACTIONS(2987),
    [anon_sym_BANG] = ACTIONS(2987),
    [anon_sym_TILDE] = ACTIONS(2989),
    [anon_sym_PLUS_PLUS] = ACTIONS(2989),
    [anon_sym_DASH_DASH] = ACTIONS(2989),
    [anon_sym_true] = ACTIONS(2987),
    [anon_sym_false] = ACTIONS(2987),
    [anon_sym_PLUS] = ACTIONS(2987),
    [anon_sym_DASH] = ACTIONS(2987),
    [anon_sym_STAR] = ACTIONS(2989),
    [anon_sym_SLASH] = ACTIONS(2991),
    [anon_sym_PERCENT] = ACTIONS(2993),
    [anon_sym_CARET] = ACTIONS(2989),
    [anon_sym_PIPE] = ACTIONS(2991),
    [anon_sym_AMP] = ACTIONS(2987),
    [anon_sym_LT_LT] = ACTIONS(2993),
    [anon_sym_GT_GT] = ACTIONS(2991),
    [anon_sym_GT_GT_GT] = ACTIONS(2993),
    [anon_sym_EQ_EQ] = ACTIONS(2993),
    [anon_sym_BANG_EQ] = ACTIONS(2993),
    [anon_sym_GT_EQ] = ACTIONS(2993),
    [anon_sym_LT_EQ] = ACTIONS(2993),
    [anon_sym_this] = ACTIONS(2987),
    [anon_sym_DOT] = ACTIONS(2991),
    [anon_sym_scoped] = ACTIONS(2987),
    [anon_sym_base] = ACTIONS(2987),
    [anon_sym_var] = ACTIONS(2987),
    [sym_predefined_type] = ACTIONS(2987),
    [anon_sym_break] = ACTIONS(2987),
    [anon_sym_unchecked] = ACTIONS(2987),
    [anon_sym_continue] = ACTIONS(2987),
    [anon_sym_do] = ACTIONS(2987),
    [anon_sym_while] = ACTIONS(2987),
    [anon_sym_for] = ACTIONS(2987),
    [anon_sym_lock] = ACTIONS(2987),
    [anon_sym_yield] = ACTIONS(2987),
    [anon_sym_switch] = ACTIONS(2987),
    [anon_sym_default] = ACTIONS(2987),
    [anon_sym_throw] = ACTIONS(2987),
    [anon_sym_try] = ACTIONS(2987),
    [anon_sym_when] = ACTIONS(2987),
    [anon_sym_await] = ACTIONS(2987),
    [anon_sym_foreach] = ACTIONS(2987),
    [anon_sym_goto] = ACTIONS(2987),
    [anon_sym_if] = ACTIONS(2987),
    [anon_sym_else] = ACTIONS(2987),
    [anon_sym_DOT_DOT] = ACTIONS(2989),
    [anon_sym_AMP_AMP] = ACTIONS(2993),
    [anon_sym_PIPE_PIPE] = ACTIONS(2993),
    [anon_sym_QMARK_QMARK] = ACTIONS(2993),
    [anon_sym_from] = ACTIONS(2987),
    [anon_sym_into] = ACTIONS(2987),
    [anon_sym_join] = ACTIONS(2987),
    [anon_sym_on] = ACTIONS(2987),
    [anon_sym_equals] = ACTIONS(2987),
    [anon_sym_let] = ACTIONS(2987),
    [anon_sym_orderby] = ACTIONS(2987),
    [anon_sym_ascending] = ACTIONS(2987),
    [anon_sym_descending] = ACTIONS(2987),
    [anon_sym_group] = ACTIONS(2987),
    [anon_sym_by] = ACTIONS(2987),
    [anon_sym_select] = ACTIONS(2987),
    [anon_sym_as] = ACTIONS(2991),
    [anon_sym_is] = ACTIONS(2991),
    [anon_sym_DASH_GT] = ACTIONS(2993),
    [anon_sym_stackalloc] = ACTIONS(2987),
    [anon_sym_with] = ACTIONS(2991),
    [anon_sym_sizeof] = ACTIONS(2987),
    [anon_sym_typeof] = ACTIONS(2987),
    [anon_sym___makeref] = ACTIONS(2987),
    [anon_sym___reftype] = ACTIONS(2987),
    [anon_sym___refvalue] = ACTIONS(2987),
    [sym_null_literal] = ACTIONS(2987),
    [anon_sym_SQUOTE] = ACTIONS(2989),
    [sym_integer_literal] = ACTIONS(2987),
    [sym_real_literal] = ACTIONS(2989),
    [anon_sym_DQUOTE] = ACTIONS(2989),
    [sym_verbatim_string_literal] = ACTIONS(2989),
    [aux_sym_preproc_if_token1] = ACTIONS(2989),
    [aux_sym_preproc_if_token3] = ACTIONS(2989),
    [aux_sym_preproc_else_token1] = ACTIONS(2989),
    [aux_sym_preproc_elif_token1] = ACTIONS(2989),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(2989),
    [sym_interpolation_verbatim_start] = ACTIONS(2989),
    [sym_interpolation_raw_start] = ACTIONS(2989),
    [sym_raw_string_start] = ACTIONS(2989),
  },
  [2204] = {
    [sym_preproc_region] = STATE(2204),
    [sym_preproc_endregion] = STATE(2204),
    [sym_preproc_line] = STATE(2204),
    [sym_preproc_pragma] = STATE(2204),
    [sym_preproc_nullable] = STATE(2204),
    [sym_preproc_error] = STATE(2204),
    [sym_preproc_warning] = STATE(2204),
    [sym_preproc_define] = STATE(2204),
    [sym_preproc_undef] = STATE(2204),
    [sym__identifier_token] = ACTIONS(2995),
    [anon_sym_extern] = ACTIONS(2995),
    [anon_sym_alias] = ACTIONS(2995),
    [anon_sym_SEMI] = ACTIONS(2997),
    [anon_sym_global] = ACTIONS(2995),
    [anon_sym_using] = ACTIONS(2995),
    [anon_sym_unsafe] = ACTIONS(2995),
    [anon_sym_static] = ACTIONS(2995),
    [anon_sym_LBRACK] = ACTIONS(2997),
    [anon_sym_LPAREN] = ACTIONS(2997),
    [anon_sym_return] = ACTIONS(2995),
    [anon_sym_namespace] = ACTIONS(2995),
    [anon_sym_class] = ACTIONS(2995),
    [anon_sym_ref] = ACTIONS(2995),
    [anon_sym_struct] = ACTIONS(2995),
    [anon_sym_enum] = ACTIONS(2995),
    [anon_sym_LBRACE] = ACTIONS(2997),
    [anon_sym_interface] = ACTIONS(2995),
    [anon_sym_delegate] = ACTIONS(2995),
    [anon_sym_record] = ACTIONS(2995),
    [anon_sym_abstract] = ACTIONS(2995),
    [anon_sym_async] = ACTIONS(2995),
    [anon_sym_const] = ACTIONS(2995),
    [anon_sym_file] = ACTIONS(2995),
    [anon_sym_fixed] = ACTIONS(2995),
    [anon_sym_internal] = ACTIONS(2995),
    [anon_sym_new] = ACTIONS(2995),
    [anon_sym_override] = ACTIONS(2995),
    [anon_sym_partial] = ACTIONS(2995),
    [anon_sym_private] = ACTIONS(2995),
    [anon_sym_protected] = ACTIONS(2995),
    [anon_sym_public] = ACTIONS(2995),
    [anon_sym_readonly] = ACTIONS(2995),
    [anon_sym_required] = ACTIONS(2995),
    [anon_sym_sealed] = ACTIONS(2995),
    [anon_sym_virtual] = ACTIONS(2995),
    [anon_sym_volatile] = ACTIONS(2995),
    [anon_sym_LT] = ACTIONS(2999),
    [anon_sym_GT] = ACTIONS(2999),
    [anon_sym_where] = ACTIONS(2995),
    [anon_sym_QMARK] = ACTIONS(2999),
    [anon_sym_notnull] = ACTIONS(2995),
    [anon_sym_unmanaged] = ACTIONS(2995),
    [anon_sym_checked] = ACTIONS(2995),
    [anon_sym_BANG] = ACTIONS(2995),
    [anon_sym_TILDE] = ACTIONS(2997),
    [anon_sym_PLUS_PLUS] = ACTIONS(2997),
    [anon_sym_DASH_DASH] = ACTIONS(2997),
    [anon_sym_true] = ACTIONS(2995),
    [anon_sym_false] = ACTIONS(2995),
    [anon_sym_PLUS] = ACTIONS(2995),
    [anon_sym_DASH] = ACTIONS(2995),
    [anon_sym_STAR] = ACTIONS(2997),
    [anon_sym_SLASH] = ACTIONS(2999),
    [anon_sym_PERCENT] = ACTIONS(3001),
    [anon_sym_CARET] = ACTIONS(2997),
    [anon_sym_PIPE] = ACTIONS(2999),
    [anon_sym_AMP] = ACTIONS(2995),
    [anon_sym_LT_LT] = ACTIONS(3001),
    [anon_sym_GT_GT] = ACTIONS(2999),
    [anon_sym_GT_GT_GT] = ACTIONS(3001),
    [anon_sym_EQ_EQ] = ACTIONS(3001),
    [anon_sym_BANG_EQ] = ACTIONS(3001),
    [anon_sym_GT_EQ] = ACTIONS(3001),
    [anon_sym_LT_EQ] = ACTIONS(3001),
    [anon_sym_this] = ACTIONS(2995),
    [anon_sym_DOT] = ACTIONS(2999),
    [anon_sym_scoped] = ACTIONS(2995),
    [anon_sym_base] = ACTIONS(2995),
    [anon_sym_var] = ACTIONS(2995),
    [sym_predefined_type] = ACTIONS(2995),
    [anon_sym_break] = ACTIONS(2995),
    [anon_sym_unchecked] = ACTIONS(2995),
    [anon_sym_continue] = ACTIONS(2995),
    [anon_sym_do] = ACTIONS(2995),
    [anon_sym_while] = ACTIONS(2995),
    [anon_sym_for] = ACTIONS(2995),
    [anon_sym_lock] = ACTIONS(2995),
    [anon_sym_yield] = ACTIONS(2995),
    [anon_sym_switch] = ACTIONS(2995),
    [anon_sym_default] = ACTIONS(2995),
    [anon_sym_throw] = ACTIONS(2995),
    [anon_sym_try] = ACTIONS(2995),
    [anon_sym_when] = ACTIONS(2995),
    [anon_sym_await] = ACTIONS(2995),
    [anon_sym_foreach] = ACTIONS(2995),
    [anon_sym_goto] = ACTIONS(2995),
    [anon_sym_if] = ACTIONS(2995),
    [anon_sym_else] = ACTIONS(2995),
    [anon_sym_DOT_DOT] = ACTIONS(2997),
    [anon_sym_AMP_AMP] = ACTIONS(3001),
    [anon_sym_PIPE_PIPE] = ACTIONS(3001),
    [anon_sym_QMARK_QMARK] = ACTIONS(3001),
    [anon_sym_from] = ACTIONS(2995),
    [anon_sym_into] = ACTIONS(2995),
    [anon_sym_join] = ACTIONS(2995),
    [anon_sym_on] = ACTIONS(2995),
    [anon_sym_equals] = ACTIONS(2995),
    [anon_sym_let] = ACTIONS(2995),
    [anon_sym_orderby] = ACTIONS(2995),
    [anon_sym_ascending] = ACTIONS(2995),
    [anon_sym_descending] = ACTIONS(2995),
    [anon_sym_group] = ACTIONS(2995),
    [anon_sym_by] = ACTIONS(2995),
    [anon_sym_select] = ACTIONS(2995),
    [anon_sym_as] = ACTIONS(2999),
    [anon_sym_is] = ACTIONS(2999),
    [anon_sym_DASH_GT] = ACTIONS(3001),
    [anon_sym_stackalloc] = ACTIONS(2995),
    [anon_sym_with] = ACTIONS(2999),
    [anon_sym_sizeof] = ACTIONS(2995),
    [anon_sym_typeof] = ACTIONS(2995),
    [anon_sym___makeref] = ACTIONS(2995),
    [anon_sym___reftype] = ACTIONS(2995),
    [anon_sym___refvalue] = ACTIONS(2995),
    [sym_null_literal] = ACTIONS(2995),
    [anon_sym_SQUOTE] = ACTIONS(2997),
    [sym_integer_literal] = ACTIONS(2995),
    [sym_real_literal] = ACTIONS(2997),
    [anon_sym_DQUOTE] = ACTIONS(2997),
    [sym_verbatim_string_literal] = ACTIONS(2997),
    [aux_sym_preproc_if_token1] = ACTIONS(2997),
    [aux_sym_preproc_if_token3] = ACTIONS(2997),
    [aux_sym_preproc_else_token1] = ACTIONS(2997),
    [aux_sym_preproc_elif_token1] = ACTIONS(2997),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(2997),
    [sym_interpolation_verbatim_start] = ACTIONS(2997),
    [sym_interpolation_raw_start] = ACTIONS(2997),
    [sym_raw_string_start] = ACTIONS(2997),
  },
  [2205] = {
    [sym_preproc_region] = STATE(2205),
    [sym_preproc_endregion] = STATE(2205),
    [sym_preproc_line] = STATE(2205),
    [sym_preproc_pragma] = STATE(2205),
    [sym_preproc_nullable] = STATE(2205),
    [sym_preproc_error] = STATE(2205),
    [sym_preproc_warning] = STATE(2205),
    [sym_preproc_define] = STATE(2205),
    [sym_preproc_undef] = STATE(2205),
    [ts_builtin_sym_end] = ACTIONS(2989),
    [sym__identifier_token] = ACTIONS(2987),
    [anon_sym_extern] = ACTIONS(2987),
    [anon_sym_alias] = ACTIONS(2987),
    [anon_sym_SEMI] = ACTIONS(2989),
    [anon_sym_global] = ACTIONS(2987),
    [anon_sym_using] = ACTIONS(2987),
    [anon_sym_unsafe] = ACTIONS(2987),
    [anon_sym_static] = ACTIONS(2987),
    [anon_sym_LBRACK] = ACTIONS(2989),
    [anon_sym_LPAREN] = ACTIONS(2989),
    [anon_sym_return] = ACTIONS(2987),
    [anon_sym_namespace] = ACTIONS(2987),
    [anon_sym_class] = ACTIONS(2987),
    [anon_sym_ref] = ACTIONS(2987),
    [anon_sym_struct] = ACTIONS(2987),
    [anon_sym_enum] = ACTIONS(2987),
    [anon_sym_LBRACE] = ACTIONS(2989),
    [anon_sym_interface] = ACTIONS(2987),
    [anon_sym_delegate] = ACTIONS(2987),
    [anon_sym_record] = ACTIONS(2987),
    [anon_sym_abstract] = ACTIONS(2987),
    [anon_sym_async] = ACTIONS(2987),
    [anon_sym_const] = ACTIONS(2987),
    [anon_sym_file] = ACTIONS(2987),
    [anon_sym_fixed] = ACTIONS(2987),
    [anon_sym_internal] = ACTIONS(2987),
    [anon_sym_new] = ACTIONS(2987),
    [anon_sym_override] = ACTIONS(2987),
    [anon_sym_partial] = ACTIONS(2987),
    [anon_sym_private] = ACTIONS(2987),
    [anon_sym_protected] = ACTIONS(2987),
    [anon_sym_public] = ACTIONS(2987),
    [anon_sym_readonly] = ACTIONS(2987),
    [anon_sym_required] = ACTIONS(2987),
    [anon_sym_sealed] = ACTIONS(2987),
    [anon_sym_virtual] = ACTIONS(2987),
    [anon_sym_volatile] = ACTIONS(2987),
    [anon_sym_LT] = ACTIONS(2991),
    [anon_sym_GT] = ACTIONS(2991),
    [anon_sym_where] = ACTIONS(2987),
    [anon_sym_QMARK] = ACTIONS(2991),
    [anon_sym_notnull] = ACTIONS(2987),
    [anon_sym_unmanaged] = ACTIONS(2987),
    [anon_sym_checked] = ACTIONS(2987),
    [anon_sym_BANG] = ACTIONS(2987),
    [anon_sym_TILDE] = ACTIONS(2989),
    [anon_sym_PLUS_PLUS] = ACTIONS(2989),
    [anon_sym_DASH_DASH] = ACTIONS(2989),
    [anon_sym_true] = ACTIONS(2987),
    [anon_sym_false] = ACTIONS(2987),
    [anon_sym_PLUS] = ACTIONS(2987),
    [anon_sym_DASH] = ACTIONS(2987),
    [anon_sym_STAR] = ACTIONS(2989),
    [anon_sym_SLASH] = ACTIONS(2991),
    [anon_sym_PERCENT] = ACTIONS(2993),
    [anon_sym_CARET] = ACTIONS(2989),
    [anon_sym_PIPE] = ACTIONS(2991),
    [anon_sym_AMP] = ACTIONS(2987),
    [anon_sym_LT_LT] = ACTIONS(2993),
    [anon_sym_GT_GT] = ACTIONS(2991),
    [anon_sym_GT_GT_GT] = ACTIONS(2993),
    [anon_sym_EQ_EQ] = ACTIONS(2993),
    [anon_sym_BANG_EQ] = ACTIONS(2993),
    [anon_sym_GT_EQ] = ACTIONS(2993),
    [anon_sym_LT_EQ] = ACTIONS(2993),
    [anon_sym_this] = ACTIONS(2987),
    [anon_sym_DOT] = ACTIONS(2991),
    [anon_sym_scoped] = ACTIONS(2987),
    [anon_sym_base] = ACTIONS(2987),
    [anon_sym_var] = ACTIONS(2987),
    [sym_predefined_type] = ACTIONS(2987),
    [anon_sym_break] = ACTIONS(2987),
    [anon_sym_unchecked] = ACTIONS(2987),
    [anon_sym_continue] = ACTIONS(2987),
    [anon_sym_do] = ACTIONS(2987),
    [anon_sym_while] = ACTIONS(2987),
    [anon_sym_for] = ACTIONS(2987),
    [anon_sym_lock] = ACTIONS(2987),
    [anon_sym_yield] = ACTIONS(2987),
    [anon_sym_switch] = ACTIONS(2987),
    [anon_sym_default] = ACTIONS(2987),
    [anon_sym_throw] = ACTIONS(2987),
    [anon_sym_try] = ACTIONS(2987),
    [anon_sym_when] = ACTIONS(2987),
    [anon_sym_await] = ACTIONS(2987),
    [anon_sym_foreach] = ACTIONS(2987),
    [anon_sym_goto] = ACTIONS(2987),
    [anon_sym_if] = ACTIONS(2987),
    [anon_sym_else] = ACTIONS(2987),
    [anon_sym_DOT_DOT] = ACTIONS(2989),
    [anon_sym_AMP_AMP] = ACTIONS(2993),
    [anon_sym_PIPE_PIPE] = ACTIONS(2993),
    [anon_sym_QMARK_QMARK] = ACTIONS(2993),
    [anon_sym_from] = ACTIONS(2987),
    [anon_sym_into] = ACTIONS(2987),
    [anon_sym_join] = ACTIONS(2987),
    [anon_sym_on] = ACTIONS(2987),
    [anon_sym_equals] = ACTIONS(2987),
    [anon_sym_let] = ACTIONS(2987),
    [anon_sym_orderby] = ACTIONS(2987),
    [anon_sym_ascending] = ACTIONS(2987),
    [anon_sym_descending] = ACTIONS(2987),
    [anon_sym_group] = ACTIONS(2987),
    [anon_sym_by] = ACTIONS(2987),
    [anon_sym_select] = ACTIONS(2987),
    [anon_sym_as] = ACTIONS(2991),
    [anon_sym_is] = ACTIONS(2991),
    [anon_sym_DASH_GT] = ACTIONS(2993),
    [anon_sym_stackalloc] = ACTIONS(2987),
    [anon_sym_with] = ACTIONS(2991),
    [anon_sym_sizeof] = ACTIONS(2987),
    [anon_sym_typeof] = ACTIONS(2987),
    [anon_sym___makeref] = ACTIONS(2987),
    [anon_sym___reftype] = ACTIONS(2987),
    [anon_sym___refvalue] = ACTIONS(2987),
    [sym_null_literal] = ACTIONS(2987),
    [anon_sym_SQUOTE] = ACTIONS(2989),
    [sym_integer_literal] = ACTIONS(2987),
    [sym_real_literal] = ACTIONS(2989),
    [anon_sym_DQUOTE] = ACTIONS(2989),
    [sym_verbatim_string_literal] = ACTIONS(2989),
    [aux_sym_preproc_if_token1] = ACTIONS(2989),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(2989),
    [sym_interpolation_verbatim_start] = ACTIONS(2989),
    [sym_interpolation_raw_start] = ACTIONS(2989),
    [sym_raw_string_start] = ACTIONS(2989),
  },
  [2206] = {
    [sym_preproc_region] = STATE(2206),
    [sym_preproc_endregion] = STATE(2206),
    [sym_preproc_line] = STATE(2206),
    [sym_preproc_pragma] = STATE(2206),
    [sym_preproc_nullable] = STATE(2206),
    [sym_preproc_error] = STATE(2206),
    [sym_preproc_warning] = STATE(2206),
    [sym_preproc_define] = STATE(2206),
    [sym_preproc_undef] = STATE(2206),
    [ts_builtin_sym_end] = ACTIONS(2997),
    [sym__identifier_token] = ACTIONS(2995),
    [anon_sym_extern] = ACTIONS(2995),
    [anon_sym_alias] = ACTIONS(2995),
    [anon_sym_SEMI] = ACTIONS(2997),
    [anon_sym_global] = ACTIONS(2995),
    [anon_sym_using] = ACTIONS(2995),
    [anon_sym_unsafe] = ACTIONS(2995),
    [anon_sym_static] = ACTIONS(2995),
    [anon_sym_LBRACK] = ACTIONS(2997),
    [anon_sym_LPAREN] = ACTIONS(2997),
    [anon_sym_return] = ACTIONS(2995),
    [anon_sym_namespace] = ACTIONS(2995),
    [anon_sym_class] = ACTIONS(2995),
    [anon_sym_ref] = ACTIONS(2995),
    [anon_sym_struct] = ACTIONS(2995),
    [anon_sym_enum] = ACTIONS(2995),
    [anon_sym_LBRACE] = ACTIONS(2997),
    [anon_sym_interface] = ACTIONS(2995),
    [anon_sym_delegate] = ACTIONS(2995),
    [anon_sym_record] = ACTIONS(2995),
    [anon_sym_abstract] = ACTIONS(2995),
    [anon_sym_async] = ACTIONS(2995),
    [anon_sym_const] = ACTIONS(2995),
    [anon_sym_file] = ACTIONS(2995),
    [anon_sym_fixed] = ACTIONS(2995),
    [anon_sym_internal] = ACTIONS(2995),
    [anon_sym_new] = ACTIONS(2995),
    [anon_sym_override] = ACTIONS(2995),
    [anon_sym_partial] = ACTIONS(2995),
    [anon_sym_private] = ACTIONS(2995),
    [anon_sym_protected] = ACTIONS(2995),
    [anon_sym_public] = ACTIONS(2995),
    [anon_sym_readonly] = ACTIONS(2995),
    [anon_sym_required] = ACTIONS(2995),
    [anon_sym_sealed] = ACTIONS(2995),
    [anon_sym_virtual] = ACTIONS(2995),
    [anon_sym_volatile] = ACTIONS(2995),
    [anon_sym_LT] = ACTIONS(2999),
    [anon_sym_GT] = ACTIONS(2999),
    [anon_sym_where] = ACTIONS(2995),
    [anon_sym_QMARK] = ACTIONS(2999),
    [anon_sym_notnull] = ACTIONS(2995),
    [anon_sym_unmanaged] = ACTIONS(2995),
    [anon_sym_checked] = ACTIONS(2995),
    [anon_sym_BANG] = ACTIONS(2995),
    [anon_sym_TILDE] = ACTIONS(2997),
    [anon_sym_PLUS_PLUS] = ACTIONS(2997),
    [anon_sym_DASH_DASH] = ACTIONS(2997),
    [anon_sym_true] = ACTIONS(2995),
    [anon_sym_false] = ACTIONS(2995),
    [anon_sym_PLUS] = ACTIONS(2995),
    [anon_sym_DASH] = ACTIONS(2995),
    [anon_sym_STAR] = ACTIONS(2997),
    [anon_sym_SLASH] = ACTIONS(2999),
    [anon_sym_PERCENT] = ACTIONS(3001),
    [anon_sym_CARET] = ACTIONS(2997),
    [anon_sym_PIPE] = ACTIONS(2999),
    [anon_sym_AMP] = ACTIONS(2995),
    [anon_sym_LT_LT] = ACTIONS(3001),
    [anon_sym_GT_GT] = ACTIONS(2999),
    [anon_sym_GT_GT_GT] = ACTIONS(3001),
    [anon_sym_EQ_EQ] = ACTIONS(3001),
    [anon_sym_BANG_EQ] = ACTIONS(3001),
    [anon_sym_GT_EQ] = ACTIONS(3001),
    [anon_sym_LT_EQ] = ACTIONS(3001),
    [anon_sym_this] = ACTIONS(2995),
    [anon_sym_DOT] = ACTIONS(2999),
    [anon_sym_scoped] = ACTIONS(2995),
    [anon_sym_base] = ACTIONS(2995),
    [anon_sym_var] = ACTIONS(2995),
    [sym_predefined_type] = ACTIONS(2995),
    [anon_sym_break] = ACTIONS(2995),
    [anon_sym_unchecked] = ACTIONS(2995),
    [anon_sym_continue] = ACTIONS(2995),
    [anon_sym_do] = ACTIONS(2995),
    [anon_sym_while] = ACTIONS(2995),
    [anon_sym_for] = ACTIONS(2995),
    [anon_sym_lock] = ACTIONS(2995),
    [anon_sym_yield] = ACTIONS(2995),
    [anon_sym_switch] = ACTIONS(2995),
    [anon_sym_default] = ACTIONS(2995),
    [anon_sym_throw] = ACTIONS(2995),
    [anon_sym_try] = ACTIONS(2995),
    [anon_sym_when] = ACTIONS(2995),
    [anon_sym_await] = ACTIONS(2995),
    [anon_sym_foreach] = ACTIONS(2995),
    [anon_sym_goto] = ACTIONS(2995),
    [anon_sym_if] = ACTIONS(2995),
    [anon_sym_else] = ACTIONS(2995),
    [anon_sym_DOT_DOT] = ACTIONS(2997),
    [anon_sym_AMP_AMP] = ACTIONS(3001),
    [anon_sym_PIPE_PIPE] = ACTIONS(3001),
    [anon_sym_QMARK_QMARK] = ACTIONS(3001),
    [anon_sym_from] = ACTIONS(2995),
    [anon_sym_into] = ACTIONS(2995),
    [anon_sym_join] = ACTIONS(2995),
    [anon_sym_on] = ACTIONS(2995),
    [anon_sym_equals] = ACTIONS(2995),
    [anon_sym_let] = ACTIONS(2995),
    [anon_sym_orderby] = ACTIONS(2995),
    [anon_sym_ascending] = ACTIONS(2995),
    [anon_sym_descending] = ACTIONS(2995),
    [anon_sym_group] = ACTIONS(2995),
    [anon_sym_by] = ACTIONS(2995),
    [anon_sym_select] = ACTIONS(2995),
    [anon_sym_as] = ACTIONS(2999),
    [anon_sym_is] = ACTIONS(2999),
    [anon_sym_DASH_GT] = ACTIONS(3001),
    [anon_sym_stackalloc] = ACTIONS(2995),
    [anon_sym_with] = ACTIONS(2999),
    [anon_sym_sizeof] = ACTIONS(2995),
    [anon_sym_typeof] = ACTIONS(2995),
    [anon_sym___makeref] = ACTIONS(2995),
    [anon_sym___reftype] = ACTIONS(2995),
    [anon_sym___refvalue] = ACTIONS(2995),
    [sym_null_literal] = ACTIONS(2995),
    [anon_sym_SQUOTE] = ACTIONS(2997),
    [sym_integer_literal] = ACTIONS(2995),
    [sym_real_literal] = ACTIONS(2997),
    [anon_sym_DQUOTE] = ACTIONS(2997),
    [sym_verbatim_string_literal] = ACTIONS(2997),
    [aux_sym_preproc_if_token1] = ACTIONS(2997),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(2997),
    [sym_interpolation_verbatim_start] = ACTIONS(2997),
    [sym_interpolation_raw_start] = ACTIONS(2997),
    [sym_raw_string_start] = ACTIONS(2997),
  },
  [2207] = {
    [sym_preproc_region] = STATE(2207),
    [sym_preproc_endregion] = STATE(2207),
    [sym_preproc_line] = STATE(2207),
    [sym_preproc_pragma] = STATE(2207),
    [sym_preproc_nullable] = STATE(2207),
    [sym_preproc_error] = STATE(2207),
    [sym_preproc_warning] = STATE(2207),
    [sym_preproc_define] = STATE(2207),
    [sym_preproc_undef] = STATE(2207),
    [sym__identifier_token] = ACTIONS(2995),
    [anon_sym_extern] = ACTIONS(2995),
    [anon_sym_alias] = ACTIONS(2995),
    [anon_sym_SEMI] = ACTIONS(2997),
    [anon_sym_global] = ACTIONS(2995),
    [anon_sym_using] = ACTIONS(2995),
    [anon_sym_unsafe] = ACTIONS(2995),
    [anon_sym_static] = ACTIONS(2995),
    [anon_sym_LBRACK] = ACTIONS(2997),
    [anon_sym_COMMA] = ACTIONS(3001),
    [anon_sym_LPAREN] = ACTIONS(2997),
    [anon_sym_return] = ACTIONS(2995),
    [anon_sym_ref] = ACTIONS(2995),
    [anon_sym_LBRACE] = ACTIONS(2997),
    [anon_sym_RBRACE] = ACTIONS(2997),
    [anon_sym_delegate] = ACTIONS(2995),
    [anon_sym_abstract] = ACTIONS(2995),
    [anon_sym_async] = ACTIONS(2995),
    [anon_sym_const] = ACTIONS(2995),
    [anon_sym_file] = ACTIONS(2995),
    [anon_sym_fixed] = ACTIONS(2995),
    [anon_sym_internal] = ACTIONS(2995),
    [anon_sym_new] = ACTIONS(2995),
    [anon_sym_override] = ACTIONS(2995),
    [anon_sym_partial] = ACTIONS(2995),
    [anon_sym_private] = ACTIONS(2995),
    [anon_sym_protected] = ACTIONS(2995),
    [anon_sym_public] = ACTIONS(2995),
    [anon_sym_readonly] = ACTIONS(2995),
    [anon_sym_required] = ACTIONS(2995),
    [anon_sym_sealed] = ACTIONS(2995),
    [anon_sym_virtual] = ACTIONS(2995),
    [anon_sym_volatile] = ACTIONS(2995),
    [anon_sym_LT] = ACTIONS(2999),
    [anon_sym_GT] = ACTIONS(2999),
    [anon_sym_where] = ACTIONS(2995),
    [anon_sym_QMARK] = ACTIONS(2999),
    [anon_sym_notnull] = ACTIONS(2995),
    [anon_sym_unmanaged] = ACTIONS(2995),
    [anon_sym_checked] = ACTIONS(2995),
    [anon_sym_BANG] = ACTIONS(2995),
    [anon_sym_TILDE] = ACTIONS(2997),
    [anon_sym_PLUS_PLUS] = ACTIONS(2997),
    [anon_sym_DASH_DASH] = ACTIONS(2997),
    [anon_sym_true] = ACTIONS(2995),
    [anon_sym_false] = ACTIONS(2995),
    [anon_sym_PLUS] = ACTIONS(2995),
    [anon_sym_DASH] = ACTIONS(2995),
    [anon_sym_STAR] = ACTIONS(2997),
    [anon_sym_SLASH] = ACTIONS(2999),
    [anon_sym_PERCENT] = ACTIONS(3001),
    [anon_sym_CARET] = ACTIONS(2997),
    [anon_sym_PIPE] = ACTIONS(2999),
    [anon_sym_AMP] = ACTIONS(2995),
    [anon_sym_LT_LT] = ACTIONS(3001),
    [anon_sym_GT_GT] = ACTIONS(2999),
    [anon_sym_GT_GT_GT] = ACTIONS(3001),
    [anon_sym_EQ_EQ] = ACTIONS(3001),
    [anon_sym_BANG_EQ] = ACTIONS(3001),
    [anon_sym_GT_EQ] = ACTIONS(3001),
    [anon_sym_LT_EQ] = ACTIONS(3001),
    [anon_sym_this] = ACTIONS(2995),
    [anon_sym_DOT] = ACTIONS(2999),
    [anon_sym_scoped] = ACTIONS(2995),
    [anon_sym_base] = ACTIONS(2995),
    [anon_sym_var] = ACTIONS(2995),
    [sym_predefined_type] = ACTIONS(2995),
    [anon_sym_break] = ACTIONS(2995),
    [anon_sym_unchecked] = ACTIONS(2995),
    [anon_sym_continue] = ACTIONS(2995),
    [anon_sym_do] = ACTIONS(2995),
    [anon_sym_while] = ACTIONS(2995),
    [anon_sym_for] = ACTIONS(2995),
    [anon_sym_lock] = ACTIONS(2995),
    [anon_sym_yield] = ACTIONS(2995),
    [anon_sym_switch] = ACTIONS(2995),
    [anon_sym_case] = ACTIONS(2995),
    [anon_sym_default] = ACTIONS(2995),
    [anon_sym_throw] = ACTIONS(2995),
    [anon_sym_try] = ACTIONS(2995),
    [anon_sym_when] = ACTIONS(2995),
    [anon_sym_await] = ACTIONS(2995),
    [anon_sym_foreach] = ACTIONS(2995),
    [anon_sym_goto] = ACTIONS(2995),
    [anon_sym_if] = ACTIONS(2995),
    [anon_sym_else] = ACTIONS(2995),
    [anon_sym_DOT_DOT] = ACTIONS(2997),
    [anon_sym_AMP_AMP] = ACTIONS(3001),
    [anon_sym_PIPE_PIPE] = ACTIONS(3001),
    [anon_sym_QMARK_QMARK] = ACTIONS(3001),
    [anon_sym_from] = ACTIONS(2995),
    [anon_sym_into] = ACTIONS(2995),
    [anon_sym_join] = ACTIONS(2995),
    [anon_sym_on] = ACTIONS(2995),
    [anon_sym_equals] = ACTIONS(2995),
    [anon_sym_let] = ACTIONS(2995),
    [anon_sym_orderby] = ACTIONS(2995),
    [anon_sym_ascending] = ACTIONS(2995),
    [anon_sym_descending] = ACTIONS(2995),
    [anon_sym_group] = ACTIONS(2995),
    [anon_sym_by] = ACTIONS(2995),
    [anon_sym_select] = ACTIONS(2995),
    [anon_sym_as] = ACTIONS(2999),
    [anon_sym_is] = ACTIONS(2999),
    [anon_sym_DASH_GT] = ACTIONS(3001),
    [anon_sym_stackalloc] = ACTIONS(2995),
    [anon_sym_with] = ACTIONS(2999),
    [anon_sym_sizeof] = ACTIONS(2995),
    [anon_sym_typeof] = ACTIONS(2995),
    [anon_sym___makeref] = ACTIONS(2995),
    [anon_sym___reftype] = ACTIONS(2995),
    [anon_sym___refvalue] = ACTIONS(2995),
    [sym_null_literal] = ACTIONS(2995),
    [anon_sym_SQUOTE] = ACTIONS(2997),
    [sym_integer_literal] = ACTIONS(2995),
    [sym_real_literal] = ACTIONS(2997),
    [anon_sym_DQUOTE] = ACTIONS(2997),
    [sym_verbatim_string_literal] = ACTIONS(2997),
    [aux_sym_preproc_if_token1] = ACTIONS(2997),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(2997),
    [sym_interpolation_verbatim_start] = ACTIONS(2997),
    [sym_interpolation_raw_start] = ACTIONS(2997),
    [sym_raw_string_start] = ACTIONS(2997),
  },
  [2208] = {
    [sym_preproc_region] = STATE(2208),
    [sym_preproc_endregion] = STATE(2208),
    [sym_preproc_line] = STATE(2208),
    [sym_preproc_pragma] = STATE(2208),
    [sym_preproc_nullable] = STATE(2208),
    [sym_preproc_error] = STATE(2208),
    [sym_preproc_warning] = STATE(2208),
    [sym_preproc_define] = STATE(2208),
    [sym_preproc_undef] = STATE(2208),
    [sym__identifier_token] = ACTIONS(2987),
    [anon_sym_extern] = ACTIONS(2987),
    [anon_sym_alias] = ACTIONS(2987),
    [anon_sym_SEMI] = ACTIONS(2989),
    [anon_sym_global] = ACTIONS(2987),
    [anon_sym_using] = ACTIONS(2987),
    [anon_sym_unsafe] = ACTIONS(2987),
    [anon_sym_static] = ACTIONS(2987),
    [anon_sym_LBRACK] = ACTIONS(2989),
    [anon_sym_COMMA] = ACTIONS(2993),
    [anon_sym_LPAREN] = ACTIONS(2989),
    [anon_sym_return] = ACTIONS(2987),
    [anon_sym_ref] = ACTIONS(2987),
    [anon_sym_LBRACE] = ACTIONS(2989),
    [anon_sym_RBRACE] = ACTIONS(2989),
    [anon_sym_delegate] = ACTIONS(2987),
    [anon_sym_abstract] = ACTIONS(2987),
    [anon_sym_async] = ACTIONS(2987),
    [anon_sym_const] = ACTIONS(2987),
    [anon_sym_file] = ACTIONS(2987),
    [anon_sym_fixed] = ACTIONS(2987),
    [anon_sym_internal] = ACTIONS(2987),
    [anon_sym_new] = ACTIONS(2987),
    [anon_sym_override] = ACTIONS(2987),
    [anon_sym_partial] = ACTIONS(2987),
    [anon_sym_private] = ACTIONS(2987),
    [anon_sym_protected] = ACTIONS(2987),
    [anon_sym_public] = ACTIONS(2987),
    [anon_sym_readonly] = ACTIONS(2987),
    [anon_sym_required] = ACTIONS(2987),
    [anon_sym_sealed] = ACTIONS(2987),
    [anon_sym_virtual] = ACTIONS(2987),
    [anon_sym_volatile] = ACTIONS(2987),
    [anon_sym_LT] = ACTIONS(2991),
    [anon_sym_GT] = ACTIONS(2991),
    [anon_sym_where] = ACTIONS(2987),
    [anon_sym_QMARK] = ACTIONS(2991),
    [anon_sym_notnull] = ACTIONS(2987),
    [anon_sym_unmanaged] = ACTIONS(2987),
    [anon_sym_checked] = ACTIONS(2987),
    [anon_sym_BANG] = ACTIONS(2987),
    [anon_sym_TILDE] = ACTIONS(2989),
    [anon_sym_PLUS_PLUS] = ACTIONS(2989),
    [anon_sym_DASH_DASH] = ACTIONS(2989),
    [anon_sym_true] = ACTIONS(2987),
    [anon_sym_false] = ACTIONS(2987),
    [anon_sym_PLUS] = ACTIONS(2987),
    [anon_sym_DASH] = ACTIONS(2987),
    [anon_sym_STAR] = ACTIONS(2989),
    [anon_sym_SLASH] = ACTIONS(2991),
    [anon_sym_PERCENT] = ACTIONS(2993),
    [anon_sym_CARET] = ACTIONS(2989),
    [anon_sym_PIPE] = ACTIONS(2991),
    [anon_sym_AMP] = ACTIONS(2987),
    [anon_sym_LT_LT] = ACTIONS(2993),
    [anon_sym_GT_GT] = ACTIONS(2991),
    [anon_sym_GT_GT_GT] = ACTIONS(2993),
    [anon_sym_EQ_EQ] = ACTIONS(2993),
    [anon_sym_BANG_EQ] = ACTIONS(2993),
    [anon_sym_GT_EQ] = ACTIONS(2993),
    [anon_sym_LT_EQ] = ACTIONS(2993),
    [anon_sym_this] = ACTIONS(2987),
    [anon_sym_DOT] = ACTIONS(2991),
    [anon_sym_scoped] = ACTIONS(2987),
    [anon_sym_base] = ACTIONS(2987),
    [anon_sym_var] = ACTIONS(2987),
    [sym_predefined_type] = ACTIONS(2987),
    [anon_sym_break] = ACTIONS(2987),
    [anon_sym_unchecked] = ACTIONS(2987),
    [anon_sym_continue] = ACTIONS(2987),
    [anon_sym_do] = ACTIONS(2987),
    [anon_sym_while] = ACTIONS(2987),
    [anon_sym_for] = ACTIONS(2987),
    [anon_sym_lock] = ACTIONS(2987),
    [anon_sym_yield] = ACTIONS(2987),
    [anon_sym_switch] = ACTIONS(2987),
    [anon_sym_case] = ACTIONS(2987),
    [anon_sym_default] = ACTIONS(2987),
    [anon_sym_throw] = ACTIONS(2987),
    [anon_sym_try] = ACTIONS(2987),
    [anon_sym_when] = ACTIONS(2987),
    [anon_sym_await] = ACTIONS(2987),
    [anon_sym_foreach] = ACTIONS(2987),
    [anon_sym_goto] = ACTIONS(2987),
    [anon_sym_if] = ACTIONS(2987),
    [anon_sym_else] = ACTIONS(2987),
    [anon_sym_DOT_DOT] = ACTIONS(2989),
    [anon_sym_AMP_AMP] = ACTIONS(2993),
    [anon_sym_PIPE_PIPE] = ACTIONS(2993),
    [anon_sym_QMARK_QMARK] = ACTIONS(2993),
    [anon_sym_from] = ACTIONS(2987),
    [anon_sym_into] = ACTIONS(2987),
    [anon_sym_join] = ACTIONS(2987),
    [anon_sym_on] = ACTIONS(2987),
    [anon_sym_equals] = ACTIONS(2987),
    [anon_sym_let] = ACTIONS(2987),
    [anon_sym_orderby] = ACTIONS(2987),
    [anon_sym_ascending] = ACTIONS(2987),
    [anon_sym_descending] = ACTIONS(2987),
    [anon_sym_group] = ACTIONS(2987),
    [anon_sym_by] = ACTIONS(2987),
    [anon_sym_select] = ACTIONS(2987),
    [anon_sym_as] = ACTIONS(2991),
    [anon_sym_is] = ACTIONS(2991),
    [anon_sym_DASH_GT] = ACTIONS(2993),
    [anon_sym_stackalloc] = ACTIONS(2987),
    [anon_sym_with] = ACTIONS(2991),
    [anon_sym_sizeof] = ACTIONS(2987),
    [anon_sym_typeof] = ACTIONS(2987),
    [anon_sym___makeref] = ACTIONS(2987),
    [anon_sym___reftype] = ACTIONS(2987),
    [anon_sym___refvalue] = ACTIONS(2987),
    [sym_null_literal] = ACTIONS(2987),
    [anon_sym_SQUOTE] = ACTIONS(2989),
    [sym_integer_literal] = ACTIONS(2987),
    [sym_real_literal] = ACTIONS(2989),
    [anon_sym_DQUOTE] = ACTIONS(2989),
    [sym_verbatim_string_literal] = ACTIONS(2989),
    [aux_sym_preproc_if_token1] = ACTIONS(2989),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(2989),
    [sym_interpolation_verbatim_start] = ACTIONS(2989),
    [sym_interpolation_raw_start] = ACTIONS(2989),
    [sym_raw_string_start] = ACTIONS(2989),
  },
  [2209] = {
    [sym_catch_clause] = STATE(2220),
    [sym_finally_clause] = STATE(2292),
    [sym_preproc_region] = STATE(2209),
    [sym_preproc_endregion] = STATE(2209),
    [sym_preproc_line] = STATE(2209),
    [sym_preproc_pragma] = STATE(2209),
    [sym_preproc_nullable] = STATE(2209),
    [sym_preproc_error] = STATE(2209),
    [sym_preproc_warning] = STATE(2209),
    [sym_preproc_define] = STATE(2209),
    [sym_preproc_undef] = STATE(2209),
    [aux_sym_try_statement_repeat1] = STATE(2210),
    [sym__identifier_token] = ACTIONS(3003),
    [anon_sym_extern] = ACTIONS(3003),
    [anon_sym_alias] = ACTIONS(3003),
    [anon_sym_SEMI] = ACTIONS(3005),
    [anon_sym_global] = ACTIONS(3003),
    [anon_sym_using] = ACTIONS(3003),
    [anon_sym_unsafe] = ACTIONS(3003),
    [anon_sym_static] = ACTIONS(3003),
    [anon_sym_LBRACK] = ACTIONS(3005),
    [anon_sym_LPAREN] = ACTIONS(3005),
    [anon_sym_return] = ACTIONS(3003),
    [anon_sym_namespace] = ACTIONS(3003),
    [anon_sym_class] = ACTIONS(3003),
    [anon_sym_ref] = ACTIONS(3003),
    [anon_sym_struct] = ACTIONS(3003),
    [anon_sym_enum] = ACTIONS(3003),
    [anon_sym_LBRACE] = ACTIONS(3005),
    [anon_sym_interface] = ACTIONS(3003),
    [anon_sym_delegate] = ACTIONS(3003),
    [anon_sym_record] = ACTIONS(3003),
    [anon_sym_abstract] = ACTIONS(3003),
    [anon_sym_async] = ACTIONS(3003),
    [anon_sym_const] = ACTIONS(3003),
    [anon_sym_file] = ACTIONS(3003),
    [anon_sym_fixed] = ACTIONS(3003),
    [anon_sym_internal] = ACTIONS(3003),
    [anon_sym_new] = ACTIONS(3003),
    [anon_sym_override] = ACTIONS(3003),
    [anon_sym_partial] = ACTIONS(3003),
    [anon_sym_private] = ACTIONS(3003),
    [anon_sym_protected] = ACTIONS(3003),
    [anon_sym_public] = ACTIONS(3003),
    [anon_sym_readonly] = ACTIONS(3003),
    [anon_sym_required] = ACTIONS(3003),
    [anon_sym_sealed] = ACTIONS(3003),
    [anon_sym_virtual] = ACTIONS(3003),
    [anon_sym_volatile] = ACTIONS(3003),
    [anon_sym_where] = ACTIONS(3003),
    [anon_sym_notnull] = ACTIONS(3003),
    [anon_sym_unmanaged] = ACTIONS(3003),
    [anon_sym_checked] = ACTIONS(3003),
    [anon_sym_BANG] = ACTIONS(3005),
    [anon_sym_TILDE] = ACTIONS(3005),
    [anon_sym_PLUS_PLUS] = ACTIONS(3005),
    [anon_sym_DASH_DASH] = ACTIONS(3005),
    [anon_sym_true] = ACTIONS(3003),
    [anon_sym_false] = ACTIONS(3003),
    [anon_sym_PLUS] = ACTIONS(3003),
    [anon_sym_DASH] = ACTIONS(3003),
    [anon_sym_STAR] = ACTIONS(3005),
    [anon_sym_CARET] = ACTIONS(3005),
    [anon_sym_AMP] = ACTIONS(3005),
    [anon_sym_this] = ACTIONS(3003),
    [anon_sym_scoped] = ACTIONS(3003),
    [anon_sym_base] = ACTIONS(3003),
    [anon_sym_var] = ACTIONS(3003),
    [sym_predefined_type] = ACTIONS(3003),
    [anon_sym_break] = ACTIONS(3003),
    [anon_sym_unchecked] = ACTIONS(3003),
    [anon_sym_continue] = ACTIONS(3003),
    [anon_sym_do] = ACTIONS(3003),
    [anon_sym_while] = ACTIONS(3003),
    [anon_sym_for] = ACTIONS(3003),
    [anon_sym_lock] = ACTIONS(3003),
    [anon_sym_yield] = ACTIONS(3003),
    [anon_sym_switch] = ACTIONS(3003),
    [anon_sym_default] = ACTIONS(3003),
    [anon_sym_throw] = ACTIONS(3003),
    [anon_sym_try] = ACTIONS(3003),
    [anon_sym_catch] = ACTIONS(3007),
    [anon_sym_when] = ACTIONS(3003),
    [anon_sym_finally] = ACTIONS(3009),
    [anon_sym_await] = ACTIONS(3003),
    [anon_sym_foreach] = ACTIONS(3003),
    [anon_sym_goto] = ACTIONS(3003),
    [anon_sym_if] = ACTIONS(3003),
    [anon_sym_else] = ACTIONS(3003),
    [anon_sym_DOT_DOT] = ACTIONS(3005),
    [anon_sym_from] = ACTIONS(3003),
    [anon_sym_into] = ACTIONS(3003),
    [anon_sym_join] = ACTIONS(3003),
    [anon_sym_on] = ACTIONS(3003),
    [anon_sym_equals] = ACTIONS(3003),
    [anon_sym_let] = ACTIONS(3003),
    [anon_sym_orderby] = ACTIONS(3003),
    [anon_sym_ascending] = ACTIONS(3003),
    [anon_sym_descending] = ACTIONS(3003),
    [anon_sym_group] = ACTIONS(3003),
    [anon_sym_by] = ACTIONS(3003),
    [anon_sym_select] = ACTIONS(3003),
    [anon_sym_stackalloc] = ACTIONS(3003),
    [anon_sym_sizeof] = ACTIONS(3003),
    [anon_sym_typeof] = ACTIONS(3003),
    [anon_sym___makeref] = ACTIONS(3003),
    [anon_sym___reftype] = ACTIONS(3003),
    [anon_sym___refvalue] = ACTIONS(3003),
    [sym_null_literal] = ACTIONS(3003),
    [anon_sym_SQUOTE] = ACTIONS(3005),
    [sym_integer_literal] = ACTIONS(3003),
    [sym_real_literal] = ACTIONS(3005),
    [anon_sym_DQUOTE] = ACTIONS(3005),
    [sym_verbatim_string_literal] = ACTIONS(3005),
    [aux_sym_preproc_if_token1] = ACTIONS(3005),
    [aux_sym_preproc_if_token3] = ACTIONS(3005),
    [aux_sym_preproc_else_token1] = ACTIONS(3005),
    [aux_sym_preproc_elif_token1] = ACTIONS(3005),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3005),
    [sym_interpolation_verbatim_start] = ACTIONS(3005),
    [sym_interpolation_raw_start] = ACTIONS(3005),
    [sym_raw_string_start] = ACTIONS(3005),
  },
  [2210] = {
    [sym_catch_clause] = STATE(2220),
    [sym_finally_clause] = STATE(2301),
    [sym_preproc_region] = STATE(2210),
    [sym_preproc_endregion] = STATE(2210),
    [sym_preproc_line] = STATE(2210),
    [sym_preproc_pragma] = STATE(2210),
    [sym_preproc_nullable] = STATE(2210),
    [sym_preproc_error] = STATE(2210),
    [sym_preproc_warning] = STATE(2210),
    [sym_preproc_define] = STATE(2210),
    [sym_preproc_undef] = STATE(2210),
    [aux_sym_try_statement_repeat1] = STATE(2211),
    [sym__identifier_token] = ACTIONS(3011),
    [anon_sym_extern] = ACTIONS(3011),
    [anon_sym_alias] = ACTIONS(3011),
    [anon_sym_SEMI] = ACTIONS(3013),
    [anon_sym_global] = ACTIONS(3011),
    [anon_sym_using] = ACTIONS(3011),
    [anon_sym_unsafe] = ACTIONS(3011),
    [anon_sym_static] = ACTIONS(3011),
    [anon_sym_LBRACK] = ACTIONS(3013),
    [anon_sym_LPAREN] = ACTIONS(3013),
    [anon_sym_return] = ACTIONS(3011),
    [anon_sym_namespace] = ACTIONS(3011),
    [anon_sym_class] = ACTIONS(3011),
    [anon_sym_ref] = ACTIONS(3011),
    [anon_sym_struct] = ACTIONS(3011),
    [anon_sym_enum] = ACTIONS(3011),
    [anon_sym_LBRACE] = ACTIONS(3013),
    [anon_sym_interface] = ACTIONS(3011),
    [anon_sym_delegate] = ACTIONS(3011),
    [anon_sym_record] = ACTIONS(3011),
    [anon_sym_abstract] = ACTIONS(3011),
    [anon_sym_async] = ACTIONS(3011),
    [anon_sym_const] = ACTIONS(3011),
    [anon_sym_file] = ACTIONS(3011),
    [anon_sym_fixed] = ACTIONS(3011),
    [anon_sym_internal] = ACTIONS(3011),
    [anon_sym_new] = ACTIONS(3011),
    [anon_sym_override] = ACTIONS(3011),
    [anon_sym_partial] = ACTIONS(3011),
    [anon_sym_private] = ACTIONS(3011),
    [anon_sym_protected] = ACTIONS(3011),
    [anon_sym_public] = ACTIONS(3011),
    [anon_sym_readonly] = ACTIONS(3011),
    [anon_sym_required] = ACTIONS(3011),
    [anon_sym_sealed] = ACTIONS(3011),
    [anon_sym_virtual] = ACTIONS(3011),
    [anon_sym_volatile] = ACTIONS(3011),
    [anon_sym_where] = ACTIONS(3011),
    [anon_sym_notnull] = ACTIONS(3011),
    [anon_sym_unmanaged] = ACTIONS(3011),
    [anon_sym_checked] = ACTIONS(3011),
    [anon_sym_BANG] = ACTIONS(3013),
    [anon_sym_TILDE] = ACTIONS(3013),
    [anon_sym_PLUS_PLUS] = ACTIONS(3013),
    [anon_sym_DASH_DASH] = ACTIONS(3013),
    [anon_sym_true] = ACTIONS(3011),
    [anon_sym_false] = ACTIONS(3011),
    [anon_sym_PLUS] = ACTIONS(3011),
    [anon_sym_DASH] = ACTIONS(3011),
    [anon_sym_STAR] = ACTIONS(3013),
    [anon_sym_CARET] = ACTIONS(3013),
    [anon_sym_AMP] = ACTIONS(3013),
    [anon_sym_this] = ACTIONS(3011),
    [anon_sym_scoped] = ACTIONS(3011),
    [anon_sym_base] = ACTIONS(3011),
    [anon_sym_var] = ACTIONS(3011),
    [sym_predefined_type] = ACTIONS(3011),
    [anon_sym_break] = ACTIONS(3011),
    [anon_sym_unchecked] = ACTIONS(3011),
    [anon_sym_continue] = ACTIONS(3011),
    [anon_sym_do] = ACTIONS(3011),
    [anon_sym_while] = ACTIONS(3011),
    [anon_sym_for] = ACTIONS(3011),
    [anon_sym_lock] = ACTIONS(3011),
    [anon_sym_yield] = ACTIONS(3011),
    [anon_sym_switch] = ACTIONS(3011),
    [anon_sym_default] = ACTIONS(3011),
    [anon_sym_throw] = ACTIONS(3011),
    [anon_sym_try] = ACTIONS(3011),
    [anon_sym_catch] = ACTIONS(3007),
    [anon_sym_when] = ACTIONS(3011),
    [anon_sym_finally] = ACTIONS(3009),
    [anon_sym_await] = ACTIONS(3011),
    [anon_sym_foreach] = ACTIONS(3011),
    [anon_sym_goto] = ACTIONS(3011),
    [anon_sym_if] = ACTIONS(3011),
    [anon_sym_else] = ACTIONS(3011),
    [anon_sym_DOT_DOT] = ACTIONS(3013),
    [anon_sym_from] = ACTIONS(3011),
    [anon_sym_into] = ACTIONS(3011),
    [anon_sym_join] = ACTIONS(3011),
    [anon_sym_on] = ACTIONS(3011),
    [anon_sym_equals] = ACTIONS(3011),
    [anon_sym_let] = ACTIONS(3011),
    [anon_sym_orderby] = ACTIONS(3011),
    [anon_sym_ascending] = ACTIONS(3011),
    [anon_sym_descending] = ACTIONS(3011),
    [anon_sym_group] = ACTIONS(3011),
    [anon_sym_by] = ACTIONS(3011),
    [anon_sym_select] = ACTIONS(3011),
    [anon_sym_stackalloc] = ACTIONS(3011),
    [anon_sym_sizeof] = ACTIONS(3011),
    [anon_sym_typeof] = ACTIONS(3011),
    [anon_sym___makeref] = ACTIONS(3011),
    [anon_sym___reftype] = ACTIONS(3011),
    [anon_sym___refvalue] = ACTIONS(3011),
    [sym_null_literal] = ACTIONS(3011),
    [anon_sym_SQUOTE] = ACTIONS(3013),
    [sym_integer_literal] = ACTIONS(3011),
    [sym_real_literal] = ACTIONS(3013),
    [anon_sym_DQUOTE] = ACTIONS(3013),
    [sym_verbatim_string_literal] = ACTIONS(3013),
    [aux_sym_preproc_if_token1] = ACTIONS(3013),
    [aux_sym_preproc_if_token3] = ACTIONS(3013),
    [aux_sym_preproc_else_token1] = ACTIONS(3013),
    [aux_sym_preproc_elif_token1] = ACTIONS(3013),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3013),
    [sym_interpolation_verbatim_start] = ACTIONS(3013),
    [sym_interpolation_raw_start] = ACTIONS(3013),
    [sym_raw_string_start] = ACTIONS(3013),
  },
  [2211] = {
    [sym_catch_clause] = STATE(2220),
    [sym_preproc_region] = STATE(2211),
    [sym_preproc_endregion] = STATE(2211),
    [sym_preproc_line] = STATE(2211),
    [sym_preproc_pragma] = STATE(2211),
    [sym_preproc_nullable] = STATE(2211),
    [sym_preproc_error] = STATE(2211),
    [sym_preproc_warning] = STATE(2211),
    [sym_preproc_define] = STATE(2211),
    [sym_preproc_undef] = STATE(2211),
    [aux_sym_try_statement_repeat1] = STATE(2211),
    [sym__identifier_token] = ACTIONS(3015),
    [anon_sym_extern] = ACTIONS(3015),
    [anon_sym_alias] = ACTIONS(3015),
    [anon_sym_SEMI] = ACTIONS(3017),
    [anon_sym_global] = ACTIONS(3015),
    [anon_sym_using] = ACTIONS(3015),
    [anon_sym_unsafe] = ACTIONS(3015),
    [anon_sym_static] = ACTIONS(3015),
    [anon_sym_LBRACK] = ACTIONS(3017),
    [anon_sym_LPAREN] = ACTIONS(3017),
    [anon_sym_return] = ACTIONS(3015),
    [anon_sym_namespace] = ACTIONS(3015),
    [anon_sym_class] = ACTIONS(3015),
    [anon_sym_ref] = ACTIONS(3015),
    [anon_sym_struct] = ACTIONS(3015),
    [anon_sym_enum] = ACTIONS(3015),
    [anon_sym_LBRACE] = ACTIONS(3017),
    [anon_sym_interface] = ACTIONS(3015),
    [anon_sym_delegate] = ACTIONS(3015),
    [anon_sym_record] = ACTIONS(3015),
    [anon_sym_abstract] = ACTIONS(3015),
    [anon_sym_async] = ACTIONS(3015),
    [anon_sym_const] = ACTIONS(3015),
    [anon_sym_file] = ACTIONS(3015),
    [anon_sym_fixed] = ACTIONS(3015),
    [anon_sym_internal] = ACTIONS(3015),
    [anon_sym_new] = ACTIONS(3015),
    [anon_sym_override] = ACTIONS(3015),
    [anon_sym_partial] = ACTIONS(3015),
    [anon_sym_private] = ACTIONS(3015),
    [anon_sym_protected] = ACTIONS(3015),
    [anon_sym_public] = ACTIONS(3015),
    [anon_sym_readonly] = ACTIONS(3015),
    [anon_sym_required] = ACTIONS(3015),
    [anon_sym_sealed] = ACTIONS(3015),
    [anon_sym_virtual] = ACTIONS(3015),
    [anon_sym_volatile] = ACTIONS(3015),
    [anon_sym_where] = ACTIONS(3015),
    [anon_sym_notnull] = ACTIONS(3015),
    [anon_sym_unmanaged] = ACTIONS(3015),
    [anon_sym_checked] = ACTIONS(3015),
    [anon_sym_BANG] = ACTIONS(3017),
    [anon_sym_TILDE] = ACTIONS(3017),
    [anon_sym_PLUS_PLUS] = ACTIONS(3017),
    [anon_sym_DASH_DASH] = ACTIONS(3017),
    [anon_sym_true] = ACTIONS(3015),
    [anon_sym_false] = ACTIONS(3015),
    [anon_sym_PLUS] = ACTIONS(3015),
    [anon_sym_DASH] = ACTIONS(3015),
    [anon_sym_STAR] = ACTIONS(3017),
    [anon_sym_CARET] = ACTIONS(3017),
    [anon_sym_AMP] = ACTIONS(3017),
    [anon_sym_this] = ACTIONS(3015),
    [anon_sym_scoped] = ACTIONS(3015),
    [anon_sym_base] = ACTIONS(3015),
    [anon_sym_var] = ACTIONS(3015),
    [sym_predefined_type] = ACTIONS(3015),
    [anon_sym_break] = ACTIONS(3015),
    [anon_sym_unchecked] = ACTIONS(3015),
    [anon_sym_continue] = ACTIONS(3015),
    [anon_sym_do] = ACTIONS(3015),
    [anon_sym_while] = ACTIONS(3015),
    [anon_sym_for] = ACTIONS(3015),
    [anon_sym_lock] = ACTIONS(3015),
    [anon_sym_yield] = ACTIONS(3015),
    [anon_sym_switch] = ACTIONS(3015),
    [anon_sym_default] = ACTIONS(3015),
    [anon_sym_throw] = ACTIONS(3015),
    [anon_sym_try] = ACTIONS(3015),
    [anon_sym_catch] = ACTIONS(3019),
    [anon_sym_when] = ACTIONS(3015),
    [anon_sym_finally] = ACTIONS(3015),
    [anon_sym_await] = ACTIONS(3015),
    [anon_sym_foreach] = ACTIONS(3015),
    [anon_sym_goto] = ACTIONS(3015),
    [anon_sym_if] = ACTIONS(3015),
    [anon_sym_else] = ACTIONS(3015),
    [anon_sym_DOT_DOT] = ACTIONS(3017),
    [anon_sym_from] = ACTIONS(3015),
    [anon_sym_into] = ACTIONS(3015),
    [anon_sym_join] = ACTIONS(3015),
    [anon_sym_on] = ACTIONS(3015),
    [anon_sym_equals] = ACTIONS(3015),
    [anon_sym_let] = ACTIONS(3015),
    [anon_sym_orderby] = ACTIONS(3015),
    [anon_sym_ascending] = ACTIONS(3015),
    [anon_sym_descending] = ACTIONS(3015),
    [anon_sym_group] = ACTIONS(3015),
    [anon_sym_by] = ACTIONS(3015),
    [anon_sym_select] = ACTIONS(3015),
    [anon_sym_stackalloc] = ACTIONS(3015),
    [anon_sym_sizeof] = ACTIONS(3015),
    [anon_sym_typeof] = ACTIONS(3015),
    [anon_sym___makeref] = ACTIONS(3015),
    [anon_sym___reftype] = ACTIONS(3015),
    [anon_sym___refvalue] = ACTIONS(3015),
    [sym_null_literal] = ACTIONS(3015),
    [anon_sym_SQUOTE] = ACTIONS(3017),
    [sym_integer_literal] = ACTIONS(3015),
    [sym_real_literal] = ACTIONS(3017),
    [anon_sym_DQUOTE] = ACTIONS(3017),
    [sym_verbatim_string_literal] = ACTIONS(3017),
    [aux_sym_preproc_if_token1] = ACTIONS(3017),
    [aux_sym_preproc_if_token3] = ACTIONS(3017),
    [aux_sym_preproc_else_token1] = ACTIONS(3017),
    [aux_sym_preproc_elif_token1] = ACTIONS(3017),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3017),
    [sym_interpolation_verbatim_start] = ACTIONS(3017),
    [sym_interpolation_raw_start] = ACTIONS(3017),
    [sym_raw_string_start] = ACTIONS(3017),
  },
  [2212] = {
    [sym_catch_clause] = STATE(2284),
    [sym_finally_clause] = STATE(2496),
    [sym_preproc_region] = STATE(2212),
    [sym_preproc_endregion] = STATE(2212),
    [sym_preproc_line] = STATE(2212),
    [sym_preproc_pragma] = STATE(2212),
    [sym_preproc_nullable] = STATE(2212),
    [sym_preproc_error] = STATE(2212),
    [sym_preproc_warning] = STATE(2212),
    [sym_preproc_define] = STATE(2212),
    [sym_preproc_undef] = STATE(2212),
    [aux_sym_try_statement_repeat1] = STATE(2213),
    [ts_builtin_sym_end] = ACTIONS(3005),
    [sym__identifier_token] = ACTIONS(3003),
    [anon_sym_extern] = ACTIONS(3003),
    [anon_sym_alias] = ACTIONS(3003),
    [anon_sym_SEMI] = ACTIONS(3005),
    [anon_sym_global] = ACTIONS(3003),
    [anon_sym_using] = ACTIONS(3003),
    [anon_sym_unsafe] = ACTIONS(3003),
    [anon_sym_static] = ACTIONS(3003),
    [anon_sym_LBRACK] = ACTIONS(3005),
    [anon_sym_LPAREN] = ACTIONS(3005),
    [anon_sym_return] = ACTIONS(3003),
    [anon_sym_namespace] = ACTIONS(3003),
    [anon_sym_class] = ACTIONS(3003),
    [anon_sym_ref] = ACTIONS(3003),
    [anon_sym_struct] = ACTIONS(3003),
    [anon_sym_enum] = ACTIONS(3003),
    [anon_sym_LBRACE] = ACTIONS(3005),
    [anon_sym_interface] = ACTIONS(3003),
    [anon_sym_delegate] = ACTIONS(3003),
    [anon_sym_record] = ACTIONS(3003),
    [anon_sym_abstract] = ACTIONS(3003),
    [anon_sym_async] = ACTIONS(3003),
    [anon_sym_const] = ACTIONS(3003),
    [anon_sym_file] = ACTIONS(3003),
    [anon_sym_fixed] = ACTIONS(3003),
    [anon_sym_internal] = ACTIONS(3003),
    [anon_sym_new] = ACTIONS(3003),
    [anon_sym_override] = ACTIONS(3003),
    [anon_sym_partial] = ACTIONS(3003),
    [anon_sym_private] = ACTIONS(3003),
    [anon_sym_protected] = ACTIONS(3003),
    [anon_sym_public] = ACTIONS(3003),
    [anon_sym_readonly] = ACTIONS(3003),
    [anon_sym_required] = ACTIONS(3003),
    [anon_sym_sealed] = ACTIONS(3003),
    [anon_sym_virtual] = ACTIONS(3003),
    [anon_sym_volatile] = ACTIONS(3003),
    [anon_sym_where] = ACTIONS(3003),
    [anon_sym_notnull] = ACTIONS(3003),
    [anon_sym_unmanaged] = ACTIONS(3003),
    [anon_sym_checked] = ACTIONS(3003),
    [anon_sym_BANG] = ACTIONS(3005),
    [anon_sym_TILDE] = ACTIONS(3005),
    [anon_sym_PLUS_PLUS] = ACTIONS(3005),
    [anon_sym_DASH_DASH] = ACTIONS(3005),
    [anon_sym_true] = ACTIONS(3003),
    [anon_sym_false] = ACTIONS(3003),
    [anon_sym_PLUS] = ACTIONS(3003),
    [anon_sym_DASH] = ACTIONS(3003),
    [anon_sym_STAR] = ACTIONS(3005),
    [anon_sym_CARET] = ACTIONS(3005),
    [anon_sym_AMP] = ACTIONS(3005),
    [anon_sym_this] = ACTIONS(3003),
    [anon_sym_scoped] = ACTIONS(3003),
    [anon_sym_base] = ACTIONS(3003),
    [anon_sym_var] = ACTIONS(3003),
    [sym_predefined_type] = ACTIONS(3003),
    [anon_sym_break] = ACTIONS(3003),
    [anon_sym_unchecked] = ACTIONS(3003),
    [anon_sym_continue] = ACTIONS(3003),
    [anon_sym_do] = ACTIONS(3003),
    [anon_sym_while] = ACTIONS(3003),
    [anon_sym_for] = ACTIONS(3003),
    [anon_sym_lock] = ACTIONS(3003),
    [anon_sym_yield] = ACTIONS(3003),
    [anon_sym_switch] = ACTIONS(3003),
    [anon_sym_default] = ACTIONS(3003),
    [anon_sym_throw] = ACTIONS(3003),
    [anon_sym_try] = ACTIONS(3003),
    [anon_sym_catch] = ACTIONS(3022),
    [anon_sym_when] = ACTIONS(3003),
    [anon_sym_finally] = ACTIONS(3024),
    [anon_sym_await] = ACTIONS(3003),
    [anon_sym_foreach] = ACTIONS(3003),
    [anon_sym_goto] = ACTIONS(3003),
    [anon_sym_if] = ACTIONS(3003),
    [anon_sym_else] = ACTIONS(3003),
    [anon_sym_DOT_DOT] = ACTIONS(3005),
    [anon_sym_from] = ACTIONS(3003),
    [anon_sym_into] = ACTIONS(3003),
    [anon_sym_join] = ACTIONS(3003),
    [anon_sym_on] = ACTIONS(3003),
    [anon_sym_equals] = ACTIONS(3003),
    [anon_sym_let] = ACTIONS(3003),
    [anon_sym_orderby] = ACTIONS(3003),
    [anon_sym_ascending] = ACTIONS(3003),
    [anon_sym_descending] = ACTIONS(3003),
    [anon_sym_group] = ACTIONS(3003),
    [anon_sym_by] = ACTIONS(3003),
    [anon_sym_select] = ACTIONS(3003),
    [anon_sym_stackalloc] = ACTIONS(3003),
    [anon_sym_sizeof] = ACTIONS(3003),
    [anon_sym_typeof] = ACTIONS(3003),
    [anon_sym___makeref] = ACTIONS(3003),
    [anon_sym___reftype] = ACTIONS(3003),
    [anon_sym___refvalue] = ACTIONS(3003),
    [sym_null_literal] = ACTIONS(3003),
    [anon_sym_SQUOTE] = ACTIONS(3005),
    [sym_integer_literal] = ACTIONS(3003),
    [sym_real_literal] = ACTIONS(3005),
    [anon_sym_DQUOTE] = ACTIONS(3005),
    [sym_verbatim_string_literal] = ACTIONS(3005),
    [aux_sym_preproc_if_token1] = ACTIONS(3005),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3005),
    [sym_interpolation_verbatim_start] = ACTIONS(3005),
    [sym_interpolation_raw_start] = ACTIONS(3005),
    [sym_raw_string_start] = ACTIONS(3005),
  },
  [2213] = {
    [sym_catch_clause] = STATE(2284),
    [sym_finally_clause] = STATE(2439),
    [sym_preproc_region] = STATE(2213),
    [sym_preproc_endregion] = STATE(2213),
    [sym_preproc_line] = STATE(2213),
    [sym_preproc_pragma] = STATE(2213),
    [sym_preproc_nullable] = STATE(2213),
    [sym_preproc_error] = STATE(2213),
    [sym_preproc_warning] = STATE(2213),
    [sym_preproc_define] = STATE(2213),
    [sym_preproc_undef] = STATE(2213),
    [aux_sym_try_statement_repeat1] = STATE(2217),
    [ts_builtin_sym_end] = ACTIONS(3013),
    [sym__identifier_token] = ACTIONS(3011),
    [anon_sym_extern] = ACTIONS(3011),
    [anon_sym_alias] = ACTIONS(3011),
    [anon_sym_SEMI] = ACTIONS(3013),
    [anon_sym_global] = ACTIONS(3011),
    [anon_sym_using] = ACTIONS(3011),
    [anon_sym_unsafe] = ACTIONS(3011),
    [anon_sym_static] = ACTIONS(3011),
    [anon_sym_LBRACK] = ACTIONS(3013),
    [anon_sym_LPAREN] = ACTIONS(3013),
    [anon_sym_return] = ACTIONS(3011),
    [anon_sym_namespace] = ACTIONS(3011),
    [anon_sym_class] = ACTIONS(3011),
    [anon_sym_ref] = ACTIONS(3011),
    [anon_sym_struct] = ACTIONS(3011),
    [anon_sym_enum] = ACTIONS(3011),
    [anon_sym_LBRACE] = ACTIONS(3013),
    [anon_sym_interface] = ACTIONS(3011),
    [anon_sym_delegate] = ACTIONS(3011),
    [anon_sym_record] = ACTIONS(3011),
    [anon_sym_abstract] = ACTIONS(3011),
    [anon_sym_async] = ACTIONS(3011),
    [anon_sym_const] = ACTIONS(3011),
    [anon_sym_file] = ACTIONS(3011),
    [anon_sym_fixed] = ACTIONS(3011),
    [anon_sym_internal] = ACTIONS(3011),
    [anon_sym_new] = ACTIONS(3011),
    [anon_sym_override] = ACTIONS(3011),
    [anon_sym_partial] = ACTIONS(3011),
    [anon_sym_private] = ACTIONS(3011),
    [anon_sym_protected] = ACTIONS(3011),
    [anon_sym_public] = ACTIONS(3011),
    [anon_sym_readonly] = ACTIONS(3011),
    [anon_sym_required] = ACTIONS(3011),
    [anon_sym_sealed] = ACTIONS(3011),
    [anon_sym_virtual] = ACTIONS(3011),
    [anon_sym_volatile] = ACTIONS(3011),
    [anon_sym_where] = ACTIONS(3011),
    [anon_sym_notnull] = ACTIONS(3011),
    [anon_sym_unmanaged] = ACTIONS(3011),
    [anon_sym_checked] = ACTIONS(3011),
    [anon_sym_BANG] = ACTIONS(3013),
    [anon_sym_TILDE] = ACTIONS(3013),
    [anon_sym_PLUS_PLUS] = ACTIONS(3013),
    [anon_sym_DASH_DASH] = ACTIONS(3013),
    [anon_sym_true] = ACTIONS(3011),
    [anon_sym_false] = ACTIONS(3011),
    [anon_sym_PLUS] = ACTIONS(3011),
    [anon_sym_DASH] = ACTIONS(3011),
    [anon_sym_STAR] = ACTIONS(3013),
    [anon_sym_CARET] = ACTIONS(3013),
    [anon_sym_AMP] = ACTIONS(3013),
    [anon_sym_this] = ACTIONS(3011),
    [anon_sym_scoped] = ACTIONS(3011),
    [anon_sym_base] = ACTIONS(3011),
    [anon_sym_var] = ACTIONS(3011),
    [sym_predefined_type] = ACTIONS(3011),
    [anon_sym_break] = ACTIONS(3011),
    [anon_sym_unchecked] = ACTIONS(3011),
    [anon_sym_continue] = ACTIONS(3011),
    [anon_sym_do] = ACTIONS(3011),
    [anon_sym_while] = ACTIONS(3011),
    [anon_sym_for] = ACTIONS(3011),
    [anon_sym_lock] = ACTIONS(3011),
    [anon_sym_yield] = ACTIONS(3011),
    [anon_sym_switch] = ACTIONS(3011),
    [anon_sym_default] = ACTIONS(3011),
    [anon_sym_throw] = ACTIONS(3011),
    [anon_sym_try] = ACTIONS(3011),
    [anon_sym_catch] = ACTIONS(3022),
    [anon_sym_when] = ACTIONS(3011),
    [anon_sym_finally] = ACTIONS(3024),
    [anon_sym_await] = ACTIONS(3011),
    [anon_sym_foreach] = ACTIONS(3011),
    [anon_sym_goto] = ACTIONS(3011),
    [anon_sym_if] = ACTIONS(3011),
    [anon_sym_else] = ACTIONS(3011),
    [anon_sym_DOT_DOT] = ACTIONS(3013),
    [anon_sym_from] = ACTIONS(3011),
    [anon_sym_into] = ACTIONS(3011),
    [anon_sym_join] = ACTIONS(3011),
    [anon_sym_on] = ACTIONS(3011),
    [anon_sym_equals] = ACTIONS(3011),
    [anon_sym_let] = ACTIONS(3011),
    [anon_sym_orderby] = ACTIONS(3011),
    [anon_sym_ascending] = ACTIONS(3011),
    [anon_sym_descending] = ACTIONS(3011),
    [anon_sym_group] = ACTIONS(3011),
    [anon_sym_by] = ACTIONS(3011),
    [anon_sym_select] = ACTIONS(3011),
    [anon_sym_stackalloc] = ACTIONS(3011),
    [anon_sym_sizeof] = ACTIONS(3011),
    [anon_sym_typeof] = ACTIONS(3011),
    [anon_sym___makeref] = ACTIONS(3011),
    [anon_sym___reftype] = ACTIONS(3011),
    [anon_sym___refvalue] = ACTIONS(3011),
    [sym_null_literal] = ACTIONS(3011),
    [anon_sym_SQUOTE] = ACTIONS(3013),
    [sym_integer_literal] = ACTIONS(3011),
    [sym_real_literal] = ACTIONS(3013),
    [anon_sym_DQUOTE] = ACTIONS(3013),
    [sym_verbatim_string_literal] = ACTIONS(3013),
    [aux_sym_preproc_if_token1] = ACTIONS(3013),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3013),
    [sym_interpolation_verbatim_start] = ACTIONS(3013),
    [sym_interpolation_raw_start] = ACTIONS(3013),
    [sym_raw_string_start] = ACTIONS(3013),
  },
  [2214] = {
    [sym_preproc_region] = STATE(2214),
    [sym_preproc_endregion] = STATE(2214),
    [sym_preproc_line] = STATE(2214),
    [sym_preproc_pragma] = STATE(2214),
    [sym_preproc_nullable] = STATE(2214),
    [sym_preproc_error] = STATE(2214),
    [sym_preproc_warning] = STATE(2214),
    [sym_preproc_define] = STATE(2214),
    [sym_preproc_undef] = STATE(2214),
    [sym__identifier_token] = ACTIONS(3026),
    [anon_sym_extern] = ACTIONS(3026),
    [anon_sym_alias] = ACTIONS(3026),
    [anon_sym_SEMI] = ACTIONS(3028),
    [anon_sym_global] = ACTIONS(3026),
    [anon_sym_using] = ACTIONS(3026),
    [anon_sym_unsafe] = ACTIONS(3026),
    [anon_sym_static] = ACTIONS(3026),
    [anon_sym_LBRACK] = ACTIONS(3028),
    [anon_sym_LPAREN] = ACTIONS(3028),
    [anon_sym_return] = ACTIONS(3026),
    [anon_sym_namespace] = ACTIONS(3026),
    [anon_sym_class] = ACTIONS(3026),
    [anon_sym_ref] = ACTIONS(3026),
    [anon_sym_struct] = ACTIONS(3026),
    [anon_sym_enum] = ACTIONS(3026),
    [anon_sym_LBRACE] = ACTIONS(3028),
    [anon_sym_interface] = ACTIONS(3026),
    [anon_sym_delegate] = ACTIONS(3026),
    [anon_sym_record] = ACTIONS(3026),
    [anon_sym_abstract] = ACTIONS(3026),
    [anon_sym_async] = ACTIONS(3026),
    [anon_sym_const] = ACTIONS(3026),
    [anon_sym_file] = ACTIONS(3026),
    [anon_sym_fixed] = ACTIONS(3026),
    [anon_sym_internal] = ACTIONS(3026),
    [anon_sym_new] = ACTIONS(3026),
    [anon_sym_override] = ACTIONS(3026),
    [anon_sym_partial] = ACTIONS(3026),
    [anon_sym_private] = ACTIONS(3026),
    [anon_sym_protected] = ACTIONS(3026),
    [anon_sym_public] = ACTIONS(3026),
    [anon_sym_readonly] = ACTIONS(3026),
    [anon_sym_required] = ACTIONS(3026),
    [anon_sym_sealed] = ACTIONS(3026),
    [anon_sym_virtual] = ACTIONS(3026),
    [anon_sym_volatile] = ACTIONS(3026),
    [anon_sym_where] = ACTIONS(3026),
    [anon_sym_notnull] = ACTIONS(3026),
    [anon_sym_unmanaged] = ACTIONS(3026),
    [anon_sym_checked] = ACTIONS(3026),
    [anon_sym_BANG] = ACTIONS(3028),
    [anon_sym_TILDE] = ACTIONS(3028),
    [anon_sym_PLUS_PLUS] = ACTIONS(3028),
    [anon_sym_DASH_DASH] = ACTIONS(3028),
    [anon_sym_true] = ACTIONS(3026),
    [anon_sym_false] = ACTIONS(3026),
    [anon_sym_PLUS] = ACTIONS(3026),
    [anon_sym_DASH] = ACTIONS(3026),
    [anon_sym_STAR] = ACTIONS(3028),
    [anon_sym_CARET] = ACTIONS(3028),
    [anon_sym_AMP] = ACTIONS(3028),
    [anon_sym_this] = ACTIONS(3026),
    [anon_sym_scoped] = ACTIONS(3026),
    [anon_sym_base] = ACTIONS(3026),
    [anon_sym_var] = ACTIONS(3026),
    [sym_predefined_type] = ACTIONS(3026),
    [anon_sym_break] = ACTIONS(3026),
    [anon_sym_unchecked] = ACTIONS(3026),
    [anon_sym_continue] = ACTIONS(3026),
    [anon_sym_do] = ACTIONS(3026),
    [anon_sym_while] = ACTIONS(3026),
    [anon_sym_for] = ACTIONS(3026),
    [anon_sym_lock] = ACTIONS(3026),
    [anon_sym_yield] = ACTIONS(3026),
    [anon_sym_switch] = ACTIONS(3026),
    [anon_sym_default] = ACTIONS(3026),
    [anon_sym_throw] = ACTIONS(3026),
    [anon_sym_try] = ACTIONS(3026),
    [anon_sym_catch] = ACTIONS(3026),
    [anon_sym_when] = ACTIONS(3026),
    [anon_sym_finally] = ACTIONS(3026),
    [anon_sym_await] = ACTIONS(3026),
    [anon_sym_foreach] = ACTIONS(3026),
    [anon_sym_goto] = ACTIONS(3026),
    [anon_sym_if] = ACTIONS(3026),
    [anon_sym_else] = ACTIONS(3026),
    [anon_sym_DOT_DOT] = ACTIONS(3028),
    [anon_sym_from] = ACTIONS(3026),
    [anon_sym_into] = ACTIONS(3026),
    [anon_sym_join] = ACTIONS(3026),
    [anon_sym_on] = ACTIONS(3026),
    [anon_sym_equals] = ACTIONS(3026),
    [anon_sym_let] = ACTIONS(3026),
    [anon_sym_orderby] = ACTIONS(3026),
    [anon_sym_ascending] = ACTIONS(3026),
    [anon_sym_descending] = ACTIONS(3026),
    [anon_sym_group] = ACTIONS(3026),
    [anon_sym_by] = ACTIONS(3026),
    [anon_sym_select] = ACTIONS(3026),
    [anon_sym_stackalloc] = ACTIONS(3026),
    [anon_sym_sizeof] = ACTIONS(3026),
    [anon_sym_typeof] = ACTIONS(3026),
    [anon_sym___makeref] = ACTIONS(3026),
    [anon_sym___reftype] = ACTIONS(3026),
    [anon_sym___refvalue] = ACTIONS(3026),
    [sym_null_literal] = ACTIONS(3026),
    [anon_sym_SQUOTE] = ACTIONS(3028),
    [sym_integer_literal] = ACTIONS(3026),
    [sym_real_literal] = ACTIONS(3028),
    [anon_sym_DQUOTE] = ACTIONS(3028),
    [sym_verbatim_string_literal] = ACTIONS(3028),
    [aux_sym_preproc_if_token1] = ACTIONS(3028),
    [aux_sym_preproc_if_token3] = ACTIONS(3028),
    [aux_sym_preproc_else_token1] = ACTIONS(3028),
    [aux_sym_preproc_elif_token1] = ACTIONS(3028),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3028),
    [sym_interpolation_verbatim_start] = ACTIONS(3028),
    [sym_interpolation_raw_start] = ACTIONS(3028),
    [sym_raw_string_start] = ACTIONS(3028),
  },
  [2215] = {
    [sym_preproc_region] = STATE(2215),
    [sym_preproc_endregion] = STATE(2215),
    [sym_preproc_line] = STATE(2215),
    [sym_preproc_pragma] = STATE(2215),
    [sym_preproc_nullable] = STATE(2215),
    [sym_preproc_error] = STATE(2215),
    [sym_preproc_warning] = STATE(2215),
    [sym_preproc_define] = STATE(2215),
    [sym_preproc_undef] = STATE(2215),
    [sym__identifier_token] = ACTIONS(2995),
    [anon_sym_extern] = ACTIONS(2995),
    [anon_sym_alias] = ACTIONS(2995),
    [anon_sym_SEMI] = ACTIONS(2997),
    [anon_sym_global] = ACTIONS(2995),
    [anon_sym_using] = ACTIONS(2995),
    [anon_sym_unsafe] = ACTIONS(2995),
    [anon_sym_static] = ACTIONS(2995),
    [anon_sym_LBRACK] = ACTIONS(2997),
    [anon_sym_LPAREN] = ACTIONS(2997),
    [anon_sym_return] = ACTIONS(2995),
    [anon_sym_namespace] = ACTIONS(2995),
    [anon_sym_class] = ACTIONS(2995),
    [anon_sym_ref] = ACTIONS(2995),
    [anon_sym_struct] = ACTIONS(2995),
    [anon_sym_enum] = ACTIONS(2995),
    [anon_sym_LBRACE] = ACTIONS(2997),
    [anon_sym_interface] = ACTIONS(2995),
    [anon_sym_delegate] = ACTIONS(2995),
    [anon_sym_record] = ACTIONS(2995),
    [anon_sym_abstract] = ACTIONS(2995),
    [anon_sym_async] = ACTIONS(2995),
    [anon_sym_const] = ACTIONS(2995),
    [anon_sym_file] = ACTIONS(2995),
    [anon_sym_fixed] = ACTIONS(2995),
    [anon_sym_internal] = ACTIONS(2995),
    [anon_sym_new] = ACTIONS(2995),
    [anon_sym_override] = ACTIONS(2995),
    [anon_sym_partial] = ACTIONS(2995),
    [anon_sym_private] = ACTIONS(2995),
    [anon_sym_protected] = ACTIONS(2995),
    [anon_sym_public] = ACTIONS(2995),
    [anon_sym_readonly] = ACTIONS(2995),
    [anon_sym_required] = ACTIONS(2995),
    [anon_sym_sealed] = ACTIONS(2995),
    [anon_sym_virtual] = ACTIONS(2995),
    [anon_sym_volatile] = ACTIONS(2995),
    [anon_sym_where] = ACTIONS(2995),
    [anon_sym_notnull] = ACTIONS(2995),
    [anon_sym_unmanaged] = ACTIONS(2995),
    [anon_sym_checked] = ACTIONS(2995),
    [anon_sym_BANG] = ACTIONS(2997),
    [anon_sym_TILDE] = ACTIONS(2997),
    [anon_sym_PLUS_PLUS] = ACTIONS(2997),
    [anon_sym_DASH_DASH] = ACTIONS(2997),
    [anon_sym_true] = ACTIONS(2995),
    [anon_sym_false] = ACTIONS(2995),
    [anon_sym_PLUS] = ACTIONS(2995),
    [anon_sym_DASH] = ACTIONS(2995),
    [anon_sym_STAR] = ACTIONS(2997),
    [anon_sym_CARET] = ACTIONS(2997),
    [anon_sym_AMP] = ACTIONS(2997),
    [anon_sym_this] = ACTIONS(2995),
    [anon_sym_scoped] = ACTIONS(2995),
    [anon_sym_base] = ACTIONS(2995),
    [anon_sym_var] = ACTIONS(2995),
    [sym_predefined_type] = ACTIONS(2995),
    [anon_sym_break] = ACTIONS(2995),
    [anon_sym_unchecked] = ACTIONS(2995),
    [anon_sym_continue] = ACTIONS(2995),
    [anon_sym_do] = ACTIONS(2995),
    [anon_sym_while] = ACTIONS(2995),
    [anon_sym_for] = ACTIONS(2995),
    [anon_sym_lock] = ACTIONS(2995),
    [anon_sym_yield] = ACTIONS(2995),
    [anon_sym_switch] = ACTIONS(2995),
    [anon_sym_default] = ACTIONS(2995),
    [anon_sym_throw] = ACTIONS(2995),
    [anon_sym_try] = ACTIONS(2995),
    [anon_sym_catch] = ACTIONS(2995),
    [anon_sym_when] = ACTIONS(2995),
    [anon_sym_finally] = ACTIONS(2995),
    [anon_sym_await] = ACTIONS(2995),
    [anon_sym_foreach] = ACTIONS(2995),
    [anon_sym_goto] = ACTIONS(2995),
    [anon_sym_if] = ACTIONS(2995),
    [anon_sym_else] = ACTIONS(2995),
    [anon_sym_DOT_DOT] = ACTIONS(2997),
    [anon_sym_from] = ACTIONS(2995),
    [anon_sym_into] = ACTIONS(2995),
    [anon_sym_join] = ACTIONS(2995),
    [anon_sym_on] = ACTIONS(2995),
    [anon_sym_equals] = ACTIONS(2995),
    [anon_sym_let] = ACTIONS(2995),
    [anon_sym_orderby] = ACTIONS(2995),
    [anon_sym_ascending] = ACTIONS(2995),
    [anon_sym_descending] = ACTIONS(2995),
    [anon_sym_group] = ACTIONS(2995),
    [anon_sym_by] = ACTIONS(2995),
    [anon_sym_select] = ACTIONS(2995),
    [anon_sym_stackalloc] = ACTIONS(2995),
    [anon_sym_sizeof] = ACTIONS(2995),
    [anon_sym_typeof] = ACTIONS(2995),
    [anon_sym___makeref] = ACTIONS(2995),
    [anon_sym___reftype] = ACTIONS(2995),
    [anon_sym___refvalue] = ACTIONS(2995),
    [sym_null_literal] = ACTIONS(2995),
    [anon_sym_SQUOTE] = ACTIONS(2997),
    [sym_integer_literal] = ACTIONS(2995),
    [sym_real_literal] = ACTIONS(2997),
    [anon_sym_DQUOTE] = ACTIONS(2997),
    [sym_verbatim_string_literal] = ACTIONS(2997),
    [aux_sym_preproc_if_token1] = ACTIONS(2997),
    [aux_sym_preproc_if_token3] = ACTIONS(2997),
    [aux_sym_preproc_else_token1] = ACTIONS(2997),
    [aux_sym_preproc_elif_token1] = ACTIONS(2997),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(2997),
    [sym_interpolation_verbatim_start] = ACTIONS(2997),
    [sym_interpolation_raw_start] = ACTIONS(2997),
    [sym_raw_string_start] = ACTIONS(2997),
  },
  [2216] = {
    [sym_preproc_region] = STATE(2216),
    [sym_preproc_endregion] = STATE(2216),
    [sym_preproc_line] = STATE(2216),
    [sym_preproc_pragma] = STATE(2216),
    [sym_preproc_nullable] = STATE(2216),
    [sym_preproc_error] = STATE(2216),
    [sym_preproc_warning] = STATE(2216),
    [sym_preproc_define] = STATE(2216),
    [sym_preproc_undef] = STATE(2216),
    [sym__identifier_token] = ACTIONS(3030),
    [anon_sym_extern] = ACTIONS(3030),
    [anon_sym_alias] = ACTIONS(3030),
    [anon_sym_SEMI] = ACTIONS(3032),
    [anon_sym_global] = ACTIONS(3030),
    [anon_sym_using] = ACTIONS(3030),
    [anon_sym_unsafe] = ACTIONS(3030),
    [anon_sym_static] = ACTIONS(3030),
    [anon_sym_LBRACK] = ACTIONS(3032),
    [anon_sym_LPAREN] = ACTIONS(3032),
    [anon_sym_return] = ACTIONS(3030),
    [anon_sym_namespace] = ACTIONS(3030),
    [anon_sym_class] = ACTIONS(3030),
    [anon_sym_ref] = ACTIONS(3030),
    [anon_sym_struct] = ACTIONS(3030),
    [anon_sym_enum] = ACTIONS(3030),
    [anon_sym_LBRACE] = ACTIONS(3032),
    [anon_sym_interface] = ACTIONS(3030),
    [anon_sym_delegate] = ACTIONS(3030),
    [anon_sym_record] = ACTIONS(3030),
    [anon_sym_abstract] = ACTIONS(3030),
    [anon_sym_async] = ACTIONS(3030),
    [anon_sym_const] = ACTIONS(3030),
    [anon_sym_file] = ACTIONS(3030),
    [anon_sym_fixed] = ACTIONS(3030),
    [anon_sym_internal] = ACTIONS(3030),
    [anon_sym_new] = ACTIONS(3030),
    [anon_sym_override] = ACTIONS(3030),
    [anon_sym_partial] = ACTIONS(3030),
    [anon_sym_private] = ACTIONS(3030),
    [anon_sym_protected] = ACTIONS(3030),
    [anon_sym_public] = ACTIONS(3030),
    [anon_sym_readonly] = ACTIONS(3030),
    [anon_sym_required] = ACTIONS(3030),
    [anon_sym_sealed] = ACTIONS(3030),
    [anon_sym_virtual] = ACTIONS(3030),
    [anon_sym_volatile] = ACTIONS(3030),
    [anon_sym_where] = ACTIONS(3030),
    [anon_sym_notnull] = ACTIONS(3030),
    [anon_sym_unmanaged] = ACTIONS(3030),
    [anon_sym_checked] = ACTIONS(3030),
    [anon_sym_BANG] = ACTIONS(3032),
    [anon_sym_TILDE] = ACTIONS(3032),
    [anon_sym_PLUS_PLUS] = ACTIONS(3032),
    [anon_sym_DASH_DASH] = ACTIONS(3032),
    [anon_sym_true] = ACTIONS(3030),
    [anon_sym_false] = ACTIONS(3030),
    [anon_sym_PLUS] = ACTIONS(3030),
    [anon_sym_DASH] = ACTIONS(3030),
    [anon_sym_STAR] = ACTIONS(3032),
    [anon_sym_CARET] = ACTIONS(3032),
    [anon_sym_AMP] = ACTIONS(3032),
    [anon_sym_this] = ACTIONS(3030),
    [anon_sym_scoped] = ACTIONS(3030),
    [anon_sym_base] = ACTIONS(3030),
    [anon_sym_var] = ACTIONS(3030),
    [sym_predefined_type] = ACTIONS(3030),
    [anon_sym_break] = ACTIONS(3030),
    [anon_sym_unchecked] = ACTIONS(3030),
    [anon_sym_continue] = ACTIONS(3030),
    [anon_sym_do] = ACTIONS(3030),
    [anon_sym_while] = ACTIONS(3030),
    [anon_sym_for] = ACTIONS(3030),
    [anon_sym_lock] = ACTIONS(3030),
    [anon_sym_yield] = ACTIONS(3030),
    [anon_sym_switch] = ACTIONS(3030),
    [anon_sym_default] = ACTIONS(3030),
    [anon_sym_throw] = ACTIONS(3030),
    [anon_sym_try] = ACTIONS(3030),
    [anon_sym_catch] = ACTIONS(3030),
    [anon_sym_when] = ACTIONS(3030),
    [anon_sym_finally] = ACTIONS(3030),
    [anon_sym_await] = ACTIONS(3030),
    [anon_sym_foreach] = ACTIONS(3030),
    [anon_sym_goto] = ACTIONS(3030),
    [anon_sym_if] = ACTIONS(3030),
    [anon_sym_else] = ACTIONS(3030),
    [anon_sym_DOT_DOT] = ACTIONS(3032),
    [anon_sym_from] = ACTIONS(3030),
    [anon_sym_into] = ACTIONS(3030),
    [anon_sym_join] = ACTIONS(3030),
    [anon_sym_on] = ACTIONS(3030),
    [anon_sym_equals] = ACTIONS(3030),
    [anon_sym_let] = ACTIONS(3030),
    [anon_sym_orderby] = ACTIONS(3030),
    [anon_sym_ascending] = ACTIONS(3030),
    [anon_sym_descending] = ACTIONS(3030),
    [anon_sym_group] = ACTIONS(3030),
    [anon_sym_by] = ACTIONS(3030),
    [anon_sym_select] = ACTIONS(3030),
    [anon_sym_stackalloc] = ACTIONS(3030),
    [anon_sym_sizeof] = ACTIONS(3030),
    [anon_sym_typeof] = ACTIONS(3030),
    [anon_sym___makeref] = ACTIONS(3030),
    [anon_sym___reftype] = ACTIONS(3030),
    [anon_sym___refvalue] = ACTIONS(3030),
    [sym_null_literal] = ACTIONS(3030),
    [anon_sym_SQUOTE] = ACTIONS(3032),
    [sym_integer_literal] = ACTIONS(3030),
    [sym_real_literal] = ACTIONS(3032),
    [anon_sym_DQUOTE] = ACTIONS(3032),
    [sym_verbatim_string_literal] = ACTIONS(3032),
    [aux_sym_preproc_if_token1] = ACTIONS(3032),
    [aux_sym_preproc_if_token3] = ACTIONS(3032),
    [aux_sym_preproc_else_token1] = ACTIONS(3032),
    [aux_sym_preproc_elif_token1] = ACTIONS(3032),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3032),
    [sym_interpolation_verbatim_start] = ACTIONS(3032),
    [sym_interpolation_raw_start] = ACTIONS(3032),
    [sym_raw_string_start] = ACTIONS(3032),
  },
  [2217] = {
    [sym_catch_clause] = STATE(2284),
    [sym_preproc_region] = STATE(2217),
    [sym_preproc_endregion] = STATE(2217),
    [sym_preproc_line] = STATE(2217),
    [sym_preproc_pragma] = STATE(2217),
    [sym_preproc_nullable] = STATE(2217),
    [sym_preproc_error] = STATE(2217),
    [sym_preproc_warning] = STATE(2217),
    [sym_preproc_define] = STATE(2217),
    [sym_preproc_undef] = STATE(2217),
    [aux_sym_try_statement_repeat1] = STATE(2217),
    [ts_builtin_sym_end] = ACTIONS(3017),
    [sym__identifier_token] = ACTIONS(3015),
    [anon_sym_extern] = ACTIONS(3015),
    [anon_sym_alias] = ACTIONS(3015),
    [anon_sym_SEMI] = ACTIONS(3017),
    [anon_sym_global] = ACTIONS(3015),
    [anon_sym_using] = ACTIONS(3015),
    [anon_sym_unsafe] = ACTIONS(3015),
    [anon_sym_static] = ACTIONS(3015),
    [anon_sym_LBRACK] = ACTIONS(3017),
    [anon_sym_LPAREN] = ACTIONS(3017),
    [anon_sym_return] = ACTIONS(3015),
    [anon_sym_namespace] = ACTIONS(3015),
    [anon_sym_class] = ACTIONS(3015),
    [anon_sym_ref] = ACTIONS(3015),
    [anon_sym_struct] = ACTIONS(3015),
    [anon_sym_enum] = ACTIONS(3015),
    [anon_sym_LBRACE] = ACTIONS(3017),
    [anon_sym_interface] = ACTIONS(3015),
    [anon_sym_delegate] = ACTIONS(3015),
    [anon_sym_record] = ACTIONS(3015),
    [anon_sym_abstract] = ACTIONS(3015),
    [anon_sym_async] = ACTIONS(3015),
    [anon_sym_const] = ACTIONS(3015),
    [anon_sym_file] = ACTIONS(3015),
    [anon_sym_fixed] = ACTIONS(3015),
    [anon_sym_internal] = ACTIONS(3015),
    [anon_sym_new] = ACTIONS(3015),
    [anon_sym_override] = ACTIONS(3015),
    [anon_sym_partial] = ACTIONS(3015),
    [anon_sym_private] = ACTIONS(3015),
    [anon_sym_protected] = ACTIONS(3015),
    [anon_sym_public] = ACTIONS(3015),
    [anon_sym_readonly] = ACTIONS(3015),
    [anon_sym_required] = ACTIONS(3015),
    [anon_sym_sealed] = ACTIONS(3015),
    [anon_sym_virtual] = ACTIONS(3015),
    [anon_sym_volatile] = ACTIONS(3015),
    [anon_sym_where] = ACTIONS(3015),
    [anon_sym_notnull] = ACTIONS(3015),
    [anon_sym_unmanaged] = ACTIONS(3015),
    [anon_sym_checked] = ACTIONS(3015),
    [anon_sym_BANG] = ACTIONS(3017),
    [anon_sym_TILDE] = ACTIONS(3017),
    [anon_sym_PLUS_PLUS] = ACTIONS(3017),
    [anon_sym_DASH_DASH] = ACTIONS(3017),
    [anon_sym_true] = ACTIONS(3015),
    [anon_sym_false] = ACTIONS(3015),
    [anon_sym_PLUS] = ACTIONS(3015),
    [anon_sym_DASH] = ACTIONS(3015),
    [anon_sym_STAR] = ACTIONS(3017),
    [anon_sym_CARET] = ACTIONS(3017),
    [anon_sym_AMP] = ACTIONS(3017),
    [anon_sym_this] = ACTIONS(3015),
    [anon_sym_scoped] = ACTIONS(3015),
    [anon_sym_base] = ACTIONS(3015),
    [anon_sym_var] = ACTIONS(3015),
    [sym_predefined_type] = ACTIONS(3015),
    [anon_sym_break] = ACTIONS(3015),
    [anon_sym_unchecked] = ACTIONS(3015),
    [anon_sym_continue] = ACTIONS(3015),
    [anon_sym_do] = ACTIONS(3015),
    [anon_sym_while] = ACTIONS(3015),
    [anon_sym_for] = ACTIONS(3015),
    [anon_sym_lock] = ACTIONS(3015),
    [anon_sym_yield] = ACTIONS(3015),
    [anon_sym_switch] = ACTIONS(3015),
    [anon_sym_default] = ACTIONS(3015),
    [anon_sym_throw] = ACTIONS(3015),
    [anon_sym_try] = ACTIONS(3015),
    [anon_sym_catch] = ACTIONS(3034),
    [anon_sym_when] = ACTIONS(3015),
    [anon_sym_finally] = ACTIONS(3015),
    [anon_sym_await] = ACTIONS(3015),
    [anon_sym_foreach] = ACTIONS(3015),
    [anon_sym_goto] = ACTIONS(3015),
    [anon_sym_if] = ACTIONS(3015),
    [anon_sym_else] = ACTIONS(3015),
    [anon_sym_DOT_DOT] = ACTIONS(3017),
    [anon_sym_from] = ACTIONS(3015),
    [anon_sym_into] = ACTIONS(3015),
    [anon_sym_join] = ACTIONS(3015),
    [anon_sym_on] = ACTIONS(3015),
    [anon_sym_equals] = ACTIONS(3015),
    [anon_sym_let] = ACTIONS(3015),
    [anon_sym_orderby] = ACTIONS(3015),
    [anon_sym_ascending] = ACTIONS(3015),
    [anon_sym_descending] = ACTIONS(3015),
    [anon_sym_group] = ACTIONS(3015),
    [anon_sym_by] = ACTIONS(3015),
    [anon_sym_select] = ACTIONS(3015),
    [anon_sym_stackalloc] = ACTIONS(3015),
    [anon_sym_sizeof] = ACTIONS(3015),
    [anon_sym_typeof] = ACTIONS(3015),
    [anon_sym___makeref] = ACTIONS(3015),
    [anon_sym___reftype] = ACTIONS(3015),
    [anon_sym___refvalue] = ACTIONS(3015),
    [sym_null_literal] = ACTIONS(3015),
    [anon_sym_SQUOTE] = ACTIONS(3017),
    [sym_integer_literal] = ACTIONS(3015),
    [sym_real_literal] = ACTIONS(3017),
    [anon_sym_DQUOTE] = ACTIONS(3017),
    [sym_verbatim_string_literal] = ACTIONS(3017),
    [aux_sym_preproc_if_token1] = ACTIONS(3017),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3017),
    [sym_interpolation_verbatim_start] = ACTIONS(3017),
    [sym_interpolation_raw_start] = ACTIONS(3017),
    [sym_raw_string_start] = ACTIONS(3017),
  },
  [2218] = {
    [sym_preproc_region] = STATE(2218),
    [sym_preproc_endregion] = STATE(2218),
    [sym_preproc_line] = STATE(2218),
    [sym_preproc_pragma] = STATE(2218),
    [sym_preproc_nullable] = STATE(2218),
    [sym_preproc_error] = STATE(2218),
    [sym_preproc_warning] = STATE(2218),
    [sym_preproc_define] = STATE(2218),
    [sym_preproc_undef] = STATE(2218),
    [sym__identifier_token] = ACTIONS(3037),
    [anon_sym_extern] = ACTIONS(3037),
    [anon_sym_alias] = ACTIONS(3037),
    [anon_sym_SEMI] = ACTIONS(3039),
    [anon_sym_global] = ACTIONS(3037),
    [anon_sym_using] = ACTIONS(3037),
    [anon_sym_unsafe] = ACTIONS(3037),
    [anon_sym_static] = ACTIONS(3037),
    [anon_sym_LBRACK] = ACTIONS(3039),
    [anon_sym_LPAREN] = ACTIONS(3039),
    [anon_sym_return] = ACTIONS(3037),
    [anon_sym_namespace] = ACTIONS(3037),
    [anon_sym_class] = ACTIONS(3037),
    [anon_sym_ref] = ACTIONS(3037),
    [anon_sym_struct] = ACTIONS(3037),
    [anon_sym_enum] = ACTIONS(3037),
    [anon_sym_LBRACE] = ACTIONS(3039),
    [anon_sym_interface] = ACTIONS(3037),
    [anon_sym_delegate] = ACTIONS(3037),
    [anon_sym_record] = ACTIONS(3037),
    [anon_sym_abstract] = ACTIONS(3037),
    [anon_sym_async] = ACTIONS(3037),
    [anon_sym_const] = ACTIONS(3037),
    [anon_sym_file] = ACTIONS(3037),
    [anon_sym_fixed] = ACTIONS(3037),
    [anon_sym_internal] = ACTIONS(3037),
    [anon_sym_new] = ACTIONS(3037),
    [anon_sym_override] = ACTIONS(3037),
    [anon_sym_partial] = ACTIONS(3037),
    [anon_sym_private] = ACTIONS(3037),
    [anon_sym_protected] = ACTIONS(3037),
    [anon_sym_public] = ACTIONS(3037),
    [anon_sym_readonly] = ACTIONS(3037),
    [anon_sym_required] = ACTIONS(3037),
    [anon_sym_sealed] = ACTIONS(3037),
    [anon_sym_virtual] = ACTIONS(3037),
    [anon_sym_volatile] = ACTIONS(3037),
    [anon_sym_where] = ACTIONS(3037),
    [anon_sym_notnull] = ACTIONS(3037),
    [anon_sym_unmanaged] = ACTIONS(3037),
    [anon_sym_checked] = ACTIONS(3037),
    [anon_sym_BANG] = ACTIONS(3039),
    [anon_sym_TILDE] = ACTIONS(3039),
    [anon_sym_PLUS_PLUS] = ACTIONS(3039),
    [anon_sym_DASH_DASH] = ACTIONS(3039),
    [anon_sym_true] = ACTIONS(3037),
    [anon_sym_false] = ACTIONS(3037),
    [anon_sym_PLUS] = ACTIONS(3037),
    [anon_sym_DASH] = ACTIONS(3037),
    [anon_sym_STAR] = ACTIONS(3039),
    [anon_sym_CARET] = ACTIONS(3039),
    [anon_sym_AMP] = ACTIONS(3039),
    [anon_sym_this] = ACTIONS(3037),
    [anon_sym_scoped] = ACTIONS(3037),
    [anon_sym_base] = ACTIONS(3037),
    [anon_sym_var] = ACTIONS(3037),
    [sym_predefined_type] = ACTIONS(3037),
    [anon_sym_break] = ACTIONS(3037),
    [anon_sym_unchecked] = ACTIONS(3037),
    [anon_sym_continue] = ACTIONS(3037),
    [anon_sym_do] = ACTIONS(3037),
    [anon_sym_while] = ACTIONS(3037),
    [anon_sym_for] = ACTIONS(3037),
    [anon_sym_lock] = ACTIONS(3037),
    [anon_sym_yield] = ACTIONS(3037),
    [anon_sym_switch] = ACTIONS(3037),
    [anon_sym_default] = ACTIONS(3037),
    [anon_sym_throw] = ACTIONS(3037),
    [anon_sym_try] = ACTIONS(3037),
    [anon_sym_catch] = ACTIONS(3037),
    [anon_sym_when] = ACTIONS(3037),
    [anon_sym_finally] = ACTIONS(3037),
    [anon_sym_await] = ACTIONS(3037),
    [anon_sym_foreach] = ACTIONS(3037),
    [anon_sym_goto] = ACTIONS(3037),
    [anon_sym_if] = ACTIONS(3037),
    [anon_sym_else] = ACTIONS(3037),
    [anon_sym_DOT_DOT] = ACTIONS(3039),
    [anon_sym_from] = ACTIONS(3037),
    [anon_sym_into] = ACTIONS(3037),
    [anon_sym_join] = ACTIONS(3037),
    [anon_sym_on] = ACTIONS(3037),
    [anon_sym_equals] = ACTIONS(3037),
    [anon_sym_let] = ACTIONS(3037),
    [anon_sym_orderby] = ACTIONS(3037),
    [anon_sym_ascending] = ACTIONS(3037),
    [anon_sym_descending] = ACTIONS(3037),
    [anon_sym_group] = ACTIONS(3037),
    [anon_sym_by] = ACTIONS(3037),
    [anon_sym_select] = ACTIONS(3037),
    [anon_sym_stackalloc] = ACTIONS(3037),
    [anon_sym_sizeof] = ACTIONS(3037),
    [anon_sym_typeof] = ACTIONS(3037),
    [anon_sym___makeref] = ACTIONS(3037),
    [anon_sym___reftype] = ACTIONS(3037),
    [anon_sym___refvalue] = ACTIONS(3037),
    [sym_null_literal] = ACTIONS(3037),
    [anon_sym_SQUOTE] = ACTIONS(3039),
    [sym_integer_literal] = ACTIONS(3037),
    [sym_real_literal] = ACTIONS(3039),
    [anon_sym_DQUOTE] = ACTIONS(3039),
    [sym_verbatim_string_literal] = ACTIONS(3039),
    [aux_sym_preproc_if_token1] = ACTIONS(3039),
    [aux_sym_preproc_if_token3] = ACTIONS(3039),
    [aux_sym_preproc_else_token1] = ACTIONS(3039),
    [aux_sym_preproc_elif_token1] = ACTIONS(3039),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3039),
    [sym_interpolation_verbatim_start] = ACTIONS(3039),
    [sym_interpolation_raw_start] = ACTIONS(3039),
    [sym_raw_string_start] = ACTIONS(3039),
  },
  [2219] = {
    [sym_preproc_region] = STATE(2219),
    [sym_preproc_endregion] = STATE(2219),
    [sym_preproc_line] = STATE(2219),
    [sym_preproc_pragma] = STATE(2219),
    [sym_preproc_nullable] = STATE(2219),
    [sym_preproc_error] = STATE(2219),
    [sym_preproc_warning] = STATE(2219),
    [sym_preproc_define] = STATE(2219),
    [sym_preproc_undef] = STATE(2219),
    [sym__identifier_token] = ACTIONS(3041),
    [anon_sym_extern] = ACTIONS(3041),
    [anon_sym_alias] = ACTIONS(3041),
    [anon_sym_SEMI] = ACTIONS(3043),
    [anon_sym_global] = ACTIONS(3041),
    [anon_sym_using] = ACTIONS(3041),
    [anon_sym_unsafe] = ACTIONS(3041),
    [anon_sym_static] = ACTIONS(3041),
    [anon_sym_LBRACK] = ACTIONS(3043),
    [anon_sym_LPAREN] = ACTIONS(3043),
    [anon_sym_return] = ACTIONS(3041),
    [anon_sym_namespace] = ACTIONS(3041),
    [anon_sym_class] = ACTIONS(3041),
    [anon_sym_ref] = ACTIONS(3041),
    [anon_sym_struct] = ACTIONS(3041),
    [anon_sym_enum] = ACTIONS(3041),
    [anon_sym_LBRACE] = ACTIONS(3043),
    [anon_sym_interface] = ACTIONS(3041),
    [anon_sym_delegate] = ACTIONS(3041),
    [anon_sym_record] = ACTIONS(3041),
    [anon_sym_abstract] = ACTIONS(3041),
    [anon_sym_async] = ACTIONS(3041),
    [anon_sym_const] = ACTIONS(3041),
    [anon_sym_file] = ACTIONS(3041),
    [anon_sym_fixed] = ACTIONS(3041),
    [anon_sym_internal] = ACTIONS(3041),
    [anon_sym_new] = ACTIONS(3041),
    [anon_sym_override] = ACTIONS(3041),
    [anon_sym_partial] = ACTIONS(3041),
    [anon_sym_private] = ACTIONS(3041),
    [anon_sym_protected] = ACTIONS(3041),
    [anon_sym_public] = ACTIONS(3041),
    [anon_sym_readonly] = ACTIONS(3041),
    [anon_sym_required] = ACTIONS(3041),
    [anon_sym_sealed] = ACTIONS(3041),
    [anon_sym_virtual] = ACTIONS(3041),
    [anon_sym_volatile] = ACTIONS(3041),
    [anon_sym_where] = ACTIONS(3041),
    [anon_sym_notnull] = ACTIONS(3041),
    [anon_sym_unmanaged] = ACTIONS(3041),
    [anon_sym_checked] = ACTIONS(3041),
    [anon_sym_BANG] = ACTIONS(3043),
    [anon_sym_TILDE] = ACTIONS(3043),
    [anon_sym_PLUS_PLUS] = ACTIONS(3043),
    [anon_sym_DASH_DASH] = ACTIONS(3043),
    [anon_sym_true] = ACTIONS(3041),
    [anon_sym_false] = ACTIONS(3041),
    [anon_sym_PLUS] = ACTIONS(3041),
    [anon_sym_DASH] = ACTIONS(3041),
    [anon_sym_STAR] = ACTIONS(3043),
    [anon_sym_CARET] = ACTIONS(3043),
    [anon_sym_AMP] = ACTIONS(3043),
    [anon_sym_this] = ACTIONS(3041),
    [anon_sym_scoped] = ACTIONS(3041),
    [anon_sym_base] = ACTIONS(3041),
    [anon_sym_var] = ACTIONS(3041),
    [sym_predefined_type] = ACTIONS(3041),
    [anon_sym_break] = ACTIONS(3041),
    [anon_sym_unchecked] = ACTIONS(3041),
    [anon_sym_continue] = ACTIONS(3041),
    [anon_sym_do] = ACTIONS(3041),
    [anon_sym_while] = ACTIONS(3041),
    [anon_sym_for] = ACTIONS(3041),
    [anon_sym_lock] = ACTIONS(3041),
    [anon_sym_yield] = ACTIONS(3041),
    [anon_sym_switch] = ACTIONS(3041),
    [anon_sym_default] = ACTIONS(3041),
    [anon_sym_throw] = ACTIONS(3041),
    [anon_sym_try] = ACTIONS(3041),
    [anon_sym_catch] = ACTIONS(3041),
    [anon_sym_when] = ACTIONS(3041),
    [anon_sym_finally] = ACTIONS(3041),
    [anon_sym_await] = ACTIONS(3041),
    [anon_sym_foreach] = ACTIONS(3041),
    [anon_sym_goto] = ACTIONS(3041),
    [anon_sym_if] = ACTIONS(3041),
    [anon_sym_else] = ACTIONS(3041),
    [anon_sym_DOT_DOT] = ACTIONS(3043),
    [anon_sym_from] = ACTIONS(3041),
    [anon_sym_into] = ACTIONS(3041),
    [anon_sym_join] = ACTIONS(3041),
    [anon_sym_on] = ACTIONS(3041),
    [anon_sym_equals] = ACTIONS(3041),
    [anon_sym_let] = ACTIONS(3041),
    [anon_sym_orderby] = ACTIONS(3041),
    [anon_sym_ascending] = ACTIONS(3041),
    [anon_sym_descending] = ACTIONS(3041),
    [anon_sym_group] = ACTIONS(3041),
    [anon_sym_by] = ACTIONS(3041),
    [anon_sym_select] = ACTIONS(3041),
    [anon_sym_stackalloc] = ACTIONS(3041),
    [anon_sym_sizeof] = ACTIONS(3041),
    [anon_sym_typeof] = ACTIONS(3041),
    [anon_sym___makeref] = ACTIONS(3041),
    [anon_sym___reftype] = ACTIONS(3041),
    [anon_sym___refvalue] = ACTIONS(3041),
    [sym_null_literal] = ACTIONS(3041),
    [anon_sym_SQUOTE] = ACTIONS(3043),
    [sym_integer_literal] = ACTIONS(3041),
    [sym_real_literal] = ACTIONS(3043),
    [anon_sym_DQUOTE] = ACTIONS(3043),
    [sym_verbatim_string_literal] = ACTIONS(3043),
    [aux_sym_preproc_if_token1] = ACTIONS(3043),
    [aux_sym_preproc_if_token3] = ACTIONS(3043),
    [aux_sym_preproc_else_token1] = ACTIONS(3043),
    [aux_sym_preproc_elif_token1] = ACTIONS(3043),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3043),
    [sym_interpolation_verbatim_start] = ACTIONS(3043),
    [sym_interpolation_raw_start] = ACTIONS(3043),
    [sym_raw_string_start] = ACTIONS(3043),
  },
  [2220] = {
    [sym_preproc_region] = STATE(2220),
    [sym_preproc_endregion] = STATE(2220),
    [sym_preproc_line] = STATE(2220),
    [sym_preproc_pragma] = STATE(2220),
    [sym_preproc_nullable] = STATE(2220),
    [sym_preproc_error] = STATE(2220),
    [sym_preproc_warning] = STATE(2220),
    [sym_preproc_define] = STATE(2220),
    [sym_preproc_undef] = STATE(2220),
    [sym__identifier_token] = ACTIONS(3045),
    [anon_sym_extern] = ACTIONS(3045),
    [anon_sym_alias] = ACTIONS(3045),
    [anon_sym_SEMI] = ACTIONS(3047),
    [anon_sym_global] = ACTIONS(3045),
    [anon_sym_using] = ACTIONS(3045),
    [anon_sym_unsafe] = ACTIONS(3045),
    [anon_sym_static] = ACTIONS(3045),
    [anon_sym_LBRACK] = ACTIONS(3047),
    [anon_sym_LPAREN] = ACTIONS(3047),
    [anon_sym_return] = ACTIONS(3045),
    [anon_sym_namespace] = ACTIONS(3045),
    [anon_sym_class] = ACTIONS(3045),
    [anon_sym_ref] = ACTIONS(3045),
    [anon_sym_struct] = ACTIONS(3045),
    [anon_sym_enum] = ACTIONS(3045),
    [anon_sym_LBRACE] = ACTIONS(3047),
    [anon_sym_interface] = ACTIONS(3045),
    [anon_sym_delegate] = ACTIONS(3045),
    [anon_sym_record] = ACTIONS(3045),
    [anon_sym_abstract] = ACTIONS(3045),
    [anon_sym_async] = ACTIONS(3045),
    [anon_sym_const] = ACTIONS(3045),
    [anon_sym_file] = ACTIONS(3045),
    [anon_sym_fixed] = ACTIONS(3045),
    [anon_sym_internal] = ACTIONS(3045),
    [anon_sym_new] = ACTIONS(3045),
    [anon_sym_override] = ACTIONS(3045),
    [anon_sym_partial] = ACTIONS(3045),
    [anon_sym_private] = ACTIONS(3045),
    [anon_sym_protected] = ACTIONS(3045),
    [anon_sym_public] = ACTIONS(3045),
    [anon_sym_readonly] = ACTIONS(3045),
    [anon_sym_required] = ACTIONS(3045),
    [anon_sym_sealed] = ACTIONS(3045),
    [anon_sym_virtual] = ACTIONS(3045),
    [anon_sym_volatile] = ACTIONS(3045),
    [anon_sym_where] = ACTIONS(3045),
    [anon_sym_notnull] = ACTIONS(3045),
    [anon_sym_unmanaged] = ACTIONS(3045),
    [anon_sym_checked] = ACTIONS(3045),
    [anon_sym_BANG] = ACTIONS(3047),
    [anon_sym_TILDE] = ACTIONS(3047),
    [anon_sym_PLUS_PLUS] = ACTIONS(3047),
    [anon_sym_DASH_DASH] = ACTIONS(3047),
    [anon_sym_true] = ACTIONS(3045),
    [anon_sym_false] = ACTIONS(3045),
    [anon_sym_PLUS] = ACTIONS(3045),
    [anon_sym_DASH] = ACTIONS(3045),
    [anon_sym_STAR] = ACTIONS(3047),
    [anon_sym_CARET] = ACTIONS(3047),
    [anon_sym_AMP] = ACTIONS(3047),
    [anon_sym_this] = ACTIONS(3045),
    [anon_sym_scoped] = ACTIONS(3045),
    [anon_sym_base] = ACTIONS(3045),
    [anon_sym_var] = ACTIONS(3045),
    [sym_predefined_type] = ACTIONS(3045),
    [anon_sym_break] = ACTIONS(3045),
    [anon_sym_unchecked] = ACTIONS(3045),
    [anon_sym_continue] = ACTIONS(3045),
    [anon_sym_do] = ACTIONS(3045),
    [anon_sym_while] = ACTIONS(3045),
    [anon_sym_for] = ACTIONS(3045),
    [anon_sym_lock] = ACTIONS(3045),
    [anon_sym_yield] = ACTIONS(3045),
    [anon_sym_switch] = ACTIONS(3045),
    [anon_sym_default] = ACTIONS(3045),
    [anon_sym_throw] = ACTIONS(3045),
    [anon_sym_try] = ACTIONS(3045),
    [anon_sym_catch] = ACTIONS(3045),
    [anon_sym_when] = ACTIONS(3045),
    [anon_sym_finally] = ACTIONS(3045),
    [anon_sym_await] = ACTIONS(3045),
    [anon_sym_foreach] = ACTIONS(3045),
    [anon_sym_goto] = ACTIONS(3045),
    [anon_sym_if] = ACTIONS(3045),
    [anon_sym_else] = ACTIONS(3045),
    [anon_sym_DOT_DOT] = ACTIONS(3047),
    [anon_sym_from] = ACTIONS(3045),
    [anon_sym_into] = ACTIONS(3045),
    [anon_sym_join] = ACTIONS(3045),
    [anon_sym_on] = ACTIONS(3045),
    [anon_sym_equals] = ACTIONS(3045),
    [anon_sym_let] = ACTIONS(3045),
    [anon_sym_orderby] = ACTIONS(3045),
    [anon_sym_ascending] = ACTIONS(3045),
    [anon_sym_descending] = ACTIONS(3045),
    [anon_sym_group] = ACTIONS(3045),
    [anon_sym_by] = ACTIONS(3045),
    [anon_sym_select] = ACTIONS(3045),
    [anon_sym_stackalloc] = ACTIONS(3045),
    [anon_sym_sizeof] = ACTIONS(3045),
    [anon_sym_typeof] = ACTIONS(3045),
    [anon_sym___makeref] = ACTIONS(3045),
    [anon_sym___reftype] = ACTIONS(3045),
    [anon_sym___refvalue] = ACTIONS(3045),
    [sym_null_literal] = ACTIONS(3045),
    [anon_sym_SQUOTE] = ACTIONS(3047),
    [sym_integer_literal] = ACTIONS(3045),
    [sym_real_literal] = ACTIONS(3047),
    [anon_sym_DQUOTE] = ACTIONS(3047),
    [sym_verbatim_string_literal] = ACTIONS(3047),
    [aux_sym_preproc_if_token1] = ACTIONS(3047),
    [aux_sym_preproc_if_token3] = ACTIONS(3047),
    [aux_sym_preproc_else_token1] = ACTIONS(3047),
    [aux_sym_preproc_elif_token1] = ACTIONS(3047),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3047),
    [sym_interpolation_verbatim_start] = ACTIONS(3047),
    [sym_interpolation_raw_start] = ACTIONS(3047),
    [sym_raw_string_start] = ACTIONS(3047),
  },
  [2221] = {
    [sym_preproc_region] = STATE(2221),
    [sym_preproc_endregion] = STATE(2221),
    [sym_preproc_line] = STATE(2221),
    [sym_preproc_pragma] = STATE(2221),
    [sym_preproc_nullable] = STATE(2221),
    [sym_preproc_error] = STATE(2221),
    [sym_preproc_warning] = STATE(2221),
    [sym_preproc_define] = STATE(2221),
    [sym_preproc_undef] = STATE(2221),
    [sym__identifier_token] = ACTIONS(3049),
    [anon_sym_extern] = ACTIONS(3049),
    [anon_sym_alias] = ACTIONS(3049),
    [anon_sym_SEMI] = ACTIONS(3051),
    [anon_sym_global] = ACTIONS(3049),
    [anon_sym_using] = ACTIONS(3049),
    [anon_sym_unsafe] = ACTIONS(3049),
    [anon_sym_static] = ACTIONS(3049),
    [anon_sym_LBRACK] = ACTIONS(3051),
    [anon_sym_LPAREN] = ACTIONS(3051),
    [anon_sym_return] = ACTIONS(3049),
    [anon_sym_namespace] = ACTIONS(3049),
    [anon_sym_class] = ACTIONS(3049),
    [anon_sym_ref] = ACTIONS(3049),
    [anon_sym_struct] = ACTIONS(3049),
    [anon_sym_enum] = ACTIONS(3049),
    [anon_sym_LBRACE] = ACTIONS(3051),
    [anon_sym_interface] = ACTIONS(3049),
    [anon_sym_delegate] = ACTIONS(3049),
    [anon_sym_record] = ACTIONS(3049),
    [anon_sym_abstract] = ACTIONS(3049),
    [anon_sym_async] = ACTIONS(3049),
    [anon_sym_const] = ACTIONS(3049),
    [anon_sym_file] = ACTIONS(3049),
    [anon_sym_fixed] = ACTIONS(3049),
    [anon_sym_internal] = ACTIONS(3049),
    [anon_sym_new] = ACTIONS(3049),
    [anon_sym_override] = ACTIONS(3049),
    [anon_sym_partial] = ACTIONS(3049),
    [anon_sym_private] = ACTIONS(3049),
    [anon_sym_protected] = ACTIONS(3049),
    [anon_sym_public] = ACTIONS(3049),
    [anon_sym_readonly] = ACTIONS(3049),
    [anon_sym_required] = ACTIONS(3049),
    [anon_sym_sealed] = ACTIONS(3049),
    [anon_sym_virtual] = ACTIONS(3049),
    [anon_sym_volatile] = ACTIONS(3049),
    [anon_sym_where] = ACTIONS(3049),
    [anon_sym_notnull] = ACTIONS(3049),
    [anon_sym_unmanaged] = ACTIONS(3049),
    [anon_sym_checked] = ACTIONS(3049),
    [anon_sym_BANG] = ACTIONS(3051),
    [anon_sym_TILDE] = ACTIONS(3051),
    [anon_sym_PLUS_PLUS] = ACTIONS(3051),
    [anon_sym_DASH_DASH] = ACTIONS(3051),
    [anon_sym_true] = ACTIONS(3049),
    [anon_sym_false] = ACTIONS(3049),
    [anon_sym_PLUS] = ACTIONS(3049),
    [anon_sym_DASH] = ACTIONS(3049),
    [anon_sym_STAR] = ACTIONS(3051),
    [anon_sym_CARET] = ACTIONS(3051),
    [anon_sym_AMP] = ACTIONS(3051),
    [anon_sym_this] = ACTIONS(3049),
    [anon_sym_scoped] = ACTIONS(3049),
    [anon_sym_base] = ACTIONS(3049),
    [anon_sym_var] = ACTIONS(3049),
    [sym_predefined_type] = ACTIONS(3049),
    [anon_sym_break] = ACTIONS(3049),
    [anon_sym_unchecked] = ACTIONS(3049),
    [anon_sym_continue] = ACTIONS(3049),
    [anon_sym_do] = ACTIONS(3049),
    [anon_sym_while] = ACTIONS(3049),
    [anon_sym_for] = ACTIONS(3049),
    [anon_sym_lock] = ACTIONS(3049),
    [anon_sym_yield] = ACTIONS(3049),
    [anon_sym_switch] = ACTIONS(3049),
    [anon_sym_default] = ACTIONS(3049),
    [anon_sym_throw] = ACTIONS(3049),
    [anon_sym_try] = ACTIONS(3049),
    [anon_sym_when] = ACTIONS(3049),
    [anon_sym_await] = ACTIONS(3049),
    [anon_sym_foreach] = ACTIONS(3049),
    [anon_sym_goto] = ACTIONS(3049),
    [anon_sym_if] = ACTIONS(3049),
    [anon_sym_else] = ACTIONS(3049),
    [anon_sym_DOT_DOT] = ACTIONS(3051),
    [anon_sym_from] = ACTIONS(3049),
    [anon_sym_into] = ACTIONS(3049),
    [anon_sym_join] = ACTIONS(3049),
    [anon_sym_on] = ACTIONS(3049),
    [anon_sym_equals] = ACTIONS(3049),
    [anon_sym_let] = ACTIONS(3049),
    [anon_sym_orderby] = ACTIONS(3049),
    [anon_sym_ascending] = ACTIONS(3049),
    [anon_sym_descending] = ACTIONS(3049),
    [anon_sym_group] = ACTIONS(3049),
    [anon_sym_by] = ACTIONS(3049),
    [anon_sym_select] = ACTIONS(3049),
    [anon_sym_stackalloc] = ACTIONS(3049),
    [anon_sym_sizeof] = ACTIONS(3049),
    [anon_sym_typeof] = ACTIONS(3049),
    [anon_sym___makeref] = ACTIONS(3049),
    [anon_sym___reftype] = ACTIONS(3049),
    [anon_sym___refvalue] = ACTIONS(3049),
    [sym_null_literal] = ACTIONS(3049),
    [anon_sym_SQUOTE] = ACTIONS(3051),
    [sym_integer_literal] = ACTIONS(3049),
    [sym_real_literal] = ACTIONS(3051),
    [anon_sym_DQUOTE] = ACTIONS(3051),
    [sym_verbatim_string_literal] = ACTIONS(3051),
    [aux_sym_preproc_if_token1] = ACTIONS(3051),
    [aux_sym_preproc_if_token3] = ACTIONS(3051),
    [aux_sym_preproc_else_token1] = ACTIONS(3051),
    [aux_sym_preproc_elif_token1] = ACTIONS(3051),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3051),
    [sym_interpolation_verbatim_start] = ACTIONS(3051),
    [sym_interpolation_raw_start] = ACTIONS(3051),
    [sym_raw_string_start] = ACTIONS(3051),
  },
  [2222] = {
    [sym_preproc_region] = STATE(2222),
    [sym_preproc_endregion] = STATE(2222),
    [sym_preproc_line] = STATE(2222),
    [sym_preproc_pragma] = STATE(2222),
    [sym_preproc_nullable] = STATE(2222),
    [sym_preproc_error] = STATE(2222),
    [sym_preproc_warning] = STATE(2222),
    [sym_preproc_define] = STATE(2222),
    [sym_preproc_undef] = STATE(2222),
    [sym__identifier_token] = ACTIONS(3053),
    [anon_sym_extern] = ACTIONS(3053),
    [anon_sym_alias] = ACTIONS(3053),
    [anon_sym_SEMI] = ACTIONS(3055),
    [anon_sym_global] = ACTIONS(3053),
    [anon_sym_using] = ACTIONS(3053),
    [anon_sym_unsafe] = ACTIONS(3053),
    [anon_sym_static] = ACTIONS(3053),
    [anon_sym_LBRACK] = ACTIONS(3055),
    [anon_sym_LPAREN] = ACTIONS(3055),
    [anon_sym_return] = ACTIONS(3053),
    [anon_sym_namespace] = ACTIONS(3053),
    [anon_sym_class] = ACTIONS(3053),
    [anon_sym_ref] = ACTIONS(3053),
    [anon_sym_struct] = ACTIONS(3053),
    [anon_sym_enum] = ACTIONS(3053),
    [anon_sym_LBRACE] = ACTIONS(3055),
    [anon_sym_interface] = ACTIONS(3053),
    [anon_sym_delegate] = ACTIONS(3053),
    [anon_sym_record] = ACTIONS(3053),
    [anon_sym_abstract] = ACTIONS(3053),
    [anon_sym_async] = ACTIONS(3053),
    [anon_sym_const] = ACTIONS(3053),
    [anon_sym_file] = ACTIONS(3053),
    [anon_sym_fixed] = ACTIONS(3053),
    [anon_sym_internal] = ACTIONS(3053),
    [anon_sym_new] = ACTIONS(3053),
    [anon_sym_override] = ACTIONS(3053),
    [anon_sym_partial] = ACTIONS(3053),
    [anon_sym_private] = ACTIONS(3053),
    [anon_sym_protected] = ACTIONS(3053),
    [anon_sym_public] = ACTIONS(3053),
    [anon_sym_readonly] = ACTIONS(3053),
    [anon_sym_required] = ACTIONS(3053),
    [anon_sym_sealed] = ACTIONS(3053),
    [anon_sym_virtual] = ACTIONS(3053),
    [anon_sym_volatile] = ACTIONS(3053),
    [anon_sym_where] = ACTIONS(3053),
    [anon_sym_notnull] = ACTIONS(3053),
    [anon_sym_unmanaged] = ACTIONS(3053),
    [anon_sym_checked] = ACTIONS(3053),
    [anon_sym_BANG] = ACTIONS(3055),
    [anon_sym_TILDE] = ACTIONS(3055),
    [anon_sym_PLUS_PLUS] = ACTIONS(3055),
    [anon_sym_DASH_DASH] = ACTIONS(3055),
    [anon_sym_true] = ACTIONS(3053),
    [anon_sym_false] = ACTIONS(3053),
    [anon_sym_PLUS] = ACTIONS(3053),
    [anon_sym_DASH] = ACTIONS(3053),
    [anon_sym_STAR] = ACTIONS(3055),
    [anon_sym_CARET] = ACTIONS(3055),
    [anon_sym_AMP] = ACTIONS(3055),
    [anon_sym_this] = ACTIONS(3053),
    [anon_sym_scoped] = ACTIONS(3053),
    [anon_sym_base] = ACTIONS(3053),
    [anon_sym_var] = ACTIONS(3053),
    [sym_predefined_type] = ACTIONS(3053),
    [anon_sym_break] = ACTIONS(3053),
    [anon_sym_unchecked] = ACTIONS(3053),
    [anon_sym_continue] = ACTIONS(3053),
    [anon_sym_do] = ACTIONS(3053),
    [anon_sym_while] = ACTIONS(3053),
    [anon_sym_for] = ACTIONS(3053),
    [anon_sym_lock] = ACTIONS(3053),
    [anon_sym_yield] = ACTIONS(3053),
    [anon_sym_switch] = ACTIONS(3053),
    [anon_sym_default] = ACTIONS(3053),
    [anon_sym_throw] = ACTIONS(3053),
    [anon_sym_try] = ACTIONS(3053),
    [anon_sym_when] = ACTIONS(3053),
    [anon_sym_await] = ACTIONS(3053),
    [anon_sym_foreach] = ACTIONS(3053),
    [anon_sym_goto] = ACTIONS(3053),
    [anon_sym_if] = ACTIONS(3053),
    [anon_sym_else] = ACTIONS(3053),
    [anon_sym_DOT_DOT] = ACTIONS(3055),
    [anon_sym_from] = ACTIONS(3053),
    [anon_sym_into] = ACTIONS(3053),
    [anon_sym_join] = ACTIONS(3053),
    [anon_sym_on] = ACTIONS(3053),
    [anon_sym_equals] = ACTIONS(3053),
    [anon_sym_let] = ACTIONS(3053),
    [anon_sym_orderby] = ACTIONS(3053),
    [anon_sym_ascending] = ACTIONS(3053),
    [anon_sym_descending] = ACTIONS(3053),
    [anon_sym_group] = ACTIONS(3053),
    [anon_sym_by] = ACTIONS(3053),
    [anon_sym_select] = ACTIONS(3053),
    [anon_sym_stackalloc] = ACTIONS(3053),
    [anon_sym_sizeof] = ACTIONS(3053),
    [anon_sym_typeof] = ACTIONS(3053),
    [anon_sym___makeref] = ACTIONS(3053),
    [anon_sym___reftype] = ACTIONS(3053),
    [anon_sym___refvalue] = ACTIONS(3053),
    [sym_null_literal] = ACTIONS(3053),
    [anon_sym_SQUOTE] = ACTIONS(3055),
    [sym_integer_literal] = ACTIONS(3053),
    [sym_real_literal] = ACTIONS(3055),
    [anon_sym_DQUOTE] = ACTIONS(3055),
    [sym_verbatim_string_literal] = ACTIONS(3055),
    [aux_sym_preproc_if_token1] = ACTIONS(3055),
    [aux_sym_preproc_if_token3] = ACTIONS(3055),
    [aux_sym_preproc_else_token1] = ACTIONS(3055),
    [aux_sym_preproc_elif_token1] = ACTIONS(3055),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3055),
    [sym_interpolation_verbatim_start] = ACTIONS(3055),
    [sym_interpolation_raw_start] = ACTIONS(3055),
    [sym_raw_string_start] = ACTIONS(3055),
  },
  [2223] = {
    [sym_preproc_region] = STATE(2223),
    [sym_preproc_endregion] = STATE(2223),
    [sym_preproc_line] = STATE(2223),
    [sym_preproc_pragma] = STATE(2223),
    [sym_preproc_nullable] = STATE(2223),
    [sym_preproc_error] = STATE(2223),
    [sym_preproc_warning] = STATE(2223),
    [sym_preproc_define] = STATE(2223),
    [sym_preproc_undef] = STATE(2223),
    [sym__identifier_token] = ACTIONS(3057),
    [anon_sym_extern] = ACTIONS(3057),
    [anon_sym_alias] = ACTIONS(3057),
    [anon_sym_SEMI] = ACTIONS(3059),
    [anon_sym_global] = ACTIONS(3057),
    [anon_sym_using] = ACTIONS(3057),
    [anon_sym_unsafe] = ACTIONS(3057),
    [anon_sym_static] = ACTIONS(3057),
    [anon_sym_LBRACK] = ACTIONS(3059),
    [anon_sym_LPAREN] = ACTIONS(3059),
    [anon_sym_return] = ACTIONS(3057),
    [anon_sym_namespace] = ACTIONS(3057),
    [anon_sym_class] = ACTIONS(3057),
    [anon_sym_ref] = ACTIONS(3057),
    [anon_sym_struct] = ACTIONS(3057),
    [anon_sym_enum] = ACTIONS(3057),
    [anon_sym_LBRACE] = ACTIONS(3059),
    [anon_sym_interface] = ACTIONS(3057),
    [anon_sym_delegate] = ACTIONS(3057),
    [anon_sym_record] = ACTIONS(3057),
    [anon_sym_abstract] = ACTIONS(3057),
    [anon_sym_async] = ACTIONS(3057),
    [anon_sym_const] = ACTIONS(3057),
    [anon_sym_file] = ACTIONS(3057),
    [anon_sym_fixed] = ACTIONS(3057),
    [anon_sym_internal] = ACTIONS(3057),
    [anon_sym_new] = ACTIONS(3057),
    [anon_sym_override] = ACTIONS(3057),
    [anon_sym_partial] = ACTIONS(3057),
    [anon_sym_private] = ACTIONS(3057),
    [anon_sym_protected] = ACTIONS(3057),
    [anon_sym_public] = ACTIONS(3057),
    [anon_sym_readonly] = ACTIONS(3057),
    [anon_sym_required] = ACTIONS(3057),
    [anon_sym_sealed] = ACTIONS(3057),
    [anon_sym_virtual] = ACTIONS(3057),
    [anon_sym_volatile] = ACTIONS(3057),
    [anon_sym_where] = ACTIONS(3057),
    [anon_sym_notnull] = ACTIONS(3057),
    [anon_sym_unmanaged] = ACTIONS(3057),
    [anon_sym_checked] = ACTIONS(3057),
    [anon_sym_BANG] = ACTIONS(3059),
    [anon_sym_TILDE] = ACTIONS(3059),
    [anon_sym_PLUS_PLUS] = ACTIONS(3059),
    [anon_sym_DASH_DASH] = ACTIONS(3059),
    [anon_sym_true] = ACTIONS(3057),
    [anon_sym_false] = ACTIONS(3057),
    [anon_sym_PLUS] = ACTIONS(3057),
    [anon_sym_DASH] = ACTIONS(3057),
    [anon_sym_STAR] = ACTIONS(3059),
    [anon_sym_CARET] = ACTIONS(3059),
    [anon_sym_AMP] = ACTIONS(3059),
    [anon_sym_this] = ACTIONS(3057),
    [anon_sym_scoped] = ACTIONS(3057),
    [anon_sym_base] = ACTIONS(3057),
    [anon_sym_var] = ACTIONS(3057),
    [sym_predefined_type] = ACTIONS(3057),
    [anon_sym_break] = ACTIONS(3057),
    [anon_sym_unchecked] = ACTIONS(3057),
    [anon_sym_continue] = ACTIONS(3057),
    [anon_sym_do] = ACTIONS(3057),
    [anon_sym_while] = ACTIONS(3057),
    [anon_sym_for] = ACTIONS(3057),
    [anon_sym_lock] = ACTIONS(3057),
    [anon_sym_yield] = ACTIONS(3057),
    [anon_sym_switch] = ACTIONS(3057),
    [anon_sym_default] = ACTIONS(3057),
    [anon_sym_throw] = ACTIONS(3057),
    [anon_sym_try] = ACTIONS(3057),
    [anon_sym_when] = ACTIONS(3057),
    [anon_sym_await] = ACTIONS(3057),
    [anon_sym_foreach] = ACTIONS(3057),
    [anon_sym_goto] = ACTIONS(3057),
    [anon_sym_if] = ACTIONS(3057),
    [anon_sym_else] = ACTIONS(3057),
    [anon_sym_DOT_DOT] = ACTIONS(3059),
    [anon_sym_from] = ACTIONS(3057),
    [anon_sym_into] = ACTIONS(3057),
    [anon_sym_join] = ACTIONS(3057),
    [anon_sym_on] = ACTIONS(3057),
    [anon_sym_equals] = ACTIONS(3057),
    [anon_sym_let] = ACTIONS(3057),
    [anon_sym_orderby] = ACTIONS(3057),
    [anon_sym_ascending] = ACTIONS(3057),
    [anon_sym_descending] = ACTIONS(3057),
    [anon_sym_group] = ACTIONS(3057),
    [anon_sym_by] = ACTIONS(3057),
    [anon_sym_select] = ACTIONS(3057),
    [anon_sym_stackalloc] = ACTIONS(3057),
    [anon_sym_sizeof] = ACTIONS(3057),
    [anon_sym_typeof] = ACTIONS(3057),
    [anon_sym___makeref] = ACTIONS(3057),
    [anon_sym___reftype] = ACTIONS(3057),
    [anon_sym___refvalue] = ACTIONS(3057),
    [sym_null_literal] = ACTIONS(3057),
    [anon_sym_SQUOTE] = ACTIONS(3059),
    [sym_integer_literal] = ACTIONS(3057),
    [sym_real_literal] = ACTIONS(3059),
    [anon_sym_DQUOTE] = ACTIONS(3059),
    [sym_verbatim_string_literal] = ACTIONS(3059),
    [aux_sym_preproc_if_token1] = ACTIONS(3059),
    [aux_sym_preproc_if_token3] = ACTIONS(3059),
    [aux_sym_preproc_else_token1] = ACTIONS(3059),
    [aux_sym_preproc_elif_token1] = ACTIONS(3059),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3059),
    [sym_interpolation_verbatim_start] = ACTIONS(3059),
    [sym_interpolation_raw_start] = ACTIONS(3059),
    [sym_raw_string_start] = ACTIONS(3059),
  },
  [2224] = {
    [sym_preproc_region] = STATE(2224),
    [sym_preproc_endregion] = STATE(2224),
    [sym_preproc_line] = STATE(2224),
    [sym_preproc_pragma] = STATE(2224),
    [sym_preproc_nullable] = STATE(2224),
    [sym_preproc_error] = STATE(2224),
    [sym_preproc_warning] = STATE(2224),
    [sym_preproc_define] = STATE(2224),
    [sym_preproc_undef] = STATE(2224),
    [sym__identifier_token] = ACTIONS(3061),
    [anon_sym_extern] = ACTIONS(3061),
    [anon_sym_alias] = ACTIONS(3061),
    [anon_sym_SEMI] = ACTIONS(3063),
    [anon_sym_global] = ACTIONS(3061),
    [anon_sym_using] = ACTIONS(3061),
    [anon_sym_unsafe] = ACTIONS(3061),
    [anon_sym_static] = ACTIONS(3061),
    [anon_sym_LBRACK] = ACTIONS(3063),
    [anon_sym_LPAREN] = ACTIONS(3063),
    [anon_sym_return] = ACTIONS(3061),
    [anon_sym_namespace] = ACTIONS(3061),
    [anon_sym_class] = ACTIONS(3061),
    [anon_sym_ref] = ACTIONS(3061),
    [anon_sym_struct] = ACTIONS(3061),
    [anon_sym_enum] = ACTIONS(3061),
    [anon_sym_LBRACE] = ACTIONS(3063),
    [anon_sym_interface] = ACTIONS(3061),
    [anon_sym_delegate] = ACTIONS(3061),
    [anon_sym_record] = ACTIONS(3061),
    [anon_sym_abstract] = ACTIONS(3061),
    [anon_sym_async] = ACTIONS(3061),
    [anon_sym_const] = ACTIONS(3061),
    [anon_sym_file] = ACTIONS(3061),
    [anon_sym_fixed] = ACTIONS(3061),
    [anon_sym_internal] = ACTIONS(3061),
    [anon_sym_new] = ACTIONS(3061),
    [anon_sym_override] = ACTIONS(3061),
    [anon_sym_partial] = ACTIONS(3061),
    [anon_sym_private] = ACTIONS(3061),
    [anon_sym_protected] = ACTIONS(3061),
    [anon_sym_public] = ACTIONS(3061),
    [anon_sym_readonly] = ACTIONS(3061),
    [anon_sym_required] = ACTIONS(3061),
    [anon_sym_sealed] = ACTIONS(3061),
    [anon_sym_virtual] = ACTIONS(3061),
    [anon_sym_volatile] = ACTIONS(3061),
    [anon_sym_where] = ACTIONS(3061),
    [anon_sym_notnull] = ACTIONS(3061),
    [anon_sym_unmanaged] = ACTIONS(3061),
    [anon_sym_checked] = ACTIONS(3061),
    [anon_sym_BANG] = ACTIONS(3063),
    [anon_sym_TILDE] = ACTIONS(3063),
    [anon_sym_PLUS_PLUS] = ACTIONS(3063),
    [anon_sym_DASH_DASH] = ACTIONS(3063),
    [anon_sym_true] = ACTIONS(3061),
    [anon_sym_false] = ACTIONS(3061),
    [anon_sym_PLUS] = ACTIONS(3061),
    [anon_sym_DASH] = ACTIONS(3061),
    [anon_sym_STAR] = ACTIONS(3063),
    [anon_sym_CARET] = ACTIONS(3063),
    [anon_sym_AMP] = ACTIONS(3063),
    [anon_sym_this] = ACTIONS(3061),
    [anon_sym_scoped] = ACTIONS(3061),
    [anon_sym_base] = ACTIONS(3061),
    [anon_sym_var] = ACTIONS(3061),
    [sym_predefined_type] = ACTIONS(3061),
    [anon_sym_break] = ACTIONS(3061),
    [anon_sym_unchecked] = ACTIONS(3061),
    [anon_sym_continue] = ACTIONS(3061),
    [anon_sym_do] = ACTIONS(3061),
    [anon_sym_while] = ACTIONS(3061),
    [anon_sym_for] = ACTIONS(3061),
    [anon_sym_lock] = ACTIONS(3061),
    [anon_sym_yield] = ACTIONS(3061),
    [anon_sym_switch] = ACTIONS(3061),
    [anon_sym_default] = ACTIONS(3061),
    [anon_sym_throw] = ACTIONS(3061),
    [anon_sym_try] = ACTIONS(3061),
    [anon_sym_when] = ACTIONS(3061),
    [anon_sym_await] = ACTIONS(3061),
    [anon_sym_foreach] = ACTIONS(3061),
    [anon_sym_goto] = ACTIONS(3061),
    [anon_sym_if] = ACTIONS(3061),
    [anon_sym_else] = ACTIONS(3061),
    [anon_sym_DOT_DOT] = ACTIONS(3063),
    [anon_sym_from] = ACTIONS(3061),
    [anon_sym_into] = ACTIONS(3061),
    [anon_sym_join] = ACTIONS(3061),
    [anon_sym_on] = ACTIONS(3061),
    [anon_sym_equals] = ACTIONS(3061),
    [anon_sym_let] = ACTIONS(3061),
    [anon_sym_orderby] = ACTIONS(3061),
    [anon_sym_ascending] = ACTIONS(3061),
    [anon_sym_descending] = ACTIONS(3061),
    [anon_sym_group] = ACTIONS(3061),
    [anon_sym_by] = ACTIONS(3061),
    [anon_sym_select] = ACTIONS(3061),
    [anon_sym_stackalloc] = ACTIONS(3061),
    [anon_sym_sizeof] = ACTIONS(3061),
    [anon_sym_typeof] = ACTIONS(3061),
    [anon_sym___makeref] = ACTIONS(3061),
    [anon_sym___reftype] = ACTIONS(3061),
    [anon_sym___refvalue] = ACTIONS(3061),
    [sym_null_literal] = ACTIONS(3061),
    [anon_sym_SQUOTE] = ACTIONS(3063),
    [sym_integer_literal] = ACTIONS(3061),
    [sym_real_literal] = ACTIONS(3063),
    [anon_sym_DQUOTE] = ACTIONS(3063),
    [sym_verbatim_string_literal] = ACTIONS(3063),
    [aux_sym_preproc_if_token1] = ACTIONS(3063),
    [aux_sym_preproc_if_token3] = ACTIONS(3063),
    [aux_sym_preproc_else_token1] = ACTIONS(3063),
    [aux_sym_preproc_elif_token1] = ACTIONS(3063),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3063),
    [sym_interpolation_verbatim_start] = ACTIONS(3063),
    [sym_interpolation_raw_start] = ACTIONS(3063),
    [sym_raw_string_start] = ACTIONS(3063),
  },
  [2225] = {
    [sym_preproc_region] = STATE(2225),
    [sym_preproc_endregion] = STATE(2225),
    [sym_preproc_line] = STATE(2225),
    [sym_preproc_pragma] = STATE(2225),
    [sym_preproc_nullable] = STATE(2225),
    [sym_preproc_error] = STATE(2225),
    [sym_preproc_warning] = STATE(2225),
    [sym_preproc_define] = STATE(2225),
    [sym_preproc_undef] = STATE(2225),
    [sym__identifier_token] = ACTIONS(3065),
    [anon_sym_extern] = ACTIONS(3065),
    [anon_sym_alias] = ACTIONS(3065),
    [anon_sym_SEMI] = ACTIONS(3067),
    [anon_sym_global] = ACTIONS(3065),
    [anon_sym_using] = ACTIONS(3065),
    [anon_sym_unsafe] = ACTIONS(3065),
    [anon_sym_static] = ACTIONS(3065),
    [anon_sym_LBRACK] = ACTIONS(3067),
    [anon_sym_LPAREN] = ACTIONS(3067),
    [anon_sym_return] = ACTIONS(3065),
    [anon_sym_namespace] = ACTIONS(3065),
    [anon_sym_class] = ACTIONS(3065),
    [anon_sym_ref] = ACTIONS(3065),
    [anon_sym_struct] = ACTIONS(3065),
    [anon_sym_enum] = ACTIONS(3065),
    [anon_sym_LBRACE] = ACTIONS(3067),
    [anon_sym_interface] = ACTIONS(3065),
    [anon_sym_delegate] = ACTIONS(3065),
    [anon_sym_record] = ACTIONS(3065),
    [anon_sym_abstract] = ACTIONS(3065),
    [anon_sym_async] = ACTIONS(3065),
    [anon_sym_const] = ACTIONS(3065),
    [anon_sym_file] = ACTIONS(3065),
    [anon_sym_fixed] = ACTIONS(3065),
    [anon_sym_internal] = ACTIONS(3065),
    [anon_sym_new] = ACTIONS(3065),
    [anon_sym_override] = ACTIONS(3065),
    [anon_sym_partial] = ACTIONS(3065),
    [anon_sym_private] = ACTIONS(3065),
    [anon_sym_protected] = ACTIONS(3065),
    [anon_sym_public] = ACTIONS(3065),
    [anon_sym_readonly] = ACTIONS(3065),
    [anon_sym_required] = ACTIONS(3065),
    [anon_sym_sealed] = ACTIONS(3065),
    [anon_sym_virtual] = ACTIONS(3065),
    [anon_sym_volatile] = ACTIONS(3065),
    [anon_sym_where] = ACTIONS(3065),
    [anon_sym_notnull] = ACTIONS(3065),
    [anon_sym_unmanaged] = ACTIONS(3065),
    [anon_sym_checked] = ACTIONS(3065),
    [anon_sym_BANG] = ACTIONS(3067),
    [anon_sym_TILDE] = ACTIONS(3067),
    [anon_sym_PLUS_PLUS] = ACTIONS(3067),
    [anon_sym_DASH_DASH] = ACTIONS(3067),
    [anon_sym_true] = ACTIONS(3065),
    [anon_sym_false] = ACTIONS(3065),
    [anon_sym_PLUS] = ACTIONS(3065),
    [anon_sym_DASH] = ACTIONS(3065),
    [anon_sym_STAR] = ACTIONS(3067),
    [anon_sym_CARET] = ACTIONS(3067),
    [anon_sym_AMP] = ACTIONS(3067),
    [anon_sym_this] = ACTIONS(3065),
    [anon_sym_scoped] = ACTIONS(3065),
    [anon_sym_base] = ACTIONS(3065),
    [anon_sym_var] = ACTIONS(3065),
    [sym_predefined_type] = ACTIONS(3065),
    [anon_sym_break] = ACTIONS(3065),
    [anon_sym_unchecked] = ACTIONS(3065),
    [anon_sym_continue] = ACTIONS(3065),
    [anon_sym_do] = ACTIONS(3065),
    [anon_sym_while] = ACTIONS(3065),
    [anon_sym_for] = ACTIONS(3065),
    [anon_sym_lock] = ACTIONS(3065),
    [anon_sym_yield] = ACTIONS(3065),
    [anon_sym_switch] = ACTIONS(3065),
    [anon_sym_default] = ACTIONS(3065),
    [anon_sym_throw] = ACTIONS(3065),
    [anon_sym_try] = ACTIONS(3065),
    [anon_sym_when] = ACTIONS(3065),
    [anon_sym_await] = ACTIONS(3065),
    [anon_sym_foreach] = ACTIONS(3065),
    [anon_sym_goto] = ACTIONS(3065),
    [anon_sym_if] = ACTIONS(3065),
    [anon_sym_else] = ACTIONS(3065),
    [anon_sym_DOT_DOT] = ACTIONS(3067),
    [anon_sym_from] = ACTIONS(3065),
    [anon_sym_into] = ACTIONS(3065),
    [anon_sym_join] = ACTIONS(3065),
    [anon_sym_on] = ACTIONS(3065),
    [anon_sym_equals] = ACTIONS(3065),
    [anon_sym_let] = ACTIONS(3065),
    [anon_sym_orderby] = ACTIONS(3065),
    [anon_sym_ascending] = ACTIONS(3065),
    [anon_sym_descending] = ACTIONS(3065),
    [anon_sym_group] = ACTIONS(3065),
    [anon_sym_by] = ACTIONS(3065),
    [anon_sym_select] = ACTIONS(3065),
    [anon_sym_stackalloc] = ACTIONS(3065),
    [anon_sym_sizeof] = ACTIONS(3065),
    [anon_sym_typeof] = ACTIONS(3065),
    [anon_sym___makeref] = ACTIONS(3065),
    [anon_sym___reftype] = ACTIONS(3065),
    [anon_sym___refvalue] = ACTIONS(3065),
    [sym_null_literal] = ACTIONS(3065),
    [anon_sym_SQUOTE] = ACTIONS(3067),
    [sym_integer_literal] = ACTIONS(3065),
    [sym_real_literal] = ACTIONS(3067),
    [anon_sym_DQUOTE] = ACTIONS(3067),
    [sym_verbatim_string_literal] = ACTIONS(3067),
    [aux_sym_preproc_if_token1] = ACTIONS(3067),
    [aux_sym_preproc_if_token3] = ACTIONS(3067),
    [aux_sym_preproc_else_token1] = ACTIONS(3067),
    [aux_sym_preproc_elif_token1] = ACTIONS(3067),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3067),
    [sym_interpolation_verbatim_start] = ACTIONS(3067),
    [sym_interpolation_raw_start] = ACTIONS(3067),
    [sym_raw_string_start] = ACTIONS(3067),
  },
  [2226] = {
    [sym_preproc_region] = STATE(2226),
    [sym_preproc_endregion] = STATE(2226),
    [sym_preproc_line] = STATE(2226),
    [sym_preproc_pragma] = STATE(2226),
    [sym_preproc_nullable] = STATE(2226),
    [sym_preproc_error] = STATE(2226),
    [sym_preproc_warning] = STATE(2226),
    [sym_preproc_define] = STATE(2226),
    [sym_preproc_undef] = STATE(2226),
    [sym__identifier_token] = ACTIONS(3069),
    [anon_sym_extern] = ACTIONS(3069),
    [anon_sym_alias] = ACTIONS(3069),
    [anon_sym_SEMI] = ACTIONS(3071),
    [anon_sym_global] = ACTIONS(3069),
    [anon_sym_using] = ACTIONS(3069),
    [anon_sym_unsafe] = ACTIONS(3069),
    [anon_sym_static] = ACTIONS(3069),
    [anon_sym_LBRACK] = ACTIONS(3071),
    [anon_sym_LPAREN] = ACTIONS(3071),
    [anon_sym_return] = ACTIONS(3069),
    [anon_sym_namespace] = ACTIONS(3069),
    [anon_sym_class] = ACTIONS(3069),
    [anon_sym_ref] = ACTIONS(3069),
    [anon_sym_struct] = ACTIONS(3069),
    [anon_sym_enum] = ACTIONS(3069),
    [anon_sym_LBRACE] = ACTIONS(3071),
    [anon_sym_interface] = ACTIONS(3069),
    [anon_sym_delegate] = ACTIONS(3069),
    [anon_sym_record] = ACTIONS(3069),
    [anon_sym_abstract] = ACTIONS(3069),
    [anon_sym_async] = ACTIONS(3069),
    [anon_sym_const] = ACTIONS(3069),
    [anon_sym_file] = ACTIONS(3069),
    [anon_sym_fixed] = ACTIONS(3069),
    [anon_sym_internal] = ACTIONS(3069),
    [anon_sym_new] = ACTIONS(3069),
    [anon_sym_override] = ACTIONS(3069),
    [anon_sym_partial] = ACTIONS(3069),
    [anon_sym_private] = ACTIONS(3069),
    [anon_sym_protected] = ACTIONS(3069),
    [anon_sym_public] = ACTIONS(3069),
    [anon_sym_readonly] = ACTIONS(3069),
    [anon_sym_required] = ACTIONS(3069),
    [anon_sym_sealed] = ACTIONS(3069),
    [anon_sym_virtual] = ACTIONS(3069),
    [anon_sym_volatile] = ACTIONS(3069),
    [anon_sym_where] = ACTIONS(3069),
    [anon_sym_notnull] = ACTIONS(3069),
    [anon_sym_unmanaged] = ACTIONS(3069),
    [anon_sym_checked] = ACTIONS(3069),
    [anon_sym_BANG] = ACTIONS(3071),
    [anon_sym_TILDE] = ACTIONS(3071),
    [anon_sym_PLUS_PLUS] = ACTIONS(3071),
    [anon_sym_DASH_DASH] = ACTIONS(3071),
    [anon_sym_true] = ACTIONS(3069),
    [anon_sym_false] = ACTIONS(3069),
    [anon_sym_PLUS] = ACTIONS(3069),
    [anon_sym_DASH] = ACTIONS(3069),
    [anon_sym_STAR] = ACTIONS(3071),
    [anon_sym_CARET] = ACTIONS(3071),
    [anon_sym_AMP] = ACTIONS(3071),
    [anon_sym_this] = ACTIONS(3069),
    [anon_sym_scoped] = ACTIONS(3069),
    [anon_sym_base] = ACTIONS(3069),
    [anon_sym_var] = ACTIONS(3069),
    [sym_predefined_type] = ACTIONS(3069),
    [anon_sym_break] = ACTIONS(3069),
    [anon_sym_unchecked] = ACTIONS(3069),
    [anon_sym_continue] = ACTIONS(3069),
    [anon_sym_do] = ACTIONS(3069),
    [anon_sym_while] = ACTIONS(3069),
    [anon_sym_for] = ACTIONS(3069),
    [anon_sym_lock] = ACTIONS(3069),
    [anon_sym_yield] = ACTIONS(3069),
    [anon_sym_switch] = ACTIONS(3069),
    [anon_sym_default] = ACTIONS(3069),
    [anon_sym_throw] = ACTIONS(3069),
    [anon_sym_try] = ACTIONS(3069),
    [anon_sym_when] = ACTIONS(3069),
    [anon_sym_await] = ACTIONS(3069),
    [anon_sym_foreach] = ACTIONS(3069),
    [anon_sym_goto] = ACTIONS(3069),
    [anon_sym_if] = ACTIONS(3069),
    [anon_sym_else] = ACTIONS(3069),
    [anon_sym_DOT_DOT] = ACTIONS(3071),
    [anon_sym_from] = ACTIONS(3069),
    [anon_sym_into] = ACTIONS(3069),
    [anon_sym_join] = ACTIONS(3069),
    [anon_sym_on] = ACTIONS(3069),
    [anon_sym_equals] = ACTIONS(3069),
    [anon_sym_let] = ACTIONS(3069),
    [anon_sym_orderby] = ACTIONS(3069),
    [anon_sym_ascending] = ACTIONS(3069),
    [anon_sym_descending] = ACTIONS(3069),
    [anon_sym_group] = ACTIONS(3069),
    [anon_sym_by] = ACTIONS(3069),
    [anon_sym_select] = ACTIONS(3069),
    [anon_sym_stackalloc] = ACTIONS(3069),
    [anon_sym_sizeof] = ACTIONS(3069),
    [anon_sym_typeof] = ACTIONS(3069),
    [anon_sym___makeref] = ACTIONS(3069),
    [anon_sym___reftype] = ACTIONS(3069),
    [anon_sym___refvalue] = ACTIONS(3069),
    [sym_null_literal] = ACTIONS(3069),
    [anon_sym_SQUOTE] = ACTIONS(3071),
    [sym_integer_literal] = ACTIONS(3069),
    [sym_real_literal] = ACTIONS(3071),
    [anon_sym_DQUOTE] = ACTIONS(3071),
    [sym_verbatim_string_literal] = ACTIONS(3071),
    [aux_sym_preproc_if_token1] = ACTIONS(3071),
    [aux_sym_preproc_if_token3] = ACTIONS(3071),
    [aux_sym_preproc_else_token1] = ACTIONS(3071),
    [aux_sym_preproc_elif_token1] = ACTIONS(3071),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3071),
    [sym_interpolation_verbatim_start] = ACTIONS(3071),
    [sym_interpolation_raw_start] = ACTIONS(3071),
    [sym_raw_string_start] = ACTIONS(3071),
  },
  [2227] = {
    [sym_preproc_region] = STATE(2227),
    [sym_preproc_endregion] = STATE(2227),
    [sym_preproc_line] = STATE(2227),
    [sym_preproc_pragma] = STATE(2227),
    [sym_preproc_nullable] = STATE(2227),
    [sym_preproc_error] = STATE(2227),
    [sym_preproc_warning] = STATE(2227),
    [sym_preproc_define] = STATE(2227),
    [sym_preproc_undef] = STATE(2227),
    [sym__identifier_token] = ACTIONS(3073),
    [anon_sym_extern] = ACTIONS(3073),
    [anon_sym_alias] = ACTIONS(3073),
    [anon_sym_SEMI] = ACTIONS(3075),
    [anon_sym_global] = ACTIONS(3073),
    [anon_sym_using] = ACTIONS(3073),
    [anon_sym_unsafe] = ACTIONS(3073),
    [anon_sym_static] = ACTIONS(3073),
    [anon_sym_LBRACK] = ACTIONS(3075),
    [anon_sym_LPAREN] = ACTIONS(3075),
    [anon_sym_return] = ACTIONS(3073),
    [anon_sym_namespace] = ACTIONS(3073),
    [anon_sym_class] = ACTIONS(3073),
    [anon_sym_ref] = ACTIONS(3073),
    [anon_sym_struct] = ACTIONS(3073),
    [anon_sym_enum] = ACTIONS(3073),
    [anon_sym_LBRACE] = ACTIONS(3075),
    [anon_sym_interface] = ACTIONS(3073),
    [anon_sym_delegate] = ACTIONS(3073),
    [anon_sym_record] = ACTIONS(3073),
    [anon_sym_abstract] = ACTIONS(3073),
    [anon_sym_async] = ACTIONS(3073),
    [anon_sym_const] = ACTIONS(3073),
    [anon_sym_file] = ACTIONS(3073),
    [anon_sym_fixed] = ACTIONS(3073),
    [anon_sym_internal] = ACTIONS(3073),
    [anon_sym_new] = ACTIONS(3073),
    [anon_sym_override] = ACTIONS(3073),
    [anon_sym_partial] = ACTIONS(3073),
    [anon_sym_private] = ACTIONS(3073),
    [anon_sym_protected] = ACTIONS(3073),
    [anon_sym_public] = ACTIONS(3073),
    [anon_sym_readonly] = ACTIONS(3073),
    [anon_sym_required] = ACTIONS(3073),
    [anon_sym_sealed] = ACTIONS(3073),
    [anon_sym_virtual] = ACTIONS(3073),
    [anon_sym_volatile] = ACTIONS(3073),
    [anon_sym_where] = ACTIONS(3073),
    [anon_sym_notnull] = ACTIONS(3073),
    [anon_sym_unmanaged] = ACTIONS(3073),
    [anon_sym_checked] = ACTIONS(3073),
    [anon_sym_BANG] = ACTIONS(3075),
    [anon_sym_TILDE] = ACTIONS(3075),
    [anon_sym_PLUS_PLUS] = ACTIONS(3075),
    [anon_sym_DASH_DASH] = ACTIONS(3075),
    [anon_sym_true] = ACTIONS(3073),
    [anon_sym_false] = ACTIONS(3073),
    [anon_sym_PLUS] = ACTIONS(3073),
    [anon_sym_DASH] = ACTIONS(3073),
    [anon_sym_STAR] = ACTIONS(3075),
    [anon_sym_CARET] = ACTIONS(3075),
    [anon_sym_AMP] = ACTIONS(3075),
    [anon_sym_this] = ACTIONS(3073),
    [anon_sym_scoped] = ACTIONS(3073),
    [anon_sym_base] = ACTIONS(3073),
    [anon_sym_var] = ACTIONS(3073),
    [sym_predefined_type] = ACTIONS(3073),
    [anon_sym_break] = ACTIONS(3073),
    [anon_sym_unchecked] = ACTIONS(3073),
    [anon_sym_continue] = ACTIONS(3073),
    [anon_sym_do] = ACTIONS(3073),
    [anon_sym_while] = ACTIONS(3073),
    [anon_sym_for] = ACTIONS(3073),
    [anon_sym_lock] = ACTIONS(3073),
    [anon_sym_yield] = ACTIONS(3073),
    [anon_sym_switch] = ACTIONS(3073),
    [anon_sym_default] = ACTIONS(3073),
    [anon_sym_throw] = ACTIONS(3073),
    [anon_sym_try] = ACTIONS(3073),
    [anon_sym_when] = ACTIONS(3073),
    [anon_sym_await] = ACTIONS(3073),
    [anon_sym_foreach] = ACTIONS(3073),
    [anon_sym_goto] = ACTIONS(3073),
    [anon_sym_if] = ACTIONS(3073),
    [anon_sym_else] = ACTIONS(3073),
    [anon_sym_DOT_DOT] = ACTIONS(3075),
    [anon_sym_from] = ACTIONS(3073),
    [anon_sym_into] = ACTIONS(3073),
    [anon_sym_join] = ACTIONS(3073),
    [anon_sym_on] = ACTIONS(3073),
    [anon_sym_equals] = ACTIONS(3073),
    [anon_sym_let] = ACTIONS(3073),
    [anon_sym_orderby] = ACTIONS(3073),
    [anon_sym_ascending] = ACTIONS(3073),
    [anon_sym_descending] = ACTIONS(3073),
    [anon_sym_group] = ACTIONS(3073),
    [anon_sym_by] = ACTIONS(3073),
    [anon_sym_select] = ACTIONS(3073),
    [anon_sym_stackalloc] = ACTIONS(3073),
    [anon_sym_sizeof] = ACTIONS(3073),
    [anon_sym_typeof] = ACTIONS(3073),
    [anon_sym___makeref] = ACTIONS(3073),
    [anon_sym___reftype] = ACTIONS(3073),
    [anon_sym___refvalue] = ACTIONS(3073),
    [sym_null_literal] = ACTIONS(3073),
    [anon_sym_SQUOTE] = ACTIONS(3075),
    [sym_integer_literal] = ACTIONS(3073),
    [sym_real_literal] = ACTIONS(3075),
    [anon_sym_DQUOTE] = ACTIONS(3075),
    [sym_verbatim_string_literal] = ACTIONS(3075),
    [aux_sym_preproc_if_token1] = ACTIONS(3075),
    [aux_sym_preproc_if_token3] = ACTIONS(3075),
    [aux_sym_preproc_else_token1] = ACTIONS(3075),
    [aux_sym_preproc_elif_token1] = ACTIONS(3075),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3075),
    [sym_interpolation_verbatim_start] = ACTIONS(3075),
    [sym_interpolation_raw_start] = ACTIONS(3075),
    [sym_raw_string_start] = ACTIONS(3075),
  },
  [2228] = {
    [sym_preproc_region] = STATE(2228),
    [sym_preproc_endregion] = STATE(2228),
    [sym_preproc_line] = STATE(2228),
    [sym_preproc_pragma] = STATE(2228),
    [sym_preproc_nullable] = STATE(2228),
    [sym_preproc_error] = STATE(2228),
    [sym_preproc_warning] = STATE(2228),
    [sym_preproc_define] = STATE(2228),
    [sym_preproc_undef] = STATE(2228),
    [sym__identifier_token] = ACTIONS(3077),
    [anon_sym_extern] = ACTIONS(3077),
    [anon_sym_alias] = ACTIONS(3077),
    [anon_sym_SEMI] = ACTIONS(3079),
    [anon_sym_global] = ACTIONS(3077),
    [anon_sym_using] = ACTIONS(3077),
    [anon_sym_unsafe] = ACTIONS(3077),
    [anon_sym_static] = ACTIONS(3077),
    [anon_sym_LBRACK] = ACTIONS(3079),
    [anon_sym_LPAREN] = ACTIONS(3079),
    [anon_sym_return] = ACTIONS(3077),
    [anon_sym_namespace] = ACTIONS(3077),
    [anon_sym_class] = ACTIONS(3077),
    [anon_sym_ref] = ACTIONS(3077),
    [anon_sym_struct] = ACTIONS(3077),
    [anon_sym_enum] = ACTIONS(3077),
    [anon_sym_LBRACE] = ACTIONS(3079),
    [anon_sym_interface] = ACTIONS(3077),
    [anon_sym_delegate] = ACTIONS(3077),
    [anon_sym_record] = ACTIONS(3077),
    [anon_sym_abstract] = ACTIONS(3077),
    [anon_sym_async] = ACTIONS(3077),
    [anon_sym_const] = ACTIONS(3077),
    [anon_sym_file] = ACTIONS(3077),
    [anon_sym_fixed] = ACTIONS(3077),
    [anon_sym_internal] = ACTIONS(3077),
    [anon_sym_new] = ACTIONS(3077),
    [anon_sym_override] = ACTIONS(3077),
    [anon_sym_partial] = ACTIONS(3077),
    [anon_sym_private] = ACTIONS(3077),
    [anon_sym_protected] = ACTIONS(3077),
    [anon_sym_public] = ACTIONS(3077),
    [anon_sym_readonly] = ACTIONS(3077),
    [anon_sym_required] = ACTIONS(3077),
    [anon_sym_sealed] = ACTIONS(3077),
    [anon_sym_virtual] = ACTIONS(3077),
    [anon_sym_volatile] = ACTIONS(3077),
    [anon_sym_where] = ACTIONS(3077),
    [anon_sym_notnull] = ACTIONS(3077),
    [anon_sym_unmanaged] = ACTIONS(3077),
    [anon_sym_checked] = ACTIONS(3077),
    [anon_sym_BANG] = ACTIONS(3079),
    [anon_sym_TILDE] = ACTIONS(3079),
    [anon_sym_PLUS_PLUS] = ACTIONS(3079),
    [anon_sym_DASH_DASH] = ACTIONS(3079),
    [anon_sym_true] = ACTIONS(3077),
    [anon_sym_false] = ACTIONS(3077),
    [anon_sym_PLUS] = ACTIONS(3077),
    [anon_sym_DASH] = ACTIONS(3077),
    [anon_sym_STAR] = ACTIONS(3079),
    [anon_sym_CARET] = ACTIONS(3079),
    [anon_sym_AMP] = ACTIONS(3079),
    [anon_sym_this] = ACTIONS(3077),
    [anon_sym_scoped] = ACTIONS(3077),
    [anon_sym_base] = ACTIONS(3077),
    [anon_sym_var] = ACTIONS(3077),
    [sym_predefined_type] = ACTIONS(3077),
    [anon_sym_break] = ACTIONS(3077),
    [anon_sym_unchecked] = ACTIONS(3077),
    [anon_sym_continue] = ACTIONS(3077),
    [anon_sym_do] = ACTIONS(3077),
    [anon_sym_while] = ACTIONS(3077),
    [anon_sym_for] = ACTIONS(3077),
    [anon_sym_lock] = ACTIONS(3077),
    [anon_sym_yield] = ACTIONS(3077),
    [anon_sym_switch] = ACTIONS(3077),
    [anon_sym_default] = ACTIONS(3077),
    [anon_sym_throw] = ACTIONS(3077),
    [anon_sym_try] = ACTIONS(3077),
    [anon_sym_when] = ACTIONS(3077),
    [anon_sym_await] = ACTIONS(3077),
    [anon_sym_foreach] = ACTIONS(3077),
    [anon_sym_goto] = ACTIONS(3077),
    [anon_sym_if] = ACTIONS(3077),
    [anon_sym_else] = ACTIONS(3077),
    [anon_sym_DOT_DOT] = ACTIONS(3079),
    [anon_sym_from] = ACTIONS(3077),
    [anon_sym_into] = ACTIONS(3077),
    [anon_sym_join] = ACTIONS(3077),
    [anon_sym_on] = ACTIONS(3077),
    [anon_sym_equals] = ACTIONS(3077),
    [anon_sym_let] = ACTIONS(3077),
    [anon_sym_orderby] = ACTIONS(3077),
    [anon_sym_ascending] = ACTIONS(3077),
    [anon_sym_descending] = ACTIONS(3077),
    [anon_sym_group] = ACTIONS(3077),
    [anon_sym_by] = ACTIONS(3077),
    [anon_sym_select] = ACTIONS(3077),
    [anon_sym_stackalloc] = ACTIONS(3077),
    [anon_sym_sizeof] = ACTIONS(3077),
    [anon_sym_typeof] = ACTIONS(3077),
    [anon_sym___makeref] = ACTIONS(3077),
    [anon_sym___reftype] = ACTIONS(3077),
    [anon_sym___refvalue] = ACTIONS(3077),
    [sym_null_literal] = ACTIONS(3077),
    [anon_sym_SQUOTE] = ACTIONS(3079),
    [sym_integer_literal] = ACTIONS(3077),
    [sym_real_literal] = ACTIONS(3079),
    [anon_sym_DQUOTE] = ACTIONS(3079),
    [sym_verbatim_string_literal] = ACTIONS(3079),
    [aux_sym_preproc_if_token1] = ACTIONS(3079),
    [aux_sym_preproc_if_token3] = ACTIONS(3079),
    [aux_sym_preproc_else_token1] = ACTIONS(3079),
    [aux_sym_preproc_elif_token1] = ACTIONS(3079),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3079),
    [sym_interpolation_verbatim_start] = ACTIONS(3079),
    [sym_interpolation_raw_start] = ACTIONS(3079),
    [sym_raw_string_start] = ACTIONS(3079),
  },
  [2229] = {
    [sym_preproc_region] = STATE(2229),
    [sym_preproc_endregion] = STATE(2229),
    [sym_preproc_line] = STATE(2229),
    [sym_preproc_pragma] = STATE(2229),
    [sym_preproc_nullable] = STATE(2229),
    [sym_preproc_error] = STATE(2229),
    [sym_preproc_warning] = STATE(2229),
    [sym_preproc_define] = STATE(2229),
    [sym_preproc_undef] = STATE(2229),
    [sym__identifier_token] = ACTIONS(3081),
    [anon_sym_extern] = ACTIONS(3081),
    [anon_sym_alias] = ACTIONS(3081),
    [anon_sym_SEMI] = ACTIONS(3083),
    [anon_sym_global] = ACTIONS(3081),
    [anon_sym_using] = ACTIONS(3081),
    [anon_sym_unsafe] = ACTIONS(3081),
    [anon_sym_static] = ACTIONS(3081),
    [anon_sym_LBRACK] = ACTIONS(3083),
    [anon_sym_LPAREN] = ACTIONS(3083),
    [anon_sym_return] = ACTIONS(3081),
    [anon_sym_namespace] = ACTIONS(3081),
    [anon_sym_class] = ACTIONS(3081),
    [anon_sym_ref] = ACTIONS(3081),
    [anon_sym_struct] = ACTIONS(3081),
    [anon_sym_enum] = ACTIONS(3081),
    [anon_sym_LBRACE] = ACTIONS(3083),
    [anon_sym_interface] = ACTIONS(3081),
    [anon_sym_delegate] = ACTIONS(3081),
    [anon_sym_record] = ACTIONS(3081),
    [anon_sym_abstract] = ACTIONS(3081),
    [anon_sym_async] = ACTIONS(3081),
    [anon_sym_const] = ACTIONS(3081),
    [anon_sym_file] = ACTIONS(3081),
    [anon_sym_fixed] = ACTIONS(3081),
    [anon_sym_internal] = ACTIONS(3081),
    [anon_sym_new] = ACTIONS(3081),
    [anon_sym_override] = ACTIONS(3081),
    [anon_sym_partial] = ACTIONS(3081),
    [anon_sym_private] = ACTIONS(3081),
    [anon_sym_protected] = ACTIONS(3081),
    [anon_sym_public] = ACTIONS(3081),
    [anon_sym_readonly] = ACTIONS(3081),
    [anon_sym_required] = ACTIONS(3081),
    [anon_sym_sealed] = ACTIONS(3081),
    [anon_sym_virtual] = ACTIONS(3081),
    [anon_sym_volatile] = ACTIONS(3081),
    [anon_sym_where] = ACTIONS(3081),
    [anon_sym_notnull] = ACTIONS(3081),
    [anon_sym_unmanaged] = ACTIONS(3081),
    [anon_sym_checked] = ACTIONS(3081),
    [anon_sym_BANG] = ACTIONS(3083),
    [anon_sym_TILDE] = ACTIONS(3083),
    [anon_sym_PLUS_PLUS] = ACTIONS(3083),
    [anon_sym_DASH_DASH] = ACTIONS(3083),
    [anon_sym_true] = ACTIONS(3081),
    [anon_sym_false] = ACTIONS(3081),
    [anon_sym_PLUS] = ACTIONS(3081),
    [anon_sym_DASH] = ACTIONS(3081),
    [anon_sym_STAR] = ACTIONS(3083),
    [anon_sym_CARET] = ACTIONS(3083),
    [anon_sym_AMP] = ACTIONS(3083),
    [anon_sym_this] = ACTIONS(3081),
    [anon_sym_scoped] = ACTIONS(3081),
    [anon_sym_base] = ACTIONS(3081),
    [anon_sym_var] = ACTIONS(3081),
    [sym_predefined_type] = ACTIONS(3081),
    [anon_sym_break] = ACTIONS(3081),
    [anon_sym_unchecked] = ACTIONS(3081),
    [anon_sym_continue] = ACTIONS(3081),
    [anon_sym_do] = ACTIONS(3081),
    [anon_sym_while] = ACTIONS(3081),
    [anon_sym_for] = ACTIONS(3081),
    [anon_sym_lock] = ACTIONS(3081),
    [anon_sym_yield] = ACTIONS(3081),
    [anon_sym_switch] = ACTIONS(3081),
    [anon_sym_default] = ACTIONS(3081),
    [anon_sym_throw] = ACTIONS(3081),
    [anon_sym_try] = ACTIONS(3081),
    [anon_sym_when] = ACTIONS(3081),
    [anon_sym_await] = ACTIONS(3081),
    [anon_sym_foreach] = ACTIONS(3081),
    [anon_sym_goto] = ACTIONS(3081),
    [anon_sym_if] = ACTIONS(3081),
    [anon_sym_else] = ACTIONS(3081),
    [anon_sym_DOT_DOT] = ACTIONS(3083),
    [anon_sym_from] = ACTIONS(3081),
    [anon_sym_into] = ACTIONS(3081),
    [anon_sym_join] = ACTIONS(3081),
    [anon_sym_on] = ACTIONS(3081),
    [anon_sym_equals] = ACTIONS(3081),
    [anon_sym_let] = ACTIONS(3081),
    [anon_sym_orderby] = ACTIONS(3081),
    [anon_sym_ascending] = ACTIONS(3081),
    [anon_sym_descending] = ACTIONS(3081),
    [anon_sym_group] = ACTIONS(3081),
    [anon_sym_by] = ACTIONS(3081),
    [anon_sym_select] = ACTIONS(3081),
    [anon_sym_stackalloc] = ACTIONS(3081),
    [anon_sym_sizeof] = ACTIONS(3081),
    [anon_sym_typeof] = ACTIONS(3081),
    [anon_sym___makeref] = ACTIONS(3081),
    [anon_sym___reftype] = ACTIONS(3081),
    [anon_sym___refvalue] = ACTIONS(3081),
    [sym_null_literal] = ACTIONS(3081),
    [anon_sym_SQUOTE] = ACTIONS(3083),
    [sym_integer_literal] = ACTIONS(3081),
    [sym_real_literal] = ACTIONS(3083),
    [anon_sym_DQUOTE] = ACTIONS(3083),
    [sym_verbatim_string_literal] = ACTIONS(3083),
    [aux_sym_preproc_if_token1] = ACTIONS(3083),
    [aux_sym_preproc_if_token3] = ACTIONS(3083),
    [aux_sym_preproc_else_token1] = ACTIONS(3083),
    [aux_sym_preproc_elif_token1] = ACTIONS(3083),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3083),
    [sym_interpolation_verbatim_start] = ACTIONS(3083),
    [sym_interpolation_raw_start] = ACTIONS(3083),
    [sym_raw_string_start] = ACTIONS(3083),
  },
  [2230] = {
    [sym_preproc_region] = STATE(2230),
    [sym_preproc_endregion] = STATE(2230),
    [sym_preproc_line] = STATE(2230),
    [sym_preproc_pragma] = STATE(2230),
    [sym_preproc_nullable] = STATE(2230),
    [sym_preproc_error] = STATE(2230),
    [sym_preproc_warning] = STATE(2230),
    [sym_preproc_define] = STATE(2230),
    [sym_preproc_undef] = STATE(2230),
    [sym__identifier_token] = ACTIONS(3085),
    [anon_sym_extern] = ACTIONS(3085),
    [anon_sym_alias] = ACTIONS(3085),
    [anon_sym_SEMI] = ACTIONS(3087),
    [anon_sym_global] = ACTIONS(3085),
    [anon_sym_using] = ACTIONS(3085),
    [anon_sym_unsafe] = ACTIONS(3085),
    [anon_sym_static] = ACTIONS(3085),
    [anon_sym_LBRACK] = ACTIONS(3087),
    [anon_sym_LPAREN] = ACTIONS(3087),
    [anon_sym_return] = ACTIONS(3085),
    [anon_sym_namespace] = ACTIONS(3085),
    [anon_sym_class] = ACTIONS(3085),
    [anon_sym_ref] = ACTIONS(3085),
    [anon_sym_struct] = ACTIONS(3085),
    [anon_sym_enum] = ACTIONS(3085),
    [anon_sym_LBRACE] = ACTIONS(3087),
    [anon_sym_interface] = ACTIONS(3085),
    [anon_sym_delegate] = ACTIONS(3085),
    [anon_sym_record] = ACTIONS(3085),
    [anon_sym_abstract] = ACTIONS(3085),
    [anon_sym_async] = ACTIONS(3085),
    [anon_sym_const] = ACTIONS(3085),
    [anon_sym_file] = ACTIONS(3085),
    [anon_sym_fixed] = ACTIONS(3085),
    [anon_sym_internal] = ACTIONS(3085),
    [anon_sym_new] = ACTIONS(3085),
    [anon_sym_override] = ACTIONS(3085),
    [anon_sym_partial] = ACTIONS(3085),
    [anon_sym_private] = ACTIONS(3085),
    [anon_sym_protected] = ACTIONS(3085),
    [anon_sym_public] = ACTIONS(3085),
    [anon_sym_readonly] = ACTIONS(3085),
    [anon_sym_required] = ACTIONS(3085),
    [anon_sym_sealed] = ACTIONS(3085),
    [anon_sym_virtual] = ACTIONS(3085),
    [anon_sym_volatile] = ACTIONS(3085),
    [anon_sym_where] = ACTIONS(3085),
    [anon_sym_notnull] = ACTIONS(3085),
    [anon_sym_unmanaged] = ACTIONS(3085),
    [anon_sym_checked] = ACTIONS(3085),
    [anon_sym_BANG] = ACTIONS(3087),
    [anon_sym_TILDE] = ACTIONS(3087),
    [anon_sym_PLUS_PLUS] = ACTIONS(3087),
    [anon_sym_DASH_DASH] = ACTIONS(3087),
    [anon_sym_true] = ACTIONS(3085),
    [anon_sym_false] = ACTIONS(3085),
    [anon_sym_PLUS] = ACTIONS(3085),
    [anon_sym_DASH] = ACTIONS(3085),
    [anon_sym_STAR] = ACTIONS(3087),
    [anon_sym_CARET] = ACTIONS(3087),
    [anon_sym_AMP] = ACTIONS(3087),
    [anon_sym_this] = ACTIONS(3085),
    [anon_sym_scoped] = ACTIONS(3085),
    [anon_sym_base] = ACTIONS(3085),
    [anon_sym_var] = ACTIONS(3085),
    [sym_predefined_type] = ACTIONS(3085),
    [anon_sym_break] = ACTIONS(3085),
    [anon_sym_unchecked] = ACTIONS(3085),
    [anon_sym_continue] = ACTIONS(3085),
    [anon_sym_do] = ACTIONS(3085),
    [anon_sym_while] = ACTIONS(3085),
    [anon_sym_for] = ACTIONS(3085),
    [anon_sym_lock] = ACTIONS(3085),
    [anon_sym_yield] = ACTIONS(3085),
    [anon_sym_switch] = ACTIONS(3085),
    [anon_sym_default] = ACTIONS(3085),
    [anon_sym_throw] = ACTIONS(3085),
    [anon_sym_try] = ACTIONS(3085),
    [anon_sym_when] = ACTIONS(3085),
    [anon_sym_await] = ACTIONS(3085),
    [anon_sym_foreach] = ACTIONS(3085),
    [anon_sym_goto] = ACTIONS(3085),
    [anon_sym_if] = ACTIONS(3085),
    [anon_sym_else] = ACTIONS(3085),
    [anon_sym_DOT_DOT] = ACTIONS(3087),
    [anon_sym_from] = ACTIONS(3085),
    [anon_sym_into] = ACTIONS(3085),
    [anon_sym_join] = ACTIONS(3085),
    [anon_sym_on] = ACTIONS(3085),
    [anon_sym_equals] = ACTIONS(3085),
    [anon_sym_let] = ACTIONS(3085),
    [anon_sym_orderby] = ACTIONS(3085),
    [anon_sym_ascending] = ACTIONS(3085),
    [anon_sym_descending] = ACTIONS(3085),
    [anon_sym_group] = ACTIONS(3085),
    [anon_sym_by] = ACTIONS(3085),
    [anon_sym_select] = ACTIONS(3085),
    [anon_sym_stackalloc] = ACTIONS(3085),
    [anon_sym_sizeof] = ACTIONS(3085),
    [anon_sym_typeof] = ACTIONS(3085),
    [anon_sym___makeref] = ACTIONS(3085),
    [anon_sym___reftype] = ACTIONS(3085),
    [anon_sym___refvalue] = ACTIONS(3085),
    [sym_null_literal] = ACTIONS(3085),
    [anon_sym_SQUOTE] = ACTIONS(3087),
    [sym_integer_literal] = ACTIONS(3085),
    [sym_real_literal] = ACTIONS(3087),
    [anon_sym_DQUOTE] = ACTIONS(3087),
    [sym_verbatim_string_literal] = ACTIONS(3087),
    [aux_sym_preproc_if_token1] = ACTIONS(3087),
    [aux_sym_preproc_if_token3] = ACTIONS(3087),
    [aux_sym_preproc_else_token1] = ACTIONS(3087),
    [aux_sym_preproc_elif_token1] = ACTIONS(3087),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3087),
    [sym_interpolation_verbatim_start] = ACTIONS(3087),
    [sym_interpolation_raw_start] = ACTIONS(3087),
    [sym_raw_string_start] = ACTIONS(3087),
  },
  [2231] = {
    [sym_preproc_region] = STATE(2231),
    [sym_preproc_endregion] = STATE(2231),
    [sym_preproc_line] = STATE(2231),
    [sym_preproc_pragma] = STATE(2231),
    [sym_preproc_nullable] = STATE(2231),
    [sym_preproc_error] = STATE(2231),
    [sym_preproc_warning] = STATE(2231),
    [sym_preproc_define] = STATE(2231),
    [sym_preproc_undef] = STATE(2231),
    [sym__identifier_token] = ACTIONS(3089),
    [anon_sym_extern] = ACTIONS(3089),
    [anon_sym_alias] = ACTIONS(3089),
    [anon_sym_SEMI] = ACTIONS(3091),
    [anon_sym_global] = ACTIONS(3089),
    [anon_sym_using] = ACTIONS(3089),
    [anon_sym_unsafe] = ACTIONS(3089),
    [anon_sym_static] = ACTIONS(3089),
    [anon_sym_LBRACK] = ACTIONS(3091),
    [anon_sym_LPAREN] = ACTIONS(3091),
    [anon_sym_return] = ACTIONS(3089),
    [anon_sym_namespace] = ACTIONS(3089),
    [anon_sym_class] = ACTIONS(3089),
    [anon_sym_ref] = ACTIONS(3089),
    [anon_sym_struct] = ACTIONS(3089),
    [anon_sym_enum] = ACTIONS(3089),
    [anon_sym_LBRACE] = ACTIONS(3091),
    [anon_sym_interface] = ACTIONS(3089),
    [anon_sym_delegate] = ACTIONS(3089),
    [anon_sym_record] = ACTIONS(3089),
    [anon_sym_abstract] = ACTIONS(3089),
    [anon_sym_async] = ACTIONS(3089),
    [anon_sym_const] = ACTIONS(3089),
    [anon_sym_file] = ACTIONS(3089),
    [anon_sym_fixed] = ACTIONS(3089),
    [anon_sym_internal] = ACTIONS(3089),
    [anon_sym_new] = ACTIONS(3089),
    [anon_sym_override] = ACTIONS(3089),
    [anon_sym_partial] = ACTIONS(3089),
    [anon_sym_private] = ACTIONS(3089),
    [anon_sym_protected] = ACTIONS(3089),
    [anon_sym_public] = ACTIONS(3089),
    [anon_sym_readonly] = ACTIONS(3089),
    [anon_sym_required] = ACTIONS(3089),
    [anon_sym_sealed] = ACTIONS(3089),
    [anon_sym_virtual] = ACTIONS(3089),
    [anon_sym_volatile] = ACTIONS(3089),
    [anon_sym_where] = ACTIONS(3089),
    [anon_sym_notnull] = ACTIONS(3089),
    [anon_sym_unmanaged] = ACTIONS(3089),
    [anon_sym_checked] = ACTIONS(3089),
    [anon_sym_BANG] = ACTIONS(3091),
    [anon_sym_TILDE] = ACTIONS(3091),
    [anon_sym_PLUS_PLUS] = ACTIONS(3091),
    [anon_sym_DASH_DASH] = ACTIONS(3091),
    [anon_sym_true] = ACTIONS(3089),
    [anon_sym_false] = ACTIONS(3089),
    [anon_sym_PLUS] = ACTIONS(3089),
    [anon_sym_DASH] = ACTIONS(3089),
    [anon_sym_STAR] = ACTIONS(3091),
    [anon_sym_CARET] = ACTIONS(3091),
    [anon_sym_AMP] = ACTIONS(3091),
    [anon_sym_this] = ACTIONS(3089),
    [anon_sym_scoped] = ACTIONS(3089),
    [anon_sym_base] = ACTIONS(3089),
    [anon_sym_var] = ACTIONS(3089),
    [sym_predefined_type] = ACTIONS(3089),
    [anon_sym_break] = ACTIONS(3089),
    [anon_sym_unchecked] = ACTIONS(3089),
    [anon_sym_continue] = ACTIONS(3089),
    [anon_sym_do] = ACTIONS(3089),
    [anon_sym_while] = ACTIONS(3089),
    [anon_sym_for] = ACTIONS(3089),
    [anon_sym_lock] = ACTIONS(3089),
    [anon_sym_yield] = ACTIONS(3089),
    [anon_sym_switch] = ACTIONS(3089),
    [anon_sym_default] = ACTIONS(3089),
    [anon_sym_throw] = ACTIONS(3089),
    [anon_sym_try] = ACTIONS(3089),
    [anon_sym_when] = ACTIONS(3089),
    [anon_sym_await] = ACTIONS(3089),
    [anon_sym_foreach] = ACTIONS(3089),
    [anon_sym_goto] = ACTIONS(3089),
    [anon_sym_if] = ACTIONS(3089),
    [anon_sym_else] = ACTIONS(3089),
    [anon_sym_DOT_DOT] = ACTIONS(3091),
    [anon_sym_from] = ACTIONS(3089),
    [anon_sym_into] = ACTIONS(3089),
    [anon_sym_join] = ACTIONS(3089),
    [anon_sym_on] = ACTIONS(3089),
    [anon_sym_equals] = ACTIONS(3089),
    [anon_sym_let] = ACTIONS(3089),
    [anon_sym_orderby] = ACTIONS(3089),
    [anon_sym_ascending] = ACTIONS(3089),
    [anon_sym_descending] = ACTIONS(3089),
    [anon_sym_group] = ACTIONS(3089),
    [anon_sym_by] = ACTIONS(3089),
    [anon_sym_select] = ACTIONS(3089),
    [anon_sym_stackalloc] = ACTIONS(3089),
    [anon_sym_sizeof] = ACTIONS(3089),
    [anon_sym_typeof] = ACTIONS(3089),
    [anon_sym___makeref] = ACTIONS(3089),
    [anon_sym___reftype] = ACTIONS(3089),
    [anon_sym___refvalue] = ACTIONS(3089),
    [sym_null_literal] = ACTIONS(3089),
    [anon_sym_SQUOTE] = ACTIONS(3091),
    [sym_integer_literal] = ACTIONS(3089),
    [sym_real_literal] = ACTIONS(3091),
    [anon_sym_DQUOTE] = ACTIONS(3091),
    [sym_verbatim_string_literal] = ACTIONS(3091),
    [aux_sym_preproc_if_token1] = ACTIONS(3091),
    [aux_sym_preproc_if_token3] = ACTIONS(3091),
    [aux_sym_preproc_else_token1] = ACTIONS(3091),
    [aux_sym_preproc_elif_token1] = ACTIONS(3091),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3091),
    [sym_interpolation_verbatim_start] = ACTIONS(3091),
    [sym_interpolation_raw_start] = ACTIONS(3091),
    [sym_raw_string_start] = ACTIONS(3091),
  },
  [2232] = {
    [sym_preproc_region] = STATE(2232),
    [sym_preproc_endregion] = STATE(2232),
    [sym_preproc_line] = STATE(2232),
    [sym_preproc_pragma] = STATE(2232),
    [sym_preproc_nullable] = STATE(2232),
    [sym_preproc_error] = STATE(2232),
    [sym_preproc_warning] = STATE(2232),
    [sym_preproc_define] = STATE(2232),
    [sym_preproc_undef] = STATE(2232),
    [sym__identifier_token] = ACTIONS(3093),
    [anon_sym_extern] = ACTIONS(3093),
    [anon_sym_alias] = ACTIONS(3093),
    [anon_sym_SEMI] = ACTIONS(3095),
    [anon_sym_global] = ACTIONS(3093),
    [anon_sym_using] = ACTIONS(3093),
    [anon_sym_unsafe] = ACTIONS(3093),
    [anon_sym_static] = ACTIONS(3093),
    [anon_sym_LBRACK] = ACTIONS(3095),
    [anon_sym_LPAREN] = ACTIONS(3095),
    [anon_sym_return] = ACTIONS(3093),
    [anon_sym_namespace] = ACTIONS(3093),
    [anon_sym_class] = ACTIONS(3093),
    [anon_sym_ref] = ACTIONS(3093),
    [anon_sym_struct] = ACTIONS(3093),
    [anon_sym_enum] = ACTIONS(3093),
    [anon_sym_LBRACE] = ACTIONS(3095),
    [anon_sym_interface] = ACTIONS(3093),
    [anon_sym_delegate] = ACTIONS(3093),
    [anon_sym_record] = ACTIONS(3093),
    [anon_sym_abstract] = ACTIONS(3093),
    [anon_sym_async] = ACTIONS(3093),
    [anon_sym_const] = ACTIONS(3093),
    [anon_sym_file] = ACTIONS(3093),
    [anon_sym_fixed] = ACTIONS(3093),
    [anon_sym_internal] = ACTIONS(3093),
    [anon_sym_new] = ACTIONS(3093),
    [anon_sym_override] = ACTIONS(3093),
    [anon_sym_partial] = ACTIONS(3093),
    [anon_sym_private] = ACTIONS(3093),
    [anon_sym_protected] = ACTIONS(3093),
    [anon_sym_public] = ACTIONS(3093),
    [anon_sym_readonly] = ACTIONS(3093),
    [anon_sym_required] = ACTIONS(3093),
    [anon_sym_sealed] = ACTIONS(3093),
    [anon_sym_virtual] = ACTIONS(3093),
    [anon_sym_volatile] = ACTIONS(3093),
    [anon_sym_where] = ACTIONS(3093),
    [anon_sym_notnull] = ACTIONS(3093),
    [anon_sym_unmanaged] = ACTIONS(3093),
    [anon_sym_checked] = ACTIONS(3093),
    [anon_sym_BANG] = ACTIONS(3095),
    [anon_sym_TILDE] = ACTIONS(3095),
    [anon_sym_PLUS_PLUS] = ACTIONS(3095),
    [anon_sym_DASH_DASH] = ACTIONS(3095),
    [anon_sym_true] = ACTIONS(3093),
    [anon_sym_false] = ACTIONS(3093),
    [anon_sym_PLUS] = ACTIONS(3093),
    [anon_sym_DASH] = ACTIONS(3093),
    [anon_sym_STAR] = ACTIONS(3095),
    [anon_sym_CARET] = ACTIONS(3095),
    [anon_sym_AMP] = ACTIONS(3095),
    [anon_sym_this] = ACTIONS(3093),
    [anon_sym_scoped] = ACTIONS(3093),
    [anon_sym_base] = ACTIONS(3093),
    [anon_sym_var] = ACTIONS(3093),
    [sym_predefined_type] = ACTIONS(3093),
    [anon_sym_break] = ACTIONS(3093),
    [anon_sym_unchecked] = ACTIONS(3093),
    [anon_sym_continue] = ACTIONS(3093),
    [anon_sym_do] = ACTIONS(3093),
    [anon_sym_while] = ACTIONS(3093),
    [anon_sym_for] = ACTIONS(3093),
    [anon_sym_lock] = ACTIONS(3093),
    [anon_sym_yield] = ACTIONS(3093),
    [anon_sym_switch] = ACTIONS(3093),
    [anon_sym_default] = ACTIONS(3093),
    [anon_sym_throw] = ACTIONS(3093),
    [anon_sym_try] = ACTIONS(3093),
    [anon_sym_when] = ACTIONS(3093),
    [anon_sym_await] = ACTIONS(3093),
    [anon_sym_foreach] = ACTIONS(3093),
    [anon_sym_goto] = ACTIONS(3093),
    [anon_sym_if] = ACTIONS(3093),
    [anon_sym_else] = ACTIONS(3093),
    [anon_sym_DOT_DOT] = ACTIONS(3095),
    [anon_sym_from] = ACTIONS(3093),
    [anon_sym_into] = ACTIONS(3093),
    [anon_sym_join] = ACTIONS(3093),
    [anon_sym_on] = ACTIONS(3093),
    [anon_sym_equals] = ACTIONS(3093),
    [anon_sym_let] = ACTIONS(3093),
    [anon_sym_orderby] = ACTIONS(3093),
    [anon_sym_ascending] = ACTIONS(3093),
    [anon_sym_descending] = ACTIONS(3093),
    [anon_sym_group] = ACTIONS(3093),
    [anon_sym_by] = ACTIONS(3093),
    [anon_sym_select] = ACTIONS(3093),
    [anon_sym_stackalloc] = ACTIONS(3093),
    [anon_sym_sizeof] = ACTIONS(3093),
    [anon_sym_typeof] = ACTIONS(3093),
    [anon_sym___makeref] = ACTIONS(3093),
    [anon_sym___reftype] = ACTIONS(3093),
    [anon_sym___refvalue] = ACTIONS(3093),
    [sym_null_literal] = ACTIONS(3093),
    [anon_sym_SQUOTE] = ACTIONS(3095),
    [sym_integer_literal] = ACTIONS(3093),
    [sym_real_literal] = ACTIONS(3095),
    [anon_sym_DQUOTE] = ACTIONS(3095),
    [sym_verbatim_string_literal] = ACTIONS(3095),
    [aux_sym_preproc_if_token1] = ACTIONS(3095),
    [aux_sym_preproc_if_token3] = ACTIONS(3095),
    [aux_sym_preproc_else_token1] = ACTIONS(3095),
    [aux_sym_preproc_elif_token1] = ACTIONS(3095),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3095),
    [sym_interpolation_verbatim_start] = ACTIONS(3095),
    [sym_interpolation_raw_start] = ACTIONS(3095),
    [sym_raw_string_start] = ACTIONS(3095),
  },
  [2233] = {
    [sym_preproc_region] = STATE(2233),
    [sym_preproc_endregion] = STATE(2233),
    [sym_preproc_line] = STATE(2233),
    [sym_preproc_pragma] = STATE(2233),
    [sym_preproc_nullable] = STATE(2233),
    [sym_preproc_error] = STATE(2233),
    [sym_preproc_warning] = STATE(2233),
    [sym_preproc_define] = STATE(2233),
    [sym_preproc_undef] = STATE(2233),
    [sym__identifier_token] = ACTIONS(3097),
    [anon_sym_extern] = ACTIONS(3097),
    [anon_sym_alias] = ACTIONS(3097),
    [anon_sym_SEMI] = ACTIONS(3099),
    [anon_sym_global] = ACTIONS(3097),
    [anon_sym_using] = ACTIONS(3097),
    [anon_sym_unsafe] = ACTIONS(3097),
    [anon_sym_static] = ACTIONS(3097),
    [anon_sym_LBRACK] = ACTIONS(3099),
    [anon_sym_LPAREN] = ACTIONS(3099),
    [anon_sym_return] = ACTIONS(3097),
    [anon_sym_namespace] = ACTIONS(3097),
    [anon_sym_class] = ACTIONS(3097),
    [anon_sym_ref] = ACTIONS(3097),
    [anon_sym_struct] = ACTIONS(3097),
    [anon_sym_enum] = ACTIONS(3097),
    [anon_sym_LBRACE] = ACTIONS(3099),
    [anon_sym_interface] = ACTIONS(3097),
    [anon_sym_delegate] = ACTIONS(3097),
    [anon_sym_record] = ACTIONS(3097),
    [anon_sym_abstract] = ACTIONS(3097),
    [anon_sym_async] = ACTIONS(3097),
    [anon_sym_const] = ACTIONS(3097),
    [anon_sym_file] = ACTIONS(3097),
    [anon_sym_fixed] = ACTIONS(3097),
    [anon_sym_internal] = ACTIONS(3097),
    [anon_sym_new] = ACTIONS(3097),
    [anon_sym_override] = ACTIONS(3097),
    [anon_sym_partial] = ACTIONS(3097),
    [anon_sym_private] = ACTIONS(3097),
    [anon_sym_protected] = ACTIONS(3097),
    [anon_sym_public] = ACTIONS(3097),
    [anon_sym_readonly] = ACTIONS(3097),
    [anon_sym_required] = ACTIONS(3097),
    [anon_sym_sealed] = ACTIONS(3097),
    [anon_sym_virtual] = ACTIONS(3097),
    [anon_sym_volatile] = ACTIONS(3097),
    [anon_sym_where] = ACTIONS(3097),
    [anon_sym_notnull] = ACTIONS(3097),
    [anon_sym_unmanaged] = ACTIONS(3097),
    [anon_sym_checked] = ACTIONS(3097),
    [anon_sym_BANG] = ACTIONS(3099),
    [anon_sym_TILDE] = ACTIONS(3099),
    [anon_sym_PLUS_PLUS] = ACTIONS(3099),
    [anon_sym_DASH_DASH] = ACTIONS(3099),
    [anon_sym_true] = ACTIONS(3097),
    [anon_sym_false] = ACTIONS(3097),
    [anon_sym_PLUS] = ACTIONS(3097),
    [anon_sym_DASH] = ACTIONS(3097),
    [anon_sym_STAR] = ACTIONS(3099),
    [anon_sym_CARET] = ACTIONS(3099),
    [anon_sym_AMP] = ACTIONS(3099),
    [anon_sym_this] = ACTIONS(3097),
    [anon_sym_scoped] = ACTIONS(3097),
    [anon_sym_base] = ACTIONS(3097),
    [anon_sym_var] = ACTIONS(3097),
    [sym_predefined_type] = ACTIONS(3097),
    [anon_sym_break] = ACTIONS(3097),
    [anon_sym_unchecked] = ACTIONS(3097),
    [anon_sym_continue] = ACTIONS(3097),
    [anon_sym_do] = ACTIONS(3097),
    [anon_sym_while] = ACTIONS(3097),
    [anon_sym_for] = ACTIONS(3097),
    [anon_sym_lock] = ACTIONS(3097),
    [anon_sym_yield] = ACTIONS(3097),
    [anon_sym_switch] = ACTIONS(3097),
    [anon_sym_default] = ACTIONS(3097),
    [anon_sym_throw] = ACTIONS(3097),
    [anon_sym_try] = ACTIONS(3097),
    [anon_sym_when] = ACTIONS(3097),
    [anon_sym_await] = ACTIONS(3097),
    [anon_sym_foreach] = ACTIONS(3097),
    [anon_sym_goto] = ACTIONS(3097),
    [anon_sym_if] = ACTIONS(3097),
    [anon_sym_else] = ACTIONS(3097),
    [anon_sym_DOT_DOT] = ACTIONS(3099),
    [anon_sym_from] = ACTIONS(3097),
    [anon_sym_into] = ACTIONS(3097),
    [anon_sym_join] = ACTIONS(3097),
    [anon_sym_on] = ACTIONS(3097),
    [anon_sym_equals] = ACTIONS(3097),
    [anon_sym_let] = ACTIONS(3097),
    [anon_sym_orderby] = ACTIONS(3097),
    [anon_sym_ascending] = ACTIONS(3097),
    [anon_sym_descending] = ACTIONS(3097),
    [anon_sym_group] = ACTIONS(3097),
    [anon_sym_by] = ACTIONS(3097),
    [anon_sym_select] = ACTIONS(3097),
    [anon_sym_stackalloc] = ACTIONS(3097),
    [anon_sym_sizeof] = ACTIONS(3097),
    [anon_sym_typeof] = ACTIONS(3097),
    [anon_sym___makeref] = ACTIONS(3097),
    [anon_sym___reftype] = ACTIONS(3097),
    [anon_sym___refvalue] = ACTIONS(3097),
    [sym_null_literal] = ACTIONS(3097),
    [anon_sym_SQUOTE] = ACTIONS(3099),
    [sym_integer_literal] = ACTIONS(3097),
    [sym_real_literal] = ACTIONS(3099),
    [anon_sym_DQUOTE] = ACTIONS(3099),
    [sym_verbatim_string_literal] = ACTIONS(3099),
    [aux_sym_preproc_if_token1] = ACTIONS(3099),
    [aux_sym_preproc_if_token3] = ACTIONS(3099),
    [aux_sym_preproc_else_token1] = ACTIONS(3099),
    [aux_sym_preproc_elif_token1] = ACTIONS(3099),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3099),
    [sym_interpolation_verbatim_start] = ACTIONS(3099),
    [sym_interpolation_raw_start] = ACTIONS(3099),
    [sym_raw_string_start] = ACTIONS(3099),
  },
  [2234] = {
    [sym_preproc_region] = STATE(2234),
    [sym_preproc_endregion] = STATE(2234),
    [sym_preproc_line] = STATE(2234),
    [sym_preproc_pragma] = STATE(2234),
    [sym_preproc_nullable] = STATE(2234),
    [sym_preproc_error] = STATE(2234),
    [sym_preproc_warning] = STATE(2234),
    [sym_preproc_define] = STATE(2234),
    [sym_preproc_undef] = STATE(2234),
    [sym__identifier_token] = ACTIONS(3101),
    [anon_sym_extern] = ACTIONS(3101),
    [anon_sym_alias] = ACTIONS(3101),
    [anon_sym_SEMI] = ACTIONS(3103),
    [anon_sym_global] = ACTIONS(3101),
    [anon_sym_using] = ACTIONS(3101),
    [anon_sym_unsafe] = ACTIONS(3101),
    [anon_sym_static] = ACTIONS(3101),
    [anon_sym_LBRACK] = ACTIONS(3103),
    [anon_sym_LPAREN] = ACTIONS(3103),
    [anon_sym_return] = ACTIONS(3101),
    [anon_sym_namespace] = ACTIONS(3101),
    [anon_sym_class] = ACTIONS(3101),
    [anon_sym_ref] = ACTIONS(3101),
    [anon_sym_struct] = ACTIONS(3101),
    [anon_sym_enum] = ACTIONS(3101),
    [anon_sym_LBRACE] = ACTIONS(3103),
    [anon_sym_interface] = ACTIONS(3101),
    [anon_sym_delegate] = ACTIONS(3101),
    [anon_sym_record] = ACTIONS(3101),
    [anon_sym_abstract] = ACTIONS(3101),
    [anon_sym_async] = ACTIONS(3101),
    [anon_sym_const] = ACTIONS(3101),
    [anon_sym_file] = ACTIONS(3101),
    [anon_sym_fixed] = ACTIONS(3101),
    [anon_sym_internal] = ACTIONS(3101),
    [anon_sym_new] = ACTIONS(3101),
    [anon_sym_override] = ACTIONS(3101),
    [anon_sym_partial] = ACTIONS(3101),
    [anon_sym_private] = ACTIONS(3101),
    [anon_sym_protected] = ACTIONS(3101),
    [anon_sym_public] = ACTIONS(3101),
    [anon_sym_readonly] = ACTIONS(3101),
    [anon_sym_required] = ACTIONS(3101),
    [anon_sym_sealed] = ACTIONS(3101),
    [anon_sym_virtual] = ACTIONS(3101),
    [anon_sym_volatile] = ACTIONS(3101),
    [anon_sym_where] = ACTIONS(3101),
    [anon_sym_notnull] = ACTIONS(3101),
    [anon_sym_unmanaged] = ACTIONS(3101),
    [anon_sym_checked] = ACTIONS(3101),
    [anon_sym_BANG] = ACTIONS(3103),
    [anon_sym_TILDE] = ACTIONS(3103),
    [anon_sym_PLUS_PLUS] = ACTIONS(3103),
    [anon_sym_DASH_DASH] = ACTIONS(3103),
    [anon_sym_true] = ACTIONS(3101),
    [anon_sym_false] = ACTIONS(3101),
    [anon_sym_PLUS] = ACTIONS(3101),
    [anon_sym_DASH] = ACTIONS(3101),
    [anon_sym_STAR] = ACTIONS(3103),
    [anon_sym_CARET] = ACTIONS(3103),
    [anon_sym_AMP] = ACTIONS(3103),
    [anon_sym_this] = ACTIONS(3101),
    [anon_sym_scoped] = ACTIONS(3101),
    [anon_sym_base] = ACTIONS(3101),
    [anon_sym_var] = ACTIONS(3101),
    [sym_predefined_type] = ACTIONS(3101),
    [anon_sym_break] = ACTIONS(3101),
    [anon_sym_unchecked] = ACTIONS(3101),
    [anon_sym_continue] = ACTIONS(3101),
    [anon_sym_do] = ACTIONS(3101),
    [anon_sym_while] = ACTIONS(3101),
    [anon_sym_for] = ACTIONS(3101),
    [anon_sym_lock] = ACTIONS(3101),
    [anon_sym_yield] = ACTIONS(3101),
    [anon_sym_switch] = ACTIONS(3101),
    [anon_sym_default] = ACTIONS(3101),
    [anon_sym_throw] = ACTIONS(3101),
    [anon_sym_try] = ACTIONS(3101),
    [anon_sym_when] = ACTIONS(3101),
    [anon_sym_await] = ACTIONS(3101),
    [anon_sym_foreach] = ACTIONS(3101),
    [anon_sym_goto] = ACTIONS(3101),
    [anon_sym_if] = ACTIONS(3101),
    [anon_sym_else] = ACTIONS(3101),
    [anon_sym_DOT_DOT] = ACTIONS(3103),
    [anon_sym_from] = ACTIONS(3101),
    [anon_sym_into] = ACTIONS(3101),
    [anon_sym_join] = ACTIONS(3101),
    [anon_sym_on] = ACTIONS(3101),
    [anon_sym_equals] = ACTIONS(3101),
    [anon_sym_let] = ACTIONS(3101),
    [anon_sym_orderby] = ACTIONS(3101),
    [anon_sym_ascending] = ACTIONS(3101),
    [anon_sym_descending] = ACTIONS(3101),
    [anon_sym_group] = ACTIONS(3101),
    [anon_sym_by] = ACTIONS(3101),
    [anon_sym_select] = ACTIONS(3101),
    [anon_sym_stackalloc] = ACTIONS(3101),
    [anon_sym_sizeof] = ACTIONS(3101),
    [anon_sym_typeof] = ACTIONS(3101),
    [anon_sym___makeref] = ACTIONS(3101),
    [anon_sym___reftype] = ACTIONS(3101),
    [anon_sym___refvalue] = ACTIONS(3101),
    [sym_null_literal] = ACTIONS(3101),
    [anon_sym_SQUOTE] = ACTIONS(3103),
    [sym_integer_literal] = ACTIONS(3101),
    [sym_real_literal] = ACTIONS(3103),
    [anon_sym_DQUOTE] = ACTIONS(3103),
    [sym_verbatim_string_literal] = ACTIONS(3103),
    [aux_sym_preproc_if_token1] = ACTIONS(3103),
    [aux_sym_preproc_if_token3] = ACTIONS(3103),
    [aux_sym_preproc_else_token1] = ACTIONS(3103),
    [aux_sym_preproc_elif_token1] = ACTIONS(3103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3103),
    [sym_interpolation_verbatim_start] = ACTIONS(3103),
    [sym_interpolation_raw_start] = ACTIONS(3103),
    [sym_raw_string_start] = ACTIONS(3103),
  },
  [2235] = {
    [sym_preproc_region] = STATE(2235),
    [sym_preproc_endregion] = STATE(2235),
    [sym_preproc_line] = STATE(2235),
    [sym_preproc_pragma] = STATE(2235),
    [sym_preproc_nullable] = STATE(2235),
    [sym_preproc_error] = STATE(2235),
    [sym_preproc_warning] = STATE(2235),
    [sym_preproc_define] = STATE(2235),
    [sym_preproc_undef] = STATE(2235),
    [sym__identifier_token] = ACTIONS(3105),
    [anon_sym_extern] = ACTIONS(3105),
    [anon_sym_alias] = ACTIONS(3105),
    [anon_sym_SEMI] = ACTIONS(3107),
    [anon_sym_global] = ACTIONS(3105),
    [anon_sym_using] = ACTIONS(3105),
    [anon_sym_unsafe] = ACTIONS(3105),
    [anon_sym_static] = ACTIONS(3105),
    [anon_sym_LBRACK] = ACTIONS(3107),
    [anon_sym_LPAREN] = ACTIONS(3107),
    [anon_sym_return] = ACTIONS(3105),
    [anon_sym_namespace] = ACTIONS(3105),
    [anon_sym_class] = ACTIONS(3105),
    [anon_sym_ref] = ACTIONS(3105),
    [anon_sym_struct] = ACTIONS(3105),
    [anon_sym_enum] = ACTIONS(3105),
    [anon_sym_LBRACE] = ACTIONS(3107),
    [anon_sym_interface] = ACTIONS(3105),
    [anon_sym_delegate] = ACTIONS(3105),
    [anon_sym_record] = ACTIONS(3105),
    [anon_sym_abstract] = ACTIONS(3105),
    [anon_sym_async] = ACTIONS(3105),
    [anon_sym_const] = ACTIONS(3105),
    [anon_sym_file] = ACTIONS(3105),
    [anon_sym_fixed] = ACTIONS(3105),
    [anon_sym_internal] = ACTIONS(3105),
    [anon_sym_new] = ACTIONS(3105),
    [anon_sym_override] = ACTIONS(3105),
    [anon_sym_partial] = ACTIONS(3105),
    [anon_sym_private] = ACTIONS(3105),
    [anon_sym_protected] = ACTIONS(3105),
    [anon_sym_public] = ACTIONS(3105),
    [anon_sym_readonly] = ACTIONS(3105),
    [anon_sym_required] = ACTIONS(3105),
    [anon_sym_sealed] = ACTIONS(3105),
    [anon_sym_virtual] = ACTIONS(3105),
    [anon_sym_volatile] = ACTIONS(3105),
    [anon_sym_where] = ACTIONS(3105),
    [anon_sym_notnull] = ACTIONS(3105),
    [anon_sym_unmanaged] = ACTIONS(3105),
    [anon_sym_checked] = ACTIONS(3105),
    [anon_sym_BANG] = ACTIONS(3107),
    [anon_sym_TILDE] = ACTIONS(3107),
    [anon_sym_PLUS_PLUS] = ACTIONS(3107),
    [anon_sym_DASH_DASH] = ACTIONS(3107),
    [anon_sym_true] = ACTIONS(3105),
    [anon_sym_false] = ACTIONS(3105),
    [anon_sym_PLUS] = ACTIONS(3105),
    [anon_sym_DASH] = ACTIONS(3105),
    [anon_sym_STAR] = ACTIONS(3107),
    [anon_sym_CARET] = ACTIONS(3107),
    [anon_sym_AMP] = ACTIONS(3107),
    [anon_sym_this] = ACTIONS(3105),
    [anon_sym_scoped] = ACTIONS(3105),
    [anon_sym_base] = ACTIONS(3105),
    [anon_sym_var] = ACTIONS(3105),
    [sym_predefined_type] = ACTIONS(3105),
    [anon_sym_break] = ACTIONS(3105),
    [anon_sym_unchecked] = ACTIONS(3105),
    [anon_sym_continue] = ACTIONS(3105),
    [anon_sym_do] = ACTIONS(3105),
    [anon_sym_while] = ACTIONS(3105),
    [anon_sym_for] = ACTIONS(3105),
    [anon_sym_lock] = ACTIONS(3105),
    [anon_sym_yield] = ACTIONS(3105),
    [anon_sym_switch] = ACTIONS(3105),
    [anon_sym_default] = ACTIONS(3105),
    [anon_sym_throw] = ACTIONS(3105),
    [anon_sym_try] = ACTIONS(3105),
    [anon_sym_when] = ACTIONS(3105),
    [anon_sym_await] = ACTIONS(3105),
    [anon_sym_foreach] = ACTIONS(3105),
    [anon_sym_goto] = ACTIONS(3105),
    [anon_sym_if] = ACTIONS(3105),
    [anon_sym_else] = ACTIONS(3105),
    [anon_sym_DOT_DOT] = ACTIONS(3107),
    [anon_sym_from] = ACTIONS(3105),
    [anon_sym_into] = ACTIONS(3105),
    [anon_sym_join] = ACTIONS(3105),
    [anon_sym_on] = ACTIONS(3105),
    [anon_sym_equals] = ACTIONS(3105),
    [anon_sym_let] = ACTIONS(3105),
    [anon_sym_orderby] = ACTIONS(3105),
    [anon_sym_ascending] = ACTIONS(3105),
    [anon_sym_descending] = ACTIONS(3105),
    [anon_sym_group] = ACTIONS(3105),
    [anon_sym_by] = ACTIONS(3105),
    [anon_sym_select] = ACTIONS(3105),
    [anon_sym_stackalloc] = ACTIONS(3105),
    [anon_sym_sizeof] = ACTIONS(3105),
    [anon_sym_typeof] = ACTIONS(3105),
    [anon_sym___makeref] = ACTIONS(3105),
    [anon_sym___reftype] = ACTIONS(3105),
    [anon_sym___refvalue] = ACTIONS(3105),
    [sym_null_literal] = ACTIONS(3105),
    [anon_sym_SQUOTE] = ACTIONS(3107),
    [sym_integer_literal] = ACTIONS(3105),
    [sym_real_literal] = ACTIONS(3107),
    [anon_sym_DQUOTE] = ACTIONS(3107),
    [sym_verbatim_string_literal] = ACTIONS(3107),
    [aux_sym_preproc_if_token1] = ACTIONS(3107),
    [aux_sym_preproc_if_token3] = ACTIONS(3107),
    [aux_sym_preproc_else_token1] = ACTIONS(3107),
    [aux_sym_preproc_elif_token1] = ACTIONS(3107),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3107),
    [sym_interpolation_verbatim_start] = ACTIONS(3107),
    [sym_interpolation_raw_start] = ACTIONS(3107),
    [sym_raw_string_start] = ACTIONS(3107),
  },
  [2236] = {
    [sym_preproc_region] = STATE(2236),
    [sym_preproc_endregion] = STATE(2236),
    [sym_preproc_line] = STATE(2236),
    [sym_preproc_pragma] = STATE(2236),
    [sym_preproc_nullable] = STATE(2236),
    [sym_preproc_error] = STATE(2236),
    [sym_preproc_warning] = STATE(2236),
    [sym_preproc_define] = STATE(2236),
    [sym_preproc_undef] = STATE(2236),
    [sym__identifier_token] = ACTIONS(3109),
    [anon_sym_extern] = ACTIONS(3109),
    [anon_sym_alias] = ACTIONS(3109),
    [anon_sym_SEMI] = ACTIONS(3111),
    [anon_sym_global] = ACTIONS(3109),
    [anon_sym_using] = ACTIONS(3109),
    [anon_sym_unsafe] = ACTIONS(3109),
    [anon_sym_static] = ACTIONS(3109),
    [anon_sym_LBRACK] = ACTIONS(3111),
    [anon_sym_LPAREN] = ACTIONS(3111),
    [anon_sym_return] = ACTIONS(3109),
    [anon_sym_namespace] = ACTIONS(3109),
    [anon_sym_class] = ACTIONS(3109),
    [anon_sym_ref] = ACTIONS(3109),
    [anon_sym_struct] = ACTIONS(3109),
    [anon_sym_enum] = ACTIONS(3109),
    [anon_sym_LBRACE] = ACTIONS(3111),
    [anon_sym_interface] = ACTIONS(3109),
    [anon_sym_delegate] = ACTIONS(3109),
    [anon_sym_record] = ACTIONS(3109),
    [anon_sym_abstract] = ACTIONS(3109),
    [anon_sym_async] = ACTIONS(3109),
    [anon_sym_const] = ACTIONS(3109),
    [anon_sym_file] = ACTIONS(3109),
    [anon_sym_fixed] = ACTIONS(3109),
    [anon_sym_internal] = ACTIONS(3109),
    [anon_sym_new] = ACTIONS(3109),
    [anon_sym_override] = ACTIONS(3109),
    [anon_sym_partial] = ACTIONS(3109),
    [anon_sym_private] = ACTIONS(3109),
    [anon_sym_protected] = ACTIONS(3109),
    [anon_sym_public] = ACTIONS(3109),
    [anon_sym_readonly] = ACTIONS(3109),
    [anon_sym_required] = ACTIONS(3109),
    [anon_sym_sealed] = ACTIONS(3109),
    [anon_sym_virtual] = ACTIONS(3109),
    [anon_sym_volatile] = ACTIONS(3109),
    [anon_sym_where] = ACTIONS(3109),
    [anon_sym_notnull] = ACTIONS(3109),
    [anon_sym_unmanaged] = ACTIONS(3109),
    [anon_sym_checked] = ACTIONS(3109),
    [anon_sym_BANG] = ACTIONS(3111),
    [anon_sym_TILDE] = ACTIONS(3111),
    [anon_sym_PLUS_PLUS] = ACTIONS(3111),
    [anon_sym_DASH_DASH] = ACTIONS(3111),
    [anon_sym_true] = ACTIONS(3109),
    [anon_sym_false] = ACTIONS(3109),
    [anon_sym_PLUS] = ACTIONS(3109),
    [anon_sym_DASH] = ACTIONS(3109),
    [anon_sym_STAR] = ACTIONS(3111),
    [anon_sym_CARET] = ACTIONS(3111),
    [anon_sym_AMP] = ACTIONS(3111),
    [anon_sym_this] = ACTIONS(3109),
    [anon_sym_scoped] = ACTIONS(3109),
    [anon_sym_base] = ACTIONS(3109),
    [anon_sym_var] = ACTIONS(3109),
    [sym_predefined_type] = ACTIONS(3109),
    [anon_sym_break] = ACTIONS(3109),
    [anon_sym_unchecked] = ACTIONS(3109),
    [anon_sym_continue] = ACTIONS(3109),
    [anon_sym_do] = ACTIONS(3109),
    [anon_sym_while] = ACTIONS(3109),
    [anon_sym_for] = ACTIONS(3109),
    [anon_sym_lock] = ACTIONS(3109),
    [anon_sym_yield] = ACTIONS(3109),
    [anon_sym_switch] = ACTIONS(3109),
    [anon_sym_default] = ACTIONS(3109),
    [anon_sym_throw] = ACTIONS(3109),
    [anon_sym_try] = ACTIONS(3109),
    [anon_sym_when] = ACTIONS(3109),
    [anon_sym_await] = ACTIONS(3109),
    [anon_sym_foreach] = ACTIONS(3109),
    [anon_sym_goto] = ACTIONS(3109),
    [anon_sym_if] = ACTIONS(3109),
    [anon_sym_else] = ACTIONS(3109),
    [anon_sym_DOT_DOT] = ACTIONS(3111),
    [anon_sym_from] = ACTIONS(3109),
    [anon_sym_into] = ACTIONS(3109),
    [anon_sym_join] = ACTIONS(3109),
    [anon_sym_on] = ACTIONS(3109),
    [anon_sym_equals] = ACTIONS(3109),
    [anon_sym_let] = ACTIONS(3109),
    [anon_sym_orderby] = ACTIONS(3109),
    [anon_sym_ascending] = ACTIONS(3109),
    [anon_sym_descending] = ACTIONS(3109),
    [anon_sym_group] = ACTIONS(3109),
    [anon_sym_by] = ACTIONS(3109),
    [anon_sym_select] = ACTIONS(3109),
    [anon_sym_stackalloc] = ACTIONS(3109),
    [anon_sym_sizeof] = ACTIONS(3109),
    [anon_sym_typeof] = ACTIONS(3109),
    [anon_sym___makeref] = ACTIONS(3109),
    [anon_sym___reftype] = ACTIONS(3109),
    [anon_sym___refvalue] = ACTIONS(3109),
    [sym_null_literal] = ACTIONS(3109),
    [anon_sym_SQUOTE] = ACTIONS(3111),
    [sym_integer_literal] = ACTIONS(3109),
    [sym_real_literal] = ACTIONS(3111),
    [anon_sym_DQUOTE] = ACTIONS(3111),
    [sym_verbatim_string_literal] = ACTIONS(3111),
    [aux_sym_preproc_if_token1] = ACTIONS(3111),
    [aux_sym_preproc_if_token3] = ACTIONS(3111),
    [aux_sym_preproc_else_token1] = ACTIONS(3111),
    [aux_sym_preproc_elif_token1] = ACTIONS(3111),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3111),
    [sym_interpolation_verbatim_start] = ACTIONS(3111),
    [sym_interpolation_raw_start] = ACTIONS(3111),
    [sym_raw_string_start] = ACTIONS(3111),
  },
  [2237] = {
    [sym_preproc_region] = STATE(2237),
    [sym_preproc_endregion] = STATE(2237),
    [sym_preproc_line] = STATE(2237),
    [sym_preproc_pragma] = STATE(2237),
    [sym_preproc_nullable] = STATE(2237),
    [sym_preproc_error] = STATE(2237),
    [sym_preproc_warning] = STATE(2237),
    [sym_preproc_define] = STATE(2237),
    [sym_preproc_undef] = STATE(2237),
    [sym__identifier_token] = ACTIONS(3113),
    [anon_sym_extern] = ACTIONS(3113),
    [anon_sym_alias] = ACTIONS(3113),
    [anon_sym_SEMI] = ACTIONS(3115),
    [anon_sym_global] = ACTIONS(3113),
    [anon_sym_using] = ACTIONS(3113),
    [anon_sym_unsafe] = ACTIONS(3113),
    [anon_sym_static] = ACTIONS(3113),
    [anon_sym_LBRACK] = ACTIONS(3115),
    [anon_sym_LPAREN] = ACTIONS(3115),
    [anon_sym_return] = ACTIONS(3113),
    [anon_sym_namespace] = ACTIONS(3113),
    [anon_sym_class] = ACTIONS(3113),
    [anon_sym_ref] = ACTIONS(3113),
    [anon_sym_struct] = ACTIONS(3113),
    [anon_sym_enum] = ACTIONS(3113),
    [anon_sym_LBRACE] = ACTIONS(3115),
    [anon_sym_interface] = ACTIONS(3113),
    [anon_sym_delegate] = ACTIONS(3113),
    [anon_sym_record] = ACTIONS(3113),
    [anon_sym_abstract] = ACTIONS(3113),
    [anon_sym_async] = ACTIONS(3113),
    [anon_sym_const] = ACTIONS(3113),
    [anon_sym_file] = ACTIONS(3113),
    [anon_sym_fixed] = ACTIONS(3113),
    [anon_sym_internal] = ACTIONS(3113),
    [anon_sym_new] = ACTIONS(3113),
    [anon_sym_override] = ACTIONS(3113),
    [anon_sym_partial] = ACTIONS(3113),
    [anon_sym_private] = ACTIONS(3113),
    [anon_sym_protected] = ACTIONS(3113),
    [anon_sym_public] = ACTIONS(3113),
    [anon_sym_readonly] = ACTIONS(3113),
    [anon_sym_required] = ACTIONS(3113),
    [anon_sym_sealed] = ACTIONS(3113),
    [anon_sym_virtual] = ACTIONS(3113),
    [anon_sym_volatile] = ACTIONS(3113),
    [anon_sym_where] = ACTIONS(3113),
    [anon_sym_notnull] = ACTIONS(3113),
    [anon_sym_unmanaged] = ACTIONS(3113),
    [anon_sym_checked] = ACTIONS(3113),
    [anon_sym_BANG] = ACTIONS(3115),
    [anon_sym_TILDE] = ACTIONS(3115),
    [anon_sym_PLUS_PLUS] = ACTIONS(3115),
    [anon_sym_DASH_DASH] = ACTIONS(3115),
    [anon_sym_true] = ACTIONS(3113),
    [anon_sym_false] = ACTIONS(3113),
    [anon_sym_PLUS] = ACTIONS(3113),
    [anon_sym_DASH] = ACTIONS(3113),
    [anon_sym_STAR] = ACTIONS(3115),
    [anon_sym_CARET] = ACTIONS(3115),
    [anon_sym_AMP] = ACTIONS(3115),
    [anon_sym_this] = ACTIONS(3113),
    [anon_sym_scoped] = ACTIONS(3113),
    [anon_sym_base] = ACTIONS(3113),
    [anon_sym_var] = ACTIONS(3113),
    [sym_predefined_type] = ACTIONS(3113),
    [anon_sym_break] = ACTIONS(3113),
    [anon_sym_unchecked] = ACTIONS(3113),
    [anon_sym_continue] = ACTIONS(3113),
    [anon_sym_do] = ACTIONS(3113),
    [anon_sym_while] = ACTIONS(3113),
    [anon_sym_for] = ACTIONS(3113),
    [anon_sym_lock] = ACTIONS(3113),
    [anon_sym_yield] = ACTIONS(3113),
    [anon_sym_switch] = ACTIONS(3113),
    [anon_sym_default] = ACTIONS(3113),
    [anon_sym_throw] = ACTIONS(3113),
    [anon_sym_try] = ACTIONS(3113),
    [anon_sym_when] = ACTIONS(3113),
    [anon_sym_await] = ACTIONS(3113),
    [anon_sym_foreach] = ACTIONS(3113),
    [anon_sym_goto] = ACTIONS(3113),
    [anon_sym_if] = ACTIONS(3113),
    [anon_sym_else] = ACTIONS(3113),
    [anon_sym_DOT_DOT] = ACTIONS(3115),
    [anon_sym_from] = ACTIONS(3113),
    [anon_sym_into] = ACTIONS(3113),
    [anon_sym_join] = ACTIONS(3113),
    [anon_sym_on] = ACTIONS(3113),
    [anon_sym_equals] = ACTIONS(3113),
    [anon_sym_let] = ACTIONS(3113),
    [anon_sym_orderby] = ACTIONS(3113),
    [anon_sym_ascending] = ACTIONS(3113),
    [anon_sym_descending] = ACTIONS(3113),
    [anon_sym_group] = ACTIONS(3113),
    [anon_sym_by] = ACTIONS(3113),
    [anon_sym_select] = ACTIONS(3113),
    [anon_sym_stackalloc] = ACTIONS(3113),
    [anon_sym_sizeof] = ACTIONS(3113),
    [anon_sym_typeof] = ACTIONS(3113),
    [anon_sym___makeref] = ACTIONS(3113),
    [anon_sym___reftype] = ACTIONS(3113),
    [anon_sym___refvalue] = ACTIONS(3113),
    [sym_null_literal] = ACTIONS(3113),
    [anon_sym_SQUOTE] = ACTIONS(3115),
    [sym_integer_literal] = ACTIONS(3113),
    [sym_real_literal] = ACTIONS(3115),
    [anon_sym_DQUOTE] = ACTIONS(3115),
    [sym_verbatim_string_literal] = ACTIONS(3115),
    [aux_sym_preproc_if_token1] = ACTIONS(3115),
    [aux_sym_preproc_if_token3] = ACTIONS(3115),
    [aux_sym_preproc_else_token1] = ACTIONS(3115),
    [aux_sym_preproc_elif_token1] = ACTIONS(3115),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3115),
    [sym_interpolation_verbatim_start] = ACTIONS(3115),
    [sym_interpolation_raw_start] = ACTIONS(3115),
    [sym_raw_string_start] = ACTIONS(3115),
  },
  [2238] = {
    [sym_preproc_region] = STATE(2238),
    [sym_preproc_endregion] = STATE(2238),
    [sym_preproc_line] = STATE(2238),
    [sym_preproc_pragma] = STATE(2238),
    [sym_preproc_nullable] = STATE(2238),
    [sym_preproc_error] = STATE(2238),
    [sym_preproc_warning] = STATE(2238),
    [sym_preproc_define] = STATE(2238),
    [sym_preproc_undef] = STATE(2238),
    [sym__identifier_token] = ACTIONS(3117),
    [anon_sym_extern] = ACTIONS(3117),
    [anon_sym_alias] = ACTIONS(3117),
    [anon_sym_SEMI] = ACTIONS(3119),
    [anon_sym_global] = ACTIONS(3117),
    [anon_sym_using] = ACTIONS(3117),
    [anon_sym_unsafe] = ACTIONS(3117),
    [anon_sym_static] = ACTIONS(3117),
    [anon_sym_LBRACK] = ACTIONS(3119),
    [anon_sym_LPAREN] = ACTIONS(3119),
    [anon_sym_return] = ACTIONS(3117),
    [anon_sym_namespace] = ACTIONS(3117),
    [anon_sym_class] = ACTIONS(3117),
    [anon_sym_ref] = ACTIONS(3117),
    [anon_sym_struct] = ACTIONS(3117),
    [anon_sym_enum] = ACTIONS(3117),
    [anon_sym_LBRACE] = ACTIONS(3119),
    [anon_sym_interface] = ACTIONS(3117),
    [anon_sym_delegate] = ACTIONS(3117),
    [anon_sym_record] = ACTIONS(3117),
    [anon_sym_abstract] = ACTIONS(3117),
    [anon_sym_async] = ACTIONS(3117),
    [anon_sym_const] = ACTIONS(3117),
    [anon_sym_file] = ACTIONS(3117),
    [anon_sym_fixed] = ACTIONS(3117),
    [anon_sym_internal] = ACTIONS(3117),
    [anon_sym_new] = ACTIONS(3117),
    [anon_sym_override] = ACTIONS(3117),
    [anon_sym_partial] = ACTIONS(3117),
    [anon_sym_private] = ACTIONS(3117),
    [anon_sym_protected] = ACTIONS(3117),
    [anon_sym_public] = ACTIONS(3117),
    [anon_sym_readonly] = ACTIONS(3117),
    [anon_sym_required] = ACTIONS(3117),
    [anon_sym_sealed] = ACTIONS(3117),
    [anon_sym_virtual] = ACTIONS(3117),
    [anon_sym_volatile] = ACTIONS(3117),
    [anon_sym_where] = ACTIONS(3117),
    [anon_sym_notnull] = ACTIONS(3117),
    [anon_sym_unmanaged] = ACTIONS(3117),
    [anon_sym_checked] = ACTIONS(3117),
    [anon_sym_BANG] = ACTIONS(3119),
    [anon_sym_TILDE] = ACTIONS(3119),
    [anon_sym_PLUS_PLUS] = ACTIONS(3119),
    [anon_sym_DASH_DASH] = ACTIONS(3119),
    [anon_sym_true] = ACTIONS(3117),
    [anon_sym_false] = ACTIONS(3117),
    [anon_sym_PLUS] = ACTIONS(3117),
    [anon_sym_DASH] = ACTIONS(3117),
    [anon_sym_STAR] = ACTIONS(3119),
    [anon_sym_CARET] = ACTIONS(3119),
    [anon_sym_AMP] = ACTIONS(3119),
    [anon_sym_this] = ACTIONS(3117),
    [anon_sym_scoped] = ACTIONS(3117),
    [anon_sym_base] = ACTIONS(3117),
    [anon_sym_var] = ACTIONS(3117),
    [sym_predefined_type] = ACTIONS(3117),
    [anon_sym_break] = ACTIONS(3117),
    [anon_sym_unchecked] = ACTIONS(3117),
    [anon_sym_continue] = ACTIONS(3117),
    [anon_sym_do] = ACTIONS(3117),
    [anon_sym_while] = ACTIONS(3117),
    [anon_sym_for] = ACTIONS(3117),
    [anon_sym_lock] = ACTIONS(3117),
    [anon_sym_yield] = ACTIONS(3117),
    [anon_sym_switch] = ACTIONS(3117),
    [anon_sym_default] = ACTIONS(3117),
    [anon_sym_throw] = ACTIONS(3117),
    [anon_sym_try] = ACTIONS(3117),
    [anon_sym_when] = ACTIONS(3117),
    [anon_sym_await] = ACTIONS(3117),
    [anon_sym_foreach] = ACTIONS(3117),
    [anon_sym_goto] = ACTIONS(3117),
    [anon_sym_if] = ACTIONS(3117),
    [anon_sym_else] = ACTIONS(3117),
    [anon_sym_DOT_DOT] = ACTIONS(3119),
    [anon_sym_from] = ACTIONS(3117),
    [anon_sym_into] = ACTIONS(3117),
    [anon_sym_join] = ACTIONS(3117),
    [anon_sym_on] = ACTIONS(3117),
    [anon_sym_equals] = ACTIONS(3117),
    [anon_sym_let] = ACTIONS(3117),
    [anon_sym_orderby] = ACTIONS(3117),
    [anon_sym_ascending] = ACTIONS(3117),
    [anon_sym_descending] = ACTIONS(3117),
    [anon_sym_group] = ACTIONS(3117),
    [anon_sym_by] = ACTIONS(3117),
    [anon_sym_select] = ACTIONS(3117),
    [anon_sym_stackalloc] = ACTIONS(3117),
    [anon_sym_sizeof] = ACTIONS(3117),
    [anon_sym_typeof] = ACTIONS(3117),
    [anon_sym___makeref] = ACTIONS(3117),
    [anon_sym___reftype] = ACTIONS(3117),
    [anon_sym___refvalue] = ACTIONS(3117),
    [sym_null_literal] = ACTIONS(3117),
    [anon_sym_SQUOTE] = ACTIONS(3119),
    [sym_integer_literal] = ACTIONS(3117),
    [sym_real_literal] = ACTIONS(3119),
    [anon_sym_DQUOTE] = ACTIONS(3119),
    [sym_verbatim_string_literal] = ACTIONS(3119),
    [aux_sym_preproc_if_token1] = ACTIONS(3119),
    [aux_sym_preproc_if_token3] = ACTIONS(3119),
    [aux_sym_preproc_else_token1] = ACTIONS(3119),
    [aux_sym_preproc_elif_token1] = ACTIONS(3119),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3119),
    [sym_interpolation_verbatim_start] = ACTIONS(3119),
    [sym_interpolation_raw_start] = ACTIONS(3119),
    [sym_raw_string_start] = ACTIONS(3119),
  },
  [2239] = {
    [sym_preproc_region] = STATE(2239),
    [sym_preproc_endregion] = STATE(2239),
    [sym_preproc_line] = STATE(2239),
    [sym_preproc_pragma] = STATE(2239),
    [sym_preproc_nullable] = STATE(2239),
    [sym_preproc_error] = STATE(2239),
    [sym_preproc_warning] = STATE(2239),
    [sym_preproc_define] = STATE(2239),
    [sym_preproc_undef] = STATE(2239),
    [sym__identifier_token] = ACTIONS(3121),
    [anon_sym_extern] = ACTIONS(3121),
    [anon_sym_alias] = ACTIONS(3121),
    [anon_sym_SEMI] = ACTIONS(3123),
    [anon_sym_global] = ACTIONS(3121),
    [anon_sym_using] = ACTIONS(3121),
    [anon_sym_unsafe] = ACTIONS(3121),
    [anon_sym_static] = ACTIONS(3121),
    [anon_sym_LBRACK] = ACTIONS(3123),
    [anon_sym_LPAREN] = ACTIONS(3123),
    [anon_sym_return] = ACTIONS(3121),
    [anon_sym_namespace] = ACTIONS(3121),
    [anon_sym_class] = ACTIONS(3121),
    [anon_sym_ref] = ACTIONS(3121),
    [anon_sym_struct] = ACTIONS(3121),
    [anon_sym_enum] = ACTIONS(3121),
    [anon_sym_LBRACE] = ACTIONS(3123),
    [anon_sym_interface] = ACTIONS(3121),
    [anon_sym_delegate] = ACTIONS(3121),
    [anon_sym_record] = ACTIONS(3121),
    [anon_sym_abstract] = ACTIONS(3121),
    [anon_sym_async] = ACTIONS(3121),
    [anon_sym_const] = ACTIONS(3121),
    [anon_sym_file] = ACTIONS(3121),
    [anon_sym_fixed] = ACTIONS(3121),
    [anon_sym_internal] = ACTIONS(3121),
    [anon_sym_new] = ACTIONS(3121),
    [anon_sym_override] = ACTIONS(3121),
    [anon_sym_partial] = ACTIONS(3121),
    [anon_sym_private] = ACTIONS(3121),
    [anon_sym_protected] = ACTIONS(3121),
    [anon_sym_public] = ACTIONS(3121),
    [anon_sym_readonly] = ACTIONS(3121),
    [anon_sym_required] = ACTIONS(3121),
    [anon_sym_sealed] = ACTIONS(3121),
    [anon_sym_virtual] = ACTIONS(3121),
    [anon_sym_volatile] = ACTIONS(3121),
    [anon_sym_where] = ACTIONS(3121),
    [anon_sym_notnull] = ACTIONS(3121),
    [anon_sym_unmanaged] = ACTIONS(3121),
    [anon_sym_checked] = ACTIONS(3121),
    [anon_sym_BANG] = ACTIONS(3123),
    [anon_sym_TILDE] = ACTIONS(3123),
    [anon_sym_PLUS_PLUS] = ACTIONS(3123),
    [anon_sym_DASH_DASH] = ACTIONS(3123),
    [anon_sym_true] = ACTIONS(3121),
    [anon_sym_false] = ACTIONS(3121),
    [anon_sym_PLUS] = ACTIONS(3121),
    [anon_sym_DASH] = ACTIONS(3121),
    [anon_sym_STAR] = ACTIONS(3123),
    [anon_sym_CARET] = ACTIONS(3123),
    [anon_sym_AMP] = ACTIONS(3123),
    [anon_sym_this] = ACTIONS(3121),
    [anon_sym_scoped] = ACTIONS(3121),
    [anon_sym_base] = ACTIONS(3121),
    [anon_sym_var] = ACTIONS(3121),
    [sym_predefined_type] = ACTIONS(3121),
    [anon_sym_break] = ACTIONS(3121),
    [anon_sym_unchecked] = ACTIONS(3121),
    [anon_sym_continue] = ACTIONS(3121),
    [anon_sym_do] = ACTIONS(3121),
    [anon_sym_while] = ACTIONS(3121),
    [anon_sym_for] = ACTIONS(3121),
    [anon_sym_lock] = ACTIONS(3121),
    [anon_sym_yield] = ACTIONS(3121),
    [anon_sym_switch] = ACTIONS(3121),
    [anon_sym_default] = ACTIONS(3121),
    [anon_sym_throw] = ACTIONS(3121),
    [anon_sym_try] = ACTIONS(3121),
    [anon_sym_when] = ACTIONS(3121),
    [anon_sym_await] = ACTIONS(3121),
    [anon_sym_foreach] = ACTIONS(3121),
    [anon_sym_goto] = ACTIONS(3121),
    [anon_sym_if] = ACTIONS(3121),
    [anon_sym_else] = ACTIONS(3121),
    [anon_sym_DOT_DOT] = ACTIONS(3123),
    [anon_sym_from] = ACTIONS(3121),
    [anon_sym_into] = ACTIONS(3121),
    [anon_sym_join] = ACTIONS(3121),
    [anon_sym_on] = ACTIONS(3121),
    [anon_sym_equals] = ACTIONS(3121),
    [anon_sym_let] = ACTIONS(3121),
    [anon_sym_orderby] = ACTIONS(3121),
    [anon_sym_ascending] = ACTIONS(3121),
    [anon_sym_descending] = ACTIONS(3121),
    [anon_sym_group] = ACTIONS(3121),
    [anon_sym_by] = ACTIONS(3121),
    [anon_sym_select] = ACTIONS(3121),
    [anon_sym_stackalloc] = ACTIONS(3121),
    [anon_sym_sizeof] = ACTIONS(3121),
    [anon_sym_typeof] = ACTIONS(3121),
    [anon_sym___makeref] = ACTIONS(3121),
    [anon_sym___reftype] = ACTIONS(3121),
    [anon_sym___refvalue] = ACTIONS(3121),
    [sym_null_literal] = ACTIONS(3121),
    [anon_sym_SQUOTE] = ACTIONS(3123),
    [sym_integer_literal] = ACTIONS(3121),
    [sym_real_literal] = ACTIONS(3123),
    [anon_sym_DQUOTE] = ACTIONS(3123),
    [sym_verbatim_string_literal] = ACTIONS(3123),
    [aux_sym_preproc_if_token1] = ACTIONS(3123),
    [aux_sym_preproc_if_token3] = ACTIONS(3123),
    [aux_sym_preproc_else_token1] = ACTIONS(3123),
    [aux_sym_preproc_elif_token1] = ACTIONS(3123),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3123),
    [sym_interpolation_verbatim_start] = ACTIONS(3123),
    [sym_interpolation_raw_start] = ACTIONS(3123),
    [sym_raw_string_start] = ACTIONS(3123),
  },
  [2240] = {
    [sym_preproc_region] = STATE(2240),
    [sym_preproc_endregion] = STATE(2240),
    [sym_preproc_line] = STATE(2240),
    [sym_preproc_pragma] = STATE(2240),
    [sym_preproc_nullable] = STATE(2240),
    [sym_preproc_error] = STATE(2240),
    [sym_preproc_warning] = STATE(2240),
    [sym_preproc_define] = STATE(2240),
    [sym_preproc_undef] = STATE(2240),
    [sym__identifier_token] = ACTIONS(3125),
    [anon_sym_extern] = ACTIONS(3125),
    [anon_sym_alias] = ACTIONS(3125),
    [anon_sym_SEMI] = ACTIONS(3127),
    [anon_sym_global] = ACTIONS(3125),
    [anon_sym_using] = ACTIONS(3125),
    [anon_sym_unsafe] = ACTIONS(3125),
    [anon_sym_static] = ACTIONS(3125),
    [anon_sym_LBRACK] = ACTIONS(3127),
    [anon_sym_LPAREN] = ACTIONS(3127),
    [anon_sym_return] = ACTIONS(3125),
    [anon_sym_namespace] = ACTIONS(3125),
    [anon_sym_class] = ACTIONS(3125),
    [anon_sym_ref] = ACTIONS(3125),
    [anon_sym_struct] = ACTIONS(3125),
    [anon_sym_enum] = ACTIONS(3125),
    [anon_sym_LBRACE] = ACTIONS(3127),
    [anon_sym_interface] = ACTIONS(3125),
    [anon_sym_delegate] = ACTIONS(3125),
    [anon_sym_record] = ACTIONS(3125),
    [anon_sym_abstract] = ACTIONS(3125),
    [anon_sym_async] = ACTIONS(3125),
    [anon_sym_const] = ACTIONS(3125),
    [anon_sym_file] = ACTIONS(3125),
    [anon_sym_fixed] = ACTIONS(3125),
    [anon_sym_internal] = ACTIONS(3125),
    [anon_sym_new] = ACTIONS(3125),
    [anon_sym_override] = ACTIONS(3125),
    [anon_sym_partial] = ACTIONS(3125),
    [anon_sym_private] = ACTIONS(3125),
    [anon_sym_protected] = ACTIONS(3125),
    [anon_sym_public] = ACTIONS(3125),
    [anon_sym_readonly] = ACTIONS(3125),
    [anon_sym_required] = ACTIONS(3125),
    [anon_sym_sealed] = ACTIONS(3125),
    [anon_sym_virtual] = ACTIONS(3125),
    [anon_sym_volatile] = ACTIONS(3125),
    [anon_sym_where] = ACTIONS(3125),
    [anon_sym_notnull] = ACTIONS(3125),
    [anon_sym_unmanaged] = ACTIONS(3125),
    [anon_sym_checked] = ACTIONS(3125),
    [anon_sym_BANG] = ACTIONS(3127),
    [anon_sym_TILDE] = ACTIONS(3127),
    [anon_sym_PLUS_PLUS] = ACTIONS(3127),
    [anon_sym_DASH_DASH] = ACTIONS(3127),
    [anon_sym_true] = ACTIONS(3125),
    [anon_sym_false] = ACTIONS(3125),
    [anon_sym_PLUS] = ACTIONS(3125),
    [anon_sym_DASH] = ACTIONS(3125),
    [anon_sym_STAR] = ACTIONS(3127),
    [anon_sym_CARET] = ACTIONS(3127),
    [anon_sym_AMP] = ACTIONS(3127),
    [anon_sym_this] = ACTIONS(3125),
    [anon_sym_scoped] = ACTIONS(3125),
    [anon_sym_base] = ACTIONS(3125),
    [anon_sym_var] = ACTIONS(3125),
    [sym_predefined_type] = ACTIONS(3125),
    [anon_sym_break] = ACTIONS(3125),
    [anon_sym_unchecked] = ACTIONS(3125),
    [anon_sym_continue] = ACTIONS(3125),
    [anon_sym_do] = ACTIONS(3125),
    [anon_sym_while] = ACTIONS(3125),
    [anon_sym_for] = ACTIONS(3125),
    [anon_sym_lock] = ACTIONS(3125),
    [anon_sym_yield] = ACTIONS(3125),
    [anon_sym_switch] = ACTIONS(3125),
    [anon_sym_default] = ACTIONS(3125),
    [anon_sym_throw] = ACTIONS(3125),
    [anon_sym_try] = ACTIONS(3125),
    [anon_sym_when] = ACTIONS(3125),
    [anon_sym_await] = ACTIONS(3125),
    [anon_sym_foreach] = ACTIONS(3125),
    [anon_sym_goto] = ACTIONS(3125),
    [anon_sym_if] = ACTIONS(3125),
    [anon_sym_else] = ACTIONS(3125),
    [anon_sym_DOT_DOT] = ACTIONS(3127),
    [anon_sym_from] = ACTIONS(3125),
    [anon_sym_into] = ACTIONS(3125),
    [anon_sym_join] = ACTIONS(3125),
    [anon_sym_on] = ACTIONS(3125),
    [anon_sym_equals] = ACTIONS(3125),
    [anon_sym_let] = ACTIONS(3125),
    [anon_sym_orderby] = ACTIONS(3125),
    [anon_sym_ascending] = ACTIONS(3125),
    [anon_sym_descending] = ACTIONS(3125),
    [anon_sym_group] = ACTIONS(3125),
    [anon_sym_by] = ACTIONS(3125),
    [anon_sym_select] = ACTIONS(3125),
    [anon_sym_stackalloc] = ACTIONS(3125),
    [anon_sym_sizeof] = ACTIONS(3125),
    [anon_sym_typeof] = ACTIONS(3125),
    [anon_sym___makeref] = ACTIONS(3125),
    [anon_sym___reftype] = ACTIONS(3125),
    [anon_sym___refvalue] = ACTIONS(3125),
    [sym_null_literal] = ACTIONS(3125),
    [anon_sym_SQUOTE] = ACTIONS(3127),
    [sym_integer_literal] = ACTIONS(3125),
    [sym_real_literal] = ACTIONS(3127),
    [anon_sym_DQUOTE] = ACTIONS(3127),
    [sym_verbatim_string_literal] = ACTIONS(3127),
    [aux_sym_preproc_if_token1] = ACTIONS(3127),
    [aux_sym_preproc_if_token3] = ACTIONS(3127),
    [aux_sym_preproc_else_token1] = ACTIONS(3127),
    [aux_sym_preproc_elif_token1] = ACTIONS(3127),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3127),
    [sym_interpolation_verbatim_start] = ACTIONS(3127),
    [sym_interpolation_raw_start] = ACTIONS(3127),
    [sym_raw_string_start] = ACTIONS(3127),
  },
  [2241] = {
    [sym_preproc_region] = STATE(2241),
    [sym_preproc_endregion] = STATE(2241),
    [sym_preproc_line] = STATE(2241),
    [sym_preproc_pragma] = STATE(2241),
    [sym_preproc_nullable] = STATE(2241),
    [sym_preproc_error] = STATE(2241),
    [sym_preproc_warning] = STATE(2241),
    [sym_preproc_define] = STATE(2241),
    [sym_preproc_undef] = STATE(2241),
    [sym__identifier_token] = ACTIONS(3129),
    [anon_sym_extern] = ACTIONS(3129),
    [anon_sym_alias] = ACTIONS(3129),
    [anon_sym_SEMI] = ACTIONS(3131),
    [anon_sym_global] = ACTIONS(3129),
    [anon_sym_using] = ACTIONS(3129),
    [anon_sym_unsafe] = ACTIONS(3129),
    [anon_sym_static] = ACTIONS(3129),
    [anon_sym_LBRACK] = ACTIONS(3131),
    [anon_sym_LPAREN] = ACTIONS(3131),
    [anon_sym_return] = ACTIONS(3129),
    [anon_sym_namespace] = ACTIONS(3129),
    [anon_sym_class] = ACTIONS(3129),
    [anon_sym_ref] = ACTIONS(3129),
    [anon_sym_struct] = ACTIONS(3129),
    [anon_sym_enum] = ACTIONS(3129),
    [anon_sym_LBRACE] = ACTIONS(3131),
    [anon_sym_interface] = ACTIONS(3129),
    [anon_sym_delegate] = ACTIONS(3129),
    [anon_sym_record] = ACTIONS(3129),
    [anon_sym_abstract] = ACTIONS(3129),
    [anon_sym_async] = ACTIONS(3129),
    [anon_sym_const] = ACTIONS(3129),
    [anon_sym_file] = ACTIONS(3129),
    [anon_sym_fixed] = ACTIONS(3129),
    [anon_sym_internal] = ACTIONS(3129),
    [anon_sym_new] = ACTIONS(3129),
    [anon_sym_override] = ACTIONS(3129),
    [anon_sym_partial] = ACTIONS(3129),
    [anon_sym_private] = ACTIONS(3129),
    [anon_sym_protected] = ACTIONS(3129),
    [anon_sym_public] = ACTIONS(3129),
    [anon_sym_readonly] = ACTIONS(3129),
    [anon_sym_required] = ACTIONS(3129),
    [anon_sym_sealed] = ACTIONS(3129),
    [anon_sym_virtual] = ACTIONS(3129),
    [anon_sym_volatile] = ACTIONS(3129),
    [anon_sym_where] = ACTIONS(3129),
    [anon_sym_notnull] = ACTIONS(3129),
    [anon_sym_unmanaged] = ACTIONS(3129),
    [anon_sym_checked] = ACTIONS(3129),
    [anon_sym_BANG] = ACTIONS(3131),
    [anon_sym_TILDE] = ACTIONS(3131),
    [anon_sym_PLUS_PLUS] = ACTIONS(3131),
    [anon_sym_DASH_DASH] = ACTIONS(3131),
    [anon_sym_true] = ACTIONS(3129),
    [anon_sym_false] = ACTIONS(3129),
    [anon_sym_PLUS] = ACTIONS(3129),
    [anon_sym_DASH] = ACTIONS(3129),
    [anon_sym_STAR] = ACTIONS(3131),
    [anon_sym_CARET] = ACTIONS(3131),
    [anon_sym_AMP] = ACTIONS(3131),
    [anon_sym_this] = ACTIONS(3129),
    [anon_sym_scoped] = ACTIONS(3129),
    [anon_sym_base] = ACTIONS(3129),
    [anon_sym_var] = ACTIONS(3129),
    [sym_predefined_type] = ACTIONS(3129),
    [anon_sym_break] = ACTIONS(3129),
    [anon_sym_unchecked] = ACTIONS(3129),
    [anon_sym_continue] = ACTIONS(3129),
    [anon_sym_do] = ACTIONS(3129),
    [anon_sym_while] = ACTIONS(3129),
    [anon_sym_for] = ACTIONS(3129),
    [anon_sym_lock] = ACTIONS(3129),
    [anon_sym_yield] = ACTIONS(3129),
    [anon_sym_switch] = ACTIONS(3129),
    [anon_sym_default] = ACTIONS(3129),
    [anon_sym_throw] = ACTIONS(3129),
    [anon_sym_try] = ACTIONS(3129),
    [anon_sym_when] = ACTIONS(3129),
    [anon_sym_await] = ACTIONS(3129),
    [anon_sym_foreach] = ACTIONS(3129),
    [anon_sym_goto] = ACTIONS(3129),
    [anon_sym_if] = ACTIONS(3129),
    [anon_sym_else] = ACTIONS(3129),
    [anon_sym_DOT_DOT] = ACTIONS(3131),
    [anon_sym_from] = ACTIONS(3129),
    [anon_sym_into] = ACTIONS(3129),
    [anon_sym_join] = ACTIONS(3129),
    [anon_sym_on] = ACTIONS(3129),
    [anon_sym_equals] = ACTIONS(3129),
    [anon_sym_let] = ACTIONS(3129),
    [anon_sym_orderby] = ACTIONS(3129),
    [anon_sym_ascending] = ACTIONS(3129),
    [anon_sym_descending] = ACTIONS(3129),
    [anon_sym_group] = ACTIONS(3129),
    [anon_sym_by] = ACTIONS(3129),
    [anon_sym_select] = ACTIONS(3129),
    [anon_sym_stackalloc] = ACTIONS(3129),
    [anon_sym_sizeof] = ACTIONS(3129),
    [anon_sym_typeof] = ACTIONS(3129),
    [anon_sym___makeref] = ACTIONS(3129),
    [anon_sym___reftype] = ACTIONS(3129),
    [anon_sym___refvalue] = ACTIONS(3129),
    [sym_null_literal] = ACTIONS(3129),
    [anon_sym_SQUOTE] = ACTIONS(3131),
    [sym_integer_literal] = ACTIONS(3129),
    [sym_real_literal] = ACTIONS(3131),
    [anon_sym_DQUOTE] = ACTIONS(3131),
    [sym_verbatim_string_literal] = ACTIONS(3131),
    [aux_sym_preproc_if_token1] = ACTIONS(3131),
    [aux_sym_preproc_if_token3] = ACTIONS(3131),
    [aux_sym_preproc_else_token1] = ACTIONS(3131),
    [aux_sym_preproc_elif_token1] = ACTIONS(3131),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3131),
    [sym_interpolation_verbatim_start] = ACTIONS(3131),
    [sym_interpolation_raw_start] = ACTIONS(3131),
    [sym_raw_string_start] = ACTIONS(3131),
  },
  [2242] = {
    [sym_preproc_region] = STATE(2242),
    [sym_preproc_endregion] = STATE(2242),
    [sym_preproc_line] = STATE(2242),
    [sym_preproc_pragma] = STATE(2242),
    [sym_preproc_nullable] = STATE(2242),
    [sym_preproc_error] = STATE(2242),
    [sym_preproc_warning] = STATE(2242),
    [sym_preproc_define] = STATE(2242),
    [sym_preproc_undef] = STATE(2242),
    [sym__identifier_token] = ACTIONS(3133),
    [anon_sym_extern] = ACTIONS(3133),
    [anon_sym_alias] = ACTIONS(3133),
    [anon_sym_SEMI] = ACTIONS(3135),
    [anon_sym_global] = ACTIONS(3133),
    [anon_sym_using] = ACTIONS(3133),
    [anon_sym_unsafe] = ACTIONS(3133),
    [anon_sym_static] = ACTIONS(3133),
    [anon_sym_LBRACK] = ACTIONS(3135),
    [anon_sym_LPAREN] = ACTIONS(3135),
    [anon_sym_return] = ACTIONS(3133),
    [anon_sym_namespace] = ACTIONS(3133),
    [anon_sym_class] = ACTIONS(3133),
    [anon_sym_ref] = ACTIONS(3133),
    [anon_sym_struct] = ACTIONS(3133),
    [anon_sym_enum] = ACTIONS(3133),
    [anon_sym_LBRACE] = ACTIONS(3135),
    [anon_sym_interface] = ACTIONS(3133),
    [anon_sym_delegate] = ACTIONS(3133),
    [anon_sym_record] = ACTIONS(3133),
    [anon_sym_abstract] = ACTIONS(3133),
    [anon_sym_async] = ACTIONS(3133),
    [anon_sym_const] = ACTIONS(3133),
    [anon_sym_file] = ACTIONS(3133),
    [anon_sym_fixed] = ACTIONS(3133),
    [anon_sym_internal] = ACTIONS(3133),
    [anon_sym_new] = ACTIONS(3133),
    [anon_sym_override] = ACTIONS(3133),
    [anon_sym_partial] = ACTIONS(3133),
    [anon_sym_private] = ACTIONS(3133),
    [anon_sym_protected] = ACTIONS(3133),
    [anon_sym_public] = ACTIONS(3133),
    [anon_sym_readonly] = ACTIONS(3133),
    [anon_sym_required] = ACTIONS(3133),
    [anon_sym_sealed] = ACTIONS(3133),
    [anon_sym_virtual] = ACTIONS(3133),
    [anon_sym_volatile] = ACTIONS(3133),
    [anon_sym_where] = ACTIONS(3133),
    [anon_sym_notnull] = ACTIONS(3133),
    [anon_sym_unmanaged] = ACTIONS(3133),
    [anon_sym_checked] = ACTIONS(3133),
    [anon_sym_BANG] = ACTIONS(3135),
    [anon_sym_TILDE] = ACTIONS(3135),
    [anon_sym_PLUS_PLUS] = ACTIONS(3135),
    [anon_sym_DASH_DASH] = ACTIONS(3135),
    [anon_sym_true] = ACTIONS(3133),
    [anon_sym_false] = ACTIONS(3133),
    [anon_sym_PLUS] = ACTIONS(3133),
    [anon_sym_DASH] = ACTIONS(3133),
    [anon_sym_STAR] = ACTIONS(3135),
    [anon_sym_CARET] = ACTIONS(3135),
    [anon_sym_AMP] = ACTIONS(3135),
    [anon_sym_this] = ACTIONS(3133),
    [anon_sym_scoped] = ACTIONS(3133),
    [anon_sym_base] = ACTIONS(3133),
    [anon_sym_var] = ACTIONS(3133),
    [sym_predefined_type] = ACTIONS(3133),
    [anon_sym_break] = ACTIONS(3133),
    [anon_sym_unchecked] = ACTIONS(3133),
    [anon_sym_continue] = ACTIONS(3133),
    [anon_sym_do] = ACTIONS(3133),
    [anon_sym_while] = ACTIONS(3133),
    [anon_sym_for] = ACTIONS(3133),
    [anon_sym_lock] = ACTIONS(3133),
    [anon_sym_yield] = ACTIONS(3133),
    [anon_sym_switch] = ACTIONS(3133),
    [anon_sym_default] = ACTIONS(3133),
    [anon_sym_throw] = ACTIONS(3133),
    [anon_sym_try] = ACTIONS(3133),
    [anon_sym_when] = ACTIONS(3133),
    [anon_sym_await] = ACTIONS(3133),
    [anon_sym_foreach] = ACTIONS(3133),
    [anon_sym_goto] = ACTIONS(3133),
    [anon_sym_if] = ACTIONS(3133),
    [anon_sym_else] = ACTIONS(3133),
    [anon_sym_DOT_DOT] = ACTIONS(3135),
    [anon_sym_from] = ACTIONS(3133),
    [anon_sym_into] = ACTIONS(3133),
    [anon_sym_join] = ACTIONS(3133),
    [anon_sym_on] = ACTIONS(3133),
    [anon_sym_equals] = ACTIONS(3133),
    [anon_sym_let] = ACTIONS(3133),
    [anon_sym_orderby] = ACTIONS(3133),
    [anon_sym_ascending] = ACTIONS(3133),
    [anon_sym_descending] = ACTIONS(3133),
    [anon_sym_group] = ACTIONS(3133),
    [anon_sym_by] = ACTIONS(3133),
    [anon_sym_select] = ACTIONS(3133),
    [anon_sym_stackalloc] = ACTIONS(3133),
    [anon_sym_sizeof] = ACTIONS(3133),
    [anon_sym_typeof] = ACTIONS(3133),
    [anon_sym___makeref] = ACTIONS(3133),
    [anon_sym___reftype] = ACTIONS(3133),
    [anon_sym___refvalue] = ACTIONS(3133),
    [sym_null_literal] = ACTIONS(3133),
    [anon_sym_SQUOTE] = ACTIONS(3135),
    [sym_integer_literal] = ACTIONS(3133),
    [sym_real_literal] = ACTIONS(3135),
    [anon_sym_DQUOTE] = ACTIONS(3135),
    [sym_verbatim_string_literal] = ACTIONS(3135),
    [aux_sym_preproc_if_token1] = ACTIONS(3135),
    [aux_sym_preproc_if_token3] = ACTIONS(3135),
    [aux_sym_preproc_else_token1] = ACTIONS(3135),
    [aux_sym_preproc_elif_token1] = ACTIONS(3135),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3135),
    [sym_interpolation_verbatim_start] = ACTIONS(3135),
    [sym_interpolation_raw_start] = ACTIONS(3135),
    [sym_raw_string_start] = ACTIONS(3135),
  },
  [2243] = {
    [sym_preproc_region] = STATE(2243),
    [sym_preproc_endregion] = STATE(2243),
    [sym_preproc_line] = STATE(2243),
    [sym_preproc_pragma] = STATE(2243),
    [sym_preproc_nullable] = STATE(2243),
    [sym_preproc_error] = STATE(2243),
    [sym_preproc_warning] = STATE(2243),
    [sym_preproc_define] = STATE(2243),
    [sym_preproc_undef] = STATE(2243),
    [sym__identifier_token] = ACTIONS(3137),
    [anon_sym_extern] = ACTIONS(3137),
    [anon_sym_alias] = ACTIONS(3137),
    [anon_sym_SEMI] = ACTIONS(3139),
    [anon_sym_global] = ACTIONS(3137),
    [anon_sym_using] = ACTIONS(3137),
    [anon_sym_unsafe] = ACTIONS(3137),
    [anon_sym_static] = ACTIONS(3137),
    [anon_sym_LBRACK] = ACTIONS(3139),
    [anon_sym_LPAREN] = ACTIONS(3139),
    [anon_sym_return] = ACTIONS(3137),
    [anon_sym_namespace] = ACTIONS(3137),
    [anon_sym_class] = ACTIONS(3137),
    [anon_sym_ref] = ACTIONS(3137),
    [anon_sym_struct] = ACTIONS(3137),
    [anon_sym_enum] = ACTIONS(3137),
    [anon_sym_LBRACE] = ACTIONS(3139),
    [anon_sym_interface] = ACTIONS(3137),
    [anon_sym_delegate] = ACTIONS(3137),
    [anon_sym_record] = ACTIONS(3137),
    [anon_sym_abstract] = ACTIONS(3137),
    [anon_sym_async] = ACTIONS(3137),
    [anon_sym_const] = ACTIONS(3137),
    [anon_sym_file] = ACTIONS(3137),
    [anon_sym_fixed] = ACTIONS(3137),
    [anon_sym_internal] = ACTIONS(3137),
    [anon_sym_new] = ACTIONS(3137),
    [anon_sym_override] = ACTIONS(3137),
    [anon_sym_partial] = ACTIONS(3137),
    [anon_sym_private] = ACTIONS(3137),
    [anon_sym_protected] = ACTIONS(3137),
    [anon_sym_public] = ACTIONS(3137),
    [anon_sym_readonly] = ACTIONS(3137),
    [anon_sym_required] = ACTIONS(3137),
    [anon_sym_sealed] = ACTIONS(3137),
    [anon_sym_virtual] = ACTIONS(3137),
    [anon_sym_volatile] = ACTIONS(3137),
    [anon_sym_where] = ACTIONS(3137),
    [anon_sym_notnull] = ACTIONS(3137),
    [anon_sym_unmanaged] = ACTIONS(3137),
    [anon_sym_checked] = ACTIONS(3137),
    [anon_sym_BANG] = ACTIONS(3139),
    [anon_sym_TILDE] = ACTIONS(3139),
    [anon_sym_PLUS_PLUS] = ACTIONS(3139),
    [anon_sym_DASH_DASH] = ACTIONS(3139),
    [anon_sym_true] = ACTIONS(3137),
    [anon_sym_false] = ACTIONS(3137),
    [anon_sym_PLUS] = ACTIONS(3137),
    [anon_sym_DASH] = ACTIONS(3137),
    [anon_sym_STAR] = ACTIONS(3139),
    [anon_sym_CARET] = ACTIONS(3139),
    [anon_sym_AMP] = ACTIONS(3139),
    [anon_sym_this] = ACTIONS(3137),
    [anon_sym_scoped] = ACTIONS(3137),
    [anon_sym_base] = ACTIONS(3137),
    [anon_sym_var] = ACTIONS(3137),
    [sym_predefined_type] = ACTIONS(3137),
    [anon_sym_break] = ACTIONS(3137),
    [anon_sym_unchecked] = ACTIONS(3137),
    [anon_sym_continue] = ACTIONS(3137),
    [anon_sym_do] = ACTIONS(3137),
    [anon_sym_while] = ACTIONS(3137),
    [anon_sym_for] = ACTIONS(3137),
    [anon_sym_lock] = ACTIONS(3137),
    [anon_sym_yield] = ACTIONS(3137),
    [anon_sym_switch] = ACTIONS(3137),
    [anon_sym_default] = ACTIONS(3137),
    [anon_sym_throw] = ACTIONS(3137),
    [anon_sym_try] = ACTIONS(3137),
    [anon_sym_when] = ACTIONS(3137),
    [anon_sym_await] = ACTIONS(3137),
    [anon_sym_foreach] = ACTIONS(3137),
    [anon_sym_goto] = ACTIONS(3137),
    [anon_sym_if] = ACTIONS(3137),
    [anon_sym_else] = ACTIONS(3137),
    [anon_sym_DOT_DOT] = ACTIONS(3139),
    [anon_sym_from] = ACTIONS(3137),
    [anon_sym_into] = ACTIONS(3137),
    [anon_sym_join] = ACTIONS(3137),
    [anon_sym_on] = ACTIONS(3137),
    [anon_sym_equals] = ACTIONS(3137),
    [anon_sym_let] = ACTIONS(3137),
    [anon_sym_orderby] = ACTIONS(3137),
    [anon_sym_ascending] = ACTIONS(3137),
    [anon_sym_descending] = ACTIONS(3137),
    [anon_sym_group] = ACTIONS(3137),
    [anon_sym_by] = ACTIONS(3137),
    [anon_sym_select] = ACTIONS(3137),
    [anon_sym_stackalloc] = ACTIONS(3137),
    [anon_sym_sizeof] = ACTIONS(3137),
    [anon_sym_typeof] = ACTIONS(3137),
    [anon_sym___makeref] = ACTIONS(3137),
    [anon_sym___reftype] = ACTIONS(3137),
    [anon_sym___refvalue] = ACTIONS(3137),
    [sym_null_literal] = ACTIONS(3137),
    [anon_sym_SQUOTE] = ACTIONS(3139),
    [sym_integer_literal] = ACTIONS(3137),
    [sym_real_literal] = ACTIONS(3139),
    [anon_sym_DQUOTE] = ACTIONS(3139),
    [sym_verbatim_string_literal] = ACTIONS(3139),
    [aux_sym_preproc_if_token1] = ACTIONS(3139),
    [aux_sym_preproc_if_token3] = ACTIONS(3139),
    [aux_sym_preproc_else_token1] = ACTIONS(3139),
    [aux_sym_preproc_elif_token1] = ACTIONS(3139),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3139),
    [sym_interpolation_verbatim_start] = ACTIONS(3139),
    [sym_interpolation_raw_start] = ACTIONS(3139),
    [sym_raw_string_start] = ACTIONS(3139),
  },
  [2244] = {
    [sym_preproc_region] = STATE(2244),
    [sym_preproc_endregion] = STATE(2244),
    [sym_preproc_line] = STATE(2244),
    [sym_preproc_pragma] = STATE(2244),
    [sym_preproc_nullable] = STATE(2244),
    [sym_preproc_error] = STATE(2244),
    [sym_preproc_warning] = STATE(2244),
    [sym_preproc_define] = STATE(2244),
    [sym_preproc_undef] = STATE(2244),
    [sym__identifier_token] = ACTIONS(3141),
    [anon_sym_extern] = ACTIONS(3141),
    [anon_sym_alias] = ACTIONS(3141),
    [anon_sym_SEMI] = ACTIONS(3143),
    [anon_sym_global] = ACTIONS(3141),
    [anon_sym_using] = ACTIONS(3141),
    [anon_sym_unsafe] = ACTIONS(3141),
    [anon_sym_static] = ACTIONS(3141),
    [anon_sym_LBRACK] = ACTIONS(3143),
    [anon_sym_LPAREN] = ACTIONS(3143),
    [anon_sym_return] = ACTIONS(3141),
    [anon_sym_namespace] = ACTIONS(3141),
    [anon_sym_class] = ACTIONS(3141),
    [anon_sym_ref] = ACTIONS(3141),
    [anon_sym_struct] = ACTIONS(3141),
    [anon_sym_enum] = ACTIONS(3141),
    [anon_sym_LBRACE] = ACTIONS(3143),
    [anon_sym_interface] = ACTIONS(3141),
    [anon_sym_delegate] = ACTIONS(3141),
    [anon_sym_record] = ACTIONS(3141),
    [anon_sym_abstract] = ACTIONS(3141),
    [anon_sym_async] = ACTIONS(3141),
    [anon_sym_const] = ACTIONS(3141),
    [anon_sym_file] = ACTIONS(3141),
    [anon_sym_fixed] = ACTIONS(3141),
    [anon_sym_internal] = ACTIONS(3141),
    [anon_sym_new] = ACTIONS(3141),
    [anon_sym_override] = ACTIONS(3141),
    [anon_sym_partial] = ACTIONS(3141),
    [anon_sym_private] = ACTIONS(3141),
    [anon_sym_protected] = ACTIONS(3141),
    [anon_sym_public] = ACTIONS(3141),
    [anon_sym_readonly] = ACTIONS(3141),
    [anon_sym_required] = ACTIONS(3141),
    [anon_sym_sealed] = ACTIONS(3141),
    [anon_sym_virtual] = ACTIONS(3141),
    [anon_sym_volatile] = ACTIONS(3141),
    [anon_sym_where] = ACTIONS(3141),
    [anon_sym_notnull] = ACTIONS(3141),
    [anon_sym_unmanaged] = ACTIONS(3141),
    [anon_sym_checked] = ACTIONS(3141),
    [anon_sym_BANG] = ACTIONS(3143),
    [anon_sym_TILDE] = ACTIONS(3143),
    [anon_sym_PLUS_PLUS] = ACTIONS(3143),
    [anon_sym_DASH_DASH] = ACTIONS(3143),
    [anon_sym_true] = ACTIONS(3141),
    [anon_sym_false] = ACTIONS(3141),
    [anon_sym_PLUS] = ACTIONS(3141),
    [anon_sym_DASH] = ACTIONS(3141),
    [anon_sym_STAR] = ACTIONS(3143),
    [anon_sym_CARET] = ACTIONS(3143),
    [anon_sym_AMP] = ACTIONS(3143),
    [anon_sym_this] = ACTIONS(3141),
    [anon_sym_scoped] = ACTIONS(3141),
    [anon_sym_base] = ACTIONS(3141),
    [anon_sym_var] = ACTIONS(3141),
    [sym_predefined_type] = ACTIONS(3141),
    [anon_sym_break] = ACTIONS(3141),
    [anon_sym_unchecked] = ACTIONS(3141),
    [anon_sym_continue] = ACTIONS(3141),
    [anon_sym_do] = ACTIONS(3141),
    [anon_sym_while] = ACTIONS(3141),
    [anon_sym_for] = ACTIONS(3141),
    [anon_sym_lock] = ACTIONS(3141),
    [anon_sym_yield] = ACTIONS(3141),
    [anon_sym_switch] = ACTIONS(3141),
    [anon_sym_default] = ACTIONS(3141),
    [anon_sym_throw] = ACTIONS(3141),
    [anon_sym_try] = ACTIONS(3141),
    [anon_sym_when] = ACTIONS(3141),
    [anon_sym_await] = ACTIONS(3141),
    [anon_sym_foreach] = ACTIONS(3141),
    [anon_sym_goto] = ACTIONS(3141),
    [anon_sym_if] = ACTIONS(3141),
    [anon_sym_else] = ACTIONS(3141),
    [anon_sym_DOT_DOT] = ACTIONS(3143),
    [anon_sym_from] = ACTIONS(3141),
    [anon_sym_into] = ACTIONS(3141),
    [anon_sym_join] = ACTIONS(3141),
    [anon_sym_on] = ACTIONS(3141),
    [anon_sym_equals] = ACTIONS(3141),
    [anon_sym_let] = ACTIONS(3141),
    [anon_sym_orderby] = ACTIONS(3141),
    [anon_sym_ascending] = ACTIONS(3141),
    [anon_sym_descending] = ACTIONS(3141),
    [anon_sym_group] = ACTIONS(3141),
    [anon_sym_by] = ACTIONS(3141),
    [anon_sym_select] = ACTIONS(3141),
    [anon_sym_stackalloc] = ACTIONS(3141),
    [anon_sym_sizeof] = ACTIONS(3141),
    [anon_sym_typeof] = ACTIONS(3141),
    [anon_sym___makeref] = ACTIONS(3141),
    [anon_sym___reftype] = ACTIONS(3141),
    [anon_sym___refvalue] = ACTIONS(3141),
    [sym_null_literal] = ACTIONS(3141),
    [anon_sym_SQUOTE] = ACTIONS(3143),
    [sym_integer_literal] = ACTIONS(3141),
    [sym_real_literal] = ACTIONS(3143),
    [anon_sym_DQUOTE] = ACTIONS(3143),
    [sym_verbatim_string_literal] = ACTIONS(3143),
    [aux_sym_preproc_if_token1] = ACTIONS(3143),
    [aux_sym_preproc_if_token3] = ACTIONS(3143),
    [aux_sym_preproc_else_token1] = ACTIONS(3143),
    [aux_sym_preproc_elif_token1] = ACTIONS(3143),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3143),
    [sym_interpolation_verbatim_start] = ACTIONS(3143),
    [sym_interpolation_raw_start] = ACTIONS(3143),
    [sym_raw_string_start] = ACTIONS(3143),
  },
  [2245] = {
    [sym_preproc_region] = STATE(2245),
    [sym_preproc_endregion] = STATE(2245),
    [sym_preproc_line] = STATE(2245),
    [sym_preproc_pragma] = STATE(2245),
    [sym_preproc_nullable] = STATE(2245),
    [sym_preproc_error] = STATE(2245),
    [sym_preproc_warning] = STATE(2245),
    [sym_preproc_define] = STATE(2245),
    [sym_preproc_undef] = STATE(2245),
    [sym__identifier_token] = ACTIONS(3145),
    [anon_sym_extern] = ACTIONS(3145),
    [anon_sym_alias] = ACTIONS(3145),
    [anon_sym_SEMI] = ACTIONS(3147),
    [anon_sym_global] = ACTIONS(3145),
    [anon_sym_using] = ACTIONS(3145),
    [anon_sym_unsafe] = ACTIONS(3145),
    [anon_sym_static] = ACTIONS(3145),
    [anon_sym_LBRACK] = ACTIONS(3147),
    [anon_sym_LPAREN] = ACTIONS(3147),
    [anon_sym_return] = ACTIONS(3145),
    [anon_sym_namespace] = ACTIONS(3145),
    [anon_sym_class] = ACTIONS(3145),
    [anon_sym_ref] = ACTIONS(3145),
    [anon_sym_struct] = ACTIONS(3145),
    [anon_sym_enum] = ACTIONS(3145),
    [anon_sym_LBRACE] = ACTIONS(3147),
    [anon_sym_interface] = ACTIONS(3145),
    [anon_sym_delegate] = ACTIONS(3145),
    [anon_sym_record] = ACTIONS(3145),
    [anon_sym_abstract] = ACTIONS(3145),
    [anon_sym_async] = ACTIONS(3145),
    [anon_sym_const] = ACTIONS(3145),
    [anon_sym_file] = ACTIONS(3145),
    [anon_sym_fixed] = ACTIONS(3145),
    [anon_sym_internal] = ACTIONS(3145),
    [anon_sym_new] = ACTIONS(3145),
    [anon_sym_override] = ACTIONS(3145),
    [anon_sym_partial] = ACTIONS(3145),
    [anon_sym_private] = ACTIONS(3145),
    [anon_sym_protected] = ACTIONS(3145),
    [anon_sym_public] = ACTIONS(3145),
    [anon_sym_readonly] = ACTIONS(3145),
    [anon_sym_required] = ACTIONS(3145),
    [anon_sym_sealed] = ACTIONS(3145),
    [anon_sym_virtual] = ACTIONS(3145),
    [anon_sym_volatile] = ACTIONS(3145),
    [anon_sym_where] = ACTIONS(3145),
    [anon_sym_notnull] = ACTIONS(3145),
    [anon_sym_unmanaged] = ACTIONS(3145),
    [anon_sym_checked] = ACTIONS(3145),
    [anon_sym_BANG] = ACTIONS(3147),
    [anon_sym_TILDE] = ACTIONS(3147),
    [anon_sym_PLUS_PLUS] = ACTIONS(3147),
    [anon_sym_DASH_DASH] = ACTIONS(3147),
    [anon_sym_true] = ACTIONS(3145),
    [anon_sym_false] = ACTIONS(3145),
    [anon_sym_PLUS] = ACTIONS(3145),
    [anon_sym_DASH] = ACTIONS(3145),
    [anon_sym_STAR] = ACTIONS(3147),
    [anon_sym_CARET] = ACTIONS(3147),
    [anon_sym_AMP] = ACTIONS(3147),
    [anon_sym_this] = ACTIONS(3145),
    [anon_sym_scoped] = ACTIONS(3145),
    [anon_sym_base] = ACTIONS(3145),
    [anon_sym_var] = ACTIONS(3145),
    [sym_predefined_type] = ACTIONS(3145),
    [anon_sym_break] = ACTIONS(3145),
    [anon_sym_unchecked] = ACTIONS(3145),
    [anon_sym_continue] = ACTIONS(3145),
    [anon_sym_do] = ACTIONS(3145),
    [anon_sym_while] = ACTIONS(3145),
    [anon_sym_for] = ACTIONS(3145),
    [anon_sym_lock] = ACTIONS(3145),
    [anon_sym_yield] = ACTIONS(3145),
    [anon_sym_switch] = ACTIONS(3145),
    [anon_sym_default] = ACTIONS(3145),
    [anon_sym_throw] = ACTIONS(3145),
    [anon_sym_try] = ACTIONS(3145),
    [anon_sym_when] = ACTIONS(3145),
    [anon_sym_await] = ACTIONS(3145),
    [anon_sym_foreach] = ACTIONS(3145),
    [anon_sym_goto] = ACTIONS(3145),
    [anon_sym_if] = ACTIONS(3145),
    [anon_sym_else] = ACTIONS(3145),
    [anon_sym_DOT_DOT] = ACTIONS(3147),
    [anon_sym_from] = ACTIONS(3145),
    [anon_sym_into] = ACTIONS(3145),
    [anon_sym_join] = ACTIONS(3145),
    [anon_sym_on] = ACTIONS(3145),
    [anon_sym_equals] = ACTIONS(3145),
    [anon_sym_let] = ACTIONS(3145),
    [anon_sym_orderby] = ACTIONS(3145),
    [anon_sym_ascending] = ACTIONS(3145),
    [anon_sym_descending] = ACTIONS(3145),
    [anon_sym_group] = ACTIONS(3145),
    [anon_sym_by] = ACTIONS(3145),
    [anon_sym_select] = ACTIONS(3145),
    [anon_sym_stackalloc] = ACTIONS(3145),
    [anon_sym_sizeof] = ACTIONS(3145),
    [anon_sym_typeof] = ACTIONS(3145),
    [anon_sym___makeref] = ACTIONS(3145),
    [anon_sym___reftype] = ACTIONS(3145),
    [anon_sym___refvalue] = ACTIONS(3145),
    [sym_null_literal] = ACTIONS(3145),
    [anon_sym_SQUOTE] = ACTIONS(3147),
    [sym_integer_literal] = ACTIONS(3145),
    [sym_real_literal] = ACTIONS(3147),
    [anon_sym_DQUOTE] = ACTIONS(3147),
    [sym_verbatim_string_literal] = ACTIONS(3147),
    [aux_sym_preproc_if_token1] = ACTIONS(3147),
    [aux_sym_preproc_if_token3] = ACTIONS(3147),
    [aux_sym_preproc_else_token1] = ACTIONS(3147),
    [aux_sym_preproc_elif_token1] = ACTIONS(3147),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3147),
    [sym_interpolation_verbatim_start] = ACTIONS(3147),
    [sym_interpolation_raw_start] = ACTIONS(3147),
    [sym_raw_string_start] = ACTIONS(3147),
  },
  [2246] = {
    [sym_preproc_region] = STATE(2246),
    [sym_preproc_endregion] = STATE(2246),
    [sym_preproc_line] = STATE(2246),
    [sym_preproc_pragma] = STATE(2246),
    [sym_preproc_nullable] = STATE(2246),
    [sym_preproc_error] = STATE(2246),
    [sym_preproc_warning] = STATE(2246),
    [sym_preproc_define] = STATE(2246),
    [sym_preproc_undef] = STATE(2246),
    [sym__identifier_token] = ACTIONS(3149),
    [anon_sym_extern] = ACTIONS(3149),
    [anon_sym_alias] = ACTIONS(3149),
    [anon_sym_SEMI] = ACTIONS(3151),
    [anon_sym_global] = ACTIONS(3149),
    [anon_sym_using] = ACTIONS(3149),
    [anon_sym_unsafe] = ACTIONS(3149),
    [anon_sym_static] = ACTIONS(3149),
    [anon_sym_LBRACK] = ACTIONS(3151),
    [anon_sym_LPAREN] = ACTIONS(3151),
    [anon_sym_return] = ACTIONS(3149),
    [anon_sym_namespace] = ACTIONS(3149),
    [anon_sym_class] = ACTIONS(3149),
    [anon_sym_ref] = ACTIONS(3149),
    [anon_sym_struct] = ACTIONS(3149),
    [anon_sym_enum] = ACTIONS(3149),
    [anon_sym_LBRACE] = ACTIONS(3151),
    [anon_sym_interface] = ACTIONS(3149),
    [anon_sym_delegate] = ACTIONS(3149),
    [anon_sym_record] = ACTIONS(3149),
    [anon_sym_abstract] = ACTIONS(3149),
    [anon_sym_async] = ACTIONS(3149),
    [anon_sym_const] = ACTIONS(3149),
    [anon_sym_file] = ACTIONS(3149),
    [anon_sym_fixed] = ACTIONS(3149),
    [anon_sym_internal] = ACTIONS(3149),
    [anon_sym_new] = ACTIONS(3149),
    [anon_sym_override] = ACTIONS(3149),
    [anon_sym_partial] = ACTIONS(3149),
    [anon_sym_private] = ACTIONS(3149),
    [anon_sym_protected] = ACTIONS(3149),
    [anon_sym_public] = ACTIONS(3149),
    [anon_sym_readonly] = ACTIONS(3149),
    [anon_sym_required] = ACTIONS(3149),
    [anon_sym_sealed] = ACTIONS(3149),
    [anon_sym_virtual] = ACTIONS(3149),
    [anon_sym_volatile] = ACTIONS(3149),
    [anon_sym_where] = ACTIONS(3149),
    [anon_sym_notnull] = ACTIONS(3149),
    [anon_sym_unmanaged] = ACTIONS(3149),
    [anon_sym_checked] = ACTIONS(3149),
    [anon_sym_BANG] = ACTIONS(3151),
    [anon_sym_TILDE] = ACTIONS(3151),
    [anon_sym_PLUS_PLUS] = ACTIONS(3151),
    [anon_sym_DASH_DASH] = ACTIONS(3151),
    [anon_sym_true] = ACTIONS(3149),
    [anon_sym_false] = ACTIONS(3149),
    [anon_sym_PLUS] = ACTIONS(3149),
    [anon_sym_DASH] = ACTIONS(3149),
    [anon_sym_STAR] = ACTIONS(3151),
    [anon_sym_CARET] = ACTIONS(3151),
    [anon_sym_AMP] = ACTIONS(3151),
    [anon_sym_this] = ACTIONS(3149),
    [anon_sym_scoped] = ACTIONS(3149),
    [anon_sym_base] = ACTIONS(3149),
    [anon_sym_var] = ACTIONS(3149),
    [sym_predefined_type] = ACTIONS(3149),
    [anon_sym_break] = ACTIONS(3149),
    [anon_sym_unchecked] = ACTIONS(3149),
    [anon_sym_continue] = ACTIONS(3149),
    [anon_sym_do] = ACTIONS(3149),
    [anon_sym_while] = ACTIONS(3149),
    [anon_sym_for] = ACTIONS(3149),
    [anon_sym_lock] = ACTIONS(3149),
    [anon_sym_yield] = ACTIONS(3149),
    [anon_sym_switch] = ACTIONS(3149),
    [anon_sym_default] = ACTIONS(3149),
    [anon_sym_throw] = ACTIONS(3149),
    [anon_sym_try] = ACTIONS(3149),
    [anon_sym_when] = ACTIONS(3149),
    [anon_sym_await] = ACTIONS(3149),
    [anon_sym_foreach] = ACTIONS(3149),
    [anon_sym_goto] = ACTIONS(3149),
    [anon_sym_if] = ACTIONS(3149),
    [anon_sym_else] = ACTIONS(3149),
    [anon_sym_DOT_DOT] = ACTIONS(3151),
    [anon_sym_from] = ACTIONS(3149),
    [anon_sym_into] = ACTIONS(3149),
    [anon_sym_join] = ACTIONS(3149),
    [anon_sym_on] = ACTIONS(3149),
    [anon_sym_equals] = ACTIONS(3149),
    [anon_sym_let] = ACTIONS(3149),
    [anon_sym_orderby] = ACTIONS(3149),
    [anon_sym_ascending] = ACTIONS(3149),
    [anon_sym_descending] = ACTIONS(3149),
    [anon_sym_group] = ACTIONS(3149),
    [anon_sym_by] = ACTIONS(3149),
    [anon_sym_select] = ACTIONS(3149),
    [anon_sym_stackalloc] = ACTIONS(3149),
    [anon_sym_sizeof] = ACTIONS(3149),
    [anon_sym_typeof] = ACTIONS(3149),
    [anon_sym___makeref] = ACTIONS(3149),
    [anon_sym___reftype] = ACTIONS(3149),
    [anon_sym___refvalue] = ACTIONS(3149),
    [sym_null_literal] = ACTIONS(3149),
    [anon_sym_SQUOTE] = ACTIONS(3151),
    [sym_integer_literal] = ACTIONS(3149),
    [sym_real_literal] = ACTIONS(3151),
    [anon_sym_DQUOTE] = ACTIONS(3151),
    [sym_verbatim_string_literal] = ACTIONS(3151),
    [aux_sym_preproc_if_token1] = ACTIONS(3151),
    [aux_sym_preproc_if_token3] = ACTIONS(3151),
    [aux_sym_preproc_else_token1] = ACTIONS(3151),
    [aux_sym_preproc_elif_token1] = ACTIONS(3151),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3151),
    [sym_interpolation_verbatim_start] = ACTIONS(3151),
    [sym_interpolation_raw_start] = ACTIONS(3151),
    [sym_raw_string_start] = ACTIONS(3151),
  },
  [2247] = {
    [sym_preproc_region] = STATE(2247),
    [sym_preproc_endregion] = STATE(2247),
    [sym_preproc_line] = STATE(2247),
    [sym_preproc_pragma] = STATE(2247),
    [sym_preproc_nullable] = STATE(2247),
    [sym_preproc_error] = STATE(2247),
    [sym_preproc_warning] = STATE(2247),
    [sym_preproc_define] = STATE(2247),
    [sym_preproc_undef] = STATE(2247),
    [sym__identifier_token] = ACTIONS(3153),
    [anon_sym_extern] = ACTIONS(3153),
    [anon_sym_alias] = ACTIONS(3153),
    [anon_sym_SEMI] = ACTIONS(3155),
    [anon_sym_global] = ACTIONS(3153),
    [anon_sym_using] = ACTIONS(3153),
    [anon_sym_unsafe] = ACTIONS(3153),
    [anon_sym_static] = ACTIONS(3153),
    [anon_sym_LBRACK] = ACTIONS(3155),
    [anon_sym_LPAREN] = ACTIONS(3155),
    [anon_sym_return] = ACTIONS(3153),
    [anon_sym_namespace] = ACTIONS(3153),
    [anon_sym_class] = ACTIONS(3153),
    [anon_sym_ref] = ACTIONS(3153),
    [anon_sym_struct] = ACTIONS(3153),
    [anon_sym_enum] = ACTIONS(3153),
    [anon_sym_LBRACE] = ACTIONS(3155),
    [anon_sym_interface] = ACTIONS(3153),
    [anon_sym_delegate] = ACTIONS(3153),
    [anon_sym_record] = ACTIONS(3153),
    [anon_sym_abstract] = ACTIONS(3153),
    [anon_sym_async] = ACTIONS(3153),
    [anon_sym_const] = ACTIONS(3153),
    [anon_sym_file] = ACTIONS(3153),
    [anon_sym_fixed] = ACTIONS(3153),
    [anon_sym_internal] = ACTIONS(3153),
    [anon_sym_new] = ACTIONS(3153),
    [anon_sym_override] = ACTIONS(3153),
    [anon_sym_partial] = ACTIONS(3153),
    [anon_sym_private] = ACTIONS(3153),
    [anon_sym_protected] = ACTIONS(3153),
    [anon_sym_public] = ACTIONS(3153),
    [anon_sym_readonly] = ACTIONS(3153),
    [anon_sym_required] = ACTIONS(3153),
    [anon_sym_sealed] = ACTIONS(3153),
    [anon_sym_virtual] = ACTIONS(3153),
    [anon_sym_volatile] = ACTIONS(3153),
    [anon_sym_where] = ACTIONS(3153),
    [anon_sym_notnull] = ACTIONS(3153),
    [anon_sym_unmanaged] = ACTIONS(3153),
    [anon_sym_checked] = ACTIONS(3153),
    [anon_sym_BANG] = ACTIONS(3155),
    [anon_sym_TILDE] = ACTIONS(3155),
    [anon_sym_PLUS_PLUS] = ACTIONS(3155),
    [anon_sym_DASH_DASH] = ACTIONS(3155),
    [anon_sym_true] = ACTIONS(3153),
    [anon_sym_false] = ACTIONS(3153),
    [anon_sym_PLUS] = ACTIONS(3153),
    [anon_sym_DASH] = ACTIONS(3153),
    [anon_sym_STAR] = ACTIONS(3155),
    [anon_sym_CARET] = ACTIONS(3155),
    [anon_sym_AMP] = ACTIONS(3155),
    [anon_sym_this] = ACTIONS(3153),
    [anon_sym_scoped] = ACTIONS(3153),
    [anon_sym_base] = ACTIONS(3153),
    [anon_sym_var] = ACTIONS(3153),
    [sym_predefined_type] = ACTIONS(3153),
    [anon_sym_break] = ACTIONS(3153),
    [anon_sym_unchecked] = ACTIONS(3153),
    [anon_sym_continue] = ACTIONS(3153),
    [anon_sym_do] = ACTIONS(3153),
    [anon_sym_while] = ACTIONS(3153),
    [anon_sym_for] = ACTIONS(3153),
    [anon_sym_lock] = ACTIONS(3153),
    [anon_sym_yield] = ACTIONS(3153),
    [anon_sym_switch] = ACTIONS(3153),
    [anon_sym_default] = ACTIONS(3153),
    [anon_sym_throw] = ACTIONS(3153),
    [anon_sym_try] = ACTIONS(3153),
    [anon_sym_when] = ACTIONS(3153),
    [anon_sym_await] = ACTIONS(3153),
    [anon_sym_foreach] = ACTIONS(3153),
    [anon_sym_goto] = ACTIONS(3153),
    [anon_sym_if] = ACTIONS(3153),
    [anon_sym_else] = ACTIONS(3153),
    [anon_sym_DOT_DOT] = ACTIONS(3155),
    [anon_sym_from] = ACTIONS(3153),
    [anon_sym_into] = ACTIONS(3153),
    [anon_sym_join] = ACTIONS(3153),
    [anon_sym_on] = ACTIONS(3153),
    [anon_sym_equals] = ACTIONS(3153),
    [anon_sym_let] = ACTIONS(3153),
    [anon_sym_orderby] = ACTIONS(3153),
    [anon_sym_ascending] = ACTIONS(3153),
    [anon_sym_descending] = ACTIONS(3153),
    [anon_sym_group] = ACTIONS(3153),
    [anon_sym_by] = ACTIONS(3153),
    [anon_sym_select] = ACTIONS(3153),
    [anon_sym_stackalloc] = ACTIONS(3153),
    [anon_sym_sizeof] = ACTIONS(3153),
    [anon_sym_typeof] = ACTIONS(3153),
    [anon_sym___makeref] = ACTIONS(3153),
    [anon_sym___reftype] = ACTIONS(3153),
    [anon_sym___refvalue] = ACTIONS(3153),
    [sym_null_literal] = ACTIONS(3153),
    [anon_sym_SQUOTE] = ACTIONS(3155),
    [sym_integer_literal] = ACTIONS(3153),
    [sym_real_literal] = ACTIONS(3155),
    [anon_sym_DQUOTE] = ACTIONS(3155),
    [sym_verbatim_string_literal] = ACTIONS(3155),
    [aux_sym_preproc_if_token1] = ACTIONS(3155),
    [aux_sym_preproc_if_token3] = ACTIONS(3155),
    [aux_sym_preproc_else_token1] = ACTIONS(3155),
    [aux_sym_preproc_elif_token1] = ACTIONS(3155),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3155),
    [sym_interpolation_verbatim_start] = ACTIONS(3155),
    [sym_interpolation_raw_start] = ACTIONS(3155),
    [sym_raw_string_start] = ACTIONS(3155),
  },
  [2248] = {
    [sym_preproc_region] = STATE(2248),
    [sym_preproc_endregion] = STATE(2248),
    [sym_preproc_line] = STATE(2248),
    [sym_preproc_pragma] = STATE(2248),
    [sym_preproc_nullable] = STATE(2248),
    [sym_preproc_error] = STATE(2248),
    [sym_preproc_warning] = STATE(2248),
    [sym_preproc_define] = STATE(2248),
    [sym_preproc_undef] = STATE(2248),
    [sym__identifier_token] = ACTIONS(3157),
    [anon_sym_extern] = ACTIONS(3157),
    [anon_sym_alias] = ACTIONS(3157),
    [anon_sym_SEMI] = ACTIONS(3159),
    [anon_sym_global] = ACTIONS(3157),
    [anon_sym_using] = ACTIONS(3157),
    [anon_sym_unsafe] = ACTIONS(3157),
    [anon_sym_static] = ACTIONS(3157),
    [anon_sym_LBRACK] = ACTIONS(3159),
    [anon_sym_LPAREN] = ACTIONS(3159),
    [anon_sym_return] = ACTIONS(3157),
    [anon_sym_namespace] = ACTIONS(3157),
    [anon_sym_class] = ACTIONS(3157),
    [anon_sym_ref] = ACTIONS(3157),
    [anon_sym_struct] = ACTIONS(3157),
    [anon_sym_enum] = ACTIONS(3157),
    [anon_sym_LBRACE] = ACTIONS(3159),
    [anon_sym_interface] = ACTIONS(3157),
    [anon_sym_delegate] = ACTIONS(3157),
    [anon_sym_record] = ACTIONS(3157),
    [anon_sym_abstract] = ACTIONS(3157),
    [anon_sym_async] = ACTIONS(3157),
    [anon_sym_const] = ACTIONS(3157),
    [anon_sym_file] = ACTIONS(3157),
    [anon_sym_fixed] = ACTIONS(3157),
    [anon_sym_internal] = ACTIONS(3157),
    [anon_sym_new] = ACTIONS(3157),
    [anon_sym_override] = ACTIONS(3157),
    [anon_sym_partial] = ACTIONS(3157),
    [anon_sym_private] = ACTIONS(3157),
    [anon_sym_protected] = ACTIONS(3157),
    [anon_sym_public] = ACTIONS(3157),
    [anon_sym_readonly] = ACTIONS(3157),
    [anon_sym_required] = ACTIONS(3157),
    [anon_sym_sealed] = ACTIONS(3157),
    [anon_sym_virtual] = ACTIONS(3157),
    [anon_sym_volatile] = ACTIONS(3157),
    [anon_sym_where] = ACTIONS(3157),
    [anon_sym_notnull] = ACTIONS(3157),
    [anon_sym_unmanaged] = ACTIONS(3157),
    [anon_sym_checked] = ACTIONS(3157),
    [anon_sym_BANG] = ACTIONS(3159),
    [anon_sym_TILDE] = ACTIONS(3159),
    [anon_sym_PLUS_PLUS] = ACTIONS(3159),
    [anon_sym_DASH_DASH] = ACTIONS(3159),
    [anon_sym_true] = ACTIONS(3157),
    [anon_sym_false] = ACTIONS(3157),
    [anon_sym_PLUS] = ACTIONS(3157),
    [anon_sym_DASH] = ACTIONS(3157),
    [anon_sym_STAR] = ACTIONS(3159),
    [anon_sym_CARET] = ACTIONS(3159),
    [anon_sym_AMP] = ACTIONS(3159),
    [anon_sym_this] = ACTIONS(3157),
    [anon_sym_scoped] = ACTIONS(3157),
    [anon_sym_base] = ACTIONS(3157),
    [anon_sym_var] = ACTIONS(3157),
    [sym_predefined_type] = ACTIONS(3157),
    [anon_sym_break] = ACTIONS(3157),
    [anon_sym_unchecked] = ACTIONS(3157),
    [anon_sym_continue] = ACTIONS(3157),
    [anon_sym_do] = ACTIONS(3157),
    [anon_sym_while] = ACTIONS(3157),
    [anon_sym_for] = ACTIONS(3157),
    [anon_sym_lock] = ACTIONS(3157),
    [anon_sym_yield] = ACTIONS(3157),
    [anon_sym_switch] = ACTIONS(3157),
    [anon_sym_default] = ACTIONS(3157),
    [anon_sym_throw] = ACTIONS(3157),
    [anon_sym_try] = ACTIONS(3157),
    [anon_sym_when] = ACTIONS(3157),
    [anon_sym_await] = ACTIONS(3157),
    [anon_sym_foreach] = ACTIONS(3157),
    [anon_sym_goto] = ACTIONS(3157),
    [anon_sym_if] = ACTIONS(3157),
    [anon_sym_else] = ACTIONS(3157),
    [anon_sym_DOT_DOT] = ACTIONS(3159),
    [anon_sym_from] = ACTIONS(3157),
    [anon_sym_into] = ACTIONS(3157),
    [anon_sym_join] = ACTIONS(3157),
    [anon_sym_on] = ACTIONS(3157),
    [anon_sym_equals] = ACTIONS(3157),
    [anon_sym_let] = ACTIONS(3157),
    [anon_sym_orderby] = ACTIONS(3157),
    [anon_sym_ascending] = ACTIONS(3157),
    [anon_sym_descending] = ACTIONS(3157),
    [anon_sym_group] = ACTIONS(3157),
    [anon_sym_by] = ACTIONS(3157),
    [anon_sym_select] = ACTIONS(3157),
    [anon_sym_stackalloc] = ACTIONS(3157),
    [anon_sym_sizeof] = ACTIONS(3157),
    [anon_sym_typeof] = ACTIONS(3157),
    [anon_sym___makeref] = ACTIONS(3157),
    [anon_sym___reftype] = ACTIONS(3157),
    [anon_sym___refvalue] = ACTIONS(3157),
    [sym_null_literal] = ACTIONS(3157),
    [anon_sym_SQUOTE] = ACTIONS(3159),
    [sym_integer_literal] = ACTIONS(3157),
    [sym_real_literal] = ACTIONS(3159),
    [anon_sym_DQUOTE] = ACTIONS(3159),
    [sym_verbatim_string_literal] = ACTIONS(3159),
    [aux_sym_preproc_if_token1] = ACTIONS(3159),
    [aux_sym_preproc_if_token3] = ACTIONS(3159),
    [aux_sym_preproc_else_token1] = ACTIONS(3159),
    [aux_sym_preproc_elif_token1] = ACTIONS(3159),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3159),
    [sym_interpolation_verbatim_start] = ACTIONS(3159),
    [sym_interpolation_raw_start] = ACTIONS(3159),
    [sym_raw_string_start] = ACTIONS(3159),
  },
  [2249] = {
    [sym_preproc_region] = STATE(2249),
    [sym_preproc_endregion] = STATE(2249),
    [sym_preproc_line] = STATE(2249),
    [sym_preproc_pragma] = STATE(2249),
    [sym_preproc_nullable] = STATE(2249),
    [sym_preproc_error] = STATE(2249),
    [sym_preproc_warning] = STATE(2249),
    [sym_preproc_define] = STATE(2249),
    [sym_preproc_undef] = STATE(2249),
    [sym__identifier_token] = ACTIONS(3161),
    [anon_sym_extern] = ACTIONS(3161),
    [anon_sym_alias] = ACTIONS(3161),
    [anon_sym_SEMI] = ACTIONS(3163),
    [anon_sym_global] = ACTIONS(3161),
    [anon_sym_using] = ACTIONS(3161),
    [anon_sym_unsafe] = ACTIONS(3161),
    [anon_sym_static] = ACTIONS(3161),
    [anon_sym_LBRACK] = ACTIONS(3163),
    [anon_sym_LPAREN] = ACTIONS(3163),
    [anon_sym_return] = ACTIONS(3161),
    [anon_sym_namespace] = ACTIONS(3161),
    [anon_sym_class] = ACTIONS(3161),
    [anon_sym_ref] = ACTIONS(3161),
    [anon_sym_struct] = ACTIONS(3161),
    [anon_sym_enum] = ACTIONS(3161),
    [anon_sym_LBRACE] = ACTIONS(3163),
    [anon_sym_interface] = ACTIONS(3161),
    [anon_sym_delegate] = ACTIONS(3161),
    [anon_sym_record] = ACTIONS(3161),
    [anon_sym_abstract] = ACTIONS(3161),
    [anon_sym_async] = ACTIONS(3161),
    [anon_sym_const] = ACTIONS(3161),
    [anon_sym_file] = ACTIONS(3161),
    [anon_sym_fixed] = ACTIONS(3161),
    [anon_sym_internal] = ACTIONS(3161),
    [anon_sym_new] = ACTIONS(3161),
    [anon_sym_override] = ACTIONS(3161),
    [anon_sym_partial] = ACTIONS(3161),
    [anon_sym_private] = ACTIONS(3161),
    [anon_sym_protected] = ACTIONS(3161),
    [anon_sym_public] = ACTIONS(3161),
    [anon_sym_readonly] = ACTIONS(3161),
    [anon_sym_required] = ACTIONS(3161),
    [anon_sym_sealed] = ACTIONS(3161),
    [anon_sym_virtual] = ACTIONS(3161),
    [anon_sym_volatile] = ACTIONS(3161),
    [anon_sym_where] = ACTIONS(3161),
    [anon_sym_notnull] = ACTIONS(3161),
    [anon_sym_unmanaged] = ACTIONS(3161),
    [anon_sym_checked] = ACTIONS(3161),
    [anon_sym_BANG] = ACTIONS(3163),
    [anon_sym_TILDE] = ACTIONS(3163),
    [anon_sym_PLUS_PLUS] = ACTIONS(3163),
    [anon_sym_DASH_DASH] = ACTIONS(3163),
    [anon_sym_true] = ACTIONS(3161),
    [anon_sym_false] = ACTIONS(3161),
    [anon_sym_PLUS] = ACTIONS(3161),
    [anon_sym_DASH] = ACTIONS(3161),
    [anon_sym_STAR] = ACTIONS(3163),
    [anon_sym_CARET] = ACTIONS(3163),
    [anon_sym_AMP] = ACTIONS(3163),
    [anon_sym_this] = ACTIONS(3161),
    [anon_sym_scoped] = ACTIONS(3161),
    [anon_sym_base] = ACTIONS(3161),
    [anon_sym_var] = ACTIONS(3161),
    [sym_predefined_type] = ACTIONS(3161),
    [anon_sym_break] = ACTIONS(3161),
    [anon_sym_unchecked] = ACTIONS(3161),
    [anon_sym_continue] = ACTIONS(3161),
    [anon_sym_do] = ACTIONS(3161),
    [anon_sym_while] = ACTIONS(3161),
    [anon_sym_for] = ACTIONS(3161),
    [anon_sym_lock] = ACTIONS(3161),
    [anon_sym_yield] = ACTIONS(3161),
    [anon_sym_switch] = ACTIONS(3161),
    [anon_sym_default] = ACTIONS(3161),
    [anon_sym_throw] = ACTIONS(3161),
    [anon_sym_try] = ACTIONS(3161),
    [anon_sym_when] = ACTIONS(3161),
    [anon_sym_await] = ACTIONS(3161),
    [anon_sym_foreach] = ACTIONS(3161),
    [anon_sym_goto] = ACTIONS(3161),
    [anon_sym_if] = ACTIONS(3161),
    [anon_sym_else] = ACTIONS(3161),
    [anon_sym_DOT_DOT] = ACTIONS(3163),
    [anon_sym_from] = ACTIONS(3161),
    [anon_sym_into] = ACTIONS(3161),
    [anon_sym_join] = ACTIONS(3161),
    [anon_sym_on] = ACTIONS(3161),
    [anon_sym_equals] = ACTIONS(3161),
    [anon_sym_let] = ACTIONS(3161),
    [anon_sym_orderby] = ACTIONS(3161),
    [anon_sym_ascending] = ACTIONS(3161),
    [anon_sym_descending] = ACTIONS(3161),
    [anon_sym_group] = ACTIONS(3161),
    [anon_sym_by] = ACTIONS(3161),
    [anon_sym_select] = ACTIONS(3161),
    [anon_sym_stackalloc] = ACTIONS(3161),
    [anon_sym_sizeof] = ACTIONS(3161),
    [anon_sym_typeof] = ACTIONS(3161),
    [anon_sym___makeref] = ACTIONS(3161),
    [anon_sym___reftype] = ACTIONS(3161),
    [anon_sym___refvalue] = ACTIONS(3161),
    [sym_null_literal] = ACTIONS(3161),
    [anon_sym_SQUOTE] = ACTIONS(3163),
    [sym_integer_literal] = ACTIONS(3161),
    [sym_real_literal] = ACTIONS(3163),
    [anon_sym_DQUOTE] = ACTIONS(3163),
    [sym_verbatim_string_literal] = ACTIONS(3163),
    [aux_sym_preproc_if_token1] = ACTIONS(3163),
    [aux_sym_preproc_if_token3] = ACTIONS(3163),
    [aux_sym_preproc_else_token1] = ACTIONS(3163),
    [aux_sym_preproc_elif_token1] = ACTIONS(3163),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3163),
    [sym_interpolation_verbatim_start] = ACTIONS(3163),
    [sym_interpolation_raw_start] = ACTIONS(3163),
    [sym_raw_string_start] = ACTIONS(3163),
  },
  [2250] = {
    [sym_preproc_region] = STATE(2250),
    [sym_preproc_endregion] = STATE(2250),
    [sym_preproc_line] = STATE(2250),
    [sym_preproc_pragma] = STATE(2250),
    [sym_preproc_nullable] = STATE(2250),
    [sym_preproc_error] = STATE(2250),
    [sym_preproc_warning] = STATE(2250),
    [sym_preproc_define] = STATE(2250),
    [sym_preproc_undef] = STATE(2250),
    [sym__identifier_token] = ACTIONS(3165),
    [anon_sym_extern] = ACTIONS(3165),
    [anon_sym_alias] = ACTIONS(3165),
    [anon_sym_SEMI] = ACTIONS(3167),
    [anon_sym_global] = ACTIONS(3165),
    [anon_sym_using] = ACTIONS(3165),
    [anon_sym_unsafe] = ACTIONS(3165),
    [anon_sym_static] = ACTIONS(3165),
    [anon_sym_LBRACK] = ACTIONS(3167),
    [anon_sym_LPAREN] = ACTIONS(3167),
    [anon_sym_return] = ACTIONS(3165),
    [anon_sym_namespace] = ACTIONS(3165),
    [anon_sym_class] = ACTIONS(3165),
    [anon_sym_ref] = ACTIONS(3165),
    [anon_sym_struct] = ACTIONS(3165),
    [anon_sym_enum] = ACTIONS(3165),
    [anon_sym_LBRACE] = ACTIONS(3167),
    [anon_sym_interface] = ACTIONS(3165),
    [anon_sym_delegate] = ACTIONS(3165),
    [anon_sym_record] = ACTIONS(3165),
    [anon_sym_abstract] = ACTIONS(3165),
    [anon_sym_async] = ACTIONS(3165),
    [anon_sym_const] = ACTIONS(3165),
    [anon_sym_file] = ACTIONS(3165),
    [anon_sym_fixed] = ACTIONS(3165),
    [anon_sym_internal] = ACTIONS(3165),
    [anon_sym_new] = ACTIONS(3165),
    [anon_sym_override] = ACTIONS(3165),
    [anon_sym_partial] = ACTIONS(3165),
    [anon_sym_private] = ACTIONS(3165),
    [anon_sym_protected] = ACTIONS(3165),
    [anon_sym_public] = ACTIONS(3165),
    [anon_sym_readonly] = ACTIONS(3165),
    [anon_sym_required] = ACTIONS(3165),
    [anon_sym_sealed] = ACTIONS(3165),
    [anon_sym_virtual] = ACTIONS(3165),
    [anon_sym_volatile] = ACTIONS(3165),
    [anon_sym_where] = ACTIONS(3165),
    [anon_sym_notnull] = ACTIONS(3165),
    [anon_sym_unmanaged] = ACTIONS(3165),
    [anon_sym_checked] = ACTIONS(3165),
    [anon_sym_BANG] = ACTIONS(3167),
    [anon_sym_TILDE] = ACTIONS(3167),
    [anon_sym_PLUS_PLUS] = ACTIONS(3167),
    [anon_sym_DASH_DASH] = ACTIONS(3167),
    [anon_sym_true] = ACTIONS(3165),
    [anon_sym_false] = ACTIONS(3165),
    [anon_sym_PLUS] = ACTIONS(3165),
    [anon_sym_DASH] = ACTIONS(3165),
    [anon_sym_STAR] = ACTIONS(3167),
    [anon_sym_CARET] = ACTIONS(3167),
    [anon_sym_AMP] = ACTIONS(3167),
    [anon_sym_this] = ACTIONS(3165),
    [anon_sym_scoped] = ACTIONS(3165),
    [anon_sym_base] = ACTIONS(3165),
    [anon_sym_var] = ACTIONS(3165),
    [sym_predefined_type] = ACTIONS(3165),
    [anon_sym_break] = ACTIONS(3165),
    [anon_sym_unchecked] = ACTIONS(3165),
    [anon_sym_continue] = ACTIONS(3165),
    [anon_sym_do] = ACTIONS(3165),
    [anon_sym_while] = ACTIONS(3165),
    [anon_sym_for] = ACTIONS(3165),
    [anon_sym_lock] = ACTIONS(3165),
    [anon_sym_yield] = ACTIONS(3165),
    [anon_sym_switch] = ACTIONS(3165),
    [anon_sym_default] = ACTIONS(3165),
    [anon_sym_throw] = ACTIONS(3165),
    [anon_sym_try] = ACTIONS(3165),
    [anon_sym_when] = ACTIONS(3165),
    [anon_sym_await] = ACTIONS(3165),
    [anon_sym_foreach] = ACTIONS(3165),
    [anon_sym_goto] = ACTIONS(3165),
    [anon_sym_if] = ACTIONS(3165),
    [anon_sym_else] = ACTIONS(3165),
    [anon_sym_DOT_DOT] = ACTIONS(3167),
    [anon_sym_from] = ACTIONS(3165),
    [anon_sym_into] = ACTIONS(3165),
    [anon_sym_join] = ACTIONS(3165),
    [anon_sym_on] = ACTIONS(3165),
    [anon_sym_equals] = ACTIONS(3165),
    [anon_sym_let] = ACTIONS(3165),
    [anon_sym_orderby] = ACTIONS(3165),
    [anon_sym_ascending] = ACTIONS(3165),
    [anon_sym_descending] = ACTIONS(3165),
    [anon_sym_group] = ACTIONS(3165),
    [anon_sym_by] = ACTIONS(3165),
    [anon_sym_select] = ACTIONS(3165),
    [anon_sym_stackalloc] = ACTIONS(3165),
    [anon_sym_sizeof] = ACTIONS(3165),
    [anon_sym_typeof] = ACTIONS(3165),
    [anon_sym___makeref] = ACTIONS(3165),
    [anon_sym___reftype] = ACTIONS(3165),
    [anon_sym___refvalue] = ACTIONS(3165),
    [sym_null_literal] = ACTIONS(3165),
    [anon_sym_SQUOTE] = ACTIONS(3167),
    [sym_integer_literal] = ACTIONS(3165),
    [sym_real_literal] = ACTIONS(3167),
    [anon_sym_DQUOTE] = ACTIONS(3167),
    [sym_verbatim_string_literal] = ACTIONS(3167),
    [aux_sym_preproc_if_token1] = ACTIONS(3167),
    [aux_sym_preproc_if_token3] = ACTIONS(3167),
    [aux_sym_preproc_else_token1] = ACTIONS(3167),
    [aux_sym_preproc_elif_token1] = ACTIONS(3167),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3167),
    [sym_interpolation_verbatim_start] = ACTIONS(3167),
    [sym_interpolation_raw_start] = ACTIONS(3167),
    [sym_raw_string_start] = ACTIONS(3167),
  },
  [2251] = {
    [sym_preproc_region] = STATE(2251),
    [sym_preproc_endregion] = STATE(2251),
    [sym_preproc_line] = STATE(2251),
    [sym_preproc_pragma] = STATE(2251),
    [sym_preproc_nullable] = STATE(2251),
    [sym_preproc_error] = STATE(2251),
    [sym_preproc_warning] = STATE(2251),
    [sym_preproc_define] = STATE(2251),
    [sym_preproc_undef] = STATE(2251),
    [sym__identifier_token] = ACTIONS(3169),
    [anon_sym_extern] = ACTIONS(3169),
    [anon_sym_alias] = ACTIONS(3169),
    [anon_sym_SEMI] = ACTIONS(3171),
    [anon_sym_global] = ACTIONS(3169),
    [anon_sym_using] = ACTIONS(3169),
    [anon_sym_unsafe] = ACTIONS(3169),
    [anon_sym_static] = ACTIONS(3169),
    [anon_sym_LBRACK] = ACTIONS(3171),
    [anon_sym_LPAREN] = ACTIONS(3171),
    [anon_sym_return] = ACTIONS(3169),
    [anon_sym_namespace] = ACTIONS(3169),
    [anon_sym_class] = ACTIONS(3169),
    [anon_sym_ref] = ACTIONS(3169),
    [anon_sym_struct] = ACTIONS(3169),
    [anon_sym_enum] = ACTIONS(3169),
    [anon_sym_LBRACE] = ACTIONS(3171),
    [anon_sym_interface] = ACTIONS(3169),
    [anon_sym_delegate] = ACTIONS(3169),
    [anon_sym_record] = ACTIONS(3169),
    [anon_sym_abstract] = ACTIONS(3169),
    [anon_sym_async] = ACTIONS(3169),
    [anon_sym_const] = ACTIONS(3169),
    [anon_sym_file] = ACTIONS(3169),
    [anon_sym_fixed] = ACTIONS(3169),
    [anon_sym_internal] = ACTIONS(3169),
    [anon_sym_new] = ACTIONS(3169),
    [anon_sym_override] = ACTIONS(3169),
    [anon_sym_partial] = ACTIONS(3169),
    [anon_sym_private] = ACTIONS(3169),
    [anon_sym_protected] = ACTIONS(3169),
    [anon_sym_public] = ACTIONS(3169),
    [anon_sym_readonly] = ACTIONS(3169),
    [anon_sym_required] = ACTIONS(3169),
    [anon_sym_sealed] = ACTIONS(3169),
    [anon_sym_virtual] = ACTIONS(3169),
    [anon_sym_volatile] = ACTIONS(3169),
    [anon_sym_where] = ACTIONS(3169),
    [anon_sym_notnull] = ACTIONS(3169),
    [anon_sym_unmanaged] = ACTIONS(3169),
    [anon_sym_checked] = ACTIONS(3169),
    [anon_sym_BANG] = ACTIONS(3171),
    [anon_sym_TILDE] = ACTIONS(3171),
    [anon_sym_PLUS_PLUS] = ACTIONS(3171),
    [anon_sym_DASH_DASH] = ACTIONS(3171),
    [anon_sym_true] = ACTIONS(3169),
    [anon_sym_false] = ACTIONS(3169),
    [anon_sym_PLUS] = ACTIONS(3169),
    [anon_sym_DASH] = ACTIONS(3169),
    [anon_sym_STAR] = ACTIONS(3171),
    [anon_sym_CARET] = ACTIONS(3171),
    [anon_sym_AMP] = ACTIONS(3171),
    [anon_sym_this] = ACTIONS(3169),
    [anon_sym_scoped] = ACTIONS(3169),
    [anon_sym_base] = ACTIONS(3169),
    [anon_sym_var] = ACTIONS(3169),
    [sym_predefined_type] = ACTIONS(3169),
    [anon_sym_break] = ACTIONS(3169),
    [anon_sym_unchecked] = ACTIONS(3169),
    [anon_sym_continue] = ACTIONS(3169),
    [anon_sym_do] = ACTIONS(3169),
    [anon_sym_while] = ACTIONS(3169),
    [anon_sym_for] = ACTIONS(3169),
    [anon_sym_lock] = ACTIONS(3169),
    [anon_sym_yield] = ACTIONS(3169),
    [anon_sym_switch] = ACTIONS(3169),
    [anon_sym_default] = ACTIONS(3169),
    [anon_sym_throw] = ACTIONS(3169),
    [anon_sym_try] = ACTIONS(3169),
    [anon_sym_when] = ACTIONS(3169),
    [anon_sym_await] = ACTIONS(3169),
    [anon_sym_foreach] = ACTIONS(3169),
    [anon_sym_goto] = ACTIONS(3169),
    [anon_sym_if] = ACTIONS(3169),
    [anon_sym_else] = ACTIONS(3169),
    [anon_sym_DOT_DOT] = ACTIONS(3171),
    [anon_sym_from] = ACTIONS(3169),
    [anon_sym_into] = ACTIONS(3169),
    [anon_sym_join] = ACTIONS(3169),
    [anon_sym_on] = ACTIONS(3169),
    [anon_sym_equals] = ACTIONS(3169),
    [anon_sym_let] = ACTIONS(3169),
    [anon_sym_orderby] = ACTIONS(3169),
    [anon_sym_ascending] = ACTIONS(3169),
    [anon_sym_descending] = ACTIONS(3169),
    [anon_sym_group] = ACTIONS(3169),
    [anon_sym_by] = ACTIONS(3169),
    [anon_sym_select] = ACTIONS(3169),
    [anon_sym_stackalloc] = ACTIONS(3169),
    [anon_sym_sizeof] = ACTIONS(3169),
    [anon_sym_typeof] = ACTIONS(3169),
    [anon_sym___makeref] = ACTIONS(3169),
    [anon_sym___reftype] = ACTIONS(3169),
    [anon_sym___refvalue] = ACTIONS(3169),
    [sym_null_literal] = ACTIONS(3169),
    [anon_sym_SQUOTE] = ACTIONS(3171),
    [sym_integer_literal] = ACTIONS(3169),
    [sym_real_literal] = ACTIONS(3171),
    [anon_sym_DQUOTE] = ACTIONS(3171),
    [sym_verbatim_string_literal] = ACTIONS(3171),
    [aux_sym_preproc_if_token1] = ACTIONS(3171),
    [aux_sym_preproc_if_token3] = ACTIONS(3171),
    [aux_sym_preproc_else_token1] = ACTIONS(3171),
    [aux_sym_preproc_elif_token1] = ACTIONS(3171),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3171),
    [sym_interpolation_verbatim_start] = ACTIONS(3171),
    [sym_interpolation_raw_start] = ACTIONS(3171),
    [sym_raw_string_start] = ACTIONS(3171),
  },
  [2252] = {
    [sym_preproc_region] = STATE(2252),
    [sym_preproc_endregion] = STATE(2252),
    [sym_preproc_line] = STATE(2252),
    [sym_preproc_pragma] = STATE(2252),
    [sym_preproc_nullable] = STATE(2252),
    [sym_preproc_error] = STATE(2252),
    [sym_preproc_warning] = STATE(2252),
    [sym_preproc_define] = STATE(2252),
    [sym_preproc_undef] = STATE(2252),
    [sym__identifier_token] = ACTIONS(3173),
    [anon_sym_extern] = ACTIONS(3173),
    [anon_sym_alias] = ACTIONS(3173),
    [anon_sym_SEMI] = ACTIONS(3175),
    [anon_sym_global] = ACTIONS(3173),
    [anon_sym_using] = ACTIONS(3173),
    [anon_sym_unsafe] = ACTIONS(3173),
    [anon_sym_static] = ACTIONS(3173),
    [anon_sym_LBRACK] = ACTIONS(3175),
    [anon_sym_LPAREN] = ACTIONS(3175),
    [anon_sym_return] = ACTIONS(3173),
    [anon_sym_namespace] = ACTIONS(3173),
    [anon_sym_class] = ACTIONS(3173),
    [anon_sym_ref] = ACTIONS(3173),
    [anon_sym_struct] = ACTIONS(3173),
    [anon_sym_enum] = ACTIONS(3173),
    [anon_sym_LBRACE] = ACTIONS(3175),
    [anon_sym_interface] = ACTIONS(3173),
    [anon_sym_delegate] = ACTIONS(3173),
    [anon_sym_record] = ACTIONS(3173),
    [anon_sym_abstract] = ACTIONS(3173),
    [anon_sym_async] = ACTIONS(3173),
    [anon_sym_const] = ACTIONS(3173),
    [anon_sym_file] = ACTIONS(3173),
    [anon_sym_fixed] = ACTIONS(3173),
    [anon_sym_internal] = ACTIONS(3173),
    [anon_sym_new] = ACTIONS(3173),
    [anon_sym_override] = ACTIONS(3173),
    [anon_sym_partial] = ACTIONS(3173),
    [anon_sym_private] = ACTIONS(3173),
    [anon_sym_protected] = ACTIONS(3173),
    [anon_sym_public] = ACTIONS(3173),
    [anon_sym_readonly] = ACTIONS(3173),
    [anon_sym_required] = ACTIONS(3173),
    [anon_sym_sealed] = ACTIONS(3173),
    [anon_sym_virtual] = ACTIONS(3173),
    [anon_sym_volatile] = ACTIONS(3173),
    [anon_sym_where] = ACTIONS(3173),
    [anon_sym_notnull] = ACTIONS(3173),
    [anon_sym_unmanaged] = ACTIONS(3173),
    [anon_sym_checked] = ACTIONS(3173),
    [anon_sym_BANG] = ACTIONS(3175),
    [anon_sym_TILDE] = ACTIONS(3175),
    [anon_sym_PLUS_PLUS] = ACTIONS(3175),
    [anon_sym_DASH_DASH] = ACTIONS(3175),
    [anon_sym_true] = ACTIONS(3173),
    [anon_sym_false] = ACTIONS(3173),
    [anon_sym_PLUS] = ACTIONS(3173),
    [anon_sym_DASH] = ACTIONS(3173),
    [anon_sym_STAR] = ACTIONS(3175),
    [anon_sym_CARET] = ACTIONS(3175),
    [anon_sym_AMP] = ACTIONS(3175),
    [anon_sym_this] = ACTIONS(3173),
    [anon_sym_scoped] = ACTIONS(3173),
    [anon_sym_base] = ACTIONS(3173),
    [anon_sym_var] = ACTIONS(3173),
    [sym_predefined_type] = ACTIONS(3173),
    [anon_sym_break] = ACTIONS(3173),
    [anon_sym_unchecked] = ACTIONS(3173),
    [anon_sym_continue] = ACTIONS(3173),
    [anon_sym_do] = ACTIONS(3173),
    [anon_sym_while] = ACTIONS(3173),
    [anon_sym_for] = ACTIONS(3173),
    [anon_sym_lock] = ACTIONS(3173),
    [anon_sym_yield] = ACTIONS(3173),
    [anon_sym_switch] = ACTIONS(3173),
    [anon_sym_default] = ACTIONS(3173),
    [anon_sym_throw] = ACTIONS(3173),
    [anon_sym_try] = ACTIONS(3173),
    [anon_sym_when] = ACTIONS(3173),
    [anon_sym_await] = ACTIONS(3173),
    [anon_sym_foreach] = ACTIONS(3173),
    [anon_sym_goto] = ACTIONS(3173),
    [anon_sym_if] = ACTIONS(3173),
    [anon_sym_else] = ACTIONS(3173),
    [anon_sym_DOT_DOT] = ACTIONS(3175),
    [anon_sym_from] = ACTIONS(3173),
    [anon_sym_into] = ACTIONS(3173),
    [anon_sym_join] = ACTIONS(3173),
    [anon_sym_on] = ACTIONS(3173),
    [anon_sym_equals] = ACTIONS(3173),
    [anon_sym_let] = ACTIONS(3173),
    [anon_sym_orderby] = ACTIONS(3173),
    [anon_sym_ascending] = ACTIONS(3173),
    [anon_sym_descending] = ACTIONS(3173),
    [anon_sym_group] = ACTIONS(3173),
    [anon_sym_by] = ACTIONS(3173),
    [anon_sym_select] = ACTIONS(3173),
    [anon_sym_stackalloc] = ACTIONS(3173),
    [anon_sym_sizeof] = ACTIONS(3173),
    [anon_sym_typeof] = ACTIONS(3173),
    [anon_sym___makeref] = ACTIONS(3173),
    [anon_sym___reftype] = ACTIONS(3173),
    [anon_sym___refvalue] = ACTIONS(3173),
    [sym_null_literal] = ACTIONS(3173),
    [anon_sym_SQUOTE] = ACTIONS(3175),
    [sym_integer_literal] = ACTIONS(3173),
    [sym_real_literal] = ACTIONS(3175),
    [anon_sym_DQUOTE] = ACTIONS(3175),
    [sym_verbatim_string_literal] = ACTIONS(3175),
    [aux_sym_preproc_if_token1] = ACTIONS(3175),
    [aux_sym_preproc_if_token3] = ACTIONS(3175),
    [aux_sym_preproc_else_token1] = ACTIONS(3175),
    [aux_sym_preproc_elif_token1] = ACTIONS(3175),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3175),
    [sym_interpolation_verbatim_start] = ACTIONS(3175),
    [sym_interpolation_raw_start] = ACTIONS(3175),
    [sym_raw_string_start] = ACTIONS(3175),
  },
  [2253] = {
    [sym_preproc_region] = STATE(2253),
    [sym_preproc_endregion] = STATE(2253),
    [sym_preproc_line] = STATE(2253),
    [sym_preproc_pragma] = STATE(2253),
    [sym_preproc_nullable] = STATE(2253),
    [sym_preproc_error] = STATE(2253),
    [sym_preproc_warning] = STATE(2253),
    [sym_preproc_define] = STATE(2253),
    [sym_preproc_undef] = STATE(2253),
    [sym__identifier_token] = ACTIONS(3177),
    [anon_sym_extern] = ACTIONS(3177),
    [anon_sym_alias] = ACTIONS(3177),
    [anon_sym_SEMI] = ACTIONS(3179),
    [anon_sym_global] = ACTIONS(3177),
    [anon_sym_using] = ACTIONS(3177),
    [anon_sym_unsafe] = ACTIONS(3177),
    [anon_sym_static] = ACTIONS(3177),
    [anon_sym_LBRACK] = ACTIONS(3179),
    [anon_sym_LPAREN] = ACTIONS(3179),
    [anon_sym_return] = ACTIONS(3177),
    [anon_sym_namespace] = ACTIONS(3177),
    [anon_sym_class] = ACTIONS(3177),
    [anon_sym_ref] = ACTIONS(3177),
    [anon_sym_struct] = ACTIONS(3177),
    [anon_sym_enum] = ACTIONS(3177),
    [anon_sym_LBRACE] = ACTIONS(3179),
    [anon_sym_interface] = ACTIONS(3177),
    [anon_sym_delegate] = ACTIONS(3177),
    [anon_sym_record] = ACTIONS(3177),
    [anon_sym_abstract] = ACTIONS(3177),
    [anon_sym_async] = ACTIONS(3177),
    [anon_sym_const] = ACTIONS(3177),
    [anon_sym_file] = ACTIONS(3177),
    [anon_sym_fixed] = ACTIONS(3177),
    [anon_sym_internal] = ACTIONS(3177),
    [anon_sym_new] = ACTIONS(3177),
    [anon_sym_override] = ACTIONS(3177),
    [anon_sym_partial] = ACTIONS(3177),
    [anon_sym_private] = ACTIONS(3177),
    [anon_sym_protected] = ACTIONS(3177),
    [anon_sym_public] = ACTIONS(3177),
    [anon_sym_readonly] = ACTIONS(3177),
    [anon_sym_required] = ACTIONS(3177),
    [anon_sym_sealed] = ACTIONS(3177),
    [anon_sym_virtual] = ACTIONS(3177),
    [anon_sym_volatile] = ACTIONS(3177),
    [anon_sym_where] = ACTIONS(3177),
    [anon_sym_notnull] = ACTIONS(3177),
    [anon_sym_unmanaged] = ACTIONS(3177),
    [anon_sym_checked] = ACTIONS(3177),
    [anon_sym_BANG] = ACTIONS(3179),
    [anon_sym_TILDE] = ACTIONS(3179),
    [anon_sym_PLUS_PLUS] = ACTIONS(3179),
    [anon_sym_DASH_DASH] = ACTIONS(3179),
    [anon_sym_true] = ACTIONS(3177),
    [anon_sym_false] = ACTIONS(3177),
    [anon_sym_PLUS] = ACTIONS(3177),
    [anon_sym_DASH] = ACTIONS(3177),
    [anon_sym_STAR] = ACTIONS(3179),
    [anon_sym_CARET] = ACTIONS(3179),
    [anon_sym_AMP] = ACTIONS(3179),
    [anon_sym_this] = ACTIONS(3177),
    [anon_sym_scoped] = ACTIONS(3177),
    [anon_sym_base] = ACTIONS(3177),
    [anon_sym_var] = ACTIONS(3177),
    [sym_predefined_type] = ACTIONS(3177),
    [anon_sym_break] = ACTIONS(3177),
    [anon_sym_unchecked] = ACTIONS(3177),
    [anon_sym_continue] = ACTIONS(3177),
    [anon_sym_do] = ACTIONS(3177),
    [anon_sym_while] = ACTIONS(3177),
    [anon_sym_for] = ACTIONS(3177),
    [anon_sym_lock] = ACTIONS(3177),
    [anon_sym_yield] = ACTIONS(3177),
    [anon_sym_switch] = ACTIONS(3177),
    [anon_sym_default] = ACTIONS(3177),
    [anon_sym_throw] = ACTIONS(3177),
    [anon_sym_try] = ACTIONS(3177),
    [anon_sym_when] = ACTIONS(3177),
    [anon_sym_await] = ACTIONS(3177),
    [anon_sym_foreach] = ACTIONS(3177),
    [anon_sym_goto] = ACTIONS(3177),
    [anon_sym_if] = ACTIONS(3177),
    [anon_sym_else] = ACTIONS(3177),
    [anon_sym_DOT_DOT] = ACTIONS(3179),
    [anon_sym_from] = ACTIONS(3177),
    [anon_sym_into] = ACTIONS(3177),
    [anon_sym_join] = ACTIONS(3177),
    [anon_sym_on] = ACTIONS(3177),
    [anon_sym_equals] = ACTIONS(3177),
    [anon_sym_let] = ACTIONS(3177),
    [anon_sym_orderby] = ACTIONS(3177),
    [anon_sym_ascending] = ACTIONS(3177),
    [anon_sym_descending] = ACTIONS(3177),
    [anon_sym_group] = ACTIONS(3177),
    [anon_sym_by] = ACTIONS(3177),
    [anon_sym_select] = ACTIONS(3177),
    [anon_sym_stackalloc] = ACTIONS(3177),
    [anon_sym_sizeof] = ACTIONS(3177),
    [anon_sym_typeof] = ACTIONS(3177),
    [anon_sym___makeref] = ACTIONS(3177),
    [anon_sym___reftype] = ACTIONS(3177),
    [anon_sym___refvalue] = ACTIONS(3177),
    [sym_null_literal] = ACTIONS(3177),
    [anon_sym_SQUOTE] = ACTIONS(3179),
    [sym_integer_literal] = ACTIONS(3177),
    [sym_real_literal] = ACTIONS(3179),
    [anon_sym_DQUOTE] = ACTIONS(3179),
    [sym_verbatim_string_literal] = ACTIONS(3179),
    [aux_sym_preproc_if_token1] = ACTIONS(3179),
    [aux_sym_preproc_if_token3] = ACTIONS(3179),
    [aux_sym_preproc_else_token1] = ACTIONS(3179),
    [aux_sym_preproc_elif_token1] = ACTIONS(3179),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3179),
    [sym_interpolation_verbatim_start] = ACTIONS(3179),
    [sym_interpolation_raw_start] = ACTIONS(3179),
    [sym_raw_string_start] = ACTIONS(3179),
  },
  [2254] = {
    [sym_preproc_region] = STATE(2254),
    [sym_preproc_endregion] = STATE(2254),
    [sym_preproc_line] = STATE(2254),
    [sym_preproc_pragma] = STATE(2254),
    [sym_preproc_nullable] = STATE(2254),
    [sym_preproc_error] = STATE(2254),
    [sym_preproc_warning] = STATE(2254),
    [sym_preproc_define] = STATE(2254),
    [sym_preproc_undef] = STATE(2254),
    [sym__identifier_token] = ACTIONS(3181),
    [anon_sym_extern] = ACTIONS(3181),
    [anon_sym_alias] = ACTIONS(3181),
    [anon_sym_SEMI] = ACTIONS(3183),
    [anon_sym_global] = ACTIONS(3181),
    [anon_sym_using] = ACTIONS(3181),
    [anon_sym_unsafe] = ACTIONS(3181),
    [anon_sym_static] = ACTIONS(3181),
    [anon_sym_LBRACK] = ACTIONS(3183),
    [anon_sym_LPAREN] = ACTIONS(3183),
    [anon_sym_return] = ACTIONS(3181),
    [anon_sym_namespace] = ACTIONS(3181),
    [anon_sym_class] = ACTIONS(3181),
    [anon_sym_ref] = ACTIONS(3181),
    [anon_sym_struct] = ACTIONS(3181),
    [anon_sym_enum] = ACTIONS(3181),
    [anon_sym_LBRACE] = ACTIONS(3183),
    [anon_sym_interface] = ACTIONS(3181),
    [anon_sym_delegate] = ACTIONS(3181),
    [anon_sym_record] = ACTIONS(3181),
    [anon_sym_abstract] = ACTIONS(3181),
    [anon_sym_async] = ACTIONS(3181),
    [anon_sym_const] = ACTIONS(3181),
    [anon_sym_file] = ACTIONS(3181),
    [anon_sym_fixed] = ACTIONS(3181),
    [anon_sym_internal] = ACTIONS(3181),
    [anon_sym_new] = ACTIONS(3181),
    [anon_sym_override] = ACTIONS(3181),
    [anon_sym_partial] = ACTIONS(3181),
    [anon_sym_private] = ACTIONS(3181),
    [anon_sym_protected] = ACTIONS(3181),
    [anon_sym_public] = ACTIONS(3181),
    [anon_sym_readonly] = ACTIONS(3181),
    [anon_sym_required] = ACTIONS(3181),
    [anon_sym_sealed] = ACTIONS(3181),
    [anon_sym_virtual] = ACTIONS(3181),
    [anon_sym_volatile] = ACTIONS(3181),
    [anon_sym_where] = ACTIONS(3181),
    [anon_sym_notnull] = ACTIONS(3181),
    [anon_sym_unmanaged] = ACTIONS(3181),
    [anon_sym_checked] = ACTIONS(3181),
    [anon_sym_BANG] = ACTIONS(3183),
    [anon_sym_TILDE] = ACTIONS(3183),
    [anon_sym_PLUS_PLUS] = ACTIONS(3183),
    [anon_sym_DASH_DASH] = ACTIONS(3183),
    [anon_sym_true] = ACTIONS(3181),
    [anon_sym_false] = ACTIONS(3181),
    [anon_sym_PLUS] = ACTIONS(3181),
    [anon_sym_DASH] = ACTIONS(3181),
    [anon_sym_STAR] = ACTIONS(3183),
    [anon_sym_CARET] = ACTIONS(3183),
    [anon_sym_AMP] = ACTIONS(3183),
    [anon_sym_this] = ACTIONS(3181),
    [anon_sym_scoped] = ACTIONS(3181),
    [anon_sym_base] = ACTIONS(3181),
    [anon_sym_var] = ACTIONS(3181),
    [sym_predefined_type] = ACTIONS(3181),
    [anon_sym_break] = ACTIONS(3181),
    [anon_sym_unchecked] = ACTIONS(3181),
    [anon_sym_continue] = ACTIONS(3181),
    [anon_sym_do] = ACTIONS(3181),
    [anon_sym_while] = ACTIONS(3181),
    [anon_sym_for] = ACTIONS(3181),
    [anon_sym_lock] = ACTIONS(3181),
    [anon_sym_yield] = ACTIONS(3181),
    [anon_sym_switch] = ACTIONS(3181),
    [anon_sym_default] = ACTIONS(3181),
    [anon_sym_throw] = ACTIONS(3181),
    [anon_sym_try] = ACTIONS(3181),
    [anon_sym_when] = ACTIONS(3181),
    [anon_sym_await] = ACTIONS(3181),
    [anon_sym_foreach] = ACTIONS(3181),
    [anon_sym_goto] = ACTIONS(3181),
    [anon_sym_if] = ACTIONS(3181),
    [anon_sym_else] = ACTIONS(3181),
    [anon_sym_DOT_DOT] = ACTIONS(3183),
    [anon_sym_from] = ACTIONS(3181),
    [anon_sym_into] = ACTIONS(3181),
    [anon_sym_join] = ACTIONS(3181),
    [anon_sym_on] = ACTIONS(3181),
    [anon_sym_equals] = ACTIONS(3181),
    [anon_sym_let] = ACTIONS(3181),
    [anon_sym_orderby] = ACTIONS(3181),
    [anon_sym_ascending] = ACTIONS(3181),
    [anon_sym_descending] = ACTIONS(3181),
    [anon_sym_group] = ACTIONS(3181),
    [anon_sym_by] = ACTIONS(3181),
    [anon_sym_select] = ACTIONS(3181),
    [anon_sym_stackalloc] = ACTIONS(3181),
    [anon_sym_sizeof] = ACTIONS(3181),
    [anon_sym_typeof] = ACTIONS(3181),
    [anon_sym___makeref] = ACTIONS(3181),
    [anon_sym___reftype] = ACTIONS(3181),
    [anon_sym___refvalue] = ACTIONS(3181),
    [sym_null_literal] = ACTIONS(3181),
    [anon_sym_SQUOTE] = ACTIONS(3183),
    [sym_integer_literal] = ACTIONS(3181),
    [sym_real_literal] = ACTIONS(3183),
    [anon_sym_DQUOTE] = ACTIONS(3183),
    [sym_verbatim_string_literal] = ACTIONS(3183),
    [aux_sym_preproc_if_token1] = ACTIONS(3183),
    [aux_sym_preproc_if_token3] = ACTIONS(3183),
    [aux_sym_preproc_else_token1] = ACTIONS(3183),
    [aux_sym_preproc_elif_token1] = ACTIONS(3183),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3183),
    [sym_interpolation_verbatim_start] = ACTIONS(3183),
    [sym_interpolation_raw_start] = ACTIONS(3183),
    [sym_raw_string_start] = ACTIONS(3183),
  },
  [2255] = {
    [sym_preproc_region] = STATE(2255),
    [sym_preproc_endregion] = STATE(2255),
    [sym_preproc_line] = STATE(2255),
    [sym_preproc_pragma] = STATE(2255),
    [sym_preproc_nullable] = STATE(2255),
    [sym_preproc_error] = STATE(2255),
    [sym_preproc_warning] = STATE(2255),
    [sym_preproc_define] = STATE(2255),
    [sym_preproc_undef] = STATE(2255),
    [sym__identifier_token] = ACTIONS(3185),
    [anon_sym_extern] = ACTIONS(3185),
    [anon_sym_alias] = ACTIONS(3185),
    [anon_sym_SEMI] = ACTIONS(3187),
    [anon_sym_global] = ACTIONS(3185),
    [anon_sym_using] = ACTIONS(3185),
    [anon_sym_unsafe] = ACTIONS(3185),
    [anon_sym_static] = ACTIONS(3185),
    [anon_sym_LBRACK] = ACTIONS(3187),
    [anon_sym_LPAREN] = ACTIONS(3187),
    [anon_sym_return] = ACTIONS(3185),
    [anon_sym_namespace] = ACTIONS(3185),
    [anon_sym_class] = ACTIONS(3185),
    [anon_sym_ref] = ACTIONS(3185),
    [anon_sym_struct] = ACTIONS(3185),
    [anon_sym_enum] = ACTIONS(3185),
    [anon_sym_LBRACE] = ACTIONS(3187),
    [anon_sym_interface] = ACTIONS(3185),
    [anon_sym_delegate] = ACTIONS(3185),
    [anon_sym_record] = ACTIONS(3185),
    [anon_sym_abstract] = ACTIONS(3185),
    [anon_sym_async] = ACTIONS(3185),
    [anon_sym_const] = ACTIONS(3185),
    [anon_sym_file] = ACTIONS(3185),
    [anon_sym_fixed] = ACTIONS(3185),
    [anon_sym_internal] = ACTIONS(3185),
    [anon_sym_new] = ACTIONS(3185),
    [anon_sym_override] = ACTIONS(3185),
    [anon_sym_partial] = ACTIONS(3185),
    [anon_sym_private] = ACTIONS(3185),
    [anon_sym_protected] = ACTIONS(3185),
    [anon_sym_public] = ACTIONS(3185),
    [anon_sym_readonly] = ACTIONS(3185),
    [anon_sym_required] = ACTIONS(3185),
    [anon_sym_sealed] = ACTIONS(3185),
    [anon_sym_virtual] = ACTIONS(3185),
    [anon_sym_volatile] = ACTIONS(3185),
    [anon_sym_where] = ACTIONS(3185),
    [anon_sym_notnull] = ACTIONS(3185),
    [anon_sym_unmanaged] = ACTIONS(3185),
    [anon_sym_checked] = ACTIONS(3185),
    [anon_sym_BANG] = ACTIONS(3187),
    [anon_sym_TILDE] = ACTIONS(3187),
    [anon_sym_PLUS_PLUS] = ACTIONS(3187),
    [anon_sym_DASH_DASH] = ACTIONS(3187),
    [anon_sym_true] = ACTIONS(3185),
    [anon_sym_false] = ACTIONS(3185),
    [anon_sym_PLUS] = ACTIONS(3185),
    [anon_sym_DASH] = ACTIONS(3185),
    [anon_sym_STAR] = ACTIONS(3187),
    [anon_sym_CARET] = ACTIONS(3187),
    [anon_sym_AMP] = ACTIONS(3187),
    [anon_sym_this] = ACTIONS(3185),
    [anon_sym_scoped] = ACTIONS(3185),
    [anon_sym_base] = ACTIONS(3185),
    [anon_sym_var] = ACTIONS(3185),
    [sym_predefined_type] = ACTIONS(3185),
    [anon_sym_break] = ACTIONS(3185),
    [anon_sym_unchecked] = ACTIONS(3185),
    [anon_sym_continue] = ACTIONS(3185),
    [anon_sym_do] = ACTIONS(3185),
    [anon_sym_while] = ACTIONS(3185),
    [anon_sym_for] = ACTIONS(3185),
    [anon_sym_lock] = ACTIONS(3185),
    [anon_sym_yield] = ACTIONS(3185),
    [anon_sym_switch] = ACTIONS(3185),
    [anon_sym_default] = ACTIONS(3185),
    [anon_sym_throw] = ACTIONS(3185),
    [anon_sym_try] = ACTIONS(3185),
    [anon_sym_when] = ACTIONS(3185),
    [anon_sym_await] = ACTIONS(3185),
    [anon_sym_foreach] = ACTIONS(3185),
    [anon_sym_goto] = ACTIONS(3185),
    [anon_sym_if] = ACTIONS(3185),
    [anon_sym_else] = ACTIONS(3185),
    [anon_sym_DOT_DOT] = ACTIONS(3187),
    [anon_sym_from] = ACTIONS(3185),
    [anon_sym_into] = ACTIONS(3185),
    [anon_sym_join] = ACTIONS(3185),
    [anon_sym_on] = ACTIONS(3185),
    [anon_sym_equals] = ACTIONS(3185),
    [anon_sym_let] = ACTIONS(3185),
    [anon_sym_orderby] = ACTIONS(3185),
    [anon_sym_ascending] = ACTIONS(3185),
    [anon_sym_descending] = ACTIONS(3185),
    [anon_sym_group] = ACTIONS(3185),
    [anon_sym_by] = ACTIONS(3185),
    [anon_sym_select] = ACTIONS(3185),
    [anon_sym_stackalloc] = ACTIONS(3185),
    [anon_sym_sizeof] = ACTIONS(3185),
    [anon_sym_typeof] = ACTIONS(3185),
    [anon_sym___makeref] = ACTIONS(3185),
    [anon_sym___reftype] = ACTIONS(3185),
    [anon_sym___refvalue] = ACTIONS(3185),
    [sym_null_literal] = ACTIONS(3185),
    [anon_sym_SQUOTE] = ACTIONS(3187),
    [sym_integer_literal] = ACTIONS(3185),
    [sym_real_literal] = ACTIONS(3187),
    [anon_sym_DQUOTE] = ACTIONS(3187),
    [sym_verbatim_string_literal] = ACTIONS(3187),
    [aux_sym_preproc_if_token1] = ACTIONS(3187),
    [aux_sym_preproc_if_token3] = ACTIONS(3187),
    [aux_sym_preproc_else_token1] = ACTIONS(3187),
    [aux_sym_preproc_elif_token1] = ACTIONS(3187),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3187),
    [sym_interpolation_verbatim_start] = ACTIONS(3187),
    [sym_interpolation_raw_start] = ACTIONS(3187),
    [sym_raw_string_start] = ACTIONS(3187),
  },
  [2256] = {
    [sym_preproc_region] = STATE(2256),
    [sym_preproc_endregion] = STATE(2256),
    [sym_preproc_line] = STATE(2256),
    [sym_preproc_pragma] = STATE(2256),
    [sym_preproc_nullable] = STATE(2256),
    [sym_preproc_error] = STATE(2256),
    [sym_preproc_warning] = STATE(2256),
    [sym_preproc_define] = STATE(2256),
    [sym_preproc_undef] = STATE(2256),
    [sym__identifier_token] = ACTIONS(3189),
    [anon_sym_extern] = ACTIONS(3189),
    [anon_sym_alias] = ACTIONS(3189),
    [anon_sym_SEMI] = ACTIONS(3191),
    [anon_sym_global] = ACTIONS(3189),
    [anon_sym_using] = ACTIONS(3189),
    [anon_sym_unsafe] = ACTIONS(3189),
    [anon_sym_static] = ACTIONS(3189),
    [anon_sym_LBRACK] = ACTIONS(3191),
    [anon_sym_LPAREN] = ACTIONS(3191),
    [anon_sym_return] = ACTIONS(3189),
    [anon_sym_namespace] = ACTIONS(3189),
    [anon_sym_class] = ACTIONS(3189),
    [anon_sym_ref] = ACTIONS(3189),
    [anon_sym_struct] = ACTIONS(3189),
    [anon_sym_enum] = ACTIONS(3189),
    [anon_sym_LBRACE] = ACTIONS(3191),
    [anon_sym_interface] = ACTIONS(3189),
    [anon_sym_delegate] = ACTIONS(3189),
    [anon_sym_record] = ACTIONS(3189),
    [anon_sym_abstract] = ACTIONS(3189),
    [anon_sym_async] = ACTIONS(3189),
    [anon_sym_const] = ACTIONS(3189),
    [anon_sym_file] = ACTIONS(3189),
    [anon_sym_fixed] = ACTIONS(3189),
    [anon_sym_internal] = ACTIONS(3189),
    [anon_sym_new] = ACTIONS(3189),
    [anon_sym_override] = ACTIONS(3189),
    [anon_sym_partial] = ACTIONS(3189),
    [anon_sym_private] = ACTIONS(3189),
    [anon_sym_protected] = ACTIONS(3189),
    [anon_sym_public] = ACTIONS(3189),
    [anon_sym_readonly] = ACTIONS(3189),
    [anon_sym_required] = ACTIONS(3189),
    [anon_sym_sealed] = ACTIONS(3189),
    [anon_sym_virtual] = ACTIONS(3189),
    [anon_sym_volatile] = ACTIONS(3189),
    [anon_sym_where] = ACTIONS(3189),
    [anon_sym_notnull] = ACTIONS(3189),
    [anon_sym_unmanaged] = ACTIONS(3189),
    [anon_sym_checked] = ACTIONS(3189),
    [anon_sym_BANG] = ACTIONS(3191),
    [anon_sym_TILDE] = ACTIONS(3191),
    [anon_sym_PLUS_PLUS] = ACTIONS(3191),
    [anon_sym_DASH_DASH] = ACTIONS(3191),
    [anon_sym_true] = ACTIONS(3189),
    [anon_sym_false] = ACTIONS(3189),
    [anon_sym_PLUS] = ACTIONS(3189),
    [anon_sym_DASH] = ACTIONS(3189),
    [anon_sym_STAR] = ACTIONS(3191),
    [anon_sym_CARET] = ACTIONS(3191),
    [anon_sym_AMP] = ACTIONS(3191),
    [anon_sym_this] = ACTIONS(3189),
    [anon_sym_scoped] = ACTIONS(3189),
    [anon_sym_base] = ACTIONS(3189),
    [anon_sym_var] = ACTIONS(3189),
    [sym_predefined_type] = ACTIONS(3189),
    [anon_sym_break] = ACTIONS(3189),
    [anon_sym_unchecked] = ACTIONS(3189),
    [anon_sym_continue] = ACTIONS(3189),
    [anon_sym_do] = ACTIONS(3189),
    [anon_sym_while] = ACTIONS(3189),
    [anon_sym_for] = ACTIONS(3189),
    [anon_sym_lock] = ACTIONS(3189),
    [anon_sym_yield] = ACTIONS(3189),
    [anon_sym_switch] = ACTIONS(3189),
    [anon_sym_default] = ACTIONS(3189),
    [anon_sym_throw] = ACTIONS(3189),
    [anon_sym_try] = ACTIONS(3189),
    [anon_sym_when] = ACTIONS(3189),
    [anon_sym_await] = ACTIONS(3189),
    [anon_sym_foreach] = ACTIONS(3189),
    [anon_sym_goto] = ACTIONS(3189),
    [anon_sym_if] = ACTIONS(3189),
    [anon_sym_else] = ACTIONS(3189),
    [anon_sym_DOT_DOT] = ACTIONS(3191),
    [anon_sym_from] = ACTIONS(3189),
    [anon_sym_into] = ACTIONS(3189),
    [anon_sym_join] = ACTIONS(3189),
    [anon_sym_on] = ACTIONS(3189),
    [anon_sym_equals] = ACTIONS(3189),
    [anon_sym_let] = ACTIONS(3189),
    [anon_sym_orderby] = ACTIONS(3189),
    [anon_sym_ascending] = ACTIONS(3189),
    [anon_sym_descending] = ACTIONS(3189),
    [anon_sym_group] = ACTIONS(3189),
    [anon_sym_by] = ACTIONS(3189),
    [anon_sym_select] = ACTIONS(3189),
    [anon_sym_stackalloc] = ACTIONS(3189),
    [anon_sym_sizeof] = ACTIONS(3189),
    [anon_sym_typeof] = ACTIONS(3189),
    [anon_sym___makeref] = ACTIONS(3189),
    [anon_sym___reftype] = ACTIONS(3189),
    [anon_sym___refvalue] = ACTIONS(3189),
    [sym_null_literal] = ACTIONS(3189),
    [anon_sym_SQUOTE] = ACTIONS(3191),
    [sym_integer_literal] = ACTIONS(3189),
    [sym_real_literal] = ACTIONS(3191),
    [anon_sym_DQUOTE] = ACTIONS(3191),
    [sym_verbatim_string_literal] = ACTIONS(3191),
    [aux_sym_preproc_if_token1] = ACTIONS(3191),
    [aux_sym_preproc_if_token3] = ACTIONS(3191),
    [aux_sym_preproc_else_token1] = ACTIONS(3191),
    [aux_sym_preproc_elif_token1] = ACTIONS(3191),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3191),
    [sym_interpolation_verbatim_start] = ACTIONS(3191),
    [sym_interpolation_raw_start] = ACTIONS(3191),
    [sym_raw_string_start] = ACTIONS(3191),
  },
  [2257] = {
    [sym_using_directive] = STATE(3324),
    [sym_attribute_list] = STATE(3740),
    [sym_namespace_declaration] = STATE(3324),
    [sym_class_declaration] = STATE(3324),
    [sym_struct_declaration] = STATE(3324),
    [sym_enum_declaration] = STATE(3324),
    [sym_interface_declaration] = STATE(3324),
    [sym_delegate_declaration] = STATE(3324),
    [sym_record_declaration] = STATE(3324),
    [sym_modifier] = STATE(3807),
    [sym_operator_declaration] = STATE(3324),
    [sym_conversion_operator_declaration] = STATE(3324),
    [sym_declaration] = STATE(3327),
    [sym_field_declaration] = STATE(3324),
    [sym_constructor_declaration] = STATE(3324),
    [sym_destructor_declaration] = STATE(3324),
    [sym_method_declaration] = STATE(3324),
    [sym_event_declaration] = STATE(3324),
    [sym_event_field_declaration] = STATE(3324),
    [sym_indexer_declaration] = STATE(3324),
    [sym_property_declaration] = STATE(3324),
    [sym_variable_declaration] = STATE(8996),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(6582),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(6750),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_if] = STATE(3324),
    [sym_preproc_else] = STATE(9054),
    [sym_preproc_elif] = STATE(9054),
    [sym_preproc_region] = STATE(2257),
    [sym_preproc_endregion] = STATE(2257),
    [sym_preproc_line] = STATE(2257),
    [sym_preproc_pragma] = STATE(2257),
    [sym_preproc_nullable] = STATE(2257),
    [sym_preproc_error] = STATE(2257),
    [sym_preproc_warning] = STATE(2257),
    [sym_preproc_define] = STATE(2257),
    [sym_preproc_undef] = STATE(2257),
    [aux_sym_class_declaration_repeat1] = STATE(2781),
    [aux_sym_class_declaration_repeat2] = STATE(2857),
    [aux_sym_declaration_list_repeat1] = STATE(2422),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_extern] = ACTIONS(3195),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3199),
    [anon_sym_using] = ACTIONS(3201),
    [anon_sym_unsafe] = ACTIONS(65),
    [anon_sym_static] = ACTIONS(65),
    [anon_sym_LBRACK] = ACTIONS(3203),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_event] = ACTIONS(3207),
    [anon_sym_namespace] = ACTIONS(3209),
    [anon_sym_class] = ACTIONS(3211),
    [anon_sym_ref] = ACTIONS(3213),
    [anon_sym_struct] = ACTIONS(3215),
    [anon_sym_enum] = ACTIONS(3217),
    [anon_sym_interface] = ACTIONS(3219),
    [anon_sym_delegate] = ACTIONS(3221),
    [anon_sym_record] = ACTIONS(3223),
    [anon_sym_abstract] = ACTIONS(65),
    [anon_sym_async] = ACTIONS(65),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_file] = ACTIONS(3225),
    [anon_sym_fixed] = ACTIONS(65),
    [anon_sym_internal] = ACTIONS(65),
    [anon_sym_new] = ACTIONS(65),
    [anon_sym_override] = ACTIONS(65),
    [anon_sym_partial] = ACTIONS(65),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_public] = ACTIONS(65),
    [anon_sym_readonly] = ACTIONS(65),
    [anon_sym_required] = ACTIONS(65),
    [anon_sym_sealed] = ACTIONS(65),
    [anon_sym_virtual] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_TILDE] = ACTIONS(3227),
    [anon_sym_implicit] = ACTIONS(3229),
    [anon_sym_explicit] = ACTIONS(3229),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_if_token1] = ACTIONS(3237),
    [aux_sym_preproc_if_token3] = ACTIONS(3239),
    [aux_sym_preproc_else_token1] = ACTIONS(3241),
    [aux_sym_preproc_elif_token1] = ACTIONS(3243),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2258] = {
    [sym_preproc_region] = STATE(2258),
    [sym_preproc_endregion] = STATE(2258),
    [sym_preproc_line] = STATE(2258),
    [sym_preproc_pragma] = STATE(2258),
    [sym_preproc_nullable] = STATE(2258),
    [sym_preproc_error] = STATE(2258),
    [sym_preproc_warning] = STATE(2258),
    [sym_preproc_define] = STATE(2258),
    [sym_preproc_undef] = STATE(2258),
    [sym__identifier_token] = ACTIONS(3245),
    [anon_sym_extern] = ACTIONS(3245),
    [anon_sym_alias] = ACTIONS(3245),
    [anon_sym_SEMI] = ACTIONS(3247),
    [anon_sym_global] = ACTIONS(3245),
    [anon_sym_using] = ACTIONS(3245),
    [anon_sym_unsafe] = ACTIONS(3245),
    [anon_sym_static] = ACTIONS(3245),
    [anon_sym_LBRACK] = ACTIONS(3247),
    [anon_sym_LPAREN] = ACTIONS(3247),
    [anon_sym_return] = ACTIONS(3245),
    [anon_sym_namespace] = ACTIONS(3245),
    [anon_sym_class] = ACTIONS(3245),
    [anon_sym_ref] = ACTIONS(3245),
    [anon_sym_struct] = ACTIONS(3245),
    [anon_sym_enum] = ACTIONS(3245),
    [anon_sym_LBRACE] = ACTIONS(3247),
    [anon_sym_interface] = ACTIONS(3245),
    [anon_sym_delegate] = ACTIONS(3245),
    [anon_sym_record] = ACTIONS(3245),
    [anon_sym_abstract] = ACTIONS(3245),
    [anon_sym_async] = ACTIONS(3245),
    [anon_sym_const] = ACTIONS(3245),
    [anon_sym_file] = ACTIONS(3245),
    [anon_sym_fixed] = ACTIONS(3245),
    [anon_sym_internal] = ACTIONS(3245),
    [anon_sym_new] = ACTIONS(3245),
    [anon_sym_override] = ACTIONS(3245),
    [anon_sym_partial] = ACTIONS(3245),
    [anon_sym_private] = ACTIONS(3245),
    [anon_sym_protected] = ACTIONS(3245),
    [anon_sym_public] = ACTIONS(3245),
    [anon_sym_readonly] = ACTIONS(3245),
    [anon_sym_required] = ACTIONS(3245),
    [anon_sym_sealed] = ACTIONS(3245),
    [anon_sym_virtual] = ACTIONS(3245),
    [anon_sym_volatile] = ACTIONS(3245),
    [anon_sym_where] = ACTIONS(3245),
    [anon_sym_notnull] = ACTIONS(3245),
    [anon_sym_unmanaged] = ACTIONS(3245),
    [anon_sym_checked] = ACTIONS(3245),
    [anon_sym_BANG] = ACTIONS(3247),
    [anon_sym_TILDE] = ACTIONS(3247),
    [anon_sym_PLUS_PLUS] = ACTIONS(3247),
    [anon_sym_DASH_DASH] = ACTIONS(3247),
    [anon_sym_true] = ACTIONS(3245),
    [anon_sym_false] = ACTIONS(3245),
    [anon_sym_PLUS] = ACTIONS(3245),
    [anon_sym_DASH] = ACTIONS(3245),
    [anon_sym_STAR] = ACTIONS(3247),
    [anon_sym_CARET] = ACTIONS(3247),
    [anon_sym_AMP] = ACTIONS(3247),
    [anon_sym_this] = ACTIONS(3245),
    [anon_sym_scoped] = ACTIONS(3245),
    [anon_sym_base] = ACTIONS(3245),
    [anon_sym_var] = ACTIONS(3245),
    [sym_predefined_type] = ACTIONS(3245),
    [anon_sym_break] = ACTIONS(3245),
    [anon_sym_unchecked] = ACTIONS(3245),
    [anon_sym_continue] = ACTIONS(3245),
    [anon_sym_do] = ACTIONS(3245),
    [anon_sym_while] = ACTIONS(3245),
    [anon_sym_for] = ACTIONS(3245),
    [anon_sym_lock] = ACTIONS(3245),
    [anon_sym_yield] = ACTIONS(3245),
    [anon_sym_switch] = ACTIONS(3245),
    [anon_sym_default] = ACTIONS(3245),
    [anon_sym_throw] = ACTIONS(3245),
    [anon_sym_try] = ACTIONS(3245),
    [anon_sym_when] = ACTIONS(3245),
    [anon_sym_await] = ACTIONS(3245),
    [anon_sym_foreach] = ACTIONS(3245),
    [anon_sym_goto] = ACTIONS(3245),
    [anon_sym_if] = ACTIONS(3245),
    [anon_sym_else] = ACTIONS(3245),
    [anon_sym_DOT_DOT] = ACTIONS(3247),
    [anon_sym_from] = ACTIONS(3245),
    [anon_sym_into] = ACTIONS(3245),
    [anon_sym_join] = ACTIONS(3245),
    [anon_sym_on] = ACTIONS(3245),
    [anon_sym_equals] = ACTIONS(3245),
    [anon_sym_let] = ACTIONS(3245),
    [anon_sym_orderby] = ACTIONS(3245),
    [anon_sym_ascending] = ACTIONS(3245),
    [anon_sym_descending] = ACTIONS(3245),
    [anon_sym_group] = ACTIONS(3245),
    [anon_sym_by] = ACTIONS(3245),
    [anon_sym_select] = ACTIONS(3245),
    [anon_sym_stackalloc] = ACTIONS(3245),
    [anon_sym_sizeof] = ACTIONS(3245),
    [anon_sym_typeof] = ACTIONS(3245),
    [anon_sym___makeref] = ACTIONS(3245),
    [anon_sym___reftype] = ACTIONS(3245),
    [anon_sym___refvalue] = ACTIONS(3245),
    [sym_null_literal] = ACTIONS(3245),
    [anon_sym_SQUOTE] = ACTIONS(3247),
    [sym_integer_literal] = ACTIONS(3245),
    [sym_real_literal] = ACTIONS(3247),
    [anon_sym_DQUOTE] = ACTIONS(3247),
    [sym_verbatim_string_literal] = ACTIONS(3247),
    [aux_sym_preproc_if_token1] = ACTIONS(3247),
    [aux_sym_preproc_if_token3] = ACTIONS(3247),
    [aux_sym_preproc_else_token1] = ACTIONS(3247),
    [aux_sym_preproc_elif_token1] = ACTIONS(3247),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3247),
    [sym_interpolation_verbatim_start] = ACTIONS(3247),
    [sym_interpolation_raw_start] = ACTIONS(3247),
    [sym_raw_string_start] = ACTIONS(3247),
  },
  [2259] = {
    [sym_preproc_region] = STATE(2259),
    [sym_preproc_endregion] = STATE(2259),
    [sym_preproc_line] = STATE(2259),
    [sym_preproc_pragma] = STATE(2259),
    [sym_preproc_nullable] = STATE(2259),
    [sym_preproc_error] = STATE(2259),
    [sym_preproc_warning] = STATE(2259),
    [sym_preproc_define] = STATE(2259),
    [sym_preproc_undef] = STATE(2259),
    [sym__identifier_token] = ACTIONS(3249),
    [anon_sym_extern] = ACTIONS(3249),
    [anon_sym_alias] = ACTIONS(3249),
    [anon_sym_SEMI] = ACTIONS(3251),
    [anon_sym_global] = ACTIONS(3249),
    [anon_sym_using] = ACTIONS(3249),
    [anon_sym_unsafe] = ACTIONS(3249),
    [anon_sym_static] = ACTIONS(3249),
    [anon_sym_LBRACK] = ACTIONS(3251),
    [anon_sym_LPAREN] = ACTIONS(3251),
    [anon_sym_return] = ACTIONS(3249),
    [anon_sym_namespace] = ACTIONS(3249),
    [anon_sym_class] = ACTIONS(3249),
    [anon_sym_ref] = ACTIONS(3249),
    [anon_sym_struct] = ACTIONS(3249),
    [anon_sym_enum] = ACTIONS(3249),
    [anon_sym_LBRACE] = ACTIONS(3251),
    [anon_sym_interface] = ACTIONS(3249),
    [anon_sym_delegate] = ACTIONS(3249),
    [anon_sym_record] = ACTIONS(3249),
    [anon_sym_abstract] = ACTIONS(3249),
    [anon_sym_async] = ACTIONS(3249),
    [anon_sym_const] = ACTIONS(3249),
    [anon_sym_file] = ACTIONS(3249),
    [anon_sym_fixed] = ACTIONS(3249),
    [anon_sym_internal] = ACTIONS(3249),
    [anon_sym_new] = ACTIONS(3249),
    [anon_sym_override] = ACTIONS(3249),
    [anon_sym_partial] = ACTIONS(3249),
    [anon_sym_private] = ACTIONS(3249),
    [anon_sym_protected] = ACTIONS(3249),
    [anon_sym_public] = ACTIONS(3249),
    [anon_sym_readonly] = ACTIONS(3249),
    [anon_sym_required] = ACTIONS(3249),
    [anon_sym_sealed] = ACTIONS(3249),
    [anon_sym_virtual] = ACTIONS(3249),
    [anon_sym_volatile] = ACTIONS(3249),
    [anon_sym_where] = ACTIONS(3249),
    [anon_sym_notnull] = ACTIONS(3249),
    [anon_sym_unmanaged] = ACTIONS(3249),
    [anon_sym_checked] = ACTIONS(3249),
    [anon_sym_BANG] = ACTIONS(3251),
    [anon_sym_TILDE] = ACTIONS(3251),
    [anon_sym_PLUS_PLUS] = ACTIONS(3251),
    [anon_sym_DASH_DASH] = ACTIONS(3251),
    [anon_sym_true] = ACTIONS(3249),
    [anon_sym_false] = ACTIONS(3249),
    [anon_sym_PLUS] = ACTIONS(3249),
    [anon_sym_DASH] = ACTIONS(3249),
    [anon_sym_STAR] = ACTIONS(3251),
    [anon_sym_CARET] = ACTIONS(3251),
    [anon_sym_AMP] = ACTIONS(3251),
    [anon_sym_this] = ACTIONS(3249),
    [anon_sym_scoped] = ACTIONS(3249),
    [anon_sym_base] = ACTIONS(3249),
    [anon_sym_var] = ACTIONS(3249),
    [sym_predefined_type] = ACTIONS(3249),
    [anon_sym_break] = ACTIONS(3249),
    [anon_sym_unchecked] = ACTIONS(3249),
    [anon_sym_continue] = ACTIONS(3249),
    [anon_sym_do] = ACTIONS(3249),
    [anon_sym_while] = ACTIONS(3249),
    [anon_sym_for] = ACTIONS(3249),
    [anon_sym_lock] = ACTIONS(3249),
    [anon_sym_yield] = ACTIONS(3249),
    [anon_sym_switch] = ACTIONS(3249),
    [anon_sym_default] = ACTIONS(3249),
    [anon_sym_throw] = ACTIONS(3249),
    [anon_sym_try] = ACTIONS(3249),
    [anon_sym_when] = ACTIONS(3249),
    [anon_sym_await] = ACTIONS(3249),
    [anon_sym_foreach] = ACTIONS(3249),
    [anon_sym_goto] = ACTIONS(3249),
    [anon_sym_if] = ACTIONS(3249),
    [anon_sym_else] = ACTIONS(3249),
    [anon_sym_DOT_DOT] = ACTIONS(3251),
    [anon_sym_from] = ACTIONS(3249),
    [anon_sym_into] = ACTIONS(3249),
    [anon_sym_join] = ACTIONS(3249),
    [anon_sym_on] = ACTIONS(3249),
    [anon_sym_equals] = ACTIONS(3249),
    [anon_sym_let] = ACTIONS(3249),
    [anon_sym_orderby] = ACTIONS(3249),
    [anon_sym_ascending] = ACTIONS(3249),
    [anon_sym_descending] = ACTIONS(3249),
    [anon_sym_group] = ACTIONS(3249),
    [anon_sym_by] = ACTIONS(3249),
    [anon_sym_select] = ACTIONS(3249),
    [anon_sym_stackalloc] = ACTIONS(3249),
    [anon_sym_sizeof] = ACTIONS(3249),
    [anon_sym_typeof] = ACTIONS(3249),
    [anon_sym___makeref] = ACTIONS(3249),
    [anon_sym___reftype] = ACTIONS(3249),
    [anon_sym___refvalue] = ACTIONS(3249),
    [sym_null_literal] = ACTIONS(3249),
    [anon_sym_SQUOTE] = ACTIONS(3251),
    [sym_integer_literal] = ACTIONS(3249),
    [sym_real_literal] = ACTIONS(3251),
    [anon_sym_DQUOTE] = ACTIONS(3251),
    [sym_verbatim_string_literal] = ACTIONS(3251),
    [aux_sym_preproc_if_token1] = ACTIONS(3251),
    [aux_sym_preproc_if_token3] = ACTIONS(3251),
    [aux_sym_preproc_else_token1] = ACTIONS(3251),
    [aux_sym_preproc_elif_token1] = ACTIONS(3251),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3251),
    [sym_interpolation_verbatim_start] = ACTIONS(3251),
    [sym_interpolation_raw_start] = ACTIONS(3251),
    [sym_raw_string_start] = ACTIONS(3251),
  },
  [2260] = {
    [sym_preproc_region] = STATE(2260),
    [sym_preproc_endregion] = STATE(2260),
    [sym_preproc_line] = STATE(2260),
    [sym_preproc_pragma] = STATE(2260),
    [sym_preproc_nullable] = STATE(2260),
    [sym_preproc_error] = STATE(2260),
    [sym_preproc_warning] = STATE(2260),
    [sym_preproc_define] = STATE(2260),
    [sym_preproc_undef] = STATE(2260),
    [sym__identifier_token] = ACTIONS(3253),
    [anon_sym_extern] = ACTIONS(3253),
    [anon_sym_alias] = ACTIONS(3253),
    [anon_sym_SEMI] = ACTIONS(3255),
    [anon_sym_global] = ACTIONS(3253),
    [anon_sym_using] = ACTIONS(3253),
    [anon_sym_unsafe] = ACTIONS(3253),
    [anon_sym_static] = ACTIONS(3253),
    [anon_sym_LBRACK] = ACTIONS(3255),
    [anon_sym_LPAREN] = ACTIONS(3255),
    [anon_sym_return] = ACTIONS(3253),
    [anon_sym_namespace] = ACTIONS(3253),
    [anon_sym_class] = ACTIONS(3253),
    [anon_sym_ref] = ACTIONS(3253),
    [anon_sym_struct] = ACTIONS(3253),
    [anon_sym_enum] = ACTIONS(3253),
    [anon_sym_LBRACE] = ACTIONS(3255),
    [anon_sym_interface] = ACTIONS(3253),
    [anon_sym_delegate] = ACTIONS(3253),
    [anon_sym_record] = ACTIONS(3253),
    [anon_sym_abstract] = ACTIONS(3253),
    [anon_sym_async] = ACTIONS(3253),
    [anon_sym_const] = ACTIONS(3253),
    [anon_sym_file] = ACTIONS(3253),
    [anon_sym_fixed] = ACTIONS(3253),
    [anon_sym_internal] = ACTIONS(3253),
    [anon_sym_new] = ACTIONS(3253),
    [anon_sym_override] = ACTIONS(3253),
    [anon_sym_partial] = ACTIONS(3253),
    [anon_sym_private] = ACTIONS(3253),
    [anon_sym_protected] = ACTIONS(3253),
    [anon_sym_public] = ACTIONS(3253),
    [anon_sym_readonly] = ACTIONS(3253),
    [anon_sym_required] = ACTIONS(3253),
    [anon_sym_sealed] = ACTIONS(3253),
    [anon_sym_virtual] = ACTIONS(3253),
    [anon_sym_volatile] = ACTIONS(3253),
    [anon_sym_where] = ACTIONS(3253),
    [anon_sym_notnull] = ACTIONS(3253),
    [anon_sym_unmanaged] = ACTIONS(3253),
    [anon_sym_checked] = ACTIONS(3253),
    [anon_sym_BANG] = ACTIONS(3255),
    [anon_sym_TILDE] = ACTIONS(3255),
    [anon_sym_PLUS_PLUS] = ACTIONS(3255),
    [anon_sym_DASH_DASH] = ACTIONS(3255),
    [anon_sym_true] = ACTIONS(3253),
    [anon_sym_false] = ACTIONS(3253),
    [anon_sym_PLUS] = ACTIONS(3253),
    [anon_sym_DASH] = ACTIONS(3253),
    [anon_sym_STAR] = ACTIONS(3255),
    [anon_sym_CARET] = ACTIONS(3255),
    [anon_sym_AMP] = ACTIONS(3255),
    [anon_sym_this] = ACTIONS(3253),
    [anon_sym_scoped] = ACTIONS(3253),
    [anon_sym_base] = ACTIONS(3253),
    [anon_sym_var] = ACTIONS(3253),
    [sym_predefined_type] = ACTIONS(3253),
    [anon_sym_break] = ACTIONS(3253),
    [anon_sym_unchecked] = ACTIONS(3253),
    [anon_sym_continue] = ACTIONS(3253),
    [anon_sym_do] = ACTIONS(3253),
    [anon_sym_while] = ACTIONS(3253),
    [anon_sym_for] = ACTIONS(3253),
    [anon_sym_lock] = ACTIONS(3253),
    [anon_sym_yield] = ACTIONS(3253),
    [anon_sym_switch] = ACTIONS(3253),
    [anon_sym_default] = ACTIONS(3253),
    [anon_sym_throw] = ACTIONS(3253),
    [anon_sym_try] = ACTIONS(3253),
    [anon_sym_when] = ACTIONS(3253),
    [anon_sym_await] = ACTIONS(3253),
    [anon_sym_foreach] = ACTIONS(3253),
    [anon_sym_goto] = ACTIONS(3253),
    [anon_sym_if] = ACTIONS(3253),
    [anon_sym_else] = ACTIONS(3253),
    [anon_sym_DOT_DOT] = ACTIONS(3255),
    [anon_sym_from] = ACTIONS(3253),
    [anon_sym_into] = ACTIONS(3253),
    [anon_sym_join] = ACTIONS(3253),
    [anon_sym_on] = ACTIONS(3253),
    [anon_sym_equals] = ACTIONS(3253),
    [anon_sym_let] = ACTIONS(3253),
    [anon_sym_orderby] = ACTIONS(3253),
    [anon_sym_ascending] = ACTIONS(3253),
    [anon_sym_descending] = ACTIONS(3253),
    [anon_sym_group] = ACTIONS(3253),
    [anon_sym_by] = ACTIONS(3253),
    [anon_sym_select] = ACTIONS(3253),
    [anon_sym_stackalloc] = ACTIONS(3253),
    [anon_sym_sizeof] = ACTIONS(3253),
    [anon_sym_typeof] = ACTIONS(3253),
    [anon_sym___makeref] = ACTIONS(3253),
    [anon_sym___reftype] = ACTIONS(3253),
    [anon_sym___refvalue] = ACTIONS(3253),
    [sym_null_literal] = ACTIONS(3253),
    [anon_sym_SQUOTE] = ACTIONS(3255),
    [sym_integer_literal] = ACTIONS(3253),
    [sym_real_literal] = ACTIONS(3255),
    [anon_sym_DQUOTE] = ACTIONS(3255),
    [sym_verbatim_string_literal] = ACTIONS(3255),
    [aux_sym_preproc_if_token1] = ACTIONS(3255),
    [aux_sym_preproc_if_token3] = ACTIONS(3255),
    [aux_sym_preproc_else_token1] = ACTIONS(3255),
    [aux_sym_preproc_elif_token1] = ACTIONS(3255),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3255),
    [sym_interpolation_verbatim_start] = ACTIONS(3255),
    [sym_interpolation_raw_start] = ACTIONS(3255),
    [sym_raw_string_start] = ACTIONS(3255),
  },
  [2261] = {
    [sym_preproc_region] = STATE(2261),
    [sym_preproc_endregion] = STATE(2261),
    [sym_preproc_line] = STATE(2261),
    [sym_preproc_pragma] = STATE(2261),
    [sym_preproc_nullable] = STATE(2261),
    [sym_preproc_error] = STATE(2261),
    [sym_preproc_warning] = STATE(2261),
    [sym_preproc_define] = STATE(2261),
    [sym_preproc_undef] = STATE(2261),
    [ts_builtin_sym_end] = ACTIONS(2997),
    [sym__identifier_token] = ACTIONS(2995),
    [anon_sym_extern] = ACTIONS(2995),
    [anon_sym_alias] = ACTIONS(2995),
    [anon_sym_SEMI] = ACTIONS(2997),
    [anon_sym_global] = ACTIONS(2995),
    [anon_sym_using] = ACTIONS(2995),
    [anon_sym_unsafe] = ACTIONS(2995),
    [anon_sym_static] = ACTIONS(2995),
    [anon_sym_LBRACK] = ACTIONS(2997),
    [anon_sym_LPAREN] = ACTIONS(2997),
    [anon_sym_return] = ACTIONS(2995),
    [anon_sym_namespace] = ACTIONS(2995),
    [anon_sym_class] = ACTIONS(2995),
    [anon_sym_ref] = ACTIONS(2995),
    [anon_sym_struct] = ACTIONS(2995),
    [anon_sym_enum] = ACTIONS(2995),
    [anon_sym_LBRACE] = ACTIONS(2997),
    [anon_sym_interface] = ACTIONS(2995),
    [anon_sym_delegate] = ACTIONS(2995),
    [anon_sym_record] = ACTIONS(2995),
    [anon_sym_abstract] = ACTIONS(2995),
    [anon_sym_async] = ACTIONS(2995),
    [anon_sym_const] = ACTIONS(2995),
    [anon_sym_file] = ACTIONS(2995),
    [anon_sym_fixed] = ACTIONS(2995),
    [anon_sym_internal] = ACTIONS(2995),
    [anon_sym_new] = ACTIONS(2995),
    [anon_sym_override] = ACTIONS(2995),
    [anon_sym_partial] = ACTIONS(2995),
    [anon_sym_private] = ACTIONS(2995),
    [anon_sym_protected] = ACTIONS(2995),
    [anon_sym_public] = ACTIONS(2995),
    [anon_sym_readonly] = ACTIONS(2995),
    [anon_sym_required] = ACTIONS(2995),
    [anon_sym_sealed] = ACTIONS(2995),
    [anon_sym_virtual] = ACTIONS(2995),
    [anon_sym_volatile] = ACTIONS(2995),
    [anon_sym_where] = ACTIONS(2995),
    [anon_sym_notnull] = ACTIONS(2995),
    [anon_sym_unmanaged] = ACTIONS(2995),
    [anon_sym_checked] = ACTIONS(2995),
    [anon_sym_BANG] = ACTIONS(2997),
    [anon_sym_TILDE] = ACTIONS(2997),
    [anon_sym_PLUS_PLUS] = ACTIONS(2997),
    [anon_sym_DASH_DASH] = ACTIONS(2997),
    [anon_sym_true] = ACTIONS(2995),
    [anon_sym_false] = ACTIONS(2995),
    [anon_sym_PLUS] = ACTIONS(2995),
    [anon_sym_DASH] = ACTIONS(2995),
    [anon_sym_STAR] = ACTIONS(2997),
    [anon_sym_CARET] = ACTIONS(2997),
    [anon_sym_AMP] = ACTIONS(2997),
    [anon_sym_this] = ACTIONS(2995),
    [anon_sym_scoped] = ACTIONS(2995),
    [anon_sym_base] = ACTIONS(2995),
    [anon_sym_var] = ACTIONS(2995),
    [sym_predefined_type] = ACTIONS(2995),
    [anon_sym_break] = ACTIONS(2995),
    [anon_sym_unchecked] = ACTIONS(2995),
    [anon_sym_continue] = ACTIONS(2995),
    [anon_sym_do] = ACTIONS(2995),
    [anon_sym_while] = ACTIONS(2995),
    [anon_sym_for] = ACTIONS(2995),
    [anon_sym_lock] = ACTIONS(2995),
    [anon_sym_yield] = ACTIONS(2995),
    [anon_sym_switch] = ACTIONS(2995),
    [anon_sym_default] = ACTIONS(2995),
    [anon_sym_throw] = ACTIONS(2995),
    [anon_sym_try] = ACTIONS(2995),
    [anon_sym_catch] = ACTIONS(2995),
    [anon_sym_when] = ACTIONS(2995),
    [anon_sym_finally] = ACTIONS(2995),
    [anon_sym_await] = ACTIONS(2995),
    [anon_sym_foreach] = ACTIONS(2995),
    [anon_sym_goto] = ACTIONS(2995),
    [anon_sym_if] = ACTIONS(2995),
    [anon_sym_else] = ACTIONS(2995),
    [anon_sym_DOT_DOT] = ACTIONS(2997),
    [anon_sym_from] = ACTIONS(2995),
    [anon_sym_into] = ACTIONS(2995),
    [anon_sym_join] = ACTIONS(2995),
    [anon_sym_on] = ACTIONS(2995),
    [anon_sym_equals] = ACTIONS(2995),
    [anon_sym_let] = ACTIONS(2995),
    [anon_sym_orderby] = ACTIONS(2995),
    [anon_sym_ascending] = ACTIONS(2995),
    [anon_sym_descending] = ACTIONS(2995),
    [anon_sym_group] = ACTIONS(2995),
    [anon_sym_by] = ACTIONS(2995),
    [anon_sym_select] = ACTIONS(2995),
    [anon_sym_stackalloc] = ACTIONS(2995),
    [anon_sym_sizeof] = ACTIONS(2995),
    [anon_sym_typeof] = ACTIONS(2995),
    [anon_sym___makeref] = ACTIONS(2995),
    [anon_sym___reftype] = ACTIONS(2995),
    [anon_sym___refvalue] = ACTIONS(2995),
    [sym_null_literal] = ACTIONS(2995),
    [anon_sym_SQUOTE] = ACTIONS(2997),
    [sym_integer_literal] = ACTIONS(2995),
    [sym_real_literal] = ACTIONS(2997),
    [anon_sym_DQUOTE] = ACTIONS(2997),
    [sym_verbatim_string_literal] = ACTIONS(2997),
    [aux_sym_preproc_if_token1] = ACTIONS(2997),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(2997),
    [sym_interpolation_verbatim_start] = ACTIONS(2997),
    [sym_interpolation_raw_start] = ACTIONS(2997),
    [sym_raw_string_start] = ACTIONS(2997),
  },
  [2262] = {
    [sym_using_directive] = STATE(3324),
    [sym_attribute_list] = STATE(3740),
    [sym_namespace_declaration] = STATE(3324),
    [sym_class_declaration] = STATE(3324),
    [sym_struct_declaration] = STATE(3324),
    [sym_enum_declaration] = STATE(3324),
    [sym_interface_declaration] = STATE(3324),
    [sym_delegate_declaration] = STATE(3324),
    [sym_record_declaration] = STATE(3324),
    [sym_modifier] = STATE(3807),
    [sym_operator_declaration] = STATE(3324),
    [sym_conversion_operator_declaration] = STATE(3324),
    [sym_declaration] = STATE(3327),
    [sym_field_declaration] = STATE(3324),
    [sym_constructor_declaration] = STATE(3324),
    [sym_destructor_declaration] = STATE(3324),
    [sym_method_declaration] = STATE(3324),
    [sym_event_declaration] = STATE(3324),
    [sym_event_field_declaration] = STATE(3324),
    [sym_indexer_declaration] = STATE(3324),
    [sym_property_declaration] = STATE(3324),
    [sym_variable_declaration] = STATE(8996),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(6582),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(6750),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_if] = STATE(3324),
    [sym_preproc_else] = STATE(9280),
    [sym_preproc_elif] = STATE(9280),
    [sym_preproc_region] = STATE(2262),
    [sym_preproc_endregion] = STATE(2262),
    [sym_preproc_line] = STATE(2262),
    [sym_preproc_pragma] = STATE(2262),
    [sym_preproc_nullable] = STATE(2262),
    [sym_preproc_error] = STATE(2262),
    [sym_preproc_warning] = STATE(2262),
    [sym_preproc_define] = STATE(2262),
    [sym_preproc_undef] = STATE(2262),
    [aux_sym_class_declaration_repeat1] = STATE(2781),
    [aux_sym_class_declaration_repeat2] = STATE(2857),
    [aux_sym_declaration_list_repeat1] = STATE(2263),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_extern] = ACTIONS(3195),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3199),
    [anon_sym_using] = ACTIONS(3201),
    [anon_sym_unsafe] = ACTIONS(65),
    [anon_sym_static] = ACTIONS(65),
    [anon_sym_LBRACK] = ACTIONS(3203),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_event] = ACTIONS(3207),
    [anon_sym_namespace] = ACTIONS(3209),
    [anon_sym_class] = ACTIONS(3211),
    [anon_sym_ref] = ACTIONS(3213),
    [anon_sym_struct] = ACTIONS(3215),
    [anon_sym_enum] = ACTIONS(3217),
    [anon_sym_interface] = ACTIONS(3219),
    [anon_sym_delegate] = ACTIONS(3221),
    [anon_sym_record] = ACTIONS(3223),
    [anon_sym_abstract] = ACTIONS(65),
    [anon_sym_async] = ACTIONS(65),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_file] = ACTIONS(3225),
    [anon_sym_fixed] = ACTIONS(65),
    [anon_sym_internal] = ACTIONS(65),
    [anon_sym_new] = ACTIONS(65),
    [anon_sym_override] = ACTIONS(65),
    [anon_sym_partial] = ACTIONS(65),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_public] = ACTIONS(65),
    [anon_sym_readonly] = ACTIONS(65),
    [anon_sym_required] = ACTIONS(65),
    [anon_sym_sealed] = ACTIONS(65),
    [anon_sym_virtual] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_TILDE] = ACTIONS(3227),
    [anon_sym_implicit] = ACTIONS(3229),
    [anon_sym_explicit] = ACTIONS(3229),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_if_token1] = ACTIONS(3237),
    [aux_sym_preproc_if_token3] = ACTIONS(3257),
    [aux_sym_preproc_else_token1] = ACTIONS(3241),
    [aux_sym_preproc_elif_token1] = ACTIONS(3243),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2263] = {
    [sym_using_directive] = STATE(3324),
    [sym_attribute_list] = STATE(3740),
    [sym_namespace_declaration] = STATE(3324),
    [sym_class_declaration] = STATE(3324),
    [sym_struct_declaration] = STATE(3324),
    [sym_enum_declaration] = STATE(3324),
    [sym_interface_declaration] = STATE(3324),
    [sym_delegate_declaration] = STATE(3324),
    [sym_record_declaration] = STATE(3324),
    [sym_modifier] = STATE(3807),
    [sym_operator_declaration] = STATE(3324),
    [sym_conversion_operator_declaration] = STATE(3324),
    [sym_declaration] = STATE(3327),
    [sym_field_declaration] = STATE(3324),
    [sym_constructor_declaration] = STATE(3324),
    [sym_destructor_declaration] = STATE(3324),
    [sym_method_declaration] = STATE(3324),
    [sym_event_declaration] = STATE(3324),
    [sym_event_field_declaration] = STATE(3324),
    [sym_indexer_declaration] = STATE(3324),
    [sym_property_declaration] = STATE(3324),
    [sym_variable_declaration] = STATE(8996),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(6582),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(6750),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_if] = STATE(3324),
    [sym_preproc_else] = STATE(9713),
    [sym_preproc_elif] = STATE(9713),
    [sym_preproc_region] = STATE(2263),
    [sym_preproc_endregion] = STATE(2263),
    [sym_preproc_line] = STATE(2263),
    [sym_preproc_pragma] = STATE(2263),
    [sym_preproc_nullable] = STATE(2263),
    [sym_preproc_error] = STATE(2263),
    [sym_preproc_warning] = STATE(2263),
    [sym_preproc_define] = STATE(2263),
    [sym_preproc_undef] = STATE(2263),
    [aux_sym_class_declaration_repeat1] = STATE(2781),
    [aux_sym_class_declaration_repeat2] = STATE(2857),
    [aux_sym_declaration_list_repeat1] = STATE(2422),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_extern] = ACTIONS(3195),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3199),
    [anon_sym_using] = ACTIONS(3201),
    [anon_sym_unsafe] = ACTIONS(65),
    [anon_sym_static] = ACTIONS(65),
    [anon_sym_LBRACK] = ACTIONS(3203),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_event] = ACTIONS(3207),
    [anon_sym_namespace] = ACTIONS(3209),
    [anon_sym_class] = ACTIONS(3211),
    [anon_sym_ref] = ACTIONS(3213),
    [anon_sym_struct] = ACTIONS(3215),
    [anon_sym_enum] = ACTIONS(3217),
    [anon_sym_interface] = ACTIONS(3219),
    [anon_sym_delegate] = ACTIONS(3221),
    [anon_sym_record] = ACTIONS(3223),
    [anon_sym_abstract] = ACTIONS(65),
    [anon_sym_async] = ACTIONS(65),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_file] = ACTIONS(3225),
    [anon_sym_fixed] = ACTIONS(65),
    [anon_sym_internal] = ACTIONS(65),
    [anon_sym_new] = ACTIONS(65),
    [anon_sym_override] = ACTIONS(65),
    [anon_sym_partial] = ACTIONS(65),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_public] = ACTIONS(65),
    [anon_sym_readonly] = ACTIONS(65),
    [anon_sym_required] = ACTIONS(65),
    [anon_sym_sealed] = ACTIONS(65),
    [anon_sym_virtual] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_TILDE] = ACTIONS(3227),
    [anon_sym_implicit] = ACTIONS(3229),
    [anon_sym_explicit] = ACTIONS(3229),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_if_token1] = ACTIONS(3237),
    [aux_sym_preproc_if_token3] = ACTIONS(3259),
    [aux_sym_preproc_else_token1] = ACTIONS(3241),
    [aux_sym_preproc_elif_token1] = ACTIONS(3243),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2264] = {
    [sym_preproc_region] = STATE(2264),
    [sym_preproc_endregion] = STATE(2264),
    [sym_preproc_line] = STATE(2264),
    [sym_preproc_pragma] = STATE(2264),
    [sym_preproc_nullable] = STATE(2264),
    [sym_preproc_error] = STATE(2264),
    [sym_preproc_warning] = STATE(2264),
    [sym_preproc_define] = STATE(2264),
    [sym_preproc_undef] = STATE(2264),
    [sym__identifier_token] = ACTIONS(3261),
    [anon_sym_extern] = ACTIONS(3261),
    [anon_sym_alias] = ACTIONS(3261),
    [anon_sym_SEMI] = ACTIONS(3263),
    [anon_sym_global] = ACTIONS(3261),
    [anon_sym_using] = ACTIONS(3261),
    [anon_sym_unsafe] = ACTIONS(3261),
    [anon_sym_static] = ACTIONS(3261),
    [anon_sym_LBRACK] = ACTIONS(3263),
    [anon_sym_LPAREN] = ACTIONS(3263),
    [anon_sym_return] = ACTIONS(3261),
    [anon_sym_namespace] = ACTIONS(3261),
    [anon_sym_class] = ACTIONS(3261),
    [anon_sym_ref] = ACTIONS(3261),
    [anon_sym_struct] = ACTIONS(3261),
    [anon_sym_enum] = ACTIONS(3261),
    [anon_sym_LBRACE] = ACTIONS(3263),
    [anon_sym_interface] = ACTIONS(3261),
    [anon_sym_delegate] = ACTIONS(3261),
    [anon_sym_record] = ACTIONS(3261),
    [anon_sym_abstract] = ACTIONS(3261),
    [anon_sym_async] = ACTIONS(3261),
    [anon_sym_const] = ACTIONS(3261),
    [anon_sym_file] = ACTIONS(3261),
    [anon_sym_fixed] = ACTIONS(3261),
    [anon_sym_internal] = ACTIONS(3261),
    [anon_sym_new] = ACTIONS(3261),
    [anon_sym_override] = ACTIONS(3261),
    [anon_sym_partial] = ACTIONS(3261),
    [anon_sym_private] = ACTIONS(3261),
    [anon_sym_protected] = ACTIONS(3261),
    [anon_sym_public] = ACTIONS(3261),
    [anon_sym_readonly] = ACTIONS(3261),
    [anon_sym_required] = ACTIONS(3261),
    [anon_sym_sealed] = ACTIONS(3261),
    [anon_sym_virtual] = ACTIONS(3261),
    [anon_sym_volatile] = ACTIONS(3261),
    [anon_sym_where] = ACTIONS(3261),
    [anon_sym_notnull] = ACTIONS(3261),
    [anon_sym_unmanaged] = ACTIONS(3261),
    [anon_sym_checked] = ACTIONS(3261),
    [anon_sym_BANG] = ACTIONS(3263),
    [anon_sym_TILDE] = ACTIONS(3263),
    [anon_sym_PLUS_PLUS] = ACTIONS(3263),
    [anon_sym_DASH_DASH] = ACTIONS(3263),
    [anon_sym_true] = ACTIONS(3261),
    [anon_sym_false] = ACTIONS(3261),
    [anon_sym_PLUS] = ACTIONS(3261),
    [anon_sym_DASH] = ACTIONS(3261),
    [anon_sym_STAR] = ACTIONS(3263),
    [anon_sym_CARET] = ACTIONS(3263),
    [anon_sym_AMP] = ACTIONS(3263),
    [anon_sym_this] = ACTIONS(3261),
    [anon_sym_scoped] = ACTIONS(3261),
    [anon_sym_base] = ACTIONS(3261),
    [anon_sym_var] = ACTIONS(3261),
    [sym_predefined_type] = ACTIONS(3261),
    [anon_sym_break] = ACTIONS(3261),
    [anon_sym_unchecked] = ACTIONS(3261),
    [anon_sym_continue] = ACTIONS(3261),
    [anon_sym_do] = ACTIONS(3261),
    [anon_sym_while] = ACTIONS(3261),
    [anon_sym_for] = ACTIONS(3261),
    [anon_sym_lock] = ACTIONS(3261),
    [anon_sym_yield] = ACTIONS(3261),
    [anon_sym_switch] = ACTIONS(3261),
    [anon_sym_default] = ACTIONS(3261),
    [anon_sym_throw] = ACTIONS(3261),
    [anon_sym_try] = ACTIONS(3261),
    [anon_sym_when] = ACTIONS(3261),
    [anon_sym_await] = ACTIONS(3261),
    [anon_sym_foreach] = ACTIONS(3261),
    [anon_sym_goto] = ACTIONS(3261),
    [anon_sym_if] = ACTIONS(3261),
    [anon_sym_else] = ACTIONS(3261),
    [anon_sym_DOT_DOT] = ACTIONS(3263),
    [anon_sym_from] = ACTIONS(3261),
    [anon_sym_into] = ACTIONS(3261),
    [anon_sym_join] = ACTIONS(3261),
    [anon_sym_on] = ACTIONS(3261),
    [anon_sym_equals] = ACTIONS(3261),
    [anon_sym_let] = ACTIONS(3261),
    [anon_sym_orderby] = ACTIONS(3261),
    [anon_sym_ascending] = ACTIONS(3261),
    [anon_sym_descending] = ACTIONS(3261),
    [anon_sym_group] = ACTIONS(3261),
    [anon_sym_by] = ACTIONS(3261),
    [anon_sym_select] = ACTIONS(3261),
    [anon_sym_stackalloc] = ACTIONS(3261),
    [anon_sym_sizeof] = ACTIONS(3261),
    [anon_sym_typeof] = ACTIONS(3261),
    [anon_sym___makeref] = ACTIONS(3261),
    [anon_sym___reftype] = ACTIONS(3261),
    [anon_sym___refvalue] = ACTIONS(3261),
    [sym_null_literal] = ACTIONS(3261),
    [anon_sym_SQUOTE] = ACTIONS(3263),
    [sym_integer_literal] = ACTIONS(3261),
    [sym_real_literal] = ACTIONS(3263),
    [anon_sym_DQUOTE] = ACTIONS(3263),
    [sym_verbatim_string_literal] = ACTIONS(3263),
    [aux_sym_preproc_if_token1] = ACTIONS(3263),
    [aux_sym_preproc_if_token3] = ACTIONS(3263),
    [aux_sym_preproc_else_token1] = ACTIONS(3263),
    [aux_sym_preproc_elif_token1] = ACTIONS(3263),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3263),
    [sym_interpolation_verbatim_start] = ACTIONS(3263),
    [sym_interpolation_raw_start] = ACTIONS(3263),
    [sym_raw_string_start] = ACTIONS(3263),
  },
  [2265] = {
    [sym_preproc_region] = STATE(2265),
    [sym_preproc_endregion] = STATE(2265),
    [sym_preproc_line] = STATE(2265),
    [sym_preproc_pragma] = STATE(2265),
    [sym_preproc_nullable] = STATE(2265),
    [sym_preproc_error] = STATE(2265),
    [sym_preproc_warning] = STATE(2265),
    [sym_preproc_define] = STATE(2265),
    [sym_preproc_undef] = STATE(2265),
    [ts_builtin_sym_end] = ACTIONS(3043),
    [sym__identifier_token] = ACTIONS(3041),
    [anon_sym_extern] = ACTIONS(3041),
    [anon_sym_alias] = ACTIONS(3041),
    [anon_sym_SEMI] = ACTIONS(3043),
    [anon_sym_global] = ACTIONS(3041),
    [anon_sym_using] = ACTIONS(3041),
    [anon_sym_unsafe] = ACTIONS(3041),
    [anon_sym_static] = ACTIONS(3041),
    [anon_sym_LBRACK] = ACTIONS(3043),
    [anon_sym_LPAREN] = ACTIONS(3043),
    [anon_sym_return] = ACTIONS(3041),
    [anon_sym_namespace] = ACTIONS(3041),
    [anon_sym_class] = ACTIONS(3041),
    [anon_sym_ref] = ACTIONS(3041),
    [anon_sym_struct] = ACTIONS(3041),
    [anon_sym_enum] = ACTIONS(3041),
    [anon_sym_LBRACE] = ACTIONS(3043),
    [anon_sym_interface] = ACTIONS(3041),
    [anon_sym_delegate] = ACTIONS(3041),
    [anon_sym_record] = ACTIONS(3041),
    [anon_sym_abstract] = ACTIONS(3041),
    [anon_sym_async] = ACTIONS(3041),
    [anon_sym_const] = ACTIONS(3041),
    [anon_sym_file] = ACTIONS(3041),
    [anon_sym_fixed] = ACTIONS(3041),
    [anon_sym_internal] = ACTIONS(3041),
    [anon_sym_new] = ACTIONS(3041),
    [anon_sym_override] = ACTIONS(3041),
    [anon_sym_partial] = ACTIONS(3041),
    [anon_sym_private] = ACTIONS(3041),
    [anon_sym_protected] = ACTIONS(3041),
    [anon_sym_public] = ACTIONS(3041),
    [anon_sym_readonly] = ACTIONS(3041),
    [anon_sym_required] = ACTIONS(3041),
    [anon_sym_sealed] = ACTIONS(3041),
    [anon_sym_virtual] = ACTIONS(3041),
    [anon_sym_volatile] = ACTIONS(3041),
    [anon_sym_where] = ACTIONS(3041),
    [anon_sym_notnull] = ACTIONS(3041),
    [anon_sym_unmanaged] = ACTIONS(3041),
    [anon_sym_checked] = ACTIONS(3041),
    [anon_sym_BANG] = ACTIONS(3043),
    [anon_sym_TILDE] = ACTIONS(3043),
    [anon_sym_PLUS_PLUS] = ACTIONS(3043),
    [anon_sym_DASH_DASH] = ACTIONS(3043),
    [anon_sym_true] = ACTIONS(3041),
    [anon_sym_false] = ACTIONS(3041),
    [anon_sym_PLUS] = ACTIONS(3041),
    [anon_sym_DASH] = ACTIONS(3041),
    [anon_sym_STAR] = ACTIONS(3043),
    [anon_sym_CARET] = ACTIONS(3043),
    [anon_sym_AMP] = ACTIONS(3043),
    [anon_sym_this] = ACTIONS(3041),
    [anon_sym_scoped] = ACTIONS(3041),
    [anon_sym_base] = ACTIONS(3041),
    [anon_sym_var] = ACTIONS(3041),
    [sym_predefined_type] = ACTIONS(3041),
    [anon_sym_break] = ACTIONS(3041),
    [anon_sym_unchecked] = ACTIONS(3041),
    [anon_sym_continue] = ACTIONS(3041),
    [anon_sym_do] = ACTIONS(3041),
    [anon_sym_while] = ACTIONS(3041),
    [anon_sym_for] = ACTIONS(3041),
    [anon_sym_lock] = ACTIONS(3041),
    [anon_sym_yield] = ACTIONS(3041),
    [anon_sym_switch] = ACTIONS(3041),
    [anon_sym_default] = ACTIONS(3041),
    [anon_sym_throw] = ACTIONS(3041),
    [anon_sym_try] = ACTIONS(3041),
    [anon_sym_catch] = ACTIONS(3041),
    [anon_sym_when] = ACTIONS(3041),
    [anon_sym_finally] = ACTIONS(3041),
    [anon_sym_await] = ACTIONS(3041),
    [anon_sym_foreach] = ACTIONS(3041),
    [anon_sym_goto] = ACTIONS(3041),
    [anon_sym_if] = ACTIONS(3041),
    [anon_sym_else] = ACTIONS(3041),
    [anon_sym_DOT_DOT] = ACTIONS(3043),
    [anon_sym_from] = ACTIONS(3041),
    [anon_sym_into] = ACTIONS(3041),
    [anon_sym_join] = ACTIONS(3041),
    [anon_sym_on] = ACTIONS(3041),
    [anon_sym_equals] = ACTIONS(3041),
    [anon_sym_let] = ACTIONS(3041),
    [anon_sym_orderby] = ACTIONS(3041),
    [anon_sym_ascending] = ACTIONS(3041),
    [anon_sym_descending] = ACTIONS(3041),
    [anon_sym_group] = ACTIONS(3041),
    [anon_sym_by] = ACTIONS(3041),
    [anon_sym_select] = ACTIONS(3041),
    [anon_sym_stackalloc] = ACTIONS(3041),
    [anon_sym_sizeof] = ACTIONS(3041),
    [anon_sym_typeof] = ACTIONS(3041),
    [anon_sym___makeref] = ACTIONS(3041),
    [anon_sym___reftype] = ACTIONS(3041),
    [anon_sym___refvalue] = ACTIONS(3041),
    [sym_null_literal] = ACTIONS(3041),
    [anon_sym_SQUOTE] = ACTIONS(3043),
    [sym_integer_literal] = ACTIONS(3041),
    [sym_real_literal] = ACTIONS(3043),
    [anon_sym_DQUOTE] = ACTIONS(3043),
    [sym_verbatim_string_literal] = ACTIONS(3043),
    [aux_sym_preproc_if_token1] = ACTIONS(3043),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3043),
    [sym_interpolation_verbatim_start] = ACTIONS(3043),
    [sym_interpolation_raw_start] = ACTIONS(3043),
    [sym_raw_string_start] = ACTIONS(3043),
  },
  [2266] = {
    [sym_preproc_region] = STATE(2266),
    [sym_preproc_endregion] = STATE(2266),
    [sym_preproc_line] = STATE(2266),
    [sym_preproc_pragma] = STATE(2266),
    [sym_preproc_nullable] = STATE(2266),
    [sym_preproc_error] = STATE(2266),
    [sym_preproc_warning] = STATE(2266),
    [sym_preproc_define] = STATE(2266),
    [sym_preproc_undef] = STATE(2266),
    [sym__identifier_token] = ACTIONS(3265),
    [anon_sym_extern] = ACTIONS(3265),
    [anon_sym_alias] = ACTIONS(3265),
    [anon_sym_SEMI] = ACTIONS(3267),
    [anon_sym_global] = ACTIONS(3265),
    [anon_sym_using] = ACTIONS(3265),
    [anon_sym_unsafe] = ACTIONS(3265),
    [anon_sym_static] = ACTIONS(3265),
    [anon_sym_LBRACK] = ACTIONS(3267),
    [anon_sym_LPAREN] = ACTIONS(3267),
    [anon_sym_return] = ACTIONS(3265),
    [anon_sym_namespace] = ACTIONS(3265),
    [anon_sym_class] = ACTIONS(3265),
    [anon_sym_ref] = ACTIONS(3265),
    [anon_sym_struct] = ACTIONS(3265),
    [anon_sym_enum] = ACTIONS(3265),
    [anon_sym_LBRACE] = ACTIONS(3267),
    [anon_sym_interface] = ACTIONS(3265),
    [anon_sym_delegate] = ACTIONS(3265),
    [anon_sym_record] = ACTIONS(3265),
    [anon_sym_abstract] = ACTIONS(3265),
    [anon_sym_async] = ACTIONS(3265),
    [anon_sym_const] = ACTIONS(3265),
    [anon_sym_file] = ACTIONS(3265),
    [anon_sym_fixed] = ACTIONS(3265),
    [anon_sym_internal] = ACTIONS(3265),
    [anon_sym_new] = ACTIONS(3265),
    [anon_sym_override] = ACTIONS(3265),
    [anon_sym_partial] = ACTIONS(3265),
    [anon_sym_private] = ACTIONS(3265),
    [anon_sym_protected] = ACTIONS(3265),
    [anon_sym_public] = ACTIONS(3265),
    [anon_sym_readonly] = ACTIONS(3265),
    [anon_sym_required] = ACTIONS(3265),
    [anon_sym_sealed] = ACTIONS(3265),
    [anon_sym_virtual] = ACTIONS(3265),
    [anon_sym_volatile] = ACTIONS(3265),
    [anon_sym_where] = ACTIONS(3265),
    [anon_sym_notnull] = ACTIONS(3265),
    [anon_sym_unmanaged] = ACTIONS(3265),
    [anon_sym_checked] = ACTIONS(3265),
    [anon_sym_BANG] = ACTIONS(3267),
    [anon_sym_TILDE] = ACTIONS(3267),
    [anon_sym_PLUS_PLUS] = ACTIONS(3267),
    [anon_sym_DASH_DASH] = ACTIONS(3267),
    [anon_sym_true] = ACTIONS(3265),
    [anon_sym_false] = ACTIONS(3265),
    [anon_sym_PLUS] = ACTIONS(3265),
    [anon_sym_DASH] = ACTIONS(3265),
    [anon_sym_STAR] = ACTIONS(3267),
    [anon_sym_CARET] = ACTIONS(3267),
    [anon_sym_AMP] = ACTIONS(3267),
    [anon_sym_this] = ACTIONS(3265),
    [anon_sym_scoped] = ACTIONS(3265),
    [anon_sym_base] = ACTIONS(3265),
    [anon_sym_var] = ACTIONS(3265),
    [sym_predefined_type] = ACTIONS(3265),
    [anon_sym_break] = ACTIONS(3265),
    [anon_sym_unchecked] = ACTIONS(3265),
    [anon_sym_continue] = ACTIONS(3265),
    [anon_sym_do] = ACTIONS(3265),
    [anon_sym_while] = ACTIONS(3265),
    [anon_sym_for] = ACTIONS(3265),
    [anon_sym_lock] = ACTIONS(3265),
    [anon_sym_yield] = ACTIONS(3265),
    [anon_sym_switch] = ACTIONS(3265),
    [anon_sym_default] = ACTIONS(3265),
    [anon_sym_throw] = ACTIONS(3265),
    [anon_sym_try] = ACTIONS(3265),
    [anon_sym_when] = ACTIONS(3265),
    [anon_sym_await] = ACTIONS(3265),
    [anon_sym_foreach] = ACTIONS(3265),
    [anon_sym_goto] = ACTIONS(3265),
    [anon_sym_if] = ACTIONS(3265),
    [anon_sym_else] = ACTIONS(3265),
    [anon_sym_DOT_DOT] = ACTIONS(3267),
    [anon_sym_from] = ACTIONS(3265),
    [anon_sym_into] = ACTIONS(3265),
    [anon_sym_join] = ACTIONS(3265),
    [anon_sym_on] = ACTIONS(3265),
    [anon_sym_equals] = ACTIONS(3265),
    [anon_sym_let] = ACTIONS(3265),
    [anon_sym_orderby] = ACTIONS(3265),
    [anon_sym_ascending] = ACTIONS(3265),
    [anon_sym_descending] = ACTIONS(3265),
    [anon_sym_group] = ACTIONS(3265),
    [anon_sym_by] = ACTIONS(3265),
    [anon_sym_select] = ACTIONS(3265),
    [anon_sym_stackalloc] = ACTIONS(3265),
    [anon_sym_sizeof] = ACTIONS(3265),
    [anon_sym_typeof] = ACTIONS(3265),
    [anon_sym___makeref] = ACTIONS(3265),
    [anon_sym___reftype] = ACTIONS(3265),
    [anon_sym___refvalue] = ACTIONS(3265),
    [sym_null_literal] = ACTIONS(3265),
    [anon_sym_SQUOTE] = ACTIONS(3267),
    [sym_integer_literal] = ACTIONS(3265),
    [sym_real_literal] = ACTIONS(3267),
    [anon_sym_DQUOTE] = ACTIONS(3267),
    [sym_verbatim_string_literal] = ACTIONS(3267),
    [aux_sym_preproc_if_token1] = ACTIONS(3267),
    [aux_sym_preproc_if_token3] = ACTIONS(3267),
    [aux_sym_preproc_else_token1] = ACTIONS(3267),
    [aux_sym_preproc_elif_token1] = ACTIONS(3267),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3267),
    [sym_interpolation_verbatim_start] = ACTIONS(3267),
    [sym_interpolation_raw_start] = ACTIONS(3267),
    [sym_raw_string_start] = ACTIONS(3267),
  },
  [2267] = {
    [sym_preproc_region] = STATE(2267),
    [sym_preproc_endregion] = STATE(2267),
    [sym_preproc_line] = STATE(2267),
    [sym_preproc_pragma] = STATE(2267),
    [sym_preproc_nullable] = STATE(2267),
    [sym_preproc_error] = STATE(2267),
    [sym_preproc_warning] = STATE(2267),
    [sym_preproc_define] = STATE(2267),
    [sym_preproc_undef] = STATE(2267),
    [sym__identifier_token] = ACTIONS(3269),
    [anon_sym_extern] = ACTIONS(3269),
    [anon_sym_alias] = ACTIONS(3269),
    [anon_sym_SEMI] = ACTIONS(3271),
    [anon_sym_global] = ACTIONS(3269),
    [anon_sym_using] = ACTIONS(3269),
    [anon_sym_unsafe] = ACTIONS(3269),
    [anon_sym_static] = ACTIONS(3269),
    [anon_sym_LBRACK] = ACTIONS(3271),
    [anon_sym_LPAREN] = ACTIONS(3271),
    [anon_sym_return] = ACTIONS(3269),
    [anon_sym_namespace] = ACTIONS(3269),
    [anon_sym_class] = ACTIONS(3269),
    [anon_sym_ref] = ACTIONS(3269),
    [anon_sym_struct] = ACTIONS(3269),
    [anon_sym_enum] = ACTIONS(3269),
    [anon_sym_LBRACE] = ACTIONS(3271),
    [anon_sym_interface] = ACTIONS(3269),
    [anon_sym_delegate] = ACTIONS(3269),
    [anon_sym_record] = ACTIONS(3269),
    [anon_sym_abstract] = ACTIONS(3269),
    [anon_sym_async] = ACTIONS(3269),
    [anon_sym_const] = ACTIONS(3269),
    [anon_sym_file] = ACTIONS(3269),
    [anon_sym_fixed] = ACTIONS(3269),
    [anon_sym_internal] = ACTIONS(3269),
    [anon_sym_new] = ACTIONS(3269),
    [anon_sym_override] = ACTIONS(3269),
    [anon_sym_partial] = ACTIONS(3269),
    [anon_sym_private] = ACTIONS(3269),
    [anon_sym_protected] = ACTIONS(3269),
    [anon_sym_public] = ACTIONS(3269),
    [anon_sym_readonly] = ACTIONS(3269),
    [anon_sym_required] = ACTIONS(3269),
    [anon_sym_sealed] = ACTIONS(3269),
    [anon_sym_virtual] = ACTIONS(3269),
    [anon_sym_volatile] = ACTIONS(3269),
    [anon_sym_where] = ACTIONS(3269),
    [anon_sym_notnull] = ACTIONS(3269),
    [anon_sym_unmanaged] = ACTIONS(3269),
    [anon_sym_checked] = ACTIONS(3269),
    [anon_sym_BANG] = ACTIONS(3271),
    [anon_sym_TILDE] = ACTIONS(3271),
    [anon_sym_PLUS_PLUS] = ACTIONS(3271),
    [anon_sym_DASH_DASH] = ACTIONS(3271),
    [anon_sym_true] = ACTIONS(3269),
    [anon_sym_false] = ACTIONS(3269),
    [anon_sym_PLUS] = ACTIONS(3269),
    [anon_sym_DASH] = ACTIONS(3269),
    [anon_sym_STAR] = ACTIONS(3271),
    [anon_sym_CARET] = ACTIONS(3271),
    [anon_sym_AMP] = ACTIONS(3271),
    [anon_sym_this] = ACTIONS(3269),
    [anon_sym_scoped] = ACTIONS(3269),
    [anon_sym_base] = ACTIONS(3269),
    [anon_sym_var] = ACTIONS(3269),
    [sym_predefined_type] = ACTIONS(3269),
    [anon_sym_break] = ACTIONS(3269),
    [anon_sym_unchecked] = ACTIONS(3269),
    [anon_sym_continue] = ACTIONS(3269),
    [anon_sym_do] = ACTIONS(3269),
    [anon_sym_while] = ACTIONS(3269),
    [anon_sym_for] = ACTIONS(3269),
    [anon_sym_lock] = ACTIONS(3269),
    [anon_sym_yield] = ACTIONS(3269),
    [anon_sym_switch] = ACTIONS(3269),
    [anon_sym_default] = ACTIONS(3269),
    [anon_sym_throw] = ACTIONS(3269),
    [anon_sym_try] = ACTIONS(3269),
    [anon_sym_when] = ACTIONS(3269),
    [anon_sym_await] = ACTIONS(3269),
    [anon_sym_foreach] = ACTIONS(3269),
    [anon_sym_goto] = ACTIONS(3269),
    [anon_sym_if] = ACTIONS(3269),
    [anon_sym_else] = ACTIONS(3269),
    [anon_sym_DOT_DOT] = ACTIONS(3271),
    [anon_sym_from] = ACTIONS(3269),
    [anon_sym_into] = ACTIONS(3269),
    [anon_sym_join] = ACTIONS(3269),
    [anon_sym_on] = ACTIONS(3269),
    [anon_sym_equals] = ACTIONS(3269),
    [anon_sym_let] = ACTIONS(3269),
    [anon_sym_orderby] = ACTIONS(3269),
    [anon_sym_ascending] = ACTIONS(3269),
    [anon_sym_descending] = ACTIONS(3269),
    [anon_sym_group] = ACTIONS(3269),
    [anon_sym_by] = ACTIONS(3269),
    [anon_sym_select] = ACTIONS(3269),
    [anon_sym_stackalloc] = ACTIONS(3269),
    [anon_sym_sizeof] = ACTIONS(3269),
    [anon_sym_typeof] = ACTIONS(3269),
    [anon_sym___makeref] = ACTIONS(3269),
    [anon_sym___reftype] = ACTIONS(3269),
    [anon_sym___refvalue] = ACTIONS(3269),
    [sym_null_literal] = ACTIONS(3269),
    [anon_sym_SQUOTE] = ACTIONS(3271),
    [sym_integer_literal] = ACTIONS(3269),
    [sym_real_literal] = ACTIONS(3271),
    [anon_sym_DQUOTE] = ACTIONS(3271),
    [sym_verbatim_string_literal] = ACTIONS(3271),
    [aux_sym_preproc_if_token1] = ACTIONS(3271),
    [aux_sym_preproc_if_token3] = ACTIONS(3271),
    [aux_sym_preproc_else_token1] = ACTIONS(3271),
    [aux_sym_preproc_elif_token1] = ACTIONS(3271),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3271),
    [sym_interpolation_verbatim_start] = ACTIONS(3271),
    [sym_interpolation_raw_start] = ACTIONS(3271),
    [sym_raw_string_start] = ACTIONS(3271),
  },
  [2268] = {
    [sym_preproc_region] = STATE(2268),
    [sym_preproc_endregion] = STATE(2268),
    [sym_preproc_line] = STATE(2268),
    [sym_preproc_pragma] = STATE(2268),
    [sym_preproc_nullable] = STATE(2268),
    [sym_preproc_error] = STATE(2268),
    [sym_preproc_warning] = STATE(2268),
    [sym_preproc_define] = STATE(2268),
    [sym_preproc_undef] = STATE(2268),
    [ts_builtin_sym_end] = ACTIONS(3039),
    [sym__identifier_token] = ACTIONS(3037),
    [anon_sym_extern] = ACTIONS(3037),
    [anon_sym_alias] = ACTIONS(3037),
    [anon_sym_SEMI] = ACTIONS(3039),
    [anon_sym_global] = ACTIONS(3037),
    [anon_sym_using] = ACTIONS(3037),
    [anon_sym_unsafe] = ACTIONS(3037),
    [anon_sym_static] = ACTIONS(3037),
    [anon_sym_LBRACK] = ACTIONS(3039),
    [anon_sym_LPAREN] = ACTIONS(3039),
    [anon_sym_return] = ACTIONS(3037),
    [anon_sym_namespace] = ACTIONS(3037),
    [anon_sym_class] = ACTIONS(3037),
    [anon_sym_ref] = ACTIONS(3037),
    [anon_sym_struct] = ACTIONS(3037),
    [anon_sym_enum] = ACTIONS(3037),
    [anon_sym_LBRACE] = ACTIONS(3039),
    [anon_sym_interface] = ACTIONS(3037),
    [anon_sym_delegate] = ACTIONS(3037),
    [anon_sym_record] = ACTIONS(3037),
    [anon_sym_abstract] = ACTIONS(3037),
    [anon_sym_async] = ACTIONS(3037),
    [anon_sym_const] = ACTIONS(3037),
    [anon_sym_file] = ACTIONS(3037),
    [anon_sym_fixed] = ACTIONS(3037),
    [anon_sym_internal] = ACTIONS(3037),
    [anon_sym_new] = ACTIONS(3037),
    [anon_sym_override] = ACTIONS(3037),
    [anon_sym_partial] = ACTIONS(3037),
    [anon_sym_private] = ACTIONS(3037),
    [anon_sym_protected] = ACTIONS(3037),
    [anon_sym_public] = ACTIONS(3037),
    [anon_sym_readonly] = ACTIONS(3037),
    [anon_sym_required] = ACTIONS(3037),
    [anon_sym_sealed] = ACTIONS(3037),
    [anon_sym_virtual] = ACTIONS(3037),
    [anon_sym_volatile] = ACTIONS(3037),
    [anon_sym_where] = ACTIONS(3037),
    [anon_sym_notnull] = ACTIONS(3037),
    [anon_sym_unmanaged] = ACTIONS(3037),
    [anon_sym_checked] = ACTIONS(3037),
    [anon_sym_BANG] = ACTIONS(3039),
    [anon_sym_TILDE] = ACTIONS(3039),
    [anon_sym_PLUS_PLUS] = ACTIONS(3039),
    [anon_sym_DASH_DASH] = ACTIONS(3039),
    [anon_sym_true] = ACTIONS(3037),
    [anon_sym_false] = ACTIONS(3037),
    [anon_sym_PLUS] = ACTIONS(3037),
    [anon_sym_DASH] = ACTIONS(3037),
    [anon_sym_STAR] = ACTIONS(3039),
    [anon_sym_CARET] = ACTIONS(3039),
    [anon_sym_AMP] = ACTIONS(3039),
    [anon_sym_this] = ACTIONS(3037),
    [anon_sym_scoped] = ACTIONS(3037),
    [anon_sym_base] = ACTIONS(3037),
    [anon_sym_var] = ACTIONS(3037),
    [sym_predefined_type] = ACTIONS(3037),
    [anon_sym_break] = ACTIONS(3037),
    [anon_sym_unchecked] = ACTIONS(3037),
    [anon_sym_continue] = ACTIONS(3037),
    [anon_sym_do] = ACTIONS(3037),
    [anon_sym_while] = ACTIONS(3037),
    [anon_sym_for] = ACTIONS(3037),
    [anon_sym_lock] = ACTIONS(3037),
    [anon_sym_yield] = ACTIONS(3037),
    [anon_sym_switch] = ACTIONS(3037),
    [anon_sym_default] = ACTIONS(3037),
    [anon_sym_throw] = ACTIONS(3037),
    [anon_sym_try] = ACTIONS(3037),
    [anon_sym_catch] = ACTIONS(3037),
    [anon_sym_when] = ACTIONS(3037),
    [anon_sym_finally] = ACTIONS(3037),
    [anon_sym_await] = ACTIONS(3037),
    [anon_sym_foreach] = ACTIONS(3037),
    [anon_sym_goto] = ACTIONS(3037),
    [anon_sym_if] = ACTIONS(3037),
    [anon_sym_else] = ACTIONS(3037),
    [anon_sym_DOT_DOT] = ACTIONS(3039),
    [anon_sym_from] = ACTIONS(3037),
    [anon_sym_into] = ACTIONS(3037),
    [anon_sym_join] = ACTIONS(3037),
    [anon_sym_on] = ACTIONS(3037),
    [anon_sym_equals] = ACTIONS(3037),
    [anon_sym_let] = ACTIONS(3037),
    [anon_sym_orderby] = ACTIONS(3037),
    [anon_sym_ascending] = ACTIONS(3037),
    [anon_sym_descending] = ACTIONS(3037),
    [anon_sym_group] = ACTIONS(3037),
    [anon_sym_by] = ACTIONS(3037),
    [anon_sym_select] = ACTIONS(3037),
    [anon_sym_stackalloc] = ACTIONS(3037),
    [anon_sym_sizeof] = ACTIONS(3037),
    [anon_sym_typeof] = ACTIONS(3037),
    [anon_sym___makeref] = ACTIONS(3037),
    [anon_sym___reftype] = ACTIONS(3037),
    [anon_sym___refvalue] = ACTIONS(3037),
    [sym_null_literal] = ACTIONS(3037),
    [anon_sym_SQUOTE] = ACTIONS(3039),
    [sym_integer_literal] = ACTIONS(3037),
    [sym_real_literal] = ACTIONS(3039),
    [anon_sym_DQUOTE] = ACTIONS(3039),
    [sym_verbatim_string_literal] = ACTIONS(3039),
    [aux_sym_preproc_if_token1] = ACTIONS(3039),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3039),
    [sym_interpolation_verbatim_start] = ACTIONS(3039),
    [sym_interpolation_raw_start] = ACTIONS(3039),
    [sym_raw_string_start] = ACTIONS(3039),
  },
  [2269] = {
    [sym_preproc_region] = STATE(2269),
    [sym_preproc_endregion] = STATE(2269),
    [sym_preproc_line] = STATE(2269),
    [sym_preproc_pragma] = STATE(2269),
    [sym_preproc_nullable] = STATE(2269),
    [sym_preproc_error] = STATE(2269),
    [sym_preproc_warning] = STATE(2269),
    [sym_preproc_define] = STATE(2269),
    [sym_preproc_undef] = STATE(2269),
    [sym__identifier_token] = ACTIONS(3273),
    [anon_sym_extern] = ACTIONS(3273),
    [anon_sym_alias] = ACTIONS(3273),
    [anon_sym_SEMI] = ACTIONS(3275),
    [anon_sym_global] = ACTIONS(3273),
    [anon_sym_using] = ACTIONS(3273),
    [anon_sym_unsafe] = ACTIONS(3273),
    [anon_sym_static] = ACTIONS(3273),
    [anon_sym_LBRACK] = ACTIONS(3275),
    [anon_sym_LPAREN] = ACTIONS(3275),
    [anon_sym_return] = ACTIONS(3273),
    [anon_sym_namespace] = ACTIONS(3273),
    [anon_sym_class] = ACTIONS(3273),
    [anon_sym_ref] = ACTIONS(3273),
    [anon_sym_struct] = ACTIONS(3273),
    [anon_sym_enum] = ACTIONS(3273),
    [anon_sym_LBRACE] = ACTIONS(3275),
    [anon_sym_interface] = ACTIONS(3273),
    [anon_sym_delegate] = ACTIONS(3273),
    [anon_sym_record] = ACTIONS(3273),
    [anon_sym_abstract] = ACTIONS(3273),
    [anon_sym_async] = ACTIONS(3273),
    [anon_sym_const] = ACTIONS(3273),
    [anon_sym_file] = ACTIONS(3273),
    [anon_sym_fixed] = ACTIONS(3273),
    [anon_sym_internal] = ACTIONS(3273),
    [anon_sym_new] = ACTIONS(3273),
    [anon_sym_override] = ACTIONS(3273),
    [anon_sym_partial] = ACTIONS(3273),
    [anon_sym_private] = ACTIONS(3273),
    [anon_sym_protected] = ACTIONS(3273),
    [anon_sym_public] = ACTIONS(3273),
    [anon_sym_readonly] = ACTIONS(3273),
    [anon_sym_required] = ACTIONS(3273),
    [anon_sym_sealed] = ACTIONS(3273),
    [anon_sym_virtual] = ACTIONS(3273),
    [anon_sym_volatile] = ACTIONS(3273),
    [anon_sym_where] = ACTIONS(3273),
    [anon_sym_notnull] = ACTIONS(3273),
    [anon_sym_unmanaged] = ACTIONS(3273),
    [anon_sym_checked] = ACTIONS(3273),
    [anon_sym_BANG] = ACTIONS(3275),
    [anon_sym_TILDE] = ACTIONS(3275),
    [anon_sym_PLUS_PLUS] = ACTIONS(3275),
    [anon_sym_DASH_DASH] = ACTIONS(3275),
    [anon_sym_true] = ACTIONS(3273),
    [anon_sym_false] = ACTIONS(3273),
    [anon_sym_PLUS] = ACTIONS(3273),
    [anon_sym_DASH] = ACTIONS(3273),
    [anon_sym_STAR] = ACTIONS(3275),
    [anon_sym_CARET] = ACTIONS(3275),
    [anon_sym_AMP] = ACTIONS(3275),
    [anon_sym_this] = ACTIONS(3273),
    [anon_sym_scoped] = ACTIONS(3273),
    [anon_sym_base] = ACTIONS(3273),
    [anon_sym_var] = ACTIONS(3273),
    [sym_predefined_type] = ACTIONS(3273),
    [anon_sym_break] = ACTIONS(3273),
    [anon_sym_unchecked] = ACTIONS(3273),
    [anon_sym_continue] = ACTIONS(3273),
    [anon_sym_do] = ACTIONS(3273),
    [anon_sym_while] = ACTIONS(3273),
    [anon_sym_for] = ACTIONS(3273),
    [anon_sym_lock] = ACTIONS(3273),
    [anon_sym_yield] = ACTIONS(3273),
    [anon_sym_switch] = ACTIONS(3273),
    [anon_sym_default] = ACTIONS(3273),
    [anon_sym_throw] = ACTIONS(3273),
    [anon_sym_try] = ACTIONS(3273),
    [anon_sym_when] = ACTIONS(3273),
    [anon_sym_await] = ACTIONS(3273),
    [anon_sym_foreach] = ACTIONS(3273),
    [anon_sym_goto] = ACTIONS(3273),
    [anon_sym_if] = ACTIONS(3273),
    [anon_sym_else] = ACTIONS(3273),
    [anon_sym_DOT_DOT] = ACTIONS(3275),
    [anon_sym_from] = ACTIONS(3273),
    [anon_sym_into] = ACTIONS(3273),
    [anon_sym_join] = ACTIONS(3273),
    [anon_sym_on] = ACTIONS(3273),
    [anon_sym_equals] = ACTIONS(3273),
    [anon_sym_let] = ACTIONS(3273),
    [anon_sym_orderby] = ACTIONS(3273),
    [anon_sym_ascending] = ACTIONS(3273),
    [anon_sym_descending] = ACTIONS(3273),
    [anon_sym_group] = ACTIONS(3273),
    [anon_sym_by] = ACTIONS(3273),
    [anon_sym_select] = ACTIONS(3273),
    [anon_sym_stackalloc] = ACTIONS(3273),
    [anon_sym_sizeof] = ACTIONS(3273),
    [anon_sym_typeof] = ACTIONS(3273),
    [anon_sym___makeref] = ACTIONS(3273),
    [anon_sym___reftype] = ACTIONS(3273),
    [anon_sym___refvalue] = ACTIONS(3273),
    [sym_null_literal] = ACTIONS(3273),
    [anon_sym_SQUOTE] = ACTIONS(3275),
    [sym_integer_literal] = ACTIONS(3273),
    [sym_real_literal] = ACTIONS(3275),
    [anon_sym_DQUOTE] = ACTIONS(3275),
    [sym_verbatim_string_literal] = ACTIONS(3275),
    [aux_sym_preproc_if_token1] = ACTIONS(3275),
    [aux_sym_preproc_if_token3] = ACTIONS(3275),
    [aux_sym_preproc_else_token1] = ACTIONS(3275),
    [aux_sym_preproc_elif_token1] = ACTIONS(3275),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3275),
    [sym_interpolation_verbatim_start] = ACTIONS(3275),
    [sym_interpolation_raw_start] = ACTIONS(3275),
    [sym_raw_string_start] = ACTIONS(3275),
  },
  [2270] = {
    [sym_preproc_region] = STATE(2270),
    [sym_preproc_endregion] = STATE(2270),
    [sym_preproc_line] = STATE(2270),
    [sym_preproc_pragma] = STATE(2270),
    [sym_preproc_nullable] = STATE(2270),
    [sym_preproc_error] = STATE(2270),
    [sym_preproc_warning] = STATE(2270),
    [sym_preproc_define] = STATE(2270),
    [sym_preproc_undef] = STATE(2270),
    [sym__identifier_token] = ACTIONS(3277),
    [anon_sym_extern] = ACTIONS(3277),
    [anon_sym_alias] = ACTIONS(3277),
    [anon_sym_SEMI] = ACTIONS(3279),
    [anon_sym_global] = ACTIONS(3277),
    [anon_sym_using] = ACTIONS(3277),
    [anon_sym_unsafe] = ACTIONS(3277),
    [anon_sym_static] = ACTIONS(3277),
    [anon_sym_LBRACK] = ACTIONS(3279),
    [anon_sym_LPAREN] = ACTIONS(3279),
    [anon_sym_return] = ACTIONS(3277),
    [anon_sym_namespace] = ACTIONS(3277),
    [anon_sym_class] = ACTIONS(3277),
    [anon_sym_ref] = ACTIONS(3277),
    [anon_sym_struct] = ACTIONS(3277),
    [anon_sym_enum] = ACTIONS(3277),
    [anon_sym_LBRACE] = ACTIONS(3279),
    [anon_sym_interface] = ACTIONS(3277),
    [anon_sym_delegate] = ACTIONS(3277),
    [anon_sym_record] = ACTIONS(3277),
    [anon_sym_abstract] = ACTIONS(3277),
    [anon_sym_async] = ACTIONS(3277),
    [anon_sym_const] = ACTIONS(3277),
    [anon_sym_file] = ACTIONS(3277),
    [anon_sym_fixed] = ACTIONS(3277),
    [anon_sym_internal] = ACTIONS(3277),
    [anon_sym_new] = ACTIONS(3277),
    [anon_sym_override] = ACTIONS(3277),
    [anon_sym_partial] = ACTIONS(3277),
    [anon_sym_private] = ACTIONS(3277),
    [anon_sym_protected] = ACTIONS(3277),
    [anon_sym_public] = ACTIONS(3277),
    [anon_sym_readonly] = ACTIONS(3277),
    [anon_sym_required] = ACTIONS(3277),
    [anon_sym_sealed] = ACTIONS(3277),
    [anon_sym_virtual] = ACTIONS(3277),
    [anon_sym_volatile] = ACTIONS(3277),
    [anon_sym_where] = ACTIONS(3277),
    [anon_sym_notnull] = ACTIONS(3277),
    [anon_sym_unmanaged] = ACTIONS(3277),
    [anon_sym_checked] = ACTIONS(3277),
    [anon_sym_BANG] = ACTIONS(3279),
    [anon_sym_TILDE] = ACTIONS(3279),
    [anon_sym_PLUS_PLUS] = ACTIONS(3279),
    [anon_sym_DASH_DASH] = ACTIONS(3279),
    [anon_sym_true] = ACTIONS(3277),
    [anon_sym_false] = ACTIONS(3277),
    [anon_sym_PLUS] = ACTIONS(3277),
    [anon_sym_DASH] = ACTIONS(3277),
    [anon_sym_STAR] = ACTIONS(3279),
    [anon_sym_CARET] = ACTIONS(3279),
    [anon_sym_AMP] = ACTIONS(3279),
    [anon_sym_this] = ACTIONS(3277),
    [anon_sym_scoped] = ACTIONS(3277),
    [anon_sym_base] = ACTIONS(3277),
    [anon_sym_var] = ACTIONS(3277),
    [sym_predefined_type] = ACTIONS(3277),
    [anon_sym_break] = ACTIONS(3277),
    [anon_sym_unchecked] = ACTIONS(3277),
    [anon_sym_continue] = ACTIONS(3277),
    [anon_sym_do] = ACTIONS(3277),
    [anon_sym_while] = ACTIONS(3277),
    [anon_sym_for] = ACTIONS(3277),
    [anon_sym_lock] = ACTIONS(3277),
    [anon_sym_yield] = ACTIONS(3277),
    [anon_sym_switch] = ACTIONS(3277),
    [anon_sym_default] = ACTIONS(3277),
    [anon_sym_throw] = ACTIONS(3277),
    [anon_sym_try] = ACTIONS(3277),
    [anon_sym_when] = ACTIONS(3277),
    [anon_sym_await] = ACTIONS(3277),
    [anon_sym_foreach] = ACTIONS(3277),
    [anon_sym_goto] = ACTIONS(3277),
    [anon_sym_if] = ACTIONS(3277),
    [anon_sym_else] = ACTIONS(3277),
    [anon_sym_DOT_DOT] = ACTIONS(3279),
    [anon_sym_from] = ACTIONS(3277),
    [anon_sym_into] = ACTIONS(3277),
    [anon_sym_join] = ACTIONS(3277),
    [anon_sym_on] = ACTIONS(3277),
    [anon_sym_equals] = ACTIONS(3277),
    [anon_sym_let] = ACTIONS(3277),
    [anon_sym_orderby] = ACTIONS(3277),
    [anon_sym_ascending] = ACTIONS(3277),
    [anon_sym_descending] = ACTIONS(3277),
    [anon_sym_group] = ACTIONS(3277),
    [anon_sym_by] = ACTIONS(3277),
    [anon_sym_select] = ACTIONS(3277),
    [anon_sym_stackalloc] = ACTIONS(3277),
    [anon_sym_sizeof] = ACTIONS(3277),
    [anon_sym_typeof] = ACTIONS(3277),
    [anon_sym___makeref] = ACTIONS(3277),
    [anon_sym___reftype] = ACTIONS(3277),
    [anon_sym___refvalue] = ACTIONS(3277),
    [sym_null_literal] = ACTIONS(3277),
    [anon_sym_SQUOTE] = ACTIONS(3279),
    [sym_integer_literal] = ACTIONS(3277),
    [sym_real_literal] = ACTIONS(3279),
    [anon_sym_DQUOTE] = ACTIONS(3279),
    [sym_verbatim_string_literal] = ACTIONS(3279),
    [aux_sym_preproc_if_token1] = ACTIONS(3279),
    [aux_sym_preproc_if_token3] = ACTIONS(3279),
    [aux_sym_preproc_else_token1] = ACTIONS(3279),
    [aux_sym_preproc_elif_token1] = ACTIONS(3279),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3279),
    [sym_interpolation_verbatim_start] = ACTIONS(3279),
    [sym_interpolation_raw_start] = ACTIONS(3279),
    [sym_raw_string_start] = ACTIONS(3279),
  },
  [2271] = {
    [sym_preproc_region] = STATE(2271),
    [sym_preproc_endregion] = STATE(2271),
    [sym_preproc_line] = STATE(2271),
    [sym_preproc_pragma] = STATE(2271),
    [sym_preproc_nullable] = STATE(2271),
    [sym_preproc_error] = STATE(2271),
    [sym_preproc_warning] = STATE(2271),
    [sym_preproc_define] = STATE(2271),
    [sym_preproc_undef] = STATE(2271),
    [sym__identifier_token] = ACTIONS(3281),
    [anon_sym_extern] = ACTIONS(3281),
    [anon_sym_alias] = ACTIONS(3281),
    [anon_sym_SEMI] = ACTIONS(3283),
    [anon_sym_global] = ACTIONS(3281),
    [anon_sym_using] = ACTIONS(3281),
    [anon_sym_unsafe] = ACTIONS(3281),
    [anon_sym_static] = ACTIONS(3281),
    [anon_sym_LBRACK] = ACTIONS(3283),
    [anon_sym_LPAREN] = ACTIONS(3283),
    [anon_sym_return] = ACTIONS(3281),
    [anon_sym_namespace] = ACTIONS(3281),
    [anon_sym_class] = ACTIONS(3281),
    [anon_sym_ref] = ACTIONS(3281),
    [anon_sym_struct] = ACTIONS(3281),
    [anon_sym_enum] = ACTIONS(3281),
    [anon_sym_LBRACE] = ACTIONS(3283),
    [anon_sym_interface] = ACTIONS(3281),
    [anon_sym_delegate] = ACTIONS(3281),
    [anon_sym_record] = ACTIONS(3281),
    [anon_sym_abstract] = ACTIONS(3281),
    [anon_sym_async] = ACTIONS(3281),
    [anon_sym_const] = ACTIONS(3281),
    [anon_sym_file] = ACTIONS(3281),
    [anon_sym_fixed] = ACTIONS(3281),
    [anon_sym_internal] = ACTIONS(3281),
    [anon_sym_new] = ACTIONS(3281),
    [anon_sym_override] = ACTIONS(3281),
    [anon_sym_partial] = ACTIONS(3281),
    [anon_sym_private] = ACTIONS(3281),
    [anon_sym_protected] = ACTIONS(3281),
    [anon_sym_public] = ACTIONS(3281),
    [anon_sym_readonly] = ACTIONS(3281),
    [anon_sym_required] = ACTIONS(3281),
    [anon_sym_sealed] = ACTIONS(3281),
    [anon_sym_virtual] = ACTIONS(3281),
    [anon_sym_volatile] = ACTIONS(3281),
    [anon_sym_where] = ACTIONS(3281),
    [anon_sym_notnull] = ACTIONS(3281),
    [anon_sym_unmanaged] = ACTIONS(3281),
    [anon_sym_checked] = ACTIONS(3281),
    [anon_sym_BANG] = ACTIONS(3283),
    [anon_sym_TILDE] = ACTIONS(3283),
    [anon_sym_PLUS_PLUS] = ACTIONS(3283),
    [anon_sym_DASH_DASH] = ACTIONS(3283),
    [anon_sym_true] = ACTIONS(3281),
    [anon_sym_false] = ACTIONS(3281),
    [anon_sym_PLUS] = ACTIONS(3281),
    [anon_sym_DASH] = ACTIONS(3281),
    [anon_sym_STAR] = ACTIONS(3283),
    [anon_sym_CARET] = ACTIONS(3283),
    [anon_sym_AMP] = ACTIONS(3283),
    [anon_sym_this] = ACTIONS(3281),
    [anon_sym_scoped] = ACTIONS(3281),
    [anon_sym_base] = ACTIONS(3281),
    [anon_sym_var] = ACTIONS(3281),
    [sym_predefined_type] = ACTIONS(3281),
    [anon_sym_break] = ACTIONS(3281),
    [anon_sym_unchecked] = ACTIONS(3281),
    [anon_sym_continue] = ACTIONS(3281),
    [anon_sym_do] = ACTIONS(3281),
    [anon_sym_while] = ACTIONS(3281),
    [anon_sym_for] = ACTIONS(3281),
    [anon_sym_lock] = ACTIONS(3281),
    [anon_sym_yield] = ACTIONS(3281),
    [anon_sym_switch] = ACTIONS(3281),
    [anon_sym_default] = ACTIONS(3281),
    [anon_sym_throw] = ACTIONS(3281),
    [anon_sym_try] = ACTIONS(3281),
    [anon_sym_when] = ACTIONS(3281),
    [anon_sym_await] = ACTIONS(3281),
    [anon_sym_foreach] = ACTIONS(3281),
    [anon_sym_goto] = ACTIONS(3281),
    [anon_sym_if] = ACTIONS(3281),
    [anon_sym_else] = ACTIONS(3281),
    [anon_sym_DOT_DOT] = ACTIONS(3283),
    [anon_sym_from] = ACTIONS(3281),
    [anon_sym_into] = ACTIONS(3281),
    [anon_sym_join] = ACTIONS(3281),
    [anon_sym_on] = ACTIONS(3281),
    [anon_sym_equals] = ACTIONS(3281),
    [anon_sym_let] = ACTIONS(3281),
    [anon_sym_orderby] = ACTIONS(3281),
    [anon_sym_ascending] = ACTIONS(3281),
    [anon_sym_descending] = ACTIONS(3281),
    [anon_sym_group] = ACTIONS(3281),
    [anon_sym_by] = ACTIONS(3281),
    [anon_sym_select] = ACTIONS(3281),
    [anon_sym_stackalloc] = ACTIONS(3281),
    [anon_sym_sizeof] = ACTIONS(3281),
    [anon_sym_typeof] = ACTIONS(3281),
    [anon_sym___makeref] = ACTIONS(3281),
    [anon_sym___reftype] = ACTIONS(3281),
    [anon_sym___refvalue] = ACTIONS(3281),
    [sym_null_literal] = ACTIONS(3281),
    [anon_sym_SQUOTE] = ACTIONS(3283),
    [sym_integer_literal] = ACTIONS(3281),
    [sym_real_literal] = ACTIONS(3283),
    [anon_sym_DQUOTE] = ACTIONS(3283),
    [sym_verbatim_string_literal] = ACTIONS(3283),
    [aux_sym_preproc_if_token1] = ACTIONS(3283),
    [aux_sym_preproc_if_token3] = ACTIONS(3283),
    [aux_sym_preproc_else_token1] = ACTIONS(3283),
    [aux_sym_preproc_elif_token1] = ACTIONS(3283),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3283),
    [sym_interpolation_verbatim_start] = ACTIONS(3283),
    [sym_interpolation_raw_start] = ACTIONS(3283),
    [sym_raw_string_start] = ACTIONS(3283),
  },
  [2272] = {
    [sym_preproc_region] = STATE(2272),
    [sym_preproc_endregion] = STATE(2272),
    [sym_preproc_line] = STATE(2272),
    [sym_preproc_pragma] = STATE(2272),
    [sym_preproc_nullable] = STATE(2272),
    [sym_preproc_error] = STATE(2272),
    [sym_preproc_warning] = STATE(2272),
    [sym_preproc_define] = STATE(2272),
    [sym_preproc_undef] = STATE(2272),
    [sym__identifier_token] = ACTIONS(3285),
    [anon_sym_extern] = ACTIONS(3285),
    [anon_sym_alias] = ACTIONS(3285),
    [anon_sym_SEMI] = ACTIONS(3287),
    [anon_sym_global] = ACTIONS(3285),
    [anon_sym_using] = ACTIONS(3285),
    [anon_sym_unsafe] = ACTIONS(3285),
    [anon_sym_static] = ACTIONS(3285),
    [anon_sym_LBRACK] = ACTIONS(3287),
    [anon_sym_LPAREN] = ACTIONS(3287),
    [anon_sym_return] = ACTIONS(3285),
    [anon_sym_namespace] = ACTIONS(3285),
    [anon_sym_class] = ACTIONS(3285),
    [anon_sym_ref] = ACTIONS(3285),
    [anon_sym_struct] = ACTIONS(3285),
    [anon_sym_enum] = ACTIONS(3285),
    [anon_sym_LBRACE] = ACTIONS(3287),
    [anon_sym_interface] = ACTIONS(3285),
    [anon_sym_delegate] = ACTIONS(3285),
    [anon_sym_record] = ACTIONS(3285),
    [anon_sym_abstract] = ACTIONS(3285),
    [anon_sym_async] = ACTIONS(3285),
    [anon_sym_const] = ACTIONS(3285),
    [anon_sym_file] = ACTIONS(3285),
    [anon_sym_fixed] = ACTIONS(3285),
    [anon_sym_internal] = ACTIONS(3285),
    [anon_sym_new] = ACTIONS(3285),
    [anon_sym_override] = ACTIONS(3285),
    [anon_sym_partial] = ACTIONS(3285),
    [anon_sym_private] = ACTIONS(3285),
    [anon_sym_protected] = ACTIONS(3285),
    [anon_sym_public] = ACTIONS(3285),
    [anon_sym_readonly] = ACTIONS(3285),
    [anon_sym_required] = ACTIONS(3285),
    [anon_sym_sealed] = ACTIONS(3285),
    [anon_sym_virtual] = ACTIONS(3285),
    [anon_sym_volatile] = ACTIONS(3285),
    [anon_sym_where] = ACTIONS(3285),
    [anon_sym_notnull] = ACTIONS(3285),
    [anon_sym_unmanaged] = ACTIONS(3285),
    [anon_sym_checked] = ACTIONS(3285),
    [anon_sym_BANG] = ACTIONS(3287),
    [anon_sym_TILDE] = ACTIONS(3287),
    [anon_sym_PLUS_PLUS] = ACTIONS(3287),
    [anon_sym_DASH_DASH] = ACTIONS(3287),
    [anon_sym_true] = ACTIONS(3285),
    [anon_sym_false] = ACTIONS(3285),
    [anon_sym_PLUS] = ACTIONS(3285),
    [anon_sym_DASH] = ACTIONS(3285),
    [anon_sym_STAR] = ACTIONS(3287),
    [anon_sym_CARET] = ACTIONS(3287),
    [anon_sym_AMP] = ACTIONS(3287),
    [anon_sym_this] = ACTIONS(3285),
    [anon_sym_scoped] = ACTIONS(3285),
    [anon_sym_base] = ACTIONS(3285),
    [anon_sym_var] = ACTIONS(3285),
    [sym_predefined_type] = ACTIONS(3285),
    [anon_sym_break] = ACTIONS(3285),
    [anon_sym_unchecked] = ACTIONS(3285),
    [anon_sym_continue] = ACTIONS(3285),
    [anon_sym_do] = ACTIONS(3285),
    [anon_sym_while] = ACTIONS(3285),
    [anon_sym_for] = ACTIONS(3285),
    [anon_sym_lock] = ACTIONS(3285),
    [anon_sym_yield] = ACTIONS(3285),
    [anon_sym_switch] = ACTIONS(3285),
    [anon_sym_default] = ACTIONS(3285),
    [anon_sym_throw] = ACTIONS(3285),
    [anon_sym_try] = ACTIONS(3285),
    [anon_sym_when] = ACTIONS(3285),
    [anon_sym_await] = ACTIONS(3285),
    [anon_sym_foreach] = ACTIONS(3285),
    [anon_sym_goto] = ACTIONS(3285),
    [anon_sym_if] = ACTIONS(3285),
    [anon_sym_else] = ACTIONS(3285),
    [anon_sym_DOT_DOT] = ACTIONS(3287),
    [anon_sym_from] = ACTIONS(3285),
    [anon_sym_into] = ACTIONS(3285),
    [anon_sym_join] = ACTIONS(3285),
    [anon_sym_on] = ACTIONS(3285),
    [anon_sym_equals] = ACTIONS(3285),
    [anon_sym_let] = ACTIONS(3285),
    [anon_sym_orderby] = ACTIONS(3285),
    [anon_sym_ascending] = ACTIONS(3285),
    [anon_sym_descending] = ACTIONS(3285),
    [anon_sym_group] = ACTIONS(3285),
    [anon_sym_by] = ACTIONS(3285),
    [anon_sym_select] = ACTIONS(3285),
    [anon_sym_stackalloc] = ACTIONS(3285),
    [anon_sym_sizeof] = ACTIONS(3285),
    [anon_sym_typeof] = ACTIONS(3285),
    [anon_sym___makeref] = ACTIONS(3285),
    [anon_sym___reftype] = ACTIONS(3285),
    [anon_sym___refvalue] = ACTIONS(3285),
    [sym_null_literal] = ACTIONS(3285),
    [anon_sym_SQUOTE] = ACTIONS(3287),
    [sym_integer_literal] = ACTIONS(3285),
    [sym_real_literal] = ACTIONS(3287),
    [anon_sym_DQUOTE] = ACTIONS(3287),
    [sym_verbatim_string_literal] = ACTIONS(3287),
    [aux_sym_preproc_if_token1] = ACTIONS(3287),
    [aux_sym_preproc_if_token3] = ACTIONS(3287),
    [aux_sym_preproc_else_token1] = ACTIONS(3287),
    [aux_sym_preproc_elif_token1] = ACTIONS(3287),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3287),
    [sym_interpolation_verbatim_start] = ACTIONS(3287),
    [sym_interpolation_raw_start] = ACTIONS(3287),
    [sym_raw_string_start] = ACTIONS(3287),
  },
  [2273] = {
    [sym_preproc_region] = STATE(2273),
    [sym_preproc_endregion] = STATE(2273),
    [sym_preproc_line] = STATE(2273),
    [sym_preproc_pragma] = STATE(2273),
    [sym_preproc_nullable] = STATE(2273),
    [sym_preproc_error] = STATE(2273),
    [sym_preproc_warning] = STATE(2273),
    [sym_preproc_define] = STATE(2273),
    [sym_preproc_undef] = STATE(2273),
    [sym__identifier_token] = ACTIONS(3289),
    [anon_sym_extern] = ACTIONS(3289),
    [anon_sym_alias] = ACTIONS(3289),
    [anon_sym_SEMI] = ACTIONS(3291),
    [anon_sym_global] = ACTIONS(3289),
    [anon_sym_using] = ACTIONS(3289),
    [anon_sym_unsafe] = ACTIONS(3289),
    [anon_sym_static] = ACTIONS(3289),
    [anon_sym_LBRACK] = ACTIONS(3291),
    [anon_sym_LPAREN] = ACTIONS(3291),
    [anon_sym_return] = ACTIONS(3289),
    [anon_sym_namespace] = ACTIONS(3289),
    [anon_sym_class] = ACTIONS(3289),
    [anon_sym_ref] = ACTIONS(3289),
    [anon_sym_struct] = ACTIONS(3289),
    [anon_sym_enum] = ACTIONS(3289),
    [anon_sym_LBRACE] = ACTIONS(3291),
    [anon_sym_interface] = ACTIONS(3289),
    [anon_sym_delegate] = ACTIONS(3289),
    [anon_sym_record] = ACTIONS(3289),
    [anon_sym_abstract] = ACTIONS(3289),
    [anon_sym_async] = ACTIONS(3289),
    [anon_sym_const] = ACTIONS(3289),
    [anon_sym_file] = ACTIONS(3289),
    [anon_sym_fixed] = ACTIONS(3289),
    [anon_sym_internal] = ACTIONS(3289),
    [anon_sym_new] = ACTIONS(3289),
    [anon_sym_override] = ACTIONS(3289),
    [anon_sym_partial] = ACTIONS(3289),
    [anon_sym_private] = ACTIONS(3289),
    [anon_sym_protected] = ACTIONS(3289),
    [anon_sym_public] = ACTIONS(3289),
    [anon_sym_readonly] = ACTIONS(3289),
    [anon_sym_required] = ACTIONS(3289),
    [anon_sym_sealed] = ACTIONS(3289),
    [anon_sym_virtual] = ACTIONS(3289),
    [anon_sym_volatile] = ACTIONS(3289),
    [anon_sym_where] = ACTIONS(3289),
    [anon_sym_notnull] = ACTIONS(3289),
    [anon_sym_unmanaged] = ACTIONS(3289),
    [anon_sym_checked] = ACTIONS(3289),
    [anon_sym_BANG] = ACTIONS(3291),
    [anon_sym_TILDE] = ACTIONS(3291),
    [anon_sym_PLUS_PLUS] = ACTIONS(3291),
    [anon_sym_DASH_DASH] = ACTIONS(3291),
    [anon_sym_true] = ACTIONS(3289),
    [anon_sym_false] = ACTIONS(3289),
    [anon_sym_PLUS] = ACTIONS(3289),
    [anon_sym_DASH] = ACTIONS(3289),
    [anon_sym_STAR] = ACTIONS(3291),
    [anon_sym_CARET] = ACTIONS(3291),
    [anon_sym_AMP] = ACTIONS(3291),
    [anon_sym_this] = ACTIONS(3289),
    [anon_sym_scoped] = ACTIONS(3289),
    [anon_sym_base] = ACTIONS(3289),
    [anon_sym_var] = ACTIONS(3289),
    [sym_predefined_type] = ACTIONS(3289),
    [anon_sym_break] = ACTIONS(3289),
    [anon_sym_unchecked] = ACTIONS(3289),
    [anon_sym_continue] = ACTIONS(3289),
    [anon_sym_do] = ACTIONS(3289),
    [anon_sym_while] = ACTIONS(3289),
    [anon_sym_for] = ACTIONS(3289),
    [anon_sym_lock] = ACTIONS(3289),
    [anon_sym_yield] = ACTIONS(3289),
    [anon_sym_switch] = ACTIONS(3289),
    [anon_sym_default] = ACTIONS(3289),
    [anon_sym_throw] = ACTIONS(3289),
    [anon_sym_try] = ACTIONS(3289),
    [anon_sym_when] = ACTIONS(3289),
    [anon_sym_await] = ACTIONS(3289),
    [anon_sym_foreach] = ACTIONS(3289),
    [anon_sym_goto] = ACTIONS(3289),
    [anon_sym_if] = ACTIONS(3289),
    [anon_sym_else] = ACTIONS(3289),
    [anon_sym_DOT_DOT] = ACTIONS(3291),
    [anon_sym_from] = ACTIONS(3289),
    [anon_sym_into] = ACTIONS(3289),
    [anon_sym_join] = ACTIONS(3289),
    [anon_sym_on] = ACTIONS(3289),
    [anon_sym_equals] = ACTIONS(3289),
    [anon_sym_let] = ACTIONS(3289),
    [anon_sym_orderby] = ACTIONS(3289),
    [anon_sym_ascending] = ACTIONS(3289),
    [anon_sym_descending] = ACTIONS(3289),
    [anon_sym_group] = ACTIONS(3289),
    [anon_sym_by] = ACTIONS(3289),
    [anon_sym_select] = ACTIONS(3289),
    [anon_sym_stackalloc] = ACTIONS(3289),
    [anon_sym_sizeof] = ACTIONS(3289),
    [anon_sym_typeof] = ACTIONS(3289),
    [anon_sym___makeref] = ACTIONS(3289),
    [anon_sym___reftype] = ACTIONS(3289),
    [anon_sym___refvalue] = ACTIONS(3289),
    [sym_null_literal] = ACTIONS(3289),
    [anon_sym_SQUOTE] = ACTIONS(3291),
    [sym_integer_literal] = ACTIONS(3289),
    [sym_real_literal] = ACTIONS(3291),
    [anon_sym_DQUOTE] = ACTIONS(3291),
    [sym_verbatim_string_literal] = ACTIONS(3291),
    [aux_sym_preproc_if_token1] = ACTIONS(3291),
    [aux_sym_preproc_if_token3] = ACTIONS(3291),
    [aux_sym_preproc_else_token1] = ACTIONS(3291),
    [aux_sym_preproc_elif_token1] = ACTIONS(3291),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3291),
    [sym_interpolation_verbatim_start] = ACTIONS(3291),
    [sym_interpolation_raw_start] = ACTIONS(3291),
    [sym_raw_string_start] = ACTIONS(3291),
  },
  [2274] = {
    [sym_preproc_region] = STATE(2274),
    [sym_preproc_endregion] = STATE(2274),
    [sym_preproc_line] = STATE(2274),
    [sym_preproc_pragma] = STATE(2274),
    [sym_preproc_nullable] = STATE(2274),
    [sym_preproc_error] = STATE(2274),
    [sym_preproc_warning] = STATE(2274),
    [sym_preproc_define] = STATE(2274),
    [sym_preproc_undef] = STATE(2274),
    [ts_builtin_sym_end] = ACTIONS(3028),
    [sym__identifier_token] = ACTIONS(3026),
    [anon_sym_extern] = ACTIONS(3026),
    [anon_sym_alias] = ACTIONS(3026),
    [anon_sym_SEMI] = ACTIONS(3028),
    [anon_sym_global] = ACTIONS(3026),
    [anon_sym_using] = ACTIONS(3026),
    [anon_sym_unsafe] = ACTIONS(3026),
    [anon_sym_static] = ACTIONS(3026),
    [anon_sym_LBRACK] = ACTIONS(3028),
    [anon_sym_LPAREN] = ACTIONS(3028),
    [anon_sym_return] = ACTIONS(3026),
    [anon_sym_namespace] = ACTIONS(3026),
    [anon_sym_class] = ACTIONS(3026),
    [anon_sym_ref] = ACTIONS(3026),
    [anon_sym_struct] = ACTIONS(3026),
    [anon_sym_enum] = ACTIONS(3026),
    [anon_sym_LBRACE] = ACTIONS(3028),
    [anon_sym_interface] = ACTIONS(3026),
    [anon_sym_delegate] = ACTIONS(3026),
    [anon_sym_record] = ACTIONS(3026),
    [anon_sym_abstract] = ACTIONS(3026),
    [anon_sym_async] = ACTIONS(3026),
    [anon_sym_const] = ACTIONS(3026),
    [anon_sym_file] = ACTIONS(3026),
    [anon_sym_fixed] = ACTIONS(3026),
    [anon_sym_internal] = ACTIONS(3026),
    [anon_sym_new] = ACTIONS(3026),
    [anon_sym_override] = ACTIONS(3026),
    [anon_sym_partial] = ACTIONS(3026),
    [anon_sym_private] = ACTIONS(3026),
    [anon_sym_protected] = ACTIONS(3026),
    [anon_sym_public] = ACTIONS(3026),
    [anon_sym_readonly] = ACTIONS(3026),
    [anon_sym_required] = ACTIONS(3026),
    [anon_sym_sealed] = ACTIONS(3026),
    [anon_sym_virtual] = ACTIONS(3026),
    [anon_sym_volatile] = ACTIONS(3026),
    [anon_sym_where] = ACTIONS(3026),
    [anon_sym_notnull] = ACTIONS(3026),
    [anon_sym_unmanaged] = ACTIONS(3026),
    [anon_sym_checked] = ACTIONS(3026),
    [anon_sym_BANG] = ACTIONS(3028),
    [anon_sym_TILDE] = ACTIONS(3028),
    [anon_sym_PLUS_PLUS] = ACTIONS(3028),
    [anon_sym_DASH_DASH] = ACTIONS(3028),
    [anon_sym_true] = ACTIONS(3026),
    [anon_sym_false] = ACTIONS(3026),
    [anon_sym_PLUS] = ACTIONS(3026),
    [anon_sym_DASH] = ACTIONS(3026),
    [anon_sym_STAR] = ACTIONS(3028),
    [anon_sym_CARET] = ACTIONS(3028),
    [anon_sym_AMP] = ACTIONS(3028),
    [anon_sym_this] = ACTIONS(3026),
    [anon_sym_scoped] = ACTIONS(3026),
    [anon_sym_base] = ACTIONS(3026),
    [anon_sym_var] = ACTIONS(3026),
    [sym_predefined_type] = ACTIONS(3026),
    [anon_sym_break] = ACTIONS(3026),
    [anon_sym_unchecked] = ACTIONS(3026),
    [anon_sym_continue] = ACTIONS(3026),
    [anon_sym_do] = ACTIONS(3026),
    [anon_sym_while] = ACTIONS(3026),
    [anon_sym_for] = ACTIONS(3026),
    [anon_sym_lock] = ACTIONS(3026),
    [anon_sym_yield] = ACTIONS(3026),
    [anon_sym_switch] = ACTIONS(3026),
    [anon_sym_default] = ACTIONS(3026),
    [anon_sym_throw] = ACTIONS(3026),
    [anon_sym_try] = ACTIONS(3026),
    [anon_sym_catch] = ACTIONS(3026),
    [anon_sym_when] = ACTIONS(3026),
    [anon_sym_finally] = ACTIONS(3026),
    [anon_sym_await] = ACTIONS(3026),
    [anon_sym_foreach] = ACTIONS(3026),
    [anon_sym_goto] = ACTIONS(3026),
    [anon_sym_if] = ACTIONS(3026),
    [anon_sym_else] = ACTIONS(3026),
    [anon_sym_DOT_DOT] = ACTIONS(3028),
    [anon_sym_from] = ACTIONS(3026),
    [anon_sym_into] = ACTIONS(3026),
    [anon_sym_join] = ACTIONS(3026),
    [anon_sym_on] = ACTIONS(3026),
    [anon_sym_equals] = ACTIONS(3026),
    [anon_sym_let] = ACTIONS(3026),
    [anon_sym_orderby] = ACTIONS(3026),
    [anon_sym_ascending] = ACTIONS(3026),
    [anon_sym_descending] = ACTIONS(3026),
    [anon_sym_group] = ACTIONS(3026),
    [anon_sym_by] = ACTIONS(3026),
    [anon_sym_select] = ACTIONS(3026),
    [anon_sym_stackalloc] = ACTIONS(3026),
    [anon_sym_sizeof] = ACTIONS(3026),
    [anon_sym_typeof] = ACTIONS(3026),
    [anon_sym___makeref] = ACTIONS(3026),
    [anon_sym___reftype] = ACTIONS(3026),
    [anon_sym___refvalue] = ACTIONS(3026),
    [sym_null_literal] = ACTIONS(3026),
    [anon_sym_SQUOTE] = ACTIONS(3028),
    [sym_integer_literal] = ACTIONS(3026),
    [sym_real_literal] = ACTIONS(3028),
    [anon_sym_DQUOTE] = ACTIONS(3028),
    [sym_verbatim_string_literal] = ACTIONS(3028),
    [aux_sym_preproc_if_token1] = ACTIONS(3028),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3028),
    [sym_interpolation_verbatim_start] = ACTIONS(3028),
    [sym_interpolation_raw_start] = ACTIONS(3028),
    [sym_raw_string_start] = ACTIONS(3028),
  },
  [2275] = {
    [sym_preproc_region] = STATE(2275),
    [sym_preproc_endregion] = STATE(2275),
    [sym_preproc_line] = STATE(2275),
    [sym_preproc_pragma] = STATE(2275),
    [sym_preproc_nullable] = STATE(2275),
    [sym_preproc_error] = STATE(2275),
    [sym_preproc_warning] = STATE(2275),
    [sym_preproc_define] = STATE(2275),
    [sym_preproc_undef] = STATE(2275),
    [sym__identifier_token] = ACTIONS(3293),
    [anon_sym_extern] = ACTIONS(3293),
    [anon_sym_alias] = ACTIONS(3293),
    [anon_sym_SEMI] = ACTIONS(3295),
    [anon_sym_global] = ACTIONS(3293),
    [anon_sym_using] = ACTIONS(3293),
    [anon_sym_unsafe] = ACTIONS(3293),
    [anon_sym_static] = ACTIONS(3293),
    [anon_sym_LBRACK] = ACTIONS(3295),
    [anon_sym_LPAREN] = ACTIONS(3295),
    [anon_sym_return] = ACTIONS(3293),
    [anon_sym_namespace] = ACTIONS(3293),
    [anon_sym_class] = ACTIONS(3293),
    [anon_sym_ref] = ACTIONS(3293),
    [anon_sym_struct] = ACTIONS(3293),
    [anon_sym_enum] = ACTIONS(3293),
    [anon_sym_LBRACE] = ACTIONS(3295),
    [anon_sym_interface] = ACTIONS(3293),
    [anon_sym_delegate] = ACTIONS(3293),
    [anon_sym_record] = ACTIONS(3293),
    [anon_sym_abstract] = ACTIONS(3293),
    [anon_sym_async] = ACTIONS(3293),
    [anon_sym_const] = ACTIONS(3293),
    [anon_sym_file] = ACTIONS(3293),
    [anon_sym_fixed] = ACTIONS(3293),
    [anon_sym_internal] = ACTIONS(3293),
    [anon_sym_new] = ACTIONS(3293),
    [anon_sym_override] = ACTIONS(3293),
    [anon_sym_partial] = ACTIONS(3293),
    [anon_sym_private] = ACTIONS(3293),
    [anon_sym_protected] = ACTIONS(3293),
    [anon_sym_public] = ACTIONS(3293),
    [anon_sym_readonly] = ACTIONS(3293),
    [anon_sym_required] = ACTIONS(3293),
    [anon_sym_sealed] = ACTIONS(3293),
    [anon_sym_virtual] = ACTIONS(3293),
    [anon_sym_volatile] = ACTIONS(3293),
    [anon_sym_where] = ACTIONS(3293),
    [anon_sym_notnull] = ACTIONS(3293),
    [anon_sym_unmanaged] = ACTIONS(3293),
    [anon_sym_checked] = ACTIONS(3293),
    [anon_sym_BANG] = ACTIONS(3295),
    [anon_sym_TILDE] = ACTIONS(3295),
    [anon_sym_PLUS_PLUS] = ACTIONS(3295),
    [anon_sym_DASH_DASH] = ACTIONS(3295),
    [anon_sym_true] = ACTIONS(3293),
    [anon_sym_false] = ACTIONS(3293),
    [anon_sym_PLUS] = ACTIONS(3293),
    [anon_sym_DASH] = ACTIONS(3293),
    [anon_sym_STAR] = ACTIONS(3295),
    [anon_sym_CARET] = ACTIONS(3295),
    [anon_sym_AMP] = ACTIONS(3295),
    [anon_sym_this] = ACTIONS(3293),
    [anon_sym_scoped] = ACTIONS(3293),
    [anon_sym_base] = ACTIONS(3293),
    [anon_sym_var] = ACTIONS(3293),
    [sym_predefined_type] = ACTIONS(3293),
    [anon_sym_break] = ACTIONS(3293),
    [anon_sym_unchecked] = ACTIONS(3293),
    [anon_sym_continue] = ACTIONS(3293),
    [anon_sym_do] = ACTIONS(3293),
    [anon_sym_while] = ACTIONS(3293),
    [anon_sym_for] = ACTIONS(3293),
    [anon_sym_lock] = ACTIONS(3293),
    [anon_sym_yield] = ACTIONS(3293),
    [anon_sym_switch] = ACTIONS(3293),
    [anon_sym_default] = ACTIONS(3293),
    [anon_sym_throw] = ACTIONS(3293),
    [anon_sym_try] = ACTIONS(3293),
    [anon_sym_when] = ACTIONS(3293),
    [anon_sym_await] = ACTIONS(3293),
    [anon_sym_foreach] = ACTIONS(3293),
    [anon_sym_goto] = ACTIONS(3293),
    [anon_sym_if] = ACTIONS(3293),
    [anon_sym_else] = ACTIONS(3293),
    [anon_sym_DOT_DOT] = ACTIONS(3295),
    [anon_sym_from] = ACTIONS(3293),
    [anon_sym_into] = ACTIONS(3293),
    [anon_sym_join] = ACTIONS(3293),
    [anon_sym_on] = ACTIONS(3293),
    [anon_sym_equals] = ACTIONS(3293),
    [anon_sym_let] = ACTIONS(3293),
    [anon_sym_orderby] = ACTIONS(3293),
    [anon_sym_ascending] = ACTIONS(3293),
    [anon_sym_descending] = ACTIONS(3293),
    [anon_sym_group] = ACTIONS(3293),
    [anon_sym_by] = ACTIONS(3293),
    [anon_sym_select] = ACTIONS(3293),
    [anon_sym_stackalloc] = ACTIONS(3293),
    [anon_sym_sizeof] = ACTIONS(3293),
    [anon_sym_typeof] = ACTIONS(3293),
    [anon_sym___makeref] = ACTIONS(3293),
    [anon_sym___reftype] = ACTIONS(3293),
    [anon_sym___refvalue] = ACTIONS(3293),
    [sym_null_literal] = ACTIONS(3293),
    [anon_sym_SQUOTE] = ACTIONS(3295),
    [sym_integer_literal] = ACTIONS(3293),
    [sym_real_literal] = ACTIONS(3295),
    [anon_sym_DQUOTE] = ACTIONS(3295),
    [sym_verbatim_string_literal] = ACTIONS(3295),
    [aux_sym_preproc_if_token1] = ACTIONS(3295),
    [aux_sym_preproc_if_token3] = ACTIONS(3295),
    [aux_sym_preproc_else_token1] = ACTIONS(3295),
    [aux_sym_preproc_elif_token1] = ACTIONS(3295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3295),
    [sym_interpolation_verbatim_start] = ACTIONS(3295),
    [sym_interpolation_raw_start] = ACTIONS(3295),
    [sym_raw_string_start] = ACTIONS(3295),
  },
  [2276] = {
    [sym_preproc_region] = STATE(2276),
    [sym_preproc_endregion] = STATE(2276),
    [sym_preproc_line] = STATE(2276),
    [sym_preproc_pragma] = STATE(2276),
    [sym_preproc_nullable] = STATE(2276),
    [sym_preproc_error] = STATE(2276),
    [sym_preproc_warning] = STATE(2276),
    [sym_preproc_define] = STATE(2276),
    [sym_preproc_undef] = STATE(2276),
    [sym__identifier_token] = ACTIONS(3297),
    [anon_sym_extern] = ACTIONS(3297),
    [anon_sym_alias] = ACTIONS(3297),
    [anon_sym_SEMI] = ACTIONS(3299),
    [anon_sym_global] = ACTIONS(3297),
    [anon_sym_using] = ACTIONS(3297),
    [anon_sym_unsafe] = ACTIONS(3297),
    [anon_sym_static] = ACTIONS(3297),
    [anon_sym_LBRACK] = ACTIONS(3299),
    [anon_sym_LPAREN] = ACTIONS(3299),
    [anon_sym_return] = ACTIONS(3297),
    [anon_sym_namespace] = ACTIONS(3297),
    [anon_sym_class] = ACTIONS(3297),
    [anon_sym_ref] = ACTIONS(3297),
    [anon_sym_struct] = ACTIONS(3297),
    [anon_sym_enum] = ACTIONS(3297),
    [anon_sym_LBRACE] = ACTIONS(3299),
    [anon_sym_interface] = ACTIONS(3297),
    [anon_sym_delegate] = ACTIONS(3297),
    [anon_sym_record] = ACTIONS(3297),
    [anon_sym_abstract] = ACTIONS(3297),
    [anon_sym_async] = ACTIONS(3297),
    [anon_sym_const] = ACTIONS(3297),
    [anon_sym_file] = ACTIONS(3297),
    [anon_sym_fixed] = ACTIONS(3297),
    [anon_sym_internal] = ACTIONS(3297),
    [anon_sym_new] = ACTIONS(3297),
    [anon_sym_override] = ACTIONS(3297),
    [anon_sym_partial] = ACTIONS(3297),
    [anon_sym_private] = ACTIONS(3297),
    [anon_sym_protected] = ACTIONS(3297),
    [anon_sym_public] = ACTIONS(3297),
    [anon_sym_readonly] = ACTIONS(3297),
    [anon_sym_required] = ACTIONS(3297),
    [anon_sym_sealed] = ACTIONS(3297),
    [anon_sym_virtual] = ACTIONS(3297),
    [anon_sym_volatile] = ACTIONS(3297),
    [anon_sym_where] = ACTIONS(3297),
    [anon_sym_notnull] = ACTIONS(3297),
    [anon_sym_unmanaged] = ACTIONS(3297),
    [anon_sym_checked] = ACTIONS(3297),
    [anon_sym_BANG] = ACTIONS(3299),
    [anon_sym_TILDE] = ACTIONS(3299),
    [anon_sym_PLUS_PLUS] = ACTIONS(3299),
    [anon_sym_DASH_DASH] = ACTIONS(3299),
    [anon_sym_true] = ACTIONS(3297),
    [anon_sym_false] = ACTIONS(3297),
    [anon_sym_PLUS] = ACTIONS(3297),
    [anon_sym_DASH] = ACTIONS(3297),
    [anon_sym_STAR] = ACTIONS(3299),
    [anon_sym_CARET] = ACTIONS(3299),
    [anon_sym_AMP] = ACTIONS(3299),
    [anon_sym_this] = ACTIONS(3297),
    [anon_sym_scoped] = ACTIONS(3297),
    [anon_sym_base] = ACTIONS(3297),
    [anon_sym_var] = ACTIONS(3297),
    [sym_predefined_type] = ACTIONS(3297),
    [anon_sym_break] = ACTIONS(3297),
    [anon_sym_unchecked] = ACTIONS(3297),
    [anon_sym_continue] = ACTIONS(3297),
    [anon_sym_do] = ACTIONS(3297),
    [anon_sym_while] = ACTIONS(3297),
    [anon_sym_for] = ACTIONS(3297),
    [anon_sym_lock] = ACTIONS(3297),
    [anon_sym_yield] = ACTIONS(3297),
    [anon_sym_switch] = ACTIONS(3297),
    [anon_sym_default] = ACTIONS(3297),
    [anon_sym_throw] = ACTIONS(3297),
    [anon_sym_try] = ACTIONS(3297),
    [anon_sym_when] = ACTIONS(3297),
    [anon_sym_await] = ACTIONS(3297),
    [anon_sym_foreach] = ACTIONS(3297),
    [anon_sym_goto] = ACTIONS(3297),
    [anon_sym_if] = ACTIONS(3297),
    [anon_sym_else] = ACTIONS(3297),
    [anon_sym_DOT_DOT] = ACTIONS(3299),
    [anon_sym_from] = ACTIONS(3297),
    [anon_sym_into] = ACTIONS(3297),
    [anon_sym_join] = ACTIONS(3297),
    [anon_sym_on] = ACTIONS(3297),
    [anon_sym_equals] = ACTIONS(3297),
    [anon_sym_let] = ACTIONS(3297),
    [anon_sym_orderby] = ACTIONS(3297),
    [anon_sym_ascending] = ACTIONS(3297),
    [anon_sym_descending] = ACTIONS(3297),
    [anon_sym_group] = ACTIONS(3297),
    [anon_sym_by] = ACTIONS(3297),
    [anon_sym_select] = ACTIONS(3297),
    [anon_sym_stackalloc] = ACTIONS(3297),
    [anon_sym_sizeof] = ACTIONS(3297),
    [anon_sym_typeof] = ACTIONS(3297),
    [anon_sym___makeref] = ACTIONS(3297),
    [anon_sym___reftype] = ACTIONS(3297),
    [anon_sym___refvalue] = ACTIONS(3297),
    [sym_null_literal] = ACTIONS(3297),
    [anon_sym_SQUOTE] = ACTIONS(3299),
    [sym_integer_literal] = ACTIONS(3297),
    [sym_real_literal] = ACTIONS(3299),
    [anon_sym_DQUOTE] = ACTIONS(3299),
    [sym_verbatim_string_literal] = ACTIONS(3299),
    [aux_sym_preproc_if_token1] = ACTIONS(3299),
    [aux_sym_preproc_if_token3] = ACTIONS(3299),
    [aux_sym_preproc_else_token1] = ACTIONS(3299),
    [aux_sym_preproc_elif_token1] = ACTIONS(3299),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3299),
    [sym_interpolation_verbatim_start] = ACTIONS(3299),
    [sym_interpolation_raw_start] = ACTIONS(3299),
    [sym_raw_string_start] = ACTIONS(3299),
  },
  [2277] = {
    [sym_preproc_region] = STATE(2277),
    [sym_preproc_endregion] = STATE(2277),
    [sym_preproc_line] = STATE(2277),
    [sym_preproc_pragma] = STATE(2277),
    [sym_preproc_nullable] = STATE(2277),
    [sym_preproc_error] = STATE(2277),
    [sym_preproc_warning] = STATE(2277),
    [sym_preproc_define] = STATE(2277),
    [sym_preproc_undef] = STATE(2277),
    [sym__identifier_token] = ACTIONS(3301),
    [anon_sym_extern] = ACTIONS(3301),
    [anon_sym_alias] = ACTIONS(3301),
    [anon_sym_SEMI] = ACTIONS(3303),
    [anon_sym_global] = ACTIONS(3301),
    [anon_sym_using] = ACTIONS(3301),
    [anon_sym_unsafe] = ACTIONS(3301),
    [anon_sym_static] = ACTIONS(3301),
    [anon_sym_LBRACK] = ACTIONS(3303),
    [anon_sym_LPAREN] = ACTIONS(3303),
    [anon_sym_return] = ACTIONS(3301),
    [anon_sym_namespace] = ACTIONS(3301),
    [anon_sym_class] = ACTIONS(3301),
    [anon_sym_ref] = ACTIONS(3301),
    [anon_sym_struct] = ACTIONS(3301),
    [anon_sym_enum] = ACTIONS(3301),
    [anon_sym_LBRACE] = ACTIONS(3303),
    [anon_sym_interface] = ACTIONS(3301),
    [anon_sym_delegate] = ACTIONS(3301),
    [anon_sym_record] = ACTIONS(3301),
    [anon_sym_abstract] = ACTIONS(3301),
    [anon_sym_async] = ACTIONS(3301),
    [anon_sym_const] = ACTIONS(3301),
    [anon_sym_file] = ACTIONS(3301),
    [anon_sym_fixed] = ACTIONS(3301),
    [anon_sym_internal] = ACTIONS(3301),
    [anon_sym_new] = ACTIONS(3301),
    [anon_sym_override] = ACTIONS(3301),
    [anon_sym_partial] = ACTIONS(3301),
    [anon_sym_private] = ACTIONS(3301),
    [anon_sym_protected] = ACTIONS(3301),
    [anon_sym_public] = ACTIONS(3301),
    [anon_sym_readonly] = ACTIONS(3301),
    [anon_sym_required] = ACTIONS(3301),
    [anon_sym_sealed] = ACTIONS(3301),
    [anon_sym_virtual] = ACTIONS(3301),
    [anon_sym_volatile] = ACTIONS(3301),
    [anon_sym_where] = ACTIONS(3301),
    [anon_sym_notnull] = ACTIONS(3301),
    [anon_sym_unmanaged] = ACTIONS(3301),
    [anon_sym_checked] = ACTIONS(3301),
    [anon_sym_BANG] = ACTIONS(3303),
    [anon_sym_TILDE] = ACTIONS(3303),
    [anon_sym_PLUS_PLUS] = ACTIONS(3303),
    [anon_sym_DASH_DASH] = ACTIONS(3303),
    [anon_sym_true] = ACTIONS(3301),
    [anon_sym_false] = ACTIONS(3301),
    [anon_sym_PLUS] = ACTIONS(3301),
    [anon_sym_DASH] = ACTIONS(3301),
    [anon_sym_STAR] = ACTIONS(3303),
    [anon_sym_CARET] = ACTIONS(3303),
    [anon_sym_AMP] = ACTIONS(3303),
    [anon_sym_this] = ACTIONS(3301),
    [anon_sym_scoped] = ACTIONS(3301),
    [anon_sym_base] = ACTIONS(3301),
    [anon_sym_var] = ACTIONS(3301),
    [sym_predefined_type] = ACTIONS(3301),
    [anon_sym_break] = ACTIONS(3301),
    [anon_sym_unchecked] = ACTIONS(3301),
    [anon_sym_continue] = ACTIONS(3301),
    [anon_sym_do] = ACTIONS(3301),
    [anon_sym_while] = ACTIONS(3301),
    [anon_sym_for] = ACTIONS(3301),
    [anon_sym_lock] = ACTIONS(3301),
    [anon_sym_yield] = ACTIONS(3301),
    [anon_sym_switch] = ACTIONS(3301),
    [anon_sym_default] = ACTIONS(3301),
    [anon_sym_throw] = ACTIONS(3301),
    [anon_sym_try] = ACTIONS(3301),
    [anon_sym_when] = ACTIONS(3301),
    [anon_sym_await] = ACTIONS(3301),
    [anon_sym_foreach] = ACTIONS(3301),
    [anon_sym_goto] = ACTIONS(3301),
    [anon_sym_if] = ACTIONS(3301),
    [anon_sym_else] = ACTIONS(3301),
    [anon_sym_DOT_DOT] = ACTIONS(3303),
    [anon_sym_from] = ACTIONS(3301),
    [anon_sym_into] = ACTIONS(3301),
    [anon_sym_join] = ACTIONS(3301),
    [anon_sym_on] = ACTIONS(3301),
    [anon_sym_equals] = ACTIONS(3301),
    [anon_sym_let] = ACTIONS(3301),
    [anon_sym_orderby] = ACTIONS(3301),
    [anon_sym_ascending] = ACTIONS(3301),
    [anon_sym_descending] = ACTIONS(3301),
    [anon_sym_group] = ACTIONS(3301),
    [anon_sym_by] = ACTIONS(3301),
    [anon_sym_select] = ACTIONS(3301),
    [anon_sym_stackalloc] = ACTIONS(3301),
    [anon_sym_sizeof] = ACTIONS(3301),
    [anon_sym_typeof] = ACTIONS(3301),
    [anon_sym___makeref] = ACTIONS(3301),
    [anon_sym___reftype] = ACTIONS(3301),
    [anon_sym___refvalue] = ACTIONS(3301),
    [sym_null_literal] = ACTIONS(3301),
    [anon_sym_SQUOTE] = ACTIONS(3303),
    [sym_integer_literal] = ACTIONS(3301),
    [sym_real_literal] = ACTIONS(3303),
    [anon_sym_DQUOTE] = ACTIONS(3303),
    [sym_verbatim_string_literal] = ACTIONS(3303),
    [aux_sym_preproc_if_token1] = ACTIONS(3303),
    [aux_sym_preproc_if_token3] = ACTIONS(3303),
    [aux_sym_preproc_else_token1] = ACTIONS(3303),
    [aux_sym_preproc_elif_token1] = ACTIONS(3303),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3303),
    [sym_interpolation_verbatim_start] = ACTIONS(3303),
    [sym_interpolation_raw_start] = ACTIONS(3303),
    [sym_raw_string_start] = ACTIONS(3303),
  },
  [2278] = {
    [sym_preproc_region] = STATE(2278),
    [sym_preproc_endregion] = STATE(2278),
    [sym_preproc_line] = STATE(2278),
    [sym_preproc_pragma] = STATE(2278),
    [sym_preproc_nullable] = STATE(2278),
    [sym_preproc_error] = STATE(2278),
    [sym_preproc_warning] = STATE(2278),
    [sym_preproc_define] = STATE(2278),
    [sym_preproc_undef] = STATE(2278),
    [sym__identifier_token] = ACTIONS(3305),
    [anon_sym_extern] = ACTIONS(3305),
    [anon_sym_alias] = ACTIONS(3305),
    [anon_sym_SEMI] = ACTIONS(3307),
    [anon_sym_global] = ACTIONS(3305),
    [anon_sym_using] = ACTIONS(3305),
    [anon_sym_unsafe] = ACTIONS(3305),
    [anon_sym_static] = ACTIONS(3305),
    [anon_sym_LBRACK] = ACTIONS(3307),
    [anon_sym_LPAREN] = ACTIONS(3307),
    [anon_sym_return] = ACTIONS(3305),
    [anon_sym_namespace] = ACTIONS(3305),
    [anon_sym_class] = ACTIONS(3305),
    [anon_sym_ref] = ACTIONS(3305),
    [anon_sym_struct] = ACTIONS(3305),
    [anon_sym_enum] = ACTIONS(3305),
    [anon_sym_LBRACE] = ACTIONS(3307),
    [anon_sym_interface] = ACTIONS(3305),
    [anon_sym_delegate] = ACTIONS(3305),
    [anon_sym_record] = ACTIONS(3305),
    [anon_sym_abstract] = ACTIONS(3305),
    [anon_sym_async] = ACTIONS(3305),
    [anon_sym_const] = ACTIONS(3305),
    [anon_sym_file] = ACTIONS(3305),
    [anon_sym_fixed] = ACTIONS(3305),
    [anon_sym_internal] = ACTIONS(3305),
    [anon_sym_new] = ACTIONS(3305),
    [anon_sym_override] = ACTIONS(3305),
    [anon_sym_partial] = ACTIONS(3305),
    [anon_sym_private] = ACTIONS(3305),
    [anon_sym_protected] = ACTIONS(3305),
    [anon_sym_public] = ACTIONS(3305),
    [anon_sym_readonly] = ACTIONS(3305),
    [anon_sym_required] = ACTIONS(3305),
    [anon_sym_sealed] = ACTIONS(3305),
    [anon_sym_virtual] = ACTIONS(3305),
    [anon_sym_volatile] = ACTIONS(3305),
    [anon_sym_where] = ACTIONS(3305),
    [anon_sym_notnull] = ACTIONS(3305),
    [anon_sym_unmanaged] = ACTIONS(3305),
    [anon_sym_checked] = ACTIONS(3305),
    [anon_sym_BANG] = ACTIONS(3307),
    [anon_sym_TILDE] = ACTIONS(3307),
    [anon_sym_PLUS_PLUS] = ACTIONS(3307),
    [anon_sym_DASH_DASH] = ACTIONS(3307),
    [anon_sym_true] = ACTIONS(3305),
    [anon_sym_false] = ACTIONS(3305),
    [anon_sym_PLUS] = ACTIONS(3305),
    [anon_sym_DASH] = ACTIONS(3305),
    [anon_sym_STAR] = ACTIONS(3307),
    [anon_sym_CARET] = ACTIONS(3307),
    [anon_sym_AMP] = ACTIONS(3307),
    [anon_sym_this] = ACTIONS(3305),
    [anon_sym_scoped] = ACTIONS(3305),
    [anon_sym_base] = ACTIONS(3305),
    [anon_sym_var] = ACTIONS(3305),
    [sym_predefined_type] = ACTIONS(3305),
    [anon_sym_break] = ACTIONS(3305),
    [anon_sym_unchecked] = ACTIONS(3305),
    [anon_sym_continue] = ACTIONS(3305),
    [anon_sym_do] = ACTIONS(3305),
    [anon_sym_while] = ACTIONS(3305),
    [anon_sym_for] = ACTIONS(3305),
    [anon_sym_lock] = ACTIONS(3305),
    [anon_sym_yield] = ACTIONS(3305),
    [anon_sym_switch] = ACTIONS(3305),
    [anon_sym_default] = ACTIONS(3305),
    [anon_sym_throw] = ACTIONS(3305),
    [anon_sym_try] = ACTIONS(3305),
    [anon_sym_when] = ACTIONS(3305),
    [anon_sym_await] = ACTIONS(3305),
    [anon_sym_foreach] = ACTIONS(3305),
    [anon_sym_goto] = ACTIONS(3305),
    [anon_sym_if] = ACTIONS(3305),
    [anon_sym_else] = ACTIONS(3305),
    [anon_sym_DOT_DOT] = ACTIONS(3307),
    [anon_sym_from] = ACTIONS(3305),
    [anon_sym_into] = ACTIONS(3305),
    [anon_sym_join] = ACTIONS(3305),
    [anon_sym_on] = ACTIONS(3305),
    [anon_sym_equals] = ACTIONS(3305),
    [anon_sym_let] = ACTIONS(3305),
    [anon_sym_orderby] = ACTIONS(3305),
    [anon_sym_ascending] = ACTIONS(3305),
    [anon_sym_descending] = ACTIONS(3305),
    [anon_sym_group] = ACTIONS(3305),
    [anon_sym_by] = ACTIONS(3305),
    [anon_sym_select] = ACTIONS(3305),
    [anon_sym_stackalloc] = ACTIONS(3305),
    [anon_sym_sizeof] = ACTIONS(3305),
    [anon_sym_typeof] = ACTIONS(3305),
    [anon_sym___makeref] = ACTIONS(3305),
    [anon_sym___reftype] = ACTIONS(3305),
    [anon_sym___refvalue] = ACTIONS(3305),
    [sym_null_literal] = ACTIONS(3305),
    [anon_sym_SQUOTE] = ACTIONS(3307),
    [sym_integer_literal] = ACTIONS(3305),
    [sym_real_literal] = ACTIONS(3307),
    [anon_sym_DQUOTE] = ACTIONS(3307),
    [sym_verbatim_string_literal] = ACTIONS(3307),
    [aux_sym_preproc_if_token1] = ACTIONS(3307),
    [aux_sym_preproc_if_token3] = ACTIONS(3307),
    [aux_sym_preproc_else_token1] = ACTIONS(3307),
    [aux_sym_preproc_elif_token1] = ACTIONS(3307),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3307),
    [sym_interpolation_verbatim_start] = ACTIONS(3307),
    [sym_interpolation_raw_start] = ACTIONS(3307),
    [sym_raw_string_start] = ACTIONS(3307),
  },
  [2279] = {
    [sym_preproc_region] = STATE(2279),
    [sym_preproc_endregion] = STATE(2279),
    [sym_preproc_line] = STATE(2279),
    [sym_preproc_pragma] = STATE(2279),
    [sym_preproc_nullable] = STATE(2279),
    [sym_preproc_error] = STATE(2279),
    [sym_preproc_warning] = STATE(2279),
    [sym_preproc_define] = STATE(2279),
    [sym_preproc_undef] = STATE(2279),
    [sym__identifier_token] = ACTIONS(3309),
    [anon_sym_extern] = ACTIONS(3309),
    [anon_sym_alias] = ACTIONS(3309),
    [anon_sym_SEMI] = ACTIONS(3311),
    [anon_sym_global] = ACTIONS(3309),
    [anon_sym_using] = ACTIONS(3309),
    [anon_sym_unsafe] = ACTIONS(3309),
    [anon_sym_static] = ACTIONS(3309),
    [anon_sym_LBRACK] = ACTIONS(3311),
    [anon_sym_LPAREN] = ACTIONS(3311),
    [anon_sym_return] = ACTIONS(3309),
    [anon_sym_namespace] = ACTIONS(3309),
    [anon_sym_class] = ACTIONS(3309),
    [anon_sym_ref] = ACTIONS(3309),
    [anon_sym_struct] = ACTIONS(3309),
    [anon_sym_enum] = ACTIONS(3309),
    [anon_sym_LBRACE] = ACTIONS(3311),
    [anon_sym_interface] = ACTIONS(3309),
    [anon_sym_delegate] = ACTIONS(3309),
    [anon_sym_record] = ACTIONS(3309),
    [anon_sym_abstract] = ACTIONS(3309),
    [anon_sym_async] = ACTIONS(3309),
    [anon_sym_const] = ACTIONS(3309),
    [anon_sym_file] = ACTIONS(3309),
    [anon_sym_fixed] = ACTIONS(3309),
    [anon_sym_internal] = ACTIONS(3309),
    [anon_sym_new] = ACTIONS(3309),
    [anon_sym_override] = ACTIONS(3309),
    [anon_sym_partial] = ACTIONS(3309),
    [anon_sym_private] = ACTIONS(3309),
    [anon_sym_protected] = ACTIONS(3309),
    [anon_sym_public] = ACTIONS(3309),
    [anon_sym_readonly] = ACTIONS(3309),
    [anon_sym_required] = ACTIONS(3309),
    [anon_sym_sealed] = ACTIONS(3309),
    [anon_sym_virtual] = ACTIONS(3309),
    [anon_sym_volatile] = ACTIONS(3309),
    [anon_sym_where] = ACTIONS(3309),
    [anon_sym_notnull] = ACTIONS(3309),
    [anon_sym_unmanaged] = ACTIONS(3309),
    [anon_sym_checked] = ACTIONS(3309),
    [anon_sym_BANG] = ACTIONS(3311),
    [anon_sym_TILDE] = ACTIONS(3311),
    [anon_sym_PLUS_PLUS] = ACTIONS(3311),
    [anon_sym_DASH_DASH] = ACTIONS(3311),
    [anon_sym_true] = ACTIONS(3309),
    [anon_sym_false] = ACTIONS(3309),
    [anon_sym_PLUS] = ACTIONS(3309),
    [anon_sym_DASH] = ACTIONS(3309),
    [anon_sym_STAR] = ACTIONS(3311),
    [anon_sym_CARET] = ACTIONS(3311),
    [anon_sym_AMP] = ACTIONS(3311),
    [anon_sym_this] = ACTIONS(3309),
    [anon_sym_scoped] = ACTIONS(3309),
    [anon_sym_base] = ACTIONS(3309),
    [anon_sym_var] = ACTIONS(3309),
    [sym_predefined_type] = ACTIONS(3309),
    [anon_sym_break] = ACTIONS(3309),
    [anon_sym_unchecked] = ACTIONS(3309),
    [anon_sym_continue] = ACTIONS(3309),
    [anon_sym_do] = ACTIONS(3309),
    [anon_sym_while] = ACTIONS(3309),
    [anon_sym_for] = ACTIONS(3309),
    [anon_sym_lock] = ACTIONS(3309),
    [anon_sym_yield] = ACTIONS(3309),
    [anon_sym_switch] = ACTIONS(3309),
    [anon_sym_default] = ACTIONS(3309),
    [anon_sym_throw] = ACTIONS(3309),
    [anon_sym_try] = ACTIONS(3309),
    [anon_sym_when] = ACTIONS(3309),
    [anon_sym_await] = ACTIONS(3309),
    [anon_sym_foreach] = ACTIONS(3309),
    [anon_sym_goto] = ACTIONS(3309),
    [anon_sym_if] = ACTIONS(3309),
    [anon_sym_else] = ACTIONS(3309),
    [anon_sym_DOT_DOT] = ACTIONS(3311),
    [anon_sym_from] = ACTIONS(3309),
    [anon_sym_into] = ACTIONS(3309),
    [anon_sym_join] = ACTIONS(3309),
    [anon_sym_on] = ACTIONS(3309),
    [anon_sym_equals] = ACTIONS(3309),
    [anon_sym_let] = ACTIONS(3309),
    [anon_sym_orderby] = ACTIONS(3309),
    [anon_sym_ascending] = ACTIONS(3309),
    [anon_sym_descending] = ACTIONS(3309),
    [anon_sym_group] = ACTIONS(3309),
    [anon_sym_by] = ACTIONS(3309),
    [anon_sym_select] = ACTIONS(3309),
    [anon_sym_stackalloc] = ACTIONS(3309),
    [anon_sym_sizeof] = ACTIONS(3309),
    [anon_sym_typeof] = ACTIONS(3309),
    [anon_sym___makeref] = ACTIONS(3309),
    [anon_sym___reftype] = ACTIONS(3309),
    [anon_sym___refvalue] = ACTIONS(3309),
    [sym_null_literal] = ACTIONS(3309),
    [anon_sym_SQUOTE] = ACTIONS(3311),
    [sym_integer_literal] = ACTIONS(3309),
    [sym_real_literal] = ACTIONS(3311),
    [anon_sym_DQUOTE] = ACTIONS(3311),
    [sym_verbatim_string_literal] = ACTIONS(3311),
    [aux_sym_preproc_if_token1] = ACTIONS(3311),
    [aux_sym_preproc_if_token3] = ACTIONS(3311),
    [aux_sym_preproc_else_token1] = ACTIONS(3311),
    [aux_sym_preproc_elif_token1] = ACTIONS(3311),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3311),
    [sym_interpolation_verbatim_start] = ACTIONS(3311),
    [sym_interpolation_raw_start] = ACTIONS(3311),
    [sym_raw_string_start] = ACTIONS(3311),
  },
  [2280] = {
    [sym_preproc_region] = STATE(2280),
    [sym_preproc_endregion] = STATE(2280),
    [sym_preproc_line] = STATE(2280),
    [sym_preproc_pragma] = STATE(2280),
    [sym_preproc_nullable] = STATE(2280),
    [sym_preproc_error] = STATE(2280),
    [sym_preproc_warning] = STATE(2280),
    [sym_preproc_define] = STATE(2280),
    [sym_preproc_undef] = STATE(2280),
    [sym__identifier_token] = ACTIONS(3313),
    [anon_sym_extern] = ACTIONS(3313),
    [anon_sym_alias] = ACTIONS(3313),
    [anon_sym_SEMI] = ACTIONS(3315),
    [anon_sym_global] = ACTIONS(3313),
    [anon_sym_using] = ACTIONS(3313),
    [anon_sym_unsafe] = ACTIONS(3313),
    [anon_sym_static] = ACTIONS(3313),
    [anon_sym_LBRACK] = ACTIONS(3315),
    [anon_sym_LPAREN] = ACTIONS(3315),
    [anon_sym_return] = ACTIONS(3313),
    [anon_sym_namespace] = ACTIONS(3313),
    [anon_sym_class] = ACTIONS(3313),
    [anon_sym_ref] = ACTIONS(3313),
    [anon_sym_struct] = ACTIONS(3313),
    [anon_sym_enum] = ACTIONS(3313),
    [anon_sym_LBRACE] = ACTIONS(3315),
    [anon_sym_interface] = ACTIONS(3313),
    [anon_sym_delegate] = ACTIONS(3313),
    [anon_sym_record] = ACTIONS(3313),
    [anon_sym_abstract] = ACTIONS(3313),
    [anon_sym_async] = ACTIONS(3313),
    [anon_sym_const] = ACTIONS(3313),
    [anon_sym_file] = ACTIONS(3313),
    [anon_sym_fixed] = ACTIONS(3313),
    [anon_sym_internal] = ACTIONS(3313),
    [anon_sym_new] = ACTIONS(3313),
    [anon_sym_override] = ACTIONS(3313),
    [anon_sym_partial] = ACTIONS(3313),
    [anon_sym_private] = ACTIONS(3313),
    [anon_sym_protected] = ACTIONS(3313),
    [anon_sym_public] = ACTIONS(3313),
    [anon_sym_readonly] = ACTIONS(3313),
    [anon_sym_required] = ACTIONS(3313),
    [anon_sym_sealed] = ACTIONS(3313),
    [anon_sym_virtual] = ACTIONS(3313),
    [anon_sym_volatile] = ACTIONS(3313),
    [anon_sym_where] = ACTIONS(3313),
    [anon_sym_notnull] = ACTIONS(3313),
    [anon_sym_unmanaged] = ACTIONS(3313),
    [anon_sym_checked] = ACTIONS(3313),
    [anon_sym_BANG] = ACTIONS(3315),
    [anon_sym_TILDE] = ACTIONS(3315),
    [anon_sym_PLUS_PLUS] = ACTIONS(3315),
    [anon_sym_DASH_DASH] = ACTIONS(3315),
    [anon_sym_true] = ACTIONS(3313),
    [anon_sym_false] = ACTIONS(3313),
    [anon_sym_PLUS] = ACTIONS(3313),
    [anon_sym_DASH] = ACTIONS(3313),
    [anon_sym_STAR] = ACTIONS(3315),
    [anon_sym_CARET] = ACTIONS(3315),
    [anon_sym_AMP] = ACTIONS(3315),
    [anon_sym_this] = ACTIONS(3313),
    [anon_sym_scoped] = ACTIONS(3313),
    [anon_sym_base] = ACTIONS(3313),
    [anon_sym_var] = ACTIONS(3313),
    [sym_predefined_type] = ACTIONS(3313),
    [anon_sym_break] = ACTIONS(3313),
    [anon_sym_unchecked] = ACTIONS(3313),
    [anon_sym_continue] = ACTIONS(3313),
    [anon_sym_do] = ACTIONS(3313),
    [anon_sym_while] = ACTIONS(3313),
    [anon_sym_for] = ACTIONS(3313),
    [anon_sym_lock] = ACTIONS(3313),
    [anon_sym_yield] = ACTIONS(3313),
    [anon_sym_switch] = ACTIONS(3313),
    [anon_sym_default] = ACTIONS(3313),
    [anon_sym_throw] = ACTIONS(3313),
    [anon_sym_try] = ACTIONS(3313),
    [anon_sym_when] = ACTIONS(3313),
    [anon_sym_await] = ACTIONS(3313),
    [anon_sym_foreach] = ACTIONS(3313),
    [anon_sym_goto] = ACTIONS(3313),
    [anon_sym_if] = ACTIONS(3313),
    [anon_sym_else] = ACTIONS(3313),
    [anon_sym_DOT_DOT] = ACTIONS(3315),
    [anon_sym_from] = ACTIONS(3313),
    [anon_sym_into] = ACTIONS(3313),
    [anon_sym_join] = ACTIONS(3313),
    [anon_sym_on] = ACTIONS(3313),
    [anon_sym_equals] = ACTIONS(3313),
    [anon_sym_let] = ACTIONS(3313),
    [anon_sym_orderby] = ACTIONS(3313),
    [anon_sym_ascending] = ACTIONS(3313),
    [anon_sym_descending] = ACTIONS(3313),
    [anon_sym_group] = ACTIONS(3313),
    [anon_sym_by] = ACTIONS(3313),
    [anon_sym_select] = ACTIONS(3313),
    [anon_sym_stackalloc] = ACTIONS(3313),
    [anon_sym_sizeof] = ACTIONS(3313),
    [anon_sym_typeof] = ACTIONS(3313),
    [anon_sym___makeref] = ACTIONS(3313),
    [anon_sym___reftype] = ACTIONS(3313),
    [anon_sym___refvalue] = ACTIONS(3313),
    [sym_null_literal] = ACTIONS(3313),
    [anon_sym_SQUOTE] = ACTIONS(3315),
    [sym_integer_literal] = ACTIONS(3313),
    [sym_real_literal] = ACTIONS(3315),
    [anon_sym_DQUOTE] = ACTIONS(3315),
    [sym_verbatim_string_literal] = ACTIONS(3315),
    [aux_sym_preproc_if_token1] = ACTIONS(3315),
    [aux_sym_preproc_if_token3] = ACTIONS(3315),
    [aux_sym_preproc_else_token1] = ACTIONS(3315),
    [aux_sym_preproc_elif_token1] = ACTIONS(3315),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3315),
    [sym_interpolation_verbatim_start] = ACTIONS(3315),
    [sym_interpolation_raw_start] = ACTIONS(3315),
    [sym_raw_string_start] = ACTIONS(3315),
  },
  [2281] = {
    [sym_preproc_region] = STATE(2281),
    [sym_preproc_endregion] = STATE(2281),
    [sym_preproc_line] = STATE(2281),
    [sym_preproc_pragma] = STATE(2281),
    [sym_preproc_nullable] = STATE(2281),
    [sym_preproc_error] = STATE(2281),
    [sym_preproc_warning] = STATE(2281),
    [sym_preproc_define] = STATE(2281),
    [sym_preproc_undef] = STATE(2281),
    [sym__identifier_token] = ACTIONS(3317),
    [anon_sym_extern] = ACTIONS(3317),
    [anon_sym_alias] = ACTIONS(3317),
    [anon_sym_SEMI] = ACTIONS(3319),
    [anon_sym_global] = ACTIONS(3317),
    [anon_sym_using] = ACTIONS(3317),
    [anon_sym_unsafe] = ACTIONS(3317),
    [anon_sym_static] = ACTIONS(3317),
    [anon_sym_LBRACK] = ACTIONS(3319),
    [anon_sym_LPAREN] = ACTIONS(3319),
    [anon_sym_return] = ACTIONS(3317),
    [anon_sym_namespace] = ACTIONS(3317),
    [anon_sym_class] = ACTIONS(3317),
    [anon_sym_ref] = ACTIONS(3317),
    [anon_sym_struct] = ACTIONS(3317),
    [anon_sym_enum] = ACTIONS(3317),
    [anon_sym_LBRACE] = ACTIONS(3319),
    [anon_sym_interface] = ACTIONS(3317),
    [anon_sym_delegate] = ACTIONS(3317),
    [anon_sym_record] = ACTIONS(3317),
    [anon_sym_abstract] = ACTIONS(3317),
    [anon_sym_async] = ACTIONS(3317),
    [anon_sym_const] = ACTIONS(3317),
    [anon_sym_file] = ACTIONS(3317),
    [anon_sym_fixed] = ACTIONS(3317),
    [anon_sym_internal] = ACTIONS(3317),
    [anon_sym_new] = ACTIONS(3317),
    [anon_sym_override] = ACTIONS(3317),
    [anon_sym_partial] = ACTIONS(3317),
    [anon_sym_private] = ACTIONS(3317),
    [anon_sym_protected] = ACTIONS(3317),
    [anon_sym_public] = ACTIONS(3317),
    [anon_sym_readonly] = ACTIONS(3317),
    [anon_sym_required] = ACTIONS(3317),
    [anon_sym_sealed] = ACTIONS(3317),
    [anon_sym_virtual] = ACTIONS(3317),
    [anon_sym_volatile] = ACTIONS(3317),
    [anon_sym_where] = ACTIONS(3317),
    [anon_sym_notnull] = ACTIONS(3317),
    [anon_sym_unmanaged] = ACTIONS(3317),
    [anon_sym_checked] = ACTIONS(3317),
    [anon_sym_BANG] = ACTIONS(3319),
    [anon_sym_TILDE] = ACTIONS(3319),
    [anon_sym_PLUS_PLUS] = ACTIONS(3319),
    [anon_sym_DASH_DASH] = ACTIONS(3319),
    [anon_sym_true] = ACTIONS(3317),
    [anon_sym_false] = ACTIONS(3317),
    [anon_sym_PLUS] = ACTIONS(3317),
    [anon_sym_DASH] = ACTIONS(3317),
    [anon_sym_STAR] = ACTIONS(3319),
    [anon_sym_CARET] = ACTIONS(3319),
    [anon_sym_AMP] = ACTIONS(3319),
    [anon_sym_this] = ACTIONS(3317),
    [anon_sym_scoped] = ACTIONS(3317),
    [anon_sym_base] = ACTIONS(3317),
    [anon_sym_var] = ACTIONS(3317),
    [sym_predefined_type] = ACTIONS(3317),
    [anon_sym_break] = ACTIONS(3317),
    [anon_sym_unchecked] = ACTIONS(3317),
    [anon_sym_continue] = ACTIONS(3317),
    [anon_sym_do] = ACTIONS(3317),
    [anon_sym_while] = ACTIONS(3317),
    [anon_sym_for] = ACTIONS(3317),
    [anon_sym_lock] = ACTIONS(3317),
    [anon_sym_yield] = ACTIONS(3317),
    [anon_sym_switch] = ACTIONS(3317),
    [anon_sym_default] = ACTIONS(3317),
    [anon_sym_throw] = ACTIONS(3317),
    [anon_sym_try] = ACTIONS(3317),
    [anon_sym_when] = ACTIONS(3317),
    [anon_sym_await] = ACTIONS(3317),
    [anon_sym_foreach] = ACTIONS(3317),
    [anon_sym_goto] = ACTIONS(3317),
    [anon_sym_if] = ACTIONS(3317),
    [anon_sym_else] = ACTIONS(3321),
    [anon_sym_DOT_DOT] = ACTIONS(3319),
    [anon_sym_from] = ACTIONS(3317),
    [anon_sym_into] = ACTIONS(3317),
    [anon_sym_join] = ACTIONS(3317),
    [anon_sym_on] = ACTIONS(3317),
    [anon_sym_equals] = ACTIONS(3317),
    [anon_sym_let] = ACTIONS(3317),
    [anon_sym_orderby] = ACTIONS(3317),
    [anon_sym_ascending] = ACTIONS(3317),
    [anon_sym_descending] = ACTIONS(3317),
    [anon_sym_group] = ACTIONS(3317),
    [anon_sym_by] = ACTIONS(3317),
    [anon_sym_select] = ACTIONS(3317),
    [anon_sym_stackalloc] = ACTIONS(3317),
    [anon_sym_sizeof] = ACTIONS(3317),
    [anon_sym_typeof] = ACTIONS(3317),
    [anon_sym___makeref] = ACTIONS(3317),
    [anon_sym___reftype] = ACTIONS(3317),
    [anon_sym___refvalue] = ACTIONS(3317),
    [sym_null_literal] = ACTIONS(3317),
    [anon_sym_SQUOTE] = ACTIONS(3319),
    [sym_integer_literal] = ACTIONS(3317),
    [sym_real_literal] = ACTIONS(3319),
    [anon_sym_DQUOTE] = ACTIONS(3319),
    [sym_verbatim_string_literal] = ACTIONS(3319),
    [aux_sym_preproc_if_token1] = ACTIONS(3319),
    [aux_sym_preproc_if_token3] = ACTIONS(3319),
    [aux_sym_preproc_else_token1] = ACTIONS(3319),
    [aux_sym_preproc_elif_token1] = ACTIONS(3319),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3319),
    [sym_interpolation_verbatim_start] = ACTIONS(3319),
    [sym_interpolation_raw_start] = ACTIONS(3319),
    [sym_raw_string_start] = ACTIONS(3319),
  },
  [2282] = {
    [sym_preproc_region] = STATE(2282),
    [sym_preproc_endregion] = STATE(2282),
    [sym_preproc_line] = STATE(2282),
    [sym_preproc_pragma] = STATE(2282),
    [sym_preproc_nullable] = STATE(2282),
    [sym_preproc_error] = STATE(2282),
    [sym_preproc_warning] = STATE(2282),
    [sym_preproc_define] = STATE(2282),
    [sym_preproc_undef] = STATE(2282),
    [sym__identifier_token] = ACTIONS(3323),
    [anon_sym_extern] = ACTIONS(3323),
    [anon_sym_alias] = ACTIONS(3323),
    [anon_sym_SEMI] = ACTIONS(3325),
    [anon_sym_global] = ACTIONS(3323),
    [anon_sym_using] = ACTIONS(3323),
    [anon_sym_unsafe] = ACTIONS(3323),
    [anon_sym_static] = ACTIONS(3323),
    [anon_sym_LBRACK] = ACTIONS(3325),
    [anon_sym_LPAREN] = ACTIONS(3325),
    [anon_sym_return] = ACTIONS(3323),
    [anon_sym_namespace] = ACTIONS(3323),
    [anon_sym_class] = ACTIONS(3323),
    [anon_sym_ref] = ACTIONS(3323),
    [anon_sym_struct] = ACTIONS(3323),
    [anon_sym_enum] = ACTIONS(3323),
    [anon_sym_LBRACE] = ACTIONS(3325),
    [anon_sym_interface] = ACTIONS(3323),
    [anon_sym_delegate] = ACTIONS(3323),
    [anon_sym_record] = ACTIONS(3323),
    [anon_sym_abstract] = ACTIONS(3323),
    [anon_sym_async] = ACTIONS(3323),
    [anon_sym_const] = ACTIONS(3323),
    [anon_sym_file] = ACTIONS(3323),
    [anon_sym_fixed] = ACTIONS(3323),
    [anon_sym_internal] = ACTIONS(3323),
    [anon_sym_new] = ACTIONS(3323),
    [anon_sym_override] = ACTIONS(3323),
    [anon_sym_partial] = ACTIONS(3323),
    [anon_sym_private] = ACTIONS(3323),
    [anon_sym_protected] = ACTIONS(3323),
    [anon_sym_public] = ACTIONS(3323),
    [anon_sym_readonly] = ACTIONS(3323),
    [anon_sym_required] = ACTIONS(3323),
    [anon_sym_sealed] = ACTIONS(3323),
    [anon_sym_virtual] = ACTIONS(3323),
    [anon_sym_volatile] = ACTIONS(3323),
    [anon_sym_where] = ACTIONS(3323),
    [anon_sym_notnull] = ACTIONS(3323),
    [anon_sym_unmanaged] = ACTIONS(3323),
    [anon_sym_checked] = ACTIONS(3323),
    [anon_sym_BANG] = ACTIONS(3325),
    [anon_sym_TILDE] = ACTIONS(3325),
    [anon_sym_PLUS_PLUS] = ACTIONS(3325),
    [anon_sym_DASH_DASH] = ACTIONS(3325),
    [anon_sym_true] = ACTIONS(3323),
    [anon_sym_false] = ACTIONS(3323),
    [anon_sym_PLUS] = ACTIONS(3323),
    [anon_sym_DASH] = ACTIONS(3323),
    [anon_sym_STAR] = ACTIONS(3325),
    [anon_sym_CARET] = ACTIONS(3325),
    [anon_sym_AMP] = ACTIONS(3325),
    [anon_sym_this] = ACTIONS(3323),
    [anon_sym_scoped] = ACTIONS(3323),
    [anon_sym_base] = ACTIONS(3323),
    [anon_sym_var] = ACTIONS(3323),
    [sym_predefined_type] = ACTIONS(3323),
    [anon_sym_break] = ACTIONS(3323),
    [anon_sym_unchecked] = ACTIONS(3323),
    [anon_sym_continue] = ACTIONS(3323),
    [anon_sym_do] = ACTIONS(3323),
    [anon_sym_while] = ACTIONS(3323),
    [anon_sym_for] = ACTIONS(3323),
    [anon_sym_lock] = ACTIONS(3323),
    [anon_sym_yield] = ACTIONS(3323),
    [anon_sym_switch] = ACTIONS(3323),
    [anon_sym_default] = ACTIONS(3323),
    [anon_sym_throw] = ACTIONS(3323),
    [anon_sym_try] = ACTIONS(3323),
    [anon_sym_when] = ACTIONS(3323),
    [anon_sym_await] = ACTIONS(3323),
    [anon_sym_foreach] = ACTIONS(3323),
    [anon_sym_goto] = ACTIONS(3323),
    [anon_sym_if] = ACTIONS(3323),
    [anon_sym_else] = ACTIONS(3323),
    [anon_sym_DOT_DOT] = ACTIONS(3325),
    [anon_sym_from] = ACTIONS(3323),
    [anon_sym_into] = ACTIONS(3323),
    [anon_sym_join] = ACTIONS(3323),
    [anon_sym_on] = ACTIONS(3323),
    [anon_sym_equals] = ACTIONS(3323),
    [anon_sym_let] = ACTIONS(3323),
    [anon_sym_orderby] = ACTIONS(3323),
    [anon_sym_ascending] = ACTIONS(3323),
    [anon_sym_descending] = ACTIONS(3323),
    [anon_sym_group] = ACTIONS(3323),
    [anon_sym_by] = ACTIONS(3323),
    [anon_sym_select] = ACTIONS(3323),
    [anon_sym_stackalloc] = ACTIONS(3323),
    [anon_sym_sizeof] = ACTIONS(3323),
    [anon_sym_typeof] = ACTIONS(3323),
    [anon_sym___makeref] = ACTIONS(3323),
    [anon_sym___reftype] = ACTIONS(3323),
    [anon_sym___refvalue] = ACTIONS(3323),
    [sym_null_literal] = ACTIONS(3323),
    [anon_sym_SQUOTE] = ACTIONS(3325),
    [sym_integer_literal] = ACTIONS(3323),
    [sym_real_literal] = ACTIONS(3325),
    [anon_sym_DQUOTE] = ACTIONS(3325),
    [sym_verbatim_string_literal] = ACTIONS(3325),
    [aux_sym_preproc_if_token1] = ACTIONS(3325),
    [aux_sym_preproc_if_token3] = ACTIONS(3325),
    [aux_sym_preproc_else_token1] = ACTIONS(3325),
    [aux_sym_preproc_elif_token1] = ACTIONS(3325),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3325),
    [sym_interpolation_verbatim_start] = ACTIONS(3325),
    [sym_interpolation_raw_start] = ACTIONS(3325),
    [sym_raw_string_start] = ACTIONS(3325),
  },
  [2283] = {
    [sym_preproc_region] = STATE(2283),
    [sym_preproc_endregion] = STATE(2283),
    [sym_preproc_line] = STATE(2283),
    [sym_preproc_pragma] = STATE(2283),
    [sym_preproc_nullable] = STATE(2283),
    [sym_preproc_error] = STATE(2283),
    [sym_preproc_warning] = STATE(2283),
    [sym_preproc_define] = STATE(2283),
    [sym_preproc_undef] = STATE(2283),
    [sym__identifier_token] = ACTIONS(3327),
    [anon_sym_extern] = ACTIONS(3327),
    [anon_sym_alias] = ACTIONS(3327),
    [anon_sym_SEMI] = ACTIONS(3329),
    [anon_sym_global] = ACTIONS(3327),
    [anon_sym_using] = ACTIONS(3327),
    [anon_sym_unsafe] = ACTIONS(3327),
    [anon_sym_static] = ACTIONS(3327),
    [anon_sym_LBRACK] = ACTIONS(3329),
    [anon_sym_LPAREN] = ACTIONS(3329),
    [anon_sym_return] = ACTIONS(3327),
    [anon_sym_namespace] = ACTIONS(3327),
    [anon_sym_class] = ACTIONS(3327),
    [anon_sym_ref] = ACTIONS(3327),
    [anon_sym_struct] = ACTIONS(3327),
    [anon_sym_enum] = ACTIONS(3327),
    [anon_sym_LBRACE] = ACTIONS(3329),
    [anon_sym_interface] = ACTIONS(3327),
    [anon_sym_delegate] = ACTIONS(3327),
    [anon_sym_record] = ACTIONS(3327),
    [anon_sym_abstract] = ACTIONS(3327),
    [anon_sym_async] = ACTIONS(3327),
    [anon_sym_const] = ACTIONS(3327),
    [anon_sym_file] = ACTIONS(3327),
    [anon_sym_fixed] = ACTIONS(3327),
    [anon_sym_internal] = ACTIONS(3327),
    [anon_sym_new] = ACTIONS(3327),
    [anon_sym_override] = ACTIONS(3327),
    [anon_sym_partial] = ACTIONS(3327),
    [anon_sym_private] = ACTIONS(3327),
    [anon_sym_protected] = ACTIONS(3327),
    [anon_sym_public] = ACTIONS(3327),
    [anon_sym_readonly] = ACTIONS(3327),
    [anon_sym_required] = ACTIONS(3327),
    [anon_sym_sealed] = ACTIONS(3327),
    [anon_sym_virtual] = ACTIONS(3327),
    [anon_sym_volatile] = ACTIONS(3327),
    [anon_sym_where] = ACTIONS(3327),
    [anon_sym_notnull] = ACTIONS(3327),
    [anon_sym_unmanaged] = ACTIONS(3327),
    [anon_sym_checked] = ACTIONS(3327),
    [anon_sym_BANG] = ACTIONS(3329),
    [anon_sym_TILDE] = ACTIONS(3329),
    [anon_sym_PLUS_PLUS] = ACTIONS(3329),
    [anon_sym_DASH_DASH] = ACTIONS(3329),
    [anon_sym_true] = ACTIONS(3327),
    [anon_sym_false] = ACTIONS(3327),
    [anon_sym_PLUS] = ACTIONS(3327),
    [anon_sym_DASH] = ACTIONS(3327),
    [anon_sym_STAR] = ACTIONS(3329),
    [anon_sym_CARET] = ACTIONS(3329),
    [anon_sym_AMP] = ACTIONS(3329),
    [anon_sym_this] = ACTIONS(3327),
    [anon_sym_scoped] = ACTIONS(3327),
    [anon_sym_base] = ACTIONS(3327),
    [anon_sym_var] = ACTIONS(3327),
    [sym_predefined_type] = ACTIONS(3327),
    [anon_sym_break] = ACTIONS(3327),
    [anon_sym_unchecked] = ACTIONS(3327),
    [anon_sym_continue] = ACTIONS(3327),
    [anon_sym_do] = ACTIONS(3327),
    [anon_sym_while] = ACTIONS(3327),
    [anon_sym_for] = ACTIONS(3327),
    [anon_sym_lock] = ACTIONS(3327),
    [anon_sym_yield] = ACTIONS(3327),
    [anon_sym_switch] = ACTIONS(3327),
    [anon_sym_default] = ACTIONS(3327),
    [anon_sym_throw] = ACTIONS(3327),
    [anon_sym_try] = ACTIONS(3327),
    [anon_sym_when] = ACTIONS(3327),
    [anon_sym_await] = ACTIONS(3327),
    [anon_sym_foreach] = ACTIONS(3327),
    [anon_sym_goto] = ACTIONS(3327),
    [anon_sym_if] = ACTIONS(3327),
    [anon_sym_else] = ACTIONS(3327),
    [anon_sym_DOT_DOT] = ACTIONS(3329),
    [anon_sym_from] = ACTIONS(3327),
    [anon_sym_into] = ACTIONS(3327),
    [anon_sym_join] = ACTIONS(3327),
    [anon_sym_on] = ACTIONS(3327),
    [anon_sym_equals] = ACTIONS(3327),
    [anon_sym_let] = ACTIONS(3327),
    [anon_sym_orderby] = ACTIONS(3327),
    [anon_sym_ascending] = ACTIONS(3327),
    [anon_sym_descending] = ACTIONS(3327),
    [anon_sym_group] = ACTIONS(3327),
    [anon_sym_by] = ACTIONS(3327),
    [anon_sym_select] = ACTIONS(3327),
    [anon_sym_stackalloc] = ACTIONS(3327),
    [anon_sym_sizeof] = ACTIONS(3327),
    [anon_sym_typeof] = ACTIONS(3327),
    [anon_sym___makeref] = ACTIONS(3327),
    [anon_sym___reftype] = ACTIONS(3327),
    [anon_sym___refvalue] = ACTIONS(3327),
    [sym_null_literal] = ACTIONS(3327),
    [anon_sym_SQUOTE] = ACTIONS(3329),
    [sym_integer_literal] = ACTIONS(3327),
    [sym_real_literal] = ACTIONS(3329),
    [anon_sym_DQUOTE] = ACTIONS(3329),
    [sym_verbatim_string_literal] = ACTIONS(3329),
    [aux_sym_preproc_if_token1] = ACTIONS(3329),
    [aux_sym_preproc_if_token3] = ACTIONS(3329),
    [aux_sym_preproc_else_token1] = ACTIONS(3329),
    [aux_sym_preproc_elif_token1] = ACTIONS(3329),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3329),
    [sym_interpolation_verbatim_start] = ACTIONS(3329),
    [sym_interpolation_raw_start] = ACTIONS(3329),
    [sym_raw_string_start] = ACTIONS(3329),
  },
  [2284] = {
    [sym_preproc_region] = STATE(2284),
    [sym_preproc_endregion] = STATE(2284),
    [sym_preproc_line] = STATE(2284),
    [sym_preproc_pragma] = STATE(2284),
    [sym_preproc_nullable] = STATE(2284),
    [sym_preproc_error] = STATE(2284),
    [sym_preproc_warning] = STATE(2284),
    [sym_preproc_define] = STATE(2284),
    [sym_preproc_undef] = STATE(2284),
    [ts_builtin_sym_end] = ACTIONS(3047),
    [sym__identifier_token] = ACTIONS(3045),
    [anon_sym_extern] = ACTIONS(3045),
    [anon_sym_alias] = ACTIONS(3045),
    [anon_sym_SEMI] = ACTIONS(3047),
    [anon_sym_global] = ACTIONS(3045),
    [anon_sym_using] = ACTIONS(3045),
    [anon_sym_unsafe] = ACTIONS(3045),
    [anon_sym_static] = ACTIONS(3045),
    [anon_sym_LBRACK] = ACTIONS(3047),
    [anon_sym_LPAREN] = ACTIONS(3047),
    [anon_sym_return] = ACTIONS(3045),
    [anon_sym_namespace] = ACTIONS(3045),
    [anon_sym_class] = ACTIONS(3045),
    [anon_sym_ref] = ACTIONS(3045),
    [anon_sym_struct] = ACTIONS(3045),
    [anon_sym_enum] = ACTIONS(3045),
    [anon_sym_LBRACE] = ACTIONS(3047),
    [anon_sym_interface] = ACTIONS(3045),
    [anon_sym_delegate] = ACTIONS(3045),
    [anon_sym_record] = ACTIONS(3045),
    [anon_sym_abstract] = ACTIONS(3045),
    [anon_sym_async] = ACTIONS(3045),
    [anon_sym_const] = ACTIONS(3045),
    [anon_sym_file] = ACTIONS(3045),
    [anon_sym_fixed] = ACTIONS(3045),
    [anon_sym_internal] = ACTIONS(3045),
    [anon_sym_new] = ACTIONS(3045),
    [anon_sym_override] = ACTIONS(3045),
    [anon_sym_partial] = ACTIONS(3045),
    [anon_sym_private] = ACTIONS(3045),
    [anon_sym_protected] = ACTIONS(3045),
    [anon_sym_public] = ACTIONS(3045),
    [anon_sym_readonly] = ACTIONS(3045),
    [anon_sym_required] = ACTIONS(3045),
    [anon_sym_sealed] = ACTIONS(3045),
    [anon_sym_virtual] = ACTIONS(3045),
    [anon_sym_volatile] = ACTIONS(3045),
    [anon_sym_where] = ACTIONS(3045),
    [anon_sym_notnull] = ACTIONS(3045),
    [anon_sym_unmanaged] = ACTIONS(3045),
    [anon_sym_checked] = ACTIONS(3045),
    [anon_sym_BANG] = ACTIONS(3047),
    [anon_sym_TILDE] = ACTIONS(3047),
    [anon_sym_PLUS_PLUS] = ACTIONS(3047),
    [anon_sym_DASH_DASH] = ACTIONS(3047),
    [anon_sym_true] = ACTIONS(3045),
    [anon_sym_false] = ACTIONS(3045),
    [anon_sym_PLUS] = ACTIONS(3045),
    [anon_sym_DASH] = ACTIONS(3045),
    [anon_sym_STAR] = ACTIONS(3047),
    [anon_sym_CARET] = ACTIONS(3047),
    [anon_sym_AMP] = ACTIONS(3047),
    [anon_sym_this] = ACTIONS(3045),
    [anon_sym_scoped] = ACTIONS(3045),
    [anon_sym_base] = ACTIONS(3045),
    [anon_sym_var] = ACTIONS(3045),
    [sym_predefined_type] = ACTIONS(3045),
    [anon_sym_break] = ACTIONS(3045),
    [anon_sym_unchecked] = ACTIONS(3045),
    [anon_sym_continue] = ACTIONS(3045),
    [anon_sym_do] = ACTIONS(3045),
    [anon_sym_while] = ACTIONS(3045),
    [anon_sym_for] = ACTIONS(3045),
    [anon_sym_lock] = ACTIONS(3045),
    [anon_sym_yield] = ACTIONS(3045),
    [anon_sym_switch] = ACTIONS(3045),
    [anon_sym_default] = ACTIONS(3045),
    [anon_sym_throw] = ACTIONS(3045),
    [anon_sym_try] = ACTIONS(3045),
    [anon_sym_catch] = ACTIONS(3045),
    [anon_sym_when] = ACTIONS(3045),
    [anon_sym_finally] = ACTIONS(3045),
    [anon_sym_await] = ACTIONS(3045),
    [anon_sym_foreach] = ACTIONS(3045),
    [anon_sym_goto] = ACTIONS(3045),
    [anon_sym_if] = ACTIONS(3045),
    [anon_sym_else] = ACTIONS(3045),
    [anon_sym_DOT_DOT] = ACTIONS(3047),
    [anon_sym_from] = ACTIONS(3045),
    [anon_sym_into] = ACTIONS(3045),
    [anon_sym_join] = ACTIONS(3045),
    [anon_sym_on] = ACTIONS(3045),
    [anon_sym_equals] = ACTIONS(3045),
    [anon_sym_let] = ACTIONS(3045),
    [anon_sym_orderby] = ACTIONS(3045),
    [anon_sym_ascending] = ACTIONS(3045),
    [anon_sym_descending] = ACTIONS(3045),
    [anon_sym_group] = ACTIONS(3045),
    [anon_sym_by] = ACTIONS(3045),
    [anon_sym_select] = ACTIONS(3045),
    [anon_sym_stackalloc] = ACTIONS(3045),
    [anon_sym_sizeof] = ACTIONS(3045),
    [anon_sym_typeof] = ACTIONS(3045),
    [anon_sym___makeref] = ACTIONS(3045),
    [anon_sym___reftype] = ACTIONS(3045),
    [anon_sym___refvalue] = ACTIONS(3045),
    [sym_null_literal] = ACTIONS(3045),
    [anon_sym_SQUOTE] = ACTIONS(3047),
    [sym_integer_literal] = ACTIONS(3045),
    [sym_real_literal] = ACTIONS(3047),
    [anon_sym_DQUOTE] = ACTIONS(3047),
    [sym_verbatim_string_literal] = ACTIONS(3047),
    [aux_sym_preproc_if_token1] = ACTIONS(3047),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3047),
    [sym_interpolation_verbatim_start] = ACTIONS(3047),
    [sym_interpolation_raw_start] = ACTIONS(3047),
    [sym_raw_string_start] = ACTIONS(3047),
  },
  [2285] = {
    [sym_preproc_region] = STATE(2285),
    [sym_preproc_endregion] = STATE(2285),
    [sym_preproc_line] = STATE(2285),
    [sym_preproc_pragma] = STATE(2285),
    [sym_preproc_nullable] = STATE(2285),
    [sym_preproc_error] = STATE(2285),
    [sym_preproc_warning] = STATE(2285),
    [sym_preproc_define] = STATE(2285),
    [sym_preproc_undef] = STATE(2285),
    [sym__identifier_token] = ACTIONS(3331),
    [anon_sym_extern] = ACTIONS(3331),
    [anon_sym_alias] = ACTIONS(3331),
    [anon_sym_SEMI] = ACTIONS(3333),
    [anon_sym_global] = ACTIONS(3331),
    [anon_sym_using] = ACTIONS(3331),
    [anon_sym_unsafe] = ACTIONS(3331),
    [anon_sym_static] = ACTIONS(3331),
    [anon_sym_LBRACK] = ACTIONS(3333),
    [anon_sym_LPAREN] = ACTIONS(3333),
    [anon_sym_return] = ACTIONS(3331),
    [anon_sym_namespace] = ACTIONS(3331),
    [anon_sym_class] = ACTIONS(3331),
    [anon_sym_ref] = ACTIONS(3331),
    [anon_sym_struct] = ACTIONS(3331),
    [anon_sym_enum] = ACTIONS(3331),
    [anon_sym_LBRACE] = ACTIONS(3333),
    [anon_sym_interface] = ACTIONS(3331),
    [anon_sym_delegate] = ACTIONS(3331),
    [anon_sym_record] = ACTIONS(3331),
    [anon_sym_abstract] = ACTIONS(3331),
    [anon_sym_async] = ACTIONS(3331),
    [anon_sym_const] = ACTIONS(3331),
    [anon_sym_file] = ACTIONS(3331),
    [anon_sym_fixed] = ACTIONS(3331),
    [anon_sym_internal] = ACTIONS(3331),
    [anon_sym_new] = ACTIONS(3331),
    [anon_sym_override] = ACTIONS(3331),
    [anon_sym_partial] = ACTIONS(3331),
    [anon_sym_private] = ACTIONS(3331),
    [anon_sym_protected] = ACTIONS(3331),
    [anon_sym_public] = ACTIONS(3331),
    [anon_sym_readonly] = ACTIONS(3331),
    [anon_sym_required] = ACTIONS(3331),
    [anon_sym_sealed] = ACTIONS(3331),
    [anon_sym_virtual] = ACTIONS(3331),
    [anon_sym_volatile] = ACTIONS(3331),
    [anon_sym_where] = ACTIONS(3331),
    [anon_sym_notnull] = ACTIONS(3331),
    [anon_sym_unmanaged] = ACTIONS(3331),
    [anon_sym_checked] = ACTIONS(3331),
    [anon_sym_BANG] = ACTIONS(3333),
    [anon_sym_TILDE] = ACTIONS(3333),
    [anon_sym_PLUS_PLUS] = ACTIONS(3333),
    [anon_sym_DASH_DASH] = ACTIONS(3333),
    [anon_sym_true] = ACTIONS(3331),
    [anon_sym_false] = ACTIONS(3331),
    [anon_sym_PLUS] = ACTIONS(3331),
    [anon_sym_DASH] = ACTIONS(3331),
    [anon_sym_STAR] = ACTIONS(3333),
    [anon_sym_CARET] = ACTIONS(3333),
    [anon_sym_AMP] = ACTIONS(3333),
    [anon_sym_this] = ACTIONS(3331),
    [anon_sym_scoped] = ACTIONS(3331),
    [anon_sym_base] = ACTIONS(3331),
    [anon_sym_var] = ACTIONS(3331),
    [sym_predefined_type] = ACTIONS(3331),
    [anon_sym_break] = ACTIONS(3331),
    [anon_sym_unchecked] = ACTIONS(3331),
    [anon_sym_continue] = ACTIONS(3331),
    [anon_sym_do] = ACTIONS(3331),
    [anon_sym_while] = ACTIONS(3331),
    [anon_sym_for] = ACTIONS(3331),
    [anon_sym_lock] = ACTIONS(3331),
    [anon_sym_yield] = ACTIONS(3331),
    [anon_sym_switch] = ACTIONS(3331),
    [anon_sym_default] = ACTIONS(3331),
    [anon_sym_throw] = ACTIONS(3331),
    [anon_sym_try] = ACTIONS(3331),
    [anon_sym_when] = ACTIONS(3331),
    [anon_sym_await] = ACTIONS(3331),
    [anon_sym_foreach] = ACTIONS(3331),
    [anon_sym_goto] = ACTIONS(3331),
    [anon_sym_if] = ACTIONS(3331),
    [anon_sym_else] = ACTIONS(3331),
    [anon_sym_DOT_DOT] = ACTIONS(3333),
    [anon_sym_from] = ACTIONS(3331),
    [anon_sym_into] = ACTIONS(3331),
    [anon_sym_join] = ACTIONS(3331),
    [anon_sym_on] = ACTIONS(3331),
    [anon_sym_equals] = ACTIONS(3331),
    [anon_sym_let] = ACTIONS(3331),
    [anon_sym_orderby] = ACTIONS(3331),
    [anon_sym_ascending] = ACTIONS(3331),
    [anon_sym_descending] = ACTIONS(3331),
    [anon_sym_group] = ACTIONS(3331),
    [anon_sym_by] = ACTIONS(3331),
    [anon_sym_select] = ACTIONS(3331),
    [anon_sym_stackalloc] = ACTIONS(3331),
    [anon_sym_sizeof] = ACTIONS(3331),
    [anon_sym_typeof] = ACTIONS(3331),
    [anon_sym___makeref] = ACTIONS(3331),
    [anon_sym___reftype] = ACTIONS(3331),
    [anon_sym___refvalue] = ACTIONS(3331),
    [sym_null_literal] = ACTIONS(3331),
    [anon_sym_SQUOTE] = ACTIONS(3333),
    [sym_integer_literal] = ACTIONS(3331),
    [sym_real_literal] = ACTIONS(3333),
    [anon_sym_DQUOTE] = ACTIONS(3333),
    [sym_verbatim_string_literal] = ACTIONS(3333),
    [aux_sym_preproc_if_token1] = ACTIONS(3333),
    [aux_sym_preproc_if_token3] = ACTIONS(3333),
    [aux_sym_preproc_else_token1] = ACTIONS(3333),
    [aux_sym_preproc_elif_token1] = ACTIONS(3333),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3333),
    [sym_interpolation_verbatim_start] = ACTIONS(3333),
    [sym_interpolation_raw_start] = ACTIONS(3333),
    [sym_raw_string_start] = ACTIONS(3333),
  },
  [2286] = {
    [sym_preproc_region] = STATE(2286),
    [sym_preproc_endregion] = STATE(2286),
    [sym_preproc_line] = STATE(2286),
    [sym_preproc_pragma] = STATE(2286),
    [sym_preproc_nullable] = STATE(2286),
    [sym_preproc_error] = STATE(2286),
    [sym_preproc_warning] = STATE(2286),
    [sym_preproc_define] = STATE(2286),
    [sym_preproc_undef] = STATE(2286),
    [sym__identifier_token] = ACTIONS(3335),
    [anon_sym_extern] = ACTIONS(3335),
    [anon_sym_alias] = ACTIONS(3335),
    [anon_sym_SEMI] = ACTIONS(3337),
    [anon_sym_global] = ACTIONS(3335),
    [anon_sym_using] = ACTIONS(3335),
    [anon_sym_unsafe] = ACTIONS(3335),
    [anon_sym_static] = ACTIONS(3335),
    [anon_sym_LBRACK] = ACTIONS(3337),
    [anon_sym_LPAREN] = ACTIONS(3337),
    [anon_sym_return] = ACTIONS(3335),
    [anon_sym_namespace] = ACTIONS(3335),
    [anon_sym_class] = ACTIONS(3335),
    [anon_sym_ref] = ACTIONS(3335),
    [anon_sym_struct] = ACTIONS(3335),
    [anon_sym_enum] = ACTIONS(3335),
    [anon_sym_LBRACE] = ACTIONS(3337),
    [anon_sym_interface] = ACTIONS(3335),
    [anon_sym_delegate] = ACTIONS(3335),
    [anon_sym_record] = ACTIONS(3335),
    [anon_sym_abstract] = ACTIONS(3335),
    [anon_sym_async] = ACTIONS(3335),
    [anon_sym_const] = ACTIONS(3335),
    [anon_sym_file] = ACTIONS(3335),
    [anon_sym_fixed] = ACTIONS(3335),
    [anon_sym_internal] = ACTIONS(3335),
    [anon_sym_new] = ACTIONS(3335),
    [anon_sym_override] = ACTIONS(3335),
    [anon_sym_partial] = ACTIONS(3335),
    [anon_sym_private] = ACTIONS(3335),
    [anon_sym_protected] = ACTIONS(3335),
    [anon_sym_public] = ACTIONS(3335),
    [anon_sym_readonly] = ACTIONS(3335),
    [anon_sym_required] = ACTIONS(3335),
    [anon_sym_sealed] = ACTIONS(3335),
    [anon_sym_virtual] = ACTIONS(3335),
    [anon_sym_volatile] = ACTIONS(3335),
    [anon_sym_where] = ACTIONS(3335),
    [anon_sym_notnull] = ACTIONS(3335),
    [anon_sym_unmanaged] = ACTIONS(3335),
    [anon_sym_checked] = ACTIONS(3335),
    [anon_sym_BANG] = ACTIONS(3337),
    [anon_sym_TILDE] = ACTIONS(3337),
    [anon_sym_PLUS_PLUS] = ACTIONS(3337),
    [anon_sym_DASH_DASH] = ACTIONS(3337),
    [anon_sym_true] = ACTIONS(3335),
    [anon_sym_false] = ACTIONS(3335),
    [anon_sym_PLUS] = ACTIONS(3335),
    [anon_sym_DASH] = ACTIONS(3335),
    [anon_sym_STAR] = ACTIONS(3337),
    [anon_sym_CARET] = ACTIONS(3337),
    [anon_sym_AMP] = ACTIONS(3337),
    [anon_sym_this] = ACTIONS(3335),
    [anon_sym_scoped] = ACTIONS(3335),
    [anon_sym_base] = ACTIONS(3335),
    [anon_sym_var] = ACTIONS(3335),
    [sym_predefined_type] = ACTIONS(3335),
    [anon_sym_break] = ACTIONS(3335),
    [anon_sym_unchecked] = ACTIONS(3335),
    [anon_sym_continue] = ACTIONS(3335),
    [anon_sym_do] = ACTIONS(3335),
    [anon_sym_while] = ACTIONS(3335),
    [anon_sym_for] = ACTIONS(3335),
    [anon_sym_lock] = ACTIONS(3335),
    [anon_sym_yield] = ACTIONS(3335),
    [anon_sym_switch] = ACTIONS(3335),
    [anon_sym_default] = ACTIONS(3335),
    [anon_sym_throw] = ACTIONS(3335),
    [anon_sym_try] = ACTIONS(3335),
    [anon_sym_when] = ACTIONS(3335),
    [anon_sym_await] = ACTIONS(3335),
    [anon_sym_foreach] = ACTIONS(3335),
    [anon_sym_goto] = ACTIONS(3335),
    [anon_sym_if] = ACTIONS(3335),
    [anon_sym_else] = ACTIONS(3335),
    [anon_sym_DOT_DOT] = ACTIONS(3337),
    [anon_sym_from] = ACTIONS(3335),
    [anon_sym_into] = ACTIONS(3335),
    [anon_sym_join] = ACTIONS(3335),
    [anon_sym_on] = ACTIONS(3335),
    [anon_sym_equals] = ACTIONS(3335),
    [anon_sym_let] = ACTIONS(3335),
    [anon_sym_orderby] = ACTIONS(3335),
    [anon_sym_ascending] = ACTIONS(3335),
    [anon_sym_descending] = ACTIONS(3335),
    [anon_sym_group] = ACTIONS(3335),
    [anon_sym_by] = ACTIONS(3335),
    [anon_sym_select] = ACTIONS(3335),
    [anon_sym_stackalloc] = ACTIONS(3335),
    [anon_sym_sizeof] = ACTIONS(3335),
    [anon_sym_typeof] = ACTIONS(3335),
    [anon_sym___makeref] = ACTIONS(3335),
    [anon_sym___reftype] = ACTIONS(3335),
    [anon_sym___refvalue] = ACTIONS(3335),
    [sym_null_literal] = ACTIONS(3335),
    [anon_sym_SQUOTE] = ACTIONS(3337),
    [sym_integer_literal] = ACTIONS(3335),
    [sym_real_literal] = ACTIONS(3337),
    [anon_sym_DQUOTE] = ACTIONS(3337),
    [sym_verbatim_string_literal] = ACTIONS(3337),
    [aux_sym_preproc_if_token1] = ACTIONS(3337),
    [aux_sym_preproc_if_token3] = ACTIONS(3337),
    [aux_sym_preproc_else_token1] = ACTIONS(3337),
    [aux_sym_preproc_elif_token1] = ACTIONS(3337),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3337),
    [sym_interpolation_verbatim_start] = ACTIONS(3337),
    [sym_interpolation_raw_start] = ACTIONS(3337),
    [sym_raw_string_start] = ACTIONS(3337),
  },
  [2287] = {
    [sym_preproc_region] = STATE(2287),
    [sym_preproc_endregion] = STATE(2287),
    [sym_preproc_line] = STATE(2287),
    [sym_preproc_pragma] = STATE(2287),
    [sym_preproc_nullable] = STATE(2287),
    [sym_preproc_error] = STATE(2287),
    [sym_preproc_warning] = STATE(2287),
    [sym_preproc_define] = STATE(2287),
    [sym_preproc_undef] = STATE(2287),
    [sym__identifier_token] = ACTIONS(3339),
    [anon_sym_extern] = ACTIONS(3339),
    [anon_sym_alias] = ACTIONS(3339),
    [anon_sym_SEMI] = ACTIONS(3341),
    [anon_sym_global] = ACTIONS(3339),
    [anon_sym_using] = ACTIONS(3339),
    [anon_sym_unsafe] = ACTIONS(3339),
    [anon_sym_static] = ACTIONS(3339),
    [anon_sym_LBRACK] = ACTIONS(3341),
    [anon_sym_LPAREN] = ACTIONS(3341),
    [anon_sym_return] = ACTIONS(3339),
    [anon_sym_namespace] = ACTIONS(3339),
    [anon_sym_class] = ACTIONS(3339),
    [anon_sym_ref] = ACTIONS(3339),
    [anon_sym_struct] = ACTIONS(3339),
    [anon_sym_enum] = ACTIONS(3339),
    [anon_sym_LBRACE] = ACTIONS(3341),
    [anon_sym_interface] = ACTIONS(3339),
    [anon_sym_delegate] = ACTIONS(3339),
    [anon_sym_record] = ACTIONS(3339),
    [anon_sym_abstract] = ACTIONS(3339),
    [anon_sym_async] = ACTIONS(3339),
    [anon_sym_const] = ACTIONS(3339),
    [anon_sym_file] = ACTIONS(3339),
    [anon_sym_fixed] = ACTIONS(3339),
    [anon_sym_internal] = ACTIONS(3339),
    [anon_sym_new] = ACTIONS(3339),
    [anon_sym_override] = ACTIONS(3339),
    [anon_sym_partial] = ACTIONS(3339),
    [anon_sym_private] = ACTIONS(3339),
    [anon_sym_protected] = ACTIONS(3339),
    [anon_sym_public] = ACTIONS(3339),
    [anon_sym_readonly] = ACTIONS(3339),
    [anon_sym_required] = ACTIONS(3339),
    [anon_sym_sealed] = ACTIONS(3339),
    [anon_sym_virtual] = ACTIONS(3339),
    [anon_sym_volatile] = ACTIONS(3339),
    [anon_sym_where] = ACTIONS(3339),
    [anon_sym_notnull] = ACTIONS(3339),
    [anon_sym_unmanaged] = ACTIONS(3339),
    [anon_sym_checked] = ACTIONS(3339),
    [anon_sym_BANG] = ACTIONS(3341),
    [anon_sym_TILDE] = ACTIONS(3341),
    [anon_sym_PLUS_PLUS] = ACTIONS(3341),
    [anon_sym_DASH_DASH] = ACTIONS(3341),
    [anon_sym_true] = ACTIONS(3339),
    [anon_sym_false] = ACTIONS(3339),
    [anon_sym_PLUS] = ACTIONS(3339),
    [anon_sym_DASH] = ACTIONS(3339),
    [anon_sym_STAR] = ACTIONS(3341),
    [anon_sym_CARET] = ACTIONS(3341),
    [anon_sym_AMP] = ACTIONS(3341),
    [anon_sym_this] = ACTIONS(3339),
    [anon_sym_scoped] = ACTIONS(3339),
    [anon_sym_base] = ACTIONS(3339),
    [anon_sym_var] = ACTIONS(3339),
    [sym_predefined_type] = ACTIONS(3339),
    [anon_sym_break] = ACTIONS(3339),
    [anon_sym_unchecked] = ACTIONS(3339),
    [anon_sym_continue] = ACTIONS(3339),
    [anon_sym_do] = ACTIONS(3339),
    [anon_sym_while] = ACTIONS(3339),
    [anon_sym_for] = ACTIONS(3339),
    [anon_sym_lock] = ACTIONS(3339),
    [anon_sym_yield] = ACTIONS(3339),
    [anon_sym_switch] = ACTIONS(3339),
    [anon_sym_default] = ACTIONS(3339),
    [anon_sym_throw] = ACTIONS(3339),
    [anon_sym_try] = ACTIONS(3339),
    [anon_sym_when] = ACTIONS(3339),
    [anon_sym_await] = ACTIONS(3339),
    [anon_sym_foreach] = ACTIONS(3339),
    [anon_sym_goto] = ACTIONS(3339),
    [anon_sym_if] = ACTIONS(3339),
    [anon_sym_else] = ACTIONS(3339),
    [anon_sym_DOT_DOT] = ACTIONS(3341),
    [anon_sym_from] = ACTIONS(3339),
    [anon_sym_into] = ACTIONS(3339),
    [anon_sym_join] = ACTIONS(3339),
    [anon_sym_on] = ACTIONS(3339),
    [anon_sym_equals] = ACTIONS(3339),
    [anon_sym_let] = ACTIONS(3339),
    [anon_sym_orderby] = ACTIONS(3339),
    [anon_sym_ascending] = ACTIONS(3339),
    [anon_sym_descending] = ACTIONS(3339),
    [anon_sym_group] = ACTIONS(3339),
    [anon_sym_by] = ACTIONS(3339),
    [anon_sym_select] = ACTIONS(3339),
    [anon_sym_stackalloc] = ACTIONS(3339),
    [anon_sym_sizeof] = ACTIONS(3339),
    [anon_sym_typeof] = ACTIONS(3339),
    [anon_sym___makeref] = ACTIONS(3339),
    [anon_sym___reftype] = ACTIONS(3339),
    [anon_sym___refvalue] = ACTIONS(3339),
    [sym_null_literal] = ACTIONS(3339),
    [anon_sym_SQUOTE] = ACTIONS(3341),
    [sym_integer_literal] = ACTIONS(3339),
    [sym_real_literal] = ACTIONS(3341),
    [anon_sym_DQUOTE] = ACTIONS(3341),
    [sym_verbatim_string_literal] = ACTIONS(3341),
    [aux_sym_preproc_if_token1] = ACTIONS(3341),
    [aux_sym_preproc_if_token3] = ACTIONS(3341),
    [aux_sym_preproc_else_token1] = ACTIONS(3341),
    [aux_sym_preproc_elif_token1] = ACTIONS(3341),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3341),
    [sym_interpolation_verbatim_start] = ACTIONS(3341),
    [sym_interpolation_raw_start] = ACTIONS(3341),
    [sym_raw_string_start] = ACTIONS(3341),
  },
  [2288] = {
    [sym_preproc_region] = STATE(2288),
    [sym_preproc_endregion] = STATE(2288),
    [sym_preproc_line] = STATE(2288),
    [sym_preproc_pragma] = STATE(2288),
    [sym_preproc_nullable] = STATE(2288),
    [sym_preproc_error] = STATE(2288),
    [sym_preproc_warning] = STATE(2288),
    [sym_preproc_define] = STATE(2288),
    [sym_preproc_undef] = STATE(2288),
    [sym__identifier_token] = ACTIONS(3343),
    [anon_sym_extern] = ACTIONS(3343),
    [anon_sym_alias] = ACTIONS(3343),
    [anon_sym_SEMI] = ACTIONS(3345),
    [anon_sym_global] = ACTIONS(3343),
    [anon_sym_using] = ACTIONS(3343),
    [anon_sym_unsafe] = ACTIONS(3343),
    [anon_sym_static] = ACTIONS(3343),
    [anon_sym_LBRACK] = ACTIONS(3345),
    [anon_sym_LPAREN] = ACTIONS(3345),
    [anon_sym_return] = ACTIONS(3343),
    [anon_sym_namespace] = ACTIONS(3343),
    [anon_sym_class] = ACTIONS(3343),
    [anon_sym_ref] = ACTIONS(3343),
    [anon_sym_struct] = ACTIONS(3343),
    [anon_sym_enum] = ACTIONS(3343),
    [anon_sym_LBRACE] = ACTIONS(3345),
    [anon_sym_interface] = ACTIONS(3343),
    [anon_sym_delegate] = ACTIONS(3343),
    [anon_sym_record] = ACTIONS(3343),
    [anon_sym_abstract] = ACTIONS(3343),
    [anon_sym_async] = ACTIONS(3343),
    [anon_sym_const] = ACTIONS(3343),
    [anon_sym_file] = ACTIONS(3343),
    [anon_sym_fixed] = ACTIONS(3343),
    [anon_sym_internal] = ACTIONS(3343),
    [anon_sym_new] = ACTIONS(3343),
    [anon_sym_override] = ACTIONS(3343),
    [anon_sym_partial] = ACTIONS(3343),
    [anon_sym_private] = ACTIONS(3343),
    [anon_sym_protected] = ACTIONS(3343),
    [anon_sym_public] = ACTIONS(3343),
    [anon_sym_readonly] = ACTIONS(3343),
    [anon_sym_required] = ACTIONS(3343),
    [anon_sym_sealed] = ACTIONS(3343),
    [anon_sym_virtual] = ACTIONS(3343),
    [anon_sym_volatile] = ACTIONS(3343),
    [anon_sym_where] = ACTIONS(3343),
    [anon_sym_notnull] = ACTIONS(3343),
    [anon_sym_unmanaged] = ACTIONS(3343),
    [anon_sym_checked] = ACTIONS(3343),
    [anon_sym_BANG] = ACTIONS(3345),
    [anon_sym_TILDE] = ACTIONS(3345),
    [anon_sym_PLUS_PLUS] = ACTIONS(3345),
    [anon_sym_DASH_DASH] = ACTIONS(3345),
    [anon_sym_true] = ACTIONS(3343),
    [anon_sym_false] = ACTIONS(3343),
    [anon_sym_PLUS] = ACTIONS(3343),
    [anon_sym_DASH] = ACTIONS(3343),
    [anon_sym_STAR] = ACTIONS(3345),
    [anon_sym_CARET] = ACTIONS(3345),
    [anon_sym_AMP] = ACTIONS(3345),
    [anon_sym_this] = ACTIONS(3343),
    [anon_sym_scoped] = ACTIONS(3343),
    [anon_sym_base] = ACTIONS(3343),
    [anon_sym_var] = ACTIONS(3343),
    [sym_predefined_type] = ACTIONS(3343),
    [anon_sym_break] = ACTIONS(3343),
    [anon_sym_unchecked] = ACTIONS(3343),
    [anon_sym_continue] = ACTIONS(3343),
    [anon_sym_do] = ACTIONS(3343),
    [anon_sym_while] = ACTIONS(3343),
    [anon_sym_for] = ACTIONS(3343),
    [anon_sym_lock] = ACTIONS(3343),
    [anon_sym_yield] = ACTIONS(3343),
    [anon_sym_switch] = ACTIONS(3343),
    [anon_sym_default] = ACTIONS(3343),
    [anon_sym_throw] = ACTIONS(3343),
    [anon_sym_try] = ACTIONS(3343),
    [anon_sym_when] = ACTIONS(3343),
    [anon_sym_await] = ACTIONS(3343),
    [anon_sym_foreach] = ACTIONS(3343),
    [anon_sym_goto] = ACTIONS(3343),
    [anon_sym_if] = ACTIONS(3343),
    [anon_sym_else] = ACTIONS(3343),
    [anon_sym_DOT_DOT] = ACTIONS(3345),
    [anon_sym_from] = ACTIONS(3343),
    [anon_sym_into] = ACTIONS(3343),
    [anon_sym_join] = ACTIONS(3343),
    [anon_sym_on] = ACTIONS(3343),
    [anon_sym_equals] = ACTIONS(3343),
    [anon_sym_let] = ACTIONS(3343),
    [anon_sym_orderby] = ACTIONS(3343),
    [anon_sym_ascending] = ACTIONS(3343),
    [anon_sym_descending] = ACTIONS(3343),
    [anon_sym_group] = ACTIONS(3343),
    [anon_sym_by] = ACTIONS(3343),
    [anon_sym_select] = ACTIONS(3343),
    [anon_sym_stackalloc] = ACTIONS(3343),
    [anon_sym_sizeof] = ACTIONS(3343),
    [anon_sym_typeof] = ACTIONS(3343),
    [anon_sym___makeref] = ACTIONS(3343),
    [anon_sym___reftype] = ACTIONS(3343),
    [anon_sym___refvalue] = ACTIONS(3343),
    [sym_null_literal] = ACTIONS(3343),
    [anon_sym_SQUOTE] = ACTIONS(3345),
    [sym_integer_literal] = ACTIONS(3343),
    [sym_real_literal] = ACTIONS(3345),
    [anon_sym_DQUOTE] = ACTIONS(3345),
    [sym_verbatim_string_literal] = ACTIONS(3345),
    [aux_sym_preproc_if_token1] = ACTIONS(3345),
    [aux_sym_preproc_if_token3] = ACTIONS(3345),
    [aux_sym_preproc_else_token1] = ACTIONS(3345),
    [aux_sym_preproc_elif_token1] = ACTIONS(3345),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3345),
    [sym_interpolation_verbatim_start] = ACTIONS(3345),
    [sym_interpolation_raw_start] = ACTIONS(3345),
    [sym_raw_string_start] = ACTIONS(3345),
  },
  [2289] = {
    [sym_preproc_region] = STATE(2289),
    [sym_preproc_endregion] = STATE(2289),
    [sym_preproc_line] = STATE(2289),
    [sym_preproc_pragma] = STATE(2289),
    [sym_preproc_nullable] = STATE(2289),
    [sym_preproc_error] = STATE(2289),
    [sym_preproc_warning] = STATE(2289),
    [sym_preproc_define] = STATE(2289),
    [sym_preproc_undef] = STATE(2289),
    [sym__identifier_token] = ACTIONS(3347),
    [anon_sym_extern] = ACTIONS(3347),
    [anon_sym_alias] = ACTIONS(3347),
    [anon_sym_SEMI] = ACTIONS(3349),
    [anon_sym_global] = ACTIONS(3347),
    [anon_sym_using] = ACTIONS(3347),
    [anon_sym_unsafe] = ACTIONS(3347),
    [anon_sym_static] = ACTIONS(3347),
    [anon_sym_LBRACK] = ACTIONS(3349),
    [anon_sym_LPAREN] = ACTIONS(3349),
    [anon_sym_return] = ACTIONS(3347),
    [anon_sym_namespace] = ACTIONS(3347),
    [anon_sym_class] = ACTIONS(3347),
    [anon_sym_ref] = ACTIONS(3347),
    [anon_sym_struct] = ACTIONS(3347),
    [anon_sym_enum] = ACTIONS(3347),
    [anon_sym_LBRACE] = ACTIONS(3349),
    [anon_sym_interface] = ACTIONS(3347),
    [anon_sym_delegate] = ACTIONS(3347),
    [anon_sym_record] = ACTIONS(3347),
    [anon_sym_abstract] = ACTIONS(3347),
    [anon_sym_async] = ACTIONS(3347),
    [anon_sym_const] = ACTIONS(3347),
    [anon_sym_file] = ACTIONS(3347),
    [anon_sym_fixed] = ACTIONS(3347),
    [anon_sym_internal] = ACTIONS(3347),
    [anon_sym_new] = ACTIONS(3347),
    [anon_sym_override] = ACTIONS(3347),
    [anon_sym_partial] = ACTIONS(3347),
    [anon_sym_private] = ACTIONS(3347),
    [anon_sym_protected] = ACTIONS(3347),
    [anon_sym_public] = ACTIONS(3347),
    [anon_sym_readonly] = ACTIONS(3347),
    [anon_sym_required] = ACTIONS(3347),
    [anon_sym_sealed] = ACTIONS(3347),
    [anon_sym_virtual] = ACTIONS(3347),
    [anon_sym_volatile] = ACTIONS(3347),
    [anon_sym_where] = ACTIONS(3347),
    [anon_sym_notnull] = ACTIONS(3347),
    [anon_sym_unmanaged] = ACTIONS(3347),
    [anon_sym_checked] = ACTIONS(3347),
    [anon_sym_BANG] = ACTIONS(3349),
    [anon_sym_TILDE] = ACTIONS(3349),
    [anon_sym_PLUS_PLUS] = ACTIONS(3349),
    [anon_sym_DASH_DASH] = ACTIONS(3349),
    [anon_sym_true] = ACTIONS(3347),
    [anon_sym_false] = ACTIONS(3347),
    [anon_sym_PLUS] = ACTIONS(3347),
    [anon_sym_DASH] = ACTIONS(3347),
    [anon_sym_STAR] = ACTIONS(3349),
    [anon_sym_CARET] = ACTIONS(3349),
    [anon_sym_AMP] = ACTIONS(3349),
    [anon_sym_this] = ACTIONS(3347),
    [anon_sym_scoped] = ACTIONS(3347),
    [anon_sym_base] = ACTIONS(3347),
    [anon_sym_var] = ACTIONS(3347),
    [sym_predefined_type] = ACTIONS(3347),
    [anon_sym_break] = ACTIONS(3347),
    [anon_sym_unchecked] = ACTIONS(3347),
    [anon_sym_continue] = ACTIONS(3347),
    [anon_sym_do] = ACTIONS(3347),
    [anon_sym_while] = ACTIONS(3347),
    [anon_sym_for] = ACTIONS(3347),
    [anon_sym_lock] = ACTIONS(3347),
    [anon_sym_yield] = ACTIONS(3347),
    [anon_sym_switch] = ACTIONS(3347),
    [anon_sym_default] = ACTIONS(3347),
    [anon_sym_throw] = ACTIONS(3347),
    [anon_sym_try] = ACTIONS(3347),
    [anon_sym_when] = ACTIONS(3347),
    [anon_sym_await] = ACTIONS(3347),
    [anon_sym_foreach] = ACTIONS(3347),
    [anon_sym_goto] = ACTIONS(3347),
    [anon_sym_if] = ACTIONS(3347),
    [anon_sym_else] = ACTIONS(3347),
    [anon_sym_DOT_DOT] = ACTIONS(3349),
    [anon_sym_from] = ACTIONS(3347),
    [anon_sym_into] = ACTIONS(3347),
    [anon_sym_join] = ACTIONS(3347),
    [anon_sym_on] = ACTIONS(3347),
    [anon_sym_equals] = ACTIONS(3347),
    [anon_sym_let] = ACTIONS(3347),
    [anon_sym_orderby] = ACTIONS(3347),
    [anon_sym_ascending] = ACTIONS(3347),
    [anon_sym_descending] = ACTIONS(3347),
    [anon_sym_group] = ACTIONS(3347),
    [anon_sym_by] = ACTIONS(3347),
    [anon_sym_select] = ACTIONS(3347),
    [anon_sym_stackalloc] = ACTIONS(3347),
    [anon_sym_sizeof] = ACTIONS(3347),
    [anon_sym_typeof] = ACTIONS(3347),
    [anon_sym___makeref] = ACTIONS(3347),
    [anon_sym___reftype] = ACTIONS(3347),
    [anon_sym___refvalue] = ACTIONS(3347),
    [sym_null_literal] = ACTIONS(3347),
    [anon_sym_SQUOTE] = ACTIONS(3349),
    [sym_integer_literal] = ACTIONS(3347),
    [sym_real_literal] = ACTIONS(3349),
    [anon_sym_DQUOTE] = ACTIONS(3349),
    [sym_verbatim_string_literal] = ACTIONS(3349),
    [aux_sym_preproc_if_token1] = ACTIONS(3349),
    [aux_sym_preproc_if_token3] = ACTIONS(3349),
    [aux_sym_preproc_else_token1] = ACTIONS(3349),
    [aux_sym_preproc_elif_token1] = ACTIONS(3349),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3349),
    [sym_interpolation_verbatim_start] = ACTIONS(3349),
    [sym_interpolation_raw_start] = ACTIONS(3349),
    [sym_raw_string_start] = ACTIONS(3349),
  },
  [2290] = {
    [sym_preproc_region] = STATE(2290),
    [sym_preproc_endregion] = STATE(2290),
    [sym_preproc_line] = STATE(2290),
    [sym_preproc_pragma] = STATE(2290),
    [sym_preproc_nullable] = STATE(2290),
    [sym_preproc_error] = STATE(2290),
    [sym_preproc_warning] = STATE(2290),
    [sym_preproc_define] = STATE(2290),
    [sym_preproc_undef] = STATE(2290),
    [sym__identifier_token] = ACTIONS(3351),
    [anon_sym_extern] = ACTIONS(3351),
    [anon_sym_alias] = ACTIONS(3351),
    [anon_sym_SEMI] = ACTIONS(3353),
    [anon_sym_global] = ACTIONS(3351),
    [anon_sym_using] = ACTIONS(3351),
    [anon_sym_unsafe] = ACTIONS(3351),
    [anon_sym_static] = ACTIONS(3351),
    [anon_sym_LBRACK] = ACTIONS(3353),
    [anon_sym_LPAREN] = ACTIONS(3353),
    [anon_sym_return] = ACTIONS(3351),
    [anon_sym_namespace] = ACTIONS(3351),
    [anon_sym_class] = ACTIONS(3351),
    [anon_sym_ref] = ACTIONS(3351),
    [anon_sym_struct] = ACTIONS(3351),
    [anon_sym_enum] = ACTIONS(3351),
    [anon_sym_LBRACE] = ACTIONS(3353),
    [anon_sym_interface] = ACTIONS(3351),
    [anon_sym_delegate] = ACTIONS(3351),
    [anon_sym_record] = ACTIONS(3351),
    [anon_sym_abstract] = ACTIONS(3351),
    [anon_sym_async] = ACTIONS(3351),
    [anon_sym_const] = ACTIONS(3351),
    [anon_sym_file] = ACTIONS(3351),
    [anon_sym_fixed] = ACTIONS(3351),
    [anon_sym_internal] = ACTIONS(3351),
    [anon_sym_new] = ACTIONS(3351),
    [anon_sym_override] = ACTIONS(3351),
    [anon_sym_partial] = ACTIONS(3351),
    [anon_sym_private] = ACTIONS(3351),
    [anon_sym_protected] = ACTIONS(3351),
    [anon_sym_public] = ACTIONS(3351),
    [anon_sym_readonly] = ACTIONS(3351),
    [anon_sym_required] = ACTIONS(3351),
    [anon_sym_sealed] = ACTIONS(3351),
    [anon_sym_virtual] = ACTIONS(3351),
    [anon_sym_volatile] = ACTIONS(3351),
    [anon_sym_where] = ACTIONS(3351),
    [anon_sym_notnull] = ACTIONS(3351),
    [anon_sym_unmanaged] = ACTIONS(3351),
    [anon_sym_checked] = ACTIONS(3351),
    [anon_sym_BANG] = ACTIONS(3353),
    [anon_sym_TILDE] = ACTIONS(3353),
    [anon_sym_PLUS_PLUS] = ACTIONS(3353),
    [anon_sym_DASH_DASH] = ACTIONS(3353),
    [anon_sym_true] = ACTIONS(3351),
    [anon_sym_false] = ACTIONS(3351),
    [anon_sym_PLUS] = ACTIONS(3351),
    [anon_sym_DASH] = ACTIONS(3351),
    [anon_sym_STAR] = ACTIONS(3353),
    [anon_sym_CARET] = ACTIONS(3353),
    [anon_sym_AMP] = ACTIONS(3353),
    [anon_sym_this] = ACTIONS(3351),
    [anon_sym_scoped] = ACTIONS(3351),
    [anon_sym_base] = ACTIONS(3351),
    [anon_sym_var] = ACTIONS(3351),
    [sym_predefined_type] = ACTIONS(3351),
    [anon_sym_break] = ACTIONS(3351),
    [anon_sym_unchecked] = ACTIONS(3351),
    [anon_sym_continue] = ACTIONS(3351),
    [anon_sym_do] = ACTIONS(3351),
    [anon_sym_while] = ACTIONS(3351),
    [anon_sym_for] = ACTIONS(3351),
    [anon_sym_lock] = ACTIONS(3351),
    [anon_sym_yield] = ACTIONS(3351),
    [anon_sym_switch] = ACTIONS(3351),
    [anon_sym_default] = ACTIONS(3351),
    [anon_sym_throw] = ACTIONS(3351),
    [anon_sym_try] = ACTIONS(3351),
    [anon_sym_when] = ACTIONS(3351),
    [anon_sym_await] = ACTIONS(3351),
    [anon_sym_foreach] = ACTIONS(3351),
    [anon_sym_goto] = ACTIONS(3351),
    [anon_sym_if] = ACTIONS(3351),
    [anon_sym_else] = ACTIONS(3351),
    [anon_sym_DOT_DOT] = ACTIONS(3353),
    [anon_sym_from] = ACTIONS(3351),
    [anon_sym_into] = ACTIONS(3351),
    [anon_sym_join] = ACTIONS(3351),
    [anon_sym_on] = ACTIONS(3351),
    [anon_sym_equals] = ACTIONS(3351),
    [anon_sym_let] = ACTIONS(3351),
    [anon_sym_orderby] = ACTIONS(3351),
    [anon_sym_ascending] = ACTIONS(3351),
    [anon_sym_descending] = ACTIONS(3351),
    [anon_sym_group] = ACTIONS(3351),
    [anon_sym_by] = ACTIONS(3351),
    [anon_sym_select] = ACTIONS(3351),
    [anon_sym_stackalloc] = ACTIONS(3351),
    [anon_sym_sizeof] = ACTIONS(3351),
    [anon_sym_typeof] = ACTIONS(3351),
    [anon_sym___makeref] = ACTIONS(3351),
    [anon_sym___reftype] = ACTIONS(3351),
    [anon_sym___refvalue] = ACTIONS(3351),
    [sym_null_literal] = ACTIONS(3351),
    [anon_sym_SQUOTE] = ACTIONS(3353),
    [sym_integer_literal] = ACTIONS(3351),
    [sym_real_literal] = ACTIONS(3353),
    [anon_sym_DQUOTE] = ACTIONS(3353),
    [sym_verbatim_string_literal] = ACTIONS(3353),
    [aux_sym_preproc_if_token1] = ACTIONS(3353),
    [aux_sym_preproc_if_token3] = ACTIONS(3353),
    [aux_sym_preproc_else_token1] = ACTIONS(3353),
    [aux_sym_preproc_elif_token1] = ACTIONS(3353),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3353),
    [sym_interpolation_verbatim_start] = ACTIONS(3353),
    [sym_interpolation_raw_start] = ACTIONS(3353),
    [sym_raw_string_start] = ACTIONS(3353),
  },
  [2291] = {
    [sym_preproc_region] = STATE(2291),
    [sym_preproc_endregion] = STATE(2291),
    [sym_preproc_line] = STATE(2291),
    [sym_preproc_pragma] = STATE(2291),
    [sym_preproc_nullable] = STATE(2291),
    [sym_preproc_error] = STATE(2291),
    [sym_preproc_warning] = STATE(2291),
    [sym_preproc_define] = STATE(2291),
    [sym_preproc_undef] = STATE(2291),
    [sym__identifier_token] = ACTIONS(3355),
    [anon_sym_extern] = ACTIONS(3355),
    [anon_sym_alias] = ACTIONS(3355),
    [anon_sym_SEMI] = ACTIONS(3357),
    [anon_sym_global] = ACTIONS(3355),
    [anon_sym_using] = ACTIONS(3355),
    [anon_sym_unsafe] = ACTIONS(3355),
    [anon_sym_static] = ACTIONS(3355),
    [anon_sym_LBRACK] = ACTIONS(3357),
    [anon_sym_LPAREN] = ACTIONS(3357),
    [anon_sym_return] = ACTIONS(3355),
    [anon_sym_namespace] = ACTIONS(3355),
    [anon_sym_class] = ACTIONS(3355),
    [anon_sym_ref] = ACTIONS(3355),
    [anon_sym_struct] = ACTIONS(3355),
    [anon_sym_enum] = ACTIONS(3355),
    [anon_sym_LBRACE] = ACTIONS(3357),
    [anon_sym_interface] = ACTIONS(3355),
    [anon_sym_delegate] = ACTIONS(3355),
    [anon_sym_record] = ACTIONS(3355),
    [anon_sym_abstract] = ACTIONS(3355),
    [anon_sym_async] = ACTIONS(3355),
    [anon_sym_const] = ACTIONS(3355),
    [anon_sym_file] = ACTIONS(3355),
    [anon_sym_fixed] = ACTIONS(3355),
    [anon_sym_internal] = ACTIONS(3355),
    [anon_sym_new] = ACTIONS(3355),
    [anon_sym_override] = ACTIONS(3355),
    [anon_sym_partial] = ACTIONS(3355),
    [anon_sym_private] = ACTIONS(3355),
    [anon_sym_protected] = ACTIONS(3355),
    [anon_sym_public] = ACTIONS(3355),
    [anon_sym_readonly] = ACTIONS(3355),
    [anon_sym_required] = ACTIONS(3355),
    [anon_sym_sealed] = ACTIONS(3355),
    [anon_sym_virtual] = ACTIONS(3355),
    [anon_sym_volatile] = ACTIONS(3355),
    [anon_sym_where] = ACTIONS(3355),
    [anon_sym_notnull] = ACTIONS(3355),
    [anon_sym_unmanaged] = ACTIONS(3355),
    [anon_sym_checked] = ACTIONS(3355),
    [anon_sym_BANG] = ACTIONS(3357),
    [anon_sym_TILDE] = ACTIONS(3357),
    [anon_sym_PLUS_PLUS] = ACTIONS(3357),
    [anon_sym_DASH_DASH] = ACTIONS(3357),
    [anon_sym_true] = ACTIONS(3355),
    [anon_sym_false] = ACTIONS(3355),
    [anon_sym_PLUS] = ACTIONS(3355),
    [anon_sym_DASH] = ACTIONS(3355),
    [anon_sym_STAR] = ACTIONS(3357),
    [anon_sym_CARET] = ACTIONS(3357),
    [anon_sym_AMP] = ACTIONS(3357),
    [anon_sym_this] = ACTIONS(3355),
    [anon_sym_scoped] = ACTIONS(3355),
    [anon_sym_base] = ACTIONS(3355),
    [anon_sym_var] = ACTIONS(3355),
    [sym_predefined_type] = ACTIONS(3355),
    [anon_sym_break] = ACTIONS(3355),
    [anon_sym_unchecked] = ACTIONS(3355),
    [anon_sym_continue] = ACTIONS(3355),
    [anon_sym_do] = ACTIONS(3355),
    [anon_sym_while] = ACTIONS(3355),
    [anon_sym_for] = ACTIONS(3355),
    [anon_sym_lock] = ACTIONS(3355),
    [anon_sym_yield] = ACTIONS(3355),
    [anon_sym_switch] = ACTIONS(3355),
    [anon_sym_default] = ACTIONS(3355),
    [anon_sym_throw] = ACTIONS(3355),
    [anon_sym_try] = ACTIONS(3355),
    [anon_sym_when] = ACTIONS(3355),
    [anon_sym_await] = ACTIONS(3355),
    [anon_sym_foreach] = ACTIONS(3355),
    [anon_sym_goto] = ACTIONS(3355),
    [anon_sym_if] = ACTIONS(3355),
    [anon_sym_else] = ACTIONS(3355),
    [anon_sym_DOT_DOT] = ACTIONS(3357),
    [anon_sym_from] = ACTIONS(3355),
    [anon_sym_into] = ACTIONS(3355),
    [anon_sym_join] = ACTIONS(3355),
    [anon_sym_on] = ACTIONS(3355),
    [anon_sym_equals] = ACTIONS(3355),
    [anon_sym_let] = ACTIONS(3355),
    [anon_sym_orderby] = ACTIONS(3355),
    [anon_sym_ascending] = ACTIONS(3355),
    [anon_sym_descending] = ACTIONS(3355),
    [anon_sym_group] = ACTIONS(3355),
    [anon_sym_by] = ACTIONS(3355),
    [anon_sym_select] = ACTIONS(3355),
    [anon_sym_stackalloc] = ACTIONS(3355),
    [anon_sym_sizeof] = ACTIONS(3355),
    [anon_sym_typeof] = ACTIONS(3355),
    [anon_sym___makeref] = ACTIONS(3355),
    [anon_sym___reftype] = ACTIONS(3355),
    [anon_sym___refvalue] = ACTIONS(3355),
    [sym_null_literal] = ACTIONS(3355),
    [anon_sym_SQUOTE] = ACTIONS(3357),
    [sym_integer_literal] = ACTIONS(3355),
    [sym_real_literal] = ACTIONS(3357),
    [anon_sym_DQUOTE] = ACTIONS(3357),
    [sym_verbatim_string_literal] = ACTIONS(3357),
    [aux_sym_preproc_if_token1] = ACTIONS(3357),
    [aux_sym_preproc_if_token3] = ACTIONS(3357),
    [aux_sym_preproc_else_token1] = ACTIONS(3357),
    [aux_sym_preproc_elif_token1] = ACTIONS(3357),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3357),
    [sym_interpolation_verbatim_start] = ACTIONS(3357),
    [sym_interpolation_raw_start] = ACTIONS(3357),
    [sym_raw_string_start] = ACTIONS(3357),
  },
  [2292] = {
    [sym_preproc_region] = STATE(2292),
    [sym_preproc_endregion] = STATE(2292),
    [sym_preproc_line] = STATE(2292),
    [sym_preproc_pragma] = STATE(2292),
    [sym_preproc_nullable] = STATE(2292),
    [sym_preproc_error] = STATE(2292),
    [sym_preproc_warning] = STATE(2292),
    [sym_preproc_define] = STATE(2292),
    [sym_preproc_undef] = STATE(2292),
    [sym__identifier_token] = ACTIONS(3011),
    [anon_sym_extern] = ACTIONS(3011),
    [anon_sym_alias] = ACTIONS(3011),
    [anon_sym_SEMI] = ACTIONS(3013),
    [anon_sym_global] = ACTIONS(3011),
    [anon_sym_using] = ACTIONS(3011),
    [anon_sym_unsafe] = ACTIONS(3011),
    [anon_sym_static] = ACTIONS(3011),
    [anon_sym_LBRACK] = ACTIONS(3013),
    [anon_sym_LPAREN] = ACTIONS(3013),
    [anon_sym_return] = ACTIONS(3011),
    [anon_sym_namespace] = ACTIONS(3011),
    [anon_sym_class] = ACTIONS(3011),
    [anon_sym_ref] = ACTIONS(3011),
    [anon_sym_struct] = ACTIONS(3011),
    [anon_sym_enum] = ACTIONS(3011),
    [anon_sym_LBRACE] = ACTIONS(3013),
    [anon_sym_interface] = ACTIONS(3011),
    [anon_sym_delegate] = ACTIONS(3011),
    [anon_sym_record] = ACTIONS(3011),
    [anon_sym_abstract] = ACTIONS(3011),
    [anon_sym_async] = ACTIONS(3011),
    [anon_sym_const] = ACTIONS(3011),
    [anon_sym_file] = ACTIONS(3011),
    [anon_sym_fixed] = ACTIONS(3011),
    [anon_sym_internal] = ACTIONS(3011),
    [anon_sym_new] = ACTIONS(3011),
    [anon_sym_override] = ACTIONS(3011),
    [anon_sym_partial] = ACTIONS(3011),
    [anon_sym_private] = ACTIONS(3011),
    [anon_sym_protected] = ACTIONS(3011),
    [anon_sym_public] = ACTIONS(3011),
    [anon_sym_readonly] = ACTIONS(3011),
    [anon_sym_required] = ACTIONS(3011),
    [anon_sym_sealed] = ACTIONS(3011),
    [anon_sym_virtual] = ACTIONS(3011),
    [anon_sym_volatile] = ACTIONS(3011),
    [anon_sym_where] = ACTIONS(3011),
    [anon_sym_notnull] = ACTIONS(3011),
    [anon_sym_unmanaged] = ACTIONS(3011),
    [anon_sym_checked] = ACTIONS(3011),
    [anon_sym_BANG] = ACTIONS(3013),
    [anon_sym_TILDE] = ACTIONS(3013),
    [anon_sym_PLUS_PLUS] = ACTIONS(3013),
    [anon_sym_DASH_DASH] = ACTIONS(3013),
    [anon_sym_true] = ACTIONS(3011),
    [anon_sym_false] = ACTIONS(3011),
    [anon_sym_PLUS] = ACTIONS(3011),
    [anon_sym_DASH] = ACTIONS(3011),
    [anon_sym_STAR] = ACTIONS(3013),
    [anon_sym_CARET] = ACTIONS(3013),
    [anon_sym_AMP] = ACTIONS(3013),
    [anon_sym_this] = ACTIONS(3011),
    [anon_sym_scoped] = ACTIONS(3011),
    [anon_sym_base] = ACTIONS(3011),
    [anon_sym_var] = ACTIONS(3011),
    [sym_predefined_type] = ACTIONS(3011),
    [anon_sym_break] = ACTIONS(3011),
    [anon_sym_unchecked] = ACTIONS(3011),
    [anon_sym_continue] = ACTIONS(3011),
    [anon_sym_do] = ACTIONS(3011),
    [anon_sym_while] = ACTIONS(3011),
    [anon_sym_for] = ACTIONS(3011),
    [anon_sym_lock] = ACTIONS(3011),
    [anon_sym_yield] = ACTIONS(3011),
    [anon_sym_switch] = ACTIONS(3011),
    [anon_sym_default] = ACTIONS(3011),
    [anon_sym_throw] = ACTIONS(3011),
    [anon_sym_try] = ACTIONS(3011),
    [anon_sym_when] = ACTIONS(3011),
    [anon_sym_await] = ACTIONS(3011),
    [anon_sym_foreach] = ACTIONS(3011),
    [anon_sym_goto] = ACTIONS(3011),
    [anon_sym_if] = ACTIONS(3011),
    [anon_sym_else] = ACTIONS(3011),
    [anon_sym_DOT_DOT] = ACTIONS(3013),
    [anon_sym_from] = ACTIONS(3011),
    [anon_sym_into] = ACTIONS(3011),
    [anon_sym_join] = ACTIONS(3011),
    [anon_sym_on] = ACTIONS(3011),
    [anon_sym_equals] = ACTIONS(3011),
    [anon_sym_let] = ACTIONS(3011),
    [anon_sym_orderby] = ACTIONS(3011),
    [anon_sym_ascending] = ACTIONS(3011),
    [anon_sym_descending] = ACTIONS(3011),
    [anon_sym_group] = ACTIONS(3011),
    [anon_sym_by] = ACTIONS(3011),
    [anon_sym_select] = ACTIONS(3011),
    [anon_sym_stackalloc] = ACTIONS(3011),
    [anon_sym_sizeof] = ACTIONS(3011),
    [anon_sym_typeof] = ACTIONS(3011),
    [anon_sym___makeref] = ACTIONS(3011),
    [anon_sym___reftype] = ACTIONS(3011),
    [anon_sym___refvalue] = ACTIONS(3011),
    [sym_null_literal] = ACTIONS(3011),
    [anon_sym_SQUOTE] = ACTIONS(3013),
    [sym_integer_literal] = ACTIONS(3011),
    [sym_real_literal] = ACTIONS(3013),
    [anon_sym_DQUOTE] = ACTIONS(3013),
    [sym_verbatim_string_literal] = ACTIONS(3013),
    [aux_sym_preproc_if_token1] = ACTIONS(3013),
    [aux_sym_preproc_if_token3] = ACTIONS(3013),
    [aux_sym_preproc_else_token1] = ACTIONS(3013),
    [aux_sym_preproc_elif_token1] = ACTIONS(3013),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3013),
    [sym_interpolation_verbatim_start] = ACTIONS(3013),
    [sym_interpolation_raw_start] = ACTIONS(3013),
    [sym_raw_string_start] = ACTIONS(3013),
  },
  [2293] = {
    [sym_preproc_region] = STATE(2293),
    [sym_preproc_endregion] = STATE(2293),
    [sym_preproc_line] = STATE(2293),
    [sym_preproc_pragma] = STATE(2293),
    [sym_preproc_nullable] = STATE(2293),
    [sym_preproc_error] = STATE(2293),
    [sym_preproc_warning] = STATE(2293),
    [sym_preproc_define] = STATE(2293),
    [sym_preproc_undef] = STATE(2293),
    [sym__identifier_token] = ACTIONS(3359),
    [anon_sym_extern] = ACTIONS(3359),
    [anon_sym_alias] = ACTIONS(3359),
    [anon_sym_SEMI] = ACTIONS(3361),
    [anon_sym_global] = ACTIONS(3359),
    [anon_sym_using] = ACTIONS(3359),
    [anon_sym_unsafe] = ACTIONS(3359),
    [anon_sym_static] = ACTIONS(3359),
    [anon_sym_LBRACK] = ACTIONS(3361),
    [anon_sym_LPAREN] = ACTIONS(3361),
    [anon_sym_return] = ACTIONS(3359),
    [anon_sym_namespace] = ACTIONS(3359),
    [anon_sym_class] = ACTIONS(3359),
    [anon_sym_ref] = ACTIONS(3359),
    [anon_sym_struct] = ACTIONS(3359),
    [anon_sym_enum] = ACTIONS(3359),
    [anon_sym_LBRACE] = ACTIONS(3361),
    [anon_sym_interface] = ACTIONS(3359),
    [anon_sym_delegate] = ACTIONS(3359),
    [anon_sym_record] = ACTIONS(3359),
    [anon_sym_abstract] = ACTIONS(3359),
    [anon_sym_async] = ACTIONS(3359),
    [anon_sym_const] = ACTIONS(3359),
    [anon_sym_file] = ACTIONS(3359),
    [anon_sym_fixed] = ACTIONS(3359),
    [anon_sym_internal] = ACTIONS(3359),
    [anon_sym_new] = ACTIONS(3359),
    [anon_sym_override] = ACTIONS(3359),
    [anon_sym_partial] = ACTIONS(3359),
    [anon_sym_private] = ACTIONS(3359),
    [anon_sym_protected] = ACTIONS(3359),
    [anon_sym_public] = ACTIONS(3359),
    [anon_sym_readonly] = ACTIONS(3359),
    [anon_sym_required] = ACTIONS(3359),
    [anon_sym_sealed] = ACTIONS(3359),
    [anon_sym_virtual] = ACTIONS(3359),
    [anon_sym_volatile] = ACTIONS(3359),
    [anon_sym_where] = ACTIONS(3359),
    [anon_sym_notnull] = ACTIONS(3359),
    [anon_sym_unmanaged] = ACTIONS(3359),
    [anon_sym_checked] = ACTIONS(3359),
    [anon_sym_BANG] = ACTIONS(3361),
    [anon_sym_TILDE] = ACTIONS(3361),
    [anon_sym_PLUS_PLUS] = ACTIONS(3361),
    [anon_sym_DASH_DASH] = ACTIONS(3361),
    [anon_sym_true] = ACTIONS(3359),
    [anon_sym_false] = ACTIONS(3359),
    [anon_sym_PLUS] = ACTIONS(3359),
    [anon_sym_DASH] = ACTIONS(3359),
    [anon_sym_STAR] = ACTIONS(3361),
    [anon_sym_CARET] = ACTIONS(3361),
    [anon_sym_AMP] = ACTIONS(3361),
    [anon_sym_this] = ACTIONS(3359),
    [anon_sym_scoped] = ACTIONS(3359),
    [anon_sym_base] = ACTIONS(3359),
    [anon_sym_var] = ACTIONS(3359),
    [sym_predefined_type] = ACTIONS(3359),
    [anon_sym_break] = ACTIONS(3359),
    [anon_sym_unchecked] = ACTIONS(3359),
    [anon_sym_continue] = ACTIONS(3359),
    [anon_sym_do] = ACTIONS(3359),
    [anon_sym_while] = ACTIONS(3359),
    [anon_sym_for] = ACTIONS(3359),
    [anon_sym_lock] = ACTIONS(3359),
    [anon_sym_yield] = ACTIONS(3359),
    [anon_sym_switch] = ACTIONS(3359),
    [anon_sym_default] = ACTIONS(3359),
    [anon_sym_throw] = ACTIONS(3359),
    [anon_sym_try] = ACTIONS(3359),
    [anon_sym_when] = ACTIONS(3359),
    [anon_sym_await] = ACTIONS(3359),
    [anon_sym_foreach] = ACTIONS(3359),
    [anon_sym_goto] = ACTIONS(3359),
    [anon_sym_if] = ACTIONS(3359),
    [anon_sym_else] = ACTIONS(3359),
    [anon_sym_DOT_DOT] = ACTIONS(3361),
    [anon_sym_from] = ACTIONS(3359),
    [anon_sym_into] = ACTIONS(3359),
    [anon_sym_join] = ACTIONS(3359),
    [anon_sym_on] = ACTIONS(3359),
    [anon_sym_equals] = ACTIONS(3359),
    [anon_sym_let] = ACTIONS(3359),
    [anon_sym_orderby] = ACTIONS(3359),
    [anon_sym_ascending] = ACTIONS(3359),
    [anon_sym_descending] = ACTIONS(3359),
    [anon_sym_group] = ACTIONS(3359),
    [anon_sym_by] = ACTIONS(3359),
    [anon_sym_select] = ACTIONS(3359),
    [anon_sym_stackalloc] = ACTIONS(3359),
    [anon_sym_sizeof] = ACTIONS(3359),
    [anon_sym_typeof] = ACTIONS(3359),
    [anon_sym___makeref] = ACTIONS(3359),
    [anon_sym___reftype] = ACTIONS(3359),
    [anon_sym___refvalue] = ACTIONS(3359),
    [sym_null_literal] = ACTIONS(3359),
    [anon_sym_SQUOTE] = ACTIONS(3361),
    [sym_integer_literal] = ACTIONS(3359),
    [sym_real_literal] = ACTIONS(3361),
    [anon_sym_DQUOTE] = ACTIONS(3361),
    [sym_verbatim_string_literal] = ACTIONS(3361),
    [aux_sym_preproc_if_token1] = ACTIONS(3361),
    [aux_sym_preproc_if_token3] = ACTIONS(3361),
    [aux_sym_preproc_else_token1] = ACTIONS(3361),
    [aux_sym_preproc_elif_token1] = ACTIONS(3361),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3361),
    [sym_interpolation_verbatim_start] = ACTIONS(3361),
    [sym_interpolation_raw_start] = ACTIONS(3361),
    [sym_raw_string_start] = ACTIONS(3361),
  },
  [2294] = {
    [sym_using_directive] = STATE(3324),
    [sym_attribute_list] = STATE(3740),
    [sym_namespace_declaration] = STATE(3324),
    [sym_class_declaration] = STATE(3324),
    [sym_struct_declaration] = STATE(3324),
    [sym_enum_declaration] = STATE(3324),
    [sym_interface_declaration] = STATE(3324),
    [sym_delegate_declaration] = STATE(3324),
    [sym_record_declaration] = STATE(3324),
    [sym_modifier] = STATE(3807),
    [sym_operator_declaration] = STATE(3324),
    [sym_conversion_operator_declaration] = STATE(3324),
    [sym_declaration] = STATE(3327),
    [sym_field_declaration] = STATE(3324),
    [sym_constructor_declaration] = STATE(3324),
    [sym_destructor_declaration] = STATE(3324),
    [sym_method_declaration] = STATE(3324),
    [sym_event_declaration] = STATE(3324),
    [sym_event_field_declaration] = STATE(3324),
    [sym_indexer_declaration] = STATE(3324),
    [sym_property_declaration] = STATE(3324),
    [sym_variable_declaration] = STATE(8996),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(6582),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(6750),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_if] = STATE(3324),
    [sym_preproc_else] = STATE(9474),
    [sym_preproc_elif] = STATE(9474),
    [sym_preproc_region] = STATE(2294),
    [sym_preproc_endregion] = STATE(2294),
    [sym_preproc_line] = STATE(2294),
    [sym_preproc_pragma] = STATE(2294),
    [sym_preproc_nullable] = STATE(2294),
    [sym_preproc_error] = STATE(2294),
    [sym_preproc_warning] = STATE(2294),
    [sym_preproc_define] = STATE(2294),
    [sym_preproc_undef] = STATE(2294),
    [aux_sym_class_declaration_repeat1] = STATE(2781),
    [aux_sym_class_declaration_repeat2] = STATE(2857),
    [aux_sym_declaration_list_repeat1] = STATE(2257),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_extern] = ACTIONS(3195),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3199),
    [anon_sym_using] = ACTIONS(3201),
    [anon_sym_unsafe] = ACTIONS(65),
    [anon_sym_static] = ACTIONS(65),
    [anon_sym_LBRACK] = ACTIONS(3203),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_event] = ACTIONS(3207),
    [anon_sym_namespace] = ACTIONS(3209),
    [anon_sym_class] = ACTIONS(3211),
    [anon_sym_ref] = ACTIONS(3213),
    [anon_sym_struct] = ACTIONS(3215),
    [anon_sym_enum] = ACTIONS(3217),
    [anon_sym_interface] = ACTIONS(3219),
    [anon_sym_delegate] = ACTIONS(3221),
    [anon_sym_record] = ACTIONS(3223),
    [anon_sym_abstract] = ACTIONS(65),
    [anon_sym_async] = ACTIONS(65),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_file] = ACTIONS(3225),
    [anon_sym_fixed] = ACTIONS(65),
    [anon_sym_internal] = ACTIONS(65),
    [anon_sym_new] = ACTIONS(65),
    [anon_sym_override] = ACTIONS(65),
    [anon_sym_partial] = ACTIONS(65),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_public] = ACTIONS(65),
    [anon_sym_readonly] = ACTIONS(65),
    [anon_sym_required] = ACTIONS(65),
    [anon_sym_sealed] = ACTIONS(65),
    [anon_sym_virtual] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_TILDE] = ACTIONS(3227),
    [anon_sym_implicit] = ACTIONS(3229),
    [anon_sym_explicit] = ACTIONS(3229),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_if_token1] = ACTIONS(3237),
    [aux_sym_preproc_if_token3] = ACTIONS(3363),
    [aux_sym_preproc_else_token1] = ACTIONS(3241),
    [aux_sym_preproc_elif_token1] = ACTIONS(3243),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2295] = {
    [sym_preproc_region] = STATE(2295),
    [sym_preproc_endregion] = STATE(2295),
    [sym_preproc_line] = STATE(2295),
    [sym_preproc_pragma] = STATE(2295),
    [sym_preproc_nullable] = STATE(2295),
    [sym_preproc_error] = STATE(2295),
    [sym_preproc_warning] = STATE(2295),
    [sym_preproc_define] = STATE(2295),
    [sym_preproc_undef] = STATE(2295),
    [sym__identifier_token] = ACTIONS(3365),
    [anon_sym_extern] = ACTIONS(3365),
    [anon_sym_alias] = ACTIONS(3365),
    [anon_sym_SEMI] = ACTIONS(3367),
    [anon_sym_global] = ACTIONS(3365),
    [anon_sym_using] = ACTIONS(3365),
    [anon_sym_unsafe] = ACTIONS(3365),
    [anon_sym_static] = ACTIONS(3365),
    [anon_sym_LBRACK] = ACTIONS(3367),
    [anon_sym_LPAREN] = ACTIONS(3367),
    [anon_sym_return] = ACTIONS(3365),
    [anon_sym_namespace] = ACTIONS(3365),
    [anon_sym_class] = ACTIONS(3365),
    [anon_sym_ref] = ACTIONS(3365),
    [anon_sym_struct] = ACTIONS(3365),
    [anon_sym_enum] = ACTIONS(3365),
    [anon_sym_LBRACE] = ACTIONS(3367),
    [anon_sym_interface] = ACTIONS(3365),
    [anon_sym_delegate] = ACTIONS(3365),
    [anon_sym_record] = ACTIONS(3365),
    [anon_sym_abstract] = ACTIONS(3365),
    [anon_sym_async] = ACTIONS(3365),
    [anon_sym_const] = ACTIONS(3365),
    [anon_sym_file] = ACTIONS(3365),
    [anon_sym_fixed] = ACTIONS(3365),
    [anon_sym_internal] = ACTIONS(3365),
    [anon_sym_new] = ACTIONS(3365),
    [anon_sym_override] = ACTIONS(3365),
    [anon_sym_partial] = ACTIONS(3365),
    [anon_sym_private] = ACTIONS(3365),
    [anon_sym_protected] = ACTIONS(3365),
    [anon_sym_public] = ACTIONS(3365),
    [anon_sym_readonly] = ACTIONS(3365),
    [anon_sym_required] = ACTIONS(3365),
    [anon_sym_sealed] = ACTIONS(3365),
    [anon_sym_virtual] = ACTIONS(3365),
    [anon_sym_volatile] = ACTIONS(3365),
    [anon_sym_where] = ACTIONS(3365),
    [anon_sym_notnull] = ACTIONS(3365),
    [anon_sym_unmanaged] = ACTIONS(3365),
    [anon_sym_checked] = ACTIONS(3365),
    [anon_sym_BANG] = ACTIONS(3367),
    [anon_sym_TILDE] = ACTIONS(3367),
    [anon_sym_PLUS_PLUS] = ACTIONS(3367),
    [anon_sym_DASH_DASH] = ACTIONS(3367),
    [anon_sym_true] = ACTIONS(3365),
    [anon_sym_false] = ACTIONS(3365),
    [anon_sym_PLUS] = ACTIONS(3365),
    [anon_sym_DASH] = ACTIONS(3365),
    [anon_sym_STAR] = ACTIONS(3367),
    [anon_sym_CARET] = ACTIONS(3367),
    [anon_sym_AMP] = ACTIONS(3367),
    [anon_sym_this] = ACTIONS(3365),
    [anon_sym_scoped] = ACTIONS(3365),
    [anon_sym_base] = ACTIONS(3365),
    [anon_sym_var] = ACTIONS(3365),
    [sym_predefined_type] = ACTIONS(3365),
    [anon_sym_break] = ACTIONS(3365),
    [anon_sym_unchecked] = ACTIONS(3365),
    [anon_sym_continue] = ACTIONS(3365),
    [anon_sym_do] = ACTIONS(3365),
    [anon_sym_while] = ACTIONS(3365),
    [anon_sym_for] = ACTIONS(3365),
    [anon_sym_lock] = ACTIONS(3365),
    [anon_sym_yield] = ACTIONS(3365),
    [anon_sym_switch] = ACTIONS(3365),
    [anon_sym_default] = ACTIONS(3365),
    [anon_sym_throw] = ACTIONS(3365),
    [anon_sym_try] = ACTIONS(3365),
    [anon_sym_when] = ACTIONS(3365),
    [anon_sym_await] = ACTIONS(3365),
    [anon_sym_foreach] = ACTIONS(3365),
    [anon_sym_goto] = ACTIONS(3365),
    [anon_sym_if] = ACTIONS(3365),
    [anon_sym_else] = ACTIONS(3365),
    [anon_sym_DOT_DOT] = ACTIONS(3367),
    [anon_sym_from] = ACTIONS(3365),
    [anon_sym_into] = ACTIONS(3365),
    [anon_sym_join] = ACTIONS(3365),
    [anon_sym_on] = ACTIONS(3365),
    [anon_sym_equals] = ACTIONS(3365),
    [anon_sym_let] = ACTIONS(3365),
    [anon_sym_orderby] = ACTIONS(3365),
    [anon_sym_ascending] = ACTIONS(3365),
    [anon_sym_descending] = ACTIONS(3365),
    [anon_sym_group] = ACTIONS(3365),
    [anon_sym_by] = ACTIONS(3365),
    [anon_sym_select] = ACTIONS(3365),
    [anon_sym_stackalloc] = ACTIONS(3365),
    [anon_sym_sizeof] = ACTIONS(3365),
    [anon_sym_typeof] = ACTIONS(3365),
    [anon_sym___makeref] = ACTIONS(3365),
    [anon_sym___reftype] = ACTIONS(3365),
    [anon_sym___refvalue] = ACTIONS(3365),
    [sym_null_literal] = ACTIONS(3365),
    [anon_sym_SQUOTE] = ACTIONS(3367),
    [sym_integer_literal] = ACTIONS(3365),
    [sym_real_literal] = ACTIONS(3367),
    [anon_sym_DQUOTE] = ACTIONS(3367),
    [sym_verbatim_string_literal] = ACTIONS(3367),
    [aux_sym_preproc_if_token1] = ACTIONS(3367),
    [aux_sym_preproc_if_token3] = ACTIONS(3367),
    [aux_sym_preproc_else_token1] = ACTIONS(3367),
    [aux_sym_preproc_elif_token1] = ACTIONS(3367),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3367),
    [sym_interpolation_verbatim_start] = ACTIONS(3367),
    [sym_interpolation_raw_start] = ACTIONS(3367),
    [sym_raw_string_start] = ACTIONS(3367),
  },
  [2296] = {
    [sym_preproc_region] = STATE(2296),
    [sym_preproc_endregion] = STATE(2296),
    [sym_preproc_line] = STATE(2296),
    [sym_preproc_pragma] = STATE(2296),
    [sym_preproc_nullable] = STATE(2296),
    [sym_preproc_error] = STATE(2296),
    [sym_preproc_warning] = STATE(2296),
    [sym_preproc_define] = STATE(2296),
    [sym_preproc_undef] = STATE(2296),
    [sym__identifier_token] = ACTIONS(3369),
    [anon_sym_extern] = ACTIONS(3369),
    [anon_sym_alias] = ACTIONS(3369),
    [anon_sym_SEMI] = ACTIONS(3371),
    [anon_sym_global] = ACTIONS(3369),
    [anon_sym_using] = ACTIONS(3369),
    [anon_sym_unsafe] = ACTIONS(3369),
    [anon_sym_static] = ACTIONS(3369),
    [anon_sym_LBRACK] = ACTIONS(3371),
    [anon_sym_LPAREN] = ACTIONS(3371),
    [anon_sym_return] = ACTIONS(3369),
    [anon_sym_namespace] = ACTIONS(3369),
    [anon_sym_class] = ACTIONS(3369),
    [anon_sym_ref] = ACTIONS(3369),
    [anon_sym_struct] = ACTIONS(3369),
    [anon_sym_enum] = ACTIONS(3369),
    [anon_sym_LBRACE] = ACTIONS(3371),
    [anon_sym_interface] = ACTIONS(3369),
    [anon_sym_delegate] = ACTIONS(3369),
    [anon_sym_record] = ACTIONS(3369),
    [anon_sym_abstract] = ACTIONS(3369),
    [anon_sym_async] = ACTIONS(3369),
    [anon_sym_const] = ACTIONS(3369),
    [anon_sym_file] = ACTIONS(3369),
    [anon_sym_fixed] = ACTIONS(3369),
    [anon_sym_internal] = ACTIONS(3369),
    [anon_sym_new] = ACTIONS(3369),
    [anon_sym_override] = ACTIONS(3369),
    [anon_sym_partial] = ACTIONS(3369),
    [anon_sym_private] = ACTIONS(3369),
    [anon_sym_protected] = ACTIONS(3369),
    [anon_sym_public] = ACTIONS(3369),
    [anon_sym_readonly] = ACTIONS(3369),
    [anon_sym_required] = ACTIONS(3369),
    [anon_sym_sealed] = ACTIONS(3369),
    [anon_sym_virtual] = ACTIONS(3369),
    [anon_sym_volatile] = ACTIONS(3369),
    [anon_sym_where] = ACTIONS(3369),
    [anon_sym_notnull] = ACTIONS(3369),
    [anon_sym_unmanaged] = ACTIONS(3369),
    [anon_sym_checked] = ACTIONS(3369),
    [anon_sym_BANG] = ACTIONS(3371),
    [anon_sym_TILDE] = ACTIONS(3371),
    [anon_sym_PLUS_PLUS] = ACTIONS(3371),
    [anon_sym_DASH_DASH] = ACTIONS(3371),
    [anon_sym_true] = ACTIONS(3369),
    [anon_sym_false] = ACTIONS(3369),
    [anon_sym_PLUS] = ACTIONS(3369),
    [anon_sym_DASH] = ACTIONS(3369),
    [anon_sym_STAR] = ACTIONS(3371),
    [anon_sym_CARET] = ACTIONS(3371),
    [anon_sym_AMP] = ACTIONS(3371),
    [anon_sym_this] = ACTIONS(3369),
    [anon_sym_scoped] = ACTIONS(3369),
    [anon_sym_base] = ACTIONS(3369),
    [anon_sym_var] = ACTIONS(3369),
    [sym_predefined_type] = ACTIONS(3369),
    [anon_sym_break] = ACTIONS(3369),
    [anon_sym_unchecked] = ACTIONS(3369),
    [anon_sym_continue] = ACTIONS(3369),
    [anon_sym_do] = ACTIONS(3369),
    [anon_sym_while] = ACTIONS(3369),
    [anon_sym_for] = ACTIONS(3369),
    [anon_sym_lock] = ACTIONS(3369),
    [anon_sym_yield] = ACTIONS(3369),
    [anon_sym_switch] = ACTIONS(3369),
    [anon_sym_default] = ACTIONS(3369),
    [anon_sym_throw] = ACTIONS(3369),
    [anon_sym_try] = ACTIONS(3369),
    [anon_sym_when] = ACTIONS(3369),
    [anon_sym_await] = ACTIONS(3369),
    [anon_sym_foreach] = ACTIONS(3369),
    [anon_sym_goto] = ACTIONS(3369),
    [anon_sym_if] = ACTIONS(3369),
    [anon_sym_else] = ACTIONS(3369),
    [anon_sym_DOT_DOT] = ACTIONS(3371),
    [anon_sym_from] = ACTIONS(3369),
    [anon_sym_into] = ACTIONS(3369),
    [anon_sym_join] = ACTIONS(3369),
    [anon_sym_on] = ACTIONS(3369),
    [anon_sym_equals] = ACTIONS(3369),
    [anon_sym_let] = ACTIONS(3369),
    [anon_sym_orderby] = ACTIONS(3369),
    [anon_sym_ascending] = ACTIONS(3369),
    [anon_sym_descending] = ACTIONS(3369),
    [anon_sym_group] = ACTIONS(3369),
    [anon_sym_by] = ACTIONS(3369),
    [anon_sym_select] = ACTIONS(3369),
    [anon_sym_stackalloc] = ACTIONS(3369),
    [anon_sym_sizeof] = ACTIONS(3369),
    [anon_sym_typeof] = ACTIONS(3369),
    [anon_sym___makeref] = ACTIONS(3369),
    [anon_sym___reftype] = ACTIONS(3369),
    [anon_sym___refvalue] = ACTIONS(3369),
    [sym_null_literal] = ACTIONS(3369),
    [anon_sym_SQUOTE] = ACTIONS(3371),
    [sym_integer_literal] = ACTIONS(3369),
    [sym_real_literal] = ACTIONS(3371),
    [anon_sym_DQUOTE] = ACTIONS(3371),
    [sym_verbatim_string_literal] = ACTIONS(3371),
    [aux_sym_preproc_if_token1] = ACTIONS(3371),
    [aux_sym_preproc_if_token3] = ACTIONS(3371),
    [aux_sym_preproc_else_token1] = ACTIONS(3371),
    [aux_sym_preproc_elif_token1] = ACTIONS(3371),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3371),
    [sym_interpolation_verbatim_start] = ACTIONS(3371),
    [sym_interpolation_raw_start] = ACTIONS(3371),
    [sym_raw_string_start] = ACTIONS(3371),
  },
  [2297] = {
    [sym_preproc_region] = STATE(2297),
    [sym_preproc_endregion] = STATE(2297),
    [sym_preproc_line] = STATE(2297),
    [sym_preproc_pragma] = STATE(2297),
    [sym_preproc_nullable] = STATE(2297),
    [sym_preproc_error] = STATE(2297),
    [sym_preproc_warning] = STATE(2297),
    [sym_preproc_define] = STATE(2297),
    [sym_preproc_undef] = STATE(2297),
    [sym__identifier_token] = ACTIONS(3373),
    [anon_sym_extern] = ACTIONS(3373),
    [anon_sym_alias] = ACTIONS(3373),
    [anon_sym_SEMI] = ACTIONS(3375),
    [anon_sym_global] = ACTIONS(3373),
    [anon_sym_using] = ACTIONS(3373),
    [anon_sym_unsafe] = ACTIONS(3373),
    [anon_sym_static] = ACTIONS(3373),
    [anon_sym_LBRACK] = ACTIONS(3375),
    [anon_sym_LPAREN] = ACTIONS(3375),
    [anon_sym_return] = ACTIONS(3373),
    [anon_sym_namespace] = ACTIONS(3373),
    [anon_sym_class] = ACTIONS(3373),
    [anon_sym_ref] = ACTIONS(3373),
    [anon_sym_struct] = ACTIONS(3373),
    [anon_sym_enum] = ACTIONS(3373),
    [anon_sym_LBRACE] = ACTIONS(3375),
    [anon_sym_interface] = ACTIONS(3373),
    [anon_sym_delegate] = ACTIONS(3373),
    [anon_sym_record] = ACTIONS(3373),
    [anon_sym_abstract] = ACTIONS(3373),
    [anon_sym_async] = ACTIONS(3373),
    [anon_sym_const] = ACTIONS(3373),
    [anon_sym_file] = ACTIONS(3373),
    [anon_sym_fixed] = ACTIONS(3373),
    [anon_sym_internal] = ACTIONS(3373),
    [anon_sym_new] = ACTIONS(3373),
    [anon_sym_override] = ACTIONS(3373),
    [anon_sym_partial] = ACTIONS(3373),
    [anon_sym_private] = ACTIONS(3373),
    [anon_sym_protected] = ACTIONS(3373),
    [anon_sym_public] = ACTIONS(3373),
    [anon_sym_readonly] = ACTIONS(3373),
    [anon_sym_required] = ACTIONS(3373),
    [anon_sym_sealed] = ACTIONS(3373),
    [anon_sym_virtual] = ACTIONS(3373),
    [anon_sym_volatile] = ACTIONS(3373),
    [anon_sym_where] = ACTIONS(3373),
    [anon_sym_notnull] = ACTIONS(3373),
    [anon_sym_unmanaged] = ACTIONS(3373),
    [anon_sym_checked] = ACTIONS(3373),
    [anon_sym_BANG] = ACTIONS(3375),
    [anon_sym_TILDE] = ACTIONS(3375),
    [anon_sym_PLUS_PLUS] = ACTIONS(3375),
    [anon_sym_DASH_DASH] = ACTIONS(3375),
    [anon_sym_true] = ACTIONS(3373),
    [anon_sym_false] = ACTIONS(3373),
    [anon_sym_PLUS] = ACTIONS(3373),
    [anon_sym_DASH] = ACTIONS(3373),
    [anon_sym_STAR] = ACTIONS(3375),
    [anon_sym_CARET] = ACTIONS(3375),
    [anon_sym_AMP] = ACTIONS(3375),
    [anon_sym_this] = ACTIONS(3373),
    [anon_sym_scoped] = ACTIONS(3373),
    [anon_sym_base] = ACTIONS(3373),
    [anon_sym_var] = ACTIONS(3373),
    [sym_predefined_type] = ACTIONS(3373),
    [anon_sym_break] = ACTIONS(3373),
    [anon_sym_unchecked] = ACTIONS(3373),
    [anon_sym_continue] = ACTIONS(3373),
    [anon_sym_do] = ACTIONS(3373),
    [anon_sym_while] = ACTIONS(3373),
    [anon_sym_for] = ACTIONS(3373),
    [anon_sym_lock] = ACTIONS(3373),
    [anon_sym_yield] = ACTIONS(3373),
    [anon_sym_switch] = ACTIONS(3373),
    [anon_sym_default] = ACTIONS(3373),
    [anon_sym_throw] = ACTIONS(3373),
    [anon_sym_try] = ACTIONS(3373),
    [anon_sym_when] = ACTIONS(3373),
    [anon_sym_await] = ACTIONS(3373),
    [anon_sym_foreach] = ACTIONS(3373),
    [anon_sym_goto] = ACTIONS(3373),
    [anon_sym_if] = ACTIONS(3373),
    [anon_sym_else] = ACTIONS(3373),
    [anon_sym_DOT_DOT] = ACTIONS(3375),
    [anon_sym_from] = ACTIONS(3373),
    [anon_sym_into] = ACTIONS(3373),
    [anon_sym_join] = ACTIONS(3373),
    [anon_sym_on] = ACTIONS(3373),
    [anon_sym_equals] = ACTIONS(3373),
    [anon_sym_let] = ACTIONS(3373),
    [anon_sym_orderby] = ACTIONS(3373),
    [anon_sym_ascending] = ACTIONS(3373),
    [anon_sym_descending] = ACTIONS(3373),
    [anon_sym_group] = ACTIONS(3373),
    [anon_sym_by] = ACTIONS(3373),
    [anon_sym_select] = ACTIONS(3373),
    [anon_sym_stackalloc] = ACTIONS(3373),
    [anon_sym_sizeof] = ACTIONS(3373),
    [anon_sym_typeof] = ACTIONS(3373),
    [anon_sym___makeref] = ACTIONS(3373),
    [anon_sym___reftype] = ACTIONS(3373),
    [anon_sym___refvalue] = ACTIONS(3373),
    [sym_null_literal] = ACTIONS(3373),
    [anon_sym_SQUOTE] = ACTIONS(3375),
    [sym_integer_literal] = ACTIONS(3373),
    [sym_real_literal] = ACTIONS(3375),
    [anon_sym_DQUOTE] = ACTIONS(3375),
    [sym_verbatim_string_literal] = ACTIONS(3375),
    [aux_sym_preproc_if_token1] = ACTIONS(3375),
    [aux_sym_preproc_if_token3] = ACTIONS(3375),
    [aux_sym_preproc_else_token1] = ACTIONS(3375),
    [aux_sym_preproc_elif_token1] = ACTIONS(3375),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3375),
    [sym_interpolation_verbatim_start] = ACTIONS(3375),
    [sym_interpolation_raw_start] = ACTIONS(3375),
    [sym_raw_string_start] = ACTIONS(3375),
  },
  [2298] = {
    [sym_preproc_region] = STATE(2298),
    [sym_preproc_endregion] = STATE(2298),
    [sym_preproc_line] = STATE(2298),
    [sym_preproc_pragma] = STATE(2298),
    [sym_preproc_nullable] = STATE(2298),
    [sym_preproc_error] = STATE(2298),
    [sym_preproc_warning] = STATE(2298),
    [sym_preproc_define] = STATE(2298),
    [sym_preproc_undef] = STATE(2298),
    [sym__identifier_token] = ACTIONS(3377),
    [anon_sym_extern] = ACTIONS(3377),
    [anon_sym_alias] = ACTIONS(3377),
    [anon_sym_SEMI] = ACTIONS(3379),
    [anon_sym_global] = ACTIONS(3377),
    [anon_sym_using] = ACTIONS(3377),
    [anon_sym_unsafe] = ACTIONS(3377),
    [anon_sym_static] = ACTIONS(3377),
    [anon_sym_LBRACK] = ACTIONS(3379),
    [anon_sym_LPAREN] = ACTIONS(3379),
    [anon_sym_return] = ACTIONS(3377),
    [anon_sym_namespace] = ACTIONS(3377),
    [anon_sym_class] = ACTIONS(3377),
    [anon_sym_ref] = ACTIONS(3377),
    [anon_sym_struct] = ACTIONS(3377),
    [anon_sym_enum] = ACTIONS(3377),
    [anon_sym_LBRACE] = ACTIONS(3379),
    [anon_sym_interface] = ACTIONS(3377),
    [anon_sym_delegate] = ACTIONS(3377),
    [anon_sym_record] = ACTIONS(3377),
    [anon_sym_abstract] = ACTIONS(3377),
    [anon_sym_async] = ACTIONS(3377),
    [anon_sym_const] = ACTIONS(3377),
    [anon_sym_file] = ACTIONS(3377),
    [anon_sym_fixed] = ACTIONS(3377),
    [anon_sym_internal] = ACTIONS(3377),
    [anon_sym_new] = ACTIONS(3377),
    [anon_sym_override] = ACTIONS(3377),
    [anon_sym_partial] = ACTIONS(3377),
    [anon_sym_private] = ACTIONS(3377),
    [anon_sym_protected] = ACTIONS(3377),
    [anon_sym_public] = ACTIONS(3377),
    [anon_sym_readonly] = ACTIONS(3377),
    [anon_sym_required] = ACTIONS(3377),
    [anon_sym_sealed] = ACTIONS(3377),
    [anon_sym_virtual] = ACTIONS(3377),
    [anon_sym_volatile] = ACTIONS(3377),
    [anon_sym_where] = ACTIONS(3377),
    [anon_sym_notnull] = ACTIONS(3377),
    [anon_sym_unmanaged] = ACTIONS(3377),
    [anon_sym_checked] = ACTIONS(3377),
    [anon_sym_BANG] = ACTIONS(3379),
    [anon_sym_TILDE] = ACTIONS(3379),
    [anon_sym_PLUS_PLUS] = ACTIONS(3379),
    [anon_sym_DASH_DASH] = ACTIONS(3379),
    [anon_sym_true] = ACTIONS(3377),
    [anon_sym_false] = ACTIONS(3377),
    [anon_sym_PLUS] = ACTIONS(3377),
    [anon_sym_DASH] = ACTIONS(3377),
    [anon_sym_STAR] = ACTIONS(3379),
    [anon_sym_CARET] = ACTIONS(3379),
    [anon_sym_AMP] = ACTIONS(3379),
    [anon_sym_this] = ACTIONS(3377),
    [anon_sym_scoped] = ACTIONS(3377),
    [anon_sym_base] = ACTIONS(3377),
    [anon_sym_var] = ACTIONS(3377),
    [sym_predefined_type] = ACTIONS(3377),
    [anon_sym_break] = ACTIONS(3377),
    [anon_sym_unchecked] = ACTIONS(3377),
    [anon_sym_continue] = ACTIONS(3377),
    [anon_sym_do] = ACTIONS(3377),
    [anon_sym_while] = ACTIONS(3377),
    [anon_sym_for] = ACTIONS(3377),
    [anon_sym_lock] = ACTIONS(3377),
    [anon_sym_yield] = ACTIONS(3377),
    [anon_sym_switch] = ACTIONS(3377),
    [anon_sym_default] = ACTIONS(3377),
    [anon_sym_throw] = ACTIONS(3377),
    [anon_sym_try] = ACTIONS(3377),
    [anon_sym_when] = ACTIONS(3377),
    [anon_sym_await] = ACTIONS(3377),
    [anon_sym_foreach] = ACTIONS(3377),
    [anon_sym_goto] = ACTIONS(3377),
    [anon_sym_if] = ACTIONS(3377),
    [anon_sym_else] = ACTIONS(3377),
    [anon_sym_DOT_DOT] = ACTIONS(3379),
    [anon_sym_from] = ACTIONS(3377),
    [anon_sym_into] = ACTIONS(3377),
    [anon_sym_join] = ACTIONS(3377),
    [anon_sym_on] = ACTIONS(3377),
    [anon_sym_equals] = ACTIONS(3377),
    [anon_sym_let] = ACTIONS(3377),
    [anon_sym_orderby] = ACTIONS(3377),
    [anon_sym_ascending] = ACTIONS(3377),
    [anon_sym_descending] = ACTIONS(3377),
    [anon_sym_group] = ACTIONS(3377),
    [anon_sym_by] = ACTIONS(3377),
    [anon_sym_select] = ACTIONS(3377),
    [anon_sym_stackalloc] = ACTIONS(3377),
    [anon_sym_sizeof] = ACTIONS(3377),
    [anon_sym_typeof] = ACTIONS(3377),
    [anon_sym___makeref] = ACTIONS(3377),
    [anon_sym___reftype] = ACTIONS(3377),
    [anon_sym___refvalue] = ACTIONS(3377),
    [sym_null_literal] = ACTIONS(3377),
    [anon_sym_SQUOTE] = ACTIONS(3379),
    [sym_integer_literal] = ACTIONS(3377),
    [sym_real_literal] = ACTIONS(3379),
    [anon_sym_DQUOTE] = ACTIONS(3379),
    [sym_verbatim_string_literal] = ACTIONS(3379),
    [aux_sym_preproc_if_token1] = ACTIONS(3379),
    [aux_sym_preproc_if_token3] = ACTIONS(3379),
    [aux_sym_preproc_else_token1] = ACTIONS(3379),
    [aux_sym_preproc_elif_token1] = ACTIONS(3379),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3379),
    [sym_interpolation_verbatim_start] = ACTIONS(3379),
    [sym_interpolation_raw_start] = ACTIONS(3379),
    [sym_raw_string_start] = ACTIONS(3379),
  },
  [2299] = {
    [sym_preproc_region] = STATE(2299),
    [sym_preproc_endregion] = STATE(2299),
    [sym_preproc_line] = STATE(2299),
    [sym_preproc_pragma] = STATE(2299),
    [sym_preproc_nullable] = STATE(2299),
    [sym_preproc_error] = STATE(2299),
    [sym_preproc_warning] = STATE(2299),
    [sym_preproc_define] = STATE(2299),
    [sym_preproc_undef] = STATE(2299),
    [ts_builtin_sym_end] = ACTIONS(3032),
    [sym__identifier_token] = ACTIONS(3030),
    [anon_sym_extern] = ACTIONS(3030),
    [anon_sym_alias] = ACTIONS(3030),
    [anon_sym_SEMI] = ACTIONS(3032),
    [anon_sym_global] = ACTIONS(3030),
    [anon_sym_using] = ACTIONS(3030),
    [anon_sym_unsafe] = ACTIONS(3030),
    [anon_sym_static] = ACTIONS(3030),
    [anon_sym_LBRACK] = ACTIONS(3032),
    [anon_sym_LPAREN] = ACTIONS(3032),
    [anon_sym_return] = ACTIONS(3030),
    [anon_sym_namespace] = ACTIONS(3030),
    [anon_sym_class] = ACTIONS(3030),
    [anon_sym_ref] = ACTIONS(3030),
    [anon_sym_struct] = ACTIONS(3030),
    [anon_sym_enum] = ACTIONS(3030),
    [anon_sym_LBRACE] = ACTIONS(3032),
    [anon_sym_interface] = ACTIONS(3030),
    [anon_sym_delegate] = ACTIONS(3030),
    [anon_sym_record] = ACTIONS(3030),
    [anon_sym_abstract] = ACTIONS(3030),
    [anon_sym_async] = ACTIONS(3030),
    [anon_sym_const] = ACTIONS(3030),
    [anon_sym_file] = ACTIONS(3030),
    [anon_sym_fixed] = ACTIONS(3030),
    [anon_sym_internal] = ACTIONS(3030),
    [anon_sym_new] = ACTIONS(3030),
    [anon_sym_override] = ACTIONS(3030),
    [anon_sym_partial] = ACTIONS(3030),
    [anon_sym_private] = ACTIONS(3030),
    [anon_sym_protected] = ACTIONS(3030),
    [anon_sym_public] = ACTIONS(3030),
    [anon_sym_readonly] = ACTIONS(3030),
    [anon_sym_required] = ACTIONS(3030),
    [anon_sym_sealed] = ACTIONS(3030),
    [anon_sym_virtual] = ACTIONS(3030),
    [anon_sym_volatile] = ACTIONS(3030),
    [anon_sym_where] = ACTIONS(3030),
    [anon_sym_notnull] = ACTIONS(3030),
    [anon_sym_unmanaged] = ACTIONS(3030),
    [anon_sym_checked] = ACTIONS(3030),
    [anon_sym_BANG] = ACTIONS(3032),
    [anon_sym_TILDE] = ACTIONS(3032),
    [anon_sym_PLUS_PLUS] = ACTIONS(3032),
    [anon_sym_DASH_DASH] = ACTIONS(3032),
    [anon_sym_true] = ACTIONS(3030),
    [anon_sym_false] = ACTIONS(3030),
    [anon_sym_PLUS] = ACTIONS(3030),
    [anon_sym_DASH] = ACTIONS(3030),
    [anon_sym_STAR] = ACTIONS(3032),
    [anon_sym_CARET] = ACTIONS(3032),
    [anon_sym_AMP] = ACTIONS(3032),
    [anon_sym_this] = ACTIONS(3030),
    [anon_sym_scoped] = ACTIONS(3030),
    [anon_sym_base] = ACTIONS(3030),
    [anon_sym_var] = ACTIONS(3030),
    [sym_predefined_type] = ACTIONS(3030),
    [anon_sym_break] = ACTIONS(3030),
    [anon_sym_unchecked] = ACTIONS(3030),
    [anon_sym_continue] = ACTIONS(3030),
    [anon_sym_do] = ACTIONS(3030),
    [anon_sym_while] = ACTIONS(3030),
    [anon_sym_for] = ACTIONS(3030),
    [anon_sym_lock] = ACTIONS(3030),
    [anon_sym_yield] = ACTIONS(3030),
    [anon_sym_switch] = ACTIONS(3030),
    [anon_sym_default] = ACTIONS(3030),
    [anon_sym_throw] = ACTIONS(3030),
    [anon_sym_try] = ACTIONS(3030),
    [anon_sym_catch] = ACTIONS(3030),
    [anon_sym_when] = ACTIONS(3030),
    [anon_sym_finally] = ACTIONS(3030),
    [anon_sym_await] = ACTIONS(3030),
    [anon_sym_foreach] = ACTIONS(3030),
    [anon_sym_goto] = ACTIONS(3030),
    [anon_sym_if] = ACTIONS(3030),
    [anon_sym_else] = ACTIONS(3030),
    [anon_sym_DOT_DOT] = ACTIONS(3032),
    [anon_sym_from] = ACTIONS(3030),
    [anon_sym_into] = ACTIONS(3030),
    [anon_sym_join] = ACTIONS(3030),
    [anon_sym_on] = ACTIONS(3030),
    [anon_sym_equals] = ACTIONS(3030),
    [anon_sym_let] = ACTIONS(3030),
    [anon_sym_orderby] = ACTIONS(3030),
    [anon_sym_ascending] = ACTIONS(3030),
    [anon_sym_descending] = ACTIONS(3030),
    [anon_sym_group] = ACTIONS(3030),
    [anon_sym_by] = ACTIONS(3030),
    [anon_sym_select] = ACTIONS(3030),
    [anon_sym_stackalloc] = ACTIONS(3030),
    [anon_sym_sizeof] = ACTIONS(3030),
    [anon_sym_typeof] = ACTIONS(3030),
    [anon_sym___makeref] = ACTIONS(3030),
    [anon_sym___reftype] = ACTIONS(3030),
    [anon_sym___refvalue] = ACTIONS(3030),
    [sym_null_literal] = ACTIONS(3030),
    [anon_sym_SQUOTE] = ACTIONS(3032),
    [sym_integer_literal] = ACTIONS(3030),
    [sym_real_literal] = ACTIONS(3032),
    [anon_sym_DQUOTE] = ACTIONS(3032),
    [sym_verbatim_string_literal] = ACTIONS(3032),
    [aux_sym_preproc_if_token1] = ACTIONS(3032),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3032),
    [sym_interpolation_verbatim_start] = ACTIONS(3032),
    [sym_interpolation_raw_start] = ACTIONS(3032),
    [sym_raw_string_start] = ACTIONS(3032),
  },
  [2300] = {
    [sym_preproc_region] = STATE(2300),
    [sym_preproc_endregion] = STATE(2300),
    [sym_preproc_line] = STATE(2300),
    [sym_preproc_pragma] = STATE(2300),
    [sym_preproc_nullable] = STATE(2300),
    [sym_preproc_error] = STATE(2300),
    [sym_preproc_warning] = STATE(2300),
    [sym_preproc_define] = STATE(2300),
    [sym_preproc_undef] = STATE(2300),
    [sym__identifier_token] = ACTIONS(3381),
    [anon_sym_extern] = ACTIONS(3381),
    [anon_sym_alias] = ACTIONS(3381),
    [anon_sym_SEMI] = ACTIONS(3383),
    [anon_sym_global] = ACTIONS(3381),
    [anon_sym_using] = ACTIONS(3381),
    [anon_sym_unsafe] = ACTIONS(3381),
    [anon_sym_static] = ACTIONS(3381),
    [anon_sym_LBRACK] = ACTIONS(3383),
    [anon_sym_LPAREN] = ACTIONS(3383),
    [anon_sym_return] = ACTIONS(3381),
    [anon_sym_namespace] = ACTIONS(3381),
    [anon_sym_class] = ACTIONS(3381),
    [anon_sym_ref] = ACTIONS(3381),
    [anon_sym_struct] = ACTIONS(3381),
    [anon_sym_enum] = ACTIONS(3381),
    [anon_sym_LBRACE] = ACTIONS(3383),
    [anon_sym_interface] = ACTIONS(3381),
    [anon_sym_delegate] = ACTIONS(3381),
    [anon_sym_record] = ACTIONS(3381),
    [anon_sym_abstract] = ACTIONS(3381),
    [anon_sym_async] = ACTIONS(3381),
    [anon_sym_const] = ACTIONS(3381),
    [anon_sym_file] = ACTIONS(3381),
    [anon_sym_fixed] = ACTIONS(3381),
    [anon_sym_internal] = ACTIONS(3381),
    [anon_sym_new] = ACTIONS(3381),
    [anon_sym_override] = ACTIONS(3381),
    [anon_sym_partial] = ACTIONS(3381),
    [anon_sym_private] = ACTIONS(3381),
    [anon_sym_protected] = ACTIONS(3381),
    [anon_sym_public] = ACTIONS(3381),
    [anon_sym_readonly] = ACTIONS(3381),
    [anon_sym_required] = ACTIONS(3381),
    [anon_sym_sealed] = ACTIONS(3381),
    [anon_sym_virtual] = ACTIONS(3381),
    [anon_sym_volatile] = ACTIONS(3381),
    [anon_sym_where] = ACTIONS(3381),
    [anon_sym_notnull] = ACTIONS(3381),
    [anon_sym_unmanaged] = ACTIONS(3381),
    [anon_sym_checked] = ACTIONS(3381),
    [anon_sym_BANG] = ACTIONS(3383),
    [anon_sym_TILDE] = ACTIONS(3383),
    [anon_sym_PLUS_PLUS] = ACTIONS(3383),
    [anon_sym_DASH_DASH] = ACTIONS(3383),
    [anon_sym_true] = ACTIONS(3381),
    [anon_sym_false] = ACTIONS(3381),
    [anon_sym_PLUS] = ACTIONS(3381),
    [anon_sym_DASH] = ACTIONS(3381),
    [anon_sym_STAR] = ACTIONS(3383),
    [anon_sym_CARET] = ACTIONS(3383),
    [anon_sym_AMP] = ACTIONS(3383),
    [anon_sym_this] = ACTIONS(3381),
    [anon_sym_scoped] = ACTIONS(3381),
    [anon_sym_base] = ACTIONS(3381),
    [anon_sym_var] = ACTIONS(3381),
    [sym_predefined_type] = ACTIONS(3381),
    [anon_sym_break] = ACTIONS(3381),
    [anon_sym_unchecked] = ACTIONS(3381),
    [anon_sym_continue] = ACTIONS(3381),
    [anon_sym_do] = ACTIONS(3381),
    [anon_sym_while] = ACTIONS(3381),
    [anon_sym_for] = ACTIONS(3381),
    [anon_sym_lock] = ACTIONS(3381),
    [anon_sym_yield] = ACTIONS(3381),
    [anon_sym_switch] = ACTIONS(3381),
    [anon_sym_default] = ACTIONS(3381),
    [anon_sym_throw] = ACTIONS(3381),
    [anon_sym_try] = ACTIONS(3381),
    [anon_sym_when] = ACTIONS(3381),
    [anon_sym_await] = ACTIONS(3381),
    [anon_sym_foreach] = ACTIONS(3381),
    [anon_sym_goto] = ACTIONS(3381),
    [anon_sym_if] = ACTIONS(3381),
    [anon_sym_else] = ACTIONS(3381),
    [anon_sym_DOT_DOT] = ACTIONS(3383),
    [anon_sym_from] = ACTIONS(3381),
    [anon_sym_into] = ACTIONS(3381),
    [anon_sym_join] = ACTIONS(3381),
    [anon_sym_on] = ACTIONS(3381),
    [anon_sym_equals] = ACTIONS(3381),
    [anon_sym_let] = ACTIONS(3381),
    [anon_sym_orderby] = ACTIONS(3381),
    [anon_sym_ascending] = ACTIONS(3381),
    [anon_sym_descending] = ACTIONS(3381),
    [anon_sym_group] = ACTIONS(3381),
    [anon_sym_by] = ACTIONS(3381),
    [anon_sym_select] = ACTIONS(3381),
    [anon_sym_stackalloc] = ACTIONS(3381),
    [anon_sym_sizeof] = ACTIONS(3381),
    [anon_sym_typeof] = ACTIONS(3381),
    [anon_sym___makeref] = ACTIONS(3381),
    [anon_sym___reftype] = ACTIONS(3381),
    [anon_sym___refvalue] = ACTIONS(3381),
    [sym_null_literal] = ACTIONS(3381),
    [anon_sym_SQUOTE] = ACTIONS(3383),
    [sym_integer_literal] = ACTIONS(3381),
    [sym_real_literal] = ACTIONS(3383),
    [anon_sym_DQUOTE] = ACTIONS(3383),
    [sym_verbatim_string_literal] = ACTIONS(3383),
    [aux_sym_preproc_if_token1] = ACTIONS(3383),
    [aux_sym_preproc_if_token3] = ACTIONS(3383),
    [aux_sym_preproc_else_token1] = ACTIONS(3383),
    [aux_sym_preproc_elif_token1] = ACTIONS(3383),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3383),
    [sym_interpolation_verbatim_start] = ACTIONS(3383),
    [sym_interpolation_raw_start] = ACTIONS(3383),
    [sym_raw_string_start] = ACTIONS(3383),
  },
  [2301] = {
    [sym_preproc_region] = STATE(2301),
    [sym_preproc_endregion] = STATE(2301),
    [sym_preproc_line] = STATE(2301),
    [sym_preproc_pragma] = STATE(2301),
    [sym_preproc_nullable] = STATE(2301),
    [sym_preproc_error] = STATE(2301),
    [sym_preproc_warning] = STATE(2301),
    [sym_preproc_define] = STATE(2301),
    [sym_preproc_undef] = STATE(2301),
    [sym__identifier_token] = ACTIONS(3385),
    [anon_sym_extern] = ACTIONS(3385),
    [anon_sym_alias] = ACTIONS(3385),
    [anon_sym_SEMI] = ACTIONS(3387),
    [anon_sym_global] = ACTIONS(3385),
    [anon_sym_using] = ACTIONS(3385),
    [anon_sym_unsafe] = ACTIONS(3385),
    [anon_sym_static] = ACTIONS(3385),
    [anon_sym_LBRACK] = ACTIONS(3387),
    [anon_sym_LPAREN] = ACTIONS(3387),
    [anon_sym_return] = ACTIONS(3385),
    [anon_sym_namespace] = ACTIONS(3385),
    [anon_sym_class] = ACTIONS(3385),
    [anon_sym_ref] = ACTIONS(3385),
    [anon_sym_struct] = ACTIONS(3385),
    [anon_sym_enum] = ACTIONS(3385),
    [anon_sym_LBRACE] = ACTIONS(3387),
    [anon_sym_interface] = ACTIONS(3385),
    [anon_sym_delegate] = ACTIONS(3385),
    [anon_sym_record] = ACTIONS(3385),
    [anon_sym_abstract] = ACTIONS(3385),
    [anon_sym_async] = ACTIONS(3385),
    [anon_sym_const] = ACTIONS(3385),
    [anon_sym_file] = ACTIONS(3385),
    [anon_sym_fixed] = ACTIONS(3385),
    [anon_sym_internal] = ACTIONS(3385),
    [anon_sym_new] = ACTIONS(3385),
    [anon_sym_override] = ACTIONS(3385),
    [anon_sym_partial] = ACTIONS(3385),
    [anon_sym_private] = ACTIONS(3385),
    [anon_sym_protected] = ACTIONS(3385),
    [anon_sym_public] = ACTIONS(3385),
    [anon_sym_readonly] = ACTIONS(3385),
    [anon_sym_required] = ACTIONS(3385),
    [anon_sym_sealed] = ACTIONS(3385),
    [anon_sym_virtual] = ACTIONS(3385),
    [anon_sym_volatile] = ACTIONS(3385),
    [anon_sym_where] = ACTIONS(3385),
    [anon_sym_notnull] = ACTIONS(3385),
    [anon_sym_unmanaged] = ACTIONS(3385),
    [anon_sym_checked] = ACTIONS(3385),
    [anon_sym_BANG] = ACTIONS(3387),
    [anon_sym_TILDE] = ACTIONS(3387),
    [anon_sym_PLUS_PLUS] = ACTIONS(3387),
    [anon_sym_DASH_DASH] = ACTIONS(3387),
    [anon_sym_true] = ACTIONS(3385),
    [anon_sym_false] = ACTIONS(3385),
    [anon_sym_PLUS] = ACTIONS(3385),
    [anon_sym_DASH] = ACTIONS(3385),
    [anon_sym_STAR] = ACTIONS(3387),
    [anon_sym_CARET] = ACTIONS(3387),
    [anon_sym_AMP] = ACTIONS(3387),
    [anon_sym_this] = ACTIONS(3385),
    [anon_sym_scoped] = ACTIONS(3385),
    [anon_sym_base] = ACTIONS(3385),
    [anon_sym_var] = ACTIONS(3385),
    [sym_predefined_type] = ACTIONS(3385),
    [anon_sym_break] = ACTIONS(3385),
    [anon_sym_unchecked] = ACTIONS(3385),
    [anon_sym_continue] = ACTIONS(3385),
    [anon_sym_do] = ACTIONS(3385),
    [anon_sym_while] = ACTIONS(3385),
    [anon_sym_for] = ACTIONS(3385),
    [anon_sym_lock] = ACTIONS(3385),
    [anon_sym_yield] = ACTIONS(3385),
    [anon_sym_switch] = ACTIONS(3385),
    [anon_sym_default] = ACTIONS(3385),
    [anon_sym_throw] = ACTIONS(3385),
    [anon_sym_try] = ACTIONS(3385),
    [anon_sym_when] = ACTIONS(3385),
    [anon_sym_await] = ACTIONS(3385),
    [anon_sym_foreach] = ACTIONS(3385),
    [anon_sym_goto] = ACTIONS(3385),
    [anon_sym_if] = ACTIONS(3385),
    [anon_sym_else] = ACTIONS(3385),
    [anon_sym_DOT_DOT] = ACTIONS(3387),
    [anon_sym_from] = ACTIONS(3385),
    [anon_sym_into] = ACTIONS(3385),
    [anon_sym_join] = ACTIONS(3385),
    [anon_sym_on] = ACTIONS(3385),
    [anon_sym_equals] = ACTIONS(3385),
    [anon_sym_let] = ACTIONS(3385),
    [anon_sym_orderby] = ACTIONS(3385),
    [anon_sym_ascending] = ACTIONS(3385),
    [anon_sym_descending] = ACTIONS(3385),
    [anon_sym_group] = ACTIONS(3385),
    [anon_sym_by] = ACTIONS(3385),
    [anon_sym_select] = ACTIONS(3385),
    [anon_sym_stackalloc] = ACTIONS(3385),
    [anon_sym_sizeof] = ACTIONS(3385),
    [anon_sym_typeof] = ACTIONS(3385),
    [anon_sym___makeref] = ACTIONS(3385),
    [anon_sym___reftype] = ACTIONS(3385),
    [anon_sym___refvalue] = ACTIONS(3385),
    [sym_null_literal] = ACTIONS(3385),
    [anon_sym_SQUOTE] = ACTIONS(3387),
    [sym_integer_literal] = ACTIONS(3385),
    [sym_real_literal] = ACTIONS(3387),
    [anon_sym_DQUOTE] = ACTIONS(3387),
    [sym_verbatim_string_literal] = ACTIONS(3387),
    [aux_sym_preproc_if_token1] = ACTIONS(3387),
    [aux_sym_preproc_if_token3] = ACTIONS(3387),
    [aux_sym_preproc_else_token1] = ACTIONS(3387),
    [aux_sym_preproc_elif_token1] = ACTIONS(3387),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3387),
    [sym_interpolation_verbatim_start] = ACTIONS(3387),
    [sym_interpolation_raw_start] = ACTIONS(3387),
    [sym_raw_string_start] = ACTIONS(3387),
  },
  [2302] = {
    [sym_preproc_region] = STATE(2302),
    [sym_preproc_endregion] = STATE(2302),
    [sym_preproc_line] = STATE(2302),
    [sym_preproc_pragma] = STATE(2302),
    [sym_preproc_nullable] = STATE(2302),
    [sym_preproc_error] = STATE(2302),
    [sym_preproc_warning] = STATE(2302),
    [sym_preproc_define] = STATE(2302),
    [sym_preproc_undef] = STATE(2302),
    [sym__identifier_token] = ACTIONS(3389),
    [anon_sym_extern] = ACTIONS(3389),
    [anon_sym_alias] = ACTIONS(3389),
    [anon_sym_SEMI] = ACTIONS(3391),
    [anon_sym_global] = ACTIONS(3389),
    [anon_sym_using] = ACTIONS(3389),
    [anon_sym_unsafe] = ACTIONS(3389),
    [anon_sym_static] = ACTIONS(3389),
    [anon_sym_LBRACK] = ACTIONS(3391),
    [anon_sym_LPAREN] = ACTIONS(3391),
    [anon_sym_return] = ACTIONS(3389),
    [anon_sym_namespace] = ACTIONS(3389),
    [anon_sym_class] = ACTIONS(3389),
    [anon_sym_ref] = ACTIONS(3389),
    [anon_sym_struct] = ACTIONS(3389),
    [anon_sym_enum] = ACTIONS(3389),
    [anon_sym_LBRACE] = ACTIONS(3391),
    [anon_sym_interface] = ACTIONS(3389),
    [anon_sym_delegate] = ACTIONS(3389),
    [anon_sym_record] = ACTIONS(3389),
    [anon_sym_abstract] = ACTIONS(3389),
    [anon_sym_async] = ACTIONS(3389),
    [anon_sym_const] = ACTIONS(3389),
    [anon_sym_file] = ACTIONS(3389),
    [anon_sym_fixed] = ACTIONS(3389),
    [anon_sym_internal] = ACTIONS(3389),
    [anon_sym_new] = ACTIONS(3389),
    [anon_sym_override] = ACTIONS(3389),
    [anon_sym_partial] = ACTIONS(3389),
    [anon_sym_private] = ACTIONS(3389),
    [anon_sym_protected] = ACTIONS(3389),
    [anon_sym_public] = ACTIONS(3389),
    [anon_sym_readonly] = ACTIONS(3389),
    [anon_sym_required] = ACTIONS(3389),
    [anon_sym_sealed] = ACTIONS(3389),
    [anon_sym_virtual] = ACTIONS(3389),
    [anon_sym_volatile] = ACTIONS(3389),
    [anon_sym_where] = ACTIONS(3389),
    [anon_sym_notnull] = ACTIONS(3389),
    [anon_sym_unmanaged] = ACTIONS(3389),
    [anon_sym_checked] = ACTIONS(3389),
    [anon_sym_BANG] = ACTIONS(3391),
    [anon_sym_TILDE] = ACTIONS(3391),
    [anon_sym_PLUS_PLUS] = ACTIONS(3391),
    [anon_sym_DASH_DASH] = ACTIONS(3391),
    [anon_sym_true] = ACTIONS(3389),
    [anon_sym_false] = ACTIONS(3389),
    [anon_sym_PLUS] = ACTIONS(3389),
    [anon_sym_DASH] = ACTIONS(3389),
    [anon_sym_STAR] = ACTIONS(3391),
    [anon_sym_CARET] = ACTIONS(3391),
    [anon_sym_AMP] = ACTIONS(3391),
    [anon_sym_this] = ACTIONS(3389),
    [anon_sym_scoped] = ACTIONS(3389),
    [anon_sym_base] = ACTIONS(3389),
    [anon_sym_var] = ACTIONS(3389),
    [sym_predefined_type] = ACTIONS(3389),
    [anon_sym_break] = ACTIONS(3389),
    [anon_sym_unchecked] = ACTIONS(3389),
    [anon_sym_continue] = ACTIONS(3389),
    [anon_sym_do] = ACTIONS(3389),
    [anon_sym_while] = ACTIONS(3389),
    [anon_sym_for] = ACTIONS(3389),
    [anon_sym_lock] = ACTIONS(3389),
    [anon_sym_yield] = ACTIONS(3389),
    [anon_sym_switch] = ACTIONS(3389),
    [anon_sym_default] = ACTIONS(3389),
    [anon_sym_throw] = ACTIONS(3389),
    [anon_sym_try] = ACTIONS(3389),
    [anon_sym_when] = ACTIONS(3389),
    [anon_sym_await] = ACTIONS(3389),
    [anon_sym_foreach] = ACTIONS(3389),
    [anon_sym_goto] = ACTIONS(3389),
    [anon_sym_if] = ACTIONS(3389),
    [anon_sym_else] = ACTIONS(3389),
    [anon_sym_DOT_DOT] = ACTIONS(3391),
    [anon_sym_from] = ACTIONS(3389),
    [anon_sym_into] = ACTIONS(3389),
    [anon_sym_join] = ACTIONS(3389),
    [anon_sym_on] = ACTIONS(3389),
    [anon_sym_equals] = ACTIONS(3389),
    [anon_sym_let] = ACTIONS(3389),
    [anon_sym_orderby] = ACTIONS(3389),
    [anon_sym_ascending] = ACTIONS(3389),
    [anon_sym_descending] = ACTIONS(3389),
    [anon_sym_group] = ACTIONS(3389),
    [anon_sym_by] = ACTIONS(3389),
    [anon_sym_select] = ACTIONS(3389),
    [anon_sym_stackalloc] = ACTIONS(3389),
    [anon_sym_sizeof] = ACTIONS(3389),
    [anon_sym_typeof] = ACTIONS(3389),
    [anon_sym___makeref] = ACTIONS(3389),
    [anon_sym___reftype] = ACTIONS(3389),
    [anon_sym___refvalue] = ACTIONS(3389),
    [sym_null_literal] = ACTIONS(3389),
    [anon_sym_SQUOTE] = ACTIONS(3391),
    [sym_integer_literal] = ACTIONS(3389),
    [sym_real_literal] = ACTIONS(3391),
    [anon_sym_DQUOTE] = ACTIONS(3391),
    [sym_verbatim_string_literal] = ACTIONS(3391),
    [aux_sym_preproc_if_token1] = ACTIONS(3391),
    [aux_sym_preproc_if_token3] = ACTIONS(3391),
    [aux_sym_preproc_else_token1] = ACTIONS(3391),
    [aux_sym_preproc_elif_token1] = ACTIONS(3391),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3391),
    [sym_interpolation_verbatim_start] = ACTIONS(3391),
    [sym_interpolation_raw_start] = ACTIONS(3391),
    [sym_raw_string_start] = ACTIONS(3391),
  },
  [2303] = {
    [sym_preproc_region] = STATE(2303),
    [sym_preproc_endregion] = STATE(2303),
    [sym_preproc_line] = STATE(2303),
    [sym_preproc_pragma] = STATE(2303),
    [sym_preproc_nullable] = STATE(2303),
    [sym_preproc_error] = STATE(2303),
    [sym_preproc_warning] = STATE(2303),
    [sym_preproc_define] = STATE(2303),
    [sym_preproc_undef] = STATE(2303),
    [sym__identifier_token] = ACTIONS(3393),
    [anon_sym_extern] = ACTIONS(3393),
    [anon_sym_alias] = ACTIONS(3393),
    [anon_sym_SEMI] = ACTIONS(3395),
    [anon_sym_global] = ACTIONS(3393),
    [anon_sym_using] = ACTIONS(3393),
    [anon_sym_unsafe] = ACTIONS(3393),
    [anon_sym_static] = ACTIONS(3393),
    [anon_sym_LBRACK] = ACTIONS(3395),
    [anon_sym_LPAREN] = ACTIONS(3395),
    [anon_sym_return] = ACTIONS(3393),
    [anon_sym_namespace] = ACTIONS(3393),
    [anon_sym_class] = ACTIONS(3393),
    [anon_sym_ref] = ACTIONS(3393),
    [anon_sym_struct] = ACTIONS(3393),
    [anon_sym_enum] = ACTIONS(3393),
    [anon_sym_LBRACE] = ACTIONS(3395),
    [anon_sym_interface] = ACTIONS(3393),
    [anon_sym_delegate] = ACTIONS(3393),
    [anon_sym_record] = ACTIONS(3393),
    [anon_sym_abstract] = ACTIONS(3393),
    [anon_sym_async] = ACTIONS(3393),
    [anon_sym_const] = ACTIONS(3393),
    [anon_sym_file] = ACTIONS(3393),
    [anon_sym_fixed] = ACTIONS(3393),
    [anon_sym_internal] = ACTIONS(3393),
    [anon_sym_new] = ACTIONS(3393),
    [anon_sym_override] = ACTIONS(3393),
    [anon_sym_partial] = ACTIONS(3393),
    [anon_sym_private] = ACTIONS(3393),
    [anon_sym_protected] = ACTIONS(3393),
    [anon_sym_public] = ACTIONS(3393),
    [anon_sym_readonly] = ACTIONS(3393),
    [anon_sym_required] = ACTIONS(3393),
    [anon_sym_sealed] = ACTIONS(3393),
    [anon_sym_virtual] = ACTIONS(3393),
    [anon_sym_volatile] = ACTIONS(3393),
    [anon_sym_where] = ACTIONS(3393),
    [anon_sym_notnull] = ACTIONS(3393),
    [anon_sym_unmanaged] = ACTIONS(3393),
    [anon_sym_checked] = ACTIONS(3393),
    [anon_sym_BANG] = ACTIONS(3395),
    [anon_sym_TILDE] = ACTIONS(3395),
    [anon_sym_PLUS_PLUS] = ACTIONS(3395),
    [anon_sym_DASH_DASH] = ACTIONS(3395),
    [anon_sym_true] = ACTIONS(3393),
    [anon_sym_false] = ACTIONS(3393),
    [anon_sym_PLUS] = ACTIONS(3393),
    [anon_sym_DASH] = ACTIONS(3393),
    [anon_sym_STAR] = ACTIONS(3395),
    [anon_sym_CARET] = ACTIONS(3395),
    [anon_sym_AMP] = ACTIONS(3395),
    [anon_sym_this] = ACTIONS(3393),
    [anon_sym_scoped] = ACTIONS(3393),
    [anon_sym_base] = ACTIONS(3393),
    [anon_sym_var] = ACTIONS(3393),
    [sym_predefined_type] = ACTIONS(3393),
    [anon_sym_break] = ACTIONS(3393),
    [anon_sym_unchecked] = ACTIONS(3393),
    [anon_sym_continue] = ACTIONS(3393),
    [anon_sym_do] = ACTIONS(3393),
    [anon_sym_while] = ACTIONS(3393),
    [anon_sym_for] = ACTIONS(3393),
    [anon_sym_lock] = ACTIONS(3393),
    [anon_sym_yield] = ACTIONS(3393),
    [anon_sym_switch] = ACTIONS(3393),
    [anon_sym_default] = ACTIONS(3393),
    [anon_sym_throw] = ACTIONS(3393),
    [anon_sym_try] = ACTIONS(3393),
    [anon_sym_when] = ACTIONS(3393),
    [anon_sym_await] = ACTIONS(3393),
    [anon_sym_foreach] = ACTIONS(3393),
    [anon_sym_goto] = ACTIONS(3393),
    [anon_sym_if] = ACTIONS(3393),
    [anon_sym_else] = ACTIONS(3393),
    [anon_sym_DOT_DOT] = ACTIONS(3395),
    [anon_sym_from] = ACTIONS(3393),
    [anon_sym_into] = ACTIONS(3393),
    [anon_sym_join] = ACTIONS(3393),
    [anon_sym_on] = ACTIONS(3393),
    [anon_sym_equals] = ACTIONS(3393),
    [anon_sym_let] = ACTIONS(3393),
    [anon_sym_orderby] = ACTIONS(3393),
    [anon_sym_ascending] = ACTIONS(3393),
    [anon_sym_descending] = ACTIONS(3393),
    [anon_sym_group] = ACTIONS(3393),
    [anon_sym_by] = ACTIONS(3393),
    [anon_sym_select] = ACTIONS(3393),
    [anon_sym_stackalloc] = ACTIONS(3393),
    [anon_sym_sizeof] = ACTIONS(3393),
    [anon_sym_typeof] = ACTIONS(3393),
    [anon_sym___makeref] = ACTIONS(3393),
    [anon_sym___reftype] = ACTIONS(3393),
    [anon_sym___refvalue] = ACTIONS(3393),
    [sym_null_literal] = ACTIONS(3393),
    [anon_sym_SQUOTE] = ACTIONS(3395),
    [sym_integer_literal] = ACTIONS(3393),
    [sym_real_literal] = ACTIONS(3395),
    [anon_sym_DQUOTE] = ACTIONS(3395),
    [sym_verbatim_string_literal] = ACTIONS(3395),
    [aux_sym_preproc_if_token1] = ACTIONS(3395),
    [aux_sym_preproc_if_token3] = ACTIONS(3395),
    [aux_sym_preproc_else_token1] = ACTIONS(3395),
    [aux_sym_preproc_elif_token1] = ACTIONS(3395),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3395),
    [sym_interpolation_verbatim_start] = ACTIONS(3395),
    [sym_interpolation_raw_start] = ACTIONS(3395),
    [sym_raw_string_start] = ACTIONS(3395),
  },
  [2304] = {
    [sym_preproc_region] = STATE(2304),
    [sym_preproc_endregion] = STATE(2304),
    [sym_preproc_line] = STATE(2304),
    [sym_preproc_pragma] = STATE(2304),
    [sym_preproc_nullable] = STATE(2304),
    [sym_preproc_error] = STATE(2304),
    [sym_preproc_warning] = STATE(2304),
    [sym_preproc_define] = STATE(2304),
    [sym_preproc_undef] = STATE(2304),
    [sym__identifier_token] = ACTIONS(3397),
    [anon_sym_extern] = ACTIONS(3397),
    [anon_sym_alias] = ACTIONS(3397),
    [anon_sym_SEMI] = ACTIONS(3399),
    [anon_sym_global] = ACTIONS(3397),
    [anon_sym_using] = ACTIONS(3397),
    [anon_sym_unsafe] = ACTIONS(3397),
    [anon_sym_static] = ACTIONS(3397),
    [anon_sym_LBRACK] = ACTIONS(3399),
    [anon_sym_LPAREN] = ACTIONS(3399),
    [anon_sym_return] = ACTIONS(3397),
    [anon_sym_namespace] = ACTIONS(3397),
    [anon_sym_class] = ACTIONS(3397),
    [anon_sym_ref] = ACTIONS(3397),
    [anon_sym_struct] = ACTIONS(3397),
    [anon_sym_enum] = ACTIONS(3397),
    [anon_sym_LBRACE] = ACTIONS(3399),
    [anon_sym_interface] = ACTIONS(3397),
    [anon_sym_delegate] = ACTIONS(3397),
    [anon_sym_record] = ACTIONS(3397),
    [anon_sym_abstract] = ACTIONS(3397),
    [anon_sym_async] = ACTIONS(3397),
    [anon_sym_const] = ACTIONS(3397),
    [anon_sym_file] = ACTIONS(3397),
    [anon_sym_fixed] = ACTIONS(3397),
    [anon_sym_internal] = ACTIONS(3397),
    [anon_sym_new] = ACTIONS(3397),
    [anon_sym_override] = ACTIONS(3397),
    [anon_sym_partial] = ACTIONS(3397),
    [anon_sym_private] = ACTIONS(3397),
    [anon_sym_protected] = ACTIONS(3397),
    [anon_sym_public] = ACTIONS(3397),
    [anon_sym_readonly] = ACTIONS(3397),
    [anon_sym_required] = ACTIONS(3397),
    [anon_sym_sealed] = ACTIONS(3397),
    [anon_sym_virtual] = ACTIONS(3397),
    [anon_sym_volatile] = ACTIONS(3397),
    [anon_sym_where] = ACTIONS(3397),
    [anon_sym_notnull] = ACTIONS(3397),
    [anon_sym_unmanaged] = ACTIONS(3397),
    [anon_sym_checked] = ACTIONS(3397),
    [anon_sym_BANG] = ACTIONS(3399),
    [anon_sym_TILDE] = ACTIONS(3399),
    [anon_sym_PLUS_PLUS] = ACTIONS(3399),
    [anon_sym_DASH_DASH] = ACTIONS(3399),
    [anon_sym_true] = ACTIONS(3397),
    [anon_sym_false] = ACTIONS(3397),
    [anon_sym_PLUS] = ACTIONS(3397),
    [anon_sym_DASH] = ACTIONS(3397),
    [anon_sym_STAR] = ACTIONS(3399),
    [anon_sym_CARET] = ACTIONS(3399),
    [anon_sym_AMP] = ACTIONS(3399),
    [anon_sym_this] = ACTIONS(3397),
    [anon_sym_scoped] = ACTIONS(3397),
    [anon_sym_base] = ACTIONS(3397),
    [anon_sym_var] = ACTIONS(3397),
    [sym_predefined_type] = ACTIONS(3397),
    [anon_sym_break] = ACTIONS(3397),
    [anon_sym_unchecked] = ACTIONS(3397),
    [anon_sym_continue] = ACTIONS(3397),
    [anon_sym_do] = ACTIONS(3397),
    [anon_sym_while] = ACTIONS(3397),
    [anon_sym_for] = ACTIONS(3397),
    [anon_sym_lock] = ACTIONS(3397),
    [anon_sym_yield] = ACTIONS(3397),
    [anon_sym_switch] = ACTIONS(3397),
    [anon_sym_default] = ACTIONS(3397),
    [anon_sym_throw] = ACTIONS(3397),
    [anon_sym_try] = ACTIONS(3397),
    [anon_sym_when] = ACTIONS(3397),
    [anon_sym_await] = ACTIONS(3397),
    [anon_sym_foreach] = ACTIONS(3397),
    [anon_sym_goto] = ACTIONS(3397),
    [anon_sym_if] = ACTIONS(3397),
    [anon_sym_else] = ACTIONS(3397),
    [anon_sym_DOT_DOT] = ACTIONS(3399),
    [anon_sym_from] = ACTIONS(3397),
    [anon_sym_into] = ACTIONS(3397),
    [anon_sym_join] = ACTIONS(3397),
    [anon_sym_on] = ACTIONS(3397),
    [anon_sym_equals] = ACTIONS(3397),
    [anon_sym_let] = ACTIONS(3397),
    [anon_sym_orderby] = ACTIONS(3397),
    [anon_sym_ascending] = ACTIONS(3397),
    [anon_sym_descending] = ACTIONS(3397),
    [anon_sym_group] = ACTIONS(3397),
    [anon_sym_by] = ACTIONS(3397),
    [anon_sym_select] = ACTIONS(3397),
    [anon_sym_stackalloc] = ACTIONS(3397),
    [anon_sym_sizeof] = ACTIONS(3397),
    [anon_sym_typeof] = ACTIONS(3397),
    [anon_sym___makeref] = ACTIONS(3397),
    [anon_sym___reftype] = ACTIONS(3397),
    [anon_sym___refvalue] = ACTIONS(3397),
    [sym_null_literal] = ACTIONS(3397),
    [anon_sym_SQUOTE] = ACTIONS(3399),
    [sym_integer_literal] = ACTIONS(3397),
    [sym_real_literal] = ACTIONS(3399),
    [anon_sym_DQUOTE] = ACTIONS(3399),
    [sym_verbatim_string_literal] = ACTIONS(3399),
    [aux_sym_preproc_if_token1] = ACTIONS(3399),
    [aux_sym_preproc_if_token3] = ACTIONS(3399),
    [aux_sym_preproc_else_token1] = ACTIONS(3399),
    [aux_sym_preproc_elif_token1] = ACTIONS(3399),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3399),
    [sym_interpolation_verbatim_start] = ACTIONS(3399),
    [sym_interpolation_raw_start] = ACTIONS(3399),
    [sym_raw_string_start] = ACTIONS(3399),
  },
  [2305] = {
    [sym_preproc_region] = STATE(2305),
    [sym_preproc_endregion] = STATE(2305),
    [sym_preproc_line] = STATE(2305),
    [sym_preproc_pragma] = STATE(2305),
    [sym_preproc_nullable] = STATE(2305),
    [sym_preproc_error] = STATE(2305),
    [sym_preproc_warning] = STATE(2305),
    [sym_preproc_define] = STATE(2305),
    [sym_preproc_undef] = STATE(2305),
    [sym__identifier_token] = ACTIONS(3401),
    [anon_sym_extern] = ACTIONS(3401),
    [anon_sym_alias] = ACTIONS(3401),
    [anon_sym_SEMI] = ACTIONS(3403),
    [anon_sym_global] = ACTIONS(3401),
    [anon_sym_using] = ACTIONS(3401),
    [anon_sym_unsafe] = ACTIONS(3401),
    [anon_sym_static] = ACTIONS(3401),
    [anon_sym_LBRACK] = ACTIONS(3403),
    [anon_sym_LPAREN] = ACTIONS(3403),
    [anon_sym_return] = ACTIONS(3401),
    [anon_sym_namespace] = ACTIONS(3401),
    [anon_sym_class] = ACTIONS(3401),
    [anon_sym_ref] = ACTIONS(3401),
    [anon_sym_struct] = ACTIONS(3401),
    [anon_sym_enum] = ACTIONS(3401),
    [anon_sym_LBRACE] = ACTIONS(3403),
    [anon_sym_interface] = ACTIONS(3401),
    [anon_sym_delegate] = ACTIONS(3401),
    [anon_sym_record] = ACTIONS(3401),
    [anon_sym_abstract] = ACTIONS(3401),
    [anon_sym_async] = ACTIONS(3401),
    [anon_sym_const] = ACTIONS(3401),
    [anon_sym_file] = ACTIONS(3401),
    [anon_sym_fixed] = ACTIONS(3401),
    [anon_sym_internal] = ACTIONS(3401),
    [anon_sym_new] = ACTIONS(3401),
    [anon_sym_override] = ACTIONS(3401),
    [anon_sym_partial] = ACTIONS(3401),
    [anon_sym_private] = ACTIONS(3401),
    [anon_sym_protected] = ACTIONS(3401),
    [anon_sym_public] = ACTIONS(3401),
    [anon_sym_readonly] = ACTIONS(3401),
    [anon_sym_required] = ACTIONS(3401),
    [anon_sym_sealed] = ACTIONS(3401),
    [anon_sym_virtual] = ACTIONS(3401),
    [anon_sym_volatile] = ACTIONS(3401),
    [anon_sym_where] = ACTIONS(3401),
    [anon_sym_notnull] = ACTIONS(3401),
    [anon_sym_unmanaged] = ACTIONS(3401),
    [anon_sym_checked] = ACTIONS(3401),
    [anon_sym_BANG] = ACTIONS(3403),
    [anon_sym_TILDE] = ACTIONS(3403),
    [anon_sym_PLUS_PLUS] = ACTIONS(3403),
    [anon_sym_DASH_DASH] = ACTIONS(3403),
    [anon_sym_true] = ACTIONS(3401),
    [anon_sym_false] = ACTIONS(3401),
    [anon_sym_PLUS] = ACTIONS(3401),
    [anon_sym_DASH] = ACTIONS(3401),
    [anon_sym_STAR] = ACTIONS(3403),
    [anon_sym_CARET] = ACTIONS(3403),
    [anon_sym_AMP] = ACTIONS(3403),
    [anon_sym_this] = ACTIONS(3401),
    [anon_sym_scoped] = ACTIONS(3401),
    [anon_sym_base] = ACTIONS(3401),
    [anon_sym_var] = ACTIONS(3401),
    [sym_predefined_type] = ACTIONS(3401),
    [anon_sym_break] = ACTIONS(3401),
    [anon_sym_unchecked] = ACTIONS(3401),
    [anon_sym_continue] = ACTIONS(3401),
    [anon_sym_do] = ACTIONS(3401),
    [anon_sym_while] = ACTIONS(3401),
    [anon_sym_for] = ACTIONS(3401),
    [anon_sym_lock] = ACTIONS(3401),
    [anon_sym_yield] = ACTIONS(3401),
    [anon_sym_switch] = ACTIONS(3401),
    [anon_sym_default] = ACTIONS(3401),
    [anon_sym_throw] = ACTIONS(3401),
    [anon_sym_try] = ACTIONS(3401),
    [anon_sym_when] = ACTIONS(3401),
    [anon_sym_await] = ACTIONS(3401),
    [anon_sym_foreach] = ACTIONS(3401),
    [anon_sym_goto] = ACTIONS(3401),
    [anon_sym_if] = ACTIONS(3401),
    [anon_sym_else] = ACTIONS(3401),
    [anon_sym_DOT_DOT] = ACTIONS(3403),
    [anon_sym_from] = ACTIONS(3401),
    [anon_sym_into] = ACTIONS(3401),
    [anon_sym_join] = ACTIONS(3401),
    [anon_sym_on] = ACTIONS(3401),
    [anon_sym_equals] = ACTIONS(3401),
    [anon_sym_let] = ACTIONS(3401),
    [anon_sym_orderby] = ACTIONS(3401),
    [anon_sym_ascending] = ACTIONS(3401),
    [anon_sym_descending] = ACTIONS(3401),
    [anon_sym_group] = ACTIONS(3401),
    [anon_sym_by] = ACTIONS(3401),
    [anon_sym_select] = ACTIONS(3401),
    [anon_sym_stackalloc] = ACTIONS(3401),
    [anon_sym_sizeof] = ACTIONS(3401),
    [anon_sym_typeof] = ACTIONS(3401),
    [anon_sym___makeref] = ACTIONS(3401),
    [anon_sym___reftype] = ACTIONS(3401),
    [anon_sym___refvalue] = ACTIONS(3401),
    [sym_null_literal] = ACTIONS(3401),
    [anon_sym_SQUOTE] = ACTIONS(3403),
    [sym_integer_literal] = ACTIONS(3401),
    [sym_real_literal] = ACTIONS(3403),
    [anon_sym_DQUOTE] = ACTIONS(3403),
    [sym_verbatim_string_literal] = ACTIONS(3403),
    [aux_sym_preproc_if_token1] = ACTIONS(3403),
    [aux_sym_preproc_if_token3] = ACTIONS(3403),
    [aux_sym_preproc_else_token1] = ACTIONS(3403),
    [aux_sym_preproc_elif_token1] = ACTIONS(3403),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3403),
    [sym_interpolation_verbatim_start] = ACTIONS(3403),
    [sym_interpolation_raw_start] = ACTIONS(3403),
    [sym_raw_string_start] = ACTIONS(3403),
  },
  [2306] = {
    [sym_preproc_region] = STATE(2306),
    [sym_preproc_endregion] = STATE(2306),
    [sym_preproc_line] = STATE(2306),
    [sym_preproc_pragma] = STATE(2306),
    [sym_preproc_nullable] = STATE(2306),
    [sym_preproc_error] = STATE(2306),
    [sym_preproc_warning] = STATE(2306),
    [sym_preproc_define] = STATE(2306),
    [sym_preproc_undef] = STATE(2306),
    [sym__identifier_token] = ACTIONS(3405),
    [anon_sym_extern] = ACTIONS(3405),
    [anon_sym_alias] = ACTIONS(3405),
    [anon_sym_SEMI] = ACTIONS(3407),
    [anon_sym_global] = ACTIONS(3405),
    [anon_sym_using] = ACTIONS(3405),
    [anon_sym_unsafe] = ACTIONS(3405),
    [anon_sym_static] = ACTIONS(3405),
    [anon_sym_LBRACK] = ACTIONS(3407),
    [anon_sym_LPAREN] = ACTIONS(3407),
    [anon_sym_return] = ACTIONS(3405),
    [anon_sym_namespace] = ACTIONS(3405),
    [anon_sym_class] = ACTIONS(3405),
    [anon_sym_ref] = ACTIONS(3405),
    [anon_sym_struct] = ACTIONS(3405),
    [anon_sym_enum] = ACTIONS(3405),
    [anon_sym_LBRACE] = ACTIONS(3407),
    [anon_sym_interface] = ACTIONS(3405),
    [anon_sym_delegate] = ACTIONS(3405),
    [anon_sym_record] = ACTIONS(3405),
    [anon_sym_abstract] = ACTIONS(3405),
    [anon_sym_async] = ACTIONS(3405),
    [anon_sym_const] = ACTIONS(3405),
    [anon_sym_file] = ACTIONS(3405),
    [anon_sym_fixed] = ACTIONS(3405),
    [anon_sym_internal] = ACTIONS(3405),
    [anon_sym_new] = ACTIONS(3405),
    [anon_sym_override] = ACTIONS(3405),
    [anon_sym_partial] = ACTIONS(3405),
    [anon_sym_private] = ACTIONS(3405),
    [anon_sym_protected] = ACTIONS(3405),
    [anon_sym_public] = ACTIONS(3405),
    [anon_sym_readonly] = ACTIONS(3405),
    [anon_sym_required] = ACTIONS(3405),
    [anon_sym_sealed] = ACTIONS(3405),
    [anon_sym_virtual] = ACTIONS(3405),
    [anon_sym_volatile] = ACTIONS(3405),
    [anon_sym_where] = ACTIONS(3405),
    [anon_sym_notnull] = ACTIONS(3405),
    [anon_sym_unmanaged] = ACTIONS(3405),
    [anon_sym_checked] = ACTIONS(3405),
    [anon_sym_BANG] = ACTIONS(3407),
    [anon_sym_TILDE] = ACTIONS(3407),
    [anon_sym_PLUS_PLUS] = ACTIONS(3407),
    [anon_sym_DASH_DASH] = ACTIONS(3407),
    [anon_sym_true] = ACTIONS(3405),
    [anon_sym_false] = ACTIONS(3405),
    [anon_sym_PLUS] = ACTIONS(3405),
    [anon_sym_DASH] = ACTIONS(3405),
    [anon_sym_STAR] = ACTIONS(3407),
    [anon_sym_CARET] = ACTIONS(3407),
    [anon_sym_AMP] = ACTIONS(3407),
    [anon_sym_this] = ACTIONS(3405),
    [anon_sym_scoped] = ACTIONS(3405),
    [anon_sym_base] = ACTIONS(3405),
    [anon_sym_var] = ACTIONS(3405),
    [sym_predefined_type] = ACTIONS(3405),
    [anon_sym_break] = ACTIONS(3405),
    [anon_sym_unchecked] = ACTIONS(3405),
    [anon_sym_continue] = ACTIONS(3405),
    [anon_sym_do] = ACTIONS(3405),
    [anon_sym_while] = ACTIONS(3405),
    [anon_sym_for] = ACTIONS(3405),
    [anon_sym_lock] = ACTIONS(3405),
    [anon_sym_yield] = ACTIONS(3405),
    [anon_sym_switch] = ACTIONS(3405),
    [anon_sym_default] = ACTIONS(3405),
    [anon_sym_throw] = ACTIONS(3405),
    [anon_sym_try] = ACTIONS(3405),
    [anon_sym_when] = ACTIONS(3405),
    [anon_sym_await] = ACTIONS(3405),
    [anon_sym_foreach] = ACTIONS(3405),
    [anon_sym_goto] = ACTIONS(3405),
    [anon_sym_if] = ACTIONS(3405),
    [anon_sym_else] = ACTIONS(3405),
    [anon_sym_DOT_DOT] = ACTIONS(3407),
    [anon_sym_from] = ACTIONS(3405),
    [anon_sym_into] = ACTIONS(3405),
    [anon_sym_join] = ACTIONS(3405),
    [anon_sym_on] = ACTIONS(3405),
    [anon_sym_equals] = ACTIONS(3405),
    [anon_sym_let] = ACTIONS(3405),
    [anon_sym_orderby] = ACTIONS(3405),
    [anon_sym_ascending] = ACTIONS(3405),
    [anon_sym_descending] = ACTIONS(3405),
    [anon_sym_group] = ACTIONS(3405),
    [anon_sym_by] = ACTIONS(3405),
    [anon_sym_select] = ACTIONS(3405),
    [anon_sym_stackalloc] = ACTIONS(3405),
    [anon_sym_sizeof] = ACTIONS(3405),
    [anon_sym_typeof] = ACTIONS(3405),
    [anon_sym___makeref] = ACTIONS(3405),
    [anon_sym___reftype] = ACTIONS(3405),
    [anon_sym___refvalue] = ACTIONS(3405),
    [sym_null_literal] = ACTIONS(3405),
    [anon_sym_SQUOTE] = ACTIONS(3407),
    [sym_integer_literal] = ACTIONS(3405),
    [sym_real_literal] = ACTIONS(3407),
    [anon_sym_DQUOTE] = ACTIONS(3407),
    [sym_verbatim_string_literal] = ACTIONS(3407),
    [aux_sym_preproc_if_token1] = ACTIONS(3407),
    [aux_sym_preproc_if_token3] = ACTIONS(3407),
    [aux_sym_preproc_else_token1] = ACTIONS(3407),
    [aux_sym_preproc_elif_token1] = ACTIONS(3407),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3407),
    [sym_interpolation_verbatim_start] = ACTIONS(3407),
    [sym_interpolation_raw_start] = ACTIONS(3407),
    [sym_raw_string_start] = ACTIONS(3407),
  },
  [2307] = {
    [sym_preproc_region] = STATE(2307),
    [sym_preproc_endregion] = STATE(2307),
    [sym_preproc_line] = STATE(2307),
    [sym_preproc_pragma] = STATE(2307),
    [sym_preproc_nullable] = STATE(2307),
    [sym_preproc_error] = STATE(2307),
    [sym_preproc_warning] = STATE(2307),
    [sym_preproc_define] = STATE(2307),
    [sym_preproc_undef] = STATE(2307),
    [sym__identifier_token] = ACTIONS(3409),
    [anon_sym_extern] = ACTIONS(3409),
    [anon_sym_alias] = ACTIONS(3409),
    [anon_sym_SEMI] = ACTIONS(3411),
    [anon_sym_global] = ACTIONS(3409),
    [anon_sym_using] = ACTIONS(3409),
    [anon_sym_unsafe] = ACTIONS(3409),
    [anon_sym_static] = ACTIONS(3409),
    [anon_sym_LBRACK] = ACTIONS(3411),
    [anon_sym_LPAREN] = ACTIONS(3411),
    [anon_sym_return] = ACTIONS(3409),
    [anon_sym_namespace] = ACTIONS(3409),
    [anon_sym_class] = ACTIONS(3409),
    [anon_sym_ref] = ACTIONS(3409),
    [anon_sym_struct] = ACTIONS(3409),
    [anon_sym_enum] = ACTIONS(3409),
    [anon_sym_LBRACE] = ACTIONS(3411),
    [anon_sym_interface] = ACTIONS(3409),
    [anon_sym_delegate] = ACTIONS(3409),
    [anon_sym_record] = ACTIONS(3409),
    [anon_sym_abstract] = ACTIONS(3409),
    [anon_sym_async] = ACTIONS(3409),
    [anon_sym_const] = ACTIONS(3409),
    [anon_sym_file] = ACTIONS(3409),
    [anon_sym_fixed] = ACTIONS(3409),
    [anon_sym_internal] = ACTIONS(3409),
    [anon_sym_new] = ACTIONS(3409),
    [anon_sym_override] = ACTIONS(3409),
    [anon_sym_partial] = ACTIONS(3409),
    [anon_sym_private] = ACTIONS(3409),
    [anon_sym_protected] = ACTIONS(3409),
    [anon_sym_public] = ACTIONS(3409),
    [anon_sym_readonly] = ACTIONS(3409),
    [anon_sym_required] = ACTIONS(3409),
    [anon_sym_sealed] = ACTIONS(3409),
    [anon_sym_virtual] = ACTIONS(3409),
    [anon_sym_volatile] = ACTIONS(3409),
    [anon_sym_where] = ACTIONS(3409),
    [anon_sym_notnull] = ACTIONS(3409),
    [anon_sym_unmanaged] = ACTIONS(3409),
    [anon_sym_checked] = ACTIONS(3409),
    [anon_sym_BANG] = ACTIONS(3411),
    [anon_sym_TILDE] = ACTIONS(3411),
    [anon_sym_PLUS_PLUS] = ACTIONS(3411),
    [anon_sym_DASH_DASH] = ACTIONS(3411),
    [anon_sym_true] = ACTIONS(3409),
    [anon_sym_false] = ACTIONS(3409),
    [anon_sym_PLUS] = ACTIONS(3409),
    [anon_sym_DASH] = ACTIONS(3409),
    [anon_sym_STAR] = ACTIONS(3411),
    [anon_sym_CARET] = ACTIONS(3411),
    [anon_sym_AMP] = ACTIONS(3411),
    [anon_sym_this] = ACTIONS(3409),
    [anon_sym_scoped] = ACTIONS(3409),
    [anon_sym_base] = ACTIONS(3409),
    [anon_sym_var] = ACTIONS(3409),
    [sym_predefined_type] = ACTIONS(3409),
    [anon_sym_break] = ACTIONS(3409),
    [anon_sym_unchecked] = ACTIONS(3409),
    [anon_sym_continue] = ACTIONS(3409),
    [anon_sym_do] = ACTIONS(3409),
    [anon_sym_while] = ACTIONS(3409),
    [anon_sym_for] = ACTIONS(3409),
    [anon_sym_lock] = ACTIONS(3409),
    [anon_sym_yield] = ACTIONS(3409),
    [anon_sym_switch] = ACTIONS(3409),
    [anon_sym_default] = ACTIONS(3409),
    [anon_sym_throw] = ACTIONS(3409),
    [anon_sym_try] = ACTIONS(3409),
    [anon_sym_when] = ACTIONS(3409),
    [anon_sym_await] = ACTIONS(3409),
    [anon_sym_foreach] = ACTIONS(3409),
    [anon_sym_goto] = ACTIONS(3409),
    [anon_sym_if] = ACTIONS(3409),
    [anon_sym_DOT_DOT] = ACTIONS(3411),
    [anon_sym_from] = ACTIONS(3409),
    [anon_sym_into] = ACTIONS(3409),
    [anon_sym_join] = ACTIONS(3409),
    [anon_sym_on] = ACTIONS(3409),
    [anon_sym_equals] = ACTIONS(3409),
    [anon_sym_let] = ACTIONS(3409),
    [anon_sym_orderby] = ACTIONS(3409),
    [anon_sym_ascending] = ACTIONS(3409),
    [anon_sym_descending] = ACTIONS(3409),
    [anon_sym_group] = ACTIONS(3409),
    [anon_sym_by] = ACTIONS(3409),
    [anon_sym_select] = ACTIONS(3409),
    [anon_sym_stackalloc] = ACTIONS(3409),
    [anon_sym_sizeof] = ACTIONS(3409),
    [anon_sym_typeof] = ACTIONS(3409),
    [anon_sym___makeref] = ACTIONS(3409),
    [anon_sym___reftype] = ACTIONS(3409),
    [anon_sym___refvalue] = ACTIONS(3409),
    [sym_null_literal] = ACTIONS(3409),
    [anon_sym_SQUOTE] = ACTIONS(3411),
    [sym_integer_literal] = ACTIONS(3409),
    [sym_real_literal] = ACTIONS(3411),
    [anon_sym_DQUOTE] = ACTIONS(3411),
    [sym_verbatim_string_literal] = ACTIONS(3411),
    [aux_sym_preproc_if_token1] = ACTIONS(3411),
    [aux_sym_preproc_if_token3] = ACTIONS(3411),
    [aux_sym_preproc_else_token1] = ACTIONS(3411),
    [aux_sym_preproc_elif_token1] = ACTIONS(3411),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3411),
    [sym_interpolation_verbatim_start] = ACTIONS(3411),
    [sym_interpolation_raw_start] = ACTIONS(3411),
    [sym_raw_string_start] = ACTIONS(3411),
  },
  [2308] = {
    [sym_preproc_region] = STATE(2308),
    [sym_preproc_endregion] = STATE(2308),
    [sym_preproc_line] = STATE(2308),
    [sym_preproc_pragma] = STATE(2308),
    [sym_preproc_nullable] = STATE(2308),
    [sym_preproc_error] = STATE(2308),
    [sym_preproc_warning] = STATE(2308),
    [sym_preproc_define] = STATE(2308),
    [sym_preproc_undef] = STATE(2308),
    [sym__identifier_token] = ACTIONS(3413),
    [anon_sym_extern] = ACTIONS(3413),
    [anon_sym_alias] = ACTIONS(3413),
    [anon_sym_SEMI] = ACTIONS(3415),
    [anon_sym_global] = ACTIONS(3413),
    [anon_sym_using] = ACTIONS(3413),
    [anon_sym_unsafe] = ACTIONS(3413),
    [anon_sym_static] = ACTIONS(3413),
    [anon_sym_LBRACK] = ACTIONS(3415),
    [anon_sym_LPAREN] = ACTIONS(3415),
    [anon_sym_return] = ACTIONS(3413),
    [anon_sym_namespace] = ACTIONS(3413),
    [anon_sym_class] = ACTIONS(3413),
    [anon_sym_ref] = ACTIONS(3413),
    [anon_sym_struct] = ACTIONS(3413),
    [anon_sym_enum] = ACTIONS(3413),
    [anon_sym_LBRACE] = ACTIONS(3415),
    [anon_sym_interface] = ACTIONS(3413),
    [anon_sym_delegate] = ACTIONS(3413),
    [anon_sym_record] = ACTIONS(3413),
    [anon_sym_abstract] = ACTIONS(3413),
    [anon_sym_async] = ACTIONS(3413),
    [anon_sym_const] = ACTIONS(3413),
    [anon_sym_file] = ACTIONS(3413),
    [anon_sym_fixed] = ACTIONS(3413),
    [anon_sym_internal] = ACTIONS(3413),
    [anon_sym_new] = ACTIONS(3413),
    [anon_sym_override] = ACTIONS(3413),
    [anon_sym_partial] = ACTIONS(3413),
    [anon_sym_private] = ACTIONS(3413),
    [anon_sym_protected] = ACTIONS(3413),
    [anon_sym_public] = ACTIONS(3413),
    [anon_sym_readonly] = ACTIONS(3413),
    [anon_sym_required] = ACTIONS(3413),
    [anon_sym_sealed] = ACTIONS(3413),
    [anon_sym_virtual] = ACTIONS(3413),
    [anon_sym_volatile] = ACTIONS(3413),
    [anon_sym_where] = ACTIONS(3413),
    [anon_sym_notnull] = ACTIONS(3413),
    [anon_sym_unmanaged] = ACTIONS(3413),
    [anon_sym_checked] = ACTIONS(3413),
    [anon_sym_BANG] = ACTIONS(3415),
    [anon_sym_TILDE] = ACTIONS(3415),
    [anon_sym_PLUS_PLUS] = ACTIONS(3415),
    [anon_sym_DASH_DASH] = ACTIONS(3415),
    [anon_sym_true] = ACTIONS(3413),
    [anon_sym_false] = ACTIONS(3413),
    [anon_sym_PLUS] = ACTIONS(3413),
    [anon_sym_DASH] = ACTIONS(3413),
    [anon_sym_STAR] = ACTIONS(3415),
    [anon_sym_CARET] = ACTIONS(3415),
    [anon_sym_AMP] = ACTIONS(3415),
    [anon_sym_this] = ACTIONS(3413),
    [anon_sym_scoped] = ACTIONS(3413),
    [anon_sym_base] = ACTIONS(3413),
    [anon_sym_var] = ACTIONS(3413),
    [sym_predefined_type] = ACTIONS(3413),
    [anon_sym_break] = ACTIONS(3413),
    [anon_sym_unchecked] = ACTIONS(3413),
    [anon_sym_continue] = ACTIONS(3413),
    [anon_sym_do] = ACTIONS(3413),
    [anon_sym_while] = ACTIONS(3413),
    [anon_sym_for] = ACTIONS(3413),
    [anon_sym_lock] = ACTIONS(3413),
    [anon_sym_yield] = ACTIONS(3413),
    [anon_sym_switch] = ACTIONS(3413),
    [anon_sym_default] = ACTIONS(3413),
    [anon_sym_throw] = ACTIONS(3413),
    [anon_sym_try] = ACTIONS(3413),
    [anon_sym_when] = ACTIONS(3413),
    [anon_sym_await] = ACTIONS(3413),
    [anon_sym_foreach] = ACTIONS(3413),
    [anon_sym_goto] = ACTIONS(3413),
    [anon_sym_if] = ACTIONS(3413),
    [anon_sym_DOT_DOT] = ACTIONS(3415),
    [anon_sym_from] = ACTIONS(3413),
    [anon_sym_into] = ACTIONS(3413),
    [anon_sym_join] = ACTIONS(3413),
    [anon_sym_on] = ACTIONS(3413),
    [anon_sym_equals] = ACTIONS(3413),
    [anon_sym_let] = ACTIONS(3413),
    [anon_sym_orderby] = ACTIONS(3413),
    [anon_sym_ascending] = ACTIONS(3413),
    [anon_sym_descending] = ACTIONS(3413),
    [anon_sym_group] = ACTIONS(3413),
    [anon_sym_by] = ACTIONS(3413),
    [anon_sym_select] = ACTIONS(3413),
    [anon_sym_stackalloc] = ACTIONS(3413),
    [anon_sym_sizeof] = ACTIONS(3413),
    [anon_sym_typeof] = ACTIONS(3413),
    [anon_sym___makeref] = ACTIONS(3413),
    [anon_sym___reftype] = ACTIONS(3413),
    [anon_sym___refvalue] = ACTIONS(3413),
    [sym_null_literal] = ACTIONS(3413),
    [anon_sym_SQUOTE] = ACTIONS(3415),
    [sym_integer_literal] = ACTIONS(3413),
    [sym_real_literal] = ACTIONS(3415),
    [anon_sym_DQUOTE] = ACTIONS(3415),
    [sym_verbatim_string_literal] = ACTIONS(3415),
    [aux_sym_preproc_if_token1] = ACTIONS(3415),
    [aux_sym_preproc_if_token3] = ACTIONS(3415),
    [aux_sym_preproc_else_token1] = ACTIONS(3415),
    [aux_sym_preproc_elif_token1] = ACTIONS(3415),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3415),
    [sym_interpolation_verbatim_start] = ACTIONS(3415),
    [sym_interpolation_raw_start] = ACTIONS(3415),
    [sym_raw_string_start] = ACTIONS(3415),
  },
  [2309] = {
    [sym_preproc_region] = STATE(2309),
    [sym_preproc_endregion] = STATE(2309),
    [sym_preproc_line] = STATE(2309),
    [sym_preproc_pragma] = STATE(2309),
    [sym_preproc_nullable] = STATE(2309),
    [sym_preproc_error] = STATE(2309),
    [sym_preproc_warning] = STATE(2309),
    [sym_preproc_define] = STATE(2309),
    [sym_preproc_undef] = STATE(2309),
    [sym__identifier_token] = ACTIONS(3417),
    [anon_sym_extern] = ACTIONS(3417),
    [anon_sym_alias] = ACTIONS(3417),
    [anon_sym_SEMI] = ACTIONS(3419),
    [anon_sym_global] = ACTIONS(3417),
    [anon_sym_using] = ACTIONS(3417),
    [anon_sym_unsafe] = ACTIONS(3417),
    [anon_sym_static] = ACTIONS(3417),
    [anon_sym_LBRACK] = ACTIONS(3419),
    [anon_sym_LPAREN] = ACTIONS(3419),
    [anon_sym_return] = ACTIONS(3417),
    [anon_sym_namespace] = ACTIONS(3417),
    [anon_sym_class] = ACTIONS(3417),
    [anon_sym_ref] = ACTIONS(3417),
    [anon_sym_struct] = ACTIONS(3417),
    [anon_sym_enum] = ACTIONS(3417),
    [anon_sym_LBRACE] = ACTIONS(3419),
    [anon_sym_interface] = ACTIONS(3417),
    [anon_sym_delegate] = ACTIONS(3417),
    [anon_sym_record] = ACTIONS(3417),
    [anon_sym_abstract] = ACTIONS(3417),
    [anon_sym_async] = ACTIONS(3417),
    [anon_sym_const] = ACTIONS(3417),
    [anon_sym_file] = ACTIONS(3417),
    [anon_sym_fixed] = ACTIONS(3417),
    [anon_sym_internal] = ACTIONS(3417),
    [anon_sym_new] = ACTIONS(3417),
    [anon_sym_override] = ACTIONS(3417),
    [anon_sym_partial] = ACTIONS(3417),
    [anon_sym_private] = ACTIONS(3417),
    [anon_sym_protected] = ACTIONS(3417),
    [anon_sym_public] = ACTIONS(3417),
    [anon_sym_readonly] = ACTIONS(3417),
    [anon_sym_required] = ACTIONS(3417),
    [anon_sym_sealed] = ACTIONS(3417),
    [anon_sym_virtual] = ACTIONS(3417),
    [anon_sym_volatile] = ACTIONS(3417),
    [anon_sym_where] = ACTIONS(3417),
    [anon_sym_notnull] = ACTIONS(3417),
    [anon_sym_unmanaged] = ACTIONS(3417),
    [anon_sym_checked] = ACTIONS(3417),
    [anon_sym_BANG] = ACTIONS(3419),
    [anon_sym_TILDE] = ACTIONS(3419),
    [anon_sym_PLUS_PLUS] = ACTIONS(3419),
    [anon_sym_DASH_DASH] = ACTIONS(3419),
    [anon_sym_true] = ACTIONS(3417),
    [anon_sym_false] = ACTIONS(3417),
    [anon_sym_PLUS] = ACTIONS(3417),
    [anon_sym_DASH] = ACTIONS(3417),
    [anon_sym_STAR] = ACTIONS(3419),
    [anon_sym_CARET] = ACTIONS(3419),
    [anon_sym_AMP] = ACTIONS(3419),
    [anon_sym_this] = ACTIONS(3417),
    [anon_sym_scoped] = ACTIONS(3417),
    [anon_sym_base] = ACTIONS(3417),
    [anon_sym_var] = ACTIONS(3417),
    [sym_predefined_type] = ACTIONS(3417),
    [anon_sym_break] = ACTIONS(3417),
    [anon_sym_unchecked] = ACTIONS(3417),
    [anon_sym_continue] = ACTIONS(3417),
    [anon_sym_do] = ACTIONS(3417),
    [anon_sym_while] = ACTIONS(3417),
    [anon_sym_for] = ACTIONS(3417),
    [anon_sym_lock] = ACTIONS(3417),
    [anon_sym_yield] = ACTIONS(3417),
    [anon_sym_switch] = ACTIONS(3417),
    [anon_sym_default] = ACTIONS(3417),
    [anon_sym_throw] = ACTIONS(3417),
    [anon_sym_try] = ACTIONS(3417),
    [anon_sym_when] = ACTIONS(3417),
    [anon_sym_await] = ACTIONS(3417),
    [anon_sym_foreach] = ACTIONS(3417),
    [anon_sym_goto] = ACTIONS(3417),
    [anon_sym_if] = ACTIONS(3417),
    [anon_sym_DOT_DOT] = ACTIONS(3419),
    [anon_sym_from] = ACTIONS(3417),
    [anon_sym_into] = ACTIONS(3417),
    [anon_sym_join] = ACTIONS(3417),
    [anon_sym_on] = ACTIONS(3417),
    [anon_sym_equals] = ACTIONS(3417),
    [anon_sym_let] = ACTIONS(3417),
    [anon_sym_orderby] = ACTIONS(3417),
    [anon_sym_ascending] = ACTIONS(3417),
    [anon_sym_descending] = ACTIONS(3417),
    [anon_sym_group] = ACTIONS(3417),
    [anon_sym_by] = ACTIONS(3417),
    [anon_sym_select] = ACTIONS(3417),
    [anon_sym_stackalloc] = ACTIONS(3417),
    [anon_sym_sizeof] = ACTIONS(3417),
    [anon_sym_typeof] = ACTIONS(3417),
    [anon_sym___makeref] = ACTIONS(3417),
    [anon_sym___reftype] = ACTIONS(3417),
    [anon_sym___refvalue] = ACTIONS(3417),
    [sym_null_literal] = ACTIONS(3417),
    [anon_sym_SQUOTE] = ACTIONS(3419),
    [sym_integer_literal] = ACTIONS(3417),
    [sym_real_literal] = ACTIONS(3419),
    [anon_sym_DQUOTE] = ACTIONS(3419),
    [sym_verbatim_string_literal] = ACTIONS(3419),
    [aux_sym_preproc_if_token1] = ACTIONS(3419),
    [aux_sym_preproc_if_token3] = ACTIONS(3419),
    [aux_sym_preproc_else_token1] = ACTIONS(3419),
    [aux_sym_preproc_elif_token1] = ACTIONS(3419),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3419),
    [sym_interpolation_verbatim_start] = ACTIONS(3419),
    [sym_interpolation_raw_start] = ACTIONS(3419),
    [sym_raw_string_start] = ACTIONS(3419),
  },
  [2310] = {
    [sym_preproc_region] = STATE(2310),
    [sym_preproc_endregion] = STATE(2310),
    [sym_preproc_line] = STATE(2310),
    [sym_preproc_pragma] = STATE(2310),
    [sym_preproc_nullable] = STATE(2310),
    [sym_preproc_error] = STATE(2310),
    [sym_preproc_warning] = STATE(2310),
    [sym_preproc_define] = STATE(2310),
    [sym_preproc_undef] = STATE(2310),
    [sym__identifier_token] = ACTIONS(3421),
    [anon_sym_extern] = ACTIONS(3421),
    [anon_sym_alias] = ACTIONS(3421),
    [anon_sym_SEMI] = ACTIONS(3423),
    [anon_sym_global] = ACTIONS(3421),
    [anon_sym_using] = ACTIONS(3421),
    [anon_sym_unsafe] = ACTIONS(3421),
    [anon_sym_static] = ACTIONS(3421),
    [anon_sym_LBRACK] = ACTIONS(3423),
    [anon_sym_LPAREN] = ACTIONS(3423),
    [anon_sym_return] = ACTIONS(3421),
    [anon_sym_namespace] = ACTIONS(3421),
    [anon_sym_class] = ACTIONS(3421),
    [anon_sym_ref] = ACTIONS(3421),
    [anon_sym_struct] = ACTIONS(3421),
    [anon_sym_enum] = ACTIONS(3421),
    [anon_sym_LBRACE] = ACTIONS(3423),
    [anon_sym_interface] = ACTIONS(3421),
    [anon_sym_delegate] = ACTIONS(3421),
    [anon_sym_record] = ACTIONS(3421),
    [anon_sym_abstract] = ACTIONS(3421),
    [anon_sym_async] = ACTIONS(3421),
    [anon_sym_const] = ACTIONS(3421),
    [anon_sym_file] = ACTIONS(3421),
    [anon_sym_fixed] = ACTIONS(3421),
    [anon_sym_internal] = ACTIONS(3421),
    [anon_sym_new] = ACTIONS(3421),
    [anon_sym_override] = ACTIONS(3421),
    [anon_sym_partial] = ACTIONS(3421),
    [anon_sym_private] = ACTIONS(3421),
    [anon_sym_protected] = ACTIONS(3421),
    [anon_sym_public] = ACTIONS(3421),
    [anon_sym_readonly] = ACTIONS(3421),
    [anon_sym_required] = ACTIONS(3421),
    [anon_sym_sealed] = ACTIONS(3421),
    [anon_sym_virtual] = ACTIONS(3421),
    [anon_sym_volatile] = ACTIONS(3421),
    [anon_sym_where] = ACTIONS(3421),
    [anon_sym_notnull] = ACTIONS(3421),
    [anon_sym_unmanaged] = ACTIONS(3421),
    [anon_sym_checked] = ACTIONS(3421),
    [anon_sym_BANG] = ACTIONS(3423),
    [anon_sym_TILDE] = ACTIONS(3423),
    [anon_sym_PLUS_PLUS] = ACTIONS(3423),
    [anon_sym_DASH_DASH] = ACTIONS(3423),
    [anon_sym_true] = ACTIONS(3421),
    [anon_sym_false] = ACTIONS(3421),
    [anon_sym_PLUS] = ACTIONS(3421),
    [anon_sym_DASH] = ACTIONS(3421),
    [anon_sym_STAR] = ACTIONS(3423),
    [anon_sym_CARET] = ACTIONS(3423),
    [anon_sym_AMP] = ACTIONS(3423),
    [anon_sym_this] = ACTIONS(3421),
    [anon_sym_scoped] = ACTIONS(3421),
    [anon_sym_base] = ACTIONS(3421),
    [anon_sym_var] = ACTIONS(3421),
    [sym_predefined_type] = ACTIONS(3421),
    [anon_sym_break] = ACTIONS(3421),
    [anon_sym_unchecked] = ACTIONS(3421),
    [anon_sym_continue] = ACTIONS(3421),
    [anon_sym_do] = ACTIONS(3421),
    [anon_sym_while] = ACTIONS(3421),
    [anon_sym_for] = ACTIONS(3421),
    [anon_sym_lock] = ACTIONS(3421),
    [anon_sym_yield] = ACTIONS(3421),
    [anon_sym_switch] = ACTIONS(3421),
    [anon_sym_default] = ACTIONS(3421),
    [anon_sym_throw] = ACTIONS(3421),
    [anon_sym_try] = ACTIONS(3421),
    [anon_sym_when] = ACTIONS(3421),
    [anon_sym_await] = ACTIONS(3421),
    [anon_sym_foreach] = ACTIONS(3421),
    [anon_sym_goto] = ACTIONS(3421),
    [anon_sym_if] = ACTIONS(3421),
    [anon_sym_DOT_DOT] = ACTIONS(3423),
    [anon_sym_from] = ACTIONS(3421),
    [anon_sym_into] = ACTIONS(3421),
    [anon_sym_join] = ACTIONS(3421),
    [anon_sym_on] = ACTIONS(3421),
    [anon_sym_equals] = ACTIONS(3421),
    [anon_sym_let] = ACTIONS(3421),
    [anon_sym_orderby] = ACTIONS(3421),
    [anon_sym_ascending] = ACTIONS(3421),
    [anon_sym_descending] = ACTIONS(3421),
    [anon_sym_group] = ACTIONS(3421),
    [anon_sym_by] = ACTIONS(3421),
    [anon_sym_select] = ACTIONS(3421),
    [anon_sym_stackalloc] = ACTIONS(3421),
    [anon_sym_sizeof] = ACTIONS(3421),
    [anon_sym_typeof] = ACTIONS(3421),
    [anon_sym___makeref] = ACTIONS(3421),
    [anon_sym___reftype] = ACTIONS(3421),
    [anon_sym___refvalue] = ACTIONS(3421),
    [sym_null_literal] = ACTIONS(3421),
    [anon_sym_SQUOTE] = ACTIONS(3423),
    [sym_integer_literal] = ACTIONS(3421),
    [sym_real_literal] = ACTIONS(3423),
    [anon_sym_DQUOTE] = ACTIONS(3423),
    [sym_verbatim_string_literal] = ACTIONS(3423),
    [aux_sym_preproc_if_token1] = ACTIONS(3423),
    [aux_sym_preproc_if_token3] = ACTIONS(3423),
    [aux_sym_preproc_else_token1] = ACTIONS(3423),
    [aux_sym_preproc_elif_token1] = ACTIONS(3423),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3423),
    [sym_interpolation_verbatim_start] = ACTIONS(3423),
    [sym_interpolation_raw_start] = ACTIONS(3423),
    [sym_raw_string_start] = ACTIONS(3423),
  },
  [2311] = {
    [sym_preproc_region] = STATE(2311),
    [sym_preproc_endregion] = STATE(2311),
    [sym_preproc_line] = STATE(2311),
    [sym_preproc_pragma] = STATE(2311),
    [sym_preproc_nullable] = STATE(2311),
    [sym_preproc_error] = STATE(2311),
    [sym_preproc_warning] = STATE(2311),
    [sym_preproc_define] = STATE(2311),
    [sym_preproc_undef] = STATE(2311),
    [sym__identifier_token] = ACTIONS(3425),
    [anon_sym_extern] = ACTIONS(3425),
    [anon_sym_alias] = ACTIONS(3425),
    [anon_sym_SEMI] = ACTIONS(3427),
    [anon_sym_global] = ACTIONS(3425),
    [anon_sym_using] = ACTIONS(3425),
    [anon_sym_unsafe] = ACTIONS(3425),
    [anon_sym_static] = ACTIONS(3425),
    [anon_sym_LBRACK] = ACTIONS(3427),
    [anon_sym_LPAREN] = ACTIONS(3427),
    [anon_sym_return] = ACTIONS(3425),
    [anon_sym_namespace] = ACTIONS(3425),
    [anon_sym_class] = ACTIONS(3425),
    [anon_sym_ref] = ACTIONS(3425),
    [anon_sym_struct] = ACTIONS(3425),
    [anon_sym_enum] = ACTIONS(3425),
    [anon_sym_LBRACE] = ACTIONS(3427),
    [anon_sym_interface] = ACTIONS(3425),
    [anon_sym_delegate] = ACTIONS(3425),
    [anon_sym_record] = ACTIONS(3425),
    [anon_sym_abstract] = ACTIONS(3425),
    [anon_sym_async] = ACTIONS(3425),
    [anon_sym_const] = ACTIONS(3425),
    [anon_sym_file] = ACTIONS(3425),
    [anon_sym_fixed] = ACTIONS(3425),
    [anon_sym_internal] = ACTIONS(3425),
    [anon_sym_new] = ACTIONS(3425),
    [anon_sym_override] = ACTIONS(3425),
    [anon_sym_partial] = ACTIONS(3425),
    [anon_sym_private] = ACTIONS(3425),
    [anon_sym_protected] = ACTIONS(3425),
    [anon_sym_public] = ACTIONS(3425),
    [anon_sym_readonly] = ACTIONS(3425),
    [anon_sym_required] = ACTIONS(3425),
    [anon_sym_sealed] = ACTIONS(3425),
    [anon_sym_virtual] = ACTIONS(3425),
    [anon_sym_volatile] = ACTIONS(3425),
    [anon_sym_where] = ACTIONS(3425),
    [anon_sym_notnull] = ACTIONS(3425),
    [anon_sym_unmanaged] = ACTIONS(3425),
    [anon_sym_checked] = ACTIONS(3425),
    [anon_sym_BANG] = ACTIONS(3427),
    [anon_sym_TILDE] = ACTIONS(3427),
    [anon_sym_PLUS_PLUS] = ACTIONS(3427),
    [anon_sym_DASH_DASH] = ACTIONS(3427),
    [anon_sym_true] = ACTIONS(3425),
    [anon_sym_false] = ACTIONS(3425),
    [anon_sym_PLUS] = ACTIONS(3425),
    [anon_sym_DASH] = ACTIONS(3425),
    [anon_sym_STAR] = ACTIONS(3427),
    [anon_sym_CARET] = ACTIONS(3427),
    [anon_sym_AMP] = ACTIONS(3427),
    [anon_sym_this] = ACTIONS(3425),
    [anon_sym_scoped] = ACTIONS(3425),
    [anon_sym_base] = ACTIONS(3425),
    [anon_sym_var] = ACTIONS(3425),
    [sym_predefined_type] = ACTIONS(3425),
    [anon_sym_break] = ACTIONS(3425),
    [anon_sym_unchecked] = ACTIONS(3425),
    [anon_sym_continue] = ACTIONS(3425),
    [anon_sym_do] = ACTIONS(3425),
    [anon_sym_while] = ACTIONS(3425),
    [anon_sym_for] = ACTIONS(3425),
    [anon_sym_lock] = ACTIONS(3425),
    [anon_sym_yield] = ACTIONS(3425),
    [anon_sym_switch] = ACTIONS(3425),
    [anon_sym_default] = ACTIONS(3425),
    [anon_sym_throw] = ACTIONS(3425),
    [anon_sym_try] = ACTIONS(3425),
    [anon_sym_when] = ACTIONS(3425),
    [anon_sym_await] = ACTIONS(3425),
    [anon_sym_foreach] = ACTIONS(3425),
    [anon_sym_goto] = ACTIONS(3425),
    [anon_sym_if] = ACTIONS(3425),
    [anon_sym_DOT_DOT] = ACTIONS(3427),
    [anon_sym_from] = ACTIONS(3425),
    [anon_sym_into] = ACTIONS(3425),
    [anon_sym_join] = ACTIONS(3425),
    [anon_sym_on] = ACTIONS(3425),
    [anon_sym_equals] = ACTIONS(3425),
    [anon_sym_let] = ACTIONS(3425),
    [anon_sym_orderby] = ACTIONS(3425),
    [anon_sym_ascending] = ACTIONS(3425),
    [anon_sym_descending] = ACTIONS(3425),
    [anon_sym_group] = ACTIONS(3425),
    [anon_sym_by] = ACTIONS(3425),
    [anon_sym_select] = ACTIONS(3425),
    [anon_sym_stackalloc] = ACTIONS(3425),
    [anon_sym_sizeof] = ACTIONS(3425),
    [anon_sym_typeof] = ACTIONS(3425),
    [anon_sym___makeref] = ACTIONS(3425),
    [anon_sym___reftype] = ACTIONS(3425),
    [anon_sym___refvalue] = ACTIONS(3425),
    [sym_null_literal] = ACTIONS(3425),
    [anon_sym_SQUOTE] = ACTIONS(3427),
    [sym_integer_literal] = ACTIONS(3425),
    [sym_real_literal] = ACTIONS(3427),
    [anon_sym_DQUOTE] = ACTIONS(3427),
    [sym_verbatim_string_literal] = ACTIONS(3427),
    [aux_sym_preproc_if_token1] = ACTIONS(3427),
    [aux_sym_preproc_if_token3] = ACTIONS(3427),
    [aux_sym_preproc_else_token1] = ACTIONS(3427),
    [aux_sym_preproc_elif_token1] = ACTIONS(3427),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3427),
    [sym_interpolation_verbatim_start] = ACTIONS(3427),
    [sym_interpolation_raw_start] = ACTIONS(3427),
    [sym_raw_string_start] = ACTIONS(3427),
  },
  [2312] = {
    [sym_preproc_region] = STATE(2312),
    [sym_preproc_endregion] = STATE(2312),
    [sym_preproc_line] = STATE(2312),
    [sym_preproc_pragma] = STATE(2312),
    [sym_preproc_nullable] = STATE(2312),
    [sym_preproc_error] = STATE(2312),
    [sym_preproc_warning] = STATE(2312),
    [sym_preproc_define] = STATE(2312),
    [sym_preproc_undef] = STATE(2312),
    [sym__identifier_token] = ACTIONS(3429),
    [anon_sym_extern] = ACTIONS(3429),
    [anon_sym_alias] = ACTIONS(3429),
    [anon_sym_SEMI] = ACTIONS(3431),
    [anon_sym_global] = ACTIONS(3429),
    [anon_sym_using] = ACTIONS(3429),
    [anon_sym_unsafe] = ACTIONS(3429),
    [anon_sym_static] = ACTIONS(3429),
    [anon_sym_LBRACK] = ACTIONS(3431),
    [anon_sym_LPAREN] = ACTIONS(3431),
    [anon_sym_return] = ACTIONS(3429),
    [anon_sym_namespace] = ACTIONS(3429),
    [anon_sym_class] = ACTIONS(3429),
    [anon_sym_ref] = ACTIONS(3429),
    [anon_sym_struct] = ACTIONS(3429),
    [anon_sym_enum] = ACTIONS(3429),
    [anon_sym_LBRACE] = ACTIONS(3431),
    [anon_sym_interface] = ACTIONS(3429),
    [anon_sym_delegate] = ACTIONS(3429),
    [anon_sym_record] = ACTIONS(3429),
    [anon_sym_abstract] = ACTIONS(3429),
    [anon_sym_async] = ACTIONS(3429),
    [anon_sym_const] = ACTIONS(3429),
    [anon_sym_file] = ACTIONS(3429),
    [anon_sym_fixed] = ACTIONS(3429),
    [anon_sym_internal] = ACTIONS(3429),
    [anon_sym_new] = ACTIONS(3429),
    [anon_sym_override] = ACTIONS(3429),
    [anon_sym_partial] = ACTIONS(3429),
    [anon_sym_private] = ACTIONS(3429),
    [anon_sym_protected] = ACTIONS(3429),
    [anon_sym_public] = ACTIONS(3429),
    [anon_sym_readonly] = ACTIONS(3429),
    [anon_sym_required] = ACTIONS(3429),
    [anon_sym_sealed] = ACTIONS(3429),
    [anon_sym_virtual] = ACTIONS(3429),
    [anon_sym_volatile] = ACTIONS(3429),
    [anon_sym_where] = ACTIONS(3429),
    [anon_sym_notnull] = ACTIONS(3429),
    [anon_sym_unmanaged] = ACTIONS(3429),
    [anon_sym_checked] = ACTIONS(3429),
    [anon_sym_BANG] = ACTIONS(3431),
    [anon_sym_TILDE] = ACTIONS(3431),
    [anon_sym_PLUS_PLUS] = ACTIONS(3431),
    [anon_sym_DASH_DASH] = ACTIONS(3431),
    [anon_sym_true] = ACTIONS(3429),
    [anon_sym_false] = ACTIONS(3429),
    [anon_sym_PLUS] = ACTIONS(3429),
    [anon_sym_DASH] = ACTIONS(3429),
    [anon_sym_STAR] = ACTIONS(3431),
    [anon_sym_CARET] = ACTIONS(3431),
    [anon_sym_AMP] = ACTIONS(3431),
    [anon_sym_this] = ACTIONS(3429),
    [anon_sym_scoped] = ACTIONS(3429),
    [anon_sym_base] = ACTIONS(3429),
    [anon_sym_var] = ACTIONS(3429),
    [sym_predefined_type] = ACTIONS(3429),
    [anon_sym_break] = ACTIONS(3429),
    [anon_sym_unchecked] = ACTIONS(3429),
    [anon_sym_continue] = ACTIONS(3429),
    [anon_sym_do] = ACTIONS(3429),
    [anon_sym_while] = ACTIONS(3429),
    [anon_sym_for] = ACTIONS(3429),
    [anon_sym_lock] = ACTIONS(3429),
    [anon_sym_yield] = ACTIONS(3429),
    [anon_sym_switch] = ACTIONS(3429),
    [anon_sym_default] = ACTIONS(3429),
    [anon_sym_throw] = ACTIONS(3429),
    [anon_sym_try] = ACTIONS(3429),
    [anon_sym_when] = ACTIONS(3429),
    [anon_sym_await] = ACTIONS(3429),
    [anon_sym_foreach] = ACTIONS(3429),
    [anon_sym_goto] = ACTIONS(3429),
    [anon_sym_if] = ACTIONS(3429),
    [anon_sym_DOT_DOT] = ACTIONS(3431),
    [anon_sym_from] = ACTIONS(3429),
    [anon_sym_into] = ACTIONS(3429),
    [anon_sym_join] = ACTIONS(3429),
    [anon_sym_on] = ACTIONS(3429),
    [anon_sym_equals] = ACTIONS(3429),
    [anon_sym_let] = ACTIONS(3429),
    [anon_sym_orderby] = ACTIONS(3429),
    [anon_sym_ascending] = ACTIONS(3429),
    [anon_sym_descending] = ACTIONS(3429),
    [anon_sym_group] = ACTIONS(3429),
    [anon_sym_by] = ACTIONS(3429),
    [anon_sym_select] = ACTIONS(3429),
    [anon_sym_stackalloc] = ACTIONS(3429),
    [anon_sym_sizeof] = ACTIONS(3429),
    [anon_sym_typeof] = ACTIONS(3429),
    [anon_sym___makeref] = ACTIONS(3429),
    [anon_sym___reftype] = ACTIONS(3429),
    [anon_sym___refvalue] = ACTIONS(3429),
    [sym_null_literal] = ACTIONS(3429),
    [anon_sym_SQUOTE] = ACTIONS(3431),
    [sym_integer_literal] = ACTIONS(3429),
    [sym_real_literal] = ACTIONS(3431),
    [anon_sym_DQUOTE] = ACTIONS(3431),
    [sym_verbatim_string_literal] = ACTIONS(3431),
    [aux_sym_preproc_if_token1] = ACTIONS(3431),
    [aux_sym_preproc_if_token3] = ACTIONS(3431),
    [aux_sym_preproc_else_token1] = ACTIONS(3431),
    [aux_sym_preproc_elif_token1] = ACTIONS(3431),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3431),
    [sym_interpolation_verbatim_start] = ACTIONS(3431),
    [sym_interpolation_raw_start] = ACTIONS(3431),
    [sym_raw_string_start] = ACTIONS(3431),
  },
  [2313] = {
    [sym_preproc_region] = STATE(2313),
    [sym_preproc_endregion] = STATE(2313),
    [sym_preproc_line] = STATE(2313),
    [sym_preproc_pragma] = STATE(2313),
    [sym_preproc_nullable] = STATE(2313),
    [sym_preproc_error] = STATE(2313),
    [sym_preproc_warning] = STATE(2313),
    [sym_preproc_define] = STATE(2313),
    [sym_preproc_undef] = STATE(2313),
    [sym__identifier_token] = ACTIONS(3433),
    [anon_sym_extern] = ACTIONS(3433),
    [anon_sym_alias] = ACTIONS(3433),
    [anon_sym_SEMI] = ACTIONS(3435),
    [anon_sym_global] = ACTIONS(3433),
    [anon_sym_using] = ACTIONS(3433),
    [anon_sym_unsafe] = ACTIONS(3433),
    [anon_sym_static] = ACTIONS(3433),
    [anon_sym_LBRACK] = ACTIONS(3435),
    [anon_sym_LPAREN] = ACTIONS(3435),
    [anon_sym_return] = ACTIONS(3433),
    [anon_sym_namespace] = ACTIONS(3433),
    [anon_sym_class] = ACTIONS(3433),
    [anon_sym_ref] = ACTIONS(3433),
    [anon_sym_struct] = ACTIONS(3433),
    [anon_sym_enum] = ACTIONS(3433),
    [anon_sym_LBRACE] = ACTIONS(3435),
    [anon_sym_interface] = ACTIONS(3433),
    [anon_sym_delegate] = ACTIONS(3433),
    [anon_sym_record] = ACTIONS(3433),
    [anon_sym_abstract] = ACTIONS(3433),
    [anon_sym_async] = ACTIONS(3433),
    [anon_sym_const] = ACTIONS(3433),
    [anon_sym_file] = ACTIONS(3433),
    [anon_sym_fixed] = ACTIONS(3433),
    [anon_sym_internal] = ACTIONS(3433),
    [anon_sym_new] = ACTIONS(3433),
    [anon_sym_override] = ACTIONS(3433),
    [anon_sym_partial] = ACTIONS(3433),
    [anon_sym_private] = ACTIONS(3433),
    [anon_sym_protected] = ACTIONS(3433),
    [anon_sym_public] = ACTIONS(3433),
    [anon_sym_readonly] = ACTIONS(3433),
    [anon_sym_required] = ACTIONS(3433),
    [anon_sym_sealed] = ACTIONS(3433),
    [anon_sym_virtual] = ACTIONS(3433),
    [anon_sym_volatile] = ACTIONS(3433),
    [anon_sym_where] = ACTIONS(3433),
    [anon_sym_notnull] = ACTIONS(3433),
    [anon_sym_unmanaged] = ACTIONS(3433),
    [anon_sym_checked] = ACTIONS(3433),
    [anon_sym_BANG] = ACTIONS(3435),
    [anon_sym_TILDE] = ACTIONS(3435),
    [anon_sym_PLUS_PLUS] = ACTIONS(3435),
    [anon_sym_DASH_DASH] = ACTIONS(3435),
    [anon_sym_true] = ACTIONS(3433),
    [anon_sym_false] = ACTIONS(3433),
    [anon_sym_PLUS] = ACTIONS(3433),
    [anon_sym_DASH] = ACTIONS(3433),
    [anon_sym_STAR] = ACTIONS(3435),
    [anon_sym_CARET] = ACTIONS(3435),
    [anon_sym_AMP] = ACTIONS(3435),
    [anon_sym_this] = ACTIONS(3433),
    [anon_sym_scoped] = ACTIONS(3433),
    [anon_sym_base] = ACTIONS(3433),
    [anon_sym_var] = ACTIONS(3433),
    [sym_predefined_type] = ACTIONS(3433),
    [anon_sym_break] = ACTIONS(3433),
    [anon_sym_unchecked] = ACTIONS(3433),
    [anon_sym_continue] = ACTIONS(3433),
    [anon_sym_do] = ACTIONS(3433),
    [anon_sym_while] = ACTIONS(3433),
    [anon_sym_for] = ACTIONS(3433),
    [anon_sym_lock] = ACTIONS(3433),
    [anon_sym_yield] = ACTIONS(3433),
    [anon_sym_switch] = ACTIONS(3433),
    [anon_sym_default] = ACTIONS(3433),
    [anon_sym_throw] = ACTIONS(3433),
    [anon_sym_try] = ACTIONS(3433),
    [anon_sym_when] = ACTIONS(3433),
    [anon_sym_await] = ACTIONS(3433),
    [anon_sym_foreach] = ACTIONS(3433),
    [anon_sym_goto] = ACTIONS(3433),
    [anon_sym_if] = ACTIONS(3433),
    [anon_sym_DOT_DOT] = ACTIONS(3435),
    [anon_sym_from] = ACTIONS(3433),
    [anon_sym_into] = ACTIONS(3433),
    [anon_sym_join] = ACTIONS(3433),
    [anon_sym_on] = ACTIONS(3433),
    [anon_sym_equals] = ACTIONS(3433),
    [anon_sym_let] = ACTIONS(3433),
    [anon_sym_orderby] = ACTIONS(3433),
    [anon_sym_ascending] = ACTIONS(3433),
    [anon_sym_descending] = ACTIONS(3433),
    [anon_sym_group] = ACTIONS(3433),
    [anon_sym_by] = ACTIONS(3433),
    [anon_sym_select] = ACTIONS(3433),
    [anon_sym_stackalloc] = ACTIONS(3433),
    [anon_sym_sizeof] = ACTIONS(3433),
    [anon_sym_typeof] = ACTIONS(3433),
    [anon_sym___makeref] = ACTIONS(3433),
    [anon_sym___reftype] = ACTIONS(3433),
    [anon_sym___refvalue] = ACTIONS(3433),
    [sym_null_literal] = ACTIONS(3433),
    [anon_sym_SQUOTE] = ACTIONS(3435),
    [sym_integer_literal] = ACTIONS(3433),
    [sym_real_literal] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3435),
    [sym_verbatim_string_literal] = ACTIONS(3435),
    [aux_sym_preproc_if_token1] = ACTIONS(3435),
    [aux_sym_preproc_if_token3] = ACTIONS(3435),
    [aux_sym_preproc_else_token1] = ACTIONS(3435),
    [aux_sym_preproc_elif_token1] = ACTIONS(3435),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3435),
    [sym_interpolation_verbatim_start] = ACTIONS(3435),
    [sym_interpolation_raw_start] = ACTIONS(3435),
    [sym_raw_string_start] = ACTIONS(3435),
  },
  [2314] = {
    [sym_preproc_region] = STATE(2314),
    [sym_preproc_endregion] = STATE(2314),
    [sym_preproc_line] = STATE(2314),
    [sym_preproc_pragma] = STATE(2314),
    [sym_preproc_nullable] = STATE(2314),
    [sym_preproc_error] = STATE(2314),
    [sym_preproc_warning] = STATE(2314),
    [sym_preproc_define] = STATE(2314),
    [sym_preproc_undef] = STATE(2314),
    [sym__identifier_token] = ACTIONS(3437),
    [anon_sym_extern] = ACTIONS(3437),
    [anon_sym_alias] = ACTIONS(3437),
    [anon_sym_SEMI] = ACTIONS(3439),
    [anon_sym_global] = ACTIONS(3437),
    [anon_sym_using] = ACTIONS(3437),
    [anon_sym_unsafe] = ACTIONS(3437),
    [anon_sym_static] = ACTIONS(3437),
    [anon_sym_LBRACK] = ACTIONS(3439),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_return] = ACTIONS(3437),
    [anon_sym_namespace] = ACTIONS(3437),
    [anon_sym_class] = ACTIONS(3437),
    [anon_sym_ref] = ACTIONS(3437),
    [anon_sym_struct] = ACTIONS(3437),
    [anon_sym_enum] = ACTIONS(3437),
    [anon_sym_LBRACE] = ACTIONS(3439),
    [anon_sym_interface] = ACTIONS(3437),
    [anon_sym_delegate] = ACTIONS(3437),
    [anon_sym_record] = ACTIONS(3437),
    [anon_sym_abstract] = ACTIONS(3437),
    [anon_sym_async] = ACTIONS(3437),
    [anon_sym_const] = ACTIONS(3437),
    [anon_sym_file] = ACTIONS(3437),
    [anon_sym_fixed] = ACTIONS(3437),
    [anon_sym_internal] = ACTIONS(3437),
    [anon_sym_new] = ACTIONS(3437),
    [anon_sym_override] = ACTIONS(3437),
    [anon_sym_partial] = ACTIONS(3437),
    [anon_sym_private] = ACTIONS(3437),
    [anon_sym_protected] = ACTIONS(3437),
    [anon_sym_public] = ACTIONS(3437),
    [anon_sym_readonly] = ACTIONS(3437),
    [anon_sym_required] = ACTIONS(3437),
    [anon_sym_sealed] = ACTIONS(3437),
    [anon_sym_virtual] = ACTIONS(3437),
    [anon_sym_volatile] = ACTIONS(3437),
    [anon_sym_where] = ACTIONS(3437),
    [anon_sym_notnull] = ACTIONS(3437),
    [anon_sym_unmanaged] = ACTIONS(3437),
    [anon_sym_checked] = ACTIONS(3437),
    [anon_sym_BANG] = ACTIONS(3439),
    [anon_sym_TILDE] = ACTIONS(3439),
    [anon_sym_PLUS_PLUS] = ACTIONS(3439),
    [anon_sym_DASH_DASH] = ACTIONS(3439),
    [anon_sym_true] = ACTIONS(3437),
    [anon_sym_false] = ACTIONS(3437),
    [anon_sym_PLUS] = ACTIONS(3437),
    [anon_sym_DASH] = ACTIONS(3437),
    [anon_sym_STAR] = ACTIONS(3439),
    [anon_sym_CARET] = ACTIONS(3439),
    [anon_sym_AMP] = ACTIONS(3439),
    [anon_sym_this] = ACTIONS(3437),
    [anon_sym_scoped] = ACTIONS(3437),
    [anon_sym_base] = ACTIONS(3437),
    [anon_sym_var] = ACTIONS(3437),
    [sym_predefined_type] = ACTIONS(3437),
    [anon_sym_break] = ACTIONS(3437),
    [anon_sym_unchecked] = ACTIONS(3437),
    [anon_sym_continue] = ACTIONS(3437),
    [anon_sym_do] = ACTIONS(3437),
    [anon_sym_while] = ACTIONS(3437),
    [anon_sym_for] = ACTIONS(3437),
    [anon_sym_lock] = ACTIONS(3437),
    [anon_sym_yield] = ACTIONS(3437),
    [anon_sym_switch] = ACTIONS(3437),
    [anon_sym_default] = ACTIONS(3437),
    [anon_sym_throw] = ACTIONS(3437),
    [anon_sym_try] = ACTIONS(3437),
    [anon_sym_when] = ACTIONS(3437),
    [anon_sym_await] = ACTIONS(3437),
    [anon_sym_foreach] = ACTIONS(3437),
    [anon_sym_goto] = ACTIONS(3437),
    [anon_sym_if] = ACTIONS(3437),
    [anon_sym_DOT_DOT] = ACTIONS(3439),
    [anon_sym_from] = ACTIONS(3437),
    [anon_sym_into] = ACTIONS(3437),
    [anon_sym_join] = ACTIONS(3437),
    [anon_sym_on] = ACTIONS(3437),
    [anon_sym_equals] = ACTIONS(3437),
    [anon_sym_let] = ACTIONS(3437),
    [anon_sym_orderby] = ACTIONS(3437),
    [anon_sym_ascending] = ACTIONS(3437),
    [anon_sym_descending] = ACTIONS(3437),
    [anon_sym_group] = ACTIONS(3437),
    [anon_sym_by] = ACTIONS(3437),
    [anon_sym_select] = ACTIONS(3437),
    [anon_sym_stackalloc] = ACTIONS(3437),
    [anon_sym_sizeof] = ACTIONS(3437),
    [anon_sym_typeof] = ACTIONS(3437),
    [anon_sym___makeref] = ACTIONS(3437),
    [anon_sym___reftype] = ACTIONS(3437),
    [anon_sym___refvalue] = ACTIONS(3437),
    [sym_null_literal] = ACTIONS(3437),
    [anon_sym_SQUOTE] = ACTIONS(3439),
    [sym_integer_literal] = ACTIONS(3437),
    [sym_real_literal] = ACTIONS(3439),
    [anon_sym_DQUOTE] = ACTIONS(3439),
    [sym_verbatim_string_literal] = ACTIONS(3439),
    [aux_sym_preproc_if_token1] = ACTIONS(3439),
    [aux_sym_preproc_if_token3] = ACTIONS(3439),
    [aux_sym_preproc_else_token1] = ACTIONS(3439),
    [aux_sym_preproc_elif_token1] = ACTIONS(3439),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3439),
    [sym_interpolation_verbatim_start] = ACTIONS(3439),
    [sym_interpolation_raw_start] = ACTIONS(3439),
    [sym_raw_string_start] = ACTIONS(3439),
  },
  [2315] = {
    [sym_preproc_region] = STATE(2315),
    [sym_preproc_endregion] = STATE(2315),
    [sym_preproc_line] = STATE(2315),
    [sym_preproc_pragma] = STATE(2315),
    [sym_preproc_nullable] = STATE(2315),
    [sym_preproc_error] = STATE(2315),
    [sym_preproc_warning] = STATE(2315),
    [sym_preproc_define] = STATE(2315),
    [sym_preproc_undef] = STATE(2315),
    [sym__identifier_token] = ACTIONS(3441),
    [anon_sym_extern] = ACTIONS(3441),
    [anon_sym_alias] = ACTIONS(3441),
    [anon_sym_SEMI] = ACTIONS(3443),
    [anon_sym_global] = ACTIONS(3441),
    [anon_sym_using] = ACTIONS(3441),
    [anon_sym_unsafe] = ACTIONS(3441),
    [anon_sym_static] = ACTIONS(3441),
    [anon_sym_LBRACK] = ACTIONS(3443),
    [anon_sym_LPAREN] = ACTIONS(3443),
    [anon_sym_return] = ACTIONS(3441),
    [anon_sym_namespace] = ACTIONS(3441),
    [anon_sym_class] = ACTIONS(3441),
    [anon_sym_ref] = ACTIONS(3441),
    [anon_sym_struct] = ACTIONS(3441),
    [anon_sym_enum] = ACTIONS(3441),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_interface] = ACTIONS(3441),
    [anon_sym_delegate] = ACTIONS(3441),
    [anon_sym_record] = ACTIONS(3441),
    [anon_sym_abstract] = ACTIONS(3441),
    [anon_sym_async] = ACTIONS(3441),
    [anon_sym_const] = ACTIONS(3441),
    [anon_sym_file] = ACTIONS(3441),
    [anon_sym_fixed] = ACTIONS(3441),
    [anon_sym_internal] = ACTIONS(3441),
    [anon_sym_new] = ACTIONS(3441),
    [anon_sym_override] = ACTIONS(3441),
    [anon_sym_partial] = ACTIONS(3441),
    [anon_sym_private] = ACTIONS(3441),
    [anon_sym_protected] = ACTIONS(3441),
    [anon_sym_public] = ACTIONS(3441),
    [anon_sym_readonly] = ACTIONS(3441),
    [anon_sym_required] = ACTIONS(3441),
    [anon_sym_sealed] = ACTIONS(3441),
    [anon_sym_virtual] = ACTIONS(3441),
    [anon_sym_volatile] = ACTIONS(3441),
    [anon_sym_where] = ACTIONS(3441),
    [anon_sym_notnull] = ACTIONS(3441),
    [anon_sym_unmanaged] = ACTIONS(3441),
    [anon_sym_checked] = ACTIONS(3441),
    [anon_sym_BANG] = ACTIONS(3443),
    [anon_sym_TILDE] = ACTIONS(3443),
    [anon_sym_PLUS_PLUS] = ACTIONS(3443),
    [anon_sym_DASH_DASH] = ACTIONS(3443),
    [anon_sym_true] = ACTIONS(3441),
    [anon_sym_false] = ACTIONS(3441),
    [anon_sym_PLUS] = ACTIONS(3441),
    [anon_sym_DASH] = ACTIONS(3441),
    [anon_sym_STAR] = ACTIONS(3443),
    [anon_sym_CARET] = ACTIONS(3443),
    [anon_sym_AMP] = ACTIONS(3443),
    [anon_sym_this] = ACTIONS(3441),
    [anon_sym_scoped] = ACTIONS(3441),
    [anon_sym_base] = ACTIONS(3441),
    [anon_sym_var] = ACTIONS(3441),
    [sym_predefined_type] = ACTIONS(3441),
    [anon_sym_break] = ACTIONS(3441),
    [anon_sym_unchecked] = ACTIONS(3441),
    [anon_sym_continue] = ACTIONS(3441),
    [anon_sym_do] = ACTIONS(3441),
    [anon_sym_while] = ACTIONS(3441),
    [anon_sym_for] = ACTIONS(3441),
    [anon_sym_lock] = ACTIONS(3441),
    [anon_sym_yield] = ACTIONS(3441),
    [anon_sym_switch] = ACTIONS(3441),
    [anon_sym_default] = ACTIONS(3441),
    [anon_sym_throw] = ACTIONS(3441),
    [anon_sym_try] = ACTIONS(3441),
    [anon_sym_when] = ACTIONS(3441),
    [anon_sym_await] = ACTIONS(3441),
    [anon_sym_foreach] = ACTIONS(3441),
    [anon_sym_goto] = ACTIONS(3441),
    [anon_sym_if] = ACTIONS(3441),
    [anon_sym_DOT_DOT] = ACTIONS(3443),
    [anon_sym_from] = ACTIONS(3441),
    [anon_sym_into] = ACTIONS(3441),
    [anon_sym_join] = ACTIONS(3441),
    [anon_sym_on] = ACTIONS(3441),
    [anon_sym_equals] = ACTIONS(3441),
    [anon_sym_let] = ACTIONS(3441),
    [anon_sym_orderby] = ACTIONS(3441),
    [anon_sym_ascending] = ACTIONS(3441),
    [anon_sym_descending] = ACTIONS(3441),
    [anon_sym_group] = ACTIONS(3441),
    [anon_sym_by] = ACTIONS(3441),
    [anon_sym_select] = ACTIONS(3441),
    [anon_sym_stackalloc] = ACTIONS(3441),
    [anon_sym_sizeof] = ACTIONS(3441),
    [anon_sym_typeof] = ACTIONS(3441),
    [anon_sym___makeref] = ACTIONS(3441),
    [anon_sym___reftype] = ACTIONS(3441),
    [anon_sym___refvalue] = ACTIONS(3441),
    [sym_null_literal] = ACTIONS(3441),
    [anon_sym_SQUOTE] = ACTIONS(3443),
    [sym_integer_literal] = ACTIONS(3441),
    [sym_real_literal] = ACTIONS(3443),
    [anon_sym_DQUOTE] = ACTIONS(3443),
    [sym_verbatim_string_literal] = ACTIONS(3443),
    [aux_sym_preproc_if_token1] = ACTIONS(3443),
    [aux_sym_preproc_if_token3] = ACTIONS(3443),
    [aux_sym_preproc_else_token1] = ACTIONS(3443),
    [aux_sym_preproc_elif_token1] = ACTIONS(3443),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3443),
    [sym_interpolation_verbatim_start] = ACTIONS(3443),
    [sym_interpolation_raw_start] = ACTIONS(3443),
    [sym_raw_string_start] = ACTIONS(3443),
  },
  [2316] = {
    [sym_preproc_region] = STATE(2316),
    [sym_preproc_endregion] = STATE(2316),
    [sym_preproc_line] = STATE(2316),
    [sym_preproc_pragma] = STATE(2316),
    [sym_preproc_nullable] = STATE(2316),
    [sym_preproc_error] = STATE(2316),
    [sym_preproc_warning] = STATE(2316),
    [sym_preproc_define] = STATE(2316),
    [sym_preproc_undef] = STATE(2316),
    [sym__identifier_token] = ACTIONS(3445),
    [anon_sym_extern] = ACTIONS(3445),
    [anon_sym_alias] = ACTIONS(3445),
    [anon_sym_SEMI] = ACTIONS(3447),
    [anon_sym_global] = ACTIONS(3445),
    [anon_sym_using] = ACTIONS(3445),
    [anon_sym_unsafe] = ACTIONS(3445),
    [anon_sym_static] = ACTIONS(3445),
    [anon_sym_LBRACK] = ACTIONS(3447),
    [anon_sym_LPAREN] = ACTIONS(3447),
    [anon_sym_return] = ACTIONS(3445),
    [anon_sym_namespace] = ACTIONS(3445),
    [anon_sym_class] = ACTIONS(3445),
    [anon_sym_ref] = ACTIONS(3445),
    [anon_sym_struct] = ACTIONS(3445),
    [anon_sym_enum] = ACTIONS(3445),
    [anon_sym_LBRACE] = ACTIONS(3447),
    [anon_sym_interface] = ACTIONS(3445),
    [anon_sym_delegate] = ACTIONS(3445),
    [anon_sym_record] = ACTIONS(3445),
    [anon_sym_abstract] = ACTIONS(3445),
    [anon_sym_async] = ACTIONS(3445),
    [anon_sym_const] = ACTIONS(3445),
    [anon_sym_file] = ACTIONS(3445),
    [anon_sym_fixed] = ACTIONS(3445),
    [anon_sym_internal] = ACTIONS(3445),
    [anon_sym_new] = ACTIONS(3445),
    [anon_sym_override] = ACTIONS(3445),
    [anon_sym_partial] = ACTIONS(3445),
    [anon_sym_private] = ACTIONS(3445),
    [anon_sym_protected] = ACTIONS(3445),
    [anon_sym_public] = ACTIONS(3445),
    [anon_sym_readonly] = ACTIONS(3445),
    [anon_sym_required] = ACTIONS(3445),
    [anon_sym_sealed] = ACTIONS(3445),
    [anon_sym_virtual] = ACTIONS(3445),
    [anon_sym_volatile] = ACTIONS(3445),
    [anon_sym_where] = ACTIONS(3445),
    [anon_sym_notnull] = ACTIONS(3445),
    [anon_sym_unmanaged] = ACTIONS(3445),
    [anon_sym_checked] = ACTIONS(3445),
    [anon_sym_BANG] = ACTIONS(3447),
    [anon_sym_TILDE] = ACTIONS(3447),
    [anon_sym_PLUS_PLUS] = ACTIONS(3447),
    [anon_sym_DASH_DASH] = ACTIONS(3447),
    [anon_sym_true] = ACTIONS(3445),
    [anon_sym_false] = ACTIONS(3445),
    [anon_sym_PLUS] = ACTIONS(3445),
    [anon_sym_DASH] = ACTIONS(3445),
    [anon_sym_STAR] = ACTIONS(3447),
    [anon_sym_CARET] = ACTIONS(3447),
    [anon_sym_AMP] = ACTIONS(3447),
    [anon_sym_this] = ACTIONS(3445),
    [anon_sym_scoped] = ACTIONS(3445),
    [anon_sym_base] = ACTIONS(3445),
    [anon_sym_var] = ACTIONS(3445),
    [sym_predefined_type] = ACTIONS(3445),
    [anon_sym_break] = ACTIONS(3445),
    [anon_sym_unchecked] = ACTIONS(3445),
    [anon_sym_continue] = ACTIONS(3445),
    [anon_sym_do] = ACTIONS(3445),
    [anon_sym_while] = ACTIONS(3445),
    [anon_sym_for] = ACTIONS(3445),
    [anon_sym_lock] = ACTIONS(3445),
    [anon_sym_yield] = ACTIONS(3445),
    [anon_sym_switch] = ACTIONS(3445),
    [anon_sym_default] = ACTIONS(3445),
    [anon_sym_throw] = ACTIONS(3445),
    [anon_sym_try] = ACTIONS(3445),
    [anon_sym_when] = ACTIONS(3445),
    [anon_sym_await] = ACTIONS(3445),
    [anon_sym_foreach] = ACTIONS(3445),
    [anon_sym_goto] = ACTIONS(3445),
    [anon_sym_if] = ACTIONS(3445),
    [anon_sym_DOT_DOT] = ACTIONS(3447),
    [anon_sym_from] = ACTIONS(3445),
    [anon_sym_into] = ACTIONS(3445),
    [anon_sym_join] = ACTIONS(3445),
    [anon_sym_on] = ACTIONS(3445),
    [anon_sym_equals] = ACTIONS(3445),
    [anon_sym_let] = ACTIONS(3445),
    [anon_sym_orderby] = ACTIONS(3445),
    [anon_sym_ascending] = ACTIONS(3445),
    [anon_sym_descending] = ACTIONS(3445),
    [anon_sym_group] = ACTIONS(3445),
    [anon_sym_by] = ACTIONS(3445),
    [anon_sym_select] = ACTIONS(3445),
    [anon_sym_stackalloc] = ACTIONS(3445),
    [anon_sym_sizeof] = ACTIONS(3445),
    [anon_sym_typeof] = ACTIONS(3445),
    [anon_sym___makeref] = ACTIONS(3445),
    [anon_sym___reftype] = ACTIONS(3445),
    [anon_sym___refvalue] = ACTIONS(3445),
    [sym_null_literal] = ACTIONS(3445),
    [anon_sym_SQUOTE] = ACTIONS(3447),
    [sym_integer_literal] = ACTIONS(3445),
    [sym_real_literal] = ACTIONS(3447),
    [anon_sym_DQUOTE] = ACTIONS(3447),
    [sym_verbatim_string_literal] = ACTIONS(3447),
    [aux_sym_preproc_if_token1] = ACTIONS(3447),
    [aux_sym_preproc_if_token3] = ACTIONS(3447),
    [aux_sym_preproc_else_token1] = ACTIONS(3447),
    [aux_sym_preproc_elif_token1] = ACTIONS(3447),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3447),
    [sym_interpolation_verbatim_start] = ACTIONS(3447),
    [sym_interpolation_raw_start] = ACTIONS(3447),
    [sym_raw_string_start] = ACTIONS(3447),
  },
  [2317] = {
    [sym_preproc_region] = STATE(2317),
    [sym_preproc_endregion] = STATE(2317),
    [sym_preproc_line] = STATE(2317),
    [sym_preproc_pragma] = STATE(2317),
    [sym_preproc_nullable] = STATE(2317),
    [sym_preproc_error] = STATE(2317),
    [sym_preproc_warning] = STATE(2317),
    [sym_preproc_define] = STATE(2317),
    [sym_preproc_undef] = STATE(2317),
    [sym__identifier_token] = ACTIONS(3449),
    [anon_sym_extern] = ACTIONS(3449),
    [anon_sym_alias] = ACTIONS(3449),
    [anon_sym_SEMI] = ACTIONS(3451),
    [anon_sym_global] = ACTIONS(3449),
    [anon_sym_using] = ACTIONS(3449),
    [anon_sym_unsafe] = ACTIONS(3449),
    [anon_sym_static] = ACTIONS(3449),
    [anon_sym_LBRACK] = ACTIONS(3451),
    [anon_sym_LPAREN] = ACTIONS(3451),
    [anon_sym_return] = ACTIONS(3449),
    [anon_sym_namespace] = ACTIONS(3449),
    [anon_sym_class] = ACTIONS(3449),
    [anon_sym_ref] = ACTIONS(3449),
    [anon_sym_struct] = ACTIONS(3449),
    [anon_sym_enum] = ACTIONS(3449),
    [anon_sym_LBRACE] = ACTIONS(3451),
    [anon_sym_interface] = ACTIONS(3449),
    [anon_sym_delegate] = ACTIONS(3449),
    [anon_sym_record] = ACTIONS(3449),
    [anon_sym_abstract] = ACTIONS(3449),
    [anon_sym_async] = ACTIONS(3449),
    [anon_sym_const] = ACTIONS(3449),
    [anon_sym_file] = ACTIONS(3449),
    [anon_sym_fixed] = ACTIONS(3449),
    [anon_sym_internal] = ACTIONS(3449),
    [anon_sym_new] = ACTIONS(3449),
    [anon_sym_override] = ACTIONS(3449),
    [anon_sym_partial] = ACTIONS(3449),
    [anon_sym_private] = ACTIONS(3449),
    [anon_sym_protected] = ACTIONS(3449),
    [anon_sym_public] = ACTIONS(3449),
    [anon_sym_readonly] = ACTIONS(3449),
    [anon_sym_required] = ACTIONS(3449),
    [anon_sym_sealed] = ACTIONS(3449),
    [anon_sym_virtual] = ACTIONS(3449),
    [anon_sym_volatile] = ACTIONS(3449),
    [anon_sym_where] = ACTIONS(3449),
    [anon_sym_notnull] = ACTIONS(3449),
    [anon_sym_unmanaged] = ACTIONS(3449),
    [anon_sym_checked] = ACTIONS(3449),
    [anon_sym_BANG] = ACTIONS(3451),
    [anon_sym_TILDE] = ACTIONS(3451),
    [anon_sym_PLUS_PLUS] = ACTIONS(3451),
    [anon_sym_DASH_DASH] = ACTIONS(3451),
    [anon_sym_true] = ACTIONS(3449),
    [anon_sym_false] = ACTIONS(3449),
    [anon_sym_PLUS] = ACTIONS(3449),
    [anon_sym_DASH] = ACTIONS(3449),
    [anon_sym_STAR] = ACTIONS(3451),
    [anon_sym_CARET] = ACTIONS(3451),
    [anon_sym_AMP] = ACTIONS(3451),
    [anon_sym_this] = ACTIONS(3449),
    [anon_sym_scoped] = ACTIONS(3449),
    [anon_sym_base] = ACTIONS(3449),
    [anon_sym_var] = ACTIONS(3449),
    [sym_predefined_type] = ACTIONS(3449),
    [anon_sym_break] = ACTIONS(3449),
    [anon_sym_unchecked] = ACTIONS(3449),
    [anon_sym_continue] = ACTIONS(3449),
    [anon_sym_do] = ACTIONS(3449),
    [anon_sym_while] = ACTIONS(3449),
    [anon_sym_for] = ACTIONS(3449),
    [anon_sym_lock] = ACTIONS(3449),
    [anon_sym_yield] = ACTIONS(3449),
    [anon_sym_switch] = ACTIONS(3449),
    [anon_sym_default] = ACTIONS(3449),
    [anon_sym_throw] = ACTIONS(3449),
    [anon_sym_try] = ACTIONS(3449),
    [anon_sym_when] = ACTIONS(3449),
    [anon_sym_await] = ACTIONS(3449),
    [anon_sym_foreach] = ACTIONS(3449),
    [anon_sym_goto] = ACTIONS(3449),
    [anon_sym_if] = ACTIONS(3449),
    [anon_sym_DOT_DOT] = ACTIONS(3451),
    [anon_sym_from] = ACTIONS(3449),
    [anon_sym_into] = ACTIONS(3449),
    [anon_sym_join] = ACTIONS(3449),
    [anon_sym_on] = ACTIONS(3449),
    [anon_sym_equals] = ACTIONS(3449),
    [anon_sym_let] = ACTIONS(3449),
    [anon_sym_orderby] = ACTIONS(3449),
    [anon_sym_ascending] = ACTIONS(3449),
    [anon_sym_descending] = ACTIONS(3449),
    [anon_sym_group] = ACTIONS(3449),
    [anon_sym_by] = ACTIONS(3449),
    [anon_sym_select] = ACTIONS(3449),
    [anon_sym_stackalloc] = ACTIONS(3449),
    [anon_sym_sizeof] = ACTIONS(3449),
    [anon_sym_typeof] = ACTIONS(3449),
    [anon_sym___makeref] = ACTIONS(3449),
    [anon_sym___reftype] = ACTIONS(3449),
    [anon_sym___refvalue] = ACTIONS(3449),
    [sym_null_literal] = ACTIONS(3449),
    [anon_sym_SQUOTE] = ACTIONS(3451),
    [sym_integer_literal] = ACTIONS(3449),
    [sym_real_literal] = ACTIONS(3451),
    [anon_sym_DQUOTE] = ACTIONS(3451),
    [sym_verbatim_string_literal] = ACTIONS(3451),
    [aux_sym_preproc_if_token1] = ACTIONS(3451),
    [aux_sym_preproc_if_token3] = ACTIONS(3451),
    [aux_sym_preproc_else_token1] = ACTIONS(3451),
    [aux_sym_preproc_elif_token1] = ACTIONS(3451),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3451),
    [sym_interpolation_verbatim_start] = ACTIONS(3451),
    [sym_interpolation_raw_start] = ACTIONS(3451),
    [sym_raw_string_start] = ACTIONS(3451),
  },
  [2318] = {
    [sym_preproc_region] = STATE(2318),
    [sym_preproc_endregion] = STATE(2318),
    [sym_preproc_line] = STATE(2318),
    [sym_preproc_pragma] = STATE(2318),
    [sym_preproc_nullable] = STATE(2318),
    [sym_preproc_error] = STATE(2318),
    [sym_preproc_warning] = STATE(2318),
    [sym_preproc_define] = STATE(2318),
    [sym_preproc_undef] = STATE(2318),
    [sym__identifier_token] = ACTIONS(3453),
    [anon_sym_extern] = ACTIONS(3453),
    [anon_sym_alias] = ACTIONS(3453),
    [anon_sym_SEMI] = ACTIONS(3455),
    [anon_sym_global] = ACTIONS(3453),
    [anon_sym_using] = ACTIONS(3453),
    [anon_sym_unsafe] = ACTIONS(3453),
    [anon_sym_static] = ACTIONS(3453),
    [anon_sym_LBRACK] = ACTIONS(3455),
    [anon_sym_LPAREN] = ACTIONS(3455),
    [anon_sym_return] = ACTIONS(3453),
    [anon_sym_namespace] = ACTIONS(3453),
    [anon_sym_class] = ACTIONS(3453),
    [anon_sym_ref] = ACTIONS(3453),
    [anon_sym_struct] = ACTIONS(3453),
    [anon_sym_enum] = ACTIONS(3453),
    [anon_sym_LBRACE] = ACTIONS(3455),
    [anon_sym_interface] = ACTIONS(3453),
    [anon_sym_delegate] = ACTIONS(3453),
    [anon_sym_record] = ACTIONS(3453),
    [anon_sym_abstract] = ACTIONS(3453),
    [anon_sym_async] = ACTIONS(3453),
    [anon_sym_const] = ACTIONS(3453),
    [anon_sym_file] = ACTIONS(3453),
    [anon_sym_fixed] = ACTIONS(3453),
    [anon_sym_internal] = ACTIONS(3453),
    [anon_sym_new] = ACTIONS(3453),
    [anon_sym_override] = ACTIONS(3453),
    [anon_sym_partial] = ACTIONS(3453),
    [anon_sym_private] = ACTIONS(3453),
    [anon_sym_protected] = ACTIONS(3453),
    [anon_sym_public] = ACTIONS(3453),
    [anon_sym_readonly] = ACTIONS(3453),
    [anon_sym_required] = ACTIONS(3453),
    [anon_sym_sealed] = ACTIONS(3453),
    [anon_sym_virtual] = ACTIONS(3453),
    [anon_sym_volatile] = ACTIONS(3453),
    [anon_sym_where] = ACTIONS(3453),
    [anon_sym_notnull] = ACTIONS(3453),
    [anon_sym_unmanaged] = ACTIONS(3453),
    [anon_sym_checked] = ACTIONS(3453),
    [anon_sym_BANG] = ACTIONS(3455),
    [anon_sym_TILDE] = ACTIONS(3455),
    [anon_sym_PLUS_PLUS] = ACTIONS(3455),
    [anon_sym_DASH_DASH] = ACTIONS(3455),
    [anon_sym_true] = ACTIONS(3453),
    [anon_sym_false] = ACTIONS(3453),
    [anon_sym_PLUS] = ACTIONS(3453),
    [anon_sym_DASH] = ACTIONS(3453),
    [anon_sym_STAR] = ACTIONS(3455),
    [anon_sym_CARET] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(3455),
    [anon_sym_this] = ACTIONS(3453),
    [anon_sym_scoped] = ACTIONS(3453),
    [anon_sym_base] = ACTIONS(3453),
    [anon_sym_var] = ACTIONS(3453),
    [sym_predefined_type] = ACTIONS(3453),
    [anon_sym_break] = ACTIONS(3453),
    [anon_sym_unchecked] = ACTIONS(3453),
    [anon_sym_continue] = ACTIONS(3453),
    [anon_sym_do] = ACTIONS(3453),
    [anon_sym_while] = ACTIONS(3453),
    [anon_sym_for] = ACTIONS(3453),
    [anon_sym_lock] = ACTIONS(3453),
    [anon_sym_yield] = ACTIONS(3453),
    [anon_sym_switch] = ACTIONS(3453),
    [anon_sym_default] = ACTIONS(3453),
    [anon_sym_throw] = ACTIONS(3453),
    [anon_sym_try] = ACTIONS(3453),
    [anon_sym_when] = ACTIONS(3453),
    [anon_sym_await] = ACTIONS(3453),
    [anon_sym_foreach] = ACTIONS(3453),
    [anon_sym_goto] = ACTIONS(3453),
    [anon_sym_if] = ACTIONS(3453),
    [anon_sym_DOT_DOT] = ACTIONS(3455),
    [anon_sym_from] = ACTIONS(3453),
    [anon_sym_into] = ACTIONS(3453),
    [anon_sym_join] = ACTIONS(3453),
    [anon_sym_on] = ACTIONS(3453),
    [anon_sym_equals] = ACTIONS(3453),
    [anon_sym_let] = ACTIONS(3453),
    [anon_sym_orderby] = ACTIONS(3453),
    [anon_sym_ascending] = ACTIONS(3453),
    [anon_sym_descending] = ACTIONS(3453),
    [anon_sym_group] = ACTIONS(3453),
    [anon_sym_by] = ACTIONS(3453),
    [anon_sym_select] = ACTIONS(3453),
    [anon_sym_stackalloc] = ACTIONS(3453),
    [anon_sym_sizeof] = ACTIONS(3453),
    [anon_sym_typeof] = ACTIONS(3453),
    [anon_sym___makeref] = ACTIONS(3453),
    [anon_sym___reftype] = ACTIONS(3453),
    [anon_sym___refvalue] = ACTIONS(3453),
    [sym_null_literal] = ACTIONS(3453),
    [anon_sym_SQUOTE] = ACTIONS(3455),
    [sym_integer_literal] = ACTIONS(3453),
    [sym_real_literal] = ACTIONS(3455),
    [anon_sym_DQUOTE] = ACTIONS(3455),
    [sym_verbatim_string_literal] = ACTIONS(3455),
    [aux_sym_preproc_if_token1] = ACTIONS(3455),
    [aux_sym_preproc_if_token3] = ACTIONS(3455),
    [aux_sym_preproc_else_token1] = ACTIONS(3455),
    [aux_sym_preproc_elif_token1] = ACTIONS(3455),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3455),
    [sym_interpolation_verbatim_start] = ACTIONS(3455),
    [sym_interpolation_raw_start] = ACTIONS(3455),
    [sym_raw_string_start] = ACTIONS(3455),
  },
  [2319] = {
    [sym_preproc_region] = STATE(2319),
    [sym_preproc_endregion] = STATE(2319),
    [sym_preproc_line] = STATE(2319),
    [sym_preproc_pragma] = STATE(2319),
    [sym_preproc_nullable] = STATE(2319),
    [sym_preproc_error] = STATE(2319),
    [sym_preproc_warning] = STATE(2319),
    [sym_preproc_define] = STATE(2319),
    [sym_preproc_undef] = STATE(2319),
    [sym__identifier_token] = ACTIONS(3457),
    [anon_sym_extern] = ACTIONS(3457),
    [anon_sym_alias] = ACTIONS(3457),
    [anon_sym_SEMI] = ACTIONS(3459),
    [anon_sym_global] = ACTIONS(3457),
    [anon_sym_using] = ACTIONS(3457),
    [anon_sym_unsafe] = ACTIONS(3457),
    [anon_sym_static] = ACTIONS(3457),
    [anon_sym_LBRACK] = ACTIONS(3459),
    [anon_sym_LPAREN] = ACTIONS(3459),
    [anon_sym_return] = ACTIONS(3457),
    [anon_sym_namespace] = ACTIONS(3457),
    [anon_sym_class] = ACTIONS(3457),
    [anon_sym_ref] = ACTIONS(3457),
    [anon_sym_struct] = ACTIONS(3457),
    [anon_sym_enum] = ACTIONS(3457),
    [anon_sym_LBRACE] = ACTIONS(3459),
    [anon_sym_interface] = ACTIONS(3457),
    [anon_sym_delegate] = ACTIONS(3457),
    [anon_sym_record] = ACTIONS(3457),
    [anon_sym_abstract] = ACTIONS(3457),
    [anon_sym_async] = ACTIONS(3457),
    [anon_sym_const] = ACTIONS(3457),
    [anon_sym_file] = ACTIONS(3457),
    [anon_sym_fixed] = ACTIONS(3457),
    [anon_sym_internal] = ACTIONS(3457),
    [anon_sym_new] = ACTIONS(3457),
    [anon_sym_override] = ACTIONS(3457),
    [anon_sym_partial] = ACTIONS(3457),
    [anon_sym_private] = ACTIONS(3457),
    [anon_sym_protected] = ACTIONS(3457),
    [anon_sym_public] = ACTIONS(3457),
    [anon_sym_readonly] = ACTIONS(3457),
    [anon_sym_required] = ACTIONS(3457),
    [anon_sym_sealed] = ACTIONS(3457),
    [anon_sym_virtual] = ACTIONS(3457),
    [anon_sym_volatile] = ACTIONS(3457),
    [anon_sym_where] = ACTIONS(3457),
    [anon_sym_notnull] = ACTIONS(3457),
    [anon_sym_unmanaged] = ACTIONS(3457),
    [anon_sym_checked] = ACTIONS(3457),
    [anon_sym_BANG] = ACTIONS(3459),
    [anon_sym_TILDE] = ACTIONS(3459),
    [anon_sym_PLUS_PLUS] = ACTIONS(3459),
    [anon_sym_DASH_DASH] = ACTIONS(3459),
    [anon_sym_true] = ACTIONS(3457),
    [anon_sym_false] = ACTIONS(3457),
    [anon_sym_PLUS] = ACTIONS(3457),
    [anon_sym_DASH] = ACTIONS(3457),
    [anon_sym_STAR] = ACTIONS(3459),
    [anon_sym_CARET] = ACTIONS(3459),
    [anon_sym_AMP] = ACTIONS(3459),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_scoped] = ACTIONS(3457),
    [anon_sym_base] = ACTIONS(3457),
    [anon_sym_var] = ACTIONS(3457),
    [sym_predefined_type] = ACTIONS(3457),
    [anon_sym_break] = ACTIONS(3457),
    [anon_sym_unchecked] = ACTIONS(3457),
    [anon_sym_continue] = ACTIONS(3457),
    [anon_sym_do] = ACTIONS(3457),
    [anon_sym_while] = ACTIONS(3457),
    [anon_sym_for] = ACTIONS(3457),
    [anon_sym_lock] = ACTIONS(3457),
    [anon_sym_yield] = ACTIONS(3457),
    [anon_sym_switch] = ACTIONS(3457),
    [anon_sym_default] = ACTIONS(3457),
    [anon_sym_throw] = ACTIONS(3457),
    [anon_sym_try] = ACTIONS(3457),
    [anon_sym_when] = ACTIONS(3457),
    [anon_sym_await] = ACTIONS(3457),
    [anon_sym_foreach] = ACTIONS(3457),
    [anon_sym_goto] = ACTIONS(3457),
    [anon_sym_if] = ACTIONS(3457),
    [anon_sym_DOT_DOT] = ACTIONS(3459),
    [anon_sym_from] = ACTIONS(3457),
    [anon_sym_into] = ACTIONS(3457),
    [anon_sym_join] = ACTIONS(3457),
    [anon_sym_on] = ACTIONS(3457),
    [anon_sym_equals] = ACTIONS(3457),
    [anon_sym_let] = ACTIONS(3457),
    [anon_sym_orderby] = ACTIONS(3457),
    [anon_sym_ascending] = ACTIONS(3457),
    [anon_sym_descending] = ACTIONS(3457),
    [anon_sym_group] = ACTIONS(3457),
    [anon_sym_by] = ACTIONS(3457),
    [anon_sym_select] = ACTIONS(3457),
    [anon_sym_stackalloc] = ACTIONS(3457),
    [anon_sym_sizeof] = ACTIONS(3457),
    [anon_sym_typeof] = ACTIONS(3457),
    [anon_sym___makeref] = ACTIONS(3457),
    [anon_sym___reftype] = ACTIONS(3457),
    [anon_sym___refvalue] = ACTIONS(3457),
    [sym_null_literal] = ACTIONS(3457),
    [anon_sym_SQUOTE] = ACTIONS(3459),
    [sym_integer_literal] = ACTIONS(3457),
    [sym_real_literal] = ACTIONS(3459),
    [anon_sym_DQUOTE] = ACTIONS(3459),
    [sym_verbatim_string_literal] = ACTIONS(3459),
    [aux_sym_preproc_if_token1] = ACTIONS(3459),
    [aux_sym_preproc_if_token3] = ACTIONS(3459),
    [aux_sym_preproc_else_token1] = ACTIONS(3459),
    [aux_sym_preproc_elif_token1] = ACTIONS(3459),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3459),
    [sym_interpolation_verbatim_start] = ACTIONS(3459),
    [sym_interpolation_raw_start] = ACTIONS(3459),
    [sym_raw_string_start] = ACTIONS(3459),
  },
  [2320] = {
    [sym_preproc_region] = STATE(2320),
    [sym_preproc_endregion] = STATE(2320),
    [sym_preproc_line] = STATE(2320),
    [sym_preproc_pragma] = STATE(2320),
    [sym_preproc_nullable] = STATE(2320),
    [sym_preproc_error] = STATE(2320),
    [sym_preproc_warning] = STATE(2320),
    [sym_preproc_define] = STATE(2320),
    [sym_preproc_undef] = STATE(2320),
    [sym__identifier_token] = ACTIONS(3461),
    [anon_sym_extern] = ACTIONS(3461),
    [anon_sym_alias] = ACTIONS(3461),
    [anon_sym_SEMI] = ACTIONS(3463),
    [anon_sym_global] = ACTIONS(3461),
    [anon_sym_using] = ACTIONS(3461),
    [anon_sym_unsafe] = ACTIONS(3461),
    [anon_sym_static] = ACTIONS(3461),
    [anon_sym_LBRACK] = ACTIONS(3463),
    [anon_sym_LPAREN] = ACTIONS(3463),
    [anon_sym_return] = ACTIONS(3461),
    [anon_sym_namespace] = ACTIONS(3461),
    [anon_sym_class] = ACTIONS(3461),
    [anon_sym_ref] = ACTIONS(3461),
    [anon_sym_struct] = ACTIONS(3461),
    [anon_sym_enum] = ACTIONS(3461),
    [anon_sym_LBRACE] = ACTIONS(3463),
    [anon_sym_interface] = ACTIONS(3461),
    [anon_sym_delegate] = ACTIONS(3461),
    [anon_sym_record] = ACTIONS(3461),
    [anon_sym_abstract] = ACTIONS(3461),
    [anon_sym_async] = ACTIONS(3461),
    [anon_sym_const] = ACTIONS(3461),
    [anon_sym_file] = ACTIONS(3461),
    [anon_sym_fixed] = ACTIONS(3461),
    [anon_sym_internal] = ACTIONS(3461),
    [anon_sym_new] = ACTIONS(3461),
    [anon_sym_override] = ACTIONS(3461),
    [anon_sym_partial] = ACTIONS(3461),
    [anon_sym_private] = ACTIONS(3461),
    [anon_sym_protected] = ACTIONS(3461),
    [anon_sym_public] = ACTIONS(3461),
    [anon_sym_readonly] = ACTIONS(3461),
    [anon_sym_required] = ACTIONS(3461),
    [anon_sym_sealed] = ACTIONS(3461),
    [anon_sym_virtual] = ACTIONS(3461),
    [anon_sym_volatile] = ACTIONS(3461),
    [anon_sym_where] = ACTIONS(3461),
    [anon_sym_notnull] = ACTIONS(3461),
    [anon_sym_unmanaged] = ACTIONS(3461),
    [anon_sym_checked] = ACTIONS(3461),
    [anon_sym_BANG] = ACTIONS(3463),
    [anon_sym_TILDE] = ACTIONS(3463),
    [anon_sym_PLUS_PLUS] = ACTIONS(3463),
    [anon_sym_DASH_DASH] = ACTIONS(3463),
    [anon_sym_true] = ACTIONS(3461),
    [anon_sym_false] = ACTIONS(3461),
    [anon_sym_PLUS] = ACTIONS(3461),
    [anon_sym_DASH] = ACTIONS(3461),
    [anon_sym_STAR] = ACTIONS(3463),
    [anon_sym_CARET] = ACTIONS(3463),
    [anon_sym_AMP] = ACTIONS(3463),
    [anon_sym_this] = ACTIONS(3461),
    [anon_sym_scoped] = ACTIONS(3461),
    [anon_sym_base] = ACTIONS(3461),
    [anon_sym_var] = ACTIONS(3461),
    [sym_predefined_type] = ACTIONS(3461),
    [anon_sym_break] = ACTIONS(3461),
    [anon_sym_unchecked] = ACTIONS(3461),
    [anon_sym_continue] = ACTIONS(3461),
    [anon_sym_do] = ACTIONS(3461),
    [anon_sym_while] = ACTIONS(3461),
    [anon_sym_for] = ACTIONS(3461),
    [anon_sym_lock] = ACTIONS(3461),
    [anon_sym_yield] = ACTIONS(3461),
    [anon_sym_switch] = ACTIONS(3461),
    [anon_sym_default] = ACTIONS(3461),
    [anon_sym_throw] = ACTIONS(3461),
    [anon_sym_try] = ACTIONS(3461),
    [anon_sym_when] = ACTIONS(3461),
    [anon_sym_await] = ACTIONS(3461),
    [anon_sym_foreach] = ACTIONS(3461),
    [anon_sym_goto] = ACTIONS(3461),
    [anon_sym_if] = ACTIONS(3461),
    [anon_sym_DOT_DOT] = ACTIONS(3463),
    [anon_sym_from] = ACTIONS(3461),
    [anon_sym_into] = ACTIONS(3461),
    [anon_sym_join] = ACTIONS(3461),
    [anon_sym_on] = ACTIONS(3461),
    [anon_sym_equals] = ACTIONS(3461),
    [anon_sym_let] = ACTIONS(3461),
    [anon_sym_orderby] = ACTIONS(3461),
    [anon_sym_ascending] = ACTIONS(3461),
    [anon_sym_descending] = ACTIONS(3461),
    [anon_sym_group] = ACTIONS(3461),
    [anon_sym_by] = ACTIONS(3461),
    [anon_sym_select] = ACTIONS(3461),
    [anon_sym_stackalloc] = ACTIONS(3461),
    [anon_sym_sizeof] = ACTIONS(3461),
    [anon_sym_typeof] = ACTIONS(3461),
    [anon_sym___makeref] = ACTIONS(3461),
    [anon_sym___reftype] = ACTIONS(3461),
    [anon_sym___refvalue] = ACTIONS(3461),
    [sym_null_literal] = ACTIONS(3461),
    [anon_sym_SQUOTE] = ACTIONS(3463),
    [sym_integer_literal] = ACTIONS(3461),
    [sym_real_literal] = ACTIONS(3463),
    [anon_sym_DQUOTE] = ACTIONS(3463),
    [sym_verbatim_string_literal] = ACTIONS(3463),
    [aux_sym_preproc_if_token1] = ACTIONS(3463),
    [aux_sym_preproc_if_token3] = ACTIONS(3463),
    [aux_sym_preproc_else_token1] = ACTIONS(3463),
    [aux_sym_preproc_elif_token1] = ACTIONS(3463),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3463),
    [sym_interpolation_verbatim_start] = ACTIONS(3463),
    [sym_interpolation_raw_start] = ACTIONS(3463),
    [sym_raw_string_start] = ACTIONS(3463),
  },
  [2321] = {
    [sym_preproc_region] = STATE(2321),
    [sym_preproc_endregion] = STATE(2321),
    [sym_preproc_line] = STATE(2321),
    [sym_preproc_pragma] = STATE(2321),
    [sym_preproc_nullable] = STATE(2321),
    [sym_preproc_error] = STATE(2321),
    [sym_preproc_warning] = STATE(2321),
    [sym_preproc_define] = STATE(2321),
    [sym_preproc_undef] = STATE(2321),
    [sym__identifier_token] = ACTIONS(3465),
    [anon_sym_extern] = ACTIONS(3465),
    [anon_sym_alias] = ACTIONS(3465),
    [anon_sym_SEMI] = ACTIONS(3467),
    [anon_sym_global] = ACTIONS(3465),
    [anon_sym_using] = ACTIONS(3465),
    [anon_sym_unsafe] = ACTIONS(3465),
    [anon_sym_static] = ACTIONS(3465),
    [anon_sym_LBRACK] = ACTIONS(3467),
    [anon_sym_LPAREN] = ACTIONS(3467),
    [anon_sym_return] = ACTIONS(3465),
    [anon_sym_namespace] = ACTIONS(3465),
    [anon_sym_class] = ACTIONS(3465),
    [anon_sym_ref] = ACTIONS(3465),
    [anon_sym_struct] = ACTIONS(3465),
    [anon_sym_enum] = ACTIONS(3465),
    [anon_sym_LBRACE] = ACTIONS(3467),
    [anon_sym_interface] = ACTIONS(3465),
    [anon_sym_delegate] = ACTIONS(3465),
    [anon_sym_record] = ACTIONS(3465),
    [anon_sym_abstract] = ACTIONS(3465),
    [anon_sym_async] = ACTIONS(3465),
    [anon_sym_const] = ACTIONS(3465),
    [anon_sym_file] = ACTIONS(3465),
    [anon_sym_fixed] = ACTIONS(3465),
    [anon_sym_internal] = ACTIONS(3465),
    [anon_sym_new] = ACTIONS(3465),
    [anon_sym_override] = ACTIONS(3465),
    [anon_sym_partial] = ACTIONS(3465),
    [anon_sym_private] = ACTIONS(3465),
    [anon_sym_protected] = ACTIONS(3465),
    [anon_sym_public] = ACTIONS(3465),
    [anon_sym_readonly] = ACTIONS(3465),
    [anon_sym_required] = ACTIONS(3465),
    [anon_sym_sealed] = ACTIONS(3465),
    [anon_sym_virtual] = ACTIONS(3465),
    [anon_sym_volatile] = ACTIONS(3465),
    [anon_sym_where] = ACTIONS(3465),
    [anon_sym_notnull] = ACTIONS(3465),
    [anon_sym_unmanaged] = ACTIONS(3465),
    [anon_sym_checked] = ACTIONS(3465),
    [anon_sym_BANG] = ACTIONS(3467),
    [anon_sym_TILDE] = ACTIONS(3467),
    [anon_sym_PLUS_PLUS] = ACTIONS(3467),
    [anon_sym_DASH_DASH] = ACTIONS(3467),
    [anon_sym_true] = ACTIONS(3465),
    [anon_sym_false] = ACTIONS(3465),
    [anon_sym_PLUS] = ACTIONS(3465),
    [anon_sym_DASH] = ACTIONS(3465),
    [anon_sym_STAR] = ACTIONS(3467),
    [anon_sym_CARET] = ACTIONS(3467),
    [anon_sym_AMP] = ACTIONS(3467),
    [anon_sym_this] = ACTIONS(3465),
    [anon_sym_scoped] = ACTIONS(3465),
    [anon_sym_base] = ACTIONS(3465),
    [anon_sym_var] = ACTIONS(3465),
    [sym_predefined_type] = ACTIONS(3465),
    [anon_sym_break] = ACTIONS(3465),
    [anon_sym_unchecked] = ACTIONS(3465),
    [anon_sym_continue] = ACTIONS(3465),
    [anon_sym_do] = ACTIONS(3465),
    [anon_sym_while] = ACTIONS(3465),
    [anon_sym_for] = ACTIONS(3465),
    [anon_sym_lock] = ACTIONS(3465),
    [anon_sym_yield] = ACTIONS(3465),
    [anon_sym_switch] = ACTIONS(3465),
    [anon_sym_default] = ACTIONS(3465),
    [anon_sym_throw] = ACTIONS(3465),
    [anon_sym_try] = ACTIONS(3465),
    [anon_sym_when] = ACTIONS(3465),
    [anon_sym_await] = ACTIONS(3465),
    [anon_sym_foreach] = ACTIONS(3465),
    [anon_sym_goto] = ACTIONS(3465),
    [anon_sym_if] = ACTIONS(3465),
    [anon_sym_DOT_DOT] = ACTIONS(3467),
    [anon_sym_from] = ACTIONS(3465),
    [anon_sym_into] = ACTIONS(3465),
    [anon_sym_join] = ACTIONS(3465),
    [anon_sym_on] = ACTIONS(3465),
    [anon_sym_equals] = ACTIONS(3465),
    [anon_sym_let] = ACTIONS(3465),
    [anon_sym_orderby] = ACTIONS(3465),
    [anon_sym_ascending] = ACTIONS(3465),
    [anon_sym_descending] = ACTIONS(3465),
    [anon_sym_group] = ACTIONS(3465),
    [anon_sym_by] = ACTIONS(3465),
    [anon_sym_select] = ACTIONS(3465),
    [anon_sym_stackalloc] = ACTIONS(3465),
    [anon_sym_sizeof] = ACTIONS(3465),
    [anon_sym_typeof] = ACTIONS(3465),
    [anon_sym___makeref] = ACTIONS(3465),
    [anon_sym___reftype] = ACTIONS(3465),
    [anon_sym___refvalue] = ACTIONS(3465),
    [sym_null_literal] = ACTIONS(3465),
    [anon_sym_SQUOTE] = ACTIONS(3467),
    [sym_integer_literal] = ACTIONS(3465),
    [sym_real_literal] = ACTIONS(3467),
    [anon_sym_DQUOTE] = ACTIONS(3467),
    [sym_verbatim_string_literal] = ACTIONS(3467),
    [aux_sym_preproc_if_token1] = ACTIONS(3467),
    [aux_sym_preproc_if_token3] = ACTIONS(3467),
    [aux_sym_preproc_else_token1] = ACTIONS(3467),
    [aux_sym_preproc_elif_token1] = ACTIONS(3467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3467),
    [sym_interpolation_verbatim_start] = ACTIONS(3467),
    [sym_interpolation_raw_start] = ACTIONS(3467),
    [sym_raw_string_start] = ACTIONS(3467),
  },
  [2322] = {
    [sym_preproc_region] = STATE(2322),
    [sym_preproc_endregion] = STATE(2322),
    [sym_preproc_line] = STATE(2322),
    [sym_preproc_pragma] = STATE(2322),
    [sym_preproc_nullable] = STATE(2322),
    [sym_preproc_error] = STATE(2322),
    [sym_preproc_warning] = STATE(2322),
    [sym_preproc_define] = STATE(2322),
    [sym_preproc_undef] = STATE(2322),
    [sym__identifier_token] = ACTIONS(3469),
    [anon_sym_extern] = ACTIONS(3469),
    [anon_sym_alias] = ACTIONS(3469),
    [anon_sym_SEMI] = ACTIONS(3471),
    [anon_sym_global] = ACTIONS(3469),
    [anon_sym_using] = ACTIONS(3469),
    [anon_sym_unsafe] = ACTIONS(3469),
    [anon_sym_static] = ACTIONS(3469),
    [anon_sym_LBRACK] = ACTIONS(3471),
    [anon_sym_LPAREN] = ACTIONS(3471),
    [anon_sym_return] = ACTIONS(3469),
    [anon_sym_namespace] = ACTIONS(3469),
    [anon_sym_class] = ACTIONS(3469),
    [anon_sym_ref] = ACTIONS(3469),
    [anon_sym_struct] = ACTIONS(3469),
    [anon_sym_enum] = ACTIONS(3469),
    [anon_sym_LBRACE] = ACTIONS(3471),
    [anon_sym_interface] = ACTIONS(3469),
    [anon_sym_delegate] = ACTIONS(3469),
    [anon_sym_record] = ACTIONS(3469),
    [anon_sym_abstract] = ACTIONS(3469),
    [anon_sym_async] = ACTIONS(3469),
    [anon_sym_const] = ACTIONS(3469),
    [anon_sym_file] = ACTIONS(3469),
    [anon_sym_fixed] = ACTIONS(3469),
    [anon_sym_internal] = ACTIONS(3469),
    [anon_sym_new] = ACTIONS(3469),
    [anon_sym_override] = ACTIONS(3469),
    [anon_sym_partial] = ACTIONS(3469),
    [anon_sym_private] = ACTIONS(3469),
    [anon_sym_protected] = ACTIONS(3469),
    [anon_sym_public] = ACTIONS(3469),
    [anon_sym_readonly] = ACTIONS(3469),
    [anon_sym_required] = ACTIONS(3469),
    [anon_sym_sealed] = ACTIONS(3469),
    [anon_sym_virtual] = ACTIONS(3469),
    [anon_sym_volatile] = ACTIONS(3469),
    [anon_sym_where] = ACTIONS(3469),
    [anon_sym_notnull] = ACTIONS(3469),
    [anon_sym_unmanaged] = ACTIONS(3469),
    [anon_sym_checked] = ACTIONS(3469),
    [anon_sym_BANG] = ACTIONS(3471),
    [anon_sym_TILDE] = ACTIONS(3471),
    [anon_sym_PLUS_PLUS] = ACTIONS(3471),
    [anon_sym_DASH_DASH] = ACTIONS(3471),
    [anon_sym_true] = ACTIONS(3469),
    [anon_sym_false] = ACTIONS(3469),
    [anon_sym_PLUS] = ACTIONS(3469),
    [anon_sym_DASH] = ACTIONS(3469),
    [anon_sym_STAR] = ACTIONS(3471),
    [anon_sym_CARET] = ACTIONS(3471),
    [anon_sym_AMP] = ACTIONS(3471),
    [anon_sym_this] = ACTIONS(3469),
    [anon_sym_scoped] = ACTIONS(3469),
    [anon_sym_base] = ACTIONS(3469),
    [anon_sym_var] = ACTIONS(3469),
    [sym_predefined_type] = ACTIONS(3469),
    [anon_sym_break] = ACTIONS(3469),
    [anon_sym_unchecked] = ACTIONS(3469),
    [anon_sym_continue] = ACTIONS(3469),
    [anon_sym_do] = ACTIONS(3469),
    [anon_sym_while] = ACTIONS(3469),
    [anon_sym_for] = ACTIONS(3469),
    [anon_sym_lock] = ACTIONS(3469),
    [anon_sym_yield] = ACTIONS(3469),
    [anon_sym_switch] = ACTIONS(3469),
    [anon_sym_default] = ACTIONS(3469),
    [anon_sym_throw] = ACTIONS(3469),
    [anon_sym_try] = ACTIONS(3469),
    [anon_sym_when] = ACTIONS(3469),
    [anon_sym_await] = ACTIONS(3469),
    [anon_sym_foreach] = ACTIONS(3469),
    [anon_sym_goto] = ACTIONS(3469),
    [anon_sym_if] = ACTIONS(3469),
    [anon_sym_DOT_DOT] = ACTIONS(3471),
    [anon_sym_from] = ACTIONS(3469),
    [anon_sym_into] = ACTIONS(3469),
    [anon_sym_join] = ACTIONS(3469),
    [anon_sym_on] = ACTIONS(3469),
    [anon_sym_equals] = ACTIONS(3469),
    [anon_sym_let] = ACTIONS(3469),
    [anon_sym_orderby] = ACTIONS(3469),
    [anon_sym_ascending] = ACTIONS(3469),
    [anon_sym_descending] = ACTIONS(3469),
    [anon_sym_group] = ACTIONS(3469),
    [anon_sym_by] = ACTIONS(3469),
    [anon_sym_select] = ACTIONS(3469),
    [anon_sym_stackalloc] = ACTIONS(3469),
    [anon_sym_sizeof] = ACTIONS(3469),
    [anon_sym_typeof] = ACTIONS(3469),
    [anon_sym___makeref] = ACTIONS(3469),
    [anon_sym___reftype] = ACTIONS(3469),
    [anon_sym___refvalue] = ACTIONS(3469),
    [sym_null_literal] = ACTIONS(3469),
    [anon_sym_SQUOTE] = ACTIONS(3471),
    [sym_integer_literal] = ACTIONS(3469),
    [sym_real_literal] = ACTIONS(3471),
    [anon_sym_DQUOTE] = ACTIONS(3471),
    [sym_verbatim_string_literal] = ACTIONS(3471),
    [aux_sym_preproc_if_token1] = ACTIONS(3471),
    [aux_sym_preproc_if_token3] = ACTIONS(3471),
    [aux_sym_preproc_else_token1] = ACTIONS(3471),
    [aux_sym_preproc_elif_token1] = ACTIONS(3471),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3471),
    [sym_interpolation_verbatim_start] = ACTIONS(3471),
    [sym_interpolation_raw_start] = ACTIONS(3471),
    [sym_raw_string_start] = ACTIONS(3471),
  },
  [2323] = {
    [sym_preproc_region] = STATE(2323),
    [sym_preproc_endregion] = STATE(2323),
    [sym_preproc_line] = STATE(2323),
    [sym_preproc_pragma] = STATE(2323),
    [sym_preproc_nullable] = STATE(2323),
    [sym_preproc_error] = STATE(2323),
    [sym_preproc_warning] = STATE(2323),
    [sym_preproc_define] = STATE(2323),
    [sym_preproc_undef] = STATE(2323),
    [sym__identifier_token] = ACTIONS(3473),
    [anon_sym_extern] = ACTIONS(3473),
    [anon_sym_alias] = ACTIONS(3473),
    [anon_sym_SEMI] = ACTIONS(3475),
    [anon_sym_global] = ACTIONS(3473),
    [anon_sym_using] = ACTIONS(3473),
    [anon_sym_unsafe] = ACTIONS(3473),
    [anon_sym_static] = ACTIONS(3473),
    [anon_sym_LBRACK] = ACTIONS(3475),
    [anon_sym_LPAREN] = ACTIONS(3475),
    [anon_sym_return] = ACTIONS(3473),
    [anon_sym_namespace] = ACTIONS(3473),
    [anon_sym_class] = ACTIONS(3473),
    [anon_sym_ref] = ACTIONS(3473),
    [anon_sym_struct] = ACTIONS(3473),
    [anon_sym_enum] = ACTIONS(3473),
    [anon_sym_LBRACE] = ACTIONS(3475),
    [anon_sym_interface] = ACTIONS(3473),
    [anon_sym_delegate] = ACTIONS(3473),
    [anon_sym_record] = ACTIONS(3473),
    [anon_sym_abstract] = ACTIONS(3473),
    [anon_sym_async] = ACTIONS(3473),
    [anon_sym_const] = ACTIONS(3473),
    [anon_sym_file] = ACTIONS(3473),
    [anon_sym_fixed] = ACTIONS(3473),
    [anon_sym_internal] = ACTIONS(3473),
    [anon_sym_new] = ACTIONS(3473),
    [anon_sym_override] = ACTIONS(3473),
    [anon_sym_partial] = ACTIONS(3473),
    [anon_sym_private] = ACTIONS(3473),
    [anon_sym_protected] = ACTIONS(3473),
    [anon_sym_public] = ACTIONS(3473),
    [anon_sym_readonly] = ACTIONS(3473),
    [anon_sym_required] = ACTIONS(3473),
    [anon_sym_sealed] = ACTIONS(3473),
    [anon_sym_virtual] = ACTIONS(3473),
    [anon_sym_volatile] = ACTIONS(3473),
    [anon_sym_where] = ACTIONS(3473),
    [anon_sym_notnull] = ACTIONS(3473),
    [anon_sym_unmanaged] = ACTIONS(3473),
    [anon_sym_checked] = ACTIONS(3473),
    [anon_sym_BANG] = ACTIONS(3475),
    [anon_sym_TILDE] = ACTIONS(3475),
    [anon_sym_PLUS_PLUS] = ACTIONS(3475),
    [anon_sym_DASH_DASH] = ACTIONS(3475),
    [anon_sym_true] = ACTIONS(3473),
    [anon_sym_false] = ACTIONS(3473),
    [anon_sym_PLUS] = ACTIONS(3473),
    [anon_sym_DASH] = ACTIONS(3473),
    [anon_sym_STAR] = ACTIONS(3475),
    [anon_sym_CARET] = ACTIONS(3475),
    [anon_sym_AMP] = ACTIONS(3475),
    [anon_sym_this] = ACTIONS(3473),
    [anon_sym_scoped] = ACTIONS(3473),
    [anon_sym_base] = ACTIONS(3473),
    [anon_sym_var] = ACTIONS(3473),
    [sym_predefined_type] = ACTIONS(3473),
    [anon_sym_break] = ACTIONS(3473),
    [anon_sym_unchecked] = ACTIONS(3473),
    [anon_sym_continue] = ACTIONS(3473),
    [anon_sym_do] = ACTIONS(3473),
    [anon_sym_while] = ACTIONS(3473),
    [anon_sym_for] = ACTIONS(3473),
    [anon_sym_lock] = ACTIONS(3473),
    [anon_sym_yield] = ACTIONS(3473),
    [anon_sym_switch] = ACTIONS(3473),
    [anon_sym_default] = ACTIONS(3473),
    [anon_sym_throw] = ACTIONS(3473),
    [anon_sym_try] = ACTIONS(3473),
    [anon_sym_when] = ACTIONS(3473),
    [anon_sym_await] = ACTIONS(3473),
    [anon_sym_foreach] = ACTIONS(3473),
    [anon_sym_goto] = ACTIONS(3473),
    [anon_sym_if] = ACTIONS(3473),
    [anon_sym_DOT_DOT] = ACTIONS(3475),
    [anon_sym_from] = ACTIONS(3473),
    [anon_sym_into] = ACTIONS(3473),
    [anon_sym_join] = ACTIONS(3473),
    [anon_sym_on] = ACTIONS(3473),
    [anon_sym_equals] = ACTIONS(3473),
    [anon_sym_let] = ACTIONS(3473),
    [anon_sym_orderby] = ACTIONS(3473),
    [anon_sym_ascending] = ACTIONS(3473),
    [anon_sym_descending] = ACTIONS(3473),
    [anon_sym_group] = ACTIONS(3473),
    [anon_sym_by] = ACTIONS(3473),
    [anon_sym_select] = ACTIONS(3473),
    [anon_sym_stackalloc] = ACTIONS(3473),
    [anon_sym_sizeof] = ACTIONS(3473),
    [anon_sym_typeof] = ACTIONS(3473),
    [anon_sym___makeref] = ACTIONS(3473),
    [anon_sym___reftype] = ACTIONS(3473),
    [anon_sym___refvalue] = ACTIONS(3473),
    [sym_null_literal] = ACTIONS(3473),
    [anon_sym_SQUOTE] = ACTIONS(3475),
    [sym_integer_literal] = ACTIONS(3473),
    [sym_real_literal] = ACTIONS(3475),
    [anon_sym_DQUOTE] = ACTIONS(3475),
    [sym_verbatim_string_literal] = ACTIONS(3475),
    [aux_sym_preproc_if_token1] = ACTIONS(3475),
    [aux_sym_preproc_if_token3] = ACTIONS(3475),
    [aux_sym_preproc_else_token1] = ACTIONS(3475),
    [aux_sym_preproc_elif_token1] = ACTIONS(3475),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3475),
    [sym_interpolation_verbatim_start] = ACTIONS(3475),
    [sym_interpolation_raw_start] = ACTIONS(3475),
    [sym_raw_string_start] = ACTIONS(3475),
  },
  [2324] = {
    [sym_preproc_region] = STATE(2324),
    [sym_preproc_endregion] = STATE(2324),
    [sym_preproc_line] = STATE(2324),
    [sym_preproc_pragma] = STATE(2324),
    [sym_preproc_nullable] = STATE(2324),
    [sym_preproc_error] = STATE(2324),
    [sym_preproc_warning] = STATE(2324),
    [sym_preproc_define] = STATE(2324),
    [sym_preproc_undef] = STATE(2324),
    [sym__identifier_token] = ACTIONS(3477),
    [anon_sym_extern] = ACTIONS(3477),
    [anon_sym_alias] = ACTIONS(3477),
    [anon_sym_SEMI] = ACTIONS(3479),
    [anon_sym_global] = ACTIONS(3477),
    [anon_sym_using] = ACTIONS(3477),
    [anon_sym_unsafe] = ACTIONS(3477),
    [anon_sym_static] = ACTIONS(3477),
    [anon_sym_LBRACK] = ACTIONS(3479),
    [anon_sym_LPAREN] = ACTIONS(3479),
    [anon_sym_return] = ACTIONS(3477),
    [anon_sym_namespace] = ACTIONS(3477),
    [anon_sym_class] = ACTIONS(3477),
    [anon_sym_ref] = ACTIONS(3477),
    [anon_sym_struct] = ACTIONS(3477),
    [anon_sym_enum] = ACTIONS(3477),
    [anon_sym_LBRACE] = ACTIONS(3479),
    [anon_sym_interface] = ACTIONS(3477),
    [anon_sym_delegate] = ACTIONS(3477),
    [anon_sym_record] = ACTIONS(3477),
    [anon_sym_abstract] = ACTIONS(3477),
    [anon_sym_async] = ACTIONS(3477),
    [anon_sym_const] = ACTIONS(3477),
    [anon_sym_file] = ACTIONS(3477),
    [anon_sym_fixed] = ACTIONS(3477),
    [anon_sym_internal] = ACTIONS(3477),
    [anon_sym_new] = ACTIONS(3477),
    [anon_sym_override] = ACTIONS(3477),
    [anon_sym_partial] = ACTIONS(3477),
    [anon_sym_private] = ACTIONS(3477),
    [anon_sym_protected] = ACTIONS(3477),
    [anon_sym_public] = ACTIONS(3477),
    [anon_sym_readonly] = ACTIONS(3477),
    [anon_sym_required] = ACTIONS(3477),
    [anon_sym_sealed] = ACTIONS(3477),
    [anon_sym_virtual] = ACTIONS(3477),
    [anon_sym_volatile] = ACTIONS(3477),
    [anon_sym_where] = ACTIONS(3477),
    [anon_sym_notnull] = ACTIONS(3477),
    [anon_sym_unmanaged] = ACTIONS(3477),
    [anon_sym_checked] = ACTIONS(3477),
    [anon_sym_BANG] = ACTIONS(3479),
    [anon_sym_TILDE] = ACTIONS(3479),
    [anon_sym_PLUS_PLUS] = ACTIONS(3479),
    [anon_sym_DASH_DASH] = ACTIONS(3479),
    [anon_sym_true] = ACTIONS(3477),
    [anon_sym_false] = ACTIONS(3477),
    [anon_sym_PLUS] = ACTIONS(3477),
    [anon_sym_DASH] = ACTIONS(3477),
    [anon_sym_STAR] = ACTIONS(3479),
    [anon_sym_CARET] = ACTIONS(3479),
    [anon_sym_AMP] = ACTIONS(3479),
    [anon_sym_this] = ACTIONS(3477),
    [anon_sym_scoped] = ACTIONS(3477),
    [anon_sym_base] = ACTIONS(3477),
    [anon_sym_var] = ACTIONS(3477),
    [sym_predefined_type] = ACTIONS(3477),
    [anon_sym_break] = ACTIONS(3477),
    [anon_sym_unchecked] = ACTIONS(3477),
    [anon_sym_continue] = ACTIONS(3477),
    [anon_sym_do] = ACTIONS(3477),
    [anon_sym_while] = ACTIONS(3477),
    [anon_sym_for] = ACTIONS(3477),
    [anon_sym_lock] = ACTIONS(3477),
    [anon_sym_yield] = ACTIONS(3477),
    [anon_sym_switch] = ACTIONS(3477),
    [anon_sym_default] = ACTIONS(3477),
    [anon_sym_throw] = ACTIONS(3477),
    [anon_sym_try] = ACTIONS(3477),
    [anon_sym_when] = ACTIONS(3477),
    [anon_sym_await] = ACTIONS(3477),
    [anon_sym_foreach] = ACTIONS(3477),
    [anon_sym_goto] = ACTIONS(3477),
    [anon_sym_if] = ACTIONS(3477),
    [anon_sym_DOT_DOT] = ACTIONS(3479),
    [anon_sym_from] = ACTIONS(3477),
    [anon_sym_into] = ACTIONS(3477),
    [anon_sym_join] = ACTIONS(3477),
    [anon_sym_on] = ACTIONS(3477),
    [anon_sym_equals] = ACTIONS(3477),
    [anon_sym_let] = ACTIONS(3477),
    [anon_sym_orderby] = ACTIONS(3477),
    [anon_sym_ascending] = ACTIONS(3477),
    [anon_sym_descending] = ACTIONS(3477),
    [anon_sym_group] = ACTIONS(3477),
    [anon_sym_by] = ACTIONS(3477),
    [anon_sym_select] = ACTIONS(3477),
    [anon_sym_stackalloc] = ACTIONS(3477),
    [anon_sym_sizeof] = ACTIONS(3477),
    [anon_sym_typeof] = ACTIONS(3477),
    [anon_sym___makeref] = ACTIONS(3477),
    [anon_sym___reftype] = ACTIONS(3477),
    [anon_sym___refvalue] = ACTIONS(3477),
    [sym_null_literal] = ACTIONS(3477),
    [anon_sym_SQUOTE] = ACTIONS(3479),
    [sym_integer_literal] = ACTIONS(3477),
    [sym_real_literal] = ACTIONS(3479),
    [anon_sym_DQUOTE] = ACTIONS(3479),
    [sym_verbatim_string_literal] = ACTIONS(3479),
    [aux_sym_preproc_if_token1] = ACTIONS(3479),
    [aux_sym_preproc_if_token3] = ACTIONS(3479),
    [aux_sym_preproc_else_token1] = ACTIONS(3479),
    [aux_sym_preproc_elif_token1] = ACTIONS(3479),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3479),
    [sym_interpolation_verbatim_start] = ACTIONS(3479),
    [sym_interpolation_raw_start] = ACTIONS(3479),
    [sym_raw_string_start] = ACTIONS(3479),
  },
  [2325] = {
    [sym_preproc_region] = STATE(2325),
    [sym_preproc_endregion] = STATE(2325),
    [sym_preproc_line] = STATE(2325),
    [sym_preproc_pragma] = STATE(2325),
    [sym_preproc_nullable] = STATE(2325),
    [sym_preproc_error] = STATE(2325),
    [sym_preproc_warning] = STATE(2325),
    [sym_preproc_define] = STATE(2325),
    [sym_preproc_undef] = STATE(2325),
    [sym__identifier_token] = ACTIONS(3481),
    [anon_sym_extern] = ACTIONS(3481),
    [anon_sym_alias] = ACTIONS(3481),
    [anon_sym_SEMI] = ACTIONS(3483),
    [anon_sym_global] = ACTIONS(3481),
    [anon_sym_using] = ACTIONS(3481),
    [anon_sym_unsafe] = ACTIONS(3481),
    [anon_sym_static] = ACTIONS(3481),
    [anon_sym_LBRACK] = ACTIONS(3483),
    [anon_sym_LPAREN] = ACTIONS(3483),
    [anon_sym_return] = ACTIONS(3481),
    [anon_sym_namespace] = ACTIONS(3481),
    [anon_sym_class] = ACTIONS(3481),
    [anon_sym_ref] = ACTIONS(3481),
    [anon_sym_struct] = ACTIONS(3481),
    [anon_sym_enum] = ACTIONS(3481),
    [anon_sym_LBRACE] = ACTIONS(3483),
    [anon_sym_interface] = ACTIONS(3481),
    [anon_sym_delegate] = ACTIONS(3481),
    [anon_sym_record] = ACTIONS(3481),
    [anon_sym_abstract] = ACTIONS(3481),
    [anon_sym_async] = ACTIONS(3481),
    [anon_sym_const] = ACTIONS(3481),
    [anon_sym_file] = ACTIONS(3481),
    [anon_sym_fixed] = ACTIONS(3481),
    [anon_sym_internal] = ACTIONS(3481),
    [anon_sym_new] = ACTIONS(3481),
    [anon_sym_override] = ACTIONS(3481),
    [anon_sym_partial] = ACTIONS(3481),
    [anon_sym_private] = ACTIONS(3481),
    [anon_sym_protected] = ACTIONS(3481),
    [anon_sym_public] = ACTIONS(3481),
    [anon_sym_readonly] = ACTIONS(3481),
    [anon_sym_required] = ACTIONS(3481),
    [anon_sym_sealed] = ACTIONS(3481),
    [anon_sym_virtual] = ACTIONS(3481),
    [anon_sym_volatile] = ACTIONS(3481),
    [anon_sym_where] = ACTIONS(3481),
    [anon_sym_notnull] = ACTIONS(3481),
    [anon_sym_unmanaged] = ACTIONS(3481),
    [anon_sym_checked] = ACTIONS(3481),
    [anon_sym_BANG] = ACTIONS(3483),
    [anon_sym_TILDE] = ACTIONS(3483),
    [anon_sym_PLUS_PLUS] = ACTIONS(3483),
    [anon_sym_DASH_DASH] = ACTIONS(3483),
    [anon_sym_true] = ACTIONS(3481),
    [anon_sym_false] = ACTIONS(3481),
    [anon_sym_PLUS] = ACTIONS(3481),
    [anon_sym_DASH] = ACTIONS(3481),
    [anon_sym_STAR] = ACTIONS(3483),
    [anon_sym_CARET] = ACTIONS(3483),
    [anon_sym_AMP] = ACTIONS(3483),
    [anon_sym_this] = ACTIONS(3481),
    [anon_sym_scoped] = ACTIONS(3481),
    [anon_sym_base] = ACTIONS(3481),
    [anon_sym_var] = ACTIONS(3481),
    [sym_predefined_type] = ACTIONS(3481),
    [anon_sym_break] = ACTIONS(3481),
    [anon_sym_unchecked] = ACTIONS(3481),
    [anon_sym_continue] = ACTIONS(3481),
    [anon_sym_do] = ACTIONS(3481),
    [anon_sym_while] = ACTIONS(3481),
    [anon_sym_for] = ACTIONS(3481),
    [anon_sym_lock] = ACTIONS(3481),
    [anon_sym_yield] = ACTIONS(3481),
    [anon_sym_switch] = ACTIONS(3481),
    [anon_sym_default] = ACTIONS(3481),
    [anon_sym_throw] = ACTIONS(3481),
    [anon_sym_try] = ACTIONS(3481),
    [anon_sym_when] = ACTIONS(3481),
    [anon_sym_await] = ACTIONS(3481),
    [anon_sym_foreach] = ACTIONS(3481),
    [anon_sym_goto] = ACTIONS(3481),
    [anon_sym_if] = ACTIONS(3481),
    [anon_sym_DOT_DOT] = ACTIONS(3483),
    [anon_sym_from] = ACTIONS(3481),
    [anon_sym_into] = ACTIONS(3481),
    [anon_sym_join] = ACTIONS(3481),
    [anon_sym_on] = ACTIONS(3481),
    [anon_sym_equals] = ACTIONS(3481),
    [anon_sym_let] = ACTIONS(3481),
    [anon_sym_orderby] = ACTIONS(3481),
    [anon_sym_ascending] = ACTIONS(3481),
    [anon_sym_descending] = ACTIONS(3481),
    [anon_sym_group] = ACTIONS(3481),
    [anon_sym_by] = ACTIONS(3481),
    [anon_sym_select] = ACTIONS(3481),
    [anon_sym_stackalloc] = ACTIONS(3481),
    [anon_sym_sizeof] = ACTIONS(3481),
    [anon_sym_typeof] = ACTIONS(3481),
    [anon_sym___makeref] = ACTIONS(3481),
    [anon_sym___reftype] = ACTIONS(3481),
    [anon_sym___refvalue] = ACTIONS(3481),
    [sym_null_literal] = ACTIONS(3481),
    [anon_sym_SQUOTE] = ACTIONS(3483),
    [sym_integer_literal] = ACTIONS(3481),
    [sym_real_literal] = ACTIONS(3483),
    [anon_sym_DQUOTE] = ACTIONS(3483),
    [sym_verbatim_string_literal] = ACTIONS(3483),
    [aux_sym_preproc_if_token1] = ACTIONS(3483),
    [aux_sym_preproc_if_token3] = ACTIONS(3483),
    [aux_sym_preproc_else_token1] = ACTIONS(3483),
    [aux_sym_preproc_elif_token1] = ACTIONS(3483),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3483),
    [sym_interpolation_verbatim_start] = ACTIONS(3483),
    [sym_interpolation_raw_start] = ACTIONS(3483),
    [sym_raw_string_start] = ACTIONS(3483),
  },
  [2326] = {
    [sym_preproc_region] = STATE(2326),
    [sym_preproc_endregion] = STATE(2326),
    [sym_preproc_line] = STATE(2326),
    [sym_preproc_pragma] = STATE(2326),
    [sym_preproc_nullable] = STATE(2326),
    [sym_preproc_error] = STATE(2326),
    [sym_preproc_warning] = STATE(2326),
    [sym_preproc_define] = STATE(2326),
    [sym_preproc_undef] = STATE(2326),
    [sym__identifier_token] = ACTIONS(3485),
    [anon_sym_extern] = ACTIONS(3485),
    [anon_sym_alias] = ACTIONS(3485),
    [anon_sym_SEMI] = ACTIONS(3487),
    [anon_sym_global] = ACTIONS(3485),
    [anon_sym_using] = ACTIONS(3485),
    [anon_sym_unsafe] = ACTIONS(3485),
    [anon_sym_static] = ACTIONS(3485),
    [anon_sym_LBRACK] = ACTIONS(3487),
    [anon_sym_LPAREN] = ACTIONS(3487),
    [anon_sym_return] = ACTIONS(3485),
    [anon_sym_namespace] = ACTIONS(3485),
    [anon_sym_class] = ACTIONS(3485),
    [anon_sym_ref] = ACTIONS(3485),
    [anon_sym_struct] = ACTIONS(3485),
    [anon_sym_enum] = ACTIONS(3485),
    [anon_sym_LBRACE] = ACTIONS(3487),
    [anon_sym_interface] = ACTIONS(3485),
    [anon_sym_delegate] = ACTIONS(3485),
    [anon_sym_record] = ACTIONS(3485),
    [anon_sym_abstract] = ACTIONS(3485),
    [anon_sym_async] = ACTIONS(3485),
    [anon_sym_const] = ACTIONS(3485),
    [anon_sym_file] = ACTIONS(3485),
    [anon_sym_fixed] = ACTIONS(3485),
    [anon_sym_internal] = ACTIONS(3485),
    [anon_sym_new] = ACTIONS(3485),
    [anon_sym_override] = ACTIONS(3485),
    [anon_sym_partial] = ACTIONS(3485),
    [anon_sym_private] = ACTIONS(3485),
    [anon_sym_protected] = ACTIONS(3485),
    [anon_sym_public] = ACTIONS(3485),
    [anon_sym_readonly] = ACTIONS(3485),
    [anon_sym_required] = ACTIONS(3485),
    [anon_sym_sealed] = ACTIONS(3485),
    [anon_sym_virtual] = ACTIONS(3485),
    [anon_sym_volatile] = ACTIONS(3485),
    [anon_sym_where] = ACTIONS(3485),
    [anon_sym_notnull] = ACTIONS(3485),
    [anon_sym_unmanaged] = ACTIONS(3485),
    [anon_sym_checked] = ACTIONS(3485),
    [anon_sym_BANG] = ACTIONS(3487),
    [anon_sym_TILDE] = ACTIONS(3487),
    [anon_sym_PLUS_PLUS] = ACTIONS(3487),
    [anon_sym_DASH_DASH] = ACTIONS(3487),
    [anon_sym_true] = ACTIONS(3485),
    [anon_sym_false] = ACTIONS(3485),
    [anon_sym_PLUS] = ACTIONS(3485),
    [anon_sym_DASH] = ACTIONS(3485),
    [anon_sym_STAR] = ACTIONS(3487),
    [anon_sym_CARET] = ACTIONS(3487),
    [anon_sym_AMP] = ACTIONS(3487),
    [anon_sym_this] = ACTIONS(3485),
    [anon_sym_scoped] = ACTIONS(3485),
    [anon_sym_base] = ACTIONS(3485),
    [anon_sym_var] = ACTIONS(3485),
    [sym_predefined_type] = ACTIONS(3485),
    [anon_sym_break] = ACTIONS(3485),
    [anon_sym_unchecked] = ACTIONS(3485),
    [anon_sym_continue] = ACTIONS(3485),
    [anon_sym_do] = ACTIONS(3485),
    [anon_sym_while] = ACTIONS(3485),
    [anon_sym_for] = ACTIONS(3485),
    [anon_sym_lock] = ACTIONS(3485),
    [anon_sym_yield] = ACTIONS(3485),
    [anon_sym_switch] = ACTIONS(3485),
    [anon_sym_default] = ACTIONS(3485),
    [anon_sym_throw] = ACTIONS(3485),
    [anon_sym_try] = ACTIONS(3485),
    [anon_sym_when] = ACTIONS(3485),
    [anon_sym_await] = ACTIONS(3485),
    [anon_sym_foreach] = ACTIONS(3485),
    [anon_sym_goto] = ACTIONS(3485),
    [anon_sym_if] = ACTIONS(3485),
    [anon_sym_DOT_DOT] = ACTIONS(3487),
    [anon_sym_from] = ACTIONS(3485),
    [anon_sym_into] = ACTIONS(3485),
    [anon_sym_join] = ACTIONS(3485),
    [anon_sym_on] = ACTIONS(3485),
    [anon_sym_equals] = ACTIONS(3485),
    [anon_sym_let] = ACTIONS(3485),
    [anon_sym_orderby] = ACTIONS(3485),
    [anon_sym_ascending] = ACTIONS(3485),
    [anon_sym_descending] = ACTIONS(3485),
    [anon_sym_group] = ACTIONS(3485),
    [anon_sym_by] = ACTIONS(3485),
    [anon_sym_select] = ACTIONS(3485),
    [anon_sym_stackalloc] = ACTIONS(3485),
    [anon_sym_sizeof] = ACTIONS(3485),
    [anon_sym_typeof] = ACTIONS(3485),
    [anon_sym___makeref] = ACTIONS(3485),
    [anon_sym___reftype] = ACTIONS(3485),
    [anon_sym___refvalue] = ACTIONS(3485),
    [sym_null_literal] = ACTIONS(3485),
    [anon_sym_SQUOTE] = ACTIONS(3487),
    [sym_integer_literal] = ACTIONS(3485),
    [sym_real_literal] = ACTIONS(3487),
    [anon_sym_DQUOTE] = ACTIONS(3487),
    [sym_verbatim_string_literal] = ACTIONS(3487),
    [aux_sym_preproc_if_token1] = ACTIONS(3487),
    [aux_sym_preproc_if_token3] = ACTIONS(3487),
    [aux_sym_preproc_else_token1] = ACTIONS(3487),
    [aux_sym_preproc_elif_token1] = ACTIONS(3487),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3487),
    [sym_interpolation_verbatim_start] = ACTIONS(3487),
    [sym_interpolation_raw_start] = ACTIONS(3487),
    [sym_raw_string_start] = ACTIONS(3487),
  },
  [2327] = {
    [sym_preproc_region] = STATE(2327),
    [sym_preproc_endregion] = STATE(2327),
    [sym_preproc_line] = STATE(2327),
    [sym_preproc_pragma] = STATE(2327),
    [sym_preproc_nullable] = STATE(2327),
    [sym_preproc_error] = STATE(2327),
    [sym_preproc_warning] = STATE(2327),
    [sym_preproc_define] = STATE(2327),
    [sym_preproc_undef] = STATE(2327),
    [sym__identifier_token] = ACTIONS(3489),
    [anon_sym_extern] = ACTIONS(3489),
    [anon_sym_alias] = ACTIONS(3489),
    [anon_sym_SEMI] = ACTIONS(3491),
    [anon_sym_global] = ACTIONS(3489),
    [anon_sym_using] = ACTIONS(3489),
    [anon_sym_unsafe] = ACTIONS(3489),
    [anon_sym_static] = ACTIONS(3489),
    [anon_sym_LBRACK] = ACTIONS(3491),
    [anon_sym_LPAREN] = ACTIONS(3491),
    [anon_sym_return] = ACTIONS(3489),
    [anon_sym_namespace] = ACTIONS(3489),
    [anon_sym_class] = ACTIONS(3489),
    [anon_sym_ref] = ACTIONS(3489),
    [anon_sym_struct] = ACTIONS(3489),
    [anon_sym_enum] = ACTIONS(3489),
    [anon_sym_LBRACE] = ACTIONS(3491),
    [anon_sym_interface] = ACTIONS(3489),
    [anon_sym_delegate] = ACTIONS(3489),
    [anon_sym_record] = ACTIONS(3489),
    [anon_sym_abstract] = ACTIONS(3489),
    [anon_sym_async] = ACTIONS(3489),
    [anon_sym_const] = ACTIONS(3489),
    [anon_sym_file] = ACTIONS(3489),
    [anon_sym_fixed] = ACTIONS(3489),
    [anon_sym_internal] = ACTIONS(3489),
    [anon_sym_new] = ACTIONS(3489),
    [anon_sym_override] = ACTIONS(3489),
    [anon_sym_partial] = ACTIONS(3489),
    [anon_sym_private] = ACTIONS(3489),
    [anon_sym_protected] = ACTIONS(3489),
    [anon_sym_public] = ACTIONS(3489),
    [anon_sym_readonly] = ACTIONS(3489),
    [anon_sym_required] = ACTIONS(3489),
    [anon_sym_sealed] = ACTIONS(3489),
    [anon_sym_virtual] = ACTIONS(3489),
    [anon_sym_volatile] = ACTIONS(3489),
    [anon_sym_where] = ACTIONS(3489),
    [anon_sym_notnull] = ACTIONS(3489),
    [anon_sym_unmanaged] = ACTIONS(3489),
    [anon_sym_checked] = ACTIONS(3489),
    [anon_sym_BANG] = ACTIONS(3491),
    [anon_sym_TILDE] = ACTIONS(3491),
    [anon_sym_PLUS_PLUS] = ACTIONS(3491),
    [anon_sym_DASH_DASH] = ACTIONS(3491),
    [anon_sym_true] = ACTIONS(3489),
    [anon_sym_false] = ACTIONS(3489),
    [anon_sym_PLUS] = ACTIONS(3489),
    [anon_sym_DASH] = ACTIONS(3489),
    [anon_sym_STAR] = ACTIONS(3491),
    [anon_sym_CARET] = ACTIONS(3491),
    [anon_sym_AMP] = ACTIONS(3491),
    [anon_sym_this] = ACTIONS(3489),
    [anon_sym_scoped] = ACTIONS(3489),
    [anon_sym_base] = ACTIONS(3489),
    [anon_sym_var] = ACTIONS(3489),
    [sym_predefined_type] = ACTIONS(3489),
    [anon_sym_break] = ACTIONS(3489),
    [anon_sym_unchecked] = ACTIONS(3489),
    [anon_sym_continue] = ACTIONS(3489),
    [anon_sym_do] = ACTIONS(3489),
    [anon_sym_while] = ACTIONS(3489),
    [anon_sym_for] = ACTIONS(3489),
    [anon_sym_lock] = ACTIONS(3489),
    [anon_sym_yield] = ACTIONS(3489),
    [anon_sym_switch] = ACTIONS(3489),
    [anon_sym_default] = ACTIONS(3489),
    [anon_sym_throw] = ACTIONS(3489),
    [anon_sym_try] = ACTIONS(3489),
    [anon_sym_when] = ACTIONS(3489),
    [anon_sym_await] = ACTIONS(3489),
    [anon_sym_foreach] = ACTIONS(3489),
    [anon_sym_goto] = ACTIONS(3489),
    [anon_sym_if] = ACTIONS(3489),
    [anon_sym_DOT_DOT] = ACTIONS(3491),
    [anon_sym_from] = ACTIONS(3489),
    [anon_sym_into] = ACTIONS(3489),
    [anon_sym_join] = ACTIONS(3489),
    [anon_sym_on] = ACTIONS(3489),
    [anon_sym_equals] = ACTIONS(3489),
    [anon_sym_let] = ACTIONS(3489),
    [anon_sym_orderby] = ACTIONS(3489),
    [anon_sym_ascending] = ACTIONS(3489),
    [anon_sym_descending] = ACTIONS(3489),
    [anon_sym_group] = ACTIONS(3489),
    [anon_sym_by] = ACTIONS(3489),
    [anon_sym_select] = ACTIONS(3489),
    [anon_sym_stackalloc] = ACTIONS(3489),
    [anon_sym_sizeof] = ACTIONS(3489),
    [anon_sym_typeof] = ACTIONS(3489),
    [anon_sym___makeref] = ACTIONS(3489),
    [anon_sym___reftype] = ACTIONS(3489),
    [anon_sym___refvalue] = ACTIONS(3489),
    [sym_null_literal] = ACTIONS(3489),
    [anon_sym_SQUOTE] = ACTIONS(3491),
    [sym_integer_literal] = ACTIONS(3489),
    [sym_real_literal] = ACTIONS(3491),
    [anon_sym_DQUOTE] = ACTIONS(3491),
    [sym_verbatim_string_literal] = ACTIONS(3491),
    [aux_sym_preproc_if_token1] = ACTIONS(3491),
    [aux_sym_preproc_if_token3] = ACTIONS(3491),
    [aux_sym_preproc_else_token1] = ACTIONS(3491),
    [aux_sym_preproc_elif_token1] = ACTIONS(3491),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3491),
    [sym_interpolation_verbatim_start] = ACTIONS(3491),
    [sym_interpolation_raw_start] = ACTIONS(3491),
    [sym_raw_string_start] = ACTIONS(3491),
  },
  [2328] = {
    [sym_preproc_region] = STATE(2328),
    [sym_preproc_endregion] = STATE(2328),
    [sym_preproc_line] = STATE(2328),
    [sym_preproc_pragma] = STATE(2328),
    [sym_preproc_nullable] = STATE(2328),
    [sym_preproc_error] = STATE(2328),
    [sym_preproc_warning] = STATE(2328),
    [sym_preproc_define] = STATE(2328),
    [sym_preproc_undef] = STATE(2328),
    [sym__identifier_token] = ACTIONS(3493),
    [anon_sym_extern] = ACTIONS(3493),
    [anon_sym_alias] = ACTIONS(3493),
    [anon_sym_SEMI] = ACTIONS(3495),
    [anon_sym_global] = ACTIONS(3493),
    [anon_sym_using] = ACTIONS(3493),
    [anon_sym_unsafe] = ACTIONS(3493),
    [anon_sym_static] = ACTIONS(3493),
    [anon_sym_LBRACK] = ACTIONS(3495),
    [anon_sym_LPAREN] = ACTIONS(3495),
    [anon_sym_return] = ACTIONS(3493),
    [anon_sym_namespace] = ACTIONS(3493),
    [anon_sym_class] = ACTIONS(3493),
    [anon_sym_ref] = ACTIONS(3493),
    [anon_sym_struct] = ACTIONS(3493),
    [anon_sym_enum] = ACTIONS(3493),
    [anon_sym_LBRACE] = ACTIONS(3495),
    [anon_sym_interface] = ACTIONS(3493),
    [anon_sym_delegate] = ACTIONS(3493),
    [anon_sym_record] = ACTIONS(3493),
    [anon_sym_abstract] = ACTIONS(3493),
    [anon_sym_async] = ACTIONS(3493),
    [anon_sym_const] = ACTIONS(3493),
    [anon_sym_file] = ACTIONS(3493),
    [anon_sym_fixed] = ACTIONS(3493),
    [anon_sym_internal] = ACTIONS(3493),
    [anon_sym_new] = ACTIONS(3493),
    [anon_sym_override] = ACTIONS(3493),
    [anon_sym_partial] = ACTIONS(3493),
    [anon_sym_private] = ACTIONS(3493),
    [anon_sym_protected] = ACTIONS(3493),
    [anon_sym_public] = ACTIONS(3493),
    [anon_sym_readonly] = ACTIONS(3493),
    [anon_sym_required] = ACTIONS(3493),
    [anon_sym_sealed] = ACTIONS(3493),
    [anon_sym_virtual] = ACTIONS(3493),
    [anon_sym_volatile] = ACTIONS(3493),
    [anon_sym_where] = ACTIONS(3493),
    [anon_sym_notnull] = ACTIONS(3493),
    [anon_sym_unmanaged] = ACTIONS(3493),
    [anon_sym_checked] = ACTIONS(3493),
    [anon_sym_BANG] = ACTIONS(3495),
    [anon_sym_TILDE] = ACTIONS(3495),
    [anon_sym_PLUS_PLUS] = ACTIONS(3495),
    [anon_sym_DASH_DASH] = ACTIONS(3495),
    [anon_sym_true] = ACTIONS(3493),
    [anon_sym_false] = ACTIONS(3493),
    [anon_sym_PLUS] = ACTIONS(3493),
    [anon_sym_DASH] = ACTIONS(3493),
    [anon_sym_STAR] = ACTIONS(3495),
    [anon_sym_CARET] = ACTIONS(3495),
    [anon_sym_AMP] = ACTIONS(3495),
    [anon_sym_this] = ACTIONS(3493),
    [anon_sym_scoped] = ACTIONS(3493),
    [anon_sym_base] = ACTIONS(3493),
    [anon_sym_var] = ACTIONS(3493),
    [sym_predefined_type] = ACTIONS(3493),
    [anon_sym_break] = ACTIONS(3493),
    [anon_sym_unchecked] = ACTIONS(3493),
    [anon_sym_continue] = ACTIONS(3493),
    [anon_sym_do] = ACTIONS(3493),
    [anon_sym_while] = ACTIONS(3493),
    [anon_sym_for] = ACTIONS(3493),
    [anon_sym_lock] = ACTIONS(3493),
    [anon_sym_yield] = ACTIONS(3493),
    [anon_sym_switch] = ACTIONS(3493),
    [anon_sym_default] = ACTIONS(3493),
    [anon_sym_throw] = ACTIONS(3493),
    [anon_sym_try] = ACTIONS(3493),
    [anon_sym_when] = ACTIONS(3493),
    [anon_sym_await] = ACTIONS(3493),
    [anon_sym_foreach] = ACTIONS(3493),
    [anon_sym_goto] = ACTIONS(3493),
    [anon_sym_if] = ACTIONS(3493),
    [anon_sym_DOT_DOT] = ACTIONS(3495),
    [anon_sym_from] = ACTIONS(3493),
    [anon_sym_into] = ACTIONS(3493),
    [anon_sym_join] = ACTIONS(3493),
    [anon_sym_on] = ACTIONS(3493),
    [anon_sym_equals] = ACTIONS(3493),
    [anon_sym_let] = ACTIONS(3493),
    [anon_sym_orderby] = ACTIONS(3493),
    [anon_sym_ascending] = ACTIONS(3493),
    [anon_sym_descending] = ACTIONS(3493),
    [anon_sym_group] = ACTIONS(3493),
    [anon_sym_by] = ACTIONS(3493),
    [anon_sym_select] = ACTIONS(3493),
    [anon_sym_stackalloc] = ACTIONS(3493),
    [anon_sym_sizeof] = ACTIONS(3493),
    [anon_sym_typeof] = ACTIONS(3493),
    [anon_sym___makeref] = ACTIONS(3493),
    [anon_sym___reftype] = ACTIONS(3493),
    [anon_sym___refvalue] = ACTIONS(3493),
    [sym_null_literal] = ACTIONS(3493),
    [anon_sym_SQUOTE] = ACTIONS(3495),
    [sym_integer_literal] = ACTIONS(3493),
    [sym_real_literal] = ACTIONS(3495),
    [anon_sym_DQUOTE] = ACTIONS(3495),
    [sym_verbatim_string_literal] = ACTIONS(3495),
    [aux_sym_preproc_if_token1] = ACTIONS(3495),
    [aux_sym_preproc_if_token3] = ACTIONS(3495),
    [aux_sym_preproc_else_token1] = ACTIONS(3495),
    [aux_sym_preproc_elif_token1] = ACTIONS(3495),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3495),
    [sym_interpolation_verbatim_start] = ACTIONS(3495),
    [sym_interpolation_raw_start] = ACTIONS(3495),
    [sym_raw_string_start] = ACTIONS(3495),
  },
  [2329] = {
    [sym_preproc_region] = STATE(2329),
    [sym_preproc_endregion] = STATE(2329),
    [sym_preproc_line] = STATE(2329),
    [sym_preproc_pragma] = STATE(2329),
    [sym_preproc_nullable] = STATE(2329),
    [sym_preproc_error] = STATE(2329),
    [sym_preproc_warning] = STATE(2329),
    [sym_preproc_define] = STATE(2329),
    [sym_preproc_undef] = STATE(2329),
    [sym__identifier_token] = ACTIONS(3277),
    [anon_sym_extern] = ACTIONS(3277),
    [anon_sym_alias] = ACTIONS(3277),
    [anon_sym_SEMI] = ACTIONS(3279),
    [anon_sym_global] = ACTIONS(3277),
    [anon_sym_using] = ACTIONS(3277),
    [anon_sym_unsafe] = ACTIONS(3277),
    [anon_sym_static] = ACTIONS(3277),
    [anon_sym_LBRACK] = ACTIONS(3279),
    [anon_sym_LPAREN] = ACTIONS(3279),
    [anon_sym_return] = ACTIONS(3277),
    [anon_sym_namespace] = ACTIONS(3277),
    [anon_sym_class] = ACTIONS(3277),
    [anon_sym_ref] = ACTIONS(3277),
    [anon_sym_struct] = ACTIONS(3277),
    [anon_sym_enum] = ACTIONS(3277),
    [anon_sym_LBRACE] = ACTIONS(3279),
    [anon_sym_interface] = ACTIONS(3277),
    [anon_sym_delegate] = ACTIONS(3277),
    [anon_sym_record] = ACTIONS(3277),
    [anon_sym_abstract] = ACTIONS(3277),
    [anon_sym_async] = ACTIONS(3277),
    [anon_sym_const] = ACTIONS(3277),
    [anon_sym_file] = ACTIONS(3277),
    [anon_sym_fixed] = ACTIONS(3277),
    [anon_sym_internal] = ACTIONS(3277),
    [anon_sym_new] = ACTIONS(3277),
    [anon_sym_override] = ACTIONS(3277),
    [anon_sym_partial] = ACTIONS(3277),
    [anon_sym_private] = ACTIONS(3277),
    [anon_sym_protected] = ACTIONS(3277),
    [anon_sym_public] = ACTIONS(3277),
    [anon_sym_readonly] = ACTIONS(3277),
    [anon_sym_required] = ACTIONS(3277),
    [anon_sym_sealed] = ACTIONS(3277),
    [anon_sym_virtual] = ACTIONS(3277),
    [anon_sym_volatile] = ACTIONS(3277),
    [anon_sym_where] = ACTIONS(3277),
    [anon_sym_notnull] = ACTIONS(3277),
    [anon_sym_unmanaged] = ACTIONS(3277),
    [anon_sym_checked] = ACTIONS(3277),
    [anon_sym_BANG] = ACTIONS(3279),
    [anon_sym_TILDE] = ACTIONS(3279),
    [anon_sym_PLUS_PLUS] = ACTIONS(3279),
    [anon_sym_DASH_DASH] = ACTIONS(3279),
    [anon_sym_true] = ACTIONS(3277),
    [anon_sym_false] = ACTIONS(3277),
    [anon_sym_PLUS] = ACTIONS(3277),
    [anon_sym_DASH] = ACTIONS(3277),
    [anon_sym_STAR] = ACTIONS(3279),
    [anon_sym_CARET] = ACTIONS(3279),
    [anon_sym_AMP] = ACTIONS(3279),
    [anon_sym_this] = ACTIONS(3277),
    [anon_sym_scoped] = ACTIONS(3277),
    [anon_sym_base] = ACTIONS(3277),
    [anon_sym_var] = ACTIONS(3277),
    [sym_predefined_type] = ACTIONS(3277),
    [anon_sym_break] = ACTIONS(3277),
    [anon_sym_unchecked] = ACTIONS(3277),
    [anon_sym_continue] = ACTIONS(3277),
    [anon_sym_do] = ACTIONS(3277),
    [anon_sym_while] = ACTIONS(3277),
    [anon_sym_for] = ACTIONS(3277),
    [anon_sym_lock] = ACTIONS(3277),
    [anon_sym_yield] = ACTIONS(3277),
    [anon_sym_switch] = ACTIONS(3277),
    [anon_sym_default] = ACTIONS(3277),
    [anon_sym_throw] = ACTIONS(3277),
    [anon_sym_try] = ACTIONS(3277),
    [anon_sym_when] = ACTIONS(3277),
    [anon_sym_await] = ACTIONS(3277),
    [anon_sym_foreach] = ACTIONS(3277),
    [anon_sym_goto] = ACTIONS(3277),
    [anon_sym_if] = ACTIONS(3277),
    [anon_sym_DOT_DOT] = ACTIONS(3279),
    [anon_sym_from] = ACTIONS(3277),
    [anon_sym_into] = ACTIONS(3277),
    [anon_sym_join] = ACTIONS(3277),
    [anon_sym_on] = ACTIONS(3277),
    [anon_sym_equals] = ACTIONS(3277),
    [anon_sym_let] = ACTIONS(3277),
    [anon_sym_orderby] = ACTIONS(3277),
    [anon_sym_ascending] = ACTIONS(3277),
    [anon_sym_descending] = ACTIONS(3277),
    [anon_sym_group] = ACTIONS(3277),
    [anon_sym_by] = ACTIONS(3277),
    [anon_sym_select] = ACTIONS(3277),
    [anon_sym_stackalloc] = ACTIONS(3277),
    [anon_sym_sizeof] = ACTIONS(3277),
    [anon_sym_typeof] = ACTIONS(3277),
    [anon_sym___makeref] = ACTIONS(3277),
    [anon_sym___reftype] = ACTIONS(3277),
    [anon_sym___refvalue] = ACTIONS(3277),
    [sym_null_literal] = ACTIONS(3277),
    [anon_sym_SQUOTE] = ACTIONS(3279),
    [sym_integer_literal] = ACTIONS(3277),
    [sym_real_literal] = ACTIONS(3279),
    [anon_sym_DQUOTE] = ACTIONS(3279),
    [sym_verbatim_string_literal] = ACTIONS(3279),
    [aux_sym_preproc_if_token1] = ACTIONS(3279),
    [aux_sym_preproc_if_token3] = ACTIONS(3279),
    [aux_sym_preproc_else_token1] = ACTIONS(3279),
    [aux_sym_preproc_elif_token1] = ACTIONS(3279),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3279),
    [sym_interpolation_verbatim_start] = ACTIONS(3279),
    [sym_interpolation_raw_start] = ACTIONS(3279),
    [sym_raw_string_start] = ACTIONS(3279),
  },
  [2330] = {
    [sym_preproc_region] = STATE(2330),
    [sym_preproc_endregion] = STATE(2330),
    [sym_preproc_line] = STATE(2330),
    [sym_preproc_pragma] = STATE(2330),
    [sym_preproc_nullable] = STATE(2330),
    [sym_preproc_error] = STATE(2330),
    [sym_preproc_warning] = STATE(2330),
    [sym_preproc_define] = STATE(2330),
    [sym_preproc_undef] = STATE(2330),
    [sym__identifier_token] = ACTIONS(3497),
    [anon_sym_extern] = ACTIONS(3497),
    [anon_sym_alias] = ACTIONS(3497),
    [anon_sym_SEMI] = ACTIONS(3499),
    [anon_sym_global] = ACTIONS(3497),
    [anon_sym_using] = ACTIONS(3497),
    [anon_sym_unsafe] = ACTIONS(3497),
    [anon_sym_static] = ACTIONS(3497),
    [anon_sym_LBRACK] = ACTIONS(3499),
    [anon_sym_LPAREN] = ACTIONS(3499),
    [anon_sym_return] = ACTIONS(3497),
    [anon_sym_namespace] = ACTIONS(3497),
    [anon_sym_class] = ACTIONS(3497),
    [anon_sym_ref] = ACTIONS(3497),
    [anon_sym_struct] = ACTIONS(3497),
    [anon_sym_enum] = ACTIONS(3497),
    [anon_sym_LBRACE] = ACTIONS(3499),
    [anon_sym_interface] = ACTIONS(3497),
    [anon_sym_delegate] = ACTIONS(3497),
    [anon_sym_record] = ACTIONS(3497),
    [anon_sym_abstract] = ACTIONS(3497),
    [anon_sym_async] = ACTIONS(3497),
    [anon_sym_const] = ACTIONS(3497),
    [anon_sym_file] = ACTIONS(3497),
    [anon_sym_fixed] = ACTIONS(3497),
    [anon_sym_internal] = ACTIONS(3497),
    [anon_sym_new] = ACTIONS(3497),
    [anon_sym_override] = ACTIONS(3497),
    [anon_sym_partial] = ACTIONS(3497),
    [anon_sym_private] = ACTIONS(3497),
    [anon_sym_protected] = ACTIONS(3497),
    [anon_sym_public] = ACTIONS(3497),
    [anon_sym_readonly] = ACTIONS(3497),
    [anon_sym_required] = ACTIONS(3497),
    [anon_sym_sealed] = ACTIONS(3497),
    [anon_sym_virtual] = ACTIONS(3497),
    [anon_sym_volatile] = ACTIONS(3497),
    [anon_sym_where] = ACTIONS(3497),
    [anon_sym_notnull] = ACTIONS(3497),
    [anon_sym_unmanaged] = ACTIONS(3497),
    [anon_sym_checked] = ACTIONS(3497),
    [anon_sym_BANG] = ACTIONS(3499),
    [anon_sym_TILDE] = ACTIONS(3499),
    [anon_sym_PLUS_PLUS] = ACTIONS(3499),
    [anon_sym_DASH_DASH] = ACTIONS(3499),
    [anon_sym_true] = ACTIONS(3497),
    [anon_sym_false] = ACTIONS(3497),
    [anon_sym_PLUS] = ACTIONS(3497),
    [anon_sym_DASH] = ACTIONS(3497),
    [anon_sym_STAR] = ACTIONS(3499),
    [anon_sym_CARET] = ACTIONS(3499),
    [anon_sym_AMP] = ACTIONS(3499),
    [anon_sym_this] = ACTIONS(3497),
    [anon_sym_scoped] = ACTIONS(3497),
    [anon_sym_base] = ACTIONS(3497),
    [anon_sym_var] = ACTIONS(3497),
    [sym_predefined_type] = ACTIONS(3497),
    [anon_sym_break] = ACTIONS(3497),
    [anon_sym_unchecked] = ACTIONS(3497),
    [anon_sym_continue] = ACTIONS(3497),
    [anon_sym_do] = ACTIONS(3497),
    [anon_sym_while] = ACTIONS(3497),
    [anon_sym_for] = ACTIONS(3497),
    [anon_sym_lock] = ACTIONS(3497),
    [anon_sym_yield] = ACTIONS(3497),
    [anon_sym_switch] = ACTIONS(3497),
    [anon_sym_default] = ACTIONS(3497),
    [anon_sym_throw] = ACTIONS(3497),
    [anon_sym_try] = ACTIONS(3497),
    [anon_sym_when] = ACTIONS(3497),
    [anon_sym_await] = ACTIONS(3497),
    [anon_sym_foreach] = ACTIONS(3497),
    [anon_sym_goto] = ACTIONS(3497),
    [anon_sym_if] = ACTIONS(3497),
    [anon_sym_DOT_DOT] = ACTIONS(3499),
    [anon_sym_from] = ACTIONS(3497),
    [anon_sym_into] = ACTIONS(3497),
    [anon_sym_join] = ACTIONS(3497),
    [anon_sym_on] = ACTIONS(3497),
    [anon_sym_equals] = ACTIONS(3497),
    [anon_sym_let] = ACTIONS(3497),
    [anon_sym_orderby] = ACTIONS(3497),
    [anon_sym_ascending] = ACTIONS(3497),
    [anon_sym_descending] = ACTIONS(3497),
    [anon_sym_group] = ACTIONS(3497),
    [anon_sym_by] = ACTIONS(3497),
    [anon_sym_select] = ACTIONS(3497),
    [anon_sym_stackalloc] = ACTIONS(3497),
    [anon_sym_sizeof] = ACTIONS(3497),
    [anon_sym_typeof] = ACTIONS(3497),
    [anon_sym___makeref] = ACTIONS(3497),
    [anon_sym___reftype] = ACTIONS(3497),
    [anon_sym___refvalue] = ACTIONS(3497),
    [sym_null_literal] = ACTIONS(3497),
    [anon_sym_SQUOTE] = ACTIONS(3499),
    [sym_integer_literal] = ACTIONS(3497),
    [sym_real_literal] = ACTIONS(3499),
    [anon_sym_DQUOTE] = ACTIONS(3499),
    [sym_verbatim_string_literal] = ACTIONS(3499),
    [aux_sym_preproc_if_token1] = ACTIONS(3499),
    [aux_sym_preproc_if_token3] = ACTIONS(3499),
    [aux_sym_preproc_else_token1] = ACTIONS(3499),
    [aux_sym_preproc_elif_token1] = ACTIONS(3499),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3499),
    [sym_interpolation_verbatim_start] = ACTIONS(3499),
    [sym_interpolation_raw_start] = ACTIONS(3499),
    [sym_raw_string_start] = ACTIONS(3499),
  },
  [2331] = {
    [sym_preproc_region] = STATE(2331),
    [sym_preproc_endregion] = STATE(2331),
    [sym_preproc_line] = STATE(2331),
    [sym_preproc_pragma] = STATE(2331),
    [sym_preproc_nullable] = STATE(2331),
    [sym_preproc_error] = STATE(2331),
    [sym_preproc_warning] = STATE(2331),
    [sym_preproc_define] = STATE(2331),
    [sym_preproc_undef] = STATE(2331),
    [sym__identifier_token] = ACTIONS(3501),
    [anon_sym_extern] = ACTIONS(3501),
    [anon_sym_alias] = ACTIONS(3501),
    [anon_sym_SEMI] = ACTIONS(3503),
    [anon_sym_global] = ACTIONS(3501),
    [anon_sym_using] = ACTIONS(3501),
    [anon_sym_unsafe] = ACTIONS(3501),
    [anon_sym_static] = ACTIONS(3501),
    [anon_sym_LBRACK] = ACTIONS(3503),
    [anon_sym_LPAREN] = ACTIONS(3503),
    [anon_sym_return] = ACTIONS(3501),
    [anon_sym_namespace] = ACTIONS(3501),
    [anon_sym_class] = ACTIONS(3501),
    [anon_sym_ref] = ACTIONS(3501),
    [anon_sym_struct] = ACTIONS(3501),
    [anon_sym_enum] = ACTIONS(3501),
    [anon_sym_LBRACE] = ACTIONS(3503),
    [anon_sym_interface] = ACTIONS(3501),
    [anon_sym_delegate] = ACTIONS(3501),
    [anon_sym_record] = ACTIONS(3501),
    [anon_sym_abstract] = ACTIONS(3501),
    [anon_sym_async] = ACTIONS(3501),
    [anon_sym_const] = ACTIONS(3501),
    [anon_sym_file] = ACTIONS(3501),
    [anon_sym_fixed] = ACTIONS(3501),
    [anon_sym_internal] = ACTIONS(3501),
    [anon_sym_new] = ACTIONS(3501),
    [anon_sym_override] = ACTIONS(3501),
    [anon_sym_partial] = ACTIONS(3501),
    [anon_sym_private] = ACTIONS(3501),
    [anon_sym_protected] = ACTIONS(3501),
    [anon_sym_public] = ACTIONS(3501),
    [anon_sym_readonly] = ACTIONS(3501),
    [anon_sym_required] = ACTIONS(3501),
    [anon_sym_sealed] = ACTIONS(3501),
    [anon_sym_virtual] = ACTIONS(3501),
    [anon_sym_volatile] = ACTIONS(3501),
    [anon_sym_where] = ACTIONS(3501),
    [anon_sym_notnull] = ACTIONS(3501),
    [anon_sym_unmanaged] = ACTIONS(3501),
    [anon_sym_checked] = ACTIONS(3501),
    [anon_sym_BANG] = ACTIONS(3503),
    [anon_sym_TILDE] = ACTIONS(3503),
    [anon_sym_PLUS_PLUS] = ACTIONS(3503),
    [anon_sym_DASH_DASH] = ACTIONS(3503),
    [anon_sym_true] = ACTIONS(3501),
    [anon_sym_false] = ACTIONS(3501),
    [anon_sym_PLUS] = ACTIONS(3501),
    [anon_sym_DASH] = ACTIONS(3501),
    [anon_sym_STAR] = ACTIONS(3503),
    [anon_sym_CARET] = ACTIONS(3503),
    [anon_sym_AMP] = ACTIONS(3503),
    [anon_sym_this] = ACTIONS(3501),
    [anon_sym_scoped] = ACTIONS(3501),
    [anon_sym_base] = ACTIONS(3501),
    [anon_sym_var] = ACTIONS(3501),
    [sym_predefined_type] = ACTIONS(3501),
    [anon_sym_break] = ACTIONS(3501),
    [anon_sym_unchecked] = ACTIONS(3501),
    [anon_sym_continue] = ACTIONS(3501),
    [anon_sym_do] = ACTIONS(3501),
    [anon_sym_while] = ACTIONS(3501),
    [anon_sym_for] = ACTIONS(3501),
    [anon_sym_lock] = ACTIONS(3501),
    [anon_sym_yield] = ACTIONS(3501),
    [anon_sym_switch] = ACTIONS(3501),
    [anon_sym_default] = ACTIONS(3501),
    [anon_sym_throw] = ACTIONS(3501),
    [anon_sym_try] = ACTIONS(3501),
    [anon_sym_when] = ACTIONS(3501),
    [anon_sym_await] = ACTIONS(3501),
    [anon_sym_foreach] = ACTIONS(3501),
    [anon_sym_goto] = ACTIONS(3501),
    [anon_sym_if] = ACTIONS(3501),
    [anon_sym_DOT_DOT] = ACTIONS(3503),
    [anon_sym_from] = ACTIONS(3501),
    [anon_sym_into] = ACTIONS(3501),
    [anon_sym_join] = ACTIONS(3501),
    [anon_sym_on] = ACTIONS(3501),
    [anon_sym_equals] = ACTIONS(3501),
    [anon_sym_let] = ACTIONS(3501),
    [anon_sym_orderby] = ACTIONS(3501),
    [anon_sym_ascending] = ACTIONS(3501),
    [anon_sym_descending] = ACTIONS(3501),
    [anon_sym_group] = ACTIONS(3501),
    [anon_sym_by] = ACTIONS(3501),
    [anon_sym_select] = ACTIONS(3501),
    [anon_sym_stackalloc] = ACTIONS(3501),
    [anon_sym_sizeof] = ACTIONS(3501),
    [anon_sym_typeof] = ACTIONS(3501),
    [anon_sym___makeref] = ACTIONS(3501),
    [anon_sym___reftype] = ACTIONS(3501),
    [anon_sym___refvalue] = ACTIONS(3501),
    [sym_null_literal] = ACTIONS(3501),
    [anon_sym_SQUOTE] = ACTIONS(3503),
    [sym_integer_literal] = ACTIONS(3501),
    [sym_real_literal] = ACTIONS(3503),
    [anon_sym_DQUOTE] = ACTIONS(3503),
    [sym_verbatim_string_literal] = ACTIONS(3503),
    [aux_sym_preproc_if_token1] = ACTIONS(3503),
    [aux_sym_preproc_if_token3] = ACTIONS(3503),
    [aux_sym_preproc_else_token1] = ACTIONS(3503),
    [aux_sym_preproc_elif_token1] = ACTIONS(3503),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3503),
    [sym_interpolation_verbatim_start] = ACTIONS(3503),
    [sym_interpolation_raw_start] = ACTIONS(3503),
    [sym_raw_string_start] = ACTIONS(3503),
  },
  [2332] = {
    [sym_preproc_region] = STATE(2332),
    [sym_preproc_endregion] = STATE(2332),
    [sym_preproc_line] = STATE(2332),
    [sym_preproc_pragma] = STATE(2332),
    [sym_preproc_nullable] = STATE(2332),
    [sym_preproc_error] = STATE(2332),
    [sym_preproc_warning] = STATE(2332),
    [sym_preproc_define] = STATE(2332),
    [sym_preproc_undef] = STATE(2332),
    [sym__identifier_token] = ACTIONS(3505),
    [anon_sym_extern] = ACTIONS(3505),
    [anon_sym_alias] = ACTIONS(3505),
    [anon_sym_SEMI] = ACTIONS(3507),
    [anon_sym_global] = ACTIONS(3505),
    [anon_sym_using] = ACTIONS(3505),
    [anon_sym_unsafe] = ACTIONS(3505),
    [anon_sym_static] = ACTIONS(3505),
    [anon_sym_LBRACK] = ACTIONS(3507),
    [anon_sym_LPAREN] = ACTIONS(3507),
    [anon_sym_return] = ACTIONS(3505),
    [anon_sym_namespace] = ACTIONS(3505),
    [anon_sym_class] = ACTIONS(3505),
    [anon_sym_ref] = ACTIONS(3505),
    [anon_sym_struct] = ACTIONS(3505),
    [anon_sym_enum] = ACTIONS(3505),
    [anon_sym_LBRACE] = ACTIONS(3507),
    [anon_sym_interface] = ACTIONS(3505),
    [anon_sym_delegate] = ACTIONS(3505),
    [anon_sym_record] = ACTIONS(3505),
    [anon_sym_abstract] = ACTIONS(3505),
    [anon_sym_async] = ACTIONS(3505),
    [anon_sym_const] = ACTIONS(3505),
    [anon_sym_file] = ACTIONS(3505),
    [anon_sym_fixed] = ACTIONS(3505),
    [anon_sym_internal] = ACTIONS(3505),
    [anon_sym_new] = ACTIONS(3505),
    [anon_sym_override] = ACTIONS(3505),
    [anon_sym_partial] = ACTIONS(3505),
    [anon_sym_private] = ACTIONS(3505),
    [anon_sym_protected] = ACTIONS(3505),
    [anon_sym_public] = ACTIONS(3505),
    [anon_sym_readonly] = ACTIONS(3505),
    [anon_sym_required] = ACTIONS(3505),
    [anon_sym_sealed] = ACTIONS(3505),
    [anon_sym_virtual] = ACTIONS(3505),
    [anon_sym_volatile] = ACTIONS(3505),
    [anon_sym_where] = ACTIONS(3505),
    [anon_sym_notnull] = ACTIONS(3505),
    [anon_sym_unmanaged] = ACTIONS(3505),
    [anon_sym_checked] = ACTIONS(3505),
    [anon_sym_BANG] = ACTIONS(3507),
    [anon_sym_TILDE] = ACTIONS(3507),
    [anon_sym_PLUS_PLUS] = ACTIONS(3507),
    [anon_sym_DASH_DASH] = ACTIONS(3507),
    [anon_sym_true] = ACTIONS(3505),
    [anon_sym_false] = ACTIONS(3505),
    [anon_sym_PLUS] = ACTIONS(3505),
    [anon_sym_DASH] = ACTIONS(3505),
    [anon_sym_STAR] = ACTIONS(3507),
    [anon_sym_CARET] = ACTIONS(3507),
    [anon_sym_AMP] = ACTIONS(3507),
    [anon_sym_this] = ACTIONS(3505),
    [anon_sym_scoped] = ACTIONS(3505),
    [anon_sym_base] = ACTIONS(3505),
    [anon_sym_var] = ACTIONS(3505),
    [sym_predefined_type] = ACTIONS(3505),
    [anon_sym_break] = ACTIONS(3505),
    [anon_sym_unchecked] = ACTIONS(3505),
    [anon_sym_continue] = ACTIONS(3505),
    [anon_sym_do] = ACTIONS(3505),
    [anon_sym_while] = ACTIONS(3505),
    [anon_sym_for] = ACTIONS(3505),
    [anon_sym_lock] = ACTIONS(3505),
    [anon_sym_yield] = ACTIONS(3505),
    [anon_sym_switch] = ACTIONS(3505),
    [anon_sym_default] = ACTIONS(3505),
    [anon_sym_throw] = ACTIONS(3505),
    [anon_sym_try] = ACTIONS(3505),
    [anon_sym_when] = ACTIONS(3505),
    [anon_sym_await] = ACTIONS(3505),
    [anon_sym_foreach] = ACTIONS(3505),
    [anon_sym_goto] = ACTIONS(3505),
    [anon_sym_if] = ACTIONS(3505),
    [anon_sym_DOT_DOT] = ACTIONS(3507),
    [anon_sym_from] = ACTIONS(3505),
    [anon_sym_into] = ACTIONS(3505),
    [anon_sym_join] = ACTIONS(3505),
    [anon_sym_on] = ACTIONS(3505),
    [anon_sym_equals] = ACTIONS(3505),
    [anon_sym_let] = ACTIONS(3505),
    [anon_sym_orderby] = ACTIONS(3505),
    [anon_sym_ascending] = ACTIONS(3505),
    [anon_sym_descending] = ACTIONS(3505),
    [anon_sym_group] = ACTIONS(3505),
    [anon_sym_by] = ACTIONS(3505),
    [anon_sym_select] = ACTIONS(3505),
    [anon_sym_stackalloc] = ACTIONS(3505),
    [anon_sym_sizeof] = ACTIONS(3505),
    [anon_sym_typeof] = ACTIONS(3505),
    [anon_sym___makeref] = ACTIONS(3505),
    [anon_sym___reftype] = ACTIONS(3505),
    [anon_sym___refvalue] = ACTIONS(3505),
    [sym_null_literal] = ACTIONS(3505),
    [anon_sym_SQUOTE] = ACTIONS(3507),
    [sym_integer_literal] = ACTIONS(3505),
    [sym_real_literal] = ACTIONS(3507),
    [anon_sym_DQUOTE] = ACTIONS(3507),
    [sym_verbatim_string_literal] = ACTIONS(3507),
    [aux_sym_preproc_if_token1] = ACTIONS(3507),
    [aux_sym_preproc_if_token3] = ACTIONS(3507),
    [aux_sym_preproc_else_token1] = ACTIONS(3507),
    [aux_sym_preproc_elif_token1] = ACTIONS(3507),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3507),
    [sym_interpolation_verbatim_start] = ACTIONS(3507),
    [sym_interpolation_raw_start] = ACTIONS(3507),
    [sym_raw_string_start] = ACTIONS(3507),
  },
  [2333] = {
    [sym_preproc_region] = STATE(2333),
    [sym_preproc_endregion] = STATE(2333),
    [sym_preproc_line] = STATE(2333),
    [sym_preproc_pragma] = STATE(2333),
    [sym_preproc_nullable] = STATE(2333),
    [sym_preproc_error] = STATE(2333),
    [sym_preproc_warning] = STATE(2333),
    [sym_preproc_define] = STATE(2333),
    [sym_preproc_undef] = STATE(2333),
    [sym__identifier_token] = ACTIONS(3509),
    [anon_sym_extern] = ACTIONS(3509),
    [anon_sym_alias] = ACTIONS(3509),
    [anon_sym_SEMI] = ACTIONS(3511),
    [anon_sym_global] = ACTIONS(3509),
    [anon_sym_using] = ACTIONS(3509),
    [anon_sym_unsafe] = ACTIONS(3509),
    [anon_sym_static] = ACTIONS(3509),
    [anon_sym_LBRACK] = ACTIONS(3511),
    [anon_sym_LPAREN] = ACTIONS(3511),
    [anon_sym_return] = ACTIONS(3509),
    [anon_sym_namespace] = ACTIONS(3509),
    [anon_sym_class] = ACTIONS(3509),
    [anon_sym_ref] = ACTIONS(3509),
    [anon_sym_struct] = ACTIONS(3509),
    [anon_sym_enum] = ACTIONS(3509),
    [anon_sym_LBRACE] = ACTIONS(3511),
    [anon_sym_interface] = ACTIONS(3509),
    [anon_sym_delegate] = ACTIONS(3509),
    [anon_sym_record] = ACTIONS(3509),
    [anon_sym_abstract] = ACTIONS(3509),
    [anon_sym_async] = ACTIONS(3509),
    [anon_sym_const] = ACTIONS(3509),
    [anon_sym_file] = ACTIONS(3509),
    [anon_sym_fixed] = ACTIONS(3509),
    [anon_sym_internal] = ACTIONS(3509),
    [anon_sym_new] = ACTIONS(3509),
    [anon_sym_override] = ACTIONS(3509),
    [anon_sym_partial] = ACTIONS(3509),
    [anon_sym_private] = ACTIONS(3509),
    [anon_sym_protected] = ACTIONS(3509),
    [anon_sym_public] = ACTIONS(3509),
    [anon_sym_readonly] = ACTIONS(3509),
    [anon_sym_required] = ACTIONS(3509),
    [anon_sym_sealed] = ACTIONS(3509),
    [anon_sym_virtual] = ACTIONS(3509),
    [anon_sym_volatile] = ACTIONS(3509),
    [anon_sym_where] = ACTIONS(3509),
    [anon_sym_notnull] = ACTIONS(3509),
    [anon_sym_unmanaged] = ACTIONS(3509),
    [anon_sym_checked] = ACTIONS(3509),
    [anon_sym_BANG] = ACTIONS(3511),
    [anon_sym_TILDE] = ACTIONS(3511),
    [anon_sym_PLUS_PLUS] = ACTIONS(3511),
    [anon_sym_DASH_DASH] = ACTIONS(3511),
    [anon_sym_true] = ACTIONS(3509),
    [anon_sym_false] = ACTIONS(3509),
    [anon_sym_PLUS] = ACTIONS(3509),
    [anon_sym_DASH] = ACTIONS(3509),
    [anon_sym_STAR] = ACTIONS(3511),
    [anon_sym_CARET] = ACTIONS(3511),
    [anon_sym_AMP] = ACTIONS(3511),
    [anon_sym_this] = ACTIONS(3509),
    [anon_sym_scoped] = ACTIONS(3509),
    [anon_sym_base] = ACTIONS(3509),
    [anon_sym_var] = ACTIONS(3509),
    [sym_predefined_type] = ACTIONS(3509),
    [anon_sym_break] = ACTIONS(3509),
    [anon_sym_unchecked] = ACTIONS(3509),
    [anon_sym_continue] = ACTIONS(3509),
    [anon_sym_do] = ACTIONS(3509),
    [anon_sym_while] = ACTIONS(3509),
    [anon_sym_for] = ACTIONS(3509),
    [anon_sym_lock] = ACTIONS(3509),
    [anon_sym_yield] = ACTIONS(3509),
    [anon_sym_switch] = ACTIONS(3509),
    [anon_sym_default] = ACTIONS(3509),
    [anon_sym_throw] = ACTIONS(3509),
    [anon_sym_try] = ACTIONS(3509),
    [anon_sym_when] = ACTIONS(3509),
    [anon_sym_await] = ACTIONS(3509),
    [anon_sym_foreach] = ACTIONS(3509),
    [anon_sym_goto] = ACTIONS(3509),
    [anon_sym_if] = ACTIONS(3509),
    [anon_sym_DOT_DOT] = ACTIONS(3511),
    [anon_sym_from] = ACTIONS(3509),
    [anon_sym_into] = ACTIONS(3509),
    [anon_sym_join] = ACTIONS(3509),
    [anon_sym_on] = ACTIONS(3509),
    [anon_sym_equals] = ACTIONS(3509),
    [anon_sym_let] = ACTIONS(3509),
    [anon_sym_orderby] = ACTIONS(3509),
    [anon_sym_ascending] = ACTIONS(3509),
    [anon_sym_descending] = ACTIONS(3509),
    [anon_sym_group] = ACTIONS(3509),
    [anon_sym_by] = ACTIONS(3509),
    [anon_sym_select] = ACTIONS(3509),
    [anon_sym_stackalloc] = ACTIONS(3509),
    [anon_sym_sizeof] = ACTIONS(3509),
    [anon_sym_typeof] = ACTIONS(3509),
    [anon_sym___makeref] = ACTIONS(3509),
    [anon_sym___reftype] = ACTIONS(3509),
    [anon_sym___refvalue] = ACTIONS(3509),
    [sym_null_literal] = ACTIONS(3509),
    [anon_sym_SQUOTE] = ACTIONS(3511),
    [sym_integer_literal] = ACTIONS(3509),
    [sym_real_literal] = ACTIONS(3511),
    [anon_sym_DQUOTE] = ACTIONS(3511),
    [sym_verbatim_string_literal] = ACTIONS(3511),
    [aux_sym_preproc_if_token1] = ACTIONS(3511),
    [aux_sym_preproc_if_token3] = ACTIONS(3511),
    [aux_sym_preproc_else_token1] = ACTIONS(3511),
    [aux_sym_preproc_elif_token1] = ACTIONS(3511),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3511),
    [sym_interpolation_verbatim_start] = ACTIONS(3511),
    [sym_interpolation_raw_start] = ACTIONS(3511),
    [sym_raw_string_start] = ACTIONS(3511),
  },
  [2334] = {
    [sym_preproc_region] = STATE(2334),
    [sym_preproc_endregion] = STATE(2334),
    [sym_preproc_line] = STATE(2334),
    [sym_preproc_pragma] = STATE(2334),
    [sym_preproc_nullable] = STATE(2334),
    [sym_preproc_error] = STATE(2334),
    [sym_preproc_warning] = STATE(2334),
    [sym_preproc_define] = STATE(2334),
    [sym_preproc_undef] = STATE(2334),
    [sym__identifier_token] = ACTIONS(3513),
    [anon_sym_extern] = ACTIONS(3513),
    [anon_sym_alias] = ACTIONS(3513),
    [anon_sym_SEMI] = ACTIONS(3515),
    [anon_sym_global] = ACTIONS(3513),
    [anon_sym_using] = ACTIONS(3513),
    [anon_sym_unsafe] = ACTIONS(3513),
    [anon_sym_static] = ACTIONS(3513),
    [anon_sym_LBRACK] = ACTIONS(3515),
    [anon_sym_LPAREN] = ACTIONS(3515),
    [anon_sym_return] = ACTIONS(3513),
    [anon_sym_namespace] = ACTIONS(3513),
    [anon_sym_class] = ACTIONS(3513),
    [anon_sym_ref] = ACTIONS(3513),
    [anon_sym_struct] = ACTIONS(3513),
    [anon_sym_enum] = ACTIONS(3513),
    [anon_sym_LBRACE] = ACTIONS(3515),
    [anon_sym_interface] = ACTIONS(3513),
    [anon_sym_delegate] = ACTIONS(3513),
    [anon_sym_record] = ACTIONS(3513),
    [anon_sym_abstract] = ACTIONS(3513),
    [anon_sym_async] = ACTIONS(3513),
    [anon_sym_const] = ACTIONS(3513),
    [anon_sym_file] = ACTIONS(3513),
    [anon_sym_fixed] = ACTIONS(3513),
    [anon_sym_internal] = ACTIONS(3513),
    [anon_sym_new] = ACTIONS(3513),
    [anon_sym_override] = ACTIONS(3513),
    [anon_sym_partial] = ACTIONS(3513),
    [anon_sym_private] = ACTIONS(3513),
    [anon_sym_protected] = ACTIONS(3513),
    [anon_sym_public] = ACTIONS(3513),
    [anon_sym_readonly] = ACTIONS(3513),
    [anon_sym_required] = ACTIONS(3513),
    [anon_sym_sealed] = ACTIONS(3513),
    [anon_sym_virtual] = ACTIONS(3513),
    [anon_sym_volatile] = ACTIONS(3513),
    [anon_sym_where] = ACTIONS(3513),
    [anon_sym_notnull] = ACTIONS(3513),
    [anon_sym_unmanaged] = ACTIONS(3513),
    [anon_sym_checked] = ACTIONS(3513),
    [anon_sym_BANG] = ACTIONS(3515),
    [anon_sym_TILDE] = ACTIONS(3515),
    [anon_sym_PLUS_PLUS] = ACTIONS(3515),
    [anon_sym_DASH_DASH] = ACTIONS(3515),
    [anon_sym_true] = ACTIONS(3513),
    [anon_sym_false] = ACTIONS(3513),
    [anon_sym_PLUS] = ACTIONS(3513),
    [anon_sym_DASH] = ACTIONS(3513),
    [anon_sym_STAR] = ACTIONS(3515),
    [anon_sym_CARET] = ACTIONS(3515),
    [anon_sym_AMP] = ACTIONS(3515),
    [anon_sym_this] = ACTIONS(3513),
    [anon_sym_scoped] = ACTIONS(3513),
    [anon_sym_base] = ACTIONS(3513),
    [anon_sym_var] = ACTIONS(3513),
    [sym_predefined_type] = ACTIONS(3513),
    [anon_sym_break] = ACTIONS(3513),
    [anon_sym_unchecked] = ACTIONS(3513),
    [anon_sym_continue] = ACTIONS(3513),
    [anon_sym_do] = ACTIONS(3513),
    [anon_sym_while] = ACTIONS(3513),
    [anon_sym_for] = ACTIONS(3513),
    [anon_sym_lock] = ACTIONS(3513),
    [anon_sym_yield] = ACTIONS(3513),
    [anon_sym_switch] = ACTIONS(3513),
    [anon_sym_default] = ACTIONS(3513),
    [anon_sym_throw] = ACTIONS(3513),
    [anon_sym_try] = ACTIONS(3513),
    [anon_sym_when] = ACTIONS(3513),
    [anon_sym_await] = ACTIONS(3513),
    [anon_sym_foreach] = ACTIONS(3513),
    [anon_sym_goto] = ACTIONS(3513),
    [anon_sym_if] = ACTIONS(3513),
    [anon_sym_DOT_DOT] = ACTIONS(3515),
    [anon_sym_from] = ACTIONS(3513),
    [anon_sym_into] = ACTIONS(3513),
    [anon_sym_join] = ACTIONS(3513),
    [anon_sym_on] = ACTIONS(3513),
    [anon_sym_equals] = ACTIONS(3513),
    [anon_sym_let] = ACTIONS(3513),
    [anon_sym_orderby] = ACTIONS(3513),
    [anon_sym_ascending] = ACTIONS(3513),
    [anon_sym_descending] = ACTIONS(3513),
    [anon_sym_group] = ACTIONS(3513),
    [anon_sym_by] = ACTIONS(3513),
    [anon_sym_select] = ACTIONS(3513),
    [anon_sym_stackalloc] = ACTIONS(3513),
    [anon_sym_sizeof] = ACTIONS(3513),
    [anon_sym_typeof] = ACTIONS(3513),
    [anon_sym___makeref] = ACTIONS(3513),
    [anon_sym___reftype] = ACTIONS(3513),
    [anon_sym___refvalue] = ACTIONS(3513),
    [sym_null_literal] = ACTIONS(3513),
    [anon_sym_SQUOTE] = ACTIONS(3515),
    [sym_integer_literal] = ACTIONS(3513),
    [sym_real_literal] = ACTIONS(3515),
    [anon_sym_DQUOTE] = ACTIONS(3515),
    [sym_verbatim_string_literal] = ACTIONS(3515),
    [aux_sym_preproc_if_token1] = ACTIONS(3515),
    [aux_sym_preproc_if_token3] = ACTIONS(3515),
    [aux_sym_preproc_else_token1] = ACTIONS(3515),
    [aux_sym_preproc_elif_token1] = ACTIONS(3515),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3515),
    [sym_interpolation_verbatim_start] = ACTIONS(3515),
    [sym_interpolation_raw_start] = ACTIONS(3515),
    [sym_raw_string_start] = ACTIONS(3515),
  },
  [2335] = {
    [sym_preproc_region] = STATE(2335),
    [sym_preproc_endregion] = STATE(2335),
    [sym_preproc_line] = STATE(2335),
    [sym_preproc_pragma] = STATE(2335),
    [sym_preproc_nullable] = STATE(2335),
    [sym_preproc_error] = STATE(2335),
    [sym_preproc_warning] = STATE(2335),
    [sym_preproc_define] = STATE(2335),
    [sym_preproc_undef] = STATE(2335),
    [sym__identifier_token] = ACTIONS(3517),
    [anon_sym_extern] = ACTIONS(3517),
    [anon_sym_alias] = ACTIONS(3517),
    [anon_sym_SEMI] = ACTIONS(3519),
    [anon_sym_global] = ACTIONS(3517),
    [anon_sym_using] = ACTIONS(3517),
    [anon_sym_unsafe] = ACTIONS(3517),
    [anon_sym_static] = ACTIONS(3517),
    [anon_sym_LBRACK] = ACTIONS(3519),
    [anon_sym_LPAREN] = ACTIONS(3519),
    [anon_sym_return] = ACTIONS(3517),
    [anon_sym_namespace] = ACTIONS(3517),
    [anon_sym_class] = ACTIONS(3517),
    [anon_sym_ref] = ACTIONS(3517),
    [anon_sym_struct] = ACTIONS(3517),
    [anon_sym_enum] = ACTIONS(3517),
    [anon_sym_LBRACE] = ACTIONS(3519),
    [anon_sym_interface] = ACTIONS(3517),
    [anon_sym_delegate] = ACTIONS(3517),
    [anon_sym_record] = ACTIONS(3517),
    [anon_sym_abstract] = ACTIONS(3517),
    [anon_sym_async] = ACTIONS(3517),
    [anon_sym_const] = ACTIONS(3517),
    [anon_sym_file] = ACTIONS(3517),
    [anon_sym_fixed] = ACTIONS(3517),
    [anon_sym_internal] = ACTIONS(3517),
    [anon_sym_new] = ACTIONS(3517),
    [anon_sym_override] = ACTIONS(3517),
    [anon_sym_partial] = ACTIONS(3517),
    [anon_sym_private] = ACTIONS(3517),
    [anon_sym_protected] = ACTIONS(3517),
    [anon_sym_public] = ACTIONS(3517),
    [anon_sym_readonly] = ACTIONS(3517),
    [anon_sym_required] = ACTIONS(3517),
    [anon_sym_sealed] = ACTIONS(3517),
    [anon_sym_virtual] = ACTIONS(3517),
    [anon_sym_volatile] = ACTIONS(3517),
    [anon_sym_where] = ACTIONS(3517),
    [anon_sym_notnull] = ACTIONS(3517),
    [anon_sym_unmanaged] = ACTIONS(3517),
    [anon_sym_checked] = ACTIONS(3517),
    [anon_sym_BANG] = ACTIONS(3519),
    [anon_sym_TILDE] = ACTIONS(3519),
    [anon_sym_PLUS_PLUS] = ACTIONS(3519),
    [anon_sym_DASH_DASH] = ACTIONS(3519),
    [anon_sym_true] = ACTIONS(3517),
    [anon_sym_false] = ACTIONS(3517),
    [anon_sym_PLUS] = ACTIONS(3517),
    [anon_sym_DASH] = ACTIONS(3517),
    [anon_sym_STAR] = ACTIONS(3519),
    [anon_sym_CARET] = ACTIONS(3519),
    [anon_sym_AMP] = ACTIONS(3519),
    [anon_sym_this] = ACTIONS(3517),
    [anon_sym_scoped] = ACTIONS(3517),
    [anon_sym_base] = ACTIONS(3517),
    [anon_sym_var] = ACTIONS(3517),
    [sym_predefined_type] = ACTIONS(3517),
    [anon_sym_break] = ACTIONS(3517),
    [anon_sym_unchecked] = ACTIONS(3517),
    [anon_sym_continue] = ACTIONS(3517),
    [anon_sym_do] = ACTIONS(3517),
    [anon_sym_while] = ACTIONS(3517),
    [anon_sym_for] = ACTIONS(3517),
    [anon_sym_lock] = ACTIONS(3517),
    [anon_sym_yield] = ACTIONS(3517),
    [anon_sym_switch] = ACTIONS(3517),
    [anon_sym_default] = ACTIONS(3517),
    [anon_sym_throw] = ACTIONS(3517),
    [anon_sym_try] = ACTIONS(3517),
    [anon_sym_when] = ACTIONS(3517),
    [anon_sym_await] = ACTIONS(3517),
    [anon_sym_foreach] = ACTIONS(3517),
    [anon_sym_goto] = ACTIONS(3517),
    [anon_sym_if] = ACTIONS(3517),
    [anon_sym_DOT_DOT] = ACTIONS(3519),
    [anon_sym_from] = ACTIONS(3517),
    [anon_sym_into] = ACTIONS(3517),
    [anon_sym_join] = ACTIONS(3517),
    [anon_sym_on] = ACTIONS(3517),
    [anon_sym_equals] = ACTIONS(3517),
    [anon_sym_let] = ACTIONS(3517),
    [anon_sym_orderby] = ACTIONS(3517),
    [anon_sym_ascending] = ACTIONS(3517),
    [anon_sym_descending] = ACTIONS(3517),
    [anon_sym_group] = ACTIONS(3517),
    [anon_sym_by] = ACTIONS(3517),
    [anon_sym_select] = ACTIONS(3517),
    [anon_sym_stackalloc] = ACTIONS(3517),
    [anon_sym_sizeof] = ACTIONS(3517),
    [anon_sym_typeof] = ACTIONS(3517),
    [anon_sym___makeref] = ACTIONS(3517),
    [anon_sym___reftype] = ACTIONS(3517),
    [anon_sym___refvalue] = ACTIONS(3517),
    [sym_null_literal] = ACTIONS(3517),
    [anon_sym_SQUOTE] = ACTIONS(3519),
    [sym_integer_literal] = ACTIONS(3517),
    [sym_real_literal] = ACTIONS(3519),
    [anon_sym_DQUOTE] = ACTIONS(3519),
    [sym_verbatim_string_literal] = ACTIONS(3519),
    [aux_sym_preproc_if_token1] = ACTIONS(3519),
    [aux_sym_preproc_if_token3] = ACTIONS(3519),
    [aux_sym_preproc_else_token1] = ACTIONS(3519),
    [aux_sym_preproc_elif_token1] = ACTIONS(3519),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3519),
    [sym_interpolation_verbatim_start] = ACTIONS(3519),
    [sym_interpolation_raw_start] = ACTIONS(3519),
    [sym_raw_string_start] = ACTIONS(3519),
  },
  [2336] = {
    [sym_preproc_region] = STATE(2336),
    [sym_preproc_endregion] = STATE(2336),
    [sym_preproc_line] = STATE(2336),
    [sym_preproc_pragma] = STATE(2336),
    [sym_preproc_nullable] = STATE(2336),
    [sym_preproc_error] = STATE(2336),
    [sym_preproc_warning] = STATE(2336),
    [sym_preproc_define] = STATE(2336),
    [sym_preproc_undef] = STATE(2336),
    [sym__identifier_token] = ACTIONS(3521),
    [anon_sym_extern] = ACTIONS(3521),
    [anon_sym_alias] = ACTIONS(3521),
    [anon_sym_SEMI] = ACTIONS(3523),
    [anon_sym_global] = ACTIONS(3521),
    [anon_sym_using] = ACTIONS(3521),
    [anon_sym_unsafe] = ACTIONS(3521),
    [anon_sym_static] = ACTIONS(3521),
    [anon_sym_LBRACK] = ACTIONS(3523),
    [anon_sym_LPAREN] = ACTIONS(3523),
    [anon_sym_return] = ACTIONS(3521),
    [anon_sym_namespace] = ACTIONS(3521),
    [anon_sym_class] = ACTIONS(3521),
    [anon_sym_ref] = ACTIONS(3521),
    [anon_sym_struct] = ACTIONS(3521),
    [anon_sym_enum] = ACTIONS(3521),
    [anon_sym_LBRACE] = ACTIONS(3523),
    [anon_sym_interface] = ACTIONS(3521),
    [anon_sym_delegate] = ACTIONS(3521),
    [anon_sym_record] = ACTIONS(3521),
    [anon_sym_abstract] = ACTIONS(3521),
    [anon_sym_async] = ACTIONS(3521),
    [anon_sym_const] = ACTIONS(3521),
    [anon_sym_file] = ACTIONS(3521),
    [anon_sym_fixed] = ACTIONS(3521),
    [anon_sym_internal] = ACTIONS(3521),
    [anon_sym_new] = ACTIONS(3521),
    [anon_sym_override] = ACTIONS(3521),
    [anon_sym_partial] = ACTIONS(3521),
    [anon_sym_private] = ACTIONS(3521),
    [anon_sym_protected] = ACTIONS(3521),
    [anon_sym_public] = ACTIONS(3521),
    [anon_sym_readonly] = ACTIONS(3521),
    [anon_sym_required] = ACTIONS(3521),
    [anon_sym_sealed] = ACTIONS(3521),
    [anon_sym_virtual] = ACTIONS(3521),
    [anon_sym_volatile] = ACTIONS(3521),
    [anon_sym_where] = ACTIONS(3521),
    [anon_sym_notnull] = ACTIONS(3521),
    [anon_sym_unmanaged] = ACTIONS(3521),
    [anon_sym_checked] = ACTIONS(3521),
    [anon_sym_BANG] = ACTIONS(3523),
    [anon_sym_TILDE] = ACTIONS(3523),
    [anon_sym_PLUS_PLUS] = ACTIONS(3523),
    [anon_sym_DASH_DASH] = ACTIONS(3523),
    [anon_sym_true] = ACTIONS(3521),
    [anon_sym_false] = ACTIONS(3521),
    [anon_sym_PLUS] = ACTIONS(3521),
    [anon_sym_DASH] = ACTIONS(3521),
    [anon_sym_STAR] = ACTIONS(3523),
    [anon_sym_CARET] = ACTIONS(3523),
    [anon_sym_AMP] = ACTIONS(3523),
    [anon_sym_this] = ACTIONS(3521),
    [anon_sym_scoped] = ACTIONS(3521),
    [anon_sym_base] = ACTIONS(3521),
    [anon_sym_var] = ACTIONS(3521),
    [sym_predefined_type] = ACTIONS(3521),
    [anon_sym_break] = ACTIONS(3521),
    [anon_sym_unchecked] = ACTIONS(3521),
    [anon_sym_continue] = ACTIONS(3521),
    [anon_sym_do] = ACTIONS(3521),
    [anon_sym_while] = ACTIONS(3521),
    [anon_sym_for] = ACTIONS(3521),
    [anon_sym_lock] = ACTIONS(3521),
    [anon_sym_yield] = ACTIONS(3521),
    [anon_sym_switch] = ACTIONS(3521),
    [anon_sym_default] = ACTIONS(3521),
    [anon_sym_throw] = ACTIONS(3521),
    [anon_sym_try] = ACTIONS(3521),
    [anon_sym_when] = ACTIONS(3521),
    [anon_sym_await] = ACTIONS(3521),
    [anon_sym_foreach] = ACTIONS(3521),
    [anon_sym_goto] = ACTIONS(3521),
    [anon_sym_if] = ACTIONS(3521),
    [anon_sym_DOT_DOT] = ACTIONS(3523),
    [anon_sym_from] = ACTIONS(3521),
    [anon_sym_into] = ACTIONS(3521),
    [anon_sym_join] = ACTIONS(3521),
    [anon_sym_on] = ACTIONS(3521),
    [anon_sym_equals] = ACTIONS(3521),
    [anon_sym_let] = ACTIONS(3521),
    [anon_sym_orderby] = ACTIONS(3521),
    [anon_sym_ascending] = ACTIONS(3521),
    [anon_sym_descending] = ACTIONS(3521),
    [anon_sym_group] = ACTIONS(3521),
    [anon_sym_by] = ACTIONS(3521),
    [anon_sym_select] = ACTIONS(3521),
    [anon_sym_stackalloc] = ACTIONS(3521),
    [anon_sym_sizeof] = ACTIONS(3521),
    [anon_sym_typeof] = ACTIONS(3521),
    [anon_sym___makeref] = ACTIONS(3521),
    [anon_sym___reftype] = ACTIONS(3521),
    [anon_sym___refvalue] = ACTIONS(3521),
    [sym_null_literal] = ACTIONS(3521),
    [anon_sym_SQUOTE] = ACTIONS(3523),
    [sym_integer_literal] = ACTIONS(3521),
    [sym_real_literal] = ACTIONS(3523),
    [anon_sym_DQUOTE] = ACTIONS(3523),
    [sym_verbatim_string_literal] = ACTIONS(3523),
    [aux_sym_preproc_if_token1] = ACTIONS(3523),
    [aux_sym_preproc_if_token3] = ACTIONS(3523),
    [aux_sym_preproc_else_token1] = ACTIONS(3523),
    [aux_sym_preproc_elif_token1] = ACTIONS(3523),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3523),
    [sym_interpolation_verbatim_start] = ACTIONS(3523),
    [sym_interpolation_raw_start] = ACTIONS(3523),
    [sym_raw_string_start] = ACTIONS(3523),
  },
  [2337] = {
    [sym_preproc_region] = STATE(2337),
    [sym_preproc_endregion] = STATE(2337),
    [sym_preproc_line] = STATE(2337),
    [sym_preproc_pragma] = STATE(2337),
    [sym_preproc_nullable] = STATE(2337),
    [sym_preproc_error] = STATE(2337),
    [sym_preproc_warning] = STATE(2337),
    [sym_preproc_define] = STATE(2337),
    [sym_preproc_undef] = STATE(2337),
    [sym__identifier_token] = ACTIONS(3525),
    [anon_sym_extern] = ACTIONS(3525),
    [anon_sym_alias] = ACTIONS(3525),
    [anon_sym_SEMI] = ACTIONS(3527),
    [anon_sym_global] = ACTIONS(3525),
    [anon_sym_using] = ACTIONS(3525),
    [anon_sym_unsafe] = ACTIONS(3525),
    [anon_sym_static] = ACTIONS(3525),
    [anon_sym_LBRACK] = ACTIONS(3527),
    [anon_sym_LPAREN] = ACTIONS(3527),
    [anon_sym_return] = ACTIONS(3525),
    [anon_sym_namespace] = ACTIONS(3525),
    [anon_sym_class] = ACTIONS(3525),
    [anon_sym_ref] = ACTIONS(3525),
    [anon_sym_struct] = ACTIONS(3525),
    [anon_sym_enum] = ACTIONS(3525),
    [anon_sym_LBRACE] = ACTIONS(3527),
    [anon_sym_interface] = ACTIONS(3525),
    [anon_sym_delegate] = ACTIONS(3525),
    [anon_sym_record] = ACTIONS(3525),
    [anon_sym_abstract] = ACTIONS(3525),
    [anon_sym_async] = ACTIONS(3525),
    [anon_sym_const] = ACTIONS(3525),
    [anon_sym_file] = ACTIONS(3525),
    [anon_sym_fixed] = ACTIONS(3525),
    [anon_sym_internal] = ACTIONS(3525),
    [anon_sym_new] = ACTIONS(3525),
    [anon_sym_override] = ACTIONS(3525),
    [anon_sym_partial] = ACTIONS(3525),
    [anon_sym_private] = ACTIONS(3525),
    [anon_sym_protected] = ACTIONS(3525),
    [anon_sym_public] = ACTIONS(3525),
    [anon_sym_readonly] = ACTIONS(3525),
    [anon_sym_required] = ACTIONS(3525),
    [anon_sym_sealed] = ACTIONS(3525),
    [anon_sym_virtual] = ACTIONS(3525),
    [anon_sym_volatile] = ACTIONS(3525),
    [anon_sym_where] = ACTIONS(3525),
    [anon_sym_notnull] = ACTIONS(3525),
    [anon_sym_unmanaged] = ACTIONS(3525),
    [anon_sym_checked] = ACTIONS(3525),
    [anon_sym_BANG] = ACTIONS(3527),
    [anon_sym_TILDE] = ACTIONS(3527),
    [anon_sym_PLUS_PLUS] = ACTIONS(3527),
    [anon_sym_DASH_DASH] = ACTIONS(3527),
    [anon_sym_true] = ACTIONS(3525),
    [anon_sym_false] = ACTIONS(3525),
    [anon_sym_PLUS] = ACTIONS(3525),
    [anon_sym_DASH] = ACTIONS(3525),
    [anon_sym_STAR] = ACTIONS(3527),
    [anon_sym_CARET] = ACTIONS(3527),
    [anon_sym_AMP] = ACTIONS(3527),
    [anon_sym_this] = ACTIONS(3525),
    [anon_sym_scoped] = ACTIONS(3525),
    [anon_sym_base] = ACTIONS(3525),
    [anon_sym_var] = ACTIONS(3525),
    [sym_predefined_type] = ACTIONS(3525),
    [anon_sym_break] = ACTIONS(3525),
    [anon_sym_unchecked] = ACTIONS(3525),
    [anon_sym_continue] = ACTIONS(3525),
    [anon_sym_do] = ACTIONS(3525),
    [anon_sym_while] = ACTIONS(3525),
    [anon_sym_for] = ACTIONS(3525),
    [anon_sym_lock] = ACTIONS(3525),
    [anon_sym_yield] = ACTIONS(3525),
    [anon_sym_switch] = ACTIONS(3525),
    [anon_sym_default] = ACTIONS(3525),
    [anon_sym_throw] = ACTIONS(3525),
    [anon_sym_try] = ACTIONS(3525),
    [anon_sym_when] = ACTIONS(3525),
    [anon_sym_await] = ACTIONS(3525),
    [anon_sym_foreach] = ACTIONS(3525),
    [anon_sym_goto] = ACTIONS(3525),
    [anon_sym_if] = ACTIONS(3525),
    [anon_sym_DOT_DOT] = ACTIONS(3527),
    [anon_sym_from] = ACTIONS(3525),
    [anon_sym_into] = ACTIONS(3525),
    [anon_sym_join] = ACTIONS(3525),
    [anon_sym_on] = ACTIONS(3525),
    [anon_sym_equals] = ACTIONS(3525),
    [anon_sym_let] = ACTIONS(3525),
    [anon_sym_orderby] = ACTIONS(3525),
    [anon_sym_ascending] = ACTIONS(3525),
    [anon_sym_descending] = ACTIONS(3525),
    [anon_sym_group] = ACTIONS(3525),
    [anon_sym_by] = ACTIONS(3525),
    [anon_sym_select] = ACTIONS(3525),
    [anon_sym_stackalloc] = ACTIONS(3525),
    [anon_sym_sizeof] = ACTIONS(3525),
    [anon_sym_typeof] = ACTIONS(3525),
    [anon_sym___makeref] = ACTIONS(3525),
    [anon_sym___reftype] = ACTIONS(3525),
    [anon_sym___refvalue] = ACTIONS(3525),
    [sym_null_literal] = ACTIONS(3525),
    [anon_sym_SQUOTE] = ACTIONS(3527),
    [sym_integer_literal] = ACTIONS(3525),
    [sym_real_literal] = ACTIONS(3527),
    [anon_sym_DQUOTE] = ACTIONS(3527),
    [sym_verbatim_string_literal] = ACTIONS(3527),
    [aux_sym_preproc_if_token1] = ACTIONS(3527),
    [aux_sym_preproc_if_token3] = ACTIONS(3527),
    [aux_sym_preproc_else_token1] = ACTIONS(3527),
    [aux_sym_preproc_elif_token1] = ACTIONS(3527),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3527),
    [sym_interpolation_verbatim_start] = ACTIONS(3527),
    [sym_interpolation_raw_start] = ACTIONS(3527),
    [sym_raw_string_start] = ACTIONS(3527),
  },
  [2338] = {
    [sym_preproc_region] = STATE(2338),
    [sym_preproc_endregion] = STATE(2338),
    [sym_preproc_line] = STATE(2338),
    [sym_preproc_pragma] = STATE(2338),
    [sym_preproc_nullable] = STATE(2338),
    [sym_preproc_error] = STATE(2338),
    [sym_preproc_warning] = STATE(2338),
    [sym_preproc_define] = STATE(2338),
    [sym_preproc_undef] = STATE(2338),
    [sym__identifier_token] = ACTIONS(3529),
    [anon_sym_extern] = ACTIONS(3529),
    [anon_sym_alias] = ACTIONS(3529),
    [anon_sym_SEMI] = ACTIONS(3531),
    [anon_sym_global] = ACTIONS(3529),
    [anon_sym_using] = ACTIONS(3529),
    [anon_sym_unsafe] = ACTIONS(3529),
    [anon_sym_static] = ACTIONS(3529),
    [anon_sym_LBRACK] = ACTIONS(3531),
    [anon_sym_LPAREN] = ACTIONS(3531),
    [anon_sym_return] = ACTIONS(3529),
    [anon_sym_namespace] = ACTIONS(3529),
    [anon_sym_class] = ACTIONS(3529),
    [anon_sym_ref] = ACTIONS(3529),
    [anon_sym_struct] = ACTIONS(3529),
    [anon_sym_enum] = ACTIONS(3529),
    [anon_sym_LBRACE] = ACTIONS(3531),
    [anon_sym_interface] = ACTIONS(3529),
    [anon_sym_delegate] = ACTIONS(3529),
    [anon_sym_record] = ACTIONS(3529),
    [anon_sym_abstract] = ACTIONS(3529),
    [anon_sym_async] = ACTIONS(3529),
    [anon_sym_const] = ACTIONS(3529),
    [anon_sym_file] = ACTIONS(3529),
    [anon_sym_fixed] = ACTIONS(3529),
    [anon_sym_internal] = ACTIONS(3529),
    [anon_sym_new] = ACTIONS(3529),
    [anon_sym_override] = ACTIONS(3529),
    [anon_sym_partial] = ACTIONS(3529),
    [anon_sym_private] = ACTIONS(3529),
    [anon_sym_protected] = ACTIONS(3529),
    [anon_sym_public] = ACTIONS(3529),
    [anon_sym_readonly] = ACTIONS(3529),
    [anon_sym_required] = ACTIONS(3529),
    [anon_sym_sealed] = ACTIONS(3529),
    [anon_sym_virtual] = ACTIONS(3529),
    [anon_sym_volatile] = ACTIONS(3529),
    [anon_sym_where] = ACTIONS(3529),
    [anon_sym_notnull] = ACTIONS(3529),
    [anon_sym_unmanaged] = ACTIONS(3529),
    [anon_sym_checked] = ACTIONS(3529),
    [anon_sym_BANG] = ACTIONS(3531),
    [anon_sym_TILDE] = ACTIONS(3531),
    [anon_sym_PLUS_PLUS] = ACTIONS(3531),
    [anon_sym_DASH_DASH] = ACTIONS(3531),
    [anon_sym_true] = ACTIONS(3529),
    [anon_sym_false] = ACTIONS(3529),
    [anon_sym_PLUS] = ACTIONS(3529),
    [anon_sym_DASH] = ACTIONS(3529),
    [anon_sym_STAR] = ACTIONS(3531),
    [anon_sym_CARET] = ACTIONS(3531),
    [anon_sym_AMP] = ACTIONS(3531),
    [anon_sym_this] = ACTIONS(3529),
    [anon_sym_scoped] = ACTIONS(3529),
    [anon_sym_base] = ACTIONS(3529),
    [anon_sym_var] = ACTIONS(3529),
    [sym_predefined_type] = ACTIONS(3529),
    [anon_sym_break] = ACTIONS(3529),
    [anon_sym_unchecked] = ACTIONS(3529),
    [anon_sym_continue] = ACTIONS(3529),
    [anon_sym_do] = ACTIONS(3529),
    [anon_sym_while] = ACTIONS(3529),
    [anon_sym_for] = ACTIONS(3529),
    [anon_sym_lock] = ACTIONS(3529),
    [anon_sym_yield] = ACTIONS(3529),
    [anon_sym_switch] = ACTIONS(3529),
    [anon_sym_default] = ACTIONS(3529),
    [anon_sym_throw] = ACTIONS(3529),
    [anon_sym_try] = ACTIONS(3529),
    [anon_sym_when] = ACTIONS(3529),
    [anon_sym_await] = ACTIONS(3529),
    [anon_sym_foreach] = ACTIONS(3529),
    [anon_sym_goto] = ACTIONS(3529),
    [anon_sym_if] = ACTIONS(3529),
    [anon_sym_DOT_DOT] = ACTIONS(3531),
    [anon_sym_from] = ACTIONS(3529),
    [anon_sym_into] = ACTIONS(3529),
    [anon_sym_join] = ACTIONS(3529),
    [anon_sym_on] = ACTIONS(3529),
    [anon_sym_equals] = ACTIONS(3529),
    [anon_sym_let] = ACTIONS(3529),
    [anon_sym_orderby] = ACTIONS(3529),
    [anon_sym_ascending] = ACTIONS(3529),
    [anon_sym_descending] = ACTIONS(3529),
    [anon_sym_group] = ACTIONS(3529),
    [anon_sym_by] = ACTIONS(3529),
    [anon_sym_select] = ACTIONS(3529),
    [anon_sym_stackalloc] = ACTIONS(3529),
    [anon_sym_sizeof] = ACTIONS(3529),
    [anon_sym_typeof] = ACTIONS(3529),
    [anon_sym___makeref] = ACTIONS(3529),
    [anon_sym___reftype] = ACTIONS(3529),
    [anon_sym___refvalue] = ACTIONS(3529),
    [sym_null_literal] = ACTIONS(3529),
    [anon_sym_SQUOTE] = ACTIONS(3531),
    [sym_integer_literal] = ACTIONS(3529),
    [sym_real_literal] = ACTIONS(3531),
    [anon_sym_DQUOTE] = ACTIONS(3531),
    [sym_verbatim_string_literal] = ACTIONS(3531),
    [aux_sym_preproc_if_token1] = ACTIONS(3531),
    [aux_sym_preproc_if_token3] = ACTIONS(3531),
    [aux_sym_preproc_else_token1] = ACTIONS(3531),
    [aux_sym_preproc_elif_token1] = ACTIONS(3531),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3531),
    [sym_interpolation_verbatim_start] = ACTIONS(3531),
    [sym_interpolation_raw_start] = ACTIONS(3531),
    [sym_raw_string_start] = ACTIONS(3531),
  },
  [2339] = {
    [sym_preproc_region] = STATE(2339),
    [sym_preproc_endregion] = STATE(2339),
    [sym_preproc_line] = STATE(2339),
    [sym_preproc_pragma] = STATE(2339),
    [sym_preproc_nullable] = STATE(2339),
    [sym_preproc_error] = STATE(2339),
    [sym_preproc_warning] = STATE(2339),
    [sym_preproc_define] = STATE(2339),
    [sym_preproc_undef] = STATE(2339),
    [sym__identifier_token] = ACTIONS(3533),
    [anon_sym_extern] = ACTIONS(3533),
    [anon_sym_alias] = ACTIONS(3533),
    [anon_sym_SEMI] = ACTIONS(3535),
    [anon_sym_global] = ACTIONS(3533),
    [anon_sym_using] = ACTIONS(3533),
    [anon_sym_unsafe] = ACTIONS(3533),
    [anon_sym_static] = ACTIONS(3533),
    [anon_sym_LBRACK] = ACTIONS(3535),
    [anon_sym_LPAREN] = ACTIONS(3535),
    [anon_sym_return] = ACTIONS(3533),
    [anon_sym_namespace] = ACTIONS(3533),
    [anon_sym_class] = ACTIONS(3533),
    [anon_sym_ref] = ACTIONS(3533),
    [anon_sym_struct] = ACTIONS(3533),
    [anon_sym_enum] = ACTIONS(3533),
    [anon_sym_LBRACE] = ACTIONS(3535),
    [anon_sym_interface] = ACTIONS(3533),
    [anon_sym_delegate] = ACTIONS(3533),
    [anon_sym_record] = ACTIONS(3533),
    [anon_sym_abstract] = ACTIONS(3533),
    [anon_sym_async] = ACTIONS(3533),
    [anon_sym_const] = ACTIONS(3533),
    [anon_sym_file] = ACTIONS(3533),
    [anon_sym_fixed] = ACTIONS(3533),
    [anon_sym_internal] = ACTIONS(3533),
    [anon_sym_new] = ACTIONS(3533),
    [anon_sym_override] = ACTIONS(3533),
    [anon_sym_partial] = ACTIONS(3533),
    [anon_sym_private] = ACTIONS(3533),
    [anon_sym_protected] = ACTIONS(3533),
    [anon_sym_public] = ACTIONS(3533),
    [anon_sym_readonly] = ACTIONS(3533),
    [anon_sym_required] = ACTIONS(3533),
    [anon_sym_sealed] = ACTIONS(3533),
    [anon_sym_virtual] = ACTIONS(3533),
    [anon_sym_volatile] = ACTIONS(3533),
    [anon_sym_where] = ACTIONS(3533),
    [anon_sym_notnull] = ACTIONS(3533),
    [anon_sym_unmanaged] = ACTIONS(3533),
    [anon_sym_checked] = ACTIONS(3533),
    [anon_sym_BANG] = ACTIONS(3535),
    [anon_sym_TILDE] = ACTIONS(3535),
    [anon_sym_PLUS_PLUS] = ACTIONS(3535),
    [anon_sym_DASH_DASH] = ACTIONS(3535),
    [anon_sym_true] = ACTIONS(3533),
    [anon_sym_false] = ACTIONS(3533),
    [anon_sym_PLUS] = ACTIONS(3533),
    [anon_sym_DASH] = ACTIONS(3533),
    [anon_sym_STAR] = ACTIONS(3535),
    [anon_sym_CARET] = ACTIONS(3535),
    [anon_sym_AMP] = ACTIONS(3535),
    [anon_sym_this] = ACTIONS(3533),
    [anon_sym_scoped] = ACTIONS(3533),
    [anon_sym_base] = ACTIONS(3533),
    [anon_sym_var] = ACTIONS(3533),
    [sym_predefined_type] = ACTIONS(3533),
    [anon_sym_break] = ACTIONS(3533),
    [anon_sym_unchecked] = ACTIONS(3533),
    [anon_sym_continue] = ACTIONS(3533),
    [anon_sym_do] = ACTIONS(3533),
    [anon_sym_while] = ACTIONS(3533),
    [anon_sym_for] = ACTIONS(3533),
    [anon_sym_lock] = ACTIONS(3533),
    [anon_sym_yield] = ACTIONS(3533),
    [anon_sym_switch] = ACTIONS(3533),
    [anon_sym_default] = ACTIONS(3533),
    [anon_sym_throw] = ACTIONS(3533),
    [anon_sym_try] = ACTIONS(3533),
    [anon_sym_when] = ACTIONS(3533),
    [anon_sym_await] = ACTIONS(3533),
    [anon_sym_foreach] = ACTIONS(3533),
    [anon_sym_goto] = ACTIONS(3533),
    [anon_sym_if] = ACTIONS(3533),
    [anon_sym_DOT_DOT] = ACTIONS(3535),
    [anon_sym_from] = ACTIONS(3533),
    [anon_sym_into] = ACTIONS(3533),
    [anon_sym_join] = ACTIONS(3533),
    [anon_sym_on] = ACTIONS(3533),
    [anon_sym_equals] = ACTIONS(3533),
    [anon_sym_let] = ACTIONS(3533),
    [anon_sym_orderby] = ACTIONS(3533),
    [anon_sym_ascending] = ACTIONS(3533),
    [anon_sym_descending] = ACTIONS(3533),
    [anon_sym_group] = ACTIONS(3533),
    [anon_sym_by] = ACTIONS(3533),
    [anon_sym_select] = ACTIONS(3533),
    [anon_sym_stackalloc] = ACTIONS(3533),
    [anon_sym_sizeof] = ACTIONS(3533),
    [anon_sym_typeof] = ACTIONS(3533),
    [anon_sym___makeref] = ACTIONS(3533),
    [anon_sym___reftype] = ACTIONS(3533),
    [anon_sym___refvalue] = ACTIONS(3533),
    [sym_null_literal] = ACTIONS(3533),
    [anon_sym_SQUOTE] = ACTIONS(3535),
    [sym_integer_literal] = ACTIONS(3533),
    [sym_real_literal] = ACTIONS(3535),
    [anon_sym_DQUOTE] = ACTIONS(3535),
    [sym_verbatim_string_literal] = ACTIONS(3535),
    [aux_sym_preproc_if_token1] = ACTIONS(3535),
    [aux_sym_preproc_if_token3] = ACTIONS(3535),
    [aux_sym_preproc_else_token1] = ACTIONS(3535),
    [aux_sym_preproc_elif_token1] = ACTIONS(3535),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3535),
    [sym_interpolation_verbatim_start] = ACTIONS(3535),
    [sym_interpolation_raw_start] = ACTIONS(3535),
    [sym_raw_string_start] = ACTIONS(3535),
  },
  [2340] = {
    [sym_preproc_region] = STATE(2340),
    [sym_preproc_endregion] = STATE(2340),
    [sym_preproc_line] = STATE(2340),
    [sym_preproc_pragma] = STATE(2340),
    [sym_preproc_nullable] = STATE(2340),
    [sym_preproc_error] = STATE(2340),
    [sym_preproc_warning] = STATE(2340),
    [sym_preproc_define] = STATE(2340),
    [sym_preproc_undef] = STATE(2340),
    [sym__identifier_token] = ACTIONS(3537),
    [anon_sym_extern] = ACTIONS(3537),
    [anon_sym_alias] = ACTIONS(3537),
    [anon_sym_SEMI] = ACTIONS(3539),
    [anon_sym_global] = ACTIONS(3537),
    [anon_sym_using] = ACTIONS(3537),
    [anon_sym_unsafe] = ACTIONS(3537),
    [anon_sym_static] = ACTIONS(3537),
    [anon_sym_LBRACK] = ACTIONS(3539),
    [anon_sym_LPAREN] = ACTIONS(3539),
    [anon_sym_return] = ACTIONS(3537),
    [anon_sym_namespace] = ACTIONS(3537),
    [anon_sym_class] = ACTIONS(3537),
    [anon_sym_ref] = ACTIONS(3537),
    [anon_sym_struct] = ACTIONS(3537),
    [anon_sym_enum] = ACTIONS(3537),
    [anon_sym_LBRACE] = ACTIONS(3539),
    [anon_sym_interface] = ACTIONS(3537),
    [anon_sym_delegate] = ACTIONS(3537),
    [anon_sym_record] = ACTIONS(3537),
    [anon_sym_abstract] = ACTIONS(3537),
    [anon_sym_async] = ACTIONS(3537),
    [anon_sym_const] = ACTIONS(3537),
    [anon_sym_file] = ACTIONS(3537),
    [anon_sym_fixed] = ACTIONS(3537),
    [anon_sym_internal] = ACTIONS(3537),
    [anon_sym_new] = ACTIONS(3537),
    [anon_sym_override] = ACTIONS(3537),
    [anon_sym_partial] = ACTIONS(3537),
    [anon_sym_private] = ACTIONS(3537),
    [anon_sym_protected] = ACTIONS(3537),
    [anon_sym_public] = ACTIONS(3537),
    [anon_sym_readonly] = ACTIONS(3537),
    [anon_sym_required] = ACTIONS(3537),
    [anon_sym_sealed] = ACTIONS(3537),
    [anon_sym_virtual] = ACTIONS(3537),
    [anon_sym_volatile] = ACTIONS(3537),
    [anon_sym_where] = ACTIONS(3537),
    [anon_sym_notnull] = ACTIONS(3537),
    [anon_sym_unmanaged] = ACTIONS(3537),
    [anon_sym_checked] = ACTIONS(3537),
    [anon_sym_BANG] = ACTIONS(3539),
    [anon_sym_TILDE] = ACTIONS(3539),
    [anon_sym_PLUS_PLUS] = ACTIONS(3539),
    [anon_sym_DASH_DASH] = ACTIONS(3539),
    [anon_sym_true] = ACTIONS(3537),
    [anon_sym_false] = ACTIONS(3537),
    [anon_sym_PLUS] = ACTIONS(3537),
    [anon_sym_DASH] = ACTIONS(3537),
    [anon_sym_STAR] = ACTIONS(3539),
    [anon_sym_CARET] = ACTIONS(3539),
    [anon_sym_AMP] = ACTIONS(3539),
    [anon_sym_this] = ACTIONS(3537),
    [anon_sym_scoped] = ACTIONS(3537),
    [anon_sym_base] = ACTIONS(3537),
    [anon_sym_var] = ACTIONS(3537),
    [sym_predefined_type] = ACTIONS(3537),
    [anon_sym_break] = ACTIONS(3537),
    [anon_sym_unchecked] = ACTIONS(3537),
    [anon_sym_continue] = ACTIONS(3537),
    [anon_sym_do] = ACTIONS(3537),
    [anon_sym_while] = ACTIONS(3537),
    [anon_sym_for] = ACTIONS(3537),
    [anon_sym_lock] = ACTIONS(3537),
    [anon_sym_yield] = ACTIONS(3537),
    [anon_sym_switch] = ACTIONS(3537),
    [anon_sym_default] = ACTIONS(3537),
    [anon_sym_throw] = ACTIONS(3537),
    [anon_sym_try] = ACTIONS(3537),
    [anon_sym_when] = ACTIONS(3537),
    [anon_sym_await] = ACTIONS(3537),
    [anon_sym_foreach] = ACTIONS(3537),
    [anon_sym_goto] = ACTIONS(3537),
    [anon_sym_if] = ACTIONS(3537),
    [anon_sym_DOT_DOT] = ACTIONS(3539),
    [anon_sym_from] = ACTIONS(3537),
    [anon_sym_into] = ACTIONS(3537),
    [anon_sym_join] = ACTIONS(3537),
    [anon_sym_on] = ACTIONS(3537),
    [anon_sym_equals] = ACTIONS(3537),
    [anon_sym_let] = ACTIONS(3537),
    [anon_sym_orderby] = ACTIONS(3537),
    [anon_sym_ascending] = ACTIONS(3537),
    [anon_sym_descending] = ACTIONS(3537),
    [anon_sym_group] = ACTIONS(3537),
    [anon_sym_by] = ACTIONS(3537),
    [anon_sym_select] = ACTIONS(3537),
    [anon_sym_stackalloc] = ACTIONS(3537),
    [anon_sym_sizeof] = ACTIONS(3537),
    [anon_sym_typeof] = ACTIONS(3537),
    [anon_sym___makeref] = ACTIONS(3537),
    [anon_sym___reftype] = ACTIONS(3537),
    [anon_sym___refvalue] = ACTIONS(3537),
    [sym_null_literal] = ACTIONS(3537),
    [anon_sym_SQUOTE] = ACTIONS(3539),
    [sym_integer_literal] = ACTIONS(3537),
    [sym_real_literal] = ACTIONS(3539),
    [anon_sym_DQUOTE] = ACTIONS(3539),
    [sym_verbatim_string_literal] = ACTIONS(3539),
    [aux_sym_preproc_if_token1] = ACTIONS(3539),
    [aux_sym_preproc_if_token3] = ACTIONS(3539),
    [aux_sym_preproc_else_token1] = ACTIONS(3539),
    [aux_sym_preproc_elif_token1] = ACTIONS(3539),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3539),
    [sym_interpolation_verbatim_start] = ACTIONS(3539),
    [sym_interpolation_raw_start] = ACTIONS(3539),
    [sym_raw_string_start] = ACTIONS(3539),
  },
  [2341] = {
    [sym_preproc_region] = STATE(2341),
    [sym_preproc_endregion] = STATE(2341),
    [sym_preproc_line] = STATE(2341),
    [sym_preproc_pragma] = STATE(2341),
    [sym_preproc_nullable] = STATE(2341),
    [sym_preproc_error] = STATE(2341),
    [sym_preproc_warning] = STATE(2341),
    [sym_preproc_define] = STATE(2341),
    [sym_preproc_undef] = STATE(2341),
    [sym__identifier_token] = ACTIONS(3541),
    [anon_sym_extern] = ACTIONS(3541),
    [anon_sym_alias] = ACTIONS(3541),
    [anon_sym_SEMI] = ACTIONS(3543),
    [anon_sym_global] = ACTIONS(3541),
    [anon_sym_using] = ACTIONS(3541),
    [anon_sym_unsafe] = ACTIONS(3541),
    [anon_sym_static] = ACTIONS(3541),
    [anon_sym_LBRACK] = ACTIONS(3543),
    [anon_sym_LPAREN] = ACTIONS(3543),
    [anon_sym_return] = ACTIONS(3541),
    [anon_sym_namespace] = ACTIONS(3541),
    [anon_sym_class] = ACTIONS(3541),
    [anon_sym_ref] = ACTIONS(3541),
    [anon_sym_struct] = ACTIONS(3541),
    [anon_sym_enum] = ACTIONS(3541),
    [anon_sym_LBRACE] = ACTIONS(3543),
    [anon_sym_interface] = ACTIONS(3541),
    [anon_sym_delegate] = ACTIONS(3541),
    [anon_sym_record] = ACTIONS(3541),
    [anon_sym_abstract] = ACTIONS(3541),
    [anon_sym_async] = ACTIONS(3541),
    [anon_sym_const] = ACTIONS(3541),
    [anon_sym_file] = ACTIONS(3541),
    [anon_sym_fixed] = ACTIONS(3541),
    [anon_sym_internal] = ACTIONS(3541),
    [anon_sym_new] = ACTIONS(3541),
    [anon_sym_override] = ACTIONS(3541),
    [anon_sym_partial] = ACTIONS(3541),
    [anon_sym_private] = ACTIONS(3541),
    [anon_sym_protected] = ACTIONS(3541),
    [anon_sym_public] = ACTIONS(3541),
    [anon_sym_readonly] = ACTIONS(3541),
    [anon_sym_required] = ACTIONS(3541),
    [anon_sym_sealed] = ACTIONS(3541),
    [anon_sym_virtual] = ACTIONS(3541),
    [anon_sym_volatile] = ACTIONS(3541),
    [anon_sym_where] = ACTIONS(3541),
    [anon_sym_notnull] = ACTIONS(3541),
    [anon_sym_unmanaged] = ACTIONS(3541),
    [anon_sym_checked] = ACTIONS(3541),
    [anon_sym_BANG] = ACTIONS(3543),
    [anon_sym_TILDE] = ACTIONS(3543),
    [anon_sym_PLUS_PLUS] = ACTIONS(3543),
    [anon_sym_DASH_DASH] = ACTIONS(3543),
    [anon_sym_true] = ACTIONS(3541),
    [anon_sym_false] = ACTIONS(3541),
    [anon_sym_PLUS] = ACTIONS(3541),
    [anon_sym_DASH] = ACTIONS(3541),
    [anon_sym_STAR] = ACTIONS(3543),
    [anon_sym_CARET] = ACTIONS(3543),
    [anon_sym_AMP] = ACTIONS(3543),
    [anon_sym_this] = ACTIONS(3541),
    [anon_sym_scoped] = ACTIONS(3541),
    [anon_sym_base] = ACTIONS(3541),
    [anon_sym_var] = ACTIONS(3541),
    [sym_predefined_type] = ACTIONS(3541),
    [anon_sym_break] = ACTIONS(3541),
    [anon_sym_unchecked] = ACTIONS(3541),
    [anon_sym_continue] = ACTIONS(3541),
    [anon_sym_do] = ACTIONS(3541),
    [anon_sym_while] = ACTIONS(3541),
    [anon_sym_for] = ACTIONS(3541),
    [anon_sym_lock] = ACTIONS(3541),
    [anon_sym_yield] = ACTIONS(3541),
    [anon_sym_switch] = ACTIONS(3541),
    [anon_sym_default] = ACTIONS(3541),
    [anon_sym_throw] = ACTIONS(3541),
    [anon_sym_try] = ACTIONS(3541),
    [anon_sym_when] = ACTIONS(3541),
    [anon_sym_await] = ACTIONS(3541),
    [anon_sym_foreach] = ACTIONS(3541),
    [anon_sym_goto] = ACTIONS(3541),
    [anon_sym_if] = ACTIONS(3541),
    [anon_sym_DOT_DOT] = ACTIONS(3543),
    [anon_sym_from] = ACTIONS(3541),
    [anon_sym_into] = ACTIONS(3541),
    [anon_sym_join] = ACTIONS(3541),
    [anon_sym_on] = ACTIONS(3541),
    [anon_sym_equals] = ACTIONS(3541),
    [anon_sym_let] = ACTIONS(3541),
    [anon_sym_orderby] = ACTIONS(3541),
    [anon_sym_ascending] = ACTIONS(3541),
    [anon_sym_descending] = ACTIONS(3541),
    [anon_sym_group] = ACTIONS(3541),
    [anon_sym_by] = ACTIONS(3541),
    [anon_sym_select] = ACTIONS(3541),
    [anon_sym_stackalloc] = ACTIONS(3541),
    [anon_sym_sizeof] = ACTIONS(3541),
    [anon_sym_typeof] = ACTIONS(3541),
    [anon_sym___makeref] = ACTIONS(3541),
    [anon_sym___reftype] = ACTIONS(3541),
    [anon_sym___refvalue] = ACTIONS(3541),
    [sym_null_literal] = ACTIONS(3541),
    [anon_sym_SQUOTE] = ACTIONS(3543),
    [sym_integer_literal] = ACTIONS(3541),
    [sym_real_literal] = ACTIONS(3543),
    [anon_sym_DQUOTE] = ACTIONS(3543),
    [sym_verbatim_string_literal] = ACTIONS(3543),
    [aux_sym_preproc_if_token1] = ACTIONS(3543),
    [aux_sym_preproc_if_token3] = ACTIONS(3543),
    [aux_sym_preproc_else_token1] = ACTIONS(3543),
    [aux_sym_preproc_elif_token1] = ACTIONS(3543),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3543),
    [sym_interpolation_verbatim_start] = ACTIONS(3543),
    [sym_interpolation_raw_start] = ACTIONS(3543),
    [sym_raw_string_start] = ACTIONS(3543),
  },
  [2342] = {
    [sym_preproc_region] = STATE(2342),
    [sym_preproc_endregion] = STATE(2342),
    [sym_preproc_line] = STATE(2342),
    [sym_preproc_pragma] = STATE(2342),
    [sym_preproc_nullable] = STATE(2342),
    [sym_preproc_error] = STATE(2342),
    [sym_preproc_warning] = STATE(2342),
    [sym_preproc_define] = STATE(2342),
    [sym_preproc_undef] = STATE(2342),
    [sym__identifier_token] = ACTIONS(3545),
    [anon_sym_extern] = ACTIONS(3545),
    [anon_sym_alias] = ACTIONS(3545),
    [anon_sym_SEMI] = ACTIONS(3547),
    [anon_sym_global] = ACTIONS(3545),
    [anon_sym_using] = ACTIONS(3545),
    [anon_sym_unsafe] = ACTIONS(3545),
    [anon_sym_static] = ACTIONS(3545),
    [anon_sym_LBRACK] = ACTIONS(3547),
    [anon_sym_LPAREN] = ACTIONS(3547),
    [anon_sym_return] = ACTIONS(3545),
    [anon_sym_namespace] = ACTIONS(3545),
    [anon_sym_class] = ACTIONS(3545),
    [anon_sym_ref] = ACTIONS(3545),
    [anon_sym_struct] = ACTIONS(3545),
    [anon_sym_enum] = ACTIONS(3545),
    [anon_sym_LBRACE] = ACTIONS(3547),
    [anon_sym_interface] = ACTIONS(3545),
    [anon_sym_delegate] = ACTIONS(3545),
    [anon_sym_record] = ACTIONS(3545),
    [anon_sym_abstract] = ACTIONS(3545),
    [anon_sym_async] = ACTIONS(3545),
    [anon_sym_const] = ACTIONS(3545),
    [anon_sym_file] = ACTIONS(3545),
    [anon_sym_fixed] = ACTIONS(3545),
    [anon_sym_internal] = ACTIONS(3545),
    [anon_sym_new] = ACTIONS(3545),
    [anon_sym_override] = ACTIONS(3545),
    [anon_sym_partial] = ACTIONS(3545),
    [anon_sym_private] = ACTIONS(3545),
    [anon_sym_protected] = ACTIONS(3545),
    [anon_sym_public] = ACTIONS(3545),
    [anon_sym_readonly] = ACTIONS(3545),
    [anon_sym_required] = ACTIONS(3545),
    [anon_sym_sealed] = ACTIONS(3545),
    [anon_sym_virtual] = ACTIONS(3545),
    [anon_sym_volatile] = ACTIONS(3545),
    [anon_sym_where] = ACTIONS(3545),
    [anon_sym_notnull] = ACTIONS(3545),
    [anon_sym_unmanaged] = ACTIONS(3545),
    [anon_sym_checked] = ACTIONS(3545),
    [anon_sym_BANG] = ACTIONS(3547),
    [anon_sym_TILDE] = ACTIONS(3547),
    [anon_sym_PLUS_PLUS] = ACTIONS(3547),
    [anon_sym_DASH_DASH] = ACTIONS(3547),
    [anon_sym_true] = ACTIONS(3545),
    [anon_sym_false] = ACTIONS(3545),
    [anon_sym_PLUS] = ACTIONS(3545),
    [anon_sym_DASH] = ACTIONS(3545),
    [anon_sym_STAR] = ACTIONS(3547),
    [anon_sym_CARET] = ACTIONS(3547),
    [anon_sym_AMP] = ACTIONS(3547),
    [anon_sym_this] = ACTIONS(3545),
    [anon_sym_scoped] = ACTIONS(3545),
    [anon_sym_base] = ACTIONS(3545),
    [anon_sym_var] = ACTIONS(3545),
    [sym_predefined_type] = ACTIONS(3545),
    [anon_sym_break] = ACTIONS(3545),
    [anon_sym_unchecked] = ACTIONS(3545),
    [anon_sym_continue] = ACTIONS(3545),
    [anon_sym_do] = ACTIONS(3545),
    [anon_sym_while] = ACTIONS(3545),
    [anon_sym_for] = ACTIONS(3545),
    [anon_sym_lock] = ACTIONS(3545),
    [anon_sym_yield] = ACTIONS(3545),
    [anon_sym_switch] = ACTIONS(3545),
    [anon_sym_default] = ACTIONS(3545),
    [anon_sym_throw] = ACTIONS(3545),
    [anon_sym_try] = ACTIONS(3545),
    [anon_sym_when] = ACTIONS(3545),
    [anon_sym_await] = ACTIONS(3545),
    [anon_sym_foreach] = ACTIONS(3545),
    [anon_sym_goto] = ACTIONS(3545),
    [anon_sym_if] = ACTIONS(3545),
    [anon_sym_DOT_DOT] = ACTIONS(3547),
    [anon_sym_from] = ACTIONS(3545),
    [anon_sym_into] = ACTIONS(3545),
    [anon_sym_join] = ACTIONS(3545),
    [anon_sym_on] = ACTIONS(3545),
    [anon_sym_equals] = ACTIONS(3545),
    [anon_sym_let] = ACTIONS(3545),
    [anon_sym_orderby] = ACTIONS(3545),
    [anon_sym_ascending] = ACTIONS(3545),
    [anon_sym_descending] = ACTIONS(3545),
    [anon_sym_group] = ACTIONS(3545),
    [anon_sym_by] = ACTIONS(3545),
    [anon_sym_select] = ACTIONS(3545),
    [anon_sym_stackalloc] = ACTIONS(3545),
    [anon_sym_sizeof] = ACTIONS(3545),
    [anon_sym_typeof] = ACTIONS(3545),
    [anon_sym___makeref] = ACTIONS(3545),
    [anon_sym___reftype] = ACTIONS(3545),
    [anon_sym___refvalue] = ACTIONS(3545),
    [sym_null_literal] = ACTIONS(3545),
    [anon_sym_SQUOTE] = ACTIONS(3547),
    [sym_integer_literal] = ACTIONS(3545),
    [sym_real_literal] = ACTIONS(3547),
    [anon_sym_DQUOTE] = ACTIONS(3547),
    [sym_verbatim_string_literal] = ACTIONS(3547),
    [aux_sym_preproc_if_token1] = ACTIONS(3547),
    [aux_sym_preproc_if_token3] = ACTIONS(3547),
    [aux_sym_preproc_else_token1] = ACTIONS(3547),
    [aux_sym_preproc_elif_token1] = ACTIONS(3547),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3547),
    [sym_interpolation_verbatim_start] = ACTIONS(3547),
    [sym_interpolation_raw_start] = ACTIONS(3547),
    [sym_raw_string_start] = ACTIONS(3547),
  },
  [2343] = {
    [sym_preproc_region] = STATE(2343),
    [sym_preproc_endregion] = STATE(2343),
    [sym_preproc_line] = STATE(2343),
    [sym_preproc_pragma] = STATE(2343),
    [sym_preproc_nullable] = STATE(2343),
    [sym_preproc_error] = STATE(2343),
    [sym_preproc_warning] = STATE(2343),
    [sym_preproc_define] = STATE(2343),
    [sym_preproc_undef] = STATE(2343),
    [sym__identifier_token] = ACTIONS(3549),
    [anon_sym_extern] = ACTIONS(3549),
    [anon_sym_alias] = ACTIONS(3549),
    [anon_sym_SEMI] = ACTIONS(3551),
    [anon_sym_global] = ACTIONS(3549),
    [anon_sym_using] = ACTIONS(3549),
    [anon_sym_unsafe] = ACTIONS(3549),
    [anon_sym_static] = ACTIONS(3549),
    [anon_sym_LBRACK] = ACTIONS(3551),
    [anon_sym_LPAREN] = ACTIONS(3551),
    [anon_sym_return] = ACTIONS(3549),
    [anon_sym_namespace] = ACTIONS(3549),
    [anon_sym_class] = ACTIONS(3549),
    [anon_sym_ref] = ACTIONS(3549),
    [anon_sym_struct] = ACTIONS(3549),
    [anon_sym_enum] = ACTIONS(3549),
    [anon_sym_LBRACE] = ACTIONS(3551),
    [anon_sym_interface] = ACTIONS(3549),
    [anon_sym_delegate] = ACTIONS(3549),
    [anon_sym_record] = ACTIONS(3549),
    [anon_sym_abstract] = ACTIONS(3549),
    [anon_sym_async] = ACTIONS(3549),
    [anon_sym_const] = ACTIONS(3549),
    [anon_sym_file] = ACTIONS(3549),
    [anon_sym_fixed] = ACTIONS(3549),
    [anon_sym_internal] = ACTIONS(3549),
    [anon_sym_new] = ACTIONS(3549),
    [anon_sym_override] = ACTIONS(3549),
    [anon_sym_partial] = ACTIONS(3549),
    [anon_sym_private] = ACTIONS(3549),
    [anon_sym_protected] = ACTIONS(3549),
    [anon_sym_public] = ACTIONS(3549),
    [anon_sym_readonly] = ACTIONS(3549),
    [anon_sym_required] = ACTIONS(3549),
    [anon_sym_sealed] = ACTIONS(3549),
    [anon_sym_virtual] = ACTIONS(3549),
    [anon_sym_volatile] = ACTIONS(3549),
    [anon_sym_where] = ACTIONS(3549),
    [anon_sym_notnull] = ACTIONS(3549),
    [anon_sym_unmanaged] = ACTIONS(3549),
    [anon_sym_checked] = ACTIONS(3549),
    [anon_sym_BANG] = ACTIONS(3551),
    [anon_sym_TILDE] = ACTIONS(3551),
    [anon_sym_PLUS_PLUS] = ACTIONS(3551),
    [anon_sym_DASH_DASH] = ACTIONS(3551),
    [anon_sym_true] = ACTIONS(3549),
    [anon_sym_false] = ACTIONS(3549),
    [anon_sym_PLUS] = ACTIONS(3549),
    [anon_sym_DASH] = ACTIONS(3549),
    [anon_sym_STAR] = ACTIONS(3551),
    [anon_sym_CARET] = ACTIONS(3551),
    [anon_sym_AMP] = ACTIONS(3551),
    [anon_sym_this] = ACTIONS(3549),
    [anon_sym_scoped] = ACTIONS(3549),
    [anon_sym_base] = ACTIONS(3549),
    [anon_sym_var] = ACTIONS(3549),
    [sym_predefined_type] = ACTIONS(3549),
    [anon_sym_break] = ACTIONS(3549),
    [anon_sym_unchecked] = ACTIONS(3549),
    [anon_sym_continue] = ACTIONS(3549),
    [anon_sym_do] = ACTIONS(3549),
    [anon_sym_while] = ACTIONS(3549),
    [anon_sym_for] = ACTIONS(3549),
    [anon_sym_lock] = ACTIONS(3549),
    [anon_sym_yield] = ACTIONS(3549),
    [anon_sym_switch] = ACTIONS(3549),
    [anon_sym_default] = ACTIONS(3549),
    [anon_sym_throw] = ACTIONS(3549),
    [anon_sym_try] = ACTIONS(3549),
    [anon_sym_when] = ACTIONS(3549),
    [anon_sym_await] = ACTIONS(3549),
    [anon_sym_foreach] = ACTIONS(3549),
    [anon_sym_goto] = ACTIONS(3549),
    [anon_sym_if] = ACTIONS(3549),
    [anon_sym_DOT_DOT] = ACTIONS(3551),
    [anon_sym_from] = ACTIONS(3549),
    [anon_sym_into] = ACTIONS(3549),
    [anon_sym_join] = ACTIONS(3549),
    [anon_sym_on] = ACTIONS(3549),
    [anon_sym_equals] = ACTIONS(3549),
    [anon_sym_let] = ACTIONS(3549),
    [anon_sym_orderby] = ACTIONS(3549),
    [anon_sym_ascending] = ACTIONS(3549),
    [anon_sym_descending] = ACTIONS(3549),
    [anon_sym_group] = ACTIONS(3549),
    [anon_sym_by] = ACTIONS(3549),
    [anon_sym_select] = ACTIONS(3549),
    [anon_sym_stackalloc] = ACTIONS(3549),
    [anon_sym_sizeof] = ACTIONS(3549),
    [anon_sym_typeof] = ACTIONS(3549),
    [anon_sym___makeref] = ACTIONS(3549),
    [anon_sym___reftype] = ACTIONS(3549),
    [anon_sym___refvalue] = ACTIONS(3549),
    [sym_null_literal] = ACTIONS(3549),
    [anon_sym_SQUOTE] = ACTIONS(3551),
    [sym_integer_literal] = ACTIONS(3549),
    [sym_real_literal] = ACTIONS(3551),
    [anon_sym_DQUOTE] = ACTIONS(3551),
    [sym_verbatim_string_literal] = ACTIONS(3551),
    [aux_sym_preproc_if_token1] = ACTIONS(3551),
    [aux_sym_preproc_if_token3] = ACTIONS(3551),
    [aux_sym_preproc_else_token1] = ACTIONS(3551),
    [aux_sym_preproc_elif_token1] = ACTIONS(3551),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3551),
    [sym_interpolation_verbatim_start] = ACTIONS(3551),
    [sym_interpolation_raw_start] = ACTIONS(3551),
    [sym_raw_string_start] = ACTIONS(3551),
  },
  [2344] = {
    [sym_preproc_region] = STATE(2344),
    [sym_preproc_endregion] = STATE(2344),
    [sym_preproc_line] = STATE(2344),
    [sym_preproc_pragma] = STATE(2344),
    [sym_preproc_nullable] = STATE(2344),
    [sym_preproc_error] = STATE(2344),
    [sym_preproc_warning] = STATE(2344),
    [sym_preproc_define] = STATE(2344),
    [sym_preproc_undef] = STATE(2344),
    [sym__identifier_token] = ACTIONS(3553),
    [anon_sym_extern] = ACTIONS(3553),
    [anon_sym_alias] = ACTIONS(3553),
    [anon_sym_SEMI] = ACTIONS(3555),
    [anon_sym_global] = ACTIONS(3553),
    [anon_sym_using] = ACTIONS(3553),
    [anon_sym_unsafe] = ACTIONS(3553),
    [anon_sym_static] = ACTIONS(3553),
    [anon_sym_LBRACK] = ACTIONS(3555),
    [anon_sym_LPAREN] = ACTIONS(3555),
    [anon_sym_return] = ACTIONS(3553),
    [anon_sym_namespace] = ACTIONS(3553),
    [anon_sym_class] = ACTIONS(3553),
    [anon_sym_ref] = ACTIONS(3553),
    [anon_sym_struct] = ACTIONS(3553),
    [anon_sym_enum] = ACTIONS(3553),
    [anon_sym_LBRACE] = ACTIONS(3555),
    [anon_sym_interface] = ACTIONS(3553),
    [anon_sym_delegate] = ACTIONS(3553),
    [anon_sym_record] = ACTIONS(3553),
    [anon_sym_abstract] = ACTIONS(3553),
    [anon_sym_async] = ACTIONS(3553),
    [anon_sym_const] = ACTIONS(3553),
    [anon_sym_file] = ACTIONS(3553),
    [anon_sym_fixed] = ACTIONS(3553),
    [anon_sym_internal] = ACTIONS(3553),
    [anon_sym_new] = ACTIONS(3553),
    [anon_sym_override] = ACTIONS(3553),
    [anon_sym_partial] = ACTIONS(3553),
    [anon_sym_private] = ACTIONS(3553),
    [anon_sym_protected] = ACTIONS(3553),
    [anon_sym_public] = ACTIONS(3553),
    [anon_sym_readonly] = ACTIONS(3553),
    [anon_sym_required] = ACTIONS(3553),
    [anon_sym_sealed] = ACTIONS(3553),
    [anon_sym_virtual] = ACTIONS(3553),
    [anon_sym_volatile] = ACTIONS(3553),
    [anon_sym_where] = ACTIONS(3553),
    [anon_sym_notnull] = ACTIONS(3553),
    [anon_sym_unmanaged] = ACTIONS(3553),
    [anon_sym_checked] = ACTIONS(3553),
    [anon_sym_BANG] = ACTIONS(3555),
    [anon_sym_TILDE] = ACTIONS(3555),
    [anon_sym_PLUS_PLUS] = ACTIONS(3555),
    [anon_sym_DASH_DASH] = ACTIONS(3555),
    [anon_sym_true] = ACTIONS(3553),
    [anon_sym_false] = ACTIONS(3553),
    [anon_sym_PLUS] = ACTIONS(3553),
    [anon_sym_DASH] = ACTIONS(3553),
    [anon_sym_STAR] = ACTIONS(3555),
    [anon_sym_CARET] = ACTIONS(3555),
    [anon_sym_AMP] = ACTIONS(3555),
    [anon_sym_this] = ACTIONS(3553),
    [anon_sym_scoped] = ACTIONS(3553),
    [anon_sym_base] = ACTIONS(3553),
    [anon_sym_var] = ACTIONS(3553),
    [sym_predefined_type] = ACTIONS(3553),
    [anon_sym_break] = ACTIONS(3553),
    [anon_sym_unchecked] = ACTIONS(3553),
    [anon_sym_continue] = ACTIONS(3553),
    [anon_sym_do] = ACTIONS(3553),
    [anon_sym_while] = ACTIONS(3553),
    [anon_sym_for] = ACTIONS(3553),
    [anon_sym_lock] = ACTIONS(3553),
    [anon_sym_yield] = ACTIONS(3553),
    [anon_sym_switch] = ACTIONS(3553),
    [anon_sym_default] = ACTIONS(3553),
    [anon_sym_throw] = ACTIONS(3553),
    [anon_sym_try] = ACTIONS(3553),
    [anon_sym_when] = ACTIONS(3553),
    [anon_sym_await] = ACTIONS(3553),
    [anon_sym_foreach] = ACTIONS(3553),
    [anon_sym_goto] = ACTIONS(3553),
    [anon_sym_if] = ACTIONS(3553),
    [anon_sym_DOT_DOT] = ACTIONS(3555),
    [anon_sym_from] = ACTIONS(3553),
    [anon_sym_into] = ACTIONS(3553),
    [anon_sym_join] = ACTIONS(3553),
    [anon_sym_on] = ACTIONS(3553),
    [anon_sym_equals] = ACTIONS(3553),
    [anon_sym_let] = ACTIONS(3553),
    [anon_sym_orderby] = ACTIONS(3553),
    [anon_sym_ascending] = ACTIONS(3553),
    [anon_sym_descending] = ACTIONS(3553),
    [anon_sym_group] = ACTIONS(3553),
    [anon_sym_by] = ACTIONS(3553),
    [anon_sym_select] = ACTIONS(3553),
    [anon_sym_stackalloc] = ACTIONS(3553),
    [anon_sym_sizeof] = ACTIONS(3553),
    [anon_sym_typeof] = ACTIONS(3553),
    [anon_sym___makeref] = ACTIONS(3553),
    [anon_sym___reftype] = ACTIONS(3553),
    [anon_sym___refvalue] = ACTIONS(3553),
    [sym_null_literal] = ACTIONS(3553),
    [anon_sym_SQUOTE] = ACTIONS(3555),
    [sym_integer_literal] = ACTIONS(3553),
    [sym_real_literal] = ACTIONS(3555),
    [anon_sym_DQUOTE] = ACTIONS(3555),
    [sym_verbatim_string_literal] = ACTIONS(3555),
    [aux_sym_preproc_if_token1] = ACTIONS(3555),
    [aux_sym_preproc_if_token3] = ACTIONS(3555),
    [aux_sym_preproc_else_token1] = ACTIONS(3555),
    [aux_sym_preproc_elif_token1] = ACTIONS(3555),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3555),
    [sym_interpolation_verbatim_start] = ACTIONS(3555),
    [sym_interpolation_raw_start] = ACTIONS(3555),
    [sym_raw_string_start] = ACTIONS(3555),
  },
  [2345] = {
    [sym_preproc_region] = STATE(2345),
    [sym_preproc_endregion] = STATE(2345),
    [sym_preproc_line] = STATE(2345),
    [sym_preproc_pragma] = STATE(2345),
    [sym_preproc_nullable] = STATE(2345),
    [sym_preproc_error] = STATE(2345),
    [sym_preproc_warning] = STATE(2345),
    [sym_preproc_define] = STATE(2345),
    [sym_preproc_undef] = STATE(2345),
    [sym__identifier_token] = ACTIONS(3557),
    [anon_sym_extern] = ACTIONS(3557),
    [anon_sym_alias] = ACTIONS(3557),
    [anon_sym_SEMI] = ACTIONS(3559),
    [anon_sym_global] = ACTIONS(3557),
    [anon_sym_using] = ACTIONS(3557),
    [anon_sym_unsafe] = ACTIONS(3557),
    [anon_sym_static] = ACTIONS(3557),
    [anon_sym_LBRACK] = ACTIONS(3559),
    [anon_sym_LPAREN] = ACTIONS(3559),
    [anon_sym_return] = ACTIONS(3557),
    [anon_sym_namespace] = ACTIONS(3557),
    [anon_sym_class] = ACTIONS(3557),
    [anon_sym_ref] = ACTIONS(3557),
    [anon_sym_struct] = ACTIONS(3557),
    [anon_sym_enum] = ACTIONS(3557),
    [anon_sym_LBRACE] = ACTIONS(3559),
    [anon_sym_interface] = ACTIONS(3557),
    [anon_sym_delegate] = ACTIONS(3557),
    [anon_sym_record] = ACTIONS(3557),
    [anon_sym_abstract] = ACTIONS(3557),
    [anon_sym_async] = ACTIONS(3557),
    [anon_sym_const] = ACTIONS(3557),
    [anon_sym_file] = ACTIONS(3557),
    [anon_sym_fixed] = ACTIONS(3557),
    [anon_sym_internal] = ACTIONS(3557),
    [anon_sym_new] = ACTIONS(3557),
    [anon_sym_override] = ACTIONS(3557),
    [anon_sym_partial] = ACTIONS(3557),
    [anon_sym_private] = ACTIONS(3557),
    [anon_sym_protected] = ACTIONS(3557),
    [anon_sym_public] = ACTIONS(3557),
    [anon_sym_readonly] = ACTIONS(3557),
    [anon_sym_required] = ACTIONS(3557),
    [anon_sym_sealed] = ACTIONS(3557),
    [anon_sym_virtual] = ACTIONS(3557),
    [anon_sym_volatile] = ACTIONS(3557),
    [anon_sym_where] = ACTIONS(3557),
    [anon_sym_notnull] = ACTIONS(3557),
    [anon_sym_unmanaged] = ACTIONS(3557),
    [anon_sym_checked] = ACTIONS(3557),
    [anon_sym_BANG] = ACTIONS(3559),
    [anon_sym_TILDE] = ACTIONS(3559),
    [anon_sym_PLUS_PLUS] = ACTIONS(3559),
    [anon_sym_DASH_DASH] = ACTIONS(3559),
    [anon_sym_true] = ACTIONS(3557),
    [anon_sym_false] = ACTIONS(3557),
    [anon_sym_PLUS] = ACTIONS(3557),
    [anon_sym_DASH] = ACTIONS(3557),
    [anon_sym_STAR] = ACTIONS(3559),
    [anon_sym_CARET] = ACTIONS(3559),
    [anon_sym_AMP] = ACTIONS(3559),
    [anon_sym_this] = ACTIONS(3557),
    [anon_sym_scoped] = ACTIONS(3557),
    [anon_sym_base] = ACTIONS(3557),
    [anon_sym_var] = ACTIONS(3557),
    [sym_predefined_type] = ACTIONS(3557),
    [anon_sym_break] = ACTIONS(3557),
    [anon_sym_unchecked] = ACTIONS(3557),
    [anon_sym_continue] = ACTIONS(3557),
    [anon_sym_do] = ACTIONS(3557),
    [anon_sym_while] = ACTIONS(3557),
    [anon_sym_for] = ACTIONS(3557),
    [anon_sym_lock] = ACTIONS(3557),
    [anon_sym_yield] = ACTIONS(3557),
    [anon_sym_switch] = ACTIONS(3557),
    [anon_sym_default] = ACTIONS(3557),
    [anon_sym_throw] = ACTIONS(3557),
    [anon_sym_try] = ACTIONS(3557),
    [anon_sym_when] = ACTIONS(3557),
    [anon_sym_await] = ACTIONS(3557),
    [anon_sym_foreach] = ACTIONS(3557),
    [anon_sym_goto] = ACTIONS(3557),
    [anon_sym_if] = ACTIONS(3557),
    [anon_sym_DOT_DOT] = ACTIONS(3559),
    [anon_sym_from] = ACTIONS(3557),
    [anon_sym_into] = ACTIONS(3557),
    [anon_sym_join] = ACTIONS(3557),
    [anon_sym_on] = ACTIONS(3557),
    [anon_sym_equals] = ACTIONS(3557),
    [anon_sym_let] = ACTIONS(3557),
    [anon_sym_orderby] = ACTIONS(3557),
    [anon_sym_ascending] = ACTIONS(3557),
    [anon_sym_descending] = ACTIONS(3557),
    [anon_sym_group] = ACTIONS(3557),
    [anon_sym_by] = ACTIONS(3557),
    [anon_sym_select] = ACTIONS(3557),
    [anon_sym_stackalloc] = ACTIONS(3557),
    [anon_sym_sizeof] = ACTIONS(3557),
    [anon_sym_typeof] = ACTIONS(3557),
    [anon_sym___makeref] = ACTIONS(3557),
    [anon_sym___reftype] = ACTIONS(3557),
    [anon_sym___refvalue] = ACTIONS(3557),
    [sym_null_literal] = ACTIONS(3557),
    [anon_sym_SQUOTE] = ACTIONS(3559),
    [sym_integer_literal] = ACTIONS(3557),
    [sym_real_literal] = ACTIONS(3559),
    [anon_sym_DQUOTE] = ACTIONS(3559),
    [sym_verbatim_string_literal] = ACTIONS(3559),
    [aux_sym_preproc_if_token1] = ACTIONS(3559),
    [aux_sym_preproc_if_token3] = ACTIONS(3559),
    [aux_sym_preproc_else_token1] = ACTIONS(3559),
    [aux_sym_preproc_elif_token1] = ACTIONS(3559),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3559),
    [sym_interpolation_verbatim_start] = ACTIONS(3559),
    [sym_interpolation_raw_start] = ACTIONS(3559),
    [sym_raw_string_start] = ACTIONS(3559),
  },
  [2346] = {
    [sym_preproc_region] = STATE(2346),
    [sym_preproc_endregion] = STATE(2346),
    [sym_preproc_line] = STATE(2346),
    [sym_preproc_pragma] = STATE(2346),
    [sym_preproc_nullable] = STATE(2346),
    [sym_preproc_error] = STATE(2346),
    [sym_preproc_warning] = STATE(2346),
    [sym_preproc_define] = STATE(2346),
    [sym_preproc_undef] = STATE(2346),
    [sym__identifier_token] = ACTIONS(3561),
    [anon_sym_extern] = ACTIONS(3561),
    [anon_sym_alias] = ACTIONS(3561),
    [anon_sym_SEMI] = ACTIONS(3563),
    [anon_sym_global] = ACTIONS(3561),
    [anon_sym_using] = ACTIONS(3561),
    [anon_sym_unsafe] = ACTIONS(3561),
    [anon_sym_static] = ACTIONS(3561),
    [anon_sym_LBRACK] = ACTIONS(3563),
    [anon_sym_LPAREN] = ACTIONS(3563),
    [anon_sym_return] = ACTIONS(3561),
    [anon_sym_namespace] = ACTIONS(3561),
    [anon_sym_class] = ACTIONS(3561),
    [anon_sym_ref] = ACTIONS(3561),
    [anon_sym_struct] = ACTIONS(3561),
    [anon_sym_enum] = ACTIONS(3561),
    [anon_sym_LBRACE] = ACTIONS(3563),
    [anon_sym_interface] = ACTIONS(3561),
    [anon_sym_delegate] = ACTIONS(3561),
    [anon_sym_record] = ACTIONS(3561),
    [anon_sym_abstract] = ACTIONS(3561),
    [anon_sym_async] = ACTIONS(3561),
    [anon_sym_const] = ACTIONS(3561),
    [anon_sym_file] = ACTIONS(3561),
    [anon_sym_fixed] = ACTIONS(3561),
    [anon_sym_internal] = ACTIONS(3561),
    [anon_sym_new] = ACTIONS(3561),
    [anon_sym_override] = ACTIONS(3561),
    [anon_sym_partial] = ACTIONS(3561),
    [anon_sym_private] = ACTIONS(3561),
    [anon_sym_protected] = ACTIONS(3561),
    [anon_sym_public] = ACTIONS(3561),
    [anon_sym_readonly] = ACTIONS(3561),
    [anon_sym_required] = ACTIONS(3561),
    [anon_sym_sealed] = ACTIONS(3561),
    [anon_sym_virtual] = ACTIONS(3561),
    [anon_sym_volatile] = ACTIONS(3561),
    [anon_sym_where] = ACTIONS(3561),
    [anon_sym_notnull] = ACTIONS(3561),
    [anon_sym_unmanaged] = ACTIONS(3561),
    [anon_sym_checked] = ACTIONS(3561),
    [anon_sym_BANG] = ACTIONS(3563),
    [anon_sym_TILDE] = ACTIONS(3563),
    [anon_sym_PLUS_PLUS] = ACTIONS(3563),
    [anon_sym_DASH_DASH] = ACTIONS(3563),
    [anon_sym_true] = ACTIONS(3561),
    [anon_sym_false] = ACTIONS(3561),
    [anon_sym_PLUS] = ACTIONS(3561),
    [anon_sym_DASH] = ACTIONS(3561),
    [anon_sym_STAR] = ACTIONS(3563),
    [anon_sym_CARET] = ACTIONS(3563),
    [anon_sym_AMP] = ACTIONS(3563),
    [anon_sym_this] = ACTIONS(3561),
    [anon_sym_scoped] = ACTIONS(3561),
    [anon_sym_base] = ACTIONS(3561),
    [anon_sym_var] = ACTIONS(3561),
    [sym_predefined_type] = ACTIONS(3561),
    [anon_sym_break] = ACTIONS(3561),
    [anon_sym_unchecked] = ACTIONS(3561),
    [anon_sym_continue] = ACTIONS(3561),
    [anon_sym_do] = ACTIONS(3561),
    [anon_sym_while] = ACTIONS(3561),
    [anon_sym_for] = ACTIONS(3561),
    [anon_sym_lock] = ACTIONS(3561),
    [anon_sym_yield] = ACTIONS(3561),
    [anon_sym_switch] = ACTIONS(3561),
    [anon_sym_default] = ACTIONS(3561),
    [anon_sym_throw] = ACTIONS(3561),
    [anon_sym_try] = ACTIONS(3561),
    [anon_sym_when] = ACTIONS(3561),
    [anon_sym_await] = ACTIONS(3561),
    [anon_sym_foreach] = ACTIONS(3561),
    [anon_sym_goto] = ACTIONS(3561),
    [anon_sym_if] = ACTIONS(3561),
    [anon_sym_DOT_DOT] = ACTIONS(3563),
    [anon_sym_from] = ACTIONS(3561),
    [anon_sym_into] = ACTIONS(3561),
    [anon_sym_join] = ACTIONS(3561),
    [anon_sym_on] = ACTIONS(3561),
    [anon_sym_equals] = ACTIONS(3561),
    [anon_sym_let] = ACTIONS(3561),
    [anon_sym_orderby] = ACTIONS(3561),
    [anon_sym_ascending] = ACTIONS(3561),
    [anon_sym_descending] = ACTIONS(3561),
    [anon_sym_group] = ACTIONS(3561),
    [anon_sym_by] = ACTIONS(3561),
    [anon_sym_select] = ACTIONS(3561),
    [anon_sym_stackalloc] = ACTIONS(3561),
    [anon_sym_sizeof] = ACTIONS(3561),
    [anon_sym_typeof] = ACTIONS(3561),
    [anon_sym___makeref] = ACTIONS(3561),
    [anon_sym___reftype] = ACTIONS(3561),
    [anon_sym___refvalue] = ACTIONS(3561),
    [sym_null_literal] = ACTIONS(3561),
    [anon_sym_SQUOTE] = ACTIONS(3563),
    [sym_integer_literal] = ACTIONS(3561),
    [sym_real_literal] = ACTIONS(3563),
    [anon_sym_DQUOTE] = ACTIONS(3563),
    [sym_verbatim_string_literal] = ACTIONS(3563),
    [aux_sym_preproc_if_token1] = ACTIONS(3563),
    [aux_sym_preproc_if_token3] = ACTIONS(3563),
    [aux_sym_preproc_else_token1] = ACTIONS(3563),
    [aux_sym_preproc_elif_token1] = ACTIONS(3563),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3563),
    [sym_interpolation_verbatim_start] = ACTIONS(3563),
    [sym_interpolation_raw_start] = ACTIONS(3563),
    [sym_raw_string_start] = ACTIONS(3563),
  },
  [2347] = {
    [sym_preproc_region] = STATE(2347),
    [sym_preproc_endregion] = STATE(2347),
    [sym_preproc_line] = STATE(2347),
    [sym_preproc_pragma] = STATE(2347),
    [sym_preproc_nullable] = STATE(2347),
    [sym_preproc_error] = STATE(2347),
    [sym_preproc_warning] = STATE(2347),
    [sym_preproc_define] = STATE(2347),
    [sym_preproc_undef] = STATE(2347),
    [sym__identifier_token] = ACTIONS(3565),
    [anon_sym_extern] = ACTIONS(3565),
    [anon_sym_alias] = ACTIONS(3565),
    [anon_sym_SEMI] = ACTIONS(3567),
    [anon_sym_global] = ACTIONS(3565),
    [anon_sym_using] = ACTIONS(3565),
    [anon_sym_unsafe] = ACTIONS(3565),
    [anon_sym_static] = ACTIONS(3565),
    [anon_sym_LBRACK] = ACTIONS(3567),
    [anon_sym_LPAREN] = ACTIONS(3567),
    [anon_sym_return] = ACTIONS(3565),
    [anon_sym_namespace] = ACTIONS(3565),
    [anon_sym_class] = ACTIONS(3565),
    [anon_sym_ref] = ACTIONS(3565),
    [anon_sym_struct] = ACTIONS(3565),
    [anon_sym_enum] = ACTIONS(3565),
    [anon_sym_LBRACE] = ACTIONS(3567),
    [anon_sym_interface] = ACTIONS(3565),
    [anon_sym_delegate] = ACTIONS(3565),
    [anon_sym_record] = ACTIONS(3565),
    [anon_sym_abstract] = ACTIONS(3565),
    [anon_sym_async] = ACTIONS(3565),
    [anon_sym_const] = ACTIONS(3565),
    [anon_sym_file] = ACTIONS(3565),
    [anon_sym_fixed] = ACTIONS(3565),
    [anon_sym_internal] = ACTIONS(3565),
    [anon_sym_new] = ACTIONS(3565),
    [anon_sym_override] = ACTIONS(3565),
    [anon_sym_partial] = ACTIONS(3565),
    [anon_sym_private] = ACTIONS(3565),
    [anon_sym_protected] = ACTIONS(3565),
    [anon_sym_public] = ACTIONS(3565),
    [anon_sym_readonly] = ACTIONS(3565),
    [anon_sym_required] = ACTIONS(3565),
    [anon_sym_sealed] = ACTIONS(3565),
    [anon_sym_virtual] = ACTIONS(3565),
    [anon_sym_volatile] = ACTIONS(3565),
    [anon_sym_where] = ACTIONS(3565),
    [anon_sym_notnull] = ACTIONS(3565),
    [anon_sym_unmanaged] = ACTIONS(3565),
    [anon_sym_checked] = ACTIONS(3565),
    [anon_sym_BANG] = ACTIONS(3567),
    [anon_sym_TILDE] = ACTIONS(3567),
    [anon_sym_PLUS_PLUS] = ACTIONS(3567),
    [anon_sym_DASH_DASH] = ACTIONS(3567),
    [anon_sym_true] = ACTIONS(3565),
    [anon_sym_false] = ACTIONS(3565),
    [anon_sym_PLUS] = ACTIONS(3565),
    [anon_sym_DASH] = ACTIONS(3565),
    [anon_sym_STAR] = ACTIONS(3567),
    [anon_sym_CARET] = ACTIONS(3567),
    [anon_sym_AMP] = ACTIONS(3567),
    [anon_sym_this] = ACTIONS(3565),
    [anon_sym_scoped] = ACTIONS(3565),
    [anon_sym_base] = ACTIONS(3565),
    [anon_sym_var] = ACTIONS(3565),
    [sym_predefined_type] = ACTIONS(3565),
    [anon_sym_break] = ACTIONS(3565),
    [anon_sym_unchecked] = ACTIONS(3565),
    [anon_sym_continue] = ACTIONS(3565),
    [anon_sym_do] = ACTIONS(3565),
    [anon_sym_while] = ACTIONS(3565),
    [anon_sym_for] = ACTIONS(3565),
    [anon_sym_lock] = ACTIONS(3565),
    [anon_sym_yield] = ACTIONS(3565),
    [anon_sym_switch] = ACTIONS(3565),
    [anon_sym_default] = ACTIONS(3565),
    [anon_sym_throw] = ACTIONS(3565),
    [anon_sym_try] = ACTIONS(3565),
    [anon_sym_when] = ACTIONS(3565),
    [anon_sym_await] = ACTIONS(3565),
    [anon_sym_foreach] = ACTIONS(3565),
    [anon_sym_goto] = ACTIONS(3565),
    [anon_sym_if] = ACTIONS(3565),
    [anon_sym_DOT_DOT] = ACTIONS(3567),
    [anon_sym_from] = ACTIONS(3565),
    [anon_sym_into] = ACTIONS(3565),
    [anon_sym_join] = ACTIONS(3565),
    [anon_sym_on] = ACTIONS(3565),
    [anon_sym_equals] = ACTIONS(3565),
    [anon_sym_let] = ACTIONS(3565),
    [anon_sym_orderby] = ACTIONS(3565),
    [anon_sym_ascending] = ACTIONS(3565),
    [anon_sym_descending] = ACTIONS(3565),
    [anon_sym_group] = ACTIONS(3565),
    [anon_sym_by] = ACTIONS(3565),
    [anon_sym_select] = ACTIONS(3565),
    [anon_sym_stackalloc] = ACTIONS(3565),
    [anon_sym_sizeof] = ACTIONS(3565),
    [anon_sym_typeof] = ACTIONS(3565),
    [anon_sym___makeref] = ACTIONS(3565),
    [anon_sym___reftype] = ACTIONS(3565),
    [anon_sym___refvalue] = ACTIONS(3565),
    [sym_null_literal] = ACTIONS(3565),
    [anon_sym_SQUOTE] = ACTIONS(3567),
    [sym_integer_literal] = ACTIONS(3565),
    [sym_real_literal] = ACTIONS(3567),
    [anon_sym_DQUOTE] = ACTIONS(3567),
    [sym_verbatim_string_literal] = ACTIONS(3567),
    [aux_sym_preproc_if_token1] = ACTIONS(3567),
    [aux_sym_preproc_if_token3] = ACTIONS(3567),
    [aux_sym_preproc_else_token1] = ACTIONS(3567),
    [aux_sym_preproc_elif_token1] = ACTIONS(3567),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3567),
    [sym_interpolation_verbatim_start] = ACTIONS(3567),
    [sym_interpolation_raw_start] = ACTIONS(3567),
    [sym_raw_string_start] = ACTIONS(3567),
  },
  [2348] = {
    [sym_preproc_region] = STATE(2348),
    [sym_preproc_endregion] = STATE(2348),
    [sym_preproc_line] = STATE(2348),
    [sym_preproc_pragma] = STATE(2348),
    [sym_preproc_nullable] = STATE(2348),
    [sym_preproc_error] = STATE(2348),
    [sym_preproc_warning] = STATE(2348),
    [sym_preproc_define] = STATE(2348),
    [sym_preproc_undef] = STATE(2348),
    [sym__identifier_token] = ACTIONS(3569),
    [anon_sym_extern] = ACTIONS(3569),
    [anon_sym_alias] = ACTIONS(3569),
    [anon_sym_SEMI] = ACTIONS(3571),
    [anon_sym_global] = ACTIONS(3569),
    [anon_sym_using] = ACTIONS(3569),
    [anon_sym_unsafe] = ACTIONS(3569),
    [anon_sym_static] = ACTIONS(3569),
    [anon_sym_LBRACK] = ACTIONS(3571),
    [anon_sym_LPAREN] = ACTIONS(3571),
    [anon_sym_return] = ACTIONS(3569),
    [anon_sym_namespace] = ACTIONS(3569),
    [anon_sym_class] = ACTIONS(3569),
    [anon_sym_ref] = ACTIONS(3569),
    [anon_sym_struct] = ACTIONS(3569),
    [anon_sym_enum] = ACTIONS(3569),
    [anon_sym_LBRACE] = ACTIONS(3571),
    [anon_sym_interface] = ACTIONS(3569),
    [anon_sym_delegate] = ACTIONS(3569),
    [anon_sym_record] = ACTIONS(3569),
    [anon_sym_abstract] = ACTIONS(3569),
    [anon_sym_async] = ACTIONS(3569),
    [anon_sym_const] = ACTIONS(3569),
    [anon_sym_file] = ACTIONS(3569),
    [anon_sym_fixed] = ACTIONS(3569),
    [anon_sym_internal] = ACTIONS(3569),
    [anon_sym_new] = ACTIONS(3569),
    [anon_sym_override] = ACTIONS(3569),
    [anon_sym_partial] = ACTIONS(3569),
    [anon_sym_private] = ACTIONS(3569),
    [anon_sym_protected] = ACTIONS(3569),
    [anon_sym_public] = ACTIONS(3569),
    [anon_sym_readonly] = ACTIONS(3569),
    [anon_sym_required] = ACTIONS(3569),
    [anon_sym_sealed] = ACTIONS(3569),
    [anon_sym_virtual] = ACTIONS(3569),
    [anon_sym_volatile] = ACTIONS(3569),
    [anon_sym_where] = ACTIONS(3569),
    [anon_sym_notnull] = ACTIONS(3569),
    [anon_sym_unmanaged] = ACTIONS(3569),
    [anon_sym_checked] = ACTIONS(3569),
    [anon_sym_BANG] = ACTIONS(3571),
    [anon_sym_TILDE] = ACTIONS(3571),
    [anon_sym_PLUS_PLUS] = ACTIONS(3571),
    [anon_sym_DASH_DASH] = ACTIONS(3571),
    [anon_sym_true] = ACTIONS(3569),
    [anon_sym_false] = ACTIONS(3569),
    [anon_sym_PLUS] = ACTIONS(3569),
    [anon_sym_DASH] = ACTIONS(3569),
    [anon_sym_STAR] = ACTIONS(3571),
    [anon_sym_CARET] = ACTIONS(3571),
    [anon_sym_AMP] = ACTIONS(3571),
    [anon_sym_this] = ACTIONS(3569),
    [anon_sym_scoped] = ACTIONS(3569),
    [anon_sym_base] = ACTIONS(3569),
    [anon_sym_var] = ACTIONS(3569),
    [sym_predefined_type] = ACTIONS(3569),
    [anon_sym_break] = ACTIONS(3569),
    [anon_sym_unchecked] = ACTIONS(3569),
    [anon_sym_continue] = ACTIONS(3569),
    [anon_sym_do] = ACTIONS(3569),
    [anon_sym_while] = ACTIONS(3569),
    [anon_sym_for] = ACTIONS(3569),
    [anon_sym_lock] = ACTIONS(3569),
    [anon_sym_yield] = ACTIONS(3569),
    [anon_sym_switch] = ACTIONS(3569),
    [anon_sym_default] = ACTIONS(3569),
    [anon_sym_throw] = ACTIONS(3569),
    [anon_sym_try] = ACTIONS(3569),
    [anon_sym_when] = ACTIONS(3569),
    [anon_sym_await] = ACTIONS(3569),
    [anon_sym_foreach] = ACTIONS(3569),
    [anon_sym_goto] = ACTIONS(3569),
    [anon_sym_if] = ACTIONS(3569),
    [anon_sym_DOT_DOT] = ACTIONS(3571),
    [anon_sym_from] = ACTIONS(3569),
    [anon_sym_into] = ACTIONS(3569),
    [anon_sym_join] = ACTIONS(3569),
    [anon_sym_on] = ACTIONS(3569),
    [anon_sym_equals] = ACTIONS(3569),
    [anon_sym_let] = ACTIONS(3569),
    [anon_sym_orderby] = ACTIONS(3569),
    [anon_sym_ascending] = ACTIONS(3569),
    [anon_sym_descending] = ACTIONS(3569),
    [anon_sym_group] = ACTIONS(3569),
    [anon_sym_by] = ACTIONS(3569),
    [anon_sym_select] = ACTIONS(3569),
    [anon_sym_stackalloc] = ACTIONS(3569),
    [anon_sym_sizeof] = ACTIONS(3569),
    [anon_sym_typeof] = ACTIONS(3569),
    [anon_sym___makeref] = ACTIONS(3569),
    [anon_sym___reftype] = ACTIONS(3569),
    [anon_sym___refvalue] = ACTIONS(3569),
    [sym_null_literal] = ACTIONS(3569),
    [anon_sym_SQUOTE] = ACTIONS(3571),
    [sym_integer_literal] = ACTIONS(3569),
    [sym_real_literal] = ACTIONS(3571),
    [anon_sym_DQUOTE] = ACTIONS(3571),
    [sym_verbatim_string_literal] = ACTIONS(3571),
    [aux_sym_preproc_if_token1] = ACTIONS(3571),
    [aux_sym_preproc_if_token3] = ACTIONS(3571),
    [aux_sym_preproc_else_token1] = ACTIONS(3571),
    [aux_sym_preproc_elif_token1] = ACTIONS(3571),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3571),
    [sym_interpolation_verbatim_start] = ACTIONS(3571),
    [sym_interpolation_raw_start] = ACTIONS(3571),
    [sym_raw_string_start] = ACTIONS(3571),
  },
  [2349] = {
    [sym_preproc_region] = STATE(2349),
    [sym_preproc_endregion] = STATE(2349),
    [sym_preproc_line] = STATE(2349),
    [sym_preproc_pragma] = STATE(2349),
    [sym_preproc_nullable] = STATE(2349),
    [sym_preproc_error] = STATE(2349),
    [sym_preproc_warning] = STATE(2349),
    [sym_preproc_define] = STATE(2349),
    [sym_preproc_undef] = STATE(2349),
    [sym__identifier_token] = ACTIONS(3573),
    [anon_sym_extern] = ACTIONS(3573),
    [anon_sym_alias] = ACTIONS(3573),
    [anon_sym_SEMI] = ACTIONS(3575),
    [anon_sym_global] = ACTIONS(3573),
    [anon_sym_using] = ACTIONS(3573),
    [anon_sym_unsafe] = ACTIONS(3573),
    [anon_sym_static] = ACTIONS(3573),
    [anon_sym_LBRACK] = ACTIONS(3575),
    [anon_sym_LPAREN] = ACTIONS(3575),
    [anon_sym_return] = ACTIONS(3573),
    [anon_sym_namespace] = ACTIONS(3573),
    [anon_sym_class] = ACTIONS(3573),
    [anon_sym_ref] = ACTIONS(3573),
    [anon_sym_struct] = ACTIONS(3573),
    [anon_sym_enum] = ACTIONS(3573),
    [anon_sym_LBRACE] = ACTIONS(3575),
    [anon_sym_interface] = ACTIONS(3573),
    [anon_sym_delegate] = ACTIONS(3573),
    [anon_sym_record] = ACTIONS(3573),
    [anon_sym_abstract] = ACTIONS(3573),
    [anon_sym_async] = ACTIONS(3573),
    [anon_sym_const] = ACTIONS(3573),
    [anon_sym_file] = ACTIONS(3573),
    [anon_sym_fixed] = ACTIONS(3573),
    [anon_sym_internal] = ACTIONS(3573),
    [anon_sym_new] = ACTIONS(3573),
    [anon_sym_override] = ACTIONS(3573),
    [anon_sym_partial] = ACTIONS(3573),
    [anon_sym_private] = ACTIONS(3573),
    [anon_sym_protected] = ACTIONS(3573),
    [anon_sym_public] = ACTIONS(3573),
    [anon_sym_readonly] = ACTIONS(3573),
    [anon_sym_required] = ACTIONS(3573),
    [anon_sym_sealed] = ACTIONS(3573),
    [anon_sym_virtual] = ACTIONS(3573),
    [anon_sym_volatile] = ACTIONS(3573),
    [anon_sym_where] = ACTIONS(3573),
    [anon_sym_notnull] = ACTIONS(3573),
    [anon_sym_unmanaged] = ACTIONS(3573),
    [anon_sym_checked] = ACTIONS(3573),
    [anon_sym_BANG] = ACTIONS(3575),
    [anon_sym_TILDE] = ACTIONS(3575),
    [anon_sym_PLUS_PLUS] = ACTIONS(3575),
    [anon_sym_DASH_DASH] = ACTIONS(3575),
    [anon_sym_true] = ACTIONS(3573),
    [anon_sym_false] = ACTIONS(3573),
    [anon_sym_PLUS] = ACTIONS(3573),
    [anon_sym_DASH] = ACTIONS(3573),
    [anon_sym_STAR] = ACTIONS(3575),
    [anon_sym_CARET] = ACTIONS(3575),
    [anon_sym_AMP] = ACTIONS(3575),
    [anon_sym_this] = ACTIONS(3573),
    [anon_sym_scoped] = ACTIONS(3573),
    [anon_sym_base] = ACTIONS(3573),
    [anon_sym_var] = ACTIONS(3573),
    [sym_predefined_type] = ACTIONS(3573),
    [anon_sym_break] = ACTIONS(3573),
    [anon_sym_unchecked] = ACTIONS(3573),
    [anon_sym_continue] = ACTIONS(3573),
    [anon_sym_do] = ACTIONS(3573),
    [anon_sym_while] = ACTIONS(3573),
    [anon_sym_for] = ACTIONS(3573),
    [anon_sym_lock] = ACTIONS(3573),
    [anon_sym_yield] = ACTIONS(3573),
    [anon_sym_switch] = ACTIONS(3573),
    [anon_sym_default] = ACTIONS(3573),
    [anon_sym_throw] = ACTIONS(3573),
    [anon_sym_try] = ACTIONS(3573),
    [anon_sym_when] = ACTIONS(3573),
    [anon_sym_await] = ACTIONS(3573),
    [anon_sym_foreach] = ACTIONS(3573),
    [anon_sym_goto] = ACTIONS(3573),
    [anon_sym_if] = ACTIONS(3573),
    [anon_sym_DOT_DOT] = ACTIONS(3575),
    [anon_sym_from] = ACTIONS(3573),
    [anon_sym_into] = ACTIONS(3573),
    [anon_sym_join] = ACTIONS(3573),
    [anon_sym_on] = ACTIONS(3573),
    [anon_sym_equals] = ACTIONS(3573),
    [anon_sym_let] = ACTIONS(3573),
    [anon_sym_orderby] = ACTIONS(3573),
    [anon_sym_ascending] = ACTIONS(3573),
    [anon_sym_descending] = ACTIONS(3573),
    [anon_sym_group] = ACTIONS(3573),
    [anon_sym_by] = ACTIONS(3573),
    [anon_sym_select] = ACTIONS(3573),
    [anon_sym_stackalloc] = ACTIONS(3573),
    [anon_sym_sizeof] = ACTIONS(3573),
    [anon_sym_typeof] = ACTIONS(3573),
    [anon_sym___makeref] = ACTIONS(3573),
    [anon_sym___reftype] = ACTIONS(3573),
    [anon_sym___refvalue] = ACTIONS(3573),
    [sym_null_literal] = ACTIONS(3573),
    [anon_sym_SQUOTE] = ACTIONS(3575),
    [sym_integer_literal] = ACTIONS(3573),
    [sym_real_literal] = ACTIONS(3575),
    [anon_sym_DQUOTE] = ACTIONS(3575),
    [sym_verbatim_string_literal] = ACTIONS(3575),
    [aux_sym_preproc_if_token1] = ACTIONS(3575),
    [aux_sym_preproc_if_token3] = ACTIONS(3575),
    [aux_sym_preproc_else_token1] = ACTIONS(3575),
    [aux_sym_preproc_elif_token1] = ACTIONS(3575),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3575),
    [sym_interpolation_verbatim_start] = ACTIONS(3575),
    [sym_interpolation_raw_start] = ACTIONS(3575),
    [sym_raw_string_start] = ACTIONS(3575),
  },
  [2350] = {
    [sym_preproc_region] = STATE(2350),
    [sym_preproc_endregion] = STATE(2350),
    [sym_preproc_line] = STATE(2350),
    [sym_preproc_pragma] = STATE(2350),
    [sym_preproc_nullable] = STATE(2350),
    [sym_preproc_error] = STATE(2350),
    [sym_preproc_warning] = STATE(2350),
    [sym_preproc_define] = STATE(2350),
    [sym_preproc_undef] = STATE(2350),
    [sym__identifier_token] = ACTIONS(3577),
    [anon_sym_extern] = ACTIONS(3577),
    [anon_sym_alias] = ACTIONS(3577),
    [anon_sym_SEMI] = ACTIONS(3579),
    [anon_sym_global] = ACTIONS(3577),
    [anon_sym_using] = ACTIONS(3577),
    [anon_sym_unsafe] = ACTIONS(3577),
    [anon_sym_static] = ACTIONS(3577),
    [anon_sym_LBRACK] = ACTIONS(3579),
    [anon_sym_LPAREN] = ACTIONS(3579),
    [anon_sym_return] = ACTIONS(3577),
    [anon_sym_namespace] = ACTIONS(3577),
    [anon_sym_class] = ACTIONS(3577),
    [anon_sym_ref] = ACTIONS(3577),
    [anon_sym_struct] = ACTIONS(3577),
    [anon_sym_enum] = ACTIONS(3577),
    [anon_sym_LBRACE] = ACTIONS(3579),
    [anon_sym_interface] = ACTIONS(3577),
    [anon_sym_delegate] = ACTIONS(3577),
    [anon_sym_record] = ACTIONS(3577),
    [anon_sym_abstract] = ACTIONS(3577),
    [anon_sym_async] = ACTIONS(3577),
    [anon_sym_const] = ACTIONS(3577),
    [anon_sym_file] = ACTIONS(3577),
    [anon_sym_fixed] = ACTIONS(3577),
    [anon_sym_internal] = ACTIONS(3577),
    [anon_sym_new] = ACTIONS(3577),
    [anon_sym_override] = ACTIONS(3577),
    [anon_sym_partial] = ACTIONS(3577),
    [anon_sym_private] = ACTIONS(3577),
    [anon_sym_protected] = ACTIONS(3577),
    [anon_sym_public] = ACTIONS(3577),
    [anon_sym_readonly] = ACTIONS(3577),
    [anon_sym_required] = ACTIONS(3577),
    [anon_sym_sealed] = ACTIONS(3577),
    [anon_sym_virtual] = ACTIONS(3577),
    [anon_sym_volatile] = ACTIONS(3577),
    [anon_sym_where] = ACTIONS(3577),
    [anon_sym_notnull] = ACTIONS(3577),
    [anon_sym_unmanaged] = ACTIONS(3577),
    [anon_sym_checked] = ACTIONS(3577),
    [anon_sym_BANG] = ACTIONS(3579),
    [anon_sym_TILDE] = ACTIONS(3579),
    [anon_sym_PLUS_PLUS] = ACTIONS(3579),
    [anon_sym_DASH_DASH] = ACTIONS(3579),
    [anon_sym_true] = ACTIONS(3577),
    [anon_sym_false] = ACTIONS(3577),
    [anon_sym_PLUS] = ACTIONS(3577),
    [anon_sym_DASH] = ACTIONS(3577),
    [anon_sym_STAR] = ACTIONS(3579),
    [anon_sym_CARET] = ACTIONS(3579),
    [anon_sym_AMP] = ACTIONS(3579),
    [anon_sym_this] = ACTIONS(3577),
    [anon_sym_scoped] = ACTIONS(3577),
    [anon_sym_base] = ACTIONS(3577),
    [anon_sym_var] = ACTIONS(3577),
    [sym_predefined_type] = ACTIONS(3577),
    [anon_sym_break] = ACTIONS(3577),
    [anon_sym_unchecked] = ACTIONS(3577),
    [anon_sym_continue] = ACTIONS(3577),
    [anon_sym_do] = ACTIONS(3577),
    [anon_sym_while] = ACTIONS(3577),
    [anon_sym_for] = ACTIONS(3577),
    [anon_sym_lock] = ACTIONS(3577),
    [anon_sym_yield] = ACTIONS(3577),
    [anon_sym_switch] = ACTIONS(3577),
    [anon_sym_default] = ACTIONS(3577),
    [anon_sym_throw] = ACTIONS(3577),
    [anon_sym_try] = ACTIONS(3577),
    [anon_sym_when] = ACTIONS(3577),
    [anon_sym_await] = ACTIONS(3577),
    [anon_sym_foreach] = ACTIONS(3577),
    [anon_sym_goto] = ACTIONS(3577),
    [anon_sym_if] = ACTIONS(3577),
    [anon_sym_DOT_DOT] = ACTIONS(3579),
    [anon_sym_from] = ACTIONS(3577),
    [anon_sym_into] = ACTIONS(3577),
    [anon_sym_join] = ACTIONS(3577),
    [anon_sym_on] = ACTIONS(3577),
    [anon_sym_equals] = ACTIONS(3577),
    [anon_sym_let] = ACTIONS(3577),
    [anon_sym_orderby] = ACTIONS(3577),
    [anon_sym_ascending] = ACTIONS(3577),
    [anon_sym_descending] = ACTIONS(3577),
    [anon_sym_group] = ACTIONS(3577),
    [anon_sym_by] = ACTIONS(3577),
    [anon_sym_select] = ACTIONS(3577),
    [anon_sym_stackalloc] = ACTIONS(3577),
    [anon_sym_sizeof] = ACTIONS(3577),
    [anon_sym_typeof] = ACTIONS(3577),
    [anon_sym___makeref] = ACTIONS(3577),
    [anon_sym___reftype] = ACTIONS(3577),
    [anon_sym___refvalue] = ACTIONS(3577),
    [sym_null_literal] = ACTIONS(3577),
    [anon_sym_SQUOTE] = ACTIONS(3579),
    [sym_integer_literal] = ACTIONS(3577),
    [sym_real_literal] = ACTIONS(3579),
    [anon_sym_DQUOTE] = ACTIONS(3579),
    [sym_verbatim_string_literal] = ACTIONS(3579),
    [aux_sym_preproc_if_token1] = ACTIONS(3579),
    [aux_sym_preproc_if_token3] = ACTIONS(3579),
    [aux_sym_preproc_else_token1] = ACTIONS(3579),
    [aux_sym_preproc_elif_token1] = ACTIONS(3579),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3579),
    [sym_interpolation_verbatim_start] = ACTIONS(3579),
    [sym_interpolation_raw_start] = ACTIONS(3579),
    [sym_raw_string_start] = ACTIONS(3579),
  },
  [2351] = {
    [sym_preproc_region] = STATE(2351),
    [sym_preproc_endregion] = STATE(2351),
    [sym_preproc_line] = STATE(2351),
    [sym_preproc_pragma] = STATE(2351),
    [sym_preproc_nullable] = STATE(2351),
    [sym_preproc_error] = STATE(2351),
    [sym_preproc_warning] = STATE(2351),
    [sym_preproc_define] = STATE(2351),
    [sym_preproc_undef] = STATE(2351),
    [sym__identifier_token] = ACTIONS(3581),
    [anon_sym_extern] = ACTIONS(3581),
    [anon_sym_alias] = ACTIONS(3581),
    [anon_sym_SEMI] = ACTIONS(3583),
    [anon_sym_global] = ACTIONS(3581),
    [anon_sym_using] = ACTIONS(3581),
    [anon_sym_unsafe] = ACTIONS(3581),
    [anon_sym_static] = ACTIONS(3581),
    [anon_sym_LBRACK] = ACTIONS(3583),
    [anon_sym_LPAREN] = ACTIONS(3583),
    [anon_sym_return] = ACTIONS(3581),
    [anon_sym_namespace] = ACTIONS(3581),
    [anon_sym_class] = ACTIONS(3581),
    [anon_sym_ref] = ACTIONS(3581),
    [anon_sym_struct] = ACTIONS(3581),
    [anon_sym_enum] = ACTIONS(3581),
    [anon_sym_LBRACE] = ACTIONS(3583),
    [anon_sym_interface] = ACTIONS(3581),
    [anon_sym_delegate] = ACTIONS(3581),
    [anon_sym_record] = ACTIONS(3581),
    [anon_sym_abstract] = ACTIONS(3581),
    [anon_sym_async] = ACTIONS(3581),
    [anon_sym_const] = ACTIONS(3581),
    [anon_sym_file] = ACTIONS(3581),
    [anon_sym_fixed] = ACTIONS(3581),
    [anon_sym_internal] = ACTIONS(3581),
    [anon_sym_new] = ACTIONS(3581),
    [anon_sym_override] = ACTIONS(3581),
    [anon_sym_partial] = ACTIONS(3581),
    [anon_sym_private] = ACTIONS(3581),
    [anon_sym_protected] = ACTIONS(3581),
    [anon_sym_public] = ACTIONS(3581),
    [anon_sym_readonly] = ACTIONS(3581),
    [anon_sym_required] = ACTIONS(3581),
    [anon_sym_sealed] = ACTIONS(3581),
    [anon_sym_virtual] = ACTIONS(3581),
    [anon_sym_volatile] = ACTIONS(3581),
    [anon_sym_where] = ACTIONS(3581),
    [anon_sym_notnull] = ACTIONS(3581),
    [anon_sym_unmanaged] = ACTIONS(3581),
    [anon_sym_checked] = ACTIONS(3581),
    [anon_sym_BANG] = ACTIONS(3583),
    [anon_sym_TILDE] = ACTIONS(3583),
    [anon_sym_PLUS_PLUS] = ACTIONS(3583),
    [anon_sym_DASH_DASH] = ACTIONS(3583),
    [anon_sym_true] = ACTIONS(3581),
    [anon_sym_false] = ACTIONS(3581),
    [anon_sym_PLUS] = ACTIONS(3581),
    [anon_sym_DASH] = ACTIONS(3581),
    [anon_sym_STAR] = ACTIONS(3583),
    [anon_sym_CARET] = ACTIONS(3583),
    [anon_sym_AMP] = ACTIONS(3583),
    [anon_sym_this] = ACTIONS(3581),
    [anon_sym_scoped] = ACTIONS(3581),
    [anon_sym_base] = ACTIONS(3581),
    [anon_sym_var] = ACTIONS(3581),
    [sym_predefined_type] = ACTIONS(3581),
    [anon_sym_break] = ACTIONS(3581),
    [anon_sym_unchecked] = ACTIONS(3581),
    [anon_sym_continue] = ACTIONS(3581),
    [anon_sym_do] = ACTIONS(3581),
    [anon_sym_while] = ACTIONS(3581),
    [anon_sym_for] = ACTIONS(3581),
    [anon_sym_lock] = ACTIONS(3581),
    [anon_sym_yield] = ACTIONS(3581),
    [anon_sym_switch] = ACTIONS(3581),
    [anon_sym_default] = ACTIONS(3581),
    [anon_sym_throw] = ACTIONS(3581),
    [anon_sym_try] = ACTIONS(3581),
    [anon_sym_when] = ACTIONS(3581),
    [anon_sym_await] = ACTIONS(3581),
    [anon_sym_foreach] = ACTIONS(3581),
    [anon_sym_goto] = ACTIONS(3581),
    [anon_sym_if] = ACTIONS(3581),
    [anon_sym_DOT_DOT] = ACTIONS(3583),
    [anon_sym_from] = ACTIONS(3581),
    [anon_sym_into] = ACTIONS(3581),
    [anon_sym_join] = ACTIONS(3581),
    [anon_sym_on] = ACTIONS(3581),
    [anon_sym_equals] = ACTIONS(3581),
    [anon_sym_let] = ACTIONS(3581),
    [anon_sym_orderby] = ACTIONS(3581),
    [anon_sym_ascending] = ACTIONS(3581),
    [anon_sym_descending] = ACTIONS(3581),
    [anon_sym_group] = ACTIONS(3581),
    [anon_sym_by] = ACTIONS(3581),
    [anon_sym_select] = ACTIONS(3581),
    [anon_sym_stackalloc] = ACTIONS(3581),
    [anon_sym_sizeof] = ACTIONS(3581),
    [anon_sym_typeof] = ACTIONS(3581),
    [anon_sym___makeref] = ACTIONS(3581),
    [anon_sym___reftype] = ACTIONS(3581),
    [anon_sym___refvalue] = ACTIONS(3581),
    [sym_null_literal] = ACTIONS(3581),
    [anon_sym_SQUOTE] = ACTIONS(3583),
    [sym_integer_literal] = ACTIONS(3581),
    [sym_real_literal] = ACTIONS(3583),
    [anon_sym_DQUOTE] = ACTIONS(3583),
    [sym_verbatim_string_literal] = ACTIONS(3583),
    [aux_sym_preproc_if_token1] = ACTIONS(3583),
    [aux_sym_preproc_if_token3] = ACTIONS(3583),
    [aux_sym_preproc_else_token1] = ACTIONS(3583),
    [aux_sym_preproc_elif_token1] = ACTIONS(3583),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3583),
    [sym_interpolation_verbatim_start] = ACTIONS(3583),
    [sym_interpolation_raw_start] = ACTIONS(3583),
    [sym_raw_string_start] = ACTIONS(3583),
  },
  [2352] = {
    [sym_preproc_region] = STATE(2352),
    [sym_preproc_endregion] = STATE(2352),
    [sym_preproc_line] = STATE(2352),
    [sym_preproc_pragma] = STATE(2352),
    [sym_preproc_nullable] = STATE(2352),
    [sym_preproc_error] = STATE(2352),
    [sym_preproc_warning] = STATE(2352),
    [sym_preproc_define] = STATE(2352),
    [sym_preproc_undef] = STATE(2352),
    [sym__identifier_token] = ACTIONS(3585),
    [anon_sym_extern] = ACTIONS(3585),
    [anon_sym_alias] = ACTIONS(3585),
    [anon_sym_SEMI] = ACTIONS(3587),
    [anon_sym_global] = ACTIONS(3585),
    [anon_sym_using] = ACTIONS(3585),
    [anon_sym_unsafe] = ACTIONS(3585),
    [anon_sym_static] = ACTIONS(3585),
    [anon_sym_LBRACK] = ACTIONS(3587),
    [anon_sym_LPAREN] = ACTIONS(3587),
    [anon_sym_return] = ACTIONS(3585),
    [anon_sym_namespace] = ACTIONS(3585),
    [anon_sym_class] = ACTIONS(3585),
    [anon_sym_ref] = ACTIONS(3585),
    [anon_sym_struct] = ACTIONS(3585),
    [anon_sym_enum] = ACTIONS(3585),
    [anon_sym_LBRACE] = ACTIONS(3587),
    [anon_sym_interface] = ACTIONS(3585),
    [anon_sym_delegate] = ACTIONS(3585),
    [anon_sym_record] = ACTIONS(3585),
    [anon_sym_abstract] = ACTIONS(3585),
    [anon_sym_async] = ACTIONS(3585),
    [anon_sym_const] = ACTIONS(3585),
    [anon_sym_file] = ACTIONS(3585),
    [anon_sym_fixed] = ACTIONS(3585),
    [anon_sym_internal] = ACTIONS(3585),
    [anon_sym_new] = ACTIONS(3585),
    [anon_sym_override] = ACTIONS(3585),
    [anon_sym_partial] = ACTIONS(3585),
    [anon_sym_private] = ACTIONS(3585),
    [anon_sym_protected] = ACTIONS(3585),
    [anon_sym_public] = ACTIONS(3585),
    [anon_sym_readonly] = ACTIONS(3585),
    [anon_sym_required] = ACTIONS(3585),
    [anon_sym_sealed] = ACTIONS(3585),
    [anon_sym_virtual] = ACTIONS(3585),
    [anon_sym_volatile] = ACTIONS(3585),
    [anon_sym_where] = ACTIONS(3585),
    [anon_sym_notnull] = ACTIONS(3585),
    [anon_sym_unmanaged] = ACTIONS(3585),
    [anon_sym_checked] = ACTIONS(3585),
    [anon_sym_BANG] = ACTIONS(3587),
    [anon_sym_TILDE] = ACTIONS(3587),
    [anon_sym_PLUS_PLUS] = ACTIONS(3587),
    [anon_sym_DASH_DASH] = ACTIONS(3587),
    [anon_sym_true] = ACTIONS(3585),
    [anon_sym_false] = ACTIONS(3585),
    [anon_sym_PLUS] = ACTIONS(3585),
    [anon_sym_DASH] = ACTIONS(3585),
    [anon_sym_STAR] = ACTIONS(3587),
    [anon_sym_CARET] = ACTIONS(3587),
    [anon_sym_AMP] = ACTIONS(3587),
    [anon_sym_this] = ACTIONS(3585),
    [anon_sym_scoped] = ACTIONS(3585),
    [anon_sym_base] = ACTIONS(3585),
    [anon_sym_var] = ACTIONS(3585),
    [sym_predefined_type] = ACTIONS(3585),
    [anon_sym_break] = ACTIONS(3585),
    [anon_sym_unchecked] = ACTIONS(3585),
    [anon_sym_continue] = ACTIONS(3585),
    [anon_sym_do] = ACTIONS(3585),
    [anon_sym_while] = ACTIONS(3585),
    [anon_sym_for] = ACTIONS(3585),
    [anon_sym_lock] = ACTIONS(3585),
    [anon_sym_yield] = ACTIONS(3585),
    [anon_sym_switch] = ACTIONS(3585),
    [anon_sym_default] = ACTIONS(3585),
    [anon_sym_throw] = ACTIONS(3585),
    [anon_sym_try] = ACTIONS(3585),
    [anon_sym_when] = ACTIONS(3585),
    [anon_sym_await] = ACTIONS(3585),
    [anon_sym_foreach] = ACTIONS(3585),
    [anon_sym_goto] = ACTIONS(3585),
    [anon_sym_if] = ACTIONS(3585),
    [anon_sym_DOT_DOT] = ACTIONS(3587),
    [anon_sym_from] = ACTIONS(3585),
    [anon_sym_into] = ACTIONS(3585),
    [anon_sym_join] = ACTIONS(3585),
    [anon_sym_on] = ACTIONS(3585),
    [anon_sym_equals] = ACTIONS(3585),
    [anon_sym_let] = ACTIONS(3585),
    [anon_sym_orderby] = ACTIONS(3585),
    [anon_sym_ascending] = ACTIONS(3585),
    [anon_sym_descending] = ACTIONS(3585),
    [anon_sym_group] = ACTIONS(3585),
    [anon_sym_by] = ACTIONS(3585),
    [anon_sym_select] = ACTIONS(3585),
    [anon_sym_stackalloc] = ACTIONS(3585),
    [anon_sym_sizeof] = ACTIONS(3585),
    [anon_sym_typeof] = ACTIONS(3585),
    [anon_sym___makeref] = ACTIONS(3585),
    [anon_sym___reftype] = ACTIONS(3585),
    [anon_sym___refvalue] = ACTIONS(3585),
    [sym_null_literal] = ACTIONS(3585),
    [anon_sym_SQUOTE] = ACTIONS(3587),
    [sym_integer_literal] = ACTIONS(3585),
    [sym_real_literal] = ACTIONS(3587),
    [anon_sym_DQUOTE] = ACTIONS(3587),
    [sym_verbatim_string_literal] = ACTIONS(3587),
    [aux_sym_preproc_if_token1] = ACTIONS(3587),
    [aux_sym_preproc_if_token3] = ACTIONS(3587),
    [aux_sym_preproc_else_token1] = ACTIONS(3587),
    [aux_sym_preproc_elif_token1] = ACTIONS(3587),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3587),
    [sym_interpolation_verbatim_start] = ACTIONS(3587),
    [sym_interpolation_raw_start] = ACTIONS(3587),
    [sym_raw_string_start] = ACTIONS(3587),
  },
  [2353] = {
    [sym_preproc_region] = STATE(2353),
    [sym_preproc_endregion] = STATE(2353),
    [sym_preproc_line] = STATE(2353),
    [sym_preproc_pragma] = STATE(2353),
    [sym_preproc_nullable] = STATE(2353),
    [sym_preproc_error] = STATE(2353),
    [sym_preproc_warning] = STATE(2353),
    [sym_preproc_define] = STATE(2353),
    [sym_preproc_undef] = STATE(2353),
    [sym__identifier_token] = ACTIONS(3589),
    [anon_sym_extern] = ACTIONS(3589),
    [anon_sym_alias] = ACTIONS(3589),
    [anon_sym_SEMI] = ACTIONS(3591),
    [anon_sym_global] = ACTIONS(3589),
    [anon_sym_using] = ACTIONS(3589),
    [anon_sym_unsafe] = ACTIONS(3589),
    [anon_sym_static] = ACTIONS(3589),
    [anon_sym_LBRACK] = ACTIONS(3591),
    [anon_sym_LPAREN] = ACTIONS(3591),
    [anon_sym_return] = ACTIONS(3589),
    [anon_sym_namespace] = ACTIONS(3589),
    [anon_sym_class] = ACTIONS(3589),
    [anon_sym_ref] = ACTIONS(3589),
    [anon_sym_struct] = ACTIONS(3589),
    [anon_sym_enum] = ACTIONS(3589),
    [anon_sym_LBRACE] = ACTIONS(3591),
    [anon_sym_interface] = ACTIONS(3589),
    [anon_sym_delegate] = ACTIONS(3589),
    [anon_sym_record] = ACTIONS(3589),
    [anon_sym_abstract] = ACTIONS(3589),
    [anon_sym_async] = ACTIONS(3589),
    [anon_sym_const] = ACTIONS(3589),
    [anon_sym_file] = ACTIONS(3589),
    [anon_sym_fixed] = ACTIONS(3589),
    [anon_sym_internal] = ACTIONS(3589),
    [anon_sym_new] = ACTIONS(3589),
    [anon_sym_override] = ACTIONS(3589),
    [anon_sym_partial] = ACTIONS(3589),
    [anon_sym_private] = ACTIONS(3589),
    [anon_sym_protected] = ACTIONS(3589),
    [anon_sym_public] = ACTIONS(3589),
    [anon_sym_readonly] = ACTIONS(3589),
    [anon_sym_required] = ACTIONS(3589),
    [anon_sym_sealed] = ACTIONS(3589),
    [anon_sym_virtual] = ACTIONS(3589),
    [anon_sym_volatile] = ACTIONS(3589),
    [anon_sym_where] = ACTIONS(3589),
    [anon_sym_notnull] = ACTIONS(3589),
    [anon_sym_unmanaged] = ACTIONS(3589),
    [anon_sym_checked] = ACTIONS(3589),
    [anon_sym_BANG] = ACTIONS(3591),
    [anon_sym_TILDE] = ACTIONS(3591),
    [anon_sym_PLUS_PLUS] = ACTIONS(3591),
    [anon_sym_DASH_DASH] = ACTIONS(3591),
    [anon_sym_true] = ACTIONS(3589),
    [anon_sym_false] = ACTIONS(3589),
    [anon_sym_PLUS] = ACTIONS(3589),
    [anon_sym_DASH] = ACTIONS(3589),
    [anon_sym_STAR] = ACTIONS(3591),
    [anon_sym_CARET] = ACTIONS(3591),
    [anon_sym_AMP] = ACTIONS(3591),
    [anon_sym_this] = ACTIONS(3589),
    [anon_sym_scoped] = ACTIONS(3589),
    [anon_sym_base] = ACTIONS(3589),
    [anon_sym_var] = ACTIONS(3589),
    [sym_predefined_type] = ACTIONS(3589),
    [anon_sym_break] = ACTIONS(3589),
    [anon_sym_unchecked] = ACTIONS(3589),
    [anon_sym_continue] = ACTIONS(3589),
    [anon_sym_do] = ACTIONS(3589),
    [anon_sym_while] = ACTIONS(3589),
    [anon_sym_for] = ACTIONS(3589),
    [anon_sym_lock] = ACTIONS(3589),
    [anon_sym_yield] = ACTIONS(3589),
    [anon_sym_switch] = ACTIONS(3589),
    [anon_sym_default] = ACTIONS(3589),
    [anon_sym_throw] = ACTIONS(3589),
    [anon_sym_try] = ACTIONS(3589),
    [anon_sym_when] = ACTIONS(3589),
    [anon_sym_await] = ACTIONS(3589),
    [anon_sym_foreach] = ACTIONS(3589),
    [anon_sym_goto] = ACTIONS(3589),
    [anon_sym_if] = ACTIONS(3589),
    [anon_sym_DOT_DOT] = ACTIONS(3591),
    [anon_sym_from] = ACTIONS(3589),
    [anon_sym_into] = ACTIONS(3589),
    [anon_sym_join] = ACTIONS(3589),
    [anon_sym_on] = ACTIONS(3589),
    [anon_sym_equals] = ACTIONS(3589),
    [anon_sym_let] = ACTIONS(3589),
    [anon_sym_orderby] = ACTIONS(3589),
    [anon_sym_ascending] = ACTIONS(3589),
    [anon_sym_descending] = ACTIONS(3589),
    [anon_sym_group] = ACTIONS(3589),
    [anon_sym_by] = ACTIONS(3589),
    [anon_sym_select] = ACTIONS(3589),
    [anon_sym_stackalloc] = ACTIONS(3589),
    [anon_sym_sizeof] = ACTIONS(3589),
    [anon_sym_typeof] = ACTIONS(3589),
    [anon_sym___makeref] = ACTIONS(3589),
    [anon_sym___reftype] = ACTIONS(3589),
    [anon_sym___refvalue] = ACTIONS(3589),
    [sym_null_literal] = ACTIONS(3589),
    [anon_sym_SQUOTE] = ACTIONS(3591),
    [sym_integer_literal] = ACTIONS(3589),
    [sym_real_literal] = ACTIONS(3591),
    [anon_sym_DQUOTE] = ACTIONS(3591),
    [sym_verbatim_string_literal] = ACTIONS(3591),
    [aux_sym_preproc_if_token1] = ACTIONS(3591),
    [aux_sym_preproc_if_token3] = ACTIONS(3591),
    [aux_sym_preproc_else_token1] = ACTIONS(3591),
    [aux_sym_preproc_elif_token1] = ACTIONS(3591),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3591),
    [sym_interpolation_verbatim_start] = ACTIONS(3591),
    [sym_interpolation_raw_start] = ACTIONS(3591),
    [sym_raw_string_start] = ACTIONS(3591),
  },
  [2354] = {
    [sym_preproc_region] = STATE(2354),
    [sym_preproc_endregion] = STATE(2354),
    [sym_preproc_line] = STATE(2354),
    [sym_preproc_pragma] = STATE(2354),
    [sym_preproc_nullable] = STATE(2354),
    [sym_preproc_error] = STATE(2354),
    [sym_preproc_warning] = STATE(2354),
    [sym_preproc_define] = STATE(2354),
    [sym_preproc_undef] = STATE(2354),
    [sym__identifier_token] = ACTIONS(3593),
    [anon_sym_extern] = ACTIONS(3593),
    [anon_sym_alias] = ACTIONS(3593),
    [anon_sym_SEMI] = ACTIONS(3595),
    [anon_sym_global] = ACTIONS(3593),
    [anon_sym_using] = ACTIONS(3593),
    [anon_sym_unsafe] = ACTIONS(3593),
    [anon_sym_static] = ACTIONS(3593),
    [anon_sym_LBRACK] = ACTIONS(3595),
    [anon_sym_LPAREN] = ACTIONS(3595),
    [anon_sym_return] = ACTIONS(3593),
    [anon_sym_namespace] = ACTIONS(3593),
    [anon_sym_class] = ACTIONS(3593),
    [anon_sym_ref] = ACTIONS(3593),
    [anon_sym_struct] = ACTIONS(3593),
    [anon_sym_enum] = ACTIONS(3593),
    [anon_sym_LBRACE] = ACTIONS(3595),
    [anon_sym_interface] = ACTIONS(3593),
    [anon_sym_delegate] = ACTIONS(3593),
    [anon_sym_record] = ACTIONS(3593),
    [anon_sym_abstract] = ACTIONS(3593),
    [anon_sym_async] = ACTIONS(3593),
    [anon_sym_const] = ACTIONS(3593),
    [anon_sym_file] = ACTIONS(3593),
    [anon_sym_fixed] = ACTIONS(3593),
    [anon_sym_internal] = ACTIONS(3593),
    [anon_sym_new] = ACTIONS(3593),
    [anon_sym_override] = ACTIONS(3593),
    [anon_sym_partial] = ACTIONS(3593),
    [anon_sym_private] = ACTIONS(3593),
    [anon_sym_protected] = ACTIONS(3593),
    [anon_sym_public] = ACTIONS(3593),
    [anon_sym_readonly] = ACTIONS(3593),
    [anon_sym_required] = ACTIONS(3593),
    [anon_sym_sealed] = ACTIONS(3593),
    [anon_sym_virtual] = ACTIONS(3593),
    [anon_sym_volatile] = ACTIONS(3593),
    [anon_sym_where] = ACTIONS(3593),
    [anon_sym_notnull] = ACTIONS(3593),
    [anon_sym_unmanaged] = ACTIONS(3593),
    [anon_sym_checked] = ACTIONS(3593),
    [anon_sym_BANG] = ACTIONS(3595),
    [anon_sym_TILDE] = ACTIONS(3595),
    [anon_sym_PLUS_PLUS] = ACTIONS(3595),
    [anon_sym_DASH_DASH] = ACTIONS(3595),
    [anon_sym_true] = ACTIONS(3593),
    [anon_sym_false] = ACTIONS(3593),
    [anon_sym_PLUS] = ACTIONS(3593),
    [anon_sym_DASH] = ACTIONS(3593),
    [anon_sym_STAR] = ACTIONS(3595),
    [anon_sym_CARET] = ACTIONS(3595),
    [anon_sym_AMP] = ACTIONS(3595),
    [anon_sym_this] = ACTIONS(3593),
    [anon_sym_scoped] = ACTIONS(3593),
    [anon_sym_base] = ACTIONS(3593),
    [anon_sym_var] = ACTIONS(3593),
    [sym_predefined_type] = ACTIONS(3593),
    [anon_sym_break] = ACTIONS(3593),
    [anon_sym_unchecked] = ACTIONS(3593),
    [anon_sym_continue] = ACTIONS(3593),
    [anon_sym_do] = ACTIONS(3593),
    [anon_sym_while] = ACTIONS(3593),
    [anon_sym_for] = ACTIONS(3593),
    [anon_sym_lock] = ACTIONS(3593),
    [anon_sym_yield] = ACTIONS(3593),
    [anon_sym_switch] = ACTIONS(3593),
    [anon_sym_default] = ACTIONS(3593),
    [anon_sym_throw] = ACTIONS(3593),
    [anon_sym_try] = ACTIONS(3593),
    [anon_sym_when] = ACTIONS(3593),
    [anon_sym_await] = ACTIONS(3593),
    [anon_sym_foreach] = ACTIONS(3593),
    [anon_sym_goto] = ACTIONS(3593),
    [anon_sym_if] = ACTIONS(3593),
    [anon_sym_DOT_DOT] = ACTIONS(3595),
    [anon_sym_from] = ACTIONS(3593),
    [anon_sym_into] = ACTIONS(3593),
    [anon_sym_join] = ACTIONS(3593),
    [anon_sym_on] = ACTIONS(3593),
    [anon_sym_equals] = ACTIONS(3593),
    [anon_sym_let] = ACTIONS(3593),
    [anon_sym_orderby] = ACTIONS(3593),
    [anon_sym_ascending] = ACTIONS(3593),
    [anon_sym_descending] = ACTIONS(3593),
    [anon_sym_group] = ACTIONS(3593),
    [anon_sym_by] = ACTIONS(3593),
    [anon_sym_select] = ACTIONS(3593),
    [anon_sym_stackalloc] = ACTIONS(3593),
    [anon_sym_sizeof] = ACTIONS(3593),
    [anon_sym_typeof] = ACTIONS(3593),
    [anon_sym___makeref] = ACTIONS(3593),
    [anon_sym___reftype] = ACTIONS(3593),
    [anon_sym___refvalue] = ACTIONS(3593),
    [sym_null_literal] = ACTIONS(3593),
    [anon_sym_SQUOTE] = ACTIONS(3595),
    [sym_integer_literal] = ACTIONS(3593),
    [sym_real_literal] = ACTIONS(3595),
    [anon_sym_DQUOTE] = ACTIONS(3595),
    [sym_verbatim_string_literal] = ACTIONS(3595),
    [aux_sym_preproc_if_token1] = ACTIONS(3595),
    [aux_sym_preproc_if_token3] = ACTIONS(3595),
    [aux_sym_preproc_else_token1] = ACTIONS(3595),
    [aux_sym_preproc_elif_token1] = ACTIONS(3595),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3595),
    [sym_interpolation_verbatim_start] = ACTIONS(3595),
    [sym_interpolation_raw_start] = ACTIONS(3595),
    [sym_raw_string_start] = ACTIONS(3595),
  },
  [2355] = {
    [sym_preproc_region] = STATE(2355),
    [sym_preproc_endregion] = STATE(2355),
    [sym_preproc_line] = STATE(2355),
    [sym_preproc_pragma] = STATE(2355),
    [sym_preproc_nullable] = STATE(2355),
    [sym_preproc_error] = STATE(2355),
    [sym_preproc_warning] = STATE(2355),
    [sym_preproc_define] = STATE(2355),
    [sym_preproc_undef] = STATE(2355),
    [sym__identifier_token] = ACTIONS(3597),
    [anon_sym_extern] = ACTIONS(3597),
    [anon_sym_alias] = ACTIONS(3597),
    [anon_sym_SEMI] = ACTIONS(3599),
    [anon_sym_global] = ACTIONS(3597),
    [anon_sym_using] = ACTIONS(3597),
    [anon_sym_unsafe] = ACTIONS(3597),
    [anon_sym_static] = ACTIONS(3597),
    [anon_sym_LBRACK] = ACTIONS(3599),
    [anon_sym_LPAREN] = ACTIONS(3599),
    [anon_sym_return] = ACTIONS(3597),
    [anon_sym_namespace] = ACTIONS(3597),
    [anon_sym_class] = ACTIONS(3597),
    [anon_sym_ref] = ACTIONS(3597),
    [anon_sym_struct] = ACTIONS(3597),
    [anon_sym_enum] = ACTIONS(3597),
    [anon_sym_LBRACE] = ACTIONS(3599),
    [anon_sym_interface] = ACTIONS(3597),
    [anon_sym_delegate] = ACTIONS(3597),
    [anon_sym_record] = ACTIONS(3597),
    [anon_sym_abstract] = ACTIONS(3597),
    [anon_sym_async] = ACTIONS(3597),
    [anon_sym_const] = ACTIONS(3597),
    [anon_sym_file] = ACTIONS(3597),
    [anon_sym_fixed] = ACTIONS(3597),
    [anon_sym_internal] = ACTIONS(3597),
    [anon_sym_new] = ACTIONS(3597),
    [anon_sym_override] = ACTIONS(3597),
    [anon_sym_partial] = ACTIONS(3597),
    [anon_sym_private] = ACTIONS(3597),
    [anon_sym_protected] = ACTIONS(3597),
    [anon_sym_public] = ACTIONS(3597),
    [anon_sym_readonly] = ACTIONS(3597),
    [anon_sym_required] = ACTIONS(3597),
    [anon_sym_sealed] = ACTIONS(3597),
    [anon_sym_virtual] = ACTIONS(3597),
    [anon_sym_volatile] = ACTIONS(3597),
    [anon_sym_where] = ACTIONS(3597),
    [anon_sym_notnull] = ACTIONS(3597),
    [anon_sym_unmanaged] = ACTIONS(3597),
    [anon_sym_checked] = ACTIONS(3597),
    [anon_sym_BANG] = ACTIONS(3599),
    [anon_sym_TILDE] = ACTIONS(3599),
    [anon_sym_PLUS_PLUS] = ACTIONS(3599),
    [anon_sym_DASH_DASH] = ACTIONS(3599),
    [anon_sym_true] = ACTIONS(3597),
    [anon_sym_false] = ACTIONS(3597),
    [anon_sym_PLUS] = ACTIONS(3597),
    [anon_sym_DASH] = ACTIONS(3597),
    [anon_sym_STAR] = ACTIONS(3599),
    [anon_sym_CARET] = ACTIONS(3599),
    [anon_sym_AMP] = ACTIONS(3599),
    [anon_sym_this] = ACTIONS(3597),
    [anon_sym_scoped] = ACTIONS(3597),
    [anon_sym_base] = ACTIONS(3597),
    [anon_sym_var] = ACTIONS(3597),
    [sym_predefined_type] = ACTIONS(3597),
    [anon_sym_break] = ACTIONS(3597),
    [anon_sym_unchecked] = ACTIONS(3597),
    [anon_sym_continue] = ACTIONS(3597),
    [anon_sym_do] = ACTIONS(3597),
    [anon_sym_while] = ACTIONS(3597),
    [anon_sym_for] = ACTIONS(3597),
    [anon_sym_lock] = ACTIONS(3597),
    [anon_sym_yield] = ACTIONS(3597),
    [anon_sym_switch] = ACTIONS(3597),
    [anon_sym_default] = ACTIONS(3597),
    [anon_sym_throw] = ACTIONS(3597),
    [anon_sym_try] = ACTIONS(3597),
    [anon_sym_when] = ACTIONS(3597),
    [anon_sym_await] = ACTIONS(3597),
    [anon_sym_foreach] = ACTIONS(3597),
    [anon_sym_goto] = ACTIONS(3597),
    [anon_sym_if] = ACTIONS(3597),
    [anon_sym_DOT_DOT] = ACTIONS(3599),
    [anon_sym_from] = ACTIONS(3597),
    [anon_sym_into] = ACTIONS(3597),
    [anon_sym_join] = ACTIONS(3597),
    [anon_sym_on] = ACTIONS(3597),
    [anon_sym_equals] = ACTIONS(3597),
    [anon_sym_let] = ACTIONS(3597),
    [anon_sym_orderby] = ACTIONS(3597),
    [anon_sym_ascending] = ACTIONS(3597),
    [anon_sym_descending] = ACTIONS(3597),
    [anon_sym_group] = ACTIONS(3597),
    [anon_sym_by] = ACTIONS(3597),
    [anon_sym_select] = ACTIONS(3597),
    [anon_sym_stackalloc] = ACTIONS(3597),
    [anon_sym_sizeof] = ACTIONS(3597),
    [anon_sym_typeof] = ACTIONS(3597),
    [anon_sym___makeref] = ACTIONS(3597),
    [anon_sym___reftype] = ACTIONS(3597),
    [anon_sym___refvalue] = ACTIONS(3597),
    [sym_null_literal] = ACTIONS(3597),
    [anon_sym_SQUOTE] = ACTIONS(3599),
    [sym_integer_literal] = ACTIONS(3597),
    [sym_real_literal] = ACTIONS(3599),
    [anon_sym_DQUOTE] = ACTIONS(3599),
    [sym_verbatim_string_literal] = ACTIONS(3599),
    [aux_sym_preproc_if_token1] = ACTIONS(3599),
    [aux_sym_preproc_if_token3] = ACTIONS(3599),
    [aux_sym_preproc_else_token1] = ACTIONS(3599),
    [aux_sym_preproc_elif_token1] = ACTIONS(3599),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3599),
    [sym_interpolation_verbatim_start] = ACTIONS(3599),
    [sym_interpolation_raw_start] = ACTIONS(3599),
    [sym_raw_string_start] = ACTIONS(3599),
  },
  [2356] = {
    [sym_preproc_region] = STATE(2356),
    [sym_preproc_endregion] = STATE(2356),
    [sym_preproc_line] = STATE(2356),
    [sym_preproc_pragma] = STATE(2356),
    [sym_preproc_nullable] = STATE(2356),
    [sym_preproc_error] = STATE(2356),
    [sym_preproc_warning] = STATE(2356),
    [sym_preproc_define] = STATE(2356),
    [sym_preproc_undef] = STATE(2356),
    [sym__identifier_token] = ACTIONS(3601),
    [anon_sym_extern] = ACTIONS(3601),
    [anon_sym_alias] = ACTIONS(3601),
    [anon_sym_SEMI] = ACTIONS(3603),
    [anon_sym_global] = ACTIONS(3601),
    [anon_sym_using] = ACTIONS(3601),
    [anon_sym_unsafe] = ACTIONS(3601),
    [anon_sym_static] = ACTIONS(3601),
    [anon_sym_LBRACK] = ACTIONS(3603),
    [anon_sym_LPAREN] = ACTIONS(3603),
    [anon_sym_return] = ACTIONS(3601),
    [anon_sym_namespace] = ACTIONS(3601),
    [anon_sym_class] = ACTIONS(3601),
    [anon_sym_ref] = ACTIONS(3601),
    [anon_sym_struct] = ACTIONS(3601),
    [anon_sym_enum] = ACTIONS(3601),
    [anon_sym_LBRACE] = ACTIONS(3603),
    [anon_sym_interface] = ACTIONS(3601),
    [anon_sym_delegate] = ACTIONS(3601),
    [anon_sym_record] = ACTIONS(3601),
    [anon_sym_abstract] = ACTIONS(3601),
    [anon_sym_async] = ACTIONS(3601),
    [anon_sym_const] = ACTIONS(3601),
    [anon_sym_file] = ACTIONS(3601),
    [anon_sym_fixed] = ACTIONS(3601),
    [anon_sym_internal] = ACTIONS(3601),
    [anon_sym_new] = ACTIONS(3601),
    [anon_sym_override] = ACTIONS(3601),
    [anon_sym_partial] = ACTIONS(3601),
    [anon_sym_private] = ACTIONS(3601),
    [anon_sym_protected] = ACTIONS(3601),
    [anon_sym_public] = ACTIONS(3601),
    [anon_sym_readonly] = ACTIONS(3601),
    [anon_sym_required] = ACTIONS(3601),
    [anon_sym_sealed] = ACTIONS(3601),
    [anon_sym_virtual] = ACTIONS(3601),
    [anon_sym_volatile] = ACTIONS(3601),
    [anon_sym_where] = ACTIONS(3601),
    [anon_sym_notnull] = ACTIONS(3601),
    [anon_sym_unmanaged] = ACTIONS(3601),
    [anon_sym_checked] = ACTIONS(3601),
    [anon_sym_BANG] = ACTIONS(3603),
    [anon_sym_TILDE] = ACTIONS(3603),
    [anon_sym_PLUS_PLUS] = ACTIONS(3603),
    [anon_sym_DASH_DASH] = ACTIONS(3603),
    [anon_sym_true] = ACTIONS(3601),
    [anon_sym_false] = ACTIONS(3601),
    [anon_sym_PLUS] = ACTIONS(3601),
    [anon_sym_DASH] = ACTIONS(3601),
    [anon_sym_STAR] = ACTIONS(3603),
    [anon_sym_CARET] = ACTIONS(3603),
    [anon_sym_AMP] = ACTIONS(3603),
    [anon_sym_this] = ACTIONS(3601),
    [anon_sym_scoped] = ACTIONS(3601),
    [anon_sym_base] = ACTIONS(3601),
    [anon_sym_var] = ACTIONS(3601),
    [sym_predefined_type] = ACTIONS(3601),
    [anon_sym_break] = ACTIONS(3601),
    [anon_sym_unchecked] = ACTIONS(3601),
    [anon_sym_continue] = ACTIONS(3601),
    [anon_sym_do] = ACTIONS(3601),
    [anon_sym_while] = ACTIONS(3601),
    [anon_sym_for] = ACTIONS(3601),
    [anon_sym_lock] = ACTIONS(3601),
    [anon_sym_yield] = ACTIONS(3601),
    [anon_sym_switch] = ACTIONS(3601),
    [anon_sym_default] = ACTIONS(3601),
    [anon_sym_throw] = ACTIONS(3601),
    [anon_sym_try] = ACTIONS(3601),
    [anon_sym_when] = ACTIONS(3601),
    [anon_sym_await] = ACTIONS(3601),
    [anon_sym_foreach] = ACTIONS(3601),
    [anon_sym_goto] = ACTIONS(3601),
    [anon_sym_if] = ACTIONS(3601),
    [anon_sym_DOT_DOT] = ACTIONS(3603),
    [anon_sym_from] = ACTIONS(3601),
    [anon_sym_into] = ACTIONS(3601),
    [anon_sym_join] = ACTIONS(3601),
    [anon_sym_on] = ACTIONS(3601),
    [anon_sym_equals] = ACTIONS(3601),
    [anon_sym_let] = ACTIONS(3601),
    [anon_sym_orderby] = ACTIONS(3601),
    [anon_sym_ascending] = ACTIONS(3601),
    [anon_sym_descending] = ACTIONS(3601),
    [anon_sym_group] = ACTIONS(3601),
    [anon_sym_by] = ACTIONS(3601),
    [anon_sym_select] = ACTIONS(3601),
    [anon_sym_stackalloc] = ACTIONS(3601),
    [anon_sym_sizeof] = ACTIONS(3601),
    [anon_sym_typeof] = ACTIONS(3601),
    [anon_sym___makeref] = ACTIONS(3601),
    [anon_sym___reftype] = ACTIONS(3601),
    [anon_sym___refvalue] = ACTIONS(3601),
    [sym_null_literal] = ACTIONS(3601),
    [anon_sym_SQUOTE] = ACTIONS(3603),
    [sym_integer_literal] = ACTIONS(3601),
    [sym_real_literal] = ACTIONS(3603),
    [anon_sym_DQUOTE] = ACTIONS(3603),
    [sym_verbatim_string_literal] = ACTIONS(3603),
    [aux_sym_preproc_if_token1] = ACTIONS(3603),
    [aux_sym_preproc_if_token3] = ACTIONS(3603),
    [aux_sym_preproc_else_token1] = ACTIONS(3603),
    [aux_sym_preproc_elif_token1] = ACTIONS(3603),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3603),
    [sym_interpolation_verbatim_start] = ACTIONS(3603),
    [sym_interpolation_raw_start] = ACTIONS(3603),
    [sym_raw_string_start] = ACTIONS(3603),
  },
  [2357] = {
    [sym_preproc_region] = STATE(2357),
    [sym_preproc_endregion] = STATE(2357),
    [sym_preproc_line] = STATE(2357),
    [sym_preproc_pragma] = STATE(2357),
    [sym_preproc_nullable] = STATE(2357),
    [sym_preproc_error] = STATE(2357),
    [sym_preproc_warning] = STATE(2357),
    [sym_preproc_define] = STATE(2357),
    [sym_preproc_undef] = STATE(2357),
    [sym__identifier_token] = ACTIONS(3605),
    [anon_sym_extern] = ACTIONS(3605),
    [anon_sym_alias] = ACTIONS(3605),
    [anon_sym_SEMI] = ACTIONS(3607),
    [anon_sym_global] = ACTIONS(3605),
    [anon_sym_using] = ACTIONS(3605),
    [anon_sym_unsafe] = ACTIONS(3605),
    [anon_sym_static] = ACTIONS(3605),
    [anon_sym_LBRACK] = ACTIONS(3607),
    [anon_sym_LPAREN] = ACTIONS(3607),
    [anon_sym_return] = ACTIONS(3605),
    [anon_sym_namespace] = ACTIONS(3605),
    [anon_sym_class] = ACTIONS(3605),
    [anon_sym_ref] = ACTIONS(3605),
    [anon_sym_struct] = ACTIONS(3605),
    [anon_sym_enum] = ACTIONS(3605),
    [anon_sym_LBRACE] = ACTIONS(3607),
    [anon_sym_interface] = ACTIONS(3605),
    [anon_sym_delegate] = ACTIONS(3605),
    [anon_sym_record] = ACTIONS(3605),
    [anon_sym_abstract] = ACTIONS(3605),
    [anon_sym_async] = ACTIONS(3605),
    [anon_sym_const] = ACTIONS(3605),
    [anon_sym_file] = ACTIONS(3605),
    [anon_sym_fixed] = ACTIONS(3605),
    [anon_sym_internal] = ACTIONS(3605),
    [anon_sym_new] = ACTIONS(3605),
    [anon_sym_override] = ACTIONS(3605),
    [anon_sym_partial] = ACTIONS(3605),
    [anon_sym_private] = ACTIONS(3605),
    [anon_sym_protected] = ACTIONS(3605),
    [anon_sym_public] = ACTIONS(3605),
    [anon_sym_readonly] = ACTIONS(3605),
    [anon_sym_required] = ACTIONS(3605),
    [anon_sym_sealed] = ACTIONS(3605),
    [anon_sym_virtual] = ACTIONS(3605),
    [anon_sym_volatile] = ACTIONS(3605),
    [anon_sym_where] = ACTIONS(3605),
    [anon_sym_notnull] = ACTIONS(3605),
    [anon_sym_unmanaged] = ACTIONS(3605),
    [anon_sym_checked] = ACTIONS(3605),
    [anon_sym_BANG] = ACTIONS(3607),
    [anon_sym_TILDE] = ACTIONS(3607),
    [anon_sym_PLUS_PLUS] = ACTIONS(3607),
    [anon_sym_DASH_DASH] = ACTIONS(3607),
    [anon_sym_true] = ACTIONS(3605),
    [anon_sym_false] = ACTIONS(3605),
    [anon_sym_PLUS] = ACTIONS(3605),
    [anon_sym_DASH] = ACTIONS(3605),
    [anon_sym_STAR] = ACTIONS(3607),
    [anon_sym_CARET] = ACTIONS(3607),
    [anon_sym_AMP] = ACTIONS(3607),
    [anon_sym_this] = ACTIONS(3605),
    [anon_sym_scoped] = ACTIONS(3605),
    [anon_sym_base] = ACTIONS(3605),
    [anon_sym_var] = ACTIONS(3605),
    [sym_predefined_type] = ACTIONS(3605),
    [anon_sym_break] = ACTIONS(3605),
    [anon_sym_unchecked] = ACTIONS(3605),
    [anon_sym_continue] = ACTIONS(3605),
    [anon_sym_do] = ACTIONS(3605),
    [anon_sym_while] = ACTIONS(3605),
    [anon_sym_for] = ACTIONS(3605),
    [anon_sym_lock] = ACTIONS(3605),
    [anon_sym_yield] = ACTIONS(3605),
    [anon_sym_switch] = ACTIONS(3605),
    [anon_sym_default] = ACTIONS(3605),
    [anon_sym_throw] = ACTIONS(3605),
    [anon_sym_try] = ACTIONS(3605),
    [anon_sym_when] = ACTIONS(3605),
    [anon_sym_await] = ACTIONS(3605),
    [anon_sym_foreach] = ACTIONS(3605),
    [anon_sym_goto] = ACTIONS(3605),
    [anon_sym_if] = ACTIONS(3605),
    [anon_sym_DOT_DOT] = ACTIONS(3607),
    [anon_sym_from] = ACTIONS(3605),
    [anon_sym_into] = ACTIONS(3605),
    [anon_sym_join] = ACTIONS(3605),
    [anon_sym_on] = ACTIONS(3605),
    [anon_sym_equals] = ACTIONS(3605),
    [anon_sym_let] = ACTIONS(3605),
    [anon_sym_orderby] = ACTIONS(3605),
    [anon_sym_ascending] = ACTIONS(3605),
    [anon_sym_descending] = ACTIONS(3605),
    [anon_sym_group] = ACTIONS(3605),
    [anon_sym_by] = ACTIONS(3605),
    [anon_sym_select] = ACTIONS(3605),
    [anon_sym_stackalloc] = ACTIONS(3605),
    [anon_sym_sizeof] = ACTIONS(3605),
    [anon_sym_typeof] = ACTIONS(3605),
    [anon_sym___makeref] = ACTIONS(3605),
    [anon_sym___reftype] = ACTIONS(3605),
    [anon_sym___refvalue] = ACTIONS(3605),
    [sym_null_literal] = ACTIONS(3605),
    [anon_sym_SQUOTE] = ACTIONS(3607),
    [sym_integer_literal] = ACTIONS(3605),
    [sym_real_literal] = ACTIONS(3607),
    [anon_sym_DQUOTE] = ACTIONS(3607),
    [sym_verbatim_string_literal] = ACTIONS(3607),
    [aux_sym_preproc_if_token1] = ACTIONS(3607),
    [aux_sym_preproc_if_token3] = ACTIONS(3607),
    [aux_sym_preproc_else_token1] = ACTIONS(3607),
    [aux_sym_preproc_elif_token1] = ACTIONS(3607),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3607),
    [sym_interpolation_verbatim_start] = ACTIONS(3607),
    [sym_interpolation_raw_start] = ACTIONS(3607),
    [sym_raw_string_start] = ACTIONS(3607),
  },
  [2358] = {
    [sym_preproc_region] = STATE(2358),
    [sym_preproc_endregion] = STATE(2358),
    [sym_preproc_line] = STATE(2358),
    [sym_preproc_pragma] = STATE(2358),
    [sym_preproc_nullable] = STATE(2358),
    [sym_preproc_error] = STATE(2358),
    [sym_preproc_warning] = STATE(2358),
    [sym_preproc_define] = STATE(2358),
    [sym_preproc_undef] = STATE(2358),
    [sym__identifier_token] = ACTIONS(3609),
    [anon_sym_extern] = ACTIONS(3609),
    [anon_sym_alias] = ACTIONS(3609),
    [anon_sym_SEMI] = ACTIONS(3611),
    [anon_sym_global] = ACTIONS(3609),
    [anon_sym_using] = ACTIONS(3609),
    [anon_sym_unsafe] = ACTIONS(3609),
    [anon_sym_static] = ACTIONS(3609),
    [anon_sym_LBRACK] = ACTIONS(3611),
    [anon_sym_LPAREN] = ACTIONS(3611),
    [anon_sym_return] = ACTIONS(3609),
    [anon_sym_namespace] = ACTIONS(3609),
    [anon_sym_class] = ACTIONS(3609),
    [anon_sym_ref] = ACTIONS(3609),
    [anon_sym_struct] = ACTIONS(3609),
    [anon_sym_enum] = ACTIONS(3609),
    [anon_sym_LBRACE] = ACTIONS(3611),
    [anon_sym_interface] = ACTIONS(3609),
    [anon_sym_delegate] = ACTIONS(3609),
    [anon_sym_record] = ACTIONS(3609),
    [anon_sym_abstract] = ACTIONS(3609),
    [anon_sym_async] = ACTIONS(3609),
    [anon_sym_const] = ACTIONS(3609),
    [anon_sym_file] = ACTIONS(3609),
    [anon_sym_fixed] = ACTIONS(3609),
    [anon_sym_internal] = ACTIONS(3609),
    [anon_sym_new] = ACTIONS(3609),
    [anon_sym_override] = ACTIONS(3609),
    [anon_sym_partial] = ACTIONS(3609),
    [anon_sym_private] = ACTIONS(3609),
    [anon_sym_protected] = ACTIONS(3609),
    [anon_sym_public] = ACTIONS(3609),
    [anon_sym_readonly] = ACTIONS(3609),
    [anon_sym_required] = ACTIONS(3609),
    [anon_sym_sealed] = ACTIONS(3609),
    [anon_sym_virtual] = ACTIONS(3609),
    [anon_sym_volatile] = ACTIONS(3609),
    [anon_sym_where] = ACTIONS(3609),
    [anon_sym_notnull] = ACTIONS(3609),
    [anon_sym_unmanaged] = ACTIONS(3609),
    [anon_sym_checked] = ACTIONS(3609),
    [anon_sym_BANG] = ACTIONS(3611),
    [anon_sym_TILDE] = ACTIONS(3611),
    [anon_sym_PLUS_PLUS] = ACTIONS(3611),
    [anon_sym_DASH_DASH] = ACTIONS(3611),
    [anon_sym_true] = ACTIONS(3609),
    [anon_sym_false] = ACTIONS(3609),
    [anon_sym_PLUS] = ACTIONS(3609),
    [anon_sym_DASH] = ACTIONS(3609),
    [anon_sym_STAR] = ACTIONS(3611),
    [anon_sym_CARET] = ACTIONS(3611),
    [anon_sym_AMP] = ACTIONS(3611),
    [anon_sym_this] = ACTIONS(3609),
    [anon_sym_scoped] = ACTIONS(3609),
    [anon_sym_base] = ACTIONS(3609),
    [anon_sym_var] = ACTIONS(3609),
    [sym_predefined_type] = ACTIONS(3609),
    [anon_sym_break] = ACTIONS(3609),
    [anon_sym_unchecked] = ACTIONS(3609),
    [anon_sym_continue] = ACTIONS(3609),
    [anon_sym_do] = ACTIONS(3609),
    [anon_sym_while] = ACTIONS(3609),
    [anon_sym_for] = ACTIONS(3609),
    [anon_sym_lock] = ACTIONS(3609),
    [anon_sym_yield] = ACTIONS(3609),
    [anon_sym_switch] = ACTIONS(3609),
    [anon_sym_default] = ACTIONS(3609),
    [anon_sym_throw] = ACTIONS(3609),
    [anon_sym_try] = ACTIONS(3609),
    [anon_sym_when] = ACTIONS(3609),
    [anon_sym_await] = ACTIONS(3609),
    [anon_sym_foreach] = ACTIONS(3609),
    [anon_sym_goto] = ACTIONS(3609),
    [anon_sym_if] = ACTIONS(3609),
    [anon_sym_DOT_DOT] = ACTIONS(3611),
    [anon_sym_from] = ACTIONS(3609),
    [anon_sym_into] = ACTIONS(3609),
    [anon_sym_join] = ACTIONS(3609),
    [anon_sym_on] = ACTIONS(3609),
    [anon_sym_equals] = ACTIONS(3609),
    [anon_sym_let] = ACTIONS(3609),
    [anon_sym_orderby] = ACTIONS(3609),
    [anon_sym_ascending] = ACTIONS(3609),
    [anon_sym_descending] = ACTIONS(3609),
    [anon_sym_group] = ACTIONS(3609),
    [anon_sym_by] = ACTIONS(3609),
    [anon_sym_select] = ACTIONS(3609),
    [anon_sym_stackalloc] = ACTIONS(3609),
    [anon_sym_sizeof] = ACTIONS(3609),
    [anon_sym_typeof] = ACTIONS(3609),
    [anon_sym___makeref] = ACTIONS(3609),
    [anon_sym___reftype] = ACTIONS(3609),
    [anon_sym___refvalue] = ACTIONS(3609),
    [sym_null_literal] = ACTIONS(3609),
    [anon_sym_SQUOTE] = ACTIONS(3611),
    [sym_integer_literal] = ACTIONS(3609),
    [sym_real_literal] = ACTIONS(3611),
    [anon_sym_DQUOTE] = ACTIONS(3611),
    [sym_verbatim_string_literal] = ACTIONS(3611),
    [aux_sym_preproc_if_token1] = ACTIONS(3611),
    [aux_sym_preproc_if_token3] = ACTIONS(3611),
    [aux_sym_preproc_else_token1] = ACTIONS(3611),
    [aux_sym_preproc_elif_token1] = ACTIONS(3611),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3611),
    [sym_interpolation_verbatim_start] = ACTIONS(3611),
    [sym_interpolation_raw_start] = ACTIONS(3611),
    [sym_raw_string_start] = ACTIONS(3611),
  },
  [2359] = {
    [sym_preproc_region] = STATE(2359),
    [sym_preproc_endregion] = STATE(2359),
    [sym_preproc_line] = STATE(2359),
    [sym_preproc_pragma] = STATE(2359),
    [sym_preproc_nullable] = STATE(2359),
    [sym_preproc_error] = STATE(2359),
    [sym_preproc_warning] = STATE(2359),
    [sym_preproc_define] = STATE(2359),
    [sym_preproc_undef] = STATE(2359),
    [sym__identifier_token] = ACTIONS(3613),
    [anon_sym_extern] = ACTIONS(3613),
    [anon_sym_alias] = ACTIONS(3613),
    [anon_sym_SEMI] = ACTIONS(3615),
    [anon_sym_global] = ACTIONS(3613),
    [anon_sym_using] = ACTIONS(3613),
    [anon_sym_unsafe] = ACTIONS(3613),
    [anon_sym_static] = ACTIONS(3613),
    [anon_sym_LBRACK] = ACTIONS(3615),
    [anon_sym_LPAREN] = ACTIONS(3615),
    [anon_sym_return] = ACTIONS(3613),
    [anon_sym_namespace] = ACTIONS(3613),
    [anon_sym_class] = ACTIONS(3613),
    [anon_sym_ref] = ACTIONS(3613),
    [anon_sym_struct] = ACTIONS(3613),
    [anon_sym_enum] = ACTIONS(3613),
    [anon_sym_LBRACE] = ACTIONS(3615),
    [anon_sym_interface] = ACTIONS(3613),
    [anon_sym_delegate] = ACTIONS(3613),
    [anon_sym_record] = ACTIONS(3613),
    [anon_sym_abstract] = ACTIONS(3613),
    [anon_sym_async] = ACTIONS(3613),
    [anon_sym_const] = ACTIONS(3613),
    [anon_sym_file] = ACTIONS(3613),
    [anon_sym_fixed] = ACTIONS(3613),
    [anon_sym_internal] = ACTIONS(3613),
    [anon_sym_new] = ACTIONS(3613),
    [anon_sym_override] = ACTIONS(3613),
    [anon_sym_partial] = ACTIONS(3613),
    [anon_sym_private] = ACTIONS(3613),
    [anon_sym_protected] = ACTIONS(3613),
    [anon_sym_public] = ACTIONS(3613),
    [anon_sym_readonly] = ACTIONS(3613),
    [anon_sym_required] = ACTIONS(3613),
    [anon_sym_sealed] = ACTIONS(3613),
    [anon_sym_virtual] = ACTIONS(3613),
    [anon_sym_volatile] = ACTIONS(3613),
    [anon_sym_where] = ACTIONS(3613),
    [anon_sym_notnull] = ACTIONS(3613),
    [anon_sym_unmanaged] = ACTIONS(3613),
    [anon_sym_checked] = ACTIONS(3613),
    [anon_sym_BANG] = ACTIONS(3615),
    [anon_sym_TILDE] = ACTIONS(3615),
    [anon_sym_PLUS_PLUS] = ACTIONS(3615),
    [anon_sym_DASH_DASH] = ACTIONS(3615),
    [anon_sym_true] = ACTIONS(3613),
    [anon_sym_false] = ACTIONS(3613),
    [anon_sym_PLUS] = ACTIONS(3613),
    [anon_sym_DASH] = ACTIONS(3613),
    [anon_sym_STAR] = ACTIONS(3615),
    [anon_sym_CARET] = ACTIONS(3615),
    [anon_sym_AMP] = ACTIONS(3615),
    [anon_sym_this] = ACTIONS(3613),
    [anon_sym_scoped] = ACTIONS(3613),
    [anon_sym_base] = ACTIONS(3613),
    [anon_sym_var] = ACTIONS(3613),
    [sym_predefined_type] = ACTIONS(3613),
    [anon_sym_break] = ACTIONS(3613),
    [anon_sym_unchecked] = ACTIONS(3613),
    [anon_sym_continue] = ACTIONS(3613),
    [anon_sym_do] = ACTIONS(3613),
    [anon_sym_while] = ACTIONS(3613),
    [anon_sym_for] = ACTIONS(3613),
    [anon_sym_lock] = ACTIONS(3613),
    [anon_sym_yield] = ACTIONS(3613),
    [anon_sym_switch] = ACTIONS(3613),
    [anon_sym_default] = ACTIONS(3613),
    [anon_sym_throw] = ACTIONS(3613),
    [anon_sym_try] = ACTIONS(3613),
    [anon_sym_when] = ACTIONS(3613),
    [anon_sym_await] = ACTIONS(3613),
    [anon_sym_foreach] = ACTIONS(3613),
    [anon_sym_goto] = ACTIONS(3613),
    [anon_sym_if] = ACTIONS(3613),
    [anon_sym_DOT_DOT] = ACTIONS(3615),
    [anon_sym_from] = ACTIONS(3613),
    [anon_sym_into] = ACTIONS(3613),
    [anon_sym_join] = ACTIONS(3613),
    [anon_sym_on] = ACTIONS(3613),
    [anon_sym_equals] = ACTIONS(3613),
    [anon_sym_let] = ACTIONS(3613),
    [anon_sym_orderby] = ACTIONS(3613),
    [anon_sym_ascending] = ACTIONS(3613),
    [anon_sym_descending] = ACTIONS(3613),
    [anon_sym_group] = ACTIONS(3613),
    [anon_sym_by] = ACTIONS(3613),
    [anon_sym_select] = ACTIONS(3613),
    [anon_sym_stackalloc] = ACTIONS(3613),
    [anon_sym_sizeof] = ACTIONS(3613),
    [anon_sym_typeof] = ACTIONS(3613),
    [anon_sym___makeref] = ACTIONS(3613),
    [anon_sym___reftype] = ACTIONS(3613),
    [anon_sym___refvalue] = ACTIONS(3613),
    [sym_null_literal] = ACTIONS(3613),
    [anon_sym_SQUOTE] = ACTIONS(3615),
    [sym_integer_literal] = ACTIONS(3613),
    [sym_real_literal] = ACTIONS(3615),
    [anon_sym_DQUOTE] = ACTIONS(3615),
    [sym_verbatim_string_literal] = ACTIONS(3615),
    [aux_sym_preproc_if_token1] = ACTIONS(3615),
    [aux_sym_preproc_if_token3] = ACTIONS(3615),
    [aux_sym_preproc_else_token1] = ACTIONS(3615),
    [aux_sym_preproc_elif_token1] = ACTIONS(3615),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3615),
    [sym_interpolation_verbatim_start] = ACTIONS(3615),
    [sym_interpolation_raw_start] = ACTIONS(3615),
    [sym_raw_string_start] = ACTIONS(3615),
  },
  [2360] = {
    [sym_preproc_region] = STATE(2360),
    [sym_preproc_endregion] = STATE(2360),
    [sym_preproc_line] = STATE(2360),
    [sym_preproc_pragma] = STATE(2360),
    [sym_preproc_nullable] = STATE(2360),
    [sym_preproc_error] = STATE(2360),
    [sym_preproc_warning] = STATE(2360),
    [sym_preproc_define] = STATE(2360),
    [sym_preproc_undef] = STATE(2360),
    [sym__identifier_token] = ACTIONS(3617),
    [anon_sym_extern] = ACTIONS(3617),
    [anon_sym_alias] = ACTIONS(3617),
    [anon_sym_SEMI] = ACTIONS(3619),
    [anon_sym_global] = ACTIONS(3617),
    [anon_sym_using] = ACTIONS(3617),
    [anon_sym_unsafe] = ACTIONS(3617),
    [anon_sym_static] = ACTIONS(3617),
    [anon_sym_LBRACK] = ACTIONS(3619),
    [anon_sym_LPAREN] = ACTIONS(3619),
    [anon_sym_return] = ACTIONS(3617),
    [anon_sym_namespace] = ACTIONS(3617),
    [anon_sym_class] = ACTIONS(3617),
    [anon_sym_ref] = ACTIONS(3617),
    [anon_sym_struct] = ACTIONS(3617),
    [anon_sym_enum] = ACTIONS(3617),
    [anon_sym_LBRACE] = ACTIONS(3619),
    [anon_sym_interface] = ACTIONS(3617),
    [anon_sym_delegate] = ACTIONS(3617),
    [anon_sym_record] = ACTIONS(3617),
    [anon_sym_abstract] = ACTIONS(3617),
    [anon_sym_async] = ACTIONS(3617),
    [anon_sym_const] = ACTIONS(3617),
    [anon_sym_file] = ACTIONS(3617),
    [anon_sym_fixed] = ACTIONS(3617),
    [anon_sym_internal] = ACTIONS(3617),
    [anon_sym_new] = ACTIONS(3617),
    [anon_sym_override] = ACTIONS(3617),
    [anon_sym_partial] = ACTIONS(3617),
    [anon_sym_private] = ACTIONS(3617),
    [anon_sym_protected] = ACTIONS(3617),
    [anon_sym_public] = ACTIONS(3617),
    [anon_sym_readonly] = ACTIONS(3617),
    [anon_sym_required] = ACTIONS(3617),
    [anon_sym_sealed] = ACTIONS(3617),
    [anon_sym_virtual] = ACTIONS(3617),
    [anon_sym_volatile] = ACTIONS(3617),
    [anon_sym_where] = ACTIONS(3617),
    [anon_sym_notnull] = ACTIONS(3617),
    [anon_sym_unmanaged] = ACTIONS(3617),
    [anon_sym_checked] = ACTIONS(3617),
    [anon_sym_BANG] = ACTIONS(3619),
    [anon_sym_TILDE] = ACTIONS(3619),
    [anon_sym_PLUS_PLUS] = ACTIONS(3619),
    [anon_sym_DASH_DASH] = ACTIONS(3619),
    [anon_sym_true] = ACTIONS(3617),
    [anon_sym_false] = ACTIONS(3617),
    [anon_sym_PLUS] = ACTIONS(3617),
    [anon_sym_DASH] = ACTIONS(3617),
    [anon_sym_STAR] = ACTIONS(3619),
    [anon_sym_CARET] = ACTIONS(3619),
    [anon_sym_AMP] = ACTIONS(3619),
    [anon_sym_this] = ACTIONS(3617),
    [anon_sym_scoped] = ACTIONS(3617),
    [anon_sym_base] = ACTIONS(3617),
    [anon_sym_var] = ACTIONS(3617),
    [sym_predefined_type] = ACTIONS(3617),
    [anon_sym_break] = ACTIONS(3617),
    [anon_sym_unchecked] = ACTIONS(3617),
    [anon_sym_continue] = ACTIONS(3617),
    [anon_sym_do] = ACTIONS(3617),
    [anon_sym_while] = ACTIONS(3617),
    [anon_sym_for] = ACTIONS(3617),
    [anon_sym_lock] = ACTIONS(3617),
    [anon_sym_yield] = ACTIONS(3617),
    [anon_sym_switch] = ACTIONS(3617),
    [anon_sym_default] = ACTIONS(3617),
    [anon_sym_throw] = ACTIONS(3617),
    [anon_sym_try] = ACTIONS(3617),
    [anon_sym_when] = ACTIONS(3617),
    [anon_sym_await] = ACTIONS(3617),
    [anon_sym_foreach] = ACTIONS(3617),
    [anon_sym_goto] = ACTIONS(3617),
    [anon_sym_if] = ACTIONS(3617),
    [anon_sym_DOT_DOT] = ACTIONS(3619),
    [anon_sym_from] = ACTIONS(3617),
    [anon_sym_into] = ACTIONS(3617),
    [anon_sym_join] = ACTIONS(3617),
    [anon_sym_on] = ACTIONS(3617),
    [anon_sym_equals] = ACTIONS(3617),
    [anon_sym_let] = ACTIONS(3617),
    [anon_sym_orderby] = ACTIONS(3617),
    [anon_sym_ascending] = ACTIONS(3617),
    [anon_sym_descending] = ACTIONS(3617),
    [anon_sym_group] = ACTIONS(3617),
    [anon_sym_by] = ACTIONS(3617),
    [anon_sym_select] = ACTIONS(3617),
    [anon_sym_stackalloc] = ACTIONS(3617),
    [anon_sym_sizeof] = ACTIONS(3617),
    [anon_sym_typeof] = ACTIONS(3617),
    [anon_sym___makeref] = ACTIONS(3617),
    [anon_sym___reftype] = ACTIONS(3617),
    [anon_sym___refvalue] = ACTIONS(3617),
    [sym_null_literal] = ACTIONS(3617),
    [anon_sym_SQUOTE] = ACTIONS(3619),
    [sym_integer_literal] = ACTIONS(3617),
    [sym_real_literal] = ACTIONS(3619),
    [anon_sym_DQUOTE] = ACTIONS(3619),
    [sym_verbatim_string_literal] = ACTIONS(3619),
    [aux_sym_preproc_if_token1] = ACTIONS(3619),
    [aux_sym_preproc_if_token3] = ACTIONS(3619),
    [aux_sym_preproc_else_token1] = ACTIONS(3619),
    [aux_sym_preproc_elif_token1] = ACTIONS(3619),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3619),
    [sym_interpolation_verbatim_start] = ACTIONS(3619),
    [sym_interpolation_raw_start] = ACTIONS(3619),
    [sym_raw_string_start] = ACTIONS(3619),
  },
  [2361] = {
    [sym_preproc_region] = STATE(2361),
    [sym_preproc_endregion] = STATE(2361),
    [sym_preproc_line] = STATE(2361),
    [sym_preproc_pragma] = STATE(2361),
    [sym_preproc_nullable] = STATE(2361),
    [sym_preproc_error] = STATE(2361),
    [sym_preproc_warning] = STATE(2361),
    [sym_preproc_define] = STATE(2361),
    [sym_preproc_undef] = STATE(2361),
    [sym__identifier_token] = ACTIONS(3621),
    [anon_sym_extern] = ACTIONS(3621),
    [anon_sym_alias] = ACTIONS(3621),
    [anon_sym_SEMI] = ACTIONS(3623),
    [anon_sym_global] = ACTIONS(3621),
    [anon_sym_using] = ACTIONS(3621),
    [anon_sym_unsafe] = ACTIONS(3621),
    [anon_sym_static] = ACTIONS(3621),
    [anon_sym_LBRACK] = ACTIONS(3623),
    [anon_sym_LPAREN] = ACTIONS(3623),
    [anon_sym_return] = ACTIONS(3621),
    [anon_sym_namespace] = ACTIONS(3621),
    [anon_sym_class] = ACTIONS(3621),
    [anon_sym_ref] = ACTIONS(3621),
    [anon_sym_struct] = ACTIONS(3621),
    [anon_sym_enum] = ACTIONS(3621),
    [anon_sym_LBRACE] = ACTIONS(3623),
    [anon_sym_interface] = ACTIONS(3621),
    [anon_sym_delegate] = ACTIONS(3621),
    [anon_sym_record] = ACTIONS(3621),
    [anon_sym_abstract] = ACTIONS(3621),
    [anon_sym_async] = ACTIONS(3621),
    [anon_sym_const] = ACTIONS(3621),
    [anon_sym_file] = ACTIONS(3621),
    [anon_sym_fixed] = ACTIONS(3621),
    [anon_sym_internal] = ACTIONS(3621),
    [anon_sym_new] = ACTIONS(3621),
    [anon_sym_override] = ACTIONS(3621),
    [anon_sym_partial] = ACTIONS(3621),
    [anon_sym_private] = ACTIONS(3621),
    [anon_sym_protected] = ACTIONS(3621),
    [anon_sym_public] = ACTIONS(3621),
    [anon_sym_readonly] = ACTIONS(3621),
    [anon_sym_required] = ACTIONS(3621),
    [anon_sym_sealed] = ACTIONS(3621),
    [anon_sym_virtual] = ACTIONS(3621),
    [anon_sym_volatile] = ACTIONS(3621),
    [anon_sym_where] = ACTIONS(3621),
    [anon_sym_notnull] = ACTIONS(3621),
    [anon_sym_unmanaged] = ACTIONS(3621),
    [anon_sym_checked] = ACTIONS(3621),
    [anon_sym_BANG] = ACTIONS(3623),
    [anon_sym_TILDE] = ACTIONS(3623),
    [anon_sym_PLUS_PLUS] = ACTIONS(3623),
    [anon_sym_DASH_DASH] = ACTIONS(3623),
    [anon_sym_true] = ACTIONS(3621),
    [anon_sym_false] = ACTIONS(3621),
    [anon_sym_PLUS] = ACTIONS(3621),
    [anon_sym_DASH] = ACTIONS(3621),
    [anon_sym_STAR] = ACTIONS(3623),
    [anon_sym_CARET] = ACTIONS(3623),
    [anon_sym_AMP] = ACTIONS(3623),
    [anon_sym_this] = ACTIONS(3621),
    [anon_sym_scoped] = ACTIONS(3621),
    [anon_sym_base] = ACTIONS(3621),
    [anon_sym_var] = ACTIONS(3621),
    [sym_predefined_type] = ACTIONS(3621),
    [anon_sym_break] = ACTIONS(3621),
    [anon_sym_unchecked] = ACTIONS(3621),
    [anon_sym_continue] = ACTIONS(3621),
    [anon_sym_do] = ACTIONS(3621),
    [anon_sym_while] = ACTIONS(3621),
    [anon_sym_for] = ACTIONS(3621),
    [anon_sym_lock] = ACTIONS(3621),
    [anon_sym_yield] = ACTIONS(3621),
    [anon_sym_switch] = ACTIONS(3621),
    [anon_sym_default] = ACTIONS(3621),
    [anon_sym_throw] = ACTIONS(3621),
    [anon_sym_try] = ACTIONS(3621),
    [anon_sym_when] = ACTIONS(3621),
    [anon_sym_await] = ACTIONS(3621),
    [anon_sym_foreach] = ACTIONS(3621),
    [anon_sym_goto] = ACTIONS(3621),
    [anon_sym_if] = ACTIONS(3621),
    [anon_sym_DOT_DOT] = ACTIONS(3623),
    [anon_sym_from] = ACTIONS(3621),
    [anon_sym_into] = ACTIONS(3621),
    [anon_sym_join] = ACTIONS(3621),
    [anon_sym_on] = ACTIONS(3621),
    [anon_sym_equals] = ACTIONS(3621),
    [anon_sym_let] = ACTIONS(3621),
    [anon_sym_orderby] = ACTIONS(3621),
    [anon_sym_ascending] = ACTIONS(3621),
    [anon_sym_descending] = ACTIONS(3621),
    [anon_sym_group] = ACTIONS(3621),
    [anon_sym_by] = ACTIONS(3621),
    [anon_sym_select] = ACTIONS(3621),
    [anon_sym_stackalloc] = ACTIONS(3621),
    [anon_sym_sizeof] = ACTIONS(3621),
    [anon_sym_typeof] = ACTIONS(3621),
    [anon_sym___makeref] = ACTIONS(3621),
    [anon_sym___reftype] = ACTIONS(3621),
    [anon_sym___refvalue] = ACTIONS(3621),
    [sym_null_literal] = ACTIONS(3621),
    [anon_sym_SQUOTE] = ACTIONS(3623),
    [sym_integer_literal] = ACTIONS(3621),
    [sym_real_literal] = ACTIONS(3623),
    [anon_sym_DQUOTE] = ACTIONS(3623),
    [sym_verbatim_string_literal] = ACTIONS(3623),
    [aux_sym_preproc_if_token1] = ACTIONS(3623),
    [aux_sym_preproc_if_token3] = ACTIONS(3623),
    [aux_sym_preproc_else_token1] = ACTIONS(3623),
    [aux_sym_preproc_elif_token1] = ACTIONS(3623),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3623),
    [sym_interpolation_verbatim_start] = ACTIONS(3623),
    [sym_interpolation_raw_start] = ACTIONS(3623),
    [sym_raw_string_start] = ACTIONS(3623),
  },
  [2362] = {
    [sym_preproc_region] = STATE(2362),
    [sym_preproc_endregion] = STATE(2362),
    [sym_preproc_line] = STATE(2362),
    [sym_preproc_pragma] = STATE(2362),
    [sym_preproc_nullable] = STATE(2362),
    [sym_preproc_error] = STATE(2362),
    [sym_preproc_warning] = STATE(2362),
    [sym_preproc_define] = STATE(2362),
    [sym_preproc_undef] = STATE(2362),
    [sym__identifier_token] = ACTIONS(3625),
    [anon_sym_extern] = ACTIONS(3625),
    [anon_sym_alias] = ACTIONS(3625),
    [anon_sym_SEMI] = ACTIONS(3627),
    [anon_sym_global] = ACTIONS(3625),
    [anon_sym_using] = ACTIONS(3625),
    [anon_sym_unsafe] = ACTIONS(3625),
    [anon_sym_static] = ACTIONS(3625),
    [anon_sym_LBRACK] = ACTIONS(3627),
    [anon_sym_LPAREN] = ACTIONS(3627),
    [anon_sym_return] = ACTIONS(3625),
    [anon_sym_namespace] = ACTIONS(3625),
    [anon_sym_class] = ACTIONS(3625),
    [anon_sym_ref] = ACTIONS(3625),
    [anon_sym_struct] = ACTIONS(3625),
    [anon_sym_enum] = ACTIONS(3625),
    [anon_sym_LBRACE] = ACTIONS(3627),
    [anon_sym_interface] = ACTIONS(3625),
    [anon_sym_delegate] = ACTIONS(3625),
    [anon_sym_record] = ACTIONS(3625),
    [anon_sym_abstract] = ACTIONS(3625),
    [anon_sym_async] = ACTIONS(3625),
    [anon_sym_const] = ACTIONS(3625),
    [anon_sym_file] = ACTIONS(3625),
    [anon_sym_fixed] = ACTIONS(3625),
    [anon_sym_internal] = ACTIONS(3625),
    [anon_sym_new] = ACTIONS(3625),
    [anon_sym_override] = ACTIONS(3625),
    [anon_sym_partial] = ACTIONS(3625),
    [anon_sym_private] = ACTIONS(3625),
    [anon_sym_protected] = ACTIONS(3625),
    [anon_sym_public] = ACTIONS(3625),
    [anon_sym_readonly] = ACTIONS(3625),
    [anon_sym_required] = ACTIONS(3625),
    [anon_sym_sealed] = ACTIONS(3625),
    [anon_sym_virtual] = ACTIONS(3625),
    [anon_sym_volatile] = ACTIONS(3625),
    [anon_sym_where] = ACTIONS(3625),
    [anon_sym_notnull] = ACTIONS(3625),
    [anon_sym_unmanaged] = ACTIONS(3625),
    [anon_sym_checked] = ACTIONS(3625),
    [anon_sym_BANG] = ACTIONS(3627),
    [anon_sym_TILDE] = ACTIONS(3627),
    [anon_sym_PLUS_PLUS] = ACTIONS(3627),
    [anon_sym_DASH_DASH] = ACTIONS(3627),
    [anon_sym_true] = ACTIONS(3625),
    [anon_sym_false] = ACTIONS(3625),
    [anon_sym_PLUS] = ACTIONS(3625),
    [anon_sym_DASH] = ACTIONS(3625),
    [anon_sym_STAR] = ACTIONS(3627),
    [anon_sym_CARET] = ACTIONS(3627),
    [anon_sym_AMP] = ACTIONS(3627),
    [anon_sym_this] = ACTIONS(3625),
    [anon_sym_scoped] = ACTIONS(3625),
    [anon_sym_base] = ACTIONS(3625),
    [anon_sym_var] = ACTIONS(3625),
    [sym_predefined_type] = ACTIONS(3625),
    [anon_sym_break] = ACTIONS(3625),
    [anon_sym_unchecked] = ACTIONS(3625),
    [anon_sym_continue] = ACTIONS(3625),
    [anon_sym_do] = ACTIONS(3625),
    [anon_sym_while] = ACTIONS(3625),
    [anon_sym_for] = ACTIONS(3625),
    [anon_sym_lock] = ACTIONS(3625),
    [anon_sym_yield] = ACTIONS(3625),
    [anon_sym_switch] = ACTIONS(3625),
    [anon_sym_default] = ACTIONS(3625),
    [anon_sym_throw] = ACTIONS(3625),
    [anon_sym_try] = ACTIONS(3625),
    [anon_sym_when] = ACTIONS(3625),
    [anon_sym_await] = ACTIONS(3625),
    [anon_sym_foreach] = ACTIONS(3625),
    [anon_sym_goto] = ACTIONS(3625),
    [anon_sym_if] = ACTIONS(3625),
    [anon_sym_DOT_DOT] = ACTIONS(3627),
    [anon_sym_from] = ACTIONS(3625),
    [anon_sym_into] = ACTIONS(3625),
    [anon_sym_join] = ACTIONS(3625),
    [anon_sym_on] = ACTIONS(3625),
    [anon_sym_equals] = ACTIONS(3625),
    [anon_sym_let] = ACTIONS(3625),
    [anon_sym_orderby] = ACTIONS(3625),
    [anon_sym_ascending] = ACTIONS(3625),
    [anon_sym_descending] = ACTIONS(3625),
    [anon_sym_group] = ACTIONS(3625),
    [anon_sym_by] = ACTIONS(3625),
    [anon_sym_select] = ACTIONS(3625),
    [anon_sym_stackalloc] = ACTIONS(3625),
    [anon_sym_sizeof] = ACTIONS(3625),
    [anon_sym_typeof] = ACTIONS(3625),
    [anon_sym___makeref] = ACTIONS(3625),
    [anon_sym___reftype] = ACTIONS(3625),
    [anon_sym___refvalue] = ACTIONS(3625),
    [sym_null_literal] = ACTIONS(3625),
    [anon_sym_SQUOTE] = ACTIONS(3627),
    [sym_integer_literal] = ACTIONS(3625),
    [sym_real_literal] = ACTIONS(3627),
    [anon_sym_DQUOTE] = ACTIONS(3627),
    [sym_verbatim_string_literal] = ACTIONS(3627),
    [aux_sym_preproc_if_token1] = ACTIONS(3627),
    [aux_sym_preproc_if_token3] = ACTIONS(3627),
    [aux_sym_preproc_else_token1] = ACTIONS(3627),
    [aux_sym_preproc_elif_token1] = ACTIONS(3627),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3627),
    [sym_interpolation_verbatim_start] = ACTIONS(3627),
    [sym_interpolation_raw_start] = ACTIONS(3627),
    [sym_raw_string_start] = ACTIONS(3627),
  },
  [2363] = {
    [sym_preproc_region] = STATE(2363),
    [sym_preproc_endregion] = STATE(2363),
    [sym_preproc_line] = STATE(2363),
    [sym_preproc_pragma] = STATE(2363),
    [sym_preproc_nullable] = STATE(2363),
    [sym_preproc_error] = STATE(2363),
    [sym_preproc_warning] = STATE(2363),
    [sym_preproc_define] = STATE(2363),
    [sym_preproc_undef] = STATE(2363),
    [sym__identifier_token] = ACTIONS(3629),
    [anon_sym_extern] = ACTIONS(3629),
    [anon_sym_alias] = ACTIONS(3629),
    [anon_sym_SEMI] = ACTIONS(3631),
    [anon_sym_global] = ACTIONS(3629),
    [anon_sym_using] = ACTIONS(3629),
    [anon_sym_unsafe] = ACTIONS(3629),
    [anon_sym_static] = ACTIONS(3629),
    [anon_sym_LBRACK] = ACTIONS(3631),
    [anon_sym_LPAREN] = ACTIONS(3631),
    [anon_sym_return] = ACTIONS(3629),
    [anon_sym_namespace] = ACTIONS(3629),
    [anon_sym_class] = ACTIONS(3629),
    [anon_sym_ref] = ACTIONS(3629),
    [anon_sym_struct] = ACTIONS(3629),
    [anon_sym_enum] = ACTIONS(3629),
    [anon_sym_LBRACE] = ACTIONS(3631),
    [anon_sym_interface] = ACTIONS(3629),
    [anon_sym_delegate] = ACTIONS(3629),
    [anon_sym_record] = ACTIONS(3629),
    [anon_sym_abstract] = ACTIONS(3629),
    [anon_sym_async] = ACTIONS(3629),
    [anon_sym_const] = ACTIONS(3629),
    [anon_sym_file] = ACTIONS(3629),
    [anon_sym_fixed] = ACTIONS(3629),
    [anon_sym_internal] = ACTIONS(3629),
    [anon_sym_new] = ACTIONS(3629),
    [anon_sym_override] = ACTIONS(3629),
    [anon_sym_partial] = ACTIONS(3629),
    [anon_sym_private] = ACTIONS(3629),
    [anon_sym_protected] = ACTIONS(3629),
    [anon_sym_public] = ACTIONS(3629),
    [anon_sym_readonly] = ACTIONS(3629),
    [anon_sym_required] = ACTIONS(3629),
    [anon_sym_sealed] = ACTIONS(3629),
    [anon_sym_virtual] = ACTIONS(3629),
    [anon_sym_volatile] = ACTIONS(3629),
    [anon_sym_where] = ACTIONS(3629),
    [anon_sym_notnull] = ACTIONS(3629),
    [anon_sym_unmanaged] = ACTIONS(3629),
    [anon_sym_checked] = ACTIONS(3629),
    [anon_sym_BANG] = ACTIONS(3631),
    [anon_sym_TILDE] = ACTIONS(3631),
    [anon_sym_PLUS_PLUS] = ACTIONS(3631),
    [anon_sym_DASH_DASH] = ACTIONS(3631),
    [anon_sym_true] = ACTIONS(3629),
    [anon_sym_false] = ACTIONS(3629),
    [anon_sym_PLUS] = ACTIONS(3629),
    [anon_sym_DASH] = ACTIONS(3629),
    [anon_sym_STAR] = ACTIONS(3631),
    [anon_sym_CARET] = ACTIONS(3631),
    [anon_sym_AMP] = ACTIONS(3631),
    [anon_sym_this] = ACTIONS(3629),
    [anon_sym_scoped] = ACTIONS(3629),
    [anon_sym_base] = ACTIONS(3629),
    [anon_sym_var] = ACTIONS(3629),
    [sym_predefined_type] = ACTIONS(3629),
    [anon_sym_break] = ACTIONS(3629),
    [anon_sym_unchecked] = ACTIONS(3629),
    [anon_sym_continue] = ACTIONS(3629),
    [anon_sym_do] = ACTIONS(3629),
    [anon_sym_while] = ACTIONS(3629),
    [anon_sym_for] = ACTIONS(3629),
    [anon_sym_lock] = ACTIONS(3629),
    [anon_sym_yield] = ACTIONS(3629),
    [anon_sym_switch] = ACTIONS(3629),
    [anon_sym_default] = ACTIONS(3629),
    [anon_sym_throw] = ACTIONS(3629),
    [anon_sym_try] = ACTIONS(3629),
    [anon_sym_when] = ACTIONS(3629),
    [anon_sym_await] = ACTIONS(3629),
    [anon_sym_foreach] = ACTIONS(3629),
    [anon_sym_goto] = ACTIONS(3629),
    [anon_sym_if] = ACTIONS(3629),
    [anon_sym_DOT_DOT] = ACTIONS(3631),
    [anon_sym_from] = ACTIONS(3629),
    [anon_sym_into] = ACTIONS(3629),
    [anon_sym_join] = ACTIONS(3629),
    [anon_sym_on] = ACTIONS(3629),
    [anon_sym_equals] = ACTIONS(3629),
    [anon_sym_let] = ACTIONS(3629),
    [anon_sym_orderby] = ACTIONS(3629),
    [anon_sym_ascending] = ACTIONS(3629),
    [anon_sym_descending] = ACTIONS(3629),
    [anon_sym_group] = ACTIONS(3629),
    [anon_sym_by] = ACTIONS(3629),
    [anon_sym_select] = ACTIONS(3629),
    [anon_sym_stackalloc] = ACTIONS(3629),
    [anon_sym_sizeof] = ACTIONS(3629),
    [anon_sym_typeof] = ACTIONS(3629),
    [anon_sym___makeref] = ACTIONS(3629),
    [anon_sym___reftype] = ACTIONS(3629),
    [anon_sym___refvalue] = ACTIONS(3629),
    [sym_null_literal] = ACTIONS(3629),
    [anon_sym_SQUOTE] = ACTIONS(3631),
    [sym_integer_literal] = ACTIONS(3629),
    [sym_real_literal] = ACTIONS(3631),
    [anon_sym_DQUOTE] = ACTIONS(3631),
    [sym_verbatim_string_literal] = ACTIONS(3631),
    [aux_sym_preproc_if_token1] = ACTIONS(3631),
    [aux_sym_preproc_if_token3] = ACTIONS(3631),
    [aux_sym_preproc_else_token1] = ACTIONS(3631),
    [aux_sym_preproc_elif_token1] = ACTIONS(3631),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3631),
    [sym_interpolation_verbatim_start] = ACTIONS(3631),
    [sym_interpolation_raw_start] = ACTIONS(3631),
    [sym_raw_string_start] = ACTIONS(3631),
  },
  [2364] = {
    [sym_preproc_region] = STATE(2364),
    [sym_preproc_endregion] = STATE(2364),
    [sym_preproc_line] = STATE(2364),
    [sym_preproc_pragma] = STATE(2364),
    [sym_preproc_nullable] = STATE(2364),
    [sym_preproc_error] = STATE(2364),
    [sym_preproc_warning] = STATE(2364),
    [sym_preproc_define] = STATE(2364),
    [sym_preproc_undef] = STATE(2364),
    [sym__identifier_token] = ACTIONS(3633),
    [anon_sym_extern] = ACTIONS(3633),
    [anon_sym_alias] = ACTIONS(3633),
    [anon_sym_SEMI] = ACTIONS(3635),
    [anon_sym_global] = ACTIONS(3633),
    [anon_sym_using] = ACTIONS(3633),
    [anon_sym_unsafe] = ACTIONS(3633),
    [anon_sym_static] = ACTIONS(3633),
    [anon_sym_LBRACK] = ACTIONS(3635),
    [anon_sym_LPAREN] = ACTIONS(3635),
    [anon_sym_return] = ACTIONS(3633),
    [anon_sym_namespace] = ACTIONS(3633),
    [anon_sym_class] = ACTIONS(3633),
    [anon_sym_ref] = ACTIONS(3633),
    [anon_sym_struct] = ACTIONS(3633),
    [anon_sym_enum] = ACTIONS(3633),
    [anon_sym_LBRACE] = ACTIONS(3635),
    [anon_sym_interface] = ACTIONS(3633),
    [anon_sym_delegate] = ACTIONS(3633),
    [anon_sym_record] = ACTIONS(3633),
    [anon_sym_abstract] = ACTIONS(3633),
    [anon_sym_async] = ACTIONS(3633),
    [anon_sym_const] = ACTIONS(3633),
    [anon_sym_file] = ACTIONS(3633),
    [anon_sym_fixed] = ACTIONS(3633),
    [anon_sym_internal] = ACTIONS(3633),
    [anon_sym_new] = ACTIONS(3633),
    [anon_sym_override] = ACTIONS(3633),
    [anon_sym_partial] = ACTIONS(3633),
    [anon_sym_private] = ACTIONS(3633),
    [anon_sym_protected] = ACTIONS(3633),
    [anon_sym_public] = ACTIONS(3633),
    [anon_sym_readonly] = ACTIONS(3633),
    [anon_sym_required] = ACTIONS(3633),
    [anon_sym_sealed] = ACTIONS(3633),
    [anon_sym_virtual] = ACTIONS(3633),
    [anon_sym_volatile] = ACTIONS(3633),
    [anon_sym_where] = ACTIONS(3633),
    [anon_sym_notnull] = ACTIONS(3633),
    [anon_sym_unmanaged] = ACTIONS(3633),
    [anon_sym_checked] = ACTIONS(3633),
    [anon_sym_BANG] = ACTIONS(3635),
    [anon_sym_TILDE] = ACTIONS(3635),
    [anon_sym_PLUS_PLUS] = ACTIONS(3635),
    [anon_sym_DASH_DASH] = ACTIONS(3635),
    [anon_sym_true] = ACTIONS(3633),
    [anon_sym_false] = ACTIONS(3633),
    [anon_sym_PLUS] = ACTIONS(3633),
    [anon_sym_DASH] = ACTIONS(3633),
    [anon_sym_STAR] = ACTIONS(3635),
    [anon_sym_CARET] = ACTIONS(3635),
    [anon_sym_AMP] = ACTIONS(3635),
    [anon_sym_this] = ACTIONS(3633),
    [anon_sym_scoped] = ACTIONS(3633),
    [anon_sym_base] = ACTIONS(3633),
    [anon_sym_var] = ACTIONS(3633),
    [sym_predefined_type] = ACTIONS(3633),
    [anon_sym_break] = ACTIONS(3633),
    [anon_sym_unchecked] = ACTIONS(3633),
    [anon_sym_continue] = ACTIONS(3633),
    [anon_sym_do] = ACTIONS(3633),
    [anon_sym_while] = ACTIONS(3633),
    [anon_sym_for] = ACTIONS(3633),
    [anon_sym_lock] = ACTIONS(3633),
    [anon_sym_yield] = ACTIONS(3633),
    [anon_sym_switch] = ACTIONS(3633),
    [anon_sym_default] = ACTIONS(3633),
    [anon_sym_throw] = ACTIONS(3633),
    [anon_sym_try] = ACTIONS(3633),
    [anon_sym_when] = ACTIONS(3633),
    [anon_sym_await] = ACTIONS(3633),
    [anon_sym_foreach] = ACTIONS(3633),
    [anon_sym_goto] = ACTIONS(3633),
    [anon_sym_if] = ACTIONS(3633),
    [anon_sym_DOT_DOT] = ACTIONS(3635),
    [anon_sym_from] = ACTIONS(3633),
    [anon_sym_into] = ACTIONS(3633),
    [anon_sym_join] = ACTIONS(3633),
    [anon_sym_on] = ACTIONS(3633),
    [anon_sym_equals] = ACTIONS(3633),
    [anon_sym_let] = ACTIONS(3633),
    [anon_sym_orderby] = ACTIONS(3633),
    [anon_sym_ascending] = ACTIONS(3633),
    [anon_sym_descending] = ACTIONS(3633),
    [anon_sym_group] = ACTIONS(3633),
    [anon_sym_by] = ACTIONS(3633),
    [anon_sym_select] = ACTIONS(3633),
    [anon_sym_stackalloc] = ACTIONS(3633),
    [anon_sym_sizeof] = ACTIONS(3633),
    [anon_sym_typeof] = ACTIONS(3633),
    [anon_sym___makeref] = ACTIONS(3633),
    [anon_sym___reftype] = ACTIONS(3633),
    [anon_sym___refvalue] = ACTIONS(3633),
    [sym_null_literal] = ACTIONS(3633),
    [anon_sym_SQUOTE] = ACTIONS(3635),
    [sym_integer_literal] = ACTIONS(3633),
    [sym_real_literal] = ACTIONS(3635),
    [anon_sym_DQUOTE] = ACTIONS(3635),
    [sym_verbatim_string_literal] = ACTIONS(3635),
    [aux_sym_preproc_if_token1] = ACTIONS(3635),
    [aux_sym_preproc_if_token3] = ACTIONS(3635),
    [aux_sym_preproc_else_token1] = ACTIONS(3635),
    [aux_sym_preproc_elif_token1] = ACTIONS(3635),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3635),
    [sym_interpolation_verbatim_start] = ACTIONS(3635),
    [sym_interpolation_raw_start] = ACTIONS(3635),
    [sym_raw_string_start] = ACTIONS(3635),
  },
  [2365] = {
    [sym_preproc_region] = STATE(2365),
    [sym_preproc_endregion] = STATE(2365),
    [sym_preproc_line] = STATE(2365),
    [sym_preproc_pragma] = STATE(2365),
    [sym_preproc_nullable] = STATE(2365),
    [sym_preproc_error] = STATE(2365),
    [sym_preproc_warning] = STATE(2365),
    [sym_preproc_define] = STATE(2365),
    [sym_preproc_undef] = STATE(2365),
    [sym__identifier_token] = ACTIONS(3637),
    [anon_sym_extern] = ACTIONS(3637),
    [anon_sym_alias] = ACTIONS(3637),
    [anon_sym_SEMI] = ACTIONS(3639),
    [anon_sym_global] = ACTIONS(3637),
    [anon_sym_using] = ACTIONS(3637),
    [anon_sym_unsafe] = ACTIONS(3637),
    [anon_sym_static] = ACTIONS(3637),
    [anon_sym_LBRACK] = ACTIONS(3639),
    [anon_sym_LPAREN] = ACTIONS(3639),
    [anon_sym_return] = ACTIONS(3637),
    [anon_sym_namespace] = ACTIONS(3637),
    [anon_sym_class] = ACTIONS(3637),
    [anon_sym_ref] = ACTIONS(3637),
    [anon_sym_struct] = ACTIONS(3637),
    [anon_sym_enum] = ACTIONS(3637),
    [anon_sym_LBRACE] = ACTIONS(3639),
    [anon_sym_interface] = ACTIONS(3637),
    [anon_sym_delegate] = ACTIONS(3637),
    [anon_sym_record] = ACTIONS(3637),
    [anon_sym_abstract] = ACTIONS(3637),
    [anon_sym_async] = ACTIONS(3637),
    [anon_sym_const] = ACTIONS(3637),
    [anon_sym_file] = ACTIONS(3637),
    [anon_sym_fixed] = ACTIONS(3637),
    [anon_sym_internal] = ACTIONS(3637),
    [anon_sym_new] = ACTIONS(3637),
    [anon_sym_override] = ACTIONS(3637),
    [anon_sym_partial] = ACTIONS(3637),
    [anon_sym_private] = ACTIONS(3637),
    [anon_sym_protected] = ACTIONS(3637),
    [anon_sym_public] = ACTIONS(3637),
    [anon_sym_readonly] = ACTIONS(3637),
    [anon_sym_required] = ACTIONS(3637),
    [anon_sym_sealed] = ACTIONS(3637),
    [anon_sym_virtual] = ACTIONS(3637),
    [anon_sym_volatile] = ACTIONS(3637),
    [anon_sym_where] = ACTIONS(3637),
    [anon_sym_notnull] = ACTIONS(3637),
    [anon_sym_unmanaged] = ACTIONS(3637),
    [anon_sym_checked] = ACTIONS(3637),
    [anon_sym_BANG] = ACTIONS(3639),
    [anon_sym_TILDE] = ACTIONS(3639),
    [anon_sym_PLUS_PLUS] = ACTIONS(3639),
    [anon_sym_DASH_DASH] = ACTIONS(3639),
    [anon_sym_true] = ACTIONS(3637),
    [anon_sym_false] = ACTIONS(3637),
    [anon_sym_PLUS] = ACTIONS(3637),
    [anon_sym_DASH] = ACTIONS(3637),
    [anon_sym_STAR] = ACTIONS(3639),
    [anon_sym_CARET] = ACTIONS(3639),
    [anon_sym_AMP] = ACTIONS(3639),
    [anon_sym_this] = ACTIONS(3637),
    [anon_sym_scoped] = ACTIONS(3637),
    [anon_sym_base] = ACTIONS(3637),
    [anon_sym_var] = ACTIONS(3637),
    [sym_predefined_type] = ACTIONS(3637),
    [anon_sym_break] = ACTIONS(3637),
    [anon_sym_unchecked] = ACTIONS(3637),
    [anon_sym_continue] = ACTIONS(3637),
    [anon_sym_do] = ACTIONS(3637),
    [anon_sym_while] = ACTIONS(3637),
    [anon_sym_for] = ACTIONS(3637),
    [anon_sym_lock] = ACTIONS(3637),
    [anon_sym_yield] = ACTIONS(3637),
    [anon_sym_switch] = ACTIONS(3637),
    [anon_sym_default] = ACTIONS(3637),
    [anon_sym_throw] = ACTIONS(3637),
    [anon_sym_try] = ACTIONS(3637),
    [anon_sym_when] = ACTIONS(3637),
    [anon_sym_await] = ACTIONS(3637),
    [anon_sym_foreach] = ACTIONS(3637),
    [anon_sym_goto] = ACTIONS(3637),
    [anon_sym_if] = ACTIONS(3637),
    [anon_sym_DOT_DOT] = ACTIONS(3639),
    [anon_sym_from] = ACTIONS(3637),
    [anon_sym_into] = ACTIONS(3637),
    [anon_sym_join] = ACTIONS(3637),
    [anon_sym_on] = ACTIONS(3637),
    [anon_sym_equals] = ACTIONS(3637),
    [anon_sym_let] = ACTIONS(3637),
    [anon_sym_orderby] = ACTIONS(3637),
    [anon_sym_ascending] = ACTIONS(3637),
    [anon_sym_descending] = ACTIONS(3637),
    [anon_sym_group] = ACTIONS(3637),
    [anon_sym_by] = ACTIONS(3637),
    [anon_sym_select] = ACTIONS(3637),
    [anon_sym_stackalloc] = ACTIONS(3637),
    [anon_sym_sizeof] = ACTIONS(3637),
    [anon_sym_typeof] = ACTIONS(3637),
    [anon_sym___makeref] = ACTIONS(3637),
    [anon_sym___reftype] = ACTIONS(3637),
    [anon_sym___refvalue] = ACTIONS(3637),
    [sym_null_literal] = ACTIONS(3637),
    [anon_sym_SQUOTE] = ACTIONS(3639),
    [sym_integer_literal] = ACTIONS(3637),
    [sym_real_literal] = ACTIONS(3639),
    [anon_sym_DQUOTE] = ACTIONS(3639),
    [sym_verbatim_string_literal] = ACTIONS(3639),
    [aux_sym_preproc_if_token1] = ACTIONS(3639),
    [aux_sym_preproc_if_token3] = ACTIONS(3639),
    [aux_sym_preproc_else_token1] = ACTIONS(3639),
    [aux_sym_preproc_elif_token1] = ACTIONS(3639),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3639),
    [sym_interpolation_verbatim_start] = ACTIONS(3639),
    [sym_interpolation_raw_start] = ACTIONS(3639),
    [sym_raw_string_start] = ACTIONS(3639),
  },
  [2366] = {
    [sym_preproc_region] = STATE(2366),
    [sym_preproc_endregion] = STATE(2366),
    [sym_preproc_line] = STATE(2366),
    [sym_preproc_pragma] = STATE(2366),
    [sym_preproc_nullable] = STATE(2366),
    [sym_preproc_error] = STATE(2366),
    [sym_preproc_warning] = STATE(2366),
    [sym_preproc_define] = STATE(2366),
    [sym_preproc_undef] = STATE(2366),
    [sym__identifier_token] = ACTIONS(3641),
    [anon_sym_extern] = ACTIONS(3641),
    [anon_sym_alias] = ACTIONS(3641),
    [anon_sym_SEMI] = ACTIONS(3643),
    [anon_sym_global] = ACTIONS(3641),
    [anon_sym_using] = ACTIONS(3641),
    [anon_sym_unsafe] = ACTIONS(3641),
    [anon_sym_static] = ACTIONS(3641),
    [anon_sym_LBRACK] = ACTIONS(3643),
    [anon_sym_LPAREN] = ACTIONS(3643),
    [anon_sym_return] = ACTIONS(3641),
    [anon_sym_namespace] = ACTIONS(3641),
    [anon_sym_class] = ACTIONS(3641),
    [anon_sym_ref] = ACTIONS(3641),
    [anon_sym_struct] = ACTIONS(3641),
    [anon_sym_enum] = ACTIONS(3641),
    [anon_sym_LBRACE] = ACTIONS(3643),
    [anon_sym_interface] = ACTIONS(3641),
    [anon_sym_delegate] = ACTIONS(3641),
    [anon_sym_record] = ACTIONS(3641),
    [anon_sym_abstract] = ACTIONS(3641),
    [anon_sym_async] = ACTIONS(3641),
    [anon_sym_const] = ACTIONS(3641),
    [anon_sym_file] = ACTIONS(3641),
    [anon_sym_fixed] = ACTIONS(3641),
    [anon_sym_internal] = ACTIONS(3641),
    [anon_sym_new] = ACTIONS(3641),
    [anon_sym_override] = ACTIONS(3641),
    [anon_sym_partial] = ACTIONS(3641),
    [anon_sym_private] = ACTIONS(3641),
    [anon_sym_protected] = ACTIONS(3641),
    [anon_sym_public] = ACTIONS(3641),
    [anon_sym_readonly] = ACTIONS(3641),
    [anon_sym_required] = ACTIONS(3641),
    [anon_sym_sealed] = ACTIONS(3641),
    [anon_sym_virtual] = ACTIONS(3641),
    [anon_sym_volatile] = ACTIONS(3641),
    [anon_sym_where] = ACTIONS(3641),
    [anon_sym_notnull] = ACTIONS(3641),
    [anon_sym_unmanaged] = ACTIONS(3641),
    [anon_sym_checked] = ACTIONS(3641),
    [anon_sym_BANG] = ACTIONS(3643),
    [anon_sym_TILDE] = ACTIONS(3643),
    [anon_sym_PLUS_PLUS] = ACTIONS(3643),
    [anon_sym_DASH_DASH] = ACTIONS(3643),
    [anon_sym_true] = ACTIONS(3641),
    [anon_sym_false] = ACTIONS(3641),
    [anon_sym_PLUS] = ACTIONS(3641),
    [anon_sym_DASH] = ACTIONS(3641),
    [anon_sym_STAR] = ACTIONS(3643),
    [anon_sym_CARET] = ACTIONS(3643),
    [anon_sym_AMP] = ACTIONS(3643),
    [anon_sym_this] = ACTIONS(3641),
    [anon_sym_scoped] = ACTIONS(3641),
    [anon_sym_base] = ACTIONS(3641),
    [anon_sym_var] = ACTIONS(3641),
    [sym_predefined_type] = ACTIONS(3641),
    [anon_sym_break] = ACTIONS(3641),
    [anon_sym_unchecked] = ACTIONS(3641),
    [anon_sym_continue] = ACTIONS(3641),
    [anon_sym_do] = ACTIONS(3641),
    [anon_sym_while] = ACTIONS(3641),
    [anon_sym_for] = ACTIONS(3641),
    [anon_sym_lock] = ACTIONS(3641),
    [anon_sym_yield] = ACTIONS(3641),
    [anon_sym_switch] = ACTIONS(3641),
    [anon_sym_default] = ACTIONS(3641),
    [anon_sym_throw] = ACTIONS(3641),
    [anon_sym_try] = ACTIONS(3641),
    [anon_sym_when] = ACTIONS(3641),
    [anon_sym_await] = ACTIONS(3641),
    [anon_sym_foreach] = ACTIONS(3641),
    [anon_sym_goto] = ACTIONS(3641),
    [anon_sym_if] = ACTIONS(3641),
    [anon_sym_DOT_DOT] = ACTIONS(3643),
    [anon_sym_from] = ACTIONS(3641),
    [anon_sym_into] = ACTIONS(3641),
    [anon_sym_join] = ACTIONS(3641),
    [anon_sym_on] = ACTIONS(3641),
    [anon_sym_equals] = ACTIONS(3641),
    [anon_sym_let] = ACTIONS(3641),
    [anon_sym_orderby] = ACTIONS(3641),
    [anon_sym_ascending] = ACTIONS(3641),
    [anon_sym_descending] = ACTIONS(3641),
    [anon_sym_group] = ACTIONS(3641),
    [anon_sym_by] = ACTIONS(3641),
    [anon_sym_select] = ACTIONS(3641),
    [anon_sym_stackalloc] = ACTIONS(3641),
    [anon_sym_sizeof] = ACTIONS(3641),
    [anon_sym_typeof] = ACTIONS(3641),
    [anon_sym___makeref] = ACTIONS(3641),
    [anon_sym___reftype] = ACTIONS(3641),
    [anon_sym___refvalue] = ACTIONS(3641),
    [sym_null_literal] = ACTIONS(3641),
    [anon_sym_SQUOTE] = ACTIONS(3643),
    [sym_integer_literal] = ACTIONS(3641),
    [sym_real_literal] = ACTIONS(3643),
    [anon_sym_DQUOTE] = ACTIONS(3643),
    [sym_verbatim_string_literal] = ACTIONS(3643),
    [aux_sym_preproc_if_token1] = ACTIONS(3643),
    [aux_sym_preproc_if_token3] = ACTIONS(3643),
    [aux_sym_preproc_else_token1] = ACTIONS(3643),
    [aux_sym_preproc_elif_token1] = ACTIONS(3643),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3643),
    [sym_interpolation_verbatim_start] = ACTIONS(3643),
    [sym_interpolation_raw_start] = ACTIONS(3643),
    [sym_raw_string_start] = ACTIONS(3643),
  },
  [2367] = {
    [sym_preproc_region] = STATE(2367),
    [sym_preproc_endregion] = STATE(2367),
    [sym_preproc_line] = STATE(2367),
    [sym_preproc_pragma] = STATE(2367),
    [sym_preproc_nullable] = STATE(2367),
    [sym_preproc_error] = STATE(2367),
    [sym_preproc_warning] = STATE(2367),
    [sym_preproc_define] = STATE(2367),
    [sym_preproc_undef] = STATE(2367),
    [sym__identifier_token] = ACTIONS(3645),
    [anon_sym_extern] = ACTIONS(3645),
    [anon_sym_alias] = ACTIONS(3645),
    [anon_sym_SEMI] = ACTIONS(3647),
    [anon_sym_global] = ACTIONS(3645),
    [anon_sym_using] = ACTIONS(3645),
    [anon_sym_unsafe] = ACTIONS(3645),
    [anon_sym_static] = ACTIONS(3645),
    [anon_sym_LBRACK] = ACTIONS(3647),
    [anon_sym_LPAREN] = ACTIONS(3647),
    [anon_sym_return] = ACTIONS(3645),
    [anon_sym_namespace] = ACTIONS(3645),
    [anon_sym_class] = ACTIONS(3645),
    [anon_sym_ref] = ACTIONS(3645),
    [anon_sym_struct] = ACTIONS(3645),
    [anon_sym_enum] = ACTIONS(3645),
    [anon_sym_LBRACE] = ACTIONS(3647),
    [anon_sym_interface] = ACTIONS(3645),
    [anon_sym_delegate] = ACTIONS(3645),
    [anon_sym_record] = ACTIONS(3645),
    [anon_sym_abstract] = ACTIONS(3645),
    [anon_sym_async] = ACTIONS(3645),
    [anon_sym_const] = ACTIONS(3645),
    [anon_sym_file] = ACTIONS(3645),
    [anon_sym_fixed] = ACTIONS(3645),
    [anon_sym_internal] = ACTIONS(3645),
    [anon_sym_new] = ACTIONS(3645),
    [anon_sym_override] = ACTIONS(3645),
    [anon_sym_partial] = ACTIONS(3645),
    [anon_sym_private] = ACTIONS(3645),
    [anon_sym_protected] = ACTIONS(3645),
    [anon_sym_public] = ACTIONS(3645),
    [anon_sym_readonly] = ACTIONS(3645),
    [anon_sym_required] = ACTIONS(3645),
    [anon_sym_sealed] = ACTIONS(3645),
    [anon_sym_virtual] = ACTIONS(3645),
    [anon_sym_volatile] = ACTIONS(3645),
    [anon_sym_where] = ACTIONS(3645),
    [anon_sym_notnull] = ACTIONS(3645),
    [anon_sym_unmanaged] = ACTIONS(3645),
    [anon_sym_checked] = ACTIONS(3645),
    [anon_sym_BANG] = ACTIONS(3647),
    [anon_sym_TILDE] = ACTIONS(3647),
    [anon_sym_PLUS_PLUS] = ACTIONS(3647),
    [anon_sym_DASH_DASH] = ACTIONS(3647),
    [anon_sym_true] = ACTIONS(3645),
    [anon_sym_false] = ACTIONS(3645),
    [anon_sym_PLUS] = ACTIONS(3645),
    [anon_sym_DASH] = ACTIONS(3645),
    [anon_sym_STAR] = ACTIONS(3647),
    [anon_sym_CARET] = ACTIONS(3647),
    [anon_sym_AMP] = ACTIONS(3647),
    [anon_sym_this] = ACTIONS(3645),
    [anon_sym_scoped] = ACTIONS(3645),
    [anon_sym_base] = ACTIONS(3645),
    [anon_sym_var] = ACTIONS(3645),
    [sym_predefined_type] = ACTIONS(3645),
    [anon_sym_break] = ACTIONS(3645),
    [anon_sym_unchecked] = ACTIONS(3645),
    [anon_sym_continue] = ACTIONS(3645),
    [anon_sym_do] = ACTIONS(3645),
    [anon_sym_while] = ACTIONS(3645),
    [anon_sym_for] = ACTIONS(3645),
    [anon_sym_lock] = ACTIONS(3645),
    [anon_sym_yield] = ACTIONS(3645),
    [anon_sym_switch] = ACTIONS(3645),
    [anon_sym_default] = ACTIONS(3645),
    [anon_sym_throw] = ACTIONS(3645),
    [anon_sym_try] = ACTIONS(3645),
    [anon_sym_when] = ACTIONS(3645),
    [anon_sym_await] = ACTIONS(3645),
    [anon_sym_foreach] = ACTIONS(3645),
    [anon_sym_goto] = ACTIONS(3645),
    [anon_sym_if] = ACTIONS(3645),
    [anon_sym_DOT_DOT] = ACTIONS(3647),
    [anon_sym_from] = ACTIONS(3645),
    [anon_sym_into] = ACTIONS(3645),
    [anon_sym_join] = ACTIONS(3645),
    [anon_sym_on] = ACTIONS(3645),
    [anon_sym_equals] = ACTIONS(3645),
    [anon_sym_let] = ACTIONS(3645),
    [anon_sym_orderby] = ACTIONS(3645),
    [anon_sym_ascending] = ACTIONS(3645),
    [anon_sym_descending] = ACTIONS(3645),
    [anon_sym_group] = ACTIONS(3645),
    [anon_sym_by] = ACTIONS(3645),
    [anon_sym_select] = ACTIONS(3645),
    [anon_sym_stackalloc] = ACTIONS(3645),
    [anon_sym_sizeof] = ACTIONS(3645),
    [anon_sym_typeof] = ACTIONS(3645),
    [anon_sym___makeref] = ACTIONS(3645),
    [anon_sym___reftype] = ACTIONS(3645),
    [anon_sym___refvalue] = ACTIONS(3645),
    [sym_null_literal] = ACTIONS(3645),
    [anon_sym_SQUOTE] = ACTIONS(3647),
    [sym_integer_literal] = ACTIONS(3645),
    [sym_real_literal] = ACTIONS(3647),
    [anon_sym_DQUOTE] = ACTIONS(3647),
    [sym_verbatim_string_literal] = ACTIONS(3647),
    [aux_sym_preproc_if_token1] = ACTIONS(3647),
    [aux_sym_preproc_if_token3] = ACTIONS(3647),
    [aux_sym_preproc_else_token1] = ACTIONS(3647),
    [aux_sym_preproc_elif_token1] = ACTIONS(3647),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3647),
    [sym_interpolation_verbatim_start] = ACTIONS(3647),
    [sym_interpolation_raw_start] = ACTIONS(3647),
    [sym_raw_string_start] = ACTIONS(3647),
  },
  [2368] = {
    [sym_preproc_region] = STATE(2368),
    [sym_preproc_endregion] = STATE(2368),
    [sym_preproc_line] = STATE(2368),
    [sym_preproc_pragma] = STATE(2368),
    [sym_preproc_nullable] = STATE(2368),
    [sym_preproc_error] = STATE(2368),
    [sym_preproc_warning] = STATE(2368),
    [sym_preproc_define] = STATE(2368),
    [sym_preproc_undef] = STATE(2368),
    [sym__identifier_token] = ACTIONS(3649),
    [anon_sym_extern] = ACTIONS(3649),
    [anon_sym_alias] = ACTIONS(3649),
    [anon_sym_SEMI] = ACTIONS(3651),
    [anon_sym_global] = ACTIONS(3649),
    [anon_sym_using] = ACTIONS(3649),
    [anon_sym_unsafe] = ACTIONS(3649),
    [anon_sym_static] = ACTIONS(3649),
    [anon_sym_LBRACK] = ACTIONS(3651),
    [anon_sym_LPAREN] = ACTIONS(3651),
    [anon_sym_return] = ACTIONS(3649),
    [anon_sym_namespace] = ACTIONS(3649),
    [anon_sym_class] = ACTIONS(3649),
    [anon_sym_ref] = ACTIONS(3649),
    [anon_sym_struct] = ACTIONS(3649),
    [anon_sym_enum] = ACTIONS(3649),
    [anon_sym_LBRACE] = ACTIONS(3651),
    [anon_sym_interface] = ACTIONS(3649),
    [anon_sym_delegate] = ACTIONS(3649),
    [anon_sym_record] = ACTIONS(3649),
    [anon_sym_abstract] = ACTIONS(3649),
    [anon_sym_async] = ACTIONS(3649),
    [anon_sym_const] = ACTIONS(3649),
    [anon_sym_file] = ACTIONS(3649),
    [anon_sym_fixed] = ACTIONS(3649),
    [anon_sym_internal] = ACTIONS(3649),
    [anon_sym_new] = ACTIONS(3649),
    [anon_sym_override] = ACTIONS(3649),
    [anon_sym_partial] = ACTIONS(3649),
    [anon_sym_private] = ACTIONS(3649),
    [anon_sym_protected] = ACTIONS(3649),
    [anon_sym_public] = ACTIONS(3649),
    [anon_sym_readonly] = ACTIONS(3649),
    [anon_sym_required] = ACTIONS(3649),
    [anon_sym_sealed] = ACTIONS(3649),
    [anon_sym_virtual] = ACTIONS(3649),
    [anon_sym_volatile] = ACTIONS(3649),
    [anon_sym_where] = ACTIONS(3649),
    [anon_sym_notnull] = ACTIONS(3649),
    [anon_sym_unmanaged] = ACTIONS(3649),
    [anon_sym_checked] = ACTIONS(3649),
    [anon_sym_BANG] = ACTIONS(3651),
    [anon_sym_TILDE] = ACTIONS(3651),
    [anon_sym_PLUS_PLUS] = ACTIONS(3651),
    [anon_sym_DASH_DASH] = ACTIONS(3651),
    [anon_sym_true] = ACTIONS(3649),
    [anon_sym_false] = ACTIONS(3649),
    [anon_sym_PLUS] = ACTIONS(3649),
    [anon_sym_DASH] = ACTIONS(3649),
    [anon_sym_STAR] = ACTIONS(3651),
    [anon_sym_CARET] = ACTIONS(3651),
    [anon_sym_AMP] = ACTIONS(3651),
    [anon_sym_this] = ACTIONS(3649),
    [anon_sym_scoped] = ACTIONS(3649),
    [anon_sym_base] = ACTIONS(3649),
    [anon_sym_var] = ACTIONS(3649),
    [sym_predefined_type] = ACTIONS(3649),
    [anon_sym_break] = ACTIONS(3649),
    [anon_sym_unchecked] = ACTIONS(3649),
    [anon_sym_continue] = ACTIONS(3649),
    [anon_sym_do] = ACTIONS(3649),
    [anon_sym_while] = ACTIONS(3649),
    [anon_sym_for] = ACTIONS(3649),
    [anon_sym_lock] = ACTIONS(3649),
    [anon_sym_yield] = ACTIONS(3649),
    [anon_sym_switch] = ACTIONS(3649),
    [anon_sym_default] = ACTIONS(3649),
    [anon_sym_throw] = ACTIONS(3649),
    [anon_sym_try] = ACTIONS(3649),
    [anon_sym_when] = ACTIONS(3649),
    [anon_sym_await] = ACTIONS(3649),
    [anon_sym_foreach] = ACTIONS(3649),
    [anon_sym_goto] = ACTIONS(3649),
    [anon_sym_if] = ACTIONS(3649),
    [anon_sym_DOT_DOT] = ACTIONS(3651),
    [anon_sym_from] = ACTIONS(3649),
    [anon_sym_into] = ACTIONS(3649),
    [anon_sym_join] = ACTIONS(3649),
    [anon_sym_on] = ACTIONS(3649),
    [anon_sym_equals] = ACTIONS(3649),
    [anon_sym_let] = ACTIONS(3649),
    [anon_sym_orderby] = ACTIONS(3649),
    [anon_sym_ascending] = ACTIONS(3649),
    [anon_sym_descending] = ACTIONS(3649),
    [anon_sym_group] = ACTIONS(3649),
    [anon_sym_by] = ACTIONS(3649),
    [anon_sym_select] = ACTIONS(3649),
    [anon_sym_stackalloc] = ACTIONS(3649),
    [anon_sym_sizeof] = ACTIONS(3649),
    [anon_sym_typeof] = ACTIONS(3649),
    [anon_sym___makeref] = ACTIONS(3649),
    [anon_sym___reftype] = ACTIONS(3649),
    [anon_sym___refvalue] = ACTIONS(3649),
    [sym_null_literal] = ACTIONS(3649),
    [anon_sym_SQUOTE] = ACTIONS(3651),
    [sym_integer_literal] = ACTIONS(3649),
    [sym_real_literal] = ACTIONS(3651),
    [anon_sym_DQUOTE] = ACTIONS(3651),
    [sym_verbatim_string_literal] = ACTIONS(3651),
    [aux_sym_preproc_if_token1] = ACTIONS(3651),
    [aux_sym_preproc_if_token3] = ACTIONS(3651),
    [aux_sym_preproc_else_token1] = ACTIONS(3651),
    [aux_sym_preproc_elif_token1] = ACTIONS(3651),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3651),
    [sym_interpolation_verbatim_start] = ACTIONS(3651),
    [sym_interpolation_raw_start] = ACTIONS(3651),
    [sym_raw_string_start] = ACTIONS(3651),
  },
  [2369] = {
    [sym_preproc_region] = STATE(2369),
    [sym_preproc_endregion] = STATE(2369),
    [sym_preproc_line] = STATE(2369),
    [sym_preproc_pragma] = STATE(2369),
    [sym_preproc_nullable] = STATE(2369),
    [sym_preproc_error] = STATE(2369),
    [sym_preproc_warning] = STATE(2369),
    [sym_preproc_define] = STATE(2369),
    [sym_preproc_undef] = STATE(2369),
    [sym__identifier_token] = ACTIONS(3653),
    [anon_sym_extern] = ACTIONS(3653),
    [anon_sym_alias] = ACTIONS(3653),
    [anon_sym_SEMI] = ACTIONS(3655),
    [anon_sym_global] = ACTIONS(3653),
    [anon_sym_using] = ACTIONS(3653),
    [anon_sym_unsafe] = ACTIONS(3653),
    [anon_sym_static] = ACTIONS(3653),
    [anon_sym_LBRACK] = ACTIONS(3655),
    [anon_sym_LPAREN] = ACTIONS(3655),
    [anon_sym_return] = ACTIONS(3653),
    [anon_sym_namespace] = ACTIONS(3653),
    [anon_sym_class] = ACTIONS(3653),
    [anon_sym_ref] = ACTIONS(3653),
    [anon_sym_struct] = ACTIONS(3653),
    [anon_sym_enum] = ACTIONS(3653),
    [anon_sym_LBRACE] = ACTIONS(3655),
    [anon_sym_interface] = ACTIONS(3653),
    [anon_sym_delegate] = ACTIONS(3653),
    [anon_sym_record] = ACTIONS(3653),
    [anon_sym_abstract] = ACTIONS(3653),
    [anon_sym_async] = ACTIONS(3653),
    [anon_sym_const] = ACTIONS(3653),
    [anon_sym_file] = ACTIONS(3653),
    [anon_sym_fixed] = ACTIONS(3653),
    [anon_sym_internal] = ACTIONS(3653),
    [anon_sym_new] = ACTIONS(3653),
    [anon_sym_override] = ACTIONS(3653),
    [anon_sym_partial] = ACTIONS(3653),
    [anon_sym_private] = ACTIONS(3653),
    [anon_sym_protected] = ACTIONS(3653),
    [anon_sym_public] = ACTIONS(3653),
    [anon_sym_readonly] = ACTIONS(3653),
    [anon_sym_required] = ACTIONS(3653),
    [anon_sym_sealed] = ACTIONS(3653),
    [anon_sym_virtual] = ACTIONS(3653),
    [anon_sym_volatile] = ACTIONS(3653),
    [anon_sym_where] = ACTIONS(3653),
    [anon_sym_notnull] = ACTIONS(3653),
    [anon_sym_unmanaged] = ACTIONS(3653),
    [anon_sym_checked] = ACTIONS(3653),
    [anon_sym_BANG] = ACTIONS(3655),
    [anon_sym_TILDE] = ACTIONS(3655),
    [anon_sym_PLUS_PLUS] = ACTIONS(3655),
    [anon_sym_DASH_DASH] = ACTIONS(3655),
    [anon_sym_true] = ACTIONS(3653),
    [anon_sym_false] = ACTIONS(3653),
    [anon_sym_PLUS] = ACTIONS(3653),
    [anon_sym_DASH] = ACTIONS(3653),
    [anon_sym_STAR] = ACTIONS(3655),
    [anon_sym_CARET] = ACTIONS(3655),
    [anon_sym_AMP] = ACTIONS(3655),
    [anon_sym_this] = ACTIONS(3653),
    [anon_sym_scoped] = ACTIONS(3653),
    [anon_sym_base] = ACTIONS(3653),
    [anon_sym_var] = ACTIONS(3653),
    [sym_predefined_type] = ACTIONS(3653),
    [anon_sym_break] = ACTIONS(3653),
    [anon_sym_unchecked] = ACTIONS(3653),
    [anon_sym_continue] = ACTIONS(3653),
    [anon_sym_do] = ACTIONS(3653),
    [anon_sym_while] = ACTIONS(3653),
    [anon_sym_for] = ACTIONS(3653),
    [anon_sym_lock] = ACTIONS(3653),
    [anon_sym_yield] = ACTIONS(3653),
    [anon_sym_switch] = ACTIONS(3653),
    [anon_sym_default] = ACTIONS(3653),
    [anon_sym_throw] = ACTIONS(3653),
    [anon_sym_try] = ACTIONS(3653),
    [anon_sym_when] = ACTIONS(3653),
    [anon_sym_await] = ACTIONS(3653),
    [anon_sym_foreach] = ACTIONS(3653),
    [anon_sym_goto] = ACTIONS(3653),
    [anon_sym_if] = ACTIONS(3653),
    [anon_sym_DOT_DOT] = ACTIONS(3655),
    [anon_sym_from] = ACTIONS(3653),
    [anon_sym_into] = ACTIONS(3653),
    [anon_sym_join] = ACTIONS(3653),
    [anon_sym_on] = ACTIONS(3653),
    [anon_sym_equals] = ACTIONS(3653),
    [anon_sym_let] = ACTIONS(3653),
    [anon_sym_orderby] = ACTIONS(3653),
    [anon_sym_ascending] = ACTIONS(3653),
    [anon_sym_descending] = ACTIONS(3653),
    [anon_sym_group] = ACTIONS(3653),
    [anon_sym_by] = ACTIONS(3653),
    [anon_sym_select] = ACTIONS(3653),
    [anon_sym_stackalloc] = ACTIONS(3653),
    [anon_sym_sizeof] = ACTIONS(3653),
    [anon_sym_typeof] = ACTIONS(3653),
    [anon_sym___makeref] = ACTIONS(3653),
    [anon_sym___reftype] = ACTIONS(3653),
    [anon_sym___refvalue] = ACTIONS(3653),
    [sym_null_literal] = ACTIONS(3653),
    [anon_sym_SQUOTE] = ACTIONS(3655),
    [sym_integer_literal] = ACTIONS(3653),
    [sym_real_literal] = ACTIONS(3655),
    [anon_sym_DQUOTE] = ACTIONS(3655),
    [sym_verbatim_string_literal] = ACTIONS(3655),
    [aux_sym_preproc_if_token1] = ACTIONS(3655),
    [aux_sym_preproc_if_token3] = ACTIONS(3655),
    [aux_sym_preproc_else_token1] = ACTIONS(3655),
    [aux_sym_preproc_elif_token1] = ACTIONS(3655),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3655),
    [sym_interpolation_verbatim_start] = ACTIONS(3655),
    [sym_interpolation_raw_start] = ACTIONS(3655),
    [sym_raw_string_start] = ACTIONS(3655),
  },
  [2370] = {
    [sym_preproc_region] = STATE(2370),
    [sym_preproc_endregion] = STATE(2370),
    [sym_preproc_line] = STATE(2370),
    [sym_preproc_pragma] = STATE(2370),
    [sym_preproc_nullable] = STATE(2370),
    [sym_preproc_error] = STATE(2370),
    [sym_preproc_warning] = STATE(2370),
    [sym_preproc_define] = STATE(2370),
    [sym_preproc_undef] = STATE(2370),
    [sym__identifier_token] = ACTIONS(3657),
    [anon_sym_extern] = ACTIONS(3657),
    [anon_sym_alias] = ACTIONS(3657),
    [anon_sym_SEMI] = ACTIONS(3659),
    [anon_sym_global] = ACTIONS(3657),
    [anon_sym_using] = ACTIONS(3657),
    [anon_sym_unsafe] = ACTIONS(3657),
    [anon_sym_static] = ACTIONS(3657),
    [anon_sym_LBRACK] = ACTIONS(3659),
    [anon_sym_LPAREN] = ACTIONS(3659),
    [anon_sym_return] = ACTIONS(3657),
    [anon_sym_namespace] = ACTIONS(3657),
    [anon_sym_class] = ACTIONS(3657),
    [anon_sym_ref] = ACTIONS(3657),
    [anon_sym_struct] = ACTIONS(3657),
    [anon_sym_enum] = ACTIONS(3657),
    [anon_sym_LBRACE] = ACTIONS(3659),
    [anon_sym_interface] = ACTIONS(3657),
    [anon_sym_delegate] = ACTIONS(3657),
    [anon_sym_record] = ACTIONS(3657),
    [anon_sym_abstract] = ACTIONS(3657),
    [anon_sym_async] = ACTIONS(3657),
    [anon_sym_const] = ACTIONS(3657),
    [anon_sym_file] = ACTIONS(3657),
    [anon_sym_fixed] = ACTIONS(3657),
    [anon_sym_internal] = ACTIONS(3657),
    [anon_sym_new] = ACTIONS(3657),
    [anon_sym_override] = ACTIONS(3657),
    [anon_sym_partial] = ACTIONS(3657),
    [anon_sym_private] = ACTIONS(3657),
    [anon_sym_protected] = ACTIONS(3657),
    [anon_sym_public] = ACTIONS(3657),
    [anon_sym_readonly] = ACTIONS(3657),
    [anon_sym_required] = ACTIONS(3657),
    [anon_sym_sealed] = ACTIONS(3657),
    [anon_sym_virtual] = ACTIONS(3657),
    [anon_sym_volatile] = ACTIONS(3657),
    [anon_sym_where] = ACTIONS(3657),
    [anon_sym_notnull] = ACTIONS(3657),
    [anon_sym_unmanaged] = ACTIONS(3657),
    [anon_sym_checked] = ACTIONS(3657),
    [anon_sym_BANG] = ACTIONS(3659),
    [anon_sym_TILDE] = ACTIONS(3659),
    [anon_sym_PLUS_PLUS] = ACTIONS(3659),
    [anon_sym_DASH_DASH] = ACTIONS(3659),
    [anon_sym_true] = ACTIONS(3657),
    [anon_sym_false] = ACTIONS(3657),
    [anon_sym_PLUS] = ACTIONS(3657),
    [anon_sym_DASH] = ACTIONS(3657),
    [anon_sym_STAR] = ACTIONS(3659),
    [anon_sym_CARET] = ACTIONS(3659),
    [anon_sym_AMP] = ACTIONS(3659),
    [anon_sym_this] = ACTIONS(3657),
    [anon_sym_scoped] = ACTIONS(3657),
    [anon_sym_base] = ACTIONS(3657),
    [anon_sym_var] = ACTIONS(3657),
    [sym_predefined_type] = ACTIONS(3657),
    [anon_sym_break] = ACTIONS(3657),
    [anon_sym_unchecked] = ACTIONS(3657),
    [anon_sym_continue] = ACTIONS(3657),
    [anon_sym_do] = ACTIONS(3657),
    [anon_sym_while] = ACTIONS(3657),
    [anon_sym_for] = ACTIONS(3657),
    [anon_sym_lock] = ACTIONS(3657),
    [anon_sym_yield] = ACTIONS(3657),
    [anon_sym_switch] = ACTIONS(3657),
    [anon_sym_default] = ACTIONS(3657),
    [anon_sym_throw] = ACTIONS(3657),
    [anon_sym_try] = ACTIONS(3657),
    [anon_sym_when] = ACTIONS(3657),
    [anon_sym_await] = ACTIONS(3657),
    [anon_sym_foreach] = ACTIONS(3657),
    [anon_sym_goto] = ACTIONS(3657),
    [anon_sym_if] = ACTIONS(3657),
    [anon_sym_DOT_DOT] = ACTIONS(3659),
    [anon_sym_from] = ACTIONS(3657),
    [anon_sym_into] = ACTIONS(3657),
    [anon_sym_join] = ACTIONS(3657),
    [anon_sym_on] = ACTIONS(3657),
    [anon_sym_equals] = ACTIONS(3657),
    [anon_sym_let] = ACTIONS(3657),
    [anon_sym_orderby] = ACTIONS(3657),
    [anon_sym_ascending] = ACTIONS(3657),
    [anon_sym_descending] = ACTIONS(3657),
    [anon_sym_group] = ACTIONS(3657),
    [anon_sym_by] = ACTIONS(3657),
    [anon_sym_select] = ACTIONS(3657),
    [anon_sym_stackalloc] = ACTIONS(3657),
    [anon_sym_sizeof] = ACTIONS(3657),
    [anon_sym_typeof] = ACTIONS(3657),
    [anon_sym___makeref] = ACTIONS(3657),
    [anon_sym___reftype] = ACTIONS(3657),
    [anon_sym___refvalue] = ACTIONS(3657),
    [sym_null_literal] = ACTIONS(3657),
    [anon_sym_SQUOTE] = ACTIONS(3659),
    [sym_integer_literal] = ACTIONS(3657),
    [sym_real_literal] = ACTIONS(3659),
    [anon_sym_DQUOTE] = ACTIONS(3659),
    [sym_verbatim_string_literal] = ACTIONS(3659),
    [aux_sym_preproc_if_token1] = ACTIONS(3659),
    [aux_sym_preproc_if_token3] = ACTIONS(3659),
    [aux_sym_preproc_else_token1] = ACTIONS(3659),
    [aux_sym_preproc_elif_token1] = ACTIONS(3659),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3659),
    [sym_interpolation_verbatim_start] = ACTIONS(3659),
    [sym_interpolation_raw_start] = ACTIONS(3659),
    [sym_raw_string_start] = ACTIONS(3659),
  },
  [2371] = {
    [sym_preproc_region] = STATE(2371),
    [sym_preproc_endregion] = STATE(2371),
    [sym_preproc_line] = STATE(2371),
    [sym_preproc_pragma] = STATE(2371),
    [sym_preproc_nullable] = STATE(2371),
    [sym_preproc_error] = STATE(2371),
    [sym_preproc_warning] = STATE(2371),
    [sym_preproc_define] = STATE(2371),
    [sym_preproc_undef] = STATE(2371),
    [sym__identifier_token] = ACTIONS(3661),
    [anon_sym_extern] = ACTIONS(3661),
    [anon_sym_alias] = ACTIONS(3661),
    [anon_sym_SEMI] = ACTIONS(3663),
    [anon_sym_global] = ACTIONS(3661),
    [anon_sym_using] = ACTIONS(3661),
    [anon_sym_unsafe] = ACTIONS(3661),
    [anon_sym_static] = ACTIONS(3661),
    [anon_sym_LBRACK] = ACTIONS(3663),
    [anon_sym_LPAREN] = ACTIONS(3663),
    [anon_sym_return] = ACTIONS(3661),
    [anon_sym_namespace] = ACTIONS(3661),
    [anon_sym_class] = ACTIONS(3661),
    [anon_sym_ref] = ACTIONS(3661),
    [anon_sym_struct] = ACTIONS(3661),
    [anon_sym_enum] = ACTIONS(3661),
    [anon_sym_LBRACE] = ACTIONS(3663),
    [anon_sym_interface] = ACTIONS(3661),
    [anon_sym_delegate] = ACTIONS(3661),
    [anon_sym_record] = ACTIONS(3661),
    [anon_sym_abstract] = ACTIONS(3661),
    [anon_sym_async] = ACTIONS(3661),
    [anon_sym_const] = ACTIONS(3661),
    [anon_sym_file] = ACTIONS(3661),
    [anon_sym_fixed] = ACTIONS(3661),
    [anon_sym_internal] = ACTIONS(3661),
    [anon_sym_new] = ACTIONS(3661),
    [anon_sym_override] = ACTIONS(3661),
    [anon_sym_partial] = ACTIONS(3661),
    [anon_sym_private] = ACTIONS(3661),
    [anon_sym_protected] = ACTIONS(3661),
    [anon_sym_public] = ACTIONS(3661),
    [anon_sym_readonly] = ACTIONS(3661),
    [anon_sym_required] = ACTIONS(3661),
    [anon_sym_sealed] = ACTIONS(3661),
    [anon_sym_virtual] = ACTIONS(3661),
    [anon_sym_volatile] = ACTIONS(3661),
    [anon_sym_where] = ACTIONS(3661),
    [anon_sym_notnull] = ACTIONS(3661),
    [anon_sym_unmanaged] = ACTIONS(3661),
    [anon_sym_checked] = ACTIONS(3661),
    [anon_sym_BANG] = ACTIONS(3663),
    [anon_sym_TILDE] = ACTIONS(3663),
    [anon_sym_PLUS_PLUS] = ACTIONS(3663),
    [anon_sym_DASH_DASH] = ACTIONS(3663),
    [anon_sym_true] = ACTIONS(3661),
    [anon_sym_false] = ACTIONS(3661),
    [anon_sym_PLUS] = ACTIONS(3661),
    [anon_sym_DASH] = ACTIONS(3661),
    [anon_sym_STAR] = ACTIONS(3663),
    [anon_sym_CARET] = ACTIONS(3663),
    [anon_sym_AMP] = ACTIONS(3663),
    [anon_sym_this] = ACTIONS(3661),
    [anon_sym_scoped] = ACTIONS(3661),
    [anon_sym_base] = ACTIONS(3661),
    [anon_sym_var] = ACTIONS(3661),
    [sym_predefined_type] = ACTIONS(3661),
    [anon_sym_break] = ACTIONS(3661),
    [anon_sym_unchecked] = ACTIONS(3661),
    [anon_sym_continue] = ACTIONS(3661),
    [anon_sym_do] = ACTIONS(3661),
    [anon_sym_while] = ACTIONS(3661),
    [anon_sym_for] = ACTIONS(3661),
    [anon_sym_lock] = ACTIONS(3661),
    [anon_sym_yield] = ACTIONS(3661),
    [anon_sym_switch] = ACTIONS(3661),
    [anon_sym_default] = ACTIONS(3661),
    [anon_sym_throw] = ACTIONS(3661),
    [anon_sym_try] = ACTIONS(3661),
    [anon_sym_when] = ACTIONS(3661),
    [anon_sym_await] = ACTIONS(3661),
    [anon_sym_foreach] = ACTIONS(3661),
    [anon_sym_goto] = ACTIONS(3661),
    [anon_sym_if] = ACTIONS(3661),
    [anon_sym_DOT_DOT] = ACTIONS(3663),
    [anon_sym_from] = ACTIONS(3661),
    [anon_sym_into] = ACTIONS(3661),
    [anon_sym_join] = ACTIONS(3661),
    [anon_sym_on] = ACTIONS(3661),
    [anon_sym_equals] = ACTIONS(3661),
    [anon_sym_let] = ACTIONS(3661),
    [anon_sym_orderby] = ACTIONS(3661),
    [anon_sym_ascending] = ACTIONS(3661),
    [anon_sym_descending] = ACTIONS(3661),
    [anon_sym_group] = ACTIONS(3661),
    [anon_sym_by] = ACTIONS(3661),
    [anon_sym_select] = ACTIONS(3661),
    [anon_sym_stackalloc] = ACTIONS(3661),
    [anon_sym_sizeof] = ACTIONS(3661),
    [anon_sym_typeof] = ACTIONS(3661),
    [anon_sym___makeref] = ACTIONS(3661),
    [anon_sym___reftype] = ACTIONS(3661),
    [anon_sym___refvalue] = ACTIONS(3661),
    [sym_null_literal] = ACTIONS(3661),
    [anon_sym_SQUOTE] = ACTIONS(3663),
    [sym_integer_literal] = ACTIONS(3661),
    [sym_real_literal] = ACTIONS(3663),
    [anon_sym_DQUOTE] = ACTIONS(3663),
    [sym_verbatim_string_literal] = ACTIONS(3663),
    [aux_sym_preproc_if_token1] = ACTIONS(3663),
    [aux_sym_preproc_if_token3] = ACTIONS(3663),
    [aux_sym_preproc_else_token1] = ACTIONS(3663),
    [aux_sym_preproc_elif_token1] = ACTIONS(3663),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3663),
    [sym_interpolation_verbatim_start] = ACTIONS(3663),
    [sym_interpolation_raw_start] = ACTIONS(3663),
    [sym_raw_string_start] = ACTIONS(3663),
  },
  [2372] = {
    [sym_preproc_region] = STATE(2372),
    [sym_preproc_endregion] = STATE(2372),
    [sym_preproc_line] = STATE(2372),
    [sym_preproc_pragma] = STATE(2372),
    [sym_preproc_nullable] = STATE(2372),
    [sym_preproc_error] = STATE(2372),
    [sym_preproc_warning] = STATE(2372),
    [sym_preproc_define] = STATE(2372),
    [sym_preproc_undef] = STATE(2372),
    [sym__identifier_token] = ACTIONS(3665),
    [anon_sym_extern] = ACTIONS(3665),
    [anon_sym_alias] = ACTIONS(3665),
    [anon_sym_SEMI] = ACTIONS(3667),
    [anon_sym_global] = ACTIONS(3665),
    [anon_sym_using] = ACTIONS(3665),
    [anon_sym_unsafe] = ACTIONS(3665),
    [anon_sym_static] = ACTIONS(3665),
    [anon_sym_LBRACK] = ACTIONS(3667),
    [anon_sym_LPAREN] = ACTIONS(3667),
    [anon_sym_return] = ACTIONS(3665),
    [anon_sym_namespace] = ACTIONS(3665),
    [anon_sym_class] = ACTIONS(3665),
    [anon_sym_ref] = ACTIONS(3665),
    [anon_sym_struct] = ACTIONS(3665),
    [anon_sym_enum] = ACTIONS(3665),
    [anon_sym_LBRACE] = ACTIONS(3667),
    [anon_sym_interface] = ACTIONS(3665),
    [anon_sym_delegate] = ACTIONS(3665),
    [anon_sym_record] = ACTIONS(3665),
    [anon_sym_abstract] = ACTIONS(3665),
    [anon_sym_async] = ACTIONS(3665),
    [anon_sym_const] = ACTIONS(3665),
    [anon_sym_file] = ACTIONS(3665),
    [anon_sym_fixed] = ACTIONS(3665),
    [anon_sym_internal] = ACTIONS(3665),
    [anon_sym_new] = ACTIONS(3665),
    [anon_sym_override] = ACTIONS(3665),
    [anon_sym_partial] = ACTIONS(3665),
    [anon_sym_private] = ACTIONS(3665),
    [anon_sym_protected] = ACTIONS(3665),
    [anon_sym_public] = ACTIONS(3665),
    [anon_sym_readonly] = ACTIONS(3665),
    [anon_sym_required] = ACTIONS(3665),
    [anon_sym_sealed] = ACTIONS(3665),
    [anon_sym_virtual] = ACTIONS(3665),
    [anon_sym_volatile] = ACTIONS(3665),
    [anon_sym_where] = ACTIONS(3665),
    [anon_sym_notnull] = ACTIONS(3665),
    [anon_sym_unmanaged] = ACTIONS(3665),
    [anon_sym_checked] = ACTIONS(3665),
    [anon_sym_BANG] = ACTIONS(3667),
    [anon_sym_TILDE] = ACTIONS(3667),
    [anon_sym_PLUS_PLUS] = ACTIONS(3667),
    [anon_sym_DASH_DASH] = ACTIONS(3667),
    [anon_sym_true] = ACTIONS(3665),
    [anon_sym_false] = ACTIONS(3665),
    [anon_sym_PLUS] = ACTIONS(3665),
    [anon_sym_DASH] = ACTIONS(3665),
    [anon_sym_STAR] = ACTIONS(3667),
    [anon_sym_CARET] = ACTIONS(3667),
    [anon_sym_AMP] = ACTIONS(3667),
    [anon_sym_this] = ACTIONS(3665),
    [anon_sym_scoped] = ACTIONS(3665),
    [anon_sym_base] = ACTIONS(3665),
    [anon_sym_var] = ACTIONS(3665),
    [sym_predefined_type] = ACTIONS(3665),
    [anon_sym_break] = ACTIONS(3665),
    [anon_sym_unchecked] = ACTIONS(3665),
    [anon_sym_continue] = ACTIONS(3665),
    [anon_sym_do] = ACTIONS(3665),
    [anon_sym_while] = ACTIONS(3665),
    [anon_sym_for] = ACTIONS(3665),
    [anon_sym_lock] = ACTIONS(3665),
    [anon_sym_yield] = ACTIONS(3665),
    [anon_sym_switch] = ACTIONS(3665),
    [anon_sym_default] = ACTIONS(3665),
    [anon_sym_throw] = ACTIONS(3665),
    [anon_sym_try] = ACTIONS(3665),
    [anon_sym_when] = ACTIONS(3665),
    [anon_sym_await] = ACTIONS(3665),
    [anon_sym_foreach] = ACTIONS(3665),
    [anon_sym_goto] = ACTIONS(3665),
    [anon_sym_if] = ACTIONS(3665),
    [anon_sym_DOT_DOT] = ACTIONS(3667),
    [anon_sym_from] = ACTIONS(3665),
    [anon_sym_into] = ACTIONS(3665),
    [anon_sym_join] = ACTIONS(3665),
    [anon_sym_on] = ACTIONS(3665),
    [anon_sym_equals] = ACTIONS(3665),
    [anon_sym_let] = ACTIONS(3665),
    [anon_sym_orderby] = ACTIONS(3665),
    [anon_sym_ascending] = ACTIONS(3665),
    [anon_sym_descending] = ACTIONS(3665),
    [anon_sym_group] = ACTIONS(3665),
    [anon_sym_by] = ACTIONS(3665),
    [anon_sym_select] = ACTIONS(3665),
    [anon_sym_stackalloc] = ACTIONS(3665),
    [anon_sym_sizeof] = ACTIONS(3665),
    [anon_sym_typeof] = ACTIONS(3665),
    [anon_sym___makeref] = ACTIONS(3665),
    [anon_sym___reftype] = ACTIONS(3665),
    [anon_sym___refvalue] = ACTIONS(3665),
    [sym_null_literal] = ACTIONS(3665),
    [anon_sym_SQUOTE] = ACTIONS(3667),
    [sym_integer_literal] = ACTIONS(3665),
    [sym_real_literal] = ACTIONS(3667),
    [anon_sym_DQUOTE] = ACTIONS(3667),
    [sym_verbatim_string_literal] = ACTIONS(3667),
    [aux_sym_preproc_if_token1] = ACTIONS(3667),
    [aux_sym_preproc_if_token3] = ACTIONS(3667),
    [aux_sym_preproc_else_token1] = ACTIONS(3667),
    [aux_sym_preproc_elif_token1] = ACTIONS(3667),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3667),
    [sym_interpolation_verbatim_start] = ACTIONS(3667),
    [sym_interpolation_raw_start] = ACTIONS(3667),
    [sym_raw_string_start] = ACTIONS(3667),
  },
  [2373] = {
    [sym_preproc_region] = STATE(2373),
    [sym_preproc_endregion] = STATE(2373),
    [sym_preproc_line] = STATE(2373),
    [sym_preproc_pragma] = STATE(2373),
    [sym_preproc_nullable] = STATE(2373),
    [sym_preproc_error] = STATE(2373),
    [sym_preproc_warning] = STATE(2373),
    [sym_preproc_define] = STATE(2373),
    [sym_preproc_undef] = STATE(2373),
    [sym__identifier_token] = ACTIONS(3669),
    [anon_sym_extern] = ACTIONS(3669),
    [anon_sym_alias] = ACTIONS(3669),
    [anon_sym_SEMI] = ACTIONS(3671),
    [anon_sym_global] = ACTIONS(3669),
    [anon_sym_using] = ACTIONS(3669),
    [anon_sym_unsafe] = ACTIONS(3669),
    [anon_sym_static] = ACTIONS(3669),
    [anon_sym_LBRACK] = ACTIONS(3671),
    [anon_sym_LPAREN] = ACTIONS(3671),
    [anon_sym_return] = ACTIONS(3669),
    [anon_sym_namespace] = ACTIONS(3669),
    [anon_sym_class] = ACTIONS(3669),
    [anon_sym_ref] = ACTIONS(3669),
    [anon_sym_struct] = ACTIONS(3669),
    [anon_sym_enum] = ACTIONS(3669),
    [anon_sym_LBRACE] = ACTIONS(3671),
    [anon_sym_interface] = ACTIONS(3669),
    [anon_sym_delegate] = ACTIONS(3669),
    [anon_sym_record] = ACTIONS(3669),
    [anon_sym_abstract] = ACTIONS(3669),
    [anon_sym_async] = ACTIONS(3669),
    [anon_sym_const] = ACTIONS(3669),
    [anon_sym_file] = ACTIONS(3669),
    [anon_sym_fixed] = ACTIONS(3669),
    [anon_sym_internal] = ACTIONS(3669),
    [anon_sym_new] = ACTIONS(3669),
    [anon_sym_override] = ACTIONS(3669),
    [anon_sym_partial] = ACTIONS(3669),
    [anon_sym_private] = ACTIONS(3669),
    [anon_sym_protected] = ACTIONS(3669),
    [anon_sym_public] = ACTIONS(3669),
    [anon_sym_readonly] = ACTIONS(3669),
    [anon_sym_required] = ACTIONS(3669),
    [anon_sym_sealed] = ACTIONS(3669),
    [anon_sym_virtual] = ACTIONS(3669),
    [anon_sym_volatile] = ACTIONS(3669),
    [anon_sym_where] = ACTIONS(3669),
    [anon_sym_notnull] = ACTIONS(3669),
    [anon_sym_unmanaged] = ACTIONS(3669),
    [anon_sym_checked] = ACTIONS(3669),
    [anon_sym_BANG] = ACTIONS(3671),
    [anon_sym_TILDE] = ACTIONS(3671),
    [anon_sym_PLUS_PLUS] = ACTIONS(3671),
    [anon_sym_DASH_DASH] = ACTIONS(3671),
    [anon_sym_true] = ACTIONS(3669),
    [anon_sym_false] = ACTIONS(3669),
    [anon_sym_PLUS] = ACTIONS(3669),
    [anon_sym_DASH] = ACTIONS(3669),
    [anon_sym_STAR] = ACTIONS(3671),
    [anon_sym_CARET] = ACTIONS(3671),
    [anon_sym_AMP] = ACTIONS(3671),
    [anon_sym_this] = ACTIONS(3669),
    [anon_sym_scoped] = ACTIONS(3669),
    [anon_sym_base] = ACTIONS(3669),
    [anon_sym_var] = ACTIONS(3669),
    [sym_predefined_type] = ACTIONS(3669),
    [anon_sym_break] = ACTIONS(3669),
    [anon_sym_unchecked] = ACTIONS(3669),
    [anon_sym_continue] = ACTIONS(3669),
    [anon_sym_do] = ACTIONS(3669),
    [anon_sym_while] = ACTIONS(3669),
    [anon_sym_for] = ACTIONS(3669),
    [anon_sym_lock] = ACTIONS(3669),
    [anon_sym_yield] = ACTIONS(3669),
    [anon_sym_switch] = ACTIONS(3669),
    [anon_sym_default] = ACTIONS(3669),
    [anon_sym_throw] = ACTIONS(3669),
    [anon_sym_try] = ACTIONS(3669),
    [anon_sym_when] = ACTIONS(3669),
    [anon_sym_await] = ACTIONS(3669),
    [anon_sym_foreach] = ACTIONS(3669),
    [anon_sym_goto] = ACTIONS(3669),
    [anon_sym_if] = ACTIONS(3669),
    [anon_sym_DOT_DOT] = ACTIONS(3671),
    [anon_sym_from] = ACTIONS(3669),
    [anon_sym_into] = ACTIONS(3669),
    [anon_sym_join] = ACTIONS(3669),
    [anon_sym_on] = ACTIONS(3669),
    [anon_sym_equals] = ACTIONS(3669),
    [anon_sym_let] = ACTIONS(3669),
    [anon_sym_orderby] = ACTIONS(3669),
    [anon_sym_ascending] = ACTIONS(3669),
    [anon_sym_descending] = ACTIONS(3669),
    [anon_sym_group] = ACTIONS(3669),
    [anon_sym_by] = ACTIONS(3669),
    [anon_sym_select] = ACTIONS(3669),
    [anon_sym_stackalloc] = ACTIONS(3669),
    [anon_sym_sizeof] = ACTIONS(3669),
    [anon_sym_typeof] = ACTIONS(3669),
    [anon_sym___makeref] = ACTIONS(3669),
    [anon_sym___reftype] = ACTIONS(3669),
    [anon_sym___refvalue] = ACTIONS(3669),
    [sym_null_literal] = ACTIONS(3669),
    [anon_sym_SQUOTE] = ACTIONS(3671),
    [sym_integer_literal] = ACTIONS(3669),
    [sym_real_literal] = ACTIONS(3671),
    [anon_sym_DQUOTE] = ACTIONS(3671),
    [sym_verbatim_string_literal] = ACTIONS(3671),
    [aux_sym_preproc_if_token1] = ACTIONS(3671),
    [aux_sym_preproc_if_token3] = ACTIONS(3671),
    [aux_sym_preproc_else_token1] = ACTIONS(3671),
    [aux_sym_preproc_elif_token1] = ACTIONS(3671),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3671),
    [sym_interpolation_verbatim_start] = ACTIONS(3671),
    [sym_interpolation_raw_start] = ACTIONS(3671),
    [sym_raw_string_start] = ACTIONS(3671),
  },
  [2374] = {
    [sym_preproc_region] = STATE(2374),
    [sym_preproc_endregion] = STATE(2374),
    [sym_preproc_line] = STATE(2374),
    [sym_preproc_pragma] = STATE(2374),
    [sym_preproc_nullable] = STATE(2374),
    [sym_preproc_error] = STATE(2374),
    [sym_preproc_warning] = STATE(2374),
    [sym_preproc_define] = STATE(2374),
    [sym_preproc_undef] = STATE(2374),
    [sym__identifier_token] = ACTIONS(3673),
    [anon_sym_extern] = ACTIONS(3673),
    [anon_sym_alias] = ACTIONS(3673),
    [anon_sym_SEMI] = ACTIONS(3675),
    [anon_sym_global] = ACTIONS(3673),
    [anon_sym_using] = ACTIONS(3673),
    [anon_sym_unsafe] = ACTIONS(3673),
    [anon_sym_static] = ACTIONS(3673),
    [anon_sym_LBRACK] = ACTIONS(3675),
    [anon_sym_LPAREN] = ACTIONS(3675),
    [anon_sym_return] = ACTIONS(3673),
    [anon_sym_namespace] = ACTIONS(3673),
    [anon_sym_class] = ACTIONS(3673),
    [anon_sym_ref] = ACTIONS(3673),
    [anon_sym_struct] = ACTIONS(3673),
    [anon_sym_enum] = ACTIONS(3673),
    [anon_sym_LBRACE] = ACTIONS(3675),
    [anon_sym_interface] = ACTIONS(3673),
    [anon_sym_delegate] = ACTIONS(3673),
    [anon_sym_record] = ACTIONS(3673),
    [anon_sym_abstract] = ACTIONS(3673),
    [anon_sym_async] = ACTIONS(3673),
    [anon_sym_const] = ACTIONS(3673),
    [anon_sym_file] = ACTIONS(3673),
    [anon_sym_fixed] = ACTIONS(3673),
    [anon_sym_internal] = ACTIONS(3673),
    [anon_sym_new] = ACTIONS(3673),
    [anon_sym_override] = ACTIONS(3673),
    [anon_sym_partial] = ACTIONS(3673),
    [anon_sym_private] = ACTIONS(3673),
    [anon_sym_protected] = ACTIONS(3673),
    [anon_sym_public] = ACTIONS(3673),
    [anon_sym_readonly] = ACTIONS(3673),
    [anon_sym_required] = ACTIONS(3673),
    [anon_sym_sealed] = ACTIONS(3673),
    [anon_sym_virtual] = ACTIONS(3673),
    [anon_sym_volatile] = ACTIONS(3673),
    [anon_sym_where] = ACTIONS(3673),
    [anon_sym_notnull] = ACTIONS(3673),
    [anon_sym_unmanaged] = ACTIONS(3673),
    [anon_sym_checked] = ACTIONS(3673),
    [anon_sym_BANG] = ACTIONS(3675),
    [anon_sym_TILDE] = ACTIONS(3675),
    [anon_sym_PLUS_PLUS] = ACTIONS(3675),
    [anon_sym_DASH_DASH] = ACTIONS(3675),
    [anon_sym_true] = ACTIONS(3673),
    [anon_sym_false] = ACTIONS(3673),
    [anon_sym_PLUS] = ACTIONS(3673),
    [anon_sym_DASH] = ACTIONS(3673),
    [anon_sym_STAR] = ACTIONS(3675),
    [anon_sym_CARET] = ACTIONS(3675),
    [anon_sym_AMP] = ACTIONS(3675),
    [anon_sym_this] = ACTIONS(3673),
    [anon_sym_scoped] = ACTIONS(3673),
    [anon_sym_base] = ACTIONS(3673),
    [anon_sym_var] = ACTIONS(3673),
    [sym_predefined_type] = ACTIONS(3673),
    [anon_sym_break] = ACTIONS(3673),
    [anon_sym_unchecked] = ACTIONS(3673),
    [anon_sym_continue] = ACTIONS(3673),
    [anon_sym_do] = ACTIONS(3673),
    [anon_sym_while] = ACTIONS(3673),
    [anon_sym_for] = ACTIONS(3673),
    [anon_sym_lock] = ACTIONS(3673),
    [anon_sym_yield] = ACTIONS(3673),
    [anon_sym_switch] = ACTIONS(3673),
    [anon_sym_default] = ACTIONS(3673),
    [anon_sym_throw] = ACTIONS(3673),
    [anon_sym_try] = ACTIONS(3673),
    [anon_sym_when] = ACTIONS(3673),
    [anon_sym_await] = ACTIONS(3673),
    [anon_sym_foreach] = ACTIONS(3673),
    [anon_sym_goto] = ACTIONS(3673),
    [anon_sym_if] = ACTIONS(3673),
    [anon_sym_DOT_DOT] = ACTIONS(3675),
    [anon_sym_from] = ACTIONS(3673),
    [anon_sym_into] = ACTIONS(3673),
    [anon_sym_join] = ACTIONS(3673),
    [anon_sym_on] = ACTIONS(3673),
    [anon_sym_equals] = ACTIONS(3673),
    [anon_sym_let] = ACTIONS(3673),
    [anon_sym_orderby] = ACTIONS(3673),
    [anon_sym_ascending] = ACTIONS(3673),
    [anon_sym_descending] = ACTIONS(3673),
    [anon_sym_group] = ACTIONS(3673),
    [anon_sym_by] = ACTIONS(3673),
    [anon_sym_select] = ACTIONS(3673),
    [anon_sym_stackalloc] = ACTIONS(3673),
    [anon_sym_sizeof] = ACTIONS(3673),
    [anon_sym_typeof] = ACTIONS(3673),
    [anon_sym___makeref] = ACTIONS(3673),
    [anon_sym___reftype] = ACTIONS(3673),
    [anon_sym___refvalue] = ACTIONS(3673),
    [sym_null_literal] = ACTIONS(3673),
    [anon_sym_SQUOTE] = ACTIONS(3675),
    [sym_integer_literal] = ACTIONS(3673),
    [sym_real_literal] = ACTIONS(3675),
    [anon_sym_DQUOTE] = ACTIONS(3675),
    [sym_verbatim_string_literal] = ACTIONS(3675),
    [aux_sym_preproc_if_token1] = ACTIONS(3675),
    [aux_sym_preproc_if_token3] = ACTIONS(3675),
    [aux_sym_preproc_else_token1] = ACTIONS(3675),
    [aux_sym_preproc_elif_token1] = ACTIONS(3675),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3675),
    [sym_interpolation_verbatim_start] = ACTIONS(3675),
    [sym_interpolation_raw_start] = ACTIONS(3675),
    [sym_raw_string_start] = ACTIONS(3675),
  },
  [2375] = {
    [sym_preproc_region] = STATE(2375),
    [sym_preproc_endregion] = STATE(2375),
    [sym_preproc_line] = STATE(2375),
    [sym_preproc_pragma] = STATE(2375),
    [sym_preproc_nullable] = STATE(2375),
    [sym_preproc_error] = STATE(2375),
    [sym_preproc_warning] = STATE(2375),
    [sym_preproc_define] = STATE(2375),
    [sym_preproc_undef] = STATE(2375),
    [sym__identifier_token] = ACTIONS(3677),
    [anon_sym_extern] = ACTIONS(3677),
    [anon_sym_alias] = ACTIONS(3677),
    [anon_sym_SEMI] = ACTIONS(3679),
    [anon_sym_global] = ACTIONS(3677),
    [anon_sym_using] = ACTIONS(3677),
    [anon_sym_unsafe] = ACTIONS(3677),
    [anon_sym_static] = ACTIONS(3677),
    [anon_sym_LBRACK] = ACTIONS(3679),
    [anon_sym_LPAREN] = ACTIONS(3679),
    [anon_sym_return] = ACTIONS(3677),
    [anon_sym_namespace] = ACTIONS(3677),
    [anon_sym_class] = ACTIONS(3677),
    [anon_sym_ref] = ACTIONS(3677),
    [anon_sym_struct] = ACTIONS(3677),
    [anon_sym_enum] = ACTIONS(3677),
    [anon_sym_LBRACE] = ACTIONS(3679),
    [anon_sym_interface] = ACTIONS(3677),
    [anon_sym_delegate] = ACTIONS(3677),
    [anon_sym_record] = ACTIONS(3677),
    [anon_sym_abstract] = ACTIONS(3677),
    [anon_sym_async] = ACTIONS(3677),
    [anon_sym_const] = ACTIONS(3677),
    [anon_sym_file] = ACTIONS(3677),
    [anon_sym_fixed] = ACTIONS(3677),
    [anon_sym_internal] = ACTIONS(3677),
    [anon_sym_new] = ACTIONS(3677),
    [anon_sym_override] = ACTIONS(3677),
    [anon_sym_partial] = ACTIONS(3677),
    [anon_sym_private] = ACTIONS(3677),
    [anon_sym_protected] = ACTIONS(3677),
    [anon_sym_public] = ACTIONS(3677),
    [anon_sym_readonly] = ACTIONS(3677),
    [anon_sym_required] = ACTIONS(3677),
    [anon_sym_sealed] = ACTIONS(3677),
    [anon_sym_virtual] = ACTIONS(3677),
    [anon_sym_volatile] = ACTIONS(3677),
    [anon_sym_where] = ACTIONS(3677),
    [anon_sym_notnull] = ACTIONS(3677),
    [anon_sym_unmanaged] = ACTIONS(3677),
    [anon_sym_checked] = ACTIONS(3677),
    [anon_sym_BANG] = ACTIONS(3679),
    [anon_sym_TILDE] = ACTIONS(3679),
    [anon_sym_PLUS_PLUS] = ACTIONS(3679),
    [anon_sym_DASH_DASH] = ACTIONS(3679),
    [anon_sym_true] = ACTIONS(3677),
    [anon_sym_false] = ACTIONS(3677),
    [anon_sym_PLUS] = ACTIONS(3677),
    [anon_sym_DASH] = ACTIONS(3677),
    [anon_sym_STAR] = ACTIONS(3679),
    [anon_sym_CARET] = ACTIONS(3679),
    [anon_sym_AMP] = ACTIONS(3679),
    [anon_sym_this] = ACTIONS(3677),
    [anon_sym_scoped] = ACTIONS(3677),
    [anon_sym_base] = ACTIONS(3677),
    [anon_sym_var] = ACTIONS(3677),
    [sym_predefined_type] = ACTIONS(3677),
    [anon_sym_break] = ACTIONS(3677),
    [anon_sym_unchecked] = ACTIONS(3677),
    [anon_sym_continue] = ACTIONS(3677),
    [anon_sym_do] = ACTIONS(3677),
    [anon_sym_while] = ACTIONS(3677),
    [anon_sym_for] = ACTIONS(3677),
    [anon_sym_lock] = ACTIONS(3677),
    [anon_sym_yield] = ACTIONS(3677),
    [anon_sym_switch] = ACTIONS(3677),
    [anon_sym_default] = ACTIONS(3677),
    [anon_sym_throw] = ACTIONS(3677),
    [anon_sym_try] = ACTIONS(3677),
    [anon_sym_when] = ACTIONS(3677),
    [anon_sym_await] = ACTIONS(3677),
    [anon_sym_foreach] = ACTIONS(3677),
    [anon_sym_goto] = ACTIONS(3677),
    [anon_sym_if] = ACTIONS(3677),
    [anon_sym_DOT_DOT] = ACTIONS(3679),
    [anon_sym_from] = ACTIONS(3677),
    [anon_sym_into] = ACTIONS(3677),
    [anon_sym_join] = ACTIONS(3677),
    [anon_sym_on] = ACTIONS(3677),
    [anon_sym_equals] = ACTIONS(3677),
    [anon_sym_let] = ACTIONS(3677),
    [anon_sym_orderby] = ACTIONS(3677),
    [anon_sym_ascending] = ACTIONS(3677),
    [anon_sym_descending] = ACTIONS(3677),
    [anon_sym_group] = ACTIONS(3677),
    [anon_sym_by] = ACTIONS(3677),
    [anon_sym_select] = ACTIONS(3677),
    [anon_sym_stackalloc] = ACTIONS(3677),
    [anon_sym_sizeof] = ACTIONS(3677),
    [anon_sym_typeof] = ACTIONS(3677),
    [anon_sym___makeref] = ACTIONS(3677),
    [anon_sym___reftype] = ACTIONS(3677),
    [anon_sym___refvalue] = ACTIONS(3677),
    [sym_null_literal] = ACTIONS(3677),
    [anon_sym_SQUOTE] = ACTIONS(3679),
    [sym_integer_literal] = ACTIONS(3677),
    [sym_real_literal] = ACTIONS(3679),
    [anon_sym_DQUOTE] = ACTIONS(3679),
    [sym_verbatim_string_literal] = ACTIONS(3679),
    [aux_sym_preproc_if_token1] = ACTIONS(3679),
    [aux_sym_preproc_if_token3] = ACTIONS(3679),
    [aux_sym_preproc_else_token1] = ACTIONS(3679),
    [aux_sym_preproc_elif_token1] = ACTIONS(3679),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3679),
    [sym_interpolation_verbatim_start] = ACTIONS(3679),
    [sym_interpolation_raw_start] = ACTIONS(3679),
    [sym_raw_string_start] = ACTIONS(3679),
  },
  [2376] = {
    [sym_preproc_region] = STATE(2376),
    [sym_preproc_endregion] = STATE(2376),
    [sym_preproc_line] = STATE(2376),
    [sym_preproc_pragma] = STATE(2376),
    [sym_preproc_nullable] = STATE(2376),
    [sym_preproc_error] = STATE(2376),
    [sym_preproc_warning] = STATE(2376),
    [sym_preproc_define] = STATE(2376),
    [sym_preproc_undef] = STATE(2376),
    [sym__identifier_token] = ACTIONS(3681),
    [anon_sym_extern] = ACTIONS(3681),
    [anon_sym_alias] = ACTIONS(3681),
    [anon_sym_SEMI] = ACTIONS(3683),
    [anon_sym_global] = ACTIONS(3681),
    [anon_sym_using] = ACTIONS(3681),
    [anon_sym_unsafe] = ACTIONS(3681),
    [anon_sym_static] = ACTIONS(3681),
    [anon_sym_LBRACK] = ACTIONS(3683),
    [anon_sym_LPAREN] = ACTIONS(3683),
    [anon_sym_return] = ACTIONS(3681),
    [anon_sym_namespace] = ACTIONS(3681),
    [anon_sym_class] = ACTIONS(3681),
    [anon_sym_ref] = ACTIONS(3681),
    [anon_sym_struct] = ACTIONS(3681),
    [anon_sym_enum] = ACTIONS(3681),
    [anon_sym_LBRACE] = ACTIONS(3683),
    [anon_sym_interface] = ACTIONS(3681),
    [anon_sym_delegate] = ACTIONS(3681),
    [anon_sym_record] = ACTIONS(3681),
    [anon_sym_abstract] = ACTIONS(3681),
    [anon_sym_async] = ACTIONS(3681),
    [anon_sym_const] = ACTIONS(3681),
    [anon_sym_file] = ACTIONS(3681),
    [anon_sym_fixed] = ACTIONS(3681),
    [anon_sym_internal] = ACTIONS(3681),
    [anon_sym_new] = ACTIONS(3681),
    [anon_sym_override] = ACTIONS(3681),
    [anon_sym_partial] = ACTIONS(3681),
    [anon_sym_private] = ACTIONS(3681),
    [anon_sym_protected] = ACTIONS(3681),
    [anon_sym_public] = ACTIONS(3681),
    [anon_sym_readonly] = ACTIONS(3681),
    [anon_sym_required] = ACTIONS(3681),
    [anon_sym_sealed] = ACTIONS(3681),
    [anon_sym_virtual] = ACTIONS(3681),
    [anon_sym_volatile] = ACTIONS(3681),
    [anon_sym_where] = ACTIONS(3681),
    [anon_sym_notnull] = ACTIONS(3681),
    [anon_sym_unmanaged] = ACTIONS(3681),
    [anon_sym_checked] = ACTIONS(3681),
    [anon_sym_BANG] = ACTIONS(3683),
    [anon_sym_TILDE] = ACTIONS(3683),
    [anon_sym_PLUS_PLUS] = ACTIONS(3683),
    [anon_sym_DASH_DASH] = ACTIONS(3683),
    [anon_sym_true] = ACTIONS(3681),
    [anon_sym_false] = ACTIONS(3681),
    [anon_sym_PLUS] = ACTIONS(3681),
    [anon_sym_DASH] = ACTIONS(3681),
    [anon_sym_STAR] = ACTIONS(3683),
    [anon_sym_CARET] = ACTIONS(3683),
    [anon_sym_AMP] = ACTIONS(3683),
    [anon_sym_this] = ACTIONS(3681),
    [anon_sym_scoped] = ACTIONS(3681),
    [anon_sym_base] = ACTIONS(3681),
    [anon_sym_var] = ACTIONS(3681),
    [sym_predefined_type] = ACTIONS(3681),
    [anon_sym_break] = ACTIONS(3681),
    [anon_sym_unchecked] = ACTIONS(3681),
    [anon_sym_continue] = ACTIONS(3681),
    [anon_sym_do] = ACTIONS(3681),
    [anon_sym_while] = ACTIONS(3681),
    [anon_sym_for] = ACTIONS(3681),
    [anon_sym_lock] = ACTIONS(3681),
    [anon_sym_yield] = ACTIONS(3681),
    [anon_sym_switch] = ACTIONS(3681),
    [anon_sym_default] = ACTIONS(3681),
    [anon_sym_throw] = ACTIONS(3681),
    [anon_sym_try] = ACTIONS(3681),
    [anon_sym_when] = ACTIONS(3681),
    [anon_sym_await] = ACTIONS(3681),
    [anon_sym_foreach] = ACTIONS(3681),
    [anon_sym_goto] = ACTIONS(3681),
    [anon_sym_if] = ACTIONS(3681),
    [anon_sym_DOT_DOT] = ACTIONS(3683),
    [anon_sym_from] = ACTIONS(3681),
    [anon_sym_into] = ACTIONS(3681),
    [anon_sym_join] = ACTIONS(3681),
    [anon_sym_on] = ACTIONS(3681),
    [anon_sym_equals] = ACTIONS(3681),
    [anon_sym_let] = ACTIONS(3681),
    [anon_sym_orderby] = ACTIONS(3681),
    [anon_sym_ascending] = ACTIONS(3681),
    [anon_sym_descending] = ACTIONS(3681),
    [anon_sym_group] = ACTIONS(3681),
    [anon_sym_by] = ACTIONS(3681),
    [anon_sym_select] = ACTIONS(3681),
    [anon_sym_stackalloc] = ACTIONS(3681),
    [anon_sym_sizeof] = ACTIONS(3681),
    [anon_sym_typeof] = ACTIONS(3681),
    [anon_sym___makeref] = ACTIONS(3681),
    [anon_sym___reftype] = ACTIONS(3681),
    [anon_sym___refvalue] = ACTIONS(3681),
    [sym_null_literal] = ACTIONS(3681),
    [anon_sym_SQUOTE] = ACTIONS(3683),
    [sym_integer_literal] = ACTIONS(3681),
    [sym_real_literal] = ACTIONS(3683),
    [anon_sym_DQUOTE] = ACTIONS(3683),
    [sym_verbatim_string_literal] = ACTIONS(3683),
    [aux_sym_preproc_if_token1] = ACTIONS(3683),
    [aux_sym_preproc_if_token3] = ACTIONS(3683),
    [aux_sym_preproc_else_token1] = ACTIONS(3683),
    [aux_sym_preproc_elif_token1] = ACTIONS(3683),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3683),
    [sym_interpolation_verbatim_start] = ACTIONS(3683),
    [sym_interpolation_raw_start] = ACTIONS(3683),
    [sym_raw_string_start] = ACTIONS(3683),
  },
  [2377] = {
    [sym_preproc_region] = STATE(2377),
    [sym_preproc_endregion] = STATE(2377),
    [sym_preproc_line] = STATE(2377),
    [sym_preproc_pragma] = STATE(2377),
    [sym_preproc_nullable] = STATE(2377),
    [sym_preproc_error] = STATE(2377),
    [sym_preproc_warning] = STATE(2377),
    [sym_preproc_define] = STATE(2377),
    [sym_preproc_undef] = STATE(2377),
    [sym__identifier_token] = ACTIONS(3685),
    [anon_sym_extern] = ACTIONS(3685),
    [anon_sym_alias] = ACTIONS(3685),
    [anon_sym_SEMI] = ACTIONS(3687),
    [anon_sym_global] = ACTIONS(3685),
    [anon_sym_using] = ACTIONS(3685),
    [anon_sym_unsafe] = ACTIONS(3685),
    [anon_sym_static] = ACTIONS(3685),
    [anon_sym_LBRACK] = ACTIONS(3687),
    [anon_sym_LPAREN] = ACTIONS(3687),
    [anon_sym_return] = ACTIONS(3685),
    [anon_sym_namespace] = ACTIONS(3685),
    [anon_sym_class] = ACTIONS(3685),
    [anon_sym_ref] = ACTIONS(3685),
    [anon_sym_struct] = ACTIONS(3685),
    [anon_sym_enum] = ACTIONS(3685),
    [anon_sym_LBRACE] = ACTIONS(3687),
    [anon_sym_interface] = ACTIONS(3685),
    [anon_sym_delegate] = ACTIONS(3685),
    [anon_sym_record] = ACTIONS(3685),
    [anon_sym_abstract] = ACTIONS(3685),
    [anon_sym_async] = ACTIONS(3685),
    [anon_sym_const] = ACTIONS(3685),
    [anon_sym_file] = ACTIONS(3685),
    [anon_sym_fixed] = ACTIONS(3685),
    [anon_sym_internal] = ACTIONS(3685),
    [anon_sym_new] = ACTIONS(3685),
    [anon_sym_override] = ACTIONS(3685),
    [anon_sym_partial] = ACTIONS(3685),
    [anon_sym_private] = ACTIONS(3685),
    [anon_sym_protected] = ACTIONS(3685),
    [anon_sym_public] = ACTIONS(3685),
    [anon_sym_readonly] = ACTIONS(3685),
    [anon_sym_required] = ACTIONS(3685),
    [anon_sym_sealed] = ACTIONS(3685),
    [anon_sym_virtual] = ACTIONS(3685),
    [anon_sym_volatile] = ACTIONS(3685),
    [anon_sym_where] = ACTIONS(3685),
    [anon_sym_notnull] = ACTIONS(3685),
    [anon_sym_unmanaged] = ACTIONS(3685),
    [anon_sym_checked] = ACTIONS(3685),
    [anon_sym_BANG] = ACTIONS(3687),
    [anon_sym_TILDE] = ACTIONS(3687),
    [anon_sym_PLUS_PLUS] = ACTIONS(3687),
    [anon_sym_DASH_DASH] = ACTIONS(3687),
    [anon_sym_true] = ACTIONS(3685),
    [anon_sym_false] = ACTIONS(3685),
    [anon_sym_PLUS] = ACTIONS(3685),
    [anon_sym_DASH] = ACTIONS(3685),
    [anon_sym_STAR] = ACTIONS(3687),
    [anon_sym_CARET] = ACTIONS(3687),
    [anon_sym_AMP] = ACTIONS(3687),
    [anon_sym_this] = ACTIONS(3685),
    [anon_sym_scoped] = ACTIONS(3685),
    [anon_sym_base] = ACTIONS(3685),
    [anon_sym_var] = ACTIONS(3685),
    [sym_predefined_type] = ACTIONS(3685),
    [anon_sym_break] = ACTIONS(3685),
    [anon_sym_unchecked] = ACTIONS(3685),
    [anon_sym_continue] = ACTIONS(3685),
    [anon_sym_do] = ACTIONS(3685),
    [anon_sym_while] = ACTIONS(3685),
    [anon_sym_for] = ACTIONS(3685),
    [anon_sym_lock] = ACTIONS(3685),
    [anon_sym_yield] = ACTIONS(3685),
    [anon_sym_switch] = ACTIONS(3685),
    [anon_sym_default] = ACTIONS(3685),
    [anon_sym_throw] = ACTIONS(3685),
    [anon_sym_try] = ACTIONS(3685),
    [anon_sym_when] = ACTIONS(3685),
    [anon_sym_await] = ACTIONS(3685),
    [anon_sym_foreach] = ACTIONS(3685),
    [anon_sym_goto] = ACTIONS(3685),
    [anon_sym_if] = ACTIONS(3685),
    [anon_sym_DOT_DOT] = ACTIONS(3687),
    [anon_sym_from] = ACTIONS(3685),
    [anon_sym_into] = ACTIONS(3685),
    [anon_sym_join] = ACTIONS(3685),
    [anon_sym_on] = ACTIONS(3685),
    [anon_sym_equals] = ACTIONS(3685),
    [anon_sym_let] = ACTIONS(3685),
    [anon_sym_orderby] = ACTIONS(3685),
    [anon_sym_ascending] = ACTIONS(3685),
    [anon_sym_descending] = ACTIONS(3685),
    [anon_sym_group] = ACTIONS(3685),
    [anon_sym_by] = ACTIONS(3685),
    [anon_sym_select] = ACTIONS(3685),
    [anon_sym_stackalloc] = ACTIONS(3685),
    [anon_sym_sizeof] = ACTIONS(3685),
    [anon_sym_typeof] = ACTIONS(3685),
    [anon_sym___makeref] = ACTIONS(3685),
    [anon_sym___reftype] = ACTIONS(3685),
    [anon_sym___refvalue] = ACTIONS(3685),
    [sym_null_literal] = ACTIONS(3685),
    [anon_sym_SQUOTE] = ACTIONS(3687),
    [sym_integer_literal] = ACTIONS(3685),
    [sym_real_literal] = ACTIONS(3687),
    [anon_sym_DQUOTE] = ACTIONS(3687),
    [sym_verbatim_string_literal] = ACTIONS(3687),
    [aux_sym_preproc_if_token1] = ACTIONS(3687),
    [aux_sym_preproc_if_token3] = ACTIONS(3687),
    [aux_sym_preproc_else_token1] = ACTIONS(3687),
    [aux_sym_preproc_elif_token1] = ACTIONS(3687),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3687),
    [sym_interpolation_verbatim_start] = ACTIONS(3687),
    [sym_interpolation_raw_start] = ACTIONS(3687),
    [sym_raw_string_start] = ACTIONS(3687),
  },
  [2378] = {
    [sym_preproc_region] = STATE(2378),
    [sym_preproc_endregion] = STATE(2378),
    [sym_preproc_line] = STATE(2378),
    [sym_preproc_pragma] = STATE(2378),
    [sym_preproc_nullable] = STATE(2378),
    [sym_preproc_error] = STATE(2378),
    [sym_preproc_warning] = STATE(2378),
    [sym_preproc_define] = STATE(2378),
    [sym_preproc_undef] = STATE(2378),
    [sym__identifier_token] = ACTIONS(3689),
    [anon_sym_extern] = ACTIONS(3689),
    [anon_sym_alias] = ACTIONS(3689),
    [anon_sym_SEMI] = ACTIONS(3691),
    [anon_sym_global] = ACTIONS(3689),
    [anon_sym_using] = ACTIONS(3689),
    [anon_sym_unsafe] = ACTIONS(3689),
    [anon_sym_static] = ACTIONS(3689),
    [anon_sym_LBRACK] = ACTIONS(3691),
    [anon_sym_LPAREN] = ACTIONS(3691),
    [anon_sym_return] = ACTIONS(3689),
    [anon_sym_namespace] = ACTIONS(3689),
    [anon_sym_class] = ACTIONS(3689),
    [anon_sym_ref] = ACTIONS(3689),
    [anon_sym_struct] = ACTIONS(3689),
    [anon_sym_enum] = ACTIONS(3689),
    [anon_sym_LBRACE] = ACTIONS(3691),
    [anon_sym_interface] = ACTIONS(3689),
    [anon_sym_delegate] = ACTIONS(3689),
    [anon_sym_record] = ACTIONS(3689),
    [anon_sym_abstract] = ACTIONS(3689),
    [anon_sym_async] = ACTIONS(3689),
    [anon_sym_const] = ACTIONS(3689),
    [anon_sym_file] = ACTIONS(3689),
    [anon_sym_fixed] = ACTIONS(3689),
    [anon_sym_internal] = ACTIONS(3689),
    [anon_sym_new] = ACTIONS(3689),
    [anon_sym_override] = ACTIONS(3689),
    [anon_sym_partial] = ACTIONS(3689),
    [anon_sym_private] = ACTIONS(3689),
    [anon_sym_protected] = ACTIONS(3689),
    [anon_sym_public] = ACTIONS(3689),
    [anon_sym_readonly] = ACTIONS(3689),
    [anon_sym_required] = ACTIONS(3689),
    [anon_sym_sealed] = ACTIONS(3689),
    [anon_sym_virtual] = ACTIONS(3689),
    [anon_sym_volatile] = ACTIONS(3689),
    [anon_sym_where] = ACTIONS(3689),
    [anon_sym_notnull] = ACTIONS(3689),
    [anon_sym_unmanaged] = ACTIONS(3689),
    [anon_sym_checked] = ACTIONS(3689),
    [anon_sym_BANG] = ACTIONS(3691),
    [anon_sym_TILDE] = ACTIONS(3691),
    [anon_sym_PLUS_PLUS] = ACTIONS(3691),
    [anon_sym_DASH_DASH] = ACTIONS(3691),
    [anon_sym_true] = ACTIONS(3689),
    [anon_sym_false] = ACTIONS(3689),
    [anon_sym_PLUS] = ACTIONS(3689),
    [anon_sym_DASH] = ACTIONS(3689),
    [anon_sym_STAR] = ACTIONS(3691),
    [anon_sym_CARET] = ACTIONS(3691),
    [anon_sym_AMP] = ACTIONS(3691),
    [anon_sym_this] = ACTIONS(3689),
    [anon_sym_scoped] = ACTIONS(3689),
    [anon_sym_base] = ACTIONS(3689),
    [anon_sym_var] = ACTIONS(3689),
    [sym_predefined_type] = ACTIONS(3689),
    [anon_sym_break] = ACTIONS(3689),
    [anon_sym_unchecked] = ACTIONS(3689),
    [anon_sym_continue] = ACTIONS(3689),
    [anon_sym_do] = ACTIONS(3689),
    [anon_sym_while] = ACTIONS(3689),
    [anon_sym_for] = ACTIONS(3689),
    [anon_sym_lock] = ACTIONS(3689),
    [anon_sym_yield] = ACTIONS(3689),
    [anon_sym_switch] = ACTIONS(3689),
    [anon_sym_default] = ACTIONS(3689),
    [anon_sym_throw] = ACTIONS(3689),
    [anon_sym_try] = ACTIONS(3689),
    [anon_sym_when] = ACTIONS(3689),
    [anon_sym_await] = ACTIONS(3689),
    [anon_sym_foreach] = ACTIONS(3689),
    [anon_sym_goto] = ACTIONS(3689),
    [anon_sym_if] = ACTIONS(3689),
    [anon_sym_DOT_DOT] = ACTIONS(3691),
    [anon_sym_from] = ACTIONS(3689),
    [anon_sym_into] = ACTIONS(3689),
    [anon_sym_join] = ACTIONS(3689),
    [anon_sym_on] = ACTIONS(3689),
    [anon_sym_equals] = ACTIONS(3689),
    [anon_sym_let] = ACTIONS(3689),
    [anon_sym_orderby] = ACTIONS(3689),
    [anon_sym_ascending] = ACTIONS(3689),
    [anon_sym_descending] = ACTIONS(3689),
    [anon_sym_group] = ACTIONS(3689),
    [anon_sym_by] = ACTIONS(3689),
    [anon_sym_select] = ACTIONS(3689),
    [anon_sym_stackalloc] = ACTIONS(3689),
    [anon_sym_sizeof] = ACTIONS(3689),
    [anon_sym_typeof] = ACTIONS(3689),
    [anon_sym___makeref] = ACTIONS(3689),
    [anon_sym___reftype] = ACTIONS(3689),
    [anon_sym___refvalue] = ACTIONS(3689),
    [sym_null_literal] = ACTIONS(3689),
    [anon_sym_SQUOTE] = ACTIONS(3691),
    [sym_integer_literal] = ACTIONS(3689),
    [sym_real_literal] = ACTIONS(3691),
    [anon_sym_DQUOTE] = ACTIONS(3691),
    [sym_verbatim_string_literal] = ACTIONS(3691),
    [aux_sym_preproc_if_token1] = ACTIONS(3691),
    [aux_sym_preproc_if_token3] = ACTIONS(3691),
    [aux_sym_preproc_else_token1] = ACTIONS(3691),
    [aux_sym_preproc_elif_token1] = ACTIONS(3691),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3691),
    [sym_interpolation_verbatim_start] = ACTIONS(3691),
    [sym_interpolation_raw_start] = ACTIONS(3691),
    [sym_raw_string_start] = ACTIONS(3691),
  },
  [2379] = {
    [sym_preproc_region] = STATE(2379),
    [sym_preproc_endregion] = STATE(2379),
    [sym_preproc_line] = STATE(2379),
    [sym_preproc_pragma] = STATE(2379),
    [sym_preproc_nullable] = STATE(2379),
    [sym_preproc_error] = STATE(2379),
    [sym_preproc_warning] = STATE(2379),
    [sym_preproc_define] = STATE(2379),
    [sym_preproc_undef] = STATE(2379),
    [sym__identifier_token] = ACTIONS(3693),
    [anon_sym_extern] = ACTIONS(3693),
    [anon_sym_alias] = ACTIONS(3693),
    [anon_sym_SEMI] = ACTIONS(3695),
    [anon_sym_global] = ACTIONS(3693),
    [anon_sym_using] = ACTIONS(3693),
    [anon_sym_unsafe] = ACTIONS(3693),
    [anon_sym_static] = ACTIONS(3693),
    [anon_sym_LBRACK] = ACTIONS(3695),
    [anon_sym_LPAREN] = ACTIONS(3695),
    [anon_sym_return] = ACTIONS(3693),
    [anon_sym_namespace] = ACTIONS(3693),
    [anon_sym_class] = ACTIONS(3693),
    [anon_sym_ref] = ACTIONS(3693),
    [anon_sym_struct] = ACTIONS(3693),
    [anon_sym_enum] = ACTIONS(3693),
    [anon_sym_LBRACE] = ACTIONS(3695),
    [anon_sym_interface] = ACTIONS(3693),
    [anon_sym_delegate] = ACTIONS(3693),
    [anon_sym_record] = ACTIONS(3693),
    [anon_sym_abstract] = ACTIONS(3693),
    [anon_sym_async] = ACTIONS(3693),
    [anon_sym_const] = ACTIONS(3693),
    [anon_sym_file] = ACTIONS(3693),
    [anon_sym_fixed] = ACTIONS(3693),
    [anon_sym_internal] = ACTIONS(3693),
    [anon_sym_new] = ACTIONS(3693),
    [anon_sym_override] = ACTIONS(3693),
    [anon_sym_partial] = ACTIONS(3693),
    [anon_sym_private] = ACTIONS(3693),
    [anon_sym_protected] = ACTIONS(3693),
    [anon_sym_public] = ACTIONS(3693),
    [anon_sym_readonly] = ACTIONS(3693),
    [anon_sym_required] = ACTIONS(3693),
    [anon_sym_sealed] = ACTIONS(3693),
    [anon_sym_virtual] = ACTIONS(3693),
    [anon_sym_volatile] = ACTIONS(3693),
    [anon_sym_where] = ACTIONS(3693),
    [anon_sym_notnull] = ACTIONS(3693),
    [anon_sym_unmanaged] = ACTIONS(3693),
    [anon_sym_checked] = ACTIONS(3693),
    [anon_sym_BANG] = ACTIONS(3695),
    [anon_sym_TILDE] = ACTIONS(3695),
    [anon_sym_PLUS_PLUS] = ACTIONS(3695),
    [anon_sym_DASH_DASH] = ACTIONS(3695),
    [anon_sym_true] = ACTIONS(3693),
    [anon_sym_false] = ACTIONS(3693),
    [anon_sym_PLUS] = ACTIONS(3693),
    [anon_sym_DASH] = ACTIONS(3693),
    [anon_sym_STAR] = ACTIONS(3695),
    [anon_sym_CARET] = ACTIONS(3695),
    [anon_sym_AMP] = ACTIONS(3695),
    [anon_sym_this] = ACTIONS(3693),
    [anon_sym_scoped] = ACTIONS(3693),
    [anon_sym_base] = ACTIONS(3693),
    [anon_sym_var] = ACTIONS(3693),
    [sym_predefined_type] = ACTIONS(3693),
    [anon_sym_break] = ACTIONS(3693),
    [anon_sym_unchecked] = ACTIONS(3693),
    [anon_sym_continue] = ACTIONS(3693),
    [anon_sym_do] = ACTIONS(3693),
    [anon_sym_while] = ACTIONS(3693),
    [anon_sym_for] = ACTIONS(3693),
    [anon_sym_lock] = ACTIONS(3693),
    [anon_sym_yield] = ACTIONS(3693),
    [anon_sym_switch] = ACTIONS(3693),
    [anon_sym_default] = ACTIONS(3693),
    [anon_sym_throw] = ACTIONS(3693),
    [anon_sym_try] = ACTIONS(3693),
    [anon_sym_when] = ACTIONS(3693),
    [anon_sym_await] = ACTIONS(3693),
    [anon_sym_foreach] = ACTIONS(3693),
    [anon_sym_goto] = ACTIONS(3693),
    [anon_sym_if] = ACTIONS(3693),
    [anon_sym_DOT_DOT] = ACTIONS(3695),
    [anon_sym_from] = ACTIONS(3693),
    [anon_sym_into] = ACTIONS(3693),
    [anon_sym_join] = ACTIONS(3693),
    [anon_sym_on] = ACTIONS(3693),
    [anon_sym_equals] = ACTIONS(3693),
    [anon_sym_let] = ACTIONS(3693),
    [anon_sym_orderby] = ACTIONS(3693),
    [anon_sym_ascending] = ACTIONS(3693),
    [anon_sym_descending] = ACTIONS(3693),
    [anon_sym_group] = ACTIONS(3693),
    [anon_sym_by] = ACTIONS(3693),
    [anon_sym_select] = ACTIONS(3693),
    [anon_sym_stackalloc] = ACTIONS(3693),
    [anon_sym_sizeof] = ACTIONS(3693),
    [anon_sym_typeof] = ACTIONS(3693),
    [anon_sym___makeref] = ACTIONS(3693),
    [anon_sym___reftype] = ACTIONS(3693),
    [anon_sym___refvalue] = ACTIONS(3693),
    [sym_null_literal] = ACTIONS(3693),
    [anon_sym_SQUOTE] = ACTIONS(3695),
    [sym_integer_literal] = ACTIONS(3693),
    [sym_real_literal] = ACTIONS(3695),
    [anon_sym_DQUOTE] = ACTIONS(3695),
    [sym_verbatim_string_literal] = ACTIONS(3695),
    [aux_sym_preproc_if_token1] = ACTIONS(3695),
    [aux_sym_preproc_if_token3] = ACTIONS(3695),
    [aux_sym_preproc_else_token1] = ACTIONS(3695),
    [aux_sym_preproc_elif_token1] = ACTIONS(3695),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3695),
    [sym_interpolation_verbatim_start] = ACTIONS(3695),
    [sym_interpolation_raw_start] = ACTIONS(3695),
    [sym_raw_string_start] = ACTIONS(3695),
  },
  [2380] = {
    [sym_preproc_region] = STATE(2380),
    [sym_preproc_endregion] = STATE(2380),
    [sym_preproc_line] = STATE(2380),
    [sym_preproc_pragma] = STATE(2380),
    [sym_preproc_nullable] = STATE(2380),
    [sym_preproc_error] = STATE(2380),
    [sym_preproc_warning] = STATE(2380),
    [sym_preproc_define] = STATE(2380),
    [sym_preproc_undef] = STATE(2380),
    [sym__identifier_token] = ACTIONS(3697),
    [anon_sym_extern] = ACTIONS(3697),
    [anon_sym_alias] = ACTIONS(3697),
    [anon_sym_SEMI] = ACTIONS(3699),
    [anon_sym_global] = ACTIONS(3697),
    [anon_sym_using] = ACTIONS(3697),
    [anon_sym_unsafe] = ACTIONS(3697),
    [anon_sym_static] = ACTIONS(3697),
    [anon_sym_LBRACK] = ACTIONS(3699),
    [anon_sym_LPAREN] = ACTIONS(3699),
    [anon_sym_return] = ACTIONS(3697),
    [anon_sym_namespace] = ACTIONS(3697),
    [anon_sym_class] = ACTIONS(3697),
    [anon_sym_ref] = ACTIONS(3697),
    [anon_sym_struct] = ACTIONS(3697),
    [anon_sym_enum] = ACTIONS(3697),
    [anon_sym_LBRACE] = ACTIONS(3699),
    [anon_sym_interface] = ACTIONS(3697),
    [anon_sym_delegate] = ACTIONS(3697),
    [anon_sym_record] = ACTIONS(3697),
    [anon_sym_abstract] = ACTIONS(3697),
    [anon_sym_async] = ACTIONS(3697),
    [anon_sym_const] = ACTIONS(3697),
    [anon_sym_file] = ACTIONS(3697),
    [anon_sym_fixed] = ACTIONS(3697),
    [anon_sym_internal] = ACTIONS(3697),
    [anon_sym_new] = ACTIONS(3697),
    [anon_sym_override] = ACTIONS(3697),
    [anon_sym_partial] = ACTIONS(3697),
    [anon_sym_private] = ACTIONS(3697),
    [anon_sym_protected] = ACTIONS(3697),
    [anon_sym_public] = ACTIONS(3697),
    [anon_sym_readonly] = ACTIONS(3697),
    [anon_sym_required] = ACTIONS(3697),
    [anon_sym_sealed] = ACTIONS(3697),
    [anon_sym_virtual] = ACTIONS(3697),
    [anon_sym_volatile] = ACTIONS(3697),
    [anon_sym_where] = ACTIONS(3697),
    [anon_sym_notnull] = ACTIONS(3697),
    [anon_sym_unmanaged] = ACTIONS(3697),
    [anon_sym_checked] = ACTIONS(3697),
    [anon_sym_BANG] = ACTIONS(3699),
    [anon_sym_TILDE] = ACTIONS(3699),
    [anon_sym_PLUS_PLUS] = ACTIONS(3699),
    [anon_sym_DASH_DASH] = ACTIONS(3699),
    [anon_sym_true] = ACTIONS(3697),
    [anon_sym_false] = ACTIONS(3697),
    [anon_sym_PLUS] = ACTIONS(3697),
    [anon_sym_DASH] = ACTIONS(3697),
    [anon_sym_STAR] = ACTIONS(3699),
    [anon_sym_CARET] = ACTIONS(3699),
    [anon_sym_AMP] = ACTIONS(3699),
    [anon_sym_this] = ACTIONS(3697),
    [anon_sym_scoped] = ACTIONS(3697),
    [anon_sym_base] = ACTIONS(3697),
    [anon_sym_var] = ACTIONS(3697),
    [sym_predefined_type] = ACTIONS(3697),
    [anon_sym_break] = ACTIONS(3697),
    [anon_sym_unchecked] = ACTIONS(3697),
    [anon_sym_continue] = ACTIONS(3697),
    [anon_sym_do] = ACTIONS(3697),
    [anon_sym_while] = ACTIONS(3697),
    [anon_sym_for] = ACTIONS(3697),
    [anon_sym_lock] = ACTIONS(3697),
    [anon_sym_yield] = ACTIONS(3697),
    [anon_sym_switch] = ACTIONS(3697),
    [anon_sym_default] = ACTIONS(3697),
    [anon_sym_throw] = ACTIONS(3697),
    [anon_sym_try] = ACTIONS(3697),
    [anon_sym_when] = ACTIONS(3697),
    [anon_sym_await] = ACTIONS(3697),
    [anon_sym_foreach] = ACTIONS(3697),
    [anon_sym_goto] = ACTIONS(3697),
    [anon_sym_if] = ACTIONS(3697),
    [anon_sym_DOT_DOT] = ACTIONS(3699),
    [anon_sym_from] = ACTIONS(3697),
    [anon_sym_into] = ACTIONS(3697),
    [anon_sym_join] = ACTIONS(3697),
    [anon_sym_on] = ACTIONS(3697),
    [anon_sym_equals] = ACTIONS(3697),
    [anon_sym_let] = ACTIONS(3697),
    [anon_sym_orderby] = ACTIONS(3697),
    [anon_sym_ascending] = ACTIONS(3697),
    [anon_sym_descending] = ACTIONS(3697),
    [anon_sym_group] = ACTIONS(3697),
    [anon_sym_by] = ACTIONS(3697),
    [anon_sym_select] = ACTIONS(3697),
    [anon_sym_stackalloc] = ACTIONS(3697),
    [anon_sym_sizeof] = ACTIONS(3697),
    [anon_sym_typeof] = ACTIONS(3697),
    [anon_sym___makeref] = ACTIONS(3697),
    [anon_sym___reftype] = ACTIONS(3697),
    [anon_sym___refvalue] = ACTIONS(3697),
    [sym_null_literal] = ACTIONS(3697),
    [anon_sym_SQUOTE] = ACTIONS(3699),
    [sym_integer_literal] = ACTIONS(3697),
    [sym_real_literal] = ACTIONS(3699),
    [anon_sym_DQUOTE] = ACTIONS(3699),
    [sym_verbatim_string_literal] = ACTIONS(3699),
    [aux_sym_preproc_if_token1] = ACTIONS(3699),
    [aux_sym_preproc_if_token3] = ACTIONS(3699),
    [aux_sym_preproc_else_token1] = ACTIONS(3699),
    [aux_sym_preproc_elif_token1] = ACTIONS(3699),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3699),
    [sym_interpolation_verbatim_start] = ACTIONS(3699),
    [sym_interpolation_raw_start] = ACTIONS(3699),
    [sym_raw_string_start] = ACTIONS(3699),
  },
  [2381] = {
    [sym_preproc_region] = STATE(2381),
    [sym_preproc_endregion] = STATE(2381),
    [sym_preproc_line] = STATE(2381),
    [sym_preproc_pragma] = STATE(2381),
    [sym_preproc_nullable] = STATE(2381),
    [sym_preproc_error] = STATE(2381),
    [sym_preproc_warning] = STATE(2381),
    [sym_preproc_define] = STATE(2381),
    [sym_preproc_undef] = STATE(2381),
    [sym__identifier_token] = ACTIONS(3701),
    [anon_sym_extern] = ACTIONS(3701),
    [anon_sym_alias] = ACTIONS(3701),
    [anon_sym_SEMI] = ACTIONS(3703),
    [anon_sym_global] = ACTIONS(3701),
    [anon_sym_using] = ACTIONS(3701),
    [anon_sym_unsafe] = ACTIONS(3701),
    [anon_sym_static] = ACTIONS(3701),
    [anon_sym_LBRACK] = ACTIONS(3703),
    [anon_sym_LPAREN] = ACTIONS(3703),
    [anon_sym_return] = ACTIONS(3701),
    [anon_sym_namespace] = ACTIONS(3701),
    [anon_sym_class] = ACTIONS(3701),
    [anon_sym_ref] = ACTIONS(3701),
    [anon_sym_struct] = ACTIONS(3701),
    [anon_sym_enum] = ACTIONS(3701),
    [anon_sym_LBRACE] = ACTIONS(3703),
    [anon_sym_interface] = ACTIONS(3701),
    [anon_sym_delegate] = ACTIONS(3701),
    [anon_sym_record] = ACTIONS(3701),
    [anon_sym_abstract] = ACTIONS(3701),
    [anon_sym_async] = ACTIONS(3701),
    [anon_sym_const] = ACTIONS(3701),
    [anon_sym_file] = ACTIONS(3701),
    [anon_sym_fixed] = ACTIONS(3701),
    [anon_sym_internal] = ACTIONS(3701),
    [anon_sym_new] = ACTIONS(3701),
    [anon_sym_override] = ACTIONS(3701),
    [anon_sym_partial] = ACTIONS(3701),
    [anon_sym_private] = ACTIONS(3701),
    [anon_sym_protected] = ACTIONS(3701),
    [anon_sym_public] = ACTIONS(3701),
    [anon_sym_readonly] = ACTIONS(3701),
    [anon_sym_required] = ACTIONS(3701),
    [anon_sym_sealed] = ACTIONS(3701),
    [anon_sym_virtual] = ACTIONS(3701),
    [anon_sym_volatile] = ACTIONS(3701),
    [anon_sym_where] = ACTIONS(3701),
    [anon_sym_notnull] = ACTIONS(3701),
    [anon_sym_unmanaged] = ACTIONS(3701),
    [anon_sym_checked] = ACTIONS(3701),
    [anon_sym_BANG] = ACTIONS(3703),
    [anon_sym_TILDE] = ACTIONS(3703),
    [anon_sym_PLUS_PLUS] = ACTIONS(3703),
    [anon_sym_DASH_DASH] = ACTIONS(3703),
    [anon_sym_true] = ACTIONS(3701),
    [anon_sym_false] = ACTIONS(3701),
    [anon_sym_PLUS] = ACTIONS(3701),
    [anon_sym_DASH] = ACTIONS(3701),
    [anon_sym_STAR] = ACTIONS(3703),
    [anon_sym_CARET] = ACTIONS(3703),
    [anon_sym_AMP] = ACTIONS(3703),
    [anon_sym_this] = ACTIONS(3701),
    [anon_sym_scoped] = ACTIONS(3701),
    [anon_sym_base] = ACTIONS(3701),
    [anon_sym_var] = ACTIONS(3701),
    [sym_predefined_type] = ACTIONS(3701),
    [anon_sym_break] = ACTIONS(3701),
    [anon_sym_unchecked] = ACTIONS(3701),
    [anon_sym_continue] = ACTIONS(3701),
    [anon_sym_do] = ACTIONS(3701),
    [anon_sym_while] = ACTIONS(3701),
    [anon_sym_for] = ACTIONS(3701),
    [anon_sym_lock] = ACTIONS(3701),
    [anon_sym_yield] = ACTIONS(3701),
    [anon_sym_switch] = ACTIONS(3701),
    [anon_sym_default] = ACTIONS(3701),
    [anon_sym_throw] = ACTIONS(3701),
    [anon_sym_try] = ACTIONS(3701),
    [anon_sym_when] = ACTIONS(3701),
    [anon_sym_await] = ACTIONS(3701),
    [anon_sym_foreach] = ACTIONS(3701),
    [anon_sym_goto] = ACTIONS(3701),
    [anon_sym_if] = ACTIONS(3701),
    [anon_sym_DOT_DOT] = ACTIONS(3703),
    [anon_sym_from] = ACTIONS(3701),
    [anon_sym_into] = ACTIONS(3701),
    [anon_sym_join] = ACTIONS(3701),
    [anon_sym_on] = ACTIONS(3701),
    [anon_sym_equals] = ACTIONS(3701),
    [anon_sym_let] = ACTIONS(3701),
    [anon_sym_orderby] = ACTIONS(3701),
    [anon_sym_ascending] = ACTIONS(3701),
    [anon_sym_descending] = ACTIONS(3701),
    [anon_sym_group] = ACTIONS(3701),
    [anon_sym_by] = ACTIONS(3701),
    [anon_sym_select] = ACTIONS(3701),
    [anon_sym_stackalloc] = ACTIONS(3701),
    [anon_sym_sizeof] = ACTIONS(3701),
    [anon_sym_typeof] = ACTIONS(3701),
    [anon_sym___makeref] = ACTIONS(3701),
    [anon_sym___reftype] = ACTIONS(3701),
    [anon_sym___refvalue] = ACTIONS(3701),
    [sym_null_literal] = ACTIONS(3701),
    [anon_sym_SQUOTE] = ACTIONS(3703),
    [sym_integer_literal] = ACTIONS(3701),
    [sym_real_literal] = ACTIONS(3703),
    [anon_sym_DQUOTE] = ACTIONS(3703),
    [sym_verbatim_string_literal] = ACTIONS(3703),
    [aux_sym_preproc_if_token1] = ACTIONS(3703),
    [aux_sym_preproc_if_token3] = ACTIONS(3703),
    [aux_sym_preproc_else_token1] = ACTIONS(3703),
    [aux_sym_preproc_elif_token1] = ACTIONS(3703),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3703),
    [sym_interpolation_verbatim_start] = ACTIONS(3703),
    [sym_interpolation_raw_start] = ACTIONS(3703),
    [sym_raw_string_start] = ACTIONS(3703),
  },
  [2382] = {
    [sym_preproc_region] = STATE(2382),
    [sym_preproc_endregion] = STATE(2382),
    [sym_preproc_line] = STATE(2382),
    [sym_preproc_pragma] = STATE(2382),
    [sym_preproc_nullable] = STATE(2382),
    [sym_preproc_error] = STATE(2382),
    [sym_preproc_warning] = STATE(2382),
    [sym_preproc_define] = STATE(2382),
    [sym_preproc_undef] = STATE(2382),
    [sym__identifier_token] = ACTIONS(3705),
    [anon_sym_extern] = ACTIONS(3705),
    [anon_sym_alias] = ACTIONS(3705),
    [anon_sym_SEMI] = ACTIONS(3707),
    [anon_sym_global] = ACTIONS(3705),
    [anon_sym_using] = ACTIONS(3705),
    [anon_sym_unsafe] = ACTIONS(3705),
    [anon_sym_static] = ACTIONS(3705),
    [anon_sym_LBRACK] = ACTIONS(3707),
    [anon_sym_LPAREN] = ACTIONS(3707),
    [anon_sym_return] = ACTIONS(3705),
    [anon_sym_namespace] = ACTIONS(3705),
    [anon_sym_class] = ACTIONS(3705),
    [anon_sym_ref] = ACTIONS(3705),
    [anon_sym_struct] = ACTIONS(3705),
    [anon_sym_enum] = ACTIONS(3705),
    [anon_sym_LBRACE] = ACTIONS(3707),
    [anon_sym_interface] = ACTIONS(3705),
    [anon_sym_delegate] = ACTIONS(3705),
    [anon_sym_record] = ACTIONS(3705),
    [anon_sym_abstract] = ACTIONS(3705),
    [anon_sym_async] = ACTIONS(3705),
    [anon_sym_const] = ACTIONS(3705),
    [anon_sym_file] = ACTIONS(3705),
    [anon_sym_fixed] = ACTIONS(3705),
    [anon_sym_internal] = ACTIONS(3705),
    [anon_sym_new] = ACTIONS(3705),
    [anon_sym_override] = ACTIONS(3705),
    [anon_sym_partial] = ACTIONS(3705),
    [anon_sym_private] = ACTIONS(3705),
    [anon_sym_protected] = ACTIONS(3705),
    [anon_sym_public] = ACTIONS(3705),
    [anon_sym_readonly] = ACTIONS(3705),
    [anon_sym_required] = ACTIONS(3705),
    [anon_sym_sealed] = ACTIONS(3705),
    [anon_sym_virtual] = ACTIONS(3705),
    [anon_sym_volatile] = ACTIONS(3705),
    [anon_sym_where] = ACTIONS(3705),
    [anon_sym_notnull] = ACTIONS(3705),
    [anon_sym_unmanaged] = ACTIONS(3705),
    [anon_sym_checked] = ACTIONS(3705),
    [anon_sym_BANG] = ACTIONS(3707),
    [anon_sym_TILDE] = ACTIONS(3707),
    [anon_sym_PLUS_PLUS] = ACTIONS(3707),
    [anon_sym_DASH_DASH] = ACTIONS(3707),
    [anon_sym_true] = ACTIONS(3705),
    [anon_sym_false] = ACTIONS(3705),
    [anon_sym_PLUS] = ACTIONS(3705),
    [anon_sym_DASH] = ACTIONS(3705),
    [anon_sym_STAR] = ACTIONS(3707),
    [anon_sym_CARET] = ACTIONS(3707),
    [anon_sym_AMP] = ACTIONS(3707),
    [anon_sym_this] = ACTIONS(3705),
    [anon_sym_scoped] = ACTIONS(3705),
    [anon_sym_base] = ACTIONS(3705),
    [anon_sym_var] = ACTIONS(3705),
    [sym_predefined_type] = ACTIONS(3705),
    [anon_sym_break] = ACTIONS(3705),
    [anon_sym_unchecked] = ACTIONS(3705),
    [anon_sym_continue] = ACTIONS(3705),
    [anon_sym_do] = ACTIONS(3705),
    [anon_sym_while] = ACTIONS(3705),
    [anon_sym_for] = ACTIONS(3705),
    [anon_sym_lock] = ACTIONS(3705),
    [anon_sym_yield] = ACTIONS(3705),
    [anon_sym_switch] = ACTIONS(3705),
    [anon_sym_default] = ACTIONS(3705),
    [anon_sym_throw] = ACTIONS(3705),
    [anon_sym_try] = ACTIONS(3705),
    [anon_sym_when] = ACTIONS(3705),
    [anon_sym_await] = ACTIONS(3705),
    [anon_sym_foreach] = ACTIONS(3705),
    [anon_sym_goto] = ACTIONS(3705),
    [anon_sym_if] = ACTIONS(3705),
    [anon_sym_DOT_DOT] = ACTIONS(3707),
    [anon_sym_from] = ACTIONS(3705),
    [anon_sym_into] = ACTIONS(3705),
    [anon_sym_join] = ACTIONS(3705),
    [anon_sym_on] = ACTIONS(3705),
    [anon_sym_equals] = ACTIONS(3705),
    [anon_sym_let] = ACTIONS(3705),
    [anon_sym_orderby] = ACTIONS(3705),
    [anon_sym_ascending] = ACTIONS(3705),
    [anon_sym_descending] = ACTIONS(3705),
    [anon_sym_group] = ACTIONS(3705),
    [anon_sym_by] = ACTIONS(3705),
    [anon_sym_select] = ACTIONS(3705),
    [anon_sym_stackalloc] = ACTIONS(3705),
    [anon_sym_sizeof] = ACTIONS(3705),
    [anon_sym_typeof] = ACTIONS(3705),
    [anon_sym___makeref] = ACTIONS(3705),
    [anon_sym___reftype] = ACTIONS(3705),
    [anon_sym___refvalue] = ACTIONS(3705),
    [sym_null_literal] = ACTIONS(3705),
    [anon_sym_SQUOTE] = ACTIONS(3707),
    [sym_integer_literal] = ACTIONS(3705),
    [sym_real_literal] = ACTIONS(3707),
    [anon_sym_DQUOTE] = ACTIONS(3707),
    [sym_verbatim_string_literal] = ACTIONS(3707),
    [aux_sym_preproc_if_token1] = ACTIONS(3707),
    [aux_sym_preproc_if_token3] = ACTIONS(3707),
    [aux_sym_preproc_else_token1] = ACTIONS(3707),
    [aux_sym_preproc_elif_token1] = ACTIONS(3707),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3707),
    [sym_interpolation_verbatim_start] = ACTIONS(3707),
    [sym_interpolation_raw_start] = ACTIONS(3707),
    [sym_raw_string_start] = ACTIONS(3707),
  },
  [2383] = {
    [sym_preproc_region] = STATE(2383),
    [sym_preproc_endregion] = STATE(2383),
    [sym_preproc_line] = STATE(2383),
    [sym_preproc_pragma] = STATE(2383),
    [sym_preproc_nullable] = STATE(2383),
    [sym_preproc_error] = STATE(2383),
    [sym_preproc_warning] = STATE(2383),
    [sym_preproc_define] = STATE(2383),
    [sym_preproc_undef] = STATE(2383),
    [sym__identifier_token] = ACTIONS(3709),
    [anon_sym_extern] = ACTIONS(3709),
    [anon_sym_alias] = ACTIONS(3709),
    [anon_sym_SEMI] = ACTIONS(3711),
    [anon_sym_global] = ACTIONS(3709),
    [anon_sym_using] = ACTIONS(3709),
    [anon_sym_unsafe] = ACTIONS(3709),
    [anon_sym_static] = ACTIONS(3709),
    [anon_sym_LBRACK] = ACTIONS(3711),
    [anon_sym_LPAREN] = ACTIONS(3711),
    [anon_sym_return] = ACTIONS(3709),
    [anon_sym_namespace] = ACTIONS(3709),
    [anon_sym_class] = ACTIONS(3709),
    [anon_sym_ref] = ACTIONS(3709),
    [anon_sym_struct] = ACTIONS(3709),
    [anon_sym_enum] = ACTIONS(3709),
    [anon_sym_LBRACE] = ACTIONS(3711),
    [anon_sym_interface] = ACTIONS(3709),
    [anon_sym_delegate] = ACTIONS(3709),
    [anon_sym_record] = ACTIONS(3709),
    [anon_sym_abstract] = ACTIONS(3709),
    [anon_sym_async] = ACTIONS(3709),
    [anon_sym_const] = ACTIONS(3709),
    [anon_sym_file] = ACTIONS(3709),
    [anon_sym_fixed] = ACTIONS(3709),
    [anon_sym_internal] = ACTIONS(3709),
    [anon_sym_new] = ACTIONS(3709),
    [anon_sym_override] = ACTIONS(3709),
    [anon_sym_partial] = ACTIONS(3709),
    [anon_sym_private] = ACTIONS(3709),
    [anon_sym_protected] = ACTIONS(3709),
    [anon_sym_public] = ACTIONS(3709),
    [anon_sym_readonly] = ACTIONS(3709),
    [anon_sym_required] = ACTIONS(3709),
    [anon_sym_sealed] = ACTIONS(3709),
    [anon_sym_virtual] = ACTIONS(3709),
    [anon_sym_volatile] = ACTIONS(3709),
    [anon_sym_where] = ACTIONS(3709),
    [anon_sym_notnull] = ACTIONS(3709),
    [anon_sym_unmanaged] = ACTIONS(3709),
    [anon_sym_checked] = ACTIONS(3709),
    [anon_sym_BANG] = ACTIONS(3711),
    [anon_sym_TILDE] = ACTIONS(3711),
    [anon_sym_PLUS_PLUS] = ACTIONS(3711),
    [anon_sym_DASH_DASH] = ACTIONS(3711),
    [anon_sym_true] = ACTIONS(3709),
    [anon_sym_false] = ACTIONS(3709),
    [anon_sym_PLUS] = ACTIONS(3709),
    [anon_sym_DASH] = ACTIONS(3709),
    [anon_sym_STAR] = ACTIONS(3711),
    [anon_sym_CARET] = ACTIONS(3711),
    [anon_sym_AMP] = ACTIONS(3711),
    [anon_sym_this] = ACTIONS(3709),
    [anon_sym_scoped] = ACTIONS(3709),
    [anon_sym_base] = ACTIONS(3709),
    [anon_sym_var] = ACTIONS(3709),
    [sym_predefined_type] = ACTIONS(3709),
    [anon_sym_break] = ACTIONS(3709),
    [anon_sym_unchecked] = ACTIONS(3709),
    [anon_sym_continue] = ACTIONS(3709),
    [anon_sym_do] = ACTIONS(3709),
    [anon_sym_while] = ACTIONS(3709),
    [anon_sym_for] = ACTIONS(3709),
    [anon_sym_lock] = ACTIONS(3709),
    [anon_sym_yield] = ACTIONS(3709),
    [anon_sym_switch] = ACTIONS(3709),
    [anon_sym_default] = ACTIONS(3709),
    [anon_sym_throw] = ACTIONS(3709),
    [anon_sym_try] = ACTIONS(3709),
    [anon_sym_when] = ACTIONS(3709),
    [anon_sym_await] = ACTIONS(3709),
    [anon_sym_foreach] = ACTIONS(3709),
    [anon_sym_goto] = ACTIONS(3709),
    [anon_sym_if] = ACTIONS(3709),
    [anon_sym_DOT_DOT] = ACTIONS(3711),
    [anon_sym_from] = ACTIONS(3709),
    [anon_sym_into] = ACTIONS(3709),
    [anon_sym_join] = ACTIONS(3709),
    [anon_sym_on] = ACTIONS(3709),
    [anon_sym_equals] = ACTIONS(3709),
    [anon_sym_let] = ACTIONS(3709),
    [anon_sym_orderby] = ACTIONS(3709),
    [anon_sym_ascending] = ACTIONS(3709),
    [anon_sym_descending] = ACTIONS(3709),
    [anon_sym_group] = ACTIONS(3709),
    [anon_sym_by] = ACTIONS(3709),
    [anon_sym_select] = ACTIONS(3709),
    [anon_sym_stackalloc] = ACTIONS(3709),
    [anon_sym_sizeof] = ACTIONS(3709),
    [anon_sym_typeof] = ACTIONS(3709),
    [anon_sym___makeref] = ACTIONS(3709),
    [anon_sym___reftype] = ACTIONS(3709),
    [anon_sym___refvalue] = ACTIONS(3709),
    [sym_null_literal] = ACTIONS(3709),
    [anon_sym_SQUOTE] = ACTIONS(3711),
    [sym_integer_literal] = ACTIONS(3709),
    [sym_real_literal] = ACTIONS(3711),
    [anon_sym_DQUOTE] = ACTIONS(3711),
    [sym_verbatim_string_literal] = ACTIONS(3711),
    [aux_sym_preproc_if_token1] = ACTIONS(3711),
    [aux_sym_preproc_if_token3] = ACTIONS(3711),
    [aux_sym_preproc_else_token1] = ACTIONS(3711),
    [aux_sym_preproc_elif_token1] = ACTIONS(3711),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3711),
    [sym_interpolation_verbatim_start] = ACTIONS(3711),
    [sym_interpolation_raw_start] = ACTIONS(3711),
    [sym_raw_string_start] = ACTIONS(3711),
  },
  [2384] = {
    [sym_preproc_region] = STATE(2384),
    [sym_preproc_endregion] = STATE(2384),
    [sym_preproc_line] = STATE(2384),
    [sym_preproc_pragma] = STATE(2384),
    [sym_preproc_nullable] = STATE(2384),
    [sym_preproc_error] = STATE(2384),
    [sym_preproc_warning] = STATE(2384),
    [sym_preproc_define] = STATE(2384),
    [sym_preproc_undef] = STATE(2384),
    [sym__identifier_token] = ACTIONS(3713),
    [anon_sym_extern] = ACTIONS(3713),
    [anon_sym_alias] = ACTIONS(3713),
    [anon_sym_SEMI] = ACTIONS(3715),
    [anon_sym_global] = ACTIONS(3713),
    [anon_sym_using] = ACTIONS(3713),
    [anon_sym_unsafe] = ACTIONS(3713),
    [anon_sym_static] = ACTIONS(3713),
    [anon_sym_LBRACK] = ACTIONS(3715),
    [anon_sym_LPAREN] = ACTIONS(3715),
    [anon_sym_return] = ACTIONS(3713),
    [anon_sym_namespace] = ACTIONS(3713),
    [anon_sym_class] = ACTIONS(3713),
    [anon_sym_ref] = ACTIONS(3713),
    [anon_sym_struct] = ACTIONS(3713),
    [anon_sym_enum] = ACTIONS(3713),
    [anon_sym_LBRACE] = ACTIONS(3715),
    [anon_sym_interface] = ACTIONS(3713),
    [anon_sym_delegate] = ACTIONS(3713),
    [anon_sym_record] = ACTIONS(3713),
    [anon_sym_abstract] = ACTIONS(3713),
    [anon_sym_async] = ACTIONS(3713),
    [anon_sym_const] = ACTIONS(3713),
    [anon_sym_file] = ACTIONS(3713),
    [anon_sym_fixed] = ACTIONS(3713),
    [anon_sym_internal] = ACTIONS(3713),
    [anon_sym_new] = ACTIONS(3713),
    [anon_sym_override] = ACTIONS(3713),
    [anon_sym_partial] = ACTIONS(3713),
    [anon_sym_private] = ACTIONS(3713),
    [anon_sym_protected] = ACTIONS(3713),
    [anon_sym_public] = ACTIONS(3713),
    [anon_sym_readonly] = ACTIONS(3713),
    [anon_sym_required] = ACTIONS(3713),
    [anon_sym_sealed] = ACTIONS(3713),
    [anon_sym_virtual] = ACTIONS(3713),
    [anon_sym_volatile] = ACTIONS(3713),
    [anon_sym_where] = ACTIONS(3713),
    [anon_sym_notnull] = ACTIONS(3713),
    [anon_sym_unmanaged] = ACTIONS(3713),
    [anon_sym_checked] = ACTIONS(3713),
    [anon_sym_BANG] = ACTIONS(3715),
    [anon_sym_TILDE] = ACTIONS(3715),
    [anon_sym_PLUS_PLUS] = ACTIONS(3715),
    [anon_sym_DASH_DASH] = ACTIONS(3715),
    [anon_sym_true] = ACTIONS(3713),
    [anon_sym_false] = ACTIONS(3713),
    [anon_sym_PLUS] = ACTIONS(3713),
    [anon_sym_DASH] = ACTIONS(3713),
    [anon_sym_STAR] = ACTIONS(3715),
    [anon_sym_CARET] = ACTIONS(3715),
    [anon_sym_AMP] = ACTIONS(3715),
    [anon_sym_this] = ACTIONS(3713),
    [anon_sym_scoped] = ACTIONS(3713),
    [anon_sym_base] = ACTIONS(3713),
    [anon_sym_var] = ACTIONS(3713),
    [sym_predefined_type] = ACTIONS(3713),
    [anon_sym_break] = ACTIONS(3713),
    [anon_sym_unchecked] = ACTIONS(3713),
    [anon_sym_continue] = ACTIONS(3713),
    [anon_sym_do] = ACTIONS(3713),
    [anon_sym_while] = ACTIONS(3713),
    [anon_sym_for] = ACTIONS(3713),
    [anon_sym_lock] = ACTIONS(3713),
    [anon_sym_yield] = ACTIONS(3713),
    [anon_sym_switch] = ACTIONS(3713),
    [anon_sym_default] = ACTIONS(3713),
    [anon_sym_throw] = ACTIONS(3713),
    [anon_sym_try] = ACTIONS(3713),
    [anon_sym_when] = ACTIONS(3713),
    [anon_sym_await] = ACTIONS(3713),
    [anon_sym_foreach] = ACTIONS(3713),
    [anon_sym_goto] = ACTIONS(3713),
    [anon_sym_if] = ACTIONS(3713),
    [anon_sym_DOT_DOT] = ACTIONS(3715),
    [anon_sym_from] = ACTIONS(3713),
    [anon_sym_into] = ACTIONS(3713),
    [anon_sym_join] = ACTIONS(3713),
    [anon_sym_on] = ACTIONS(3713),
    [anon_sym_equals] = ACTIONS(3713),
    [anon_sym_let] = ACTIONS(3713),
    [anon_sym_orderby] = ACTIONS(3713),
    [anon_sym_ascending] = ACTIONS(3713),
    [anon_sym_descending] = ACTIONS(3713),
    [anon_sym_group] = ACTIONS(3713),
    [anon_sym_by] = ACTIONS(3713),
    [anon_sym_select] = ACTIONS(3713),
    [anon_sym_stackalloc] = ACTIONS(3713),
    [anon_sym_sizeof] = ACTIONS(3713),
    [anon_sym_typeof] = ACTIONS(3713),
    [anon_sym___makeref] = ACTIONS(3713),
    [anon_sym___reftype] = ACTIONS(3713),
    [anon_sym___refvalue] = ACTIONS(3713),
    [sym_null_literal] = ACTIONS(3713),
    [anon_sym_SQUOTE] = ACTIONS(3715),
    [sym_integer_literal] = ACTIONS(3713),
    [sym_real_literal] = ACTIONS(3715),
    [anon_sym_DQUOTE] = ACTIONS(3715),
    [sym_verbatim_string_literal] = ACTIONS(3715),
    [aux_sym_preproc_if_token1] = ACTIONS(3715),
    [aux_sym_preproc_if_token3] = ACTIONS(3715),
    [aux_sym_preproc_else_token1] = ACTIONS(3715),
    [aux_sym_preproc_elif_token1] = ACTIONS(3715),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3715),
    [sym_interpolation_verbatim_start] = ACTIONS(3715),
    [sym_interpolation_raw_start] = ACTIONS(3715),
    [sym_raw_string_start] = ACTIONS(3715),
  },
  [2385] = {
    [sym_preproc_region] = STATE(2385),
    [sym_preproc_endregion] = STATE(2385),
    [sym_preproc_line] = STATE(2385),
    [sym_preproc_pragma] = STATE(2385),
    [sym_preproc_nullable] = STATE(2385),
    [sym_preproc_error] = STATE(2385),
    [sym_preproc_warning] = STATE(2385),
    [sym_preproc_define] = STATE(2385),
    [sym_preproc_undef] = STATE(2385),
    [sym__identifier_token] = ACTIONS(3717),
    [anon_sym_extern] = ACTIONS(3717),
    [anon_sym_alias] = ACTIONS(3717),
    [anon_sym_SEMI] = ACTIONS(3719),
    [anon_sym_global] = ACTIONS(3717),
    [anon_sym_using] = ACTIONS(3717),
    [anon_sym_unsafe] = ACTIONS(3717),
    [anon_sym_static] = ACTIONS(3717),
    [anon_sym_LBRACK] = ACTIONS(3719),
    [anon_sym_LPAREN] = ACTIONS(3719),
    [anon_sym_return] = ACTIONS(3717),
    [anon_sym_namespace] = ACTIONS(3717),
    [anon_sym_class] = ACTIONS(3717),
    [anon_sym_ref] = ACTIONS(3717),
    [anon_sym_struct] = ACTIONS(3717),
    [anon_sym_enum] = ACTIONS(3717),
    [anon_sym_LBRACE] = ACTIONS(3719),
    [anon_sym_interface] = ACTIONS(3717),
    [anon_sym_delegate] = ACTIONS(3717),
    [anon_sym_record] = ACTIONS(3717),
    [anon_sym_abstract] = ACTIONS(3717),
    [anon_sym_async] = ACTIONS(3717),
    [anon_sym_const] = ACTIONS(3717),
    [anon_sym_file] = ACTIONS(3717),
    [anon_sym_fixed] = ACTIONS(3717),
    [anon_sym_internal] = ACTIONS(3717),
    [anon_sym_new] = ACTIONS(3717),
    [anon_sym_override] = ACTIONS(3717),
    [anon_sym_partial] = ACTIONS(3717),
    [anon_sym_private] = ACTIONS(3717),
    [anon_sym_protected] = ACTIONS(3717),
    [anon_sym_public] = ACTIONS(3717),
    [anon_sym_readonly] = ACTIONS(3717),
    [anon_sym_required] = ACTIONS(3717),
    [anon_sym_sealed] = ACTIONS(3717),
    [anon_sym_virtual] = ACTIONS(3717),
    [anon_sym_volatile] = ACTIONS(3717),
    [anon_sym_where] = ACTIONS(3717),
    [anon_sym_notnull] = ACTIONS(3717),
    [anon_sym_unmanaged] = ACTIONS(3717),
    [anon_sym_checked] = ACTIONS(3717),
    [anon_sym_BANG] = ACTIONS(3719),
    [anon_sym_TILDE] = ACTIONS(3719),
    [anon_sym_PLUS_PLUS] = ACTIONS(3719),
    [anon_sym_DASH_DASH] = ACTIONS(3719),
    [anon_sym_true] = ACTIONS(3717),
    [anon_sym_false] = ACTIONS(3717),
    [anon_sym_PLUS] = ACTIONS(3717),
    [anon_sym_DASH] = ACTIONS(3717),
    [anon_sym_STAR] = ACTIONS(3719),
    [anon_sym_CARET] = ACTIONS(3719),
    [anon_sym_AMP] = ACTIONS(3719),
    [anon_sym_this] = ACTIONS(3717),
    [anon_sym_scoped] = ACTIONS(3717),
    [anon_sym_base] = ACTIONS(3717),
    [anon_sym_var] = ACTIONS(3717),
    [sym_predefined_type] = ACTIONS(3717),
    [anon_sym_break] = ACTIONS(3717),
    [anon_sym_unchecked] = ACTIONS(3717),
    [anon_sym_continue] = ACTIONS(3717),
    [anon_sym_do] = ACTIONS(3717),
    [anon_sym_while] = ACTIONS(3717),
    [anon_sym_for] = ACTIONS(3717),
    [anon_sym_lock] = ACTIONS(3717),
    [anon_sym_yield] = ACTIONS(3717),
    [anon_sym_switch] = ACTIONS(3717),
    [anon_sym_default] = ACTIONS(3717),
    [anon_sym_throw] = ACTIONS(3717),
    [anon_sym_try] = ACTIONS(3717),
    [anon_sym_when] = ACTIONS(3717),
    [anon_sym_await] = ACTIONS(3717),
    [anon_sym_foreach] = ACTIONS(3717),
    [anon_sym_goto] = ACTIONS(3717),
    [anon_sym_if] = ACTIONS(3717),
    [anon_sym_DOT_DOT] = ACTIONS(3719),
    [anon_sym_from] = ACTIONS(3717),
    [anon_sym_into] = ACTIONS(3717),
    [anon_sym_join] = ACTIONS(3717),
    [anon_sym_on] = ACTIONS(3717),
    [anon_sym_equals] = ACTIONS(3717),
    [anon_sym_let] = ACTIONS(3717),
    [anon_sym_orderby] = ACTIONS(3717),
    [anon_sym_ascending] = ACTIONS(3717),
    [anon_sym_descending] = ACTIONS(3717),
    [anon_sym_group] = ACTIONS(3717),
    [anon_sym_by] = ACTIONS(3717),
    [anon_sym_select] = ACTIONS(3717),
    [anon_sym_stackalloc] = ACTIONS(3717),
    [anon_sym_sizeof] = ACTIONS(3717),
    [anon_sym_typeof] = ACTIONS(3717),
    [anon_sym___makeref] = ACTIONS(3717),
    [anon_sym___reftype] = ACTIONS(3717),
    [anon_sym___refvalue] = ACTIONS(3717),
    [sym_null_literal] = ACTIONS(3717),
    [anon_sym_SQUOTE] = ACTIONS(3719),
    [sym_integer_literal] = ACTIONS(3717),
    [sym_real_literal] = ACTIONS(3719),
    [anon_sym_DQUOTE] = ACTIONS(3719),
    [sym_verbatim_string_literal] = ACTIONS(3719),
    [aux_sym_preproc_if_token1] = ACTIONS(3719),
    [aux_sym_preproc_if_token3] = ACTIONS(3719),
    [aux_sym_preproc_else_token1] = ACTIONS(3719),
    [aux_sym_preproc_elif_token1] = ACTIONS(3719),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3719),
    [sym_interpolation_verbatim_start] = ACTIONS(3719),
    [sym_interpolation_raw_start] = ACTIONS(3719),
    [sym_raw_string_start] = ACTIONS(3719),
  },
  [2386] = {
    [sym_preproc_region] = STATE(2386),
    [sym_preproc_endregion] = STATE(2386),
    [sym_preproc_line] = STATE(2386),
    [sym_preproc_pragma] = STATE(2386),
    [sym_preproc_nullable] = STATE(2386),
    [sym_preproc_error] = STATE(2386),
    [sym_preproc_warning] = STATE(2386),
    [sym_preproc_define] = STATE(2386),
    [sym_preproc_undef] = STATE(2386),
    [sym__identifier_token] = ACTIONS(3721),
    [anon_sym_extern] = ACTIONS(3721),
    [anon_sym_alias] = ACTIONS(3721),
    [anon_sym_SEMI] = ACTIONS(3723),
    [anon_sym_global] = ACTIONS(3721),
    [anon_sym_using] = ACTIONS(3721),
    [anon_sym_unsafe] = ACTIONS(3721),
    [anon_sym_static] = ACTIONS(3721),
    [anon_sym_LBRACK] = ACTIONS(3723),
    [anon_sym_LPAREN] = ACTIONS(3723),
    [anon_sym_return] = ACTIONS(3721),
    [anon_sym_namespace] = ACTIONS(3721),
    [anon_sym_class] = ACTIONS(3721),
    [anon_sym_ref] = ACTIONS(3721),
    [anon_sym_struct] = ACTIONS(3721),
    [anon_sym_enum] = ACTIONS(3721),
    [anon_sym_LBRACE] = ACTIONS(3723),
    [anon_sym_interface] = ACTIONS(3721),
    [anon_sym_delegate] = ACTIONS(3721),
    [anon_sym_record] = ACTIONS(3721),
    [anon_sym_abstract] = ACTIONS(3721),
    [anon_sym_async] = ACTIONS(3721),
    [anon_sym_const] = ACTIONS(3721),
    [anon_sym_file] = ACTIONS(3721),
    [anon_sym_fixed] = ACTIONS(3721),
    [anon_sym_internal] = ACTIONS(3721),
    [anon_sym_new] = ACTIONS(3721),
    [anon_sym_override] = ACTIONS(3721),
    [anon_sym_partial] = ACTIONS(3721),
    [anon_sym_private] = ACTIONS(3721),
    [anon_sym_protected] = ACTIONS(3721),
    [anon_sym_public] = ACTIONS(3721),
    [anon_sym_readonly] = ACTIONS(3721),
    [anon_sym_required] = ACTIONS(3721),
    [anon_sym_sealed] = ACTIONS(3721),
    [anon_sym_virtual] = ACTIONS(3721),
    [anon_sym_volatile] = ACTIONS(3721),
    [anon_sym_where] = ACTIONS(3721),
    [anon_sym_notnull] = ACTIONS(3721),
    [anon_sym_unmanaged] = ACTIONS(3721),
    [anon_sym_checked] = ACTIONS(3721),
    [anon_sym_BANG] = ACTIONS(3723),
    [anon_sym_TILDE] = ACTIONS(3723),
    [anon_sym_PLUS_PLUS] = ACTIONS(3723),
    [anon_sym_DASH_DASH] = ACTIONS(3723),
    [anon_sym_true] = ACTIONS(3721),
    [anon_sym_false] = ACTIONS(3721),
    [anon_sym_PLUS] = ACTIONS(3721),
    [anon_sym_DASH] = ACTIONS(3721),
    [anon_sym_STAR] = ACTIONS(3723),
    [anon_sym_CARET] = ACTIONS(3723),
    [anon_sym_AMP] = ACTIONS(3723),
    [anon_sym_this] = ACTIONS(3721),
    [anon_sym_scoped] = ACTIONS(3721),
    [anon_sym_base] = ACTIONS(3721),
    [anon_sym_var] = ACTIONS(3721),
    [sym_predefined_type] = ACTIONS(3721),
    [anon_sym_break] = ACTIONS(3721),
    [anon_sym_unchecked] = ACTIONS(3721),
    [anon_sym_continue] = ACTIONS(3721),
    [anon_sym_do] = ACTIONS(3721),
    [anon_sym_while] = ACTIONS(3721),
    [anon_sym_for] = ACTIONS(3721),
    [anon_sym_lock] = ACTIONS(3721),
    [anon_sym_yield] = ACTIONS(3721),
    [anon_sym_switch] = ACTIONS(3721),
    [anon_sym_default] = ACTIONS(3721),
    [anon_sym_throw] = ACTIONS(3721),
    [anon_sym_try] = ACTIONS(3721),
    [anon_sym_when] = ACTIONS(3721),
    [anon_sym_await] = ACTIONS(3721),
    [anon_sym_foreach] = ACTIONS(3721),
    [anon_sym_goto] = ACTIONS(3721),
    [anon_sym_if] = ACTIONS(3721),
    [anon_sym_DOT_DOT] = ACTIONS(3723),
    [anon_sym_from] = ACTIONS(3721),
    [anon_sym_into] = ACTIONS(3721),
    [anon_sym_join] = ACTIONS(3721),
    [anon_sym_on] = ACTIONS(3721),
    [anon_sym_equals] = ACTIONS(3721),
    [anon_sym_let] = ACTIONS(3721),
    [anon_sym_orderby] = ACTIONS(3721),
    [anon_sym_ascending] = ACTIONS(3721),
    [anon_sym_descending] = ACTIONS(3721),
    [anon_sym_group] = ACTIONS(3721),
    [anon_sym_by] = ACTIONS(3721),
    [anon_sym_select] = ACTIONS(3721),
    [anon_sym_stackalloc] = ACTIONS(3721),
    [anon_sym_sizeof] = ACTIONS(3721),
    [anon_sym_typeof] = ACTIONS(3721),
    [anon_sym___makeref] = ACTIONS(3721),
    [anon_sym___reftype] = ACTIONS(3721),
    [anon_sym___refvalue] = ACTIONS(3721),
    [sym_null_literal] = ACTIONS(3721),
    [anon_sym_SQUOTE] = ACTIONS(3723),
    [sym_integer_literal] = ACTIONS(3721),
    [sym_real_literal] = ACTIONS(3723),
    [anon_sym_DQUOTE] = ACTIONS(3723),
    [sym_verbatim_string_literal] = ACTIONS(3723),
    [aux_sym_preproc_if_token1] = ACTIONS(3723),
    [aux_sym_preproc_if_token3] = ACTIONS(3723),
    [aux_sym_preproc_else_token1] = ACTIONS(3723),
    [aux_sym_preproc_elif_token1] = ACTIONS(3723),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3723),
    [sym_interpolation_verbatim_start] = ACTIONS(3723),
    [sym_interpolation_raw_start] = ACTIONS(3723),
    [sym_raw_string_start] = ACTIONS(3723),
  },
  [2387] = {
    [sym_preproc_region] = STATE(2387),
    [sym_preproc_endregion] = STATE(2387),
    [sym_preproc_line] = STATE(2387),
    [sym_preproc_pragma] = STATE(2387),
    [sym_preproc_nullable] = STATE(2387),
    [sym_preproc_error] = STATE(2387),
    [sym_preproc_warning] = STATE(2387),
    [sym_preproc_define] = STATE(2387),
    [sym_preproc_undef] = STATE(2387),
    [sym__identifier_token] = ACTIONS(3725),
    [anon_sym_extern] = ACTIONS(3725),
    [anon_sym_alias] = ACTIONS(3725),
    [anon_sym_SEMI] = ACTIONS(3727),
    [anon_sym_global] = ACTIONS(3725),
    [anon_sym_using] = ACTIONS(3725),
    [anon_sym_unsafe] = ACTIONS(3725),
    [anon_sym_static] = ACTIONS(3725),
    [anon_sym_LBRACK] = ACTIONS(3727),
    [anon_sym_LPAREN] = ACTIONS(3727),
    [anon_sym_return] = ACTIONS(3725),
    [anon_sym_namespace] = ACTIONS(3725),
    [anon_sym_class] = ACTIONS(3725),
    [anon_sym_ref] = ACTIONS(3725),
    [anon_sym_struct] = ACTIONS(3725),
    [anon_sym_enum] = ACTIONS(3725),
    [anon_sym_LBRACE] = ACTIONS(3727),
    [anon_sym_interface] = ACTIONS(3725),
    [anon_sym_delegate] = ACTIONS(3725),
    [anon_sym_record] = ACTIONS(3725),
    [anon_sym_abstract] = ACTIONS(3725),
    [anon_sym_async] = ACTIONS(3725),
    [anon_sym_const] = ACTIONS(3725),
    [anon_sym_file] = ACTIONS(3725),
    [anon_sym_fixed] = ACTIONS(3725),
    [anon_sym_internal] = ACTIONS(3725),
    [anon_sym_new] = ACTIONS(3725),
    [anon_sym_override] = ACTIONS(3725),
    [anon_sym_partial] = ACTIONS(3725),
    [anon_sym_private] = ACTIONS(3725),
    [anon_sym_protected] = ACTIONS(3725),
    [anon_sym_public] = ACTIONS(3725),
    [anon_sym_readonly] = ACTIONS(3725),
    [anon_sym_required] = ACTIONS(3725),
    [anon_sym_sealed] = ACTIONS(3725),
    [anon_sym_virtual] = ACTIONS(3725),
    [anon_sym_volatile] = ACTIONS(3725),
    [anon_sym_where] = ACTIONS(3725),
    [anon_sym_notnull] = ACTIONS(3725),
    [anon_sym_unmanaged] = ACTIONS(3725),
    [anon_sym_checked] = ACTIONS(3725),
    [anon_sym_BANG] = ACTIONS(3727),
    [anon_sym_TILDE] = ACTIONS(3727),
    [anon_sym_PLUS_PLUS] = ACTIONS(3727),
    [anon_sym_DASH_DASH] = ACTIONS(3727),
    [anon_sym_true] = ACTIONS(3725),
    [anon_sym_false] = ACTIONS(3725),
    [anon_sym_PLUS] = ACTIONS(3725),
    [anon_sym_DASH] = ACTIONS(3725),
    [anon_sym_STAR] = ACTIONS(3727),
    [anon_sym_CARET] = ACTIONS(3727),
    [anon_sym_AMP] = ACTIONS(3727),
    [anon_sym_this] = ACTIONS(3725),
    [anon_sym_scoped] = ACTIONS(3725),
    [anon_sym_base] = ACTIONS(3725),
    [anon_sym_var] = ACTIONS(3725),
    [sym_predefined_type] = ACTIONS(3725),
    [anon_sym_break] = ACTIONS(3725),
    [anon_sym_unchecked] = ACTIONS(3725),
    [anon_sym_continue] = ACTIONS(3725),
    [anon_sym_do] = ACTIONS(3725),
    [anon_sym_while] = ACTIONS(3725),
    [anon_sym_for] = ACTIONS(3725),
    [anon_sym_lock] = ACTIONS(3725),
    [anon_sym_yield] = ACTIONS(3725),
    [anon_sym_switch] = ACTIONS(3725),
    [anon_sym_default] = ACTIONS(3725),
    [anon_sym_throw] = ACTIONS(3725),
    [anon_sym_try] = ACTIONS(3725),
    [anon_sym_when] = ACTIONS(3725),
    [anon_sym_await] = ACTIONS(3725),
    [anon_sym_foreach] = ACTIONS(3725),
    [anon_sym_goto] = ACTIONS(3725),
    [anon_sym_if] = ACTIONS(3725),
    [anon_sym_DOT_DOT] = ACTIONS(3727),
    [anon_sym_from] = ACTIONS(3725),
    [anon_sym_into] = ACTIONS(3725),
    [anon_sym_join] = ACTIONS(3725),
    [anon_sym_on] = ACTIONS(3725),
    [anon_sym_equals] = ACTIONS(3725),
    [anon_sym_let] = ACTIONS(3725),
    [anon_sym_orderby] = ACTIONS(3725),
    [anon_sym_ascending] = ACTIONS(3725),
    [anon_sym_descending] = ACTIONS(3725),
    [anon_sym_group] = ACTIONS(3725),
    [anon_sym_by] = ACTIONS(3725),
    [anon_sym_select] = ACTIONS(3725),
    [anon_sym_stackalloc] = ACTIONS(3725),
    [anon_sym_sizeof] = ACTIONS(3725),
    [anon_sym_typeof] = ACTIONS(3725),
    [anon_sym___makeref] = ACTIONS(3725),
    [anon_sym___reftype] = ACTIONS(3725),
    [anon_sym___refvalue] = ACTIONS(3725),
    [sym_null_literal] = ACTIONS(3725),
    [anon_sym_SQUOTE] = ACTIONS(3727),
    [sym_integer_literal] = ACTIONS(3725),
    [sym_real_literal] = ACTIONS(3727),
    [anon_sym_DQUOTE] = ACTIONS(3727),
    [sym_verbatim_string_literal] = ACTIONS(3727),
    [aux_sym_preproc_if_token1] = ACTIONS(3727),
    [aux_sym_preproc_if_token3] = ACTIONS(3727),
    [aux_sym_preproc_else_token1] = ACTIONS(3727),
    [aux_sym_preproc_elif_token1] = ACTIONS(3727),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3727),
    [sym_interpolation_verbatim_start] = ACTIONS(3727),
    [sym_interpolation_raw_start] = ACTIONS(3727),
    [sym_raw_string_start] = ACTIONS(3727),
  },
  [2388] = {
    [sym_preproc_region] = STATE(2388),
    [sym_preproc_endregion] = STATE(2388),
    [sym_preproc_line] = STATE(2388),
    [sym_preproc_pragma] = STATE(2388),
    [sym_preproc_nullable] = STATE(2388),
    [sym_preproc_error] = STATE(2388),
    [sym_preproc_warning] = STATE(2388),
    [sym_preproc_define] = STATE(2388),
    [sym_preproc_undef] = STATE(2388),
    [sym__identifier_token] = ACTIONS(3729),
    [anon_sym_extern] = ACTIONS(3729),
    [anon_sym_alias] = ACTIONS(3729),
    [anon_sym_SEMI] = ACTIONS(3731),
    [anon_sym_global] = ACTIONS(3729),
    [anon_sym_using] = ACTIONS(3729),
    [anon_sym_unsafe] = ACTIONS(3729),
    [anon_sym_static] = ACTIONS(3729),
    [anon_sym_LBRACK] = ACTIONS(3731),
    [anon_sym_LPAREN] = ACTIONS(3731),
    [anon_sym_return] = ACTIONS(3729),
    [anon_sym_namespace] = ACTIONS(3729),
    [anon_sym_class] = ACTIONS(3729),
    [anon_sym_ref] = ACTIONS(3729),
    [anon_sym_struct] = ACTIONS(3729),
    [anon_sym_enum] = ACTIONS(3729),
    [anon_sym_LBRACE] = ACTIONS(3731),
    [anon_sym_interface] = ACTIONS(3729),
    [anon_sym_delegate] = ACTIONS(3729),
    [anon_sym_record] = ACTIONS(3729),
    [anon_sym_abstract] = ACTIONS(3729),
    [anon_sym_async] = ACTIONS(3729),
    [anon_sym_const] = ACTIONS(3729),
    [anon_sym_file] = ACTIONS(3729),
    [anon_sym_fixed] = ACTIONS(3729),
    [anon_sym_internal] = ACTIONS(3729),
    [anon_sym_new] = ACTIONS(3729),
    [anon_sym_override] = ACTIONS(3729),
    [anon_sym_partial] = ACTIONS(3729),
    [anon_sym_private] = ACTIONS(3729),
    [anon_sym_protected] = ACTIONS(3729),
    [anon_sym_public] = ACTIONS(3729),
    [anon_sym_readonly] = ACTIONS(3729),
    [anon_sym_required] = ACTIONS(3729),
    [anon_sym_sealed] = ACTIONS(3729),
    [anon_sym_virtual] = ACTIONS(3729),
    [anon_sym_volatile] = ACTIONS(3729),
    [anon_sym_where] = ACTIONS(3729),
    [anon_sym_notnull] = ACTIONS(3729),
    [anon_sym_unmanaged] = ACTIONS(3729),
    [anon_sym_checked] = ACTIONS(3729),
    [anon_sym_BANG] = ACTIONS(3731),
    [anon_sym_TILDE] = ACTIONS(3731),
    [anon_sym_PLUS_PLUS] = ACTIONS(3731),
    [anon_sym_DASH_DASH] = ACTIONS(3731),
    [anon_sym_true] = ACTIONS(3729),
    [anon_sym_false] = ACTIONS(3729),
    [anon_sym_PLUS] = ACTIONS(3729),
    [anon_sym_DASH] = ACTIONS(3729),
    [anon_sym_STAR] = ACTIONS(3731),
    [anon_sym_CARET] = ACTIONS(3731),
    [anon_sym_AMP] = ACTIONS(3731),
    [anon_sym_this] = ACTIONS(3729),
    [anon_sym_scoped] = ACTIONS(3729),
    [anon_sym_base] = ACTIONS(3729),
    [anon_sym_var] = ACTIONS(3729),
    [sym_predefined_type] = ACTIONS(3729),
    [anon_sym_break] = ACTIONS(3729),
    [anon_sym_unchecked] = ACTIONS(3729),
    [anon_sym_continue] = ACTIONS(3729),
    [anon_sym_do] = ACTIONS(3729),
    [anon_sym_while] = ACTIONS(3729),
    [anon_sym_for] = ACTIONS(3729),
    [anon_sym_lock] = ACTIONS(3729),
    [anon_sym_yield] = ACTIONS(3729),
    [anon_sym_switch] = ACTIONS(3729),
    [anon_sym_default] = ACTIONS(3729),
    [anon_sym_throw] = ACTIONS(3729),
    [anon_sym_try] = ACTIONS(3729),
    [anon_sym_when] = ACTIONS(3729),
    [anon_sym_await] = ACTIONS(3729),
    [anon_sym_foreach] = ACTIONS(3729),
    [anon_sym_goto] = ACTIONS(3729),
    [anon_sym_if] = ACTIONS(3729),
    [anon_sym_DOT_DOT] = ACTIONS(3731),
    [anon_sym_from] = ACTIONS(3729),
    [anon_sym_into] = ACTIONS(3729),
    [anon_sym_join] = ACTIONS(3729),
    [anon_sym_on] = ACTIONS(3729),
    [anon_sym_equals] = ACTIONS(3729),
    [anon_sym_let] = ACTIONS(3729),
    [anon_sym_orderby] = ACTIONS(3729),
    [anon_sym_ascending] = ACTIONS(3729),
    [anon_sym_descending] = ACTIONS(3729),
    [anon_sym_group] = ACTIONS(3729),
    [anon_sym_by] = ACTIONS(3729),
    [anon_sym_select] = ACTIONS(3729),
    [anon_sym_stackalloc] = ACTIONS(3729),
    [anon_sym_sizeof] = ACTIONS(3729),
    [anon_sym_typeof] = ACTIONS(3729),
    [anon_sym___makeref] = ACTIONS(3729),
    [anon_sym___reftype] = ACTIONS(3729),
    [anon_sym___refvalue] = ACTIONS(3729),
    [sym_null_literal] = ACTIONS(3729),
    [anon_sym_SQUOTE] = ACTIONS(3731),
    [sym_integer_literal] = ACTIONS(3729),
    [sym_real_literal] = ACTIONS(3731),
    [anon_sym_DQUOTE] = ACTIONS(3731),
    [sym_verbatim_string_literal] = ACTIONS(3731),
    [aux_sym_preproc_if_token1] = ACTIONS(3731),
    [aux_sym_preproc_if_token3] = ACTIONS(3731),
    [aux_sym_preproc_else_token1] = ACTIONS(3731),
    [aux_sym_preproc_elif_token1] = ACTIONS(3731),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3731),
    [sym_interpolation_verbatim_start] = ACTIONS(3731),
    [sym_interpolation_raw_start] = ACTIONS(3731),
    [sym_raw_string_start] = ACTIONS(3731),
  },
  [2389] = {
    [sym_preproc_region] = STATE(2389),
    [sym_preproc_endregion] = STATE(2389),
    [sym_preproc_line] = STATE(2389),
    [sym_preproc_pragma] = STATE(2389),
    [sym_preproc_nullable] = STATE(2389),
    [sym_preproc_error] = STATE(2389),
    [sym_preproc_warning] = STATE(2389),
    [sym_preproc_define] = STATE(2389),
    [sym_preproc_undef] = STATE(2389),
    [sym__identifier_token] = ACTIONS(3733),
    [anon_sym_extern] = ACTIONS(3733),
    [anon_sym_alias] = ACTIONS(3733),
    [anon_sym_SEMI] = ACTIONS(3735),
    [anon_sym_global] = ACTIONS(3733),
    [anon_sym_using] = ACTIONS(3733),
    [anon_sym_unsafe] = ACTIONS(3733),
    [anon_sym_static] = ACTIONS(3733),
    [anon_sym_LBRACK] = ACTIONS(3735),
    [anon_sym_LPAREN] = ACTIONS(3735),
    [anon_sym_return] = ACTIONS(3733),
    [anon_sym_namespace] = ACTIONS(3733),
    [anon_sym_class] = ACTIONS(3733),
    [anon_sym_ref] = ACTIONS(3733),
    [anon_sym_struct] = ACTIONS(3733),
    [anon_sym_enum] = ACTIONS(3733),
    [anon_sym_LBRACE] = ACTIONS(3735),
    [anon_sym_interface] = ACTIONS(3733),
    [anon_sym_delegate] = ACTIONS(3733),
    [anon_sym_record] = ACTIONS(3733),
    [anon_sym_abstract] = ACTIONS(3733),
    [anon_sym_async] = ACTIONS(3733),
    [anon_sym_const] = ACTIONS(3733),
    [anon_sym_file] = ACTIONS(3733),
    [anon_sym_fixed] = ACTIONS(3733),
    [anon_sym_internal] = ACTIONS(3733),
    [anon_sym_new] = ACTIONS(3733),
    [anon_sym_override] = ACTIONS(3733),
    [anon_sym_partial] = ACTIONS(3733),
    [anon_sym_private] = ACTIONS(3733),
    [anon_sym_protected] = ACTIONS(3733),
    [anon_sym_public] = ACTIONS(3733),
    [anon_sym_readonly] = ACTIONS(3733),
    [anon_sym_required] = ACTIONS(3733),
    [anon_sym_sealed] = ACTIONS(3733),
    [anon_sym_virtual] = ACTIONS(3733),
    [anon_sym_volatile] = ACTIONS(3733),
    [anon_sym_where] = ACTIONS(3733),
    [anon_sym_notnull] = ACTIONS(3733),
    [anon_sym_unmanaged] = ACTIONS(3733),
    [anon_sym_checked] = ACTIONS(3733),
    [anon_sym_BANG] = ACTIONS(3735),
    [anon_sym_TILDE] = ACTIONS(3735),
    [anon_sym_PLUS_PLUS] = ACTIONS(3735),
    [anon_sym_DASH_DASH] = ACTIONS(3735),
    [anon_sym_true] = ACTIONS(3733),
    [anon_sym_false] = ACTIONS(3733),
    [anon_sym_PLUS] = ACTIONS(3733),
    [anon_sym_DASH] = ACTIONS(3733),
    [anon_sym_STAR] = ACTIONS(3735),
    [anon_sym_CARET] = ACTIONS(3735),
    [anon_sym_AMP] = ACTIONS(3735),
    [anon_sym_this] = ACTIONS(3733),
    [anon_sym_scoped] = ACTIONS(3733),
    [anon_sym_base] = ACTIONS(3733),
    [anon_sym_var] = ACTIONS(3733),
    [sym_predefined_type] = ACTIONS(3733),
    [anon_sym_break] = ACTIONS(3733),
    [anon_sym_unchecked] = ACTIONS(3733),
    [anon_sym_continue] = ACTIONS(3733),
    [anon_sym_do] = ACTIONS(3733),
    [anon_sym_while] = ACTIONS(3733),
    [anon_sym_for] = ACTIONS(3733),
    [anon_sym_lock] = ACTIONS(3733),
    [anon_sym_yield] = ACTIONS(3733),
    [anon_sym_switch] = ACTIONS(3733),
    [anon_sym_default] = ACTIONS(3733),
    [anon_sym_throw] = ACTIONS(3733),
    [anon_sym_try] = ACTIONS(3733),
    [anon_sym_when] = ACTIONS(3733),
    [anon_sym_await] = ACTIONS(3733),
    [anon_sym_foreach] = ACTIONS(3733),
    [anon_sym_goto] = ACTIONS(3733),
    [anon_sym_if] = ACTIONS(3733),
    [anon_sym_DOT_DOT] = ACTIONS(3735),
    [anon_sym_from] = ACTIONS(3733),
    [anon_sym_into] = ACTIONS(3733),
    [anon_sym_join] = ACTIONS(3733),
    [anon_sym_on] = ACTIONS(3733),
    [anon_sym_equals] = ACTIONS(3733),
    [anon_sym_let] = ACTIONS(3733),
    [anon_sym_orderby] = ACTIONS(3733),
    [anon_sym_ascending] = ACTIONS(3733),
    [anon_sym_descending] = ACTIONS(3733),
    [anon_sym_group] = ACTIONS(3733),
    [anon_sym_by] = ACTIONS(3733),
    [anon_sym_select] = ACTIONS(3733),
    [anon_sym_stackalloc] = ACTIONS(3733),
    [anon_sym_sizeof] = ACTIONS(3733),
    [anon_sym_typeof] = ACTIONS(3733),
    [anon_sym___makeref] = ACTIONS(3733),
    [anon_sym___reftype] = ACTIONS(3733),
    [anon_sym___refvalue] = ACTIONS(3733),
    [sym_null_literal] = ACTIONS(3733),
    [anon_sym_SQUOTE] = ACTIONS(3735),
    [sym_integer_literal] = ACTIONS(3733),
    [sym_real_literal] = ACTIONS(3735),
    [anon_sym_DQUOTE] = ACTIONS(3735),
    [sym_verbatim_string_literal] = ACTIONS(3735),
    [aux_sym_preproc_if_token1] = ACTIONS(3735),
    [aux_sym_preproc_if_token3] = ACTIONS(3735),
    [aux_sym_preproc_else_token1] = ACTIONS(3735),
    [aux_sym_preproc_elif_token1] = ACTIONS(3735),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3735),
    [sym_interpolation_verbatim_start] = ACTIONS(3735),
    [sym_interpolation_raw_start] = ACTIONS(3735),
    [sym_raw_string_start] = ACTIONS(3735),
  },
  [2390] = {
    [sym_preproc_region] = STATE(2390),
    [sym_preproc_endregion] = STATE(2390),
    [sym_preproc_line] = STATE(2390),
    [sym_preproc_pragma] = STATE(2390),
    [sym_preproc_nullable] = STATE(2390),
    [sym_preproc_error] = STATE(2390),
    [sym_preproc_warning] = STATE(2390),
    [sym_preproc_define] = STATE(2390),
    [sym_preproc_undef] = STATE(2390),
    [sym__identifier_token] = ACTIONS(3737),
    [anon_sym_extern] = ACTIONS(3737),
    [anon_sym_alias] = ACTIONS(3737),
    [anon_sym_SEMI] = ACTIONS(3739),
    [anon_sym_global] = ACTIONS(3737),
    [anon_sym_using] = ACTIONS(3737),
    [anon_sym_unsafe] = ACTIONS(3737),
    [anon_sym_static] = ACTIONS(3737),
    [anon_sym_LBRACK] = ACTIONS(3739),
    [anon_sym_LPAREN] = ACTIONS(3739),
    [anon_sym_return] = ACTIONS(3737),
    [anon_sym_namespace] = ACTIONS(3737),
    [anon_sym_class] = ACTIONS(3737),
    [anon_sym_ref] = ACTIONS(3737),
    [anon_sym_struct] = ACTIONS(3737),
    [anon_sym_enum] = ACTIONS(3737),
    [anon_sym_LBRACE] = ACTIONS(3739),
    [anon_sym_interface] = ACTIONS(3737),
    [anon_sym_delegate] = ACTIONS(3737),
    [anon_sym_record] = ACTIONS(3737),
    [anon_sym_abstract] = ACTIONS(3737),
    [anon_sym_async] = ACTIONS(3737),
    [anon_sym_const] = ACTIONS(3737),
    [anon_sym_file] = ACTIONS(3737),
    [anon_sym_fixed] = ACTIONS(3737),
    [anon_sym_internal] = ACTIONS(3737),
    [anon_sym_new] = ACTIONS(3737),
    [anon_sym_override] = ACTIONS(3737),
    [anon_sym_partial] = ACTIONS(3737),
    [anon_sym_private] = ACTIONS(3737),
    [anon_sym_protected] = ACTIONS(3737),
    [anon_sym_public] = ACTIONS(3737),
    [anon_sym_readonly] = ACTIONS(3737),
    [anon_sym_required] = ACTIONS(3737),
    [anon_sym_sealed] = ACTIONS(3737),
    [anon_sym_virtual] = ACTIONS(3737),
    [anon_sym_volatile] = ACTIONS(3737),
    [anon_sym_where] = ACTIONS(3737),
    [anon_sym_notnull] = ACTIONS(3737),
    [anon_sym_unmanaged] = ACTIONS(3737),
    [anon_sym_checked] = ACTIONS(3737),
    [anon_sym_BANG] = ACTIONS(3739),
    [anon_sym_TILDE] = ACTIONS(3739),
    [anon_sym_PLUS_PLUS] = ACTIONS(3739),
    [anon_sym_DASH_DASH] = ACTIONS(3739),
    [anon_sym_true] = ACTIONS(3737),
    [anon_sym_false] = ACTIONS(3737),
    [anon_sym_PLUS] = ACTIONS(3737),
    [anon_sym_DASH] = ACTIONS(3737),
    [anon_sym_STAR] = ACTIONS(3739),
    [anon_sym_CARET] = ACTIONS(3739),
    [anon_sym_AMP] = ACTIONS(3739),
    [anon_sym_this] = ACTIONS(3737),
    [anon_sym_scoped] = ACTIONS(3737),
    [anon_sym_base] = ACTIONS(3737),
    [anon_sym_var] = ACTIONS(3737),
    [sym_predefined_type] = ACTIONS(3737),
    [anon_sym_break] = ACTIONS(3737),
    [anon_sym_unchecked] = ACTIONS(3737),
    [anon_sym_continue] = ACTIONS(3737),
    [anon_sym_do] = ACTIONS(3737),
    [anon_sym_while] = ACTIONS(3737),
    [anon_sym_for] = ACTIONS(3737),
    [anon_sym_lock] = ACTIONS(3737),
    [anon_sym_yield] = ACTIONS(3737),
    [anon_sym_switch] = ACTIONS(3737),
    [anon_sym_default] = ACTIONS(3737),
    [anon_sym_throw] = ACTIONS(3737),
    [anon_sym_try] = ACTIONS(3737),
    [anon_sym_when] = ACTIONS(3737),
    [anon_sym_await] = ACTIONS(3737),
    [anon_sym_foreach] = ACTIONS(3737),
    [anon_sym_goto] = ACTIONS(3737),
    [anon_sym_if] = ACTIONS(3737),
    [anon_sym_DOT_DOT] = ACTIONS(3739),
    [anon_sym_from] = ACTIONS(3737),
    [anon_sym_into] = ACTIONS(3737),
    [anon_sym_join] = ACTIONS(3737),
    [anon_sym_on] = ACTIONS(3737),
    [anon_sym_equals] = ACTIONS(3737),
    [anon_sym_let] = ACTIONS(3737),
    [anon_sym_orderby] = ACTIONS(3737),
    [anon_sym_ascending] = ACTIONS(3737),
    [anon_sym_descending] = ACTIONS(3737),
    [anon_sym_group] = ACTIONS(3737),
    [anon_sym_by] = ACTIONS(3737),
    [anon_sym_select] = ACTIONS(3737),
    [anon_sym_stackalloc] = ACTIONS(3737),
    [anon_sym_sizeof] = ACTIONS(3737),
    [anon_sym_typeof] = ACTIONS(3737),
    [anon_sym___makeref] = ACTIONS(3737),
    [anon_sym___reftype] = ACTIONS(3737),
    [anon_sym___refvalue] = ACTIONS(3737),
    [sym_null_literal] = ACTIONS(3737),
    [anon_sym_SQUOTE] = ACTIONS(3739),
    [sym_integer_literal] = ACTIONS(3737),
    [sym_real_literal] = ACTIONS(3739),
    [anon_sym_DQUOTE] = ACTIONS(3739),
    [sym_verbatim_string_literal] = ACTIONS(3739),
    [aux_sym_preproc_if_token1] = ACTIONS(3739),
    [aux_sym_preproc_if_token3] = ACTIONS(3739),
    [aux_sym_preproc_else_token1] = ACTIONS(3739),
    [aux_sym_preproc_elif_token1] = ACTIONS(3739),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3739),
    [sym_interpolation_verbatim_start] = ACTIONS(3739),
    [sym_interpolation_raw_start] = ACTIONS(3739),
    [sym_raw_string_start] = ACTIONS(3739),
  },
  [2391] = {
    [sym_preproc_region] = STATE(2391),
    [sym_preproc_endregion] = STATE(2391),
    [sym_preproc_line] = STATE(2391),
    [sym_preproc_pragma] = STATE(2391),
    [sym_preproc_nullable] = STATE(2391),
    [sym_preproc_error] = STATE(2391),
    [sym_preproc_warning] = STATE(2391),
    [sym_preproc_define] = STATE(2391),
    [sym_preproc_undef] = STATE(2391),
    [sym__identifier_token] = ACTIONS(3741),
    [anon_sym_extern] = ACTIONS(3741),
    [anon_sym_alias] = ACTIONS(3741),
    [anon_sym_SEMI] = ACTIONS(3743),
    [anon_sym_global] = ACTIONS(3741),
    [anon_sym_using] = ACTIONS(3741),
    [anon_sym_unsafe] = ACTIONS(3741),
    [anon_sym_static] = ACTIONS(3741),
    [anon_sym_LBRACK] = ACTIONS(3743),
    [anon_sym_LPAREN] = ACTIONS(3743),
    [anon_sym_return] = ACTIONS(3741),
    [anon_sym_namespace] = ACTIONS(3741),
    [anon_sym_class] = ACTIONS(3741),
    [anon_sym_ref] = ACTIONS(3741),
    [anon_sym_struct] = ACTIONS(3741),
    [anon_sym_enum] = ACTIONS(3741),
    [anon_sym_LBRACE] = ACTIONS(3743),
    [anon_sym_interface] = ACTIONS(3741),
    [anon_sym_delegate] = ACTIONS(3741),
    [anon_sym_record] = ACTIONS(3741),
    [anon_sym_abstract] = ACTIONS(3741),
    [anon_sym_async] = ACTIONS(3741),
    [anon_sym_const] = ACTIONS(3741),
    [anon_sym_file] = ACTIONS(3741),
    [anon_sym_fixed] = ACTIONS(3741),
    [anon_sym_internal] = ACTIONS(3741),
    [anon_sym_new] = ACTIONS(3741),
    [anon_sym_override] = ACTIONS(3741),
    [anon_sym_partial] = ACTIONS(3741),
    [anon_sym_private] = ACTIONS(3741),
    [anon_sym_protected] = ACTIONS(3741),
    [anon_sym_public] = ACTIONS(3741),
    [anon_sym_readonly] = ACTIONS(3741),
    [anon_sym_required] = ACTIONS(3741),
    [anon_sym_sealed] = ACTIONS(3741),
    [anon_sym_virtual] = ACTIONS(3741),
    [anon_sym_volatile] = ACTIONS(3741),
    [anon_sym_where] = ACTIONS(3741),
    [anon_sym_notnull] = ACTIONS(3741),
    [anon_sym_unmanaged] = ACTIONS(3741),
    [anon_sym_checked] = ACTIONS(3741),
    [anon_sym_BANG] = ACTIONS(3743),
    [anon_sym_TILDE] = ACTIONS(3743),
    [anon_sym_PLUS_PLUS] = ACTIONS(3743),
    [anon_sym_DASH_DASH] = ACTIONS(3743),
    [anon_sym_true] = ACTIONS(3741),
    [anon_sym_false] = ACTIONS(3741),
    [anon_sym_PLUS] = ACTIONS(3741),
    [anon_sym_DASH] = ACTIONS(3741),
    [anon_sym_STAR] = ACTIONS(3743),
    [anon_sym_CARET] = ACTIONS(3743),
    [anon_sym_AMP] = ACTIONS(3743),
    [anon_sym_this] = ACTIONS(3741),
    [anon_sym_scoped] = ACTIONS(3741),
    [anon_sym_base] = ACTIONS(3741),
    [anon_sym_var] = ACTIONS(3741),
    [sym_predefined_type] = ACTIONS(3741),
    [anon_sym_break] = ACTIONS(3741),
    [anon_sym_unchecked] = ACTIONS(3741),
    [anon_sym_continue] = ACTIONS(3741),
    [anon_sym_do] = ACTIONS(3741),
    [anon_sym_while] = ACTIONS(3741),
    [anon_sym_for] = ACTIONS(3741),
    [anon_sym_lock] = ACTIONS(3741),
    [anon_sym_yield] = ACTIONS(3741),
    [anon_sym_switch] = ACTIONS(3741),
    [anon_sym_default] = ACTIONS(3741),
    [anon_sym_throw] = ACTIONS(3741),
    [anon_sym_try] = ACTIONS(3741),
    [anon_sym_when] = ACTIONS(3741),
    [anon_sym_await] = ACTIONS(3741),
    [anon_sym_foreach] = ACTIONS(3741),
    [anon_sym_goto] = ACTIONS(3741),
    [anon_sym_if] = ACTIONS(3741),
    [anon_sym_DOT_DOT] = ACTIONS(3743),
    [anon_sym_from] = ACTIONS(3741),
    [anon_sym_into] = ACTIONS(3741),
    [anon_sym_join] = ACTIONS(3741),
    [anon_sym_on] = ACTIONS(3741),
    [anon_sym_equals] = ACTIONS(3741),
    [anon_sym_let] = ACTIONS(3741),
    [anon_sym_orderby] = ACTIONS(3741),
    [anon_sym_ascending] = ACTIONS(3741),
    [anon_sym_descending] = ACTIONS(3741),
    [anon_sym_group] = ACTIONS(3741),
    [anon_sym_by] = ACTIONS(3741),
    [anon_sym_select] = ACTIONS(3741),
    [anon_sym_stackalloc] = ACTIONS(3741),
    [anon_sym_sizeof] = ACTIONS(3741),
    [anon_sym_typeof] = ACTIONS(3741),
    [anon_sym___makeref] = ACTIONS(3741),
    [anon_sym___reftype] = ACTIONS(3741),
    [anon_sym___refvalue] = ACTIONS(3741),
    [sym_null_literal] = ACTIONS(3741),
    [anon_sym_SQUOTE] = ACTIONS(3743),
    [sym_integer_literal] = ACTIONS(3741),
    [sym_real_literal] = ACTIONS(3743),
    [anon_sym_DQUOTE] = ACTIONS(3743),
    [sym_verbatim_string_literal] = ACTIONS(3743),
    [aux_sym_preproc_if_token1] = ACTIONS(3743),
    [aux_sym_preproc_if_token3] = ACTIONS(3743),
    [aux_sym_preproc_else_token1] = ACTIONS(3743),
    [aux_sym_preproc_elif_token1] = ACTIONS(3743),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3743),
    [sym_interpolation_verbatim_start] = ACTIONS(3743),
    [sym_interpolation_raw_start] = ACTIONS(3743),
    [sym_raw_string_start] = ACTIONS(3743),
  },
  [2392] = {
    [sym_preproc_region] = STATE(2392),
    [sym_preproc_endregion] = STATE(2392),
    [sym_preproc_line] = STATE(2392),
    [sym_preproc_pragma] = STATE(2392),
    [sym_preproc_nullable] = STATE(2392),
    [sym_preproc_error] = STATE(2392),
    [sym_preproc_warning] = STATE(2392),
    [sym_preproc_define] = STATE(2392),
    [sym_preproc_undef] = STATE(2392),
    [sym__identifier_token] = ACTIONS(3745),
    [anon_sym_extern] = ACTIONS(3745),
    [anon_sym_alias] = ACTIONS(3745),
    [anon_sym_SEMI] = ACTIONS(3747),
    [anon_sym_global] = ACTIONS(3745),
    [anon_sym_using] = ACTIONS(3745),
    [anon_sym_unsafe] = ACTIONS(3745),
    [anon_sym_static] = ACTIONS(3745),
    [anon_sym_LBRACK] = ACTIONS(3747),
    [anon_sym_LPAREN] = ACTIONS(3747),
    [anon_sym_return] = ACTIONS(3745),
    [anon_sym_namespace] = ACTIONS(3745),
    [anon_sym_class] = ACTIONS(3745),
    [anon_sym_ref] = ACTIONS(3745),
    [anon_sym_struct] = ACTIONS(3745),
    [anon_sym_enum] = ACTIONS(3745),
    [anon_sym_LBRACE] = ACTIONS(3747),
    [anon_sym_interface] = ACTIONS(3745),
    [anon_sym_delegate] = ACTIONS(3745),
    [anon_sym_record] = ACTIONS(3745),
    [anon_sym_abstract] = ACTIONS(3745),
    [anon_sym_async] = ACTIONS(3745),
    [anon_sym_const] = ACTIONS(3745),
    [anon_sym_file] = ACTIONS(3745),
    [anon_sym_fixed] = ACTIONS(3745),
    [anon_sym_internal] = ACTIONS(3745),
    [anon_sym_new] = ACTIONS(3745),
    [anon_sym_override] = ACTIONS(3745),
    [anon_sym_partial] = ACTIONS(3745),
    [anon_sym_private] = ACTIONS(3745),
    [anon_sym_protected] = ACTIONS(3745),
    [anon_sym_public] = ACTIONS(3745),
    [anon_sym_readonly] = ACTIONS(3745),
    [anon_sym_required] = ACTIONS(3745),
    [anon_sym_sealed] = ACTIONS(3745),
    [anon_sym_virtual] = ACTIONS(3745),
    [anon_sym_volatile] = ACTIONS(3745),
    [anon_sym_where] = ACTIONS(3745),
    [anon_sym_notnull] = ACTIONS(3745),
    [anon_sym_unmanaged] = ACTIONS(3745),
    [anon_sym_checked] = ACTIONS(3745),
    [anon_sym_BANG] = ACTIONS(3747),
    [anon_sym_TILDE] = ACTIONS(3747),
    [anon_sym_PLUS_PLUS] = ACTIONS(3747),
    [anon_sym_DASH_DASH] = ACTIONS(3747),
    [anon_sym_true] = ACTIONS(3745),
    [anon_sym_false] = ACTIONS(3745),
    [anon_sym_PLUS] = ACTIONS(3745),
    [anon_sym_DASH] = ACTIONS(3745),
    [anon_sym_STAR] = ACTIONS(3747),
    [anon_sym_CARET] = ACTIONS(3747),
    [anon_sym_AMP] = ACTIONS(3747),
    [anon_sym_this] = ACTIONS(3745),
    [anon_sym_scoped] = ACTIONS(3745),
    [anon_sym_base] = ACTIONS(3745),
    [anon_sym_var] = ACTIONS(3745),
    [sym_predefined_type] = ACTIONS(3745),
    [anon_sym_break] = ACTIONS(3745),
    [anon_sym_unchecked] = ACTIONS(3745),
    [anon_sym_continue] = ACTIONS(3745),
    [anon_sym_do] = ACTIONS(3745),
    [anon_sym_while] = ACTIONS(3745),
    [anon_sym_for] = ACTIONS(3745),
    [anon_sym_lock] = ACTIONS(3745),
    [anon_sym_yield] = ACTIONS(3745),
    [anon_sym_switch] = ACTIONS(3745),
    [anon_sym_default] = ACTIONS(3745),
    [anon_sym_throw] = ACTIONS(3745),
    [anon_sym_try] = ACTIONS(3745),
    [anon_sym_when] = ACTIONS(3745),
    [anon_sym_await] = ACTIONS(3745),
    [anon_sym_foreach] = ACTIONS(3745),
    [anon_sym_goto] = ACTIONS(3745),
    [anon_sym_if] = ACTIONS(3745),
    [anon_sym_DOT_DOT] = ACTIONS(3747),
    [anon_sym_from] = ACTIONS(3745),
    [anon_sym_into] = ACTIONS(3745),
    [anon_sym_join] = ACTIONS(3745),
    [anon_sym_on] = ACTIONS(3745),
    [anon_sym_equals] = ACTIONS(3745),
    [anon_sym_let] = ACTIONS(3745),
    [anon_sym_orderby] = ACTIONS(3745),
    [anon_sym_ascending] = ACTIONS(3745),
    [anon_sym_descending] = ACTIONS(3745),
    [anon_sym_group] = ACTIONS(3745),
    [anon_sym_by] = ACTIONS(3745),
    [anon_sym_select] = ACTIONS(3745),
    [anon_sym_stackalloc] = ACTIONS(3745),
    [anon_sym_sizeof] = ACTIONS(3745),
    [anon_sym_typeof] = ACTIONS(3745),
    [anon_sym___makeref] = ACTIONS(3745),
    [anon_sym___reftype] = ACTIONS(3745),
    [anon_sym___refvalue] = ACTIONS(3745),
    [sym_null_literal] = ACTIONS(3745),
    [anon_sym_SQUOTE] = ACTIONS(3747),
    [sym_integer_literal] = ACTIONS(3745),
    [sym_real_literal] = ACTIONS(3747),
    [anon_sym_DQUOTE] = ACTIONS(3747),
    [sym_verbatim_string_literal] = ACTIONS(3747),
    [aux_sym_preproc_if_token1] = ACTIONS(3747),
    [aux_sym_preproc_if_token3] = ACTIONS(3747),
    [aux_sym_preproc_else_token1] = ACTIONS(3747),
    [aux_sym_preproc_elif_token1] = ACTIONS(3747),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3747),
    [sym_interpolation_verbatim_start] = ACTIONS(3747),
    [sym_interpolation_raw_start] = ACTIONS(3747),
    [sym_raw_string_start] = ACTIONS(3747),
  },
  [2393] = {
    [sym_preproc_region] = STATE(2393),
    [sym_preproc_endregion] = STATE(2393),
    [sym_preproc_line] = STATE(2393),
    [sym_preproc_pragma] = STATE(2393),
    [sym_preproc_nullable] = STATE(2393),
    [sym_preproc_error] = STATE(2393),
    [sym_preproc_warning] = STATE(2393),
    [sym_preproc_define] = STATE(2393),
    [sym_preproc_undef] = STATE(2393),
    [sym__identifier_token] = ACTIONS(3749),
    [anon_sym_extern] = ACTIONS(3749),
    [anon_sym_alias] = ACTIONS(3749),
    [anon_sym_SEMI] = ACTIONS(3751),
    [anon_sym_global] = ACTIONS(3749),
    [anon_sym_using] = ACTIONS(3749),
    [anon_sym_unsafe] = ACTIONS(3749),
    [anon_sym_static] = ACTIONS(3749),
    [anon_sym_LBRACK] = ACTIONS(3751),
    [anon_sym_LPAREN] = ACTIONS(3751),
    [anon_sym_return] = ACTIONS(3749),
    [anon_sym_namespace] = ACTIONS(3749),
    [anon_sym_class] = ACTIONS(3749),
    [anon_sym_ref] = ACTIONS(3749),
    [anon_sym_struct] = ACTIONS(3749),
    [anon_sym_enum] = ACTIONS(3749),
    [anon_sym_LBRACE] = ACTIONS(3751),
    [anon_sym_interface] = ACTIONS(3749),
    [anon_sym_delegate] = ACTIONS(3749),
    [anon_sym_record] = ACTIONS(3749),
    [anon_sym_abstract] = ACTIONS(3749),
    [anon_sym_async] = ACTIONS(3749),
    [anon_sym_const] = ACTIONS(3749),
    [anon_sym_file] = ACTIONS(3749),
    [anon_sym_fixed] = ACTIONS(3749),
    [anon_sym_internal] = ACTIONS(3749),
    [anon_sym_new] = ACTIONS(3749),
    [anon_sym_override] = ACTIONS(3749),
    [anon_sym_partial] = ACTIONS(3749),
    [anon_sym_private] = ACTIONS(3749),
    [anon_sym_protected] = ACTIONS(3749),
    [anon_sym_public] = ACTIONS(3749),
    [anon_sym_readonly] = ACTIONS(3749),
    [anon_sym_required] = ACTIONS(3749),
    [anon_sym_sealed] = ACTIONS(3749),
    [anon_sym_virtual] = ACTIONS(3749),
    [anon_sym_volatile] = ACTIONS(3749),
    [anon_sym_where] = ACTIONS(3749),
    [anon_sym_notnull] = ACTIONS(3749),
    [anon_sym_unmanaged] = ACTIONS(3749),
    [anon_sym_checked] = ACTIONS(3749),
    [anon_sym_BANG] = ACTIONS(3751),
    [anon_sym_TILDE] = ACTIONS(3751),
    [anon_sym_PLUS_PLUS] = ACTIONS(3751),
    [anon_sym_DASH_DASH] = ACTIONS(3751),
    [anon_sym_true] = ACTIONS(3749),
    [anon_sym_false] = ACTIONS(3749),
    [anon_sym_PLUS] = ACTIONS(3749),
    [anon_sym_DASH] = ACTIONS(3749),
    [anon_sym_STAR] = ACTIONS(3751),
    [anon_sym_CARET] = ACTIONS(3751),
    [anon_sym_AMP] = ACTIONS(3751),
    [anon_sym_this] = ACTIONS(3749),
    [anon_sym_scoped] = ACTIONS(3749),
    [anon_sym_base] = ACTIONS(3749),
    [anon_sym_var] = ACTIONS(3749),
    [sym_predefined_type] = ACTIONS(3749),
    [anon_sym_break] = ACTIONS(3749),
    [anon_sym_unchecked] = ACTIONS(3749),
    [anon_sym_continue] = ACTIONS(3749),
    [anon_sym_do] = ACTIONS(3749),
    [anon_sym_while] = ACTIONS(3749),
    [anon_sym_for] = ACTIONS(3749),
    [anon_sym_lock] = ACTIONS(3749),
    [anon_sym_yield] = ACTIONS(3749),
    [anon_sym_switch] = ACTIONS(3749),
    [anon_sym_default] = ACTIONS(3749),
    [anon_sym_throw] = ACTIONS(3749),
    [anon_sym_try] = ACTIONS(3749),
    [anon_sym_when] = ACTIONS(3749),
    [anon_sym_await] = ACTIONS(3749),
    [anon_sym_foreach] = ACTIONS(3749),
    [anon_sym_goto] = ACTIONS(3749),
    [anon_sym_if] = ACTIONS(3749),
    [anon_sym_DOT_DOT] = ACTIONS(3751),
    [anon_sym_from] = ACTIONS(3749),
    [anon_sym_into] = ACTIONS(3749),
    [anon_sym_join] = ACTIONS(3749),
    [anon_sym_on] = ACTIONS(3749),
    [anon_sym_equals] = ACTIONS(3749),
    [anon_sym_let] = ACTIONS(3749),
    [anon_sym_orderby] = ACTIONS(3749),
    [anon_sym_ascending] = ACTIONS(3749),
    [anon_sym_descending] = ACTIONS(3749),
    [anon_sym_group] = ACTIONS(3749),
    [anon_sym_by] = ACTIONS(3749),
    [anon_sym_select] = ACTIONS(3749),
    [anon_sym_stackalloc] = ACTIONS(3749),
    [anon_sym_sizeof] = ACTIONS(3749),
    [anon_sym_typeof] = ACTIONS(3749),
    [anon_sym___makeref] = ACTIONS(3749),
    [anon_sym___reftype] = ACTIONS(3749),
    [anon_sym___refvalue] = ACTIONS(3749),
    [sym_null_literal] = ACTIONS(3749),
    [anon_sym_SQUOTE] = ACTIONS(3751),
    [sym_integer_literal] = ACTIONS(3749),
    [sym_real_literal] = ACTIONS(3751),
    [anon_sym_DQUOTE] = ACTIONS(3751),
    [sym_verbatim_string_literal] = ACTIONS(3751),
    [aux_sym_preproc_if_token1] = ACTIONS(3751),
    [aux_sym_preproc_if_token3] = ACTIONS(3751),
    [aux_sym_preproc_else_token1] = ACTIONS(3751),
    [aux_sym_preproc_elif_token1] = ACTIONS(3751),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3751),
    [sym_interpolation_verbatim_start] = ACTIONS(3751),
    [sym_interpolation_raw_start] = ACTIONS(3751),
    [sym_raw_string_start] = ACTIONS(3751),
  },
  [2394] = {
    [sym_preproc_region] = STATE(2394),
    [sym_preproc_endregion] = STATE(2394),
    [sym_preproc_line] = STATE(2394),
    [sym_preproc_pragma] = STATE(2394),
    [sym_preproc_nullable] = STATE(2394),
    [sym_preproc_error] = STATE(2394),
    [sym_preproc_warning] = STATE(2394),
    [sym_preproc_define] = STATE(2394),
    [sym_preproc_undef] = STATE(2394),
    [sym__identifier_token] = ACTIONS(3753),
    [anon_sym_extern] = ACTIONS(3753),
    [anon_sym_alias] = ACTIONS(3753),
    [anon_sym_SEMI] = ACTIONS(3755),
    [anon_sym_global] = ACTIONS(3753),
    [anon_sym_using] = ACTIONS(3753),
    [anon_sym_unsafe] = ACTIONS(3753),
    [anon_sym_static] = ACTIONS(3753),
    [anon_sym_LBRACK] = ACTIONS(3755),
    [anon_sym_LPAREN] = ACTIONS(3755),
    [anon_sym_return] = ACTIONS(3753),
    [anon_sym_namespace] = ACTIONS(3753),
    [anon_sym_class] = ACTIONS(3753),
    [anon_sym_ref] = ACTIONS(3753),
    [anon_sym_struct] = ACTIONS(3753),
    [anon_sym_enum] = ACTIONS(3753),
    [anon_sym_LBRACE] = ACTIONS(3755),
    [anon_sym_interface] = ACTIONS(3753),
    [anon_sym_delegate] = ACTIONS(3753),
    [anon_sym_record] = ACTIONS(3753),
    [anon_sym_abstract] = ACTIONS(3753),
    [anon_sym_async] = ACTIONS(3753),
    [anon_sym_const] = ACTIONS(3753),
    [anon_sym_file] = ACTIONS(3753),
    [anon_sym_fixed] = ACTIONS(3753),
    [anon_sym_internal] = ACTIONS(3753),
    [anon_sym_new] = ACTIONS(3753),
    [anon_sym_override] = ACTIONS(3753),
    [anon_sym_partial] = ACTIONS(3753),
    [anon_sym_private] = ACTIONS(3753),
    [anon_sym_protected] = ACTIONS(3753),
    [anon_sym_public] = ACTIONS(3753),
    [anon_sym_readonly] = ACTIONS(3753),
    [anon_sym_required] = ACTIONS(3753),
    [anon_sym_sealed] = ACTIONS(3753),
    [anon_sym_virtual] = ACTIONS(3753),
    [anon_sym_volatile] = ACTIONS(3753),
    [anon_sym_where] = ACTIONS(3753),
    [anon_sym_notnull] = ACTIONS(3753),
    [anon_sym_unmanaged] = ACTIONS(3753),
    [anon_sym_checked] = ACTIONS(3753),
    [anon_sym_BANG] = ACTIONS(3755),
    [anon_sym_TILDE] = ACTIONS(3755),
    [anon_sym_PLUS_PLUS] = ACTIONS(3755),
    [anon_sym_DASH_DASH] = ACTIONS(3755),
    [anon_sym_true] = ACTIONS(3753),
    [anon_sym_false] = ACTIONS(3753),
    [anon_sym_PLUS] = ACTIONS(3753),
    [anon_sym_DASH] = ACTIONS(3753),
    [anon_sym_STAR] = ACTIONS(3755),
    [anon_sym_CARET] = ACTIONS(3755),
    [anon_sym_AMP] = ACTIONS(3755),
    [anon_sym_this] = ACTIONS(3753),
    [anon_sym_scoped] = ACTIONS(3753),
    [anon_sym_base] = ACTIONS(3753),
    [anon_sym_var] = ACTIONS(3753),
    [sym_predefined_type] = ACTIONS(3753),
    [anon_sym_break] = ACTIONS(3753),
    [anon_sym_unchecked] = ACTIONS(3753),
    [anon_sym_continue] = ACTIONS(3753),
    [anon_sym_do] = ACTIONS(3753),
    [anon_sym_while] = ACTIONS(3753),
    [anon_sym_for] = ACTIONS(3753),
    [anon_sym_lock] = ACTIONS(3753),
    [anon_sym_yield] = ACTIONS(3753),
    [anon_sym_switch] = ACTIONS(3753),
    [anon_sym_default] = ACTIONS(3753),
    [anon_sym_throw] = ACTIONS(3753),
    [anon_sym_try] = ACTIONS(3753),
    [anon_sym_when] = ACTIONS(3753),
    [anon_sym_await] = ACTIONS(3753),
    [anon_sym_foreach] = ACTIONS(3753),
    [anon_sym_goto] = ACTIONS(3753),
    [anon_sym_if] = ACTIONS(3753),
    [anon_sym_DOT_DOT] = ACTIONS(3755),
    [anon_sym_from] = ACTIONS(3753),
    [anon_sym_into] = ACTIONS(3753),
    [anon_sym_join] = ACTIONS(3753),
    [anon_sym_on] = ACTIONS(3753),
    [anon_sym_equals] = ACTIONS(3753),
    [anon_sym_let] = ACTIONS(3753),
    [anon_sym_orderby] = ACTIONS(3753),
    [anon_sym_ascending] = ACTIONS(3753),
    [anon_sym_descending] = ACTIONS(3753),
    [anon_sym_group] = ACTIONS(3753),
    [anon_sym_by] = ACTIONS(3753),
    [anon_sym_select] = ACTIONS(3753),
    [anon_sym_stackalloc] = ACTIONS(3753),
    [anon_sym_sizeof] = ACTIONS(3753),
    [anon_sym_typeof] = ACTIONS(3753),
    [anon_sym___makeref] = ACTIONS(3753),
    [anon_sym___reftype] = ACTIONS(3753),
    [anon_sym___refvalue] = ACTIONS(3753),
    [sym_null_literal] = ACTIONS(3753),
    [anon_sym_SQUOTE] = ACTIONS(3755),
    [sym_integer_literal] = ACTIONS(3753),
    [sym_real_literal] = ACTIONS(3755),
    [anon_sym_DQUOTE] = ACTIONS(3755),
    [sym_verbatim_string_literal] = ACTIONS(3755),
    [aux_sym_preproc_if_token1] = ACTIONS(3755),
    [aux_sym_preproc_if_token3] = ACTIONS(3755),
    [aux_sym_preproc_else_token1] = ACTIONS(3755),
    [aux_sym_preproc_elif_token1] = ACTIONS(3755),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3755),
    [sym_interpolation_verbatim_start] = ACTIONS(3755),
    [sym_interpolation_raw_start] = ACTIONS(3755),
    [sym_raw_string_start] = ACTIONS(3755),
  },
  [2395] = {
    [sym_preproc_region] = STATE(2395),
    [sym_preproc_endregion] = STATE(2395),
    [sym_preproc_line] = STATE(2395),
    [sym_preproc_pragma] = STATE(2395),
    [sym_preproc_nullable] = STATE(2395),
    [sym_preproc_error] = STATE(2395),
    [sym_preproc_warning] = STATE(2395),
    [sym_preproc_define] = STATE(2395),
    [sym_preproc_undef] = STATE(2395),
    [sym__identifier_token] = ACTIONS(3757),
    [anon_sym_extern] = ACTIONS(3757),
    [anon_sym_alias] = ACTIONS(3757),
    [anon_sym_SEMI] = ACTIONS(3759),
    [anon_sym_global] = ACTIONS(3757),
    [anon_sym_using] = ACTIONS(3757),
    [anon_sym_unsafe] = ACTIONS(3757),
    [anon_sym_static] = ACTIONS(3757),
    [anon_sym_LBRACK] = ACTIONS(3759),
    [anon_sym_LPAREN] = ACTIONS(3759),
    [anon_sym_return] = ACTIONS(3757),
    [anon_sym_namespace] = ACTIONS(3757),
    [anon_sym_class] = ACTIONS(3757),
    [anon_sym_ref] = ACTIONS(3757),
    [anon_sym_struct] = ACTIONS(3757),
    [anon_sym_enum] = ACTIONS(3757),
    [anon_sym_LBRACE] = ACTIONS(3759),
    [anon_sym_interface] = ACTIONS(3757),
    [anon_sym_delegate] = ACTIONS(3757),
    [anon_sym_record] = ACTIONS(3757),
    [anon_sym_abstract] = ACTIONS(3757),
    [anon_sym_async] = ACTIONS(3757),
    [anon_sym_const] = ACTIONS(3757),
    [anon_sym_file] = ACTIONS(3757),
    [anon_sym_fixed] = ACTIONS(3757),
    [anon_sym_internal] = ACTIONS(3757),
    [anon_sym_new] = ACTIONS(3757),
    [anon_sym_override] = ACTIONS(3757),
    [anon_sym_partial] = ACTIONS(3757),
    [anon_sym_private] = ACTIONS(3757),
    [anon_sym_protected] = ACTIONS(3757),
    [anon_sym_public] = ACTIONS(3757),
    [anon_sym_readonly] = ACTIONS(3757),
    [anon_sym_required] = ACTIONS(3757),
    [anon_sym_sealed] = ACTIONS(3757),
    [anon_sym_virtual] = ACTIONS(3757),
    [anon_sym_volatile] = ACTIONS(3757),
    [anon_sym_where] = ACTIONS(3757),
    [anon_sym_notnull] = ACTIONS(3757),
    [anon_sym_unmanaged] = ACTIONS(3757),
    [anon_sym_checked] = ACTIONS(3757),
    [anon_sym_BANG] = ACTIONS(3759),
    [anon_sym_TILDE] = ACTIONS(3759),
    [anon_sym_PLUS_PLUS] = ACTIONS(3759),
    [anon_sym_DASH_DASH] = ACTIONS(3759),
    [anon_sym_true] = ACTIONS(3757),
    [anon_sym_false] = ACTIONS(3757),
    [anon_sym_PLUS] = ACTIONS(3757),
    [anon_sym_DASH] = ACTIONS(3757),
    [anon_sym_STAR] = ACTIONS(3759),
    [anon_sym_CARET] = ACTIONS(3759),
    [anon_sym_AMP] = ACTIONS(3759),
    [anon_sym_this] = ACTIONS(3757),
    [anon_sym_scoped] = ACTIONS(3757),
    [anon_sym_base] = ACTIONS(3757),
    [anon_sym_var] = ACTIONS(3757),
    [sym_predefined_type] = ACTIONS(3757),
    [anon_sym_break] = ACTIONS(3757),
    [anon_sym_unchecked] = ACTIONS(3757),
    [anon_sym_continue] = ACTIONS(3757),
    [anon_sym_do] = ACTIONS(3757),
    [anon_sym_while] = ACTIONS(3757),
    [anon_sym_for] = ACTIONS(3757),
    [anon_sym_lock] = ACTIONS(3757),
    [anon_sym_yield] = ACTIONS(3757),
    [anon_sym_switch] = ACTIONS(3757),
    [anon_sym_default] = ACTIONS(3757),
    [anon_sym_throw] = ACTIONS(3757),
    [anon_sym_try] = ACTIONS(3757),
    [anon_sym_when] = ACTIONS(3757),
    [anon_sym_await] = ACTIONS(3757),
    [anon_sym_foreach] = ACTIONS(3757),
    [anon_sym_goto] = ACTIONS(3757),
    [anon_sym_if] = ACTIONS(3757),
    [anon_sym_DOT_DOT] = ACTIONS(3759),
    [anon_sym_from] = ACTIONS(3757),
    [anon_sym_into] = ACTIONS(3757),
    [anon_sym_join] = ACTIONS(3757),
    [anon_sym_on] = ACTIONS(3757),
    [anon_sym_equals] = ACTIONS(3757),
    [anon_sym_let] = ACTIONS(3757),
    [anon_sym_orderby] = ACTIONS(3757),
    [anon_sym_ascending] = ACTIONS(3757),
    [anon_sym_descending] = ACTIONS(3757),
    [anon_sym_group] = ACTIONS(3757),
    [anon_sym_by] = ACTIONS(3757),
    [anon_sym_select] = ACTIONS(3757),
    [anon_sym_stackalloc] = ACTIONS(3757),
    [anon_sym_sizeof] = ACTIONS(3757),
    [anon_sym_typeof] = ACTIONS(3757),
    [anon_sym___makeref] = ACTIONS(3757),
    [anon_sym___reftype] = ACTIONS(3757),
    [anon_sym___refvalue] = ACTIONS(3757),
    [sym_null_literal] = ACTIONS(3757),
    [anon_sym_SQUOTE] = ACTIONS(3759),
    [sym_integer_literal] = ACTIONS(3757),
    [sym_real_literal] = ACTIONS(3759),
    [anon_sym_DQUOTE] = ACTIONS(3759),
    [sym_verbatim_string_literal] = ACTIONS(3759),
    [aux_sym_preproc_if_token1] = ACTIONS(3759),
    [aux_sym_preproc_if_token3] = ACTIONS(3759),
    [aux_sym_preproc_else_token1] = ACTIONS(3759),
    [aux_sym_preproc_elif_token1] = ACTIONS(3759),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3759),
    [sym_interpolation_verbatim_start] = ACTIONS(3759),
    [sym_interpolation_raw_start] = ACTIONS(3759),
    [sym_raw_string_start] = ACTIONS(3759),
  },
  [2396] = {
    [sym_preproc_region] = STATE(2396),
    [sym_preproc_endregion] = STATE(2396),
    [sym_preproc_line] = STATE(2396),
    [sym_preproc_pragma] = STATE(2396),
    [sym_preproc_nullable] = STATE(2396),
    [sym_preproc_error] = STATE(2396),
    [sym_preproc_warning] = STATE(2396),
    [sym_preproc_define] = STATE(2396),
    [sym_preproc_undef] = STATE(2396),
    [sym__identifier_token] = ACTIONS(3761),
    [anon_sym_extern] = ACTIONS(3761),
    [anon_sym_alias] = ACTIONS(3761),
    [anon_sym_SEMI] = ACTIONS(3763),
    [anon_sym_global] = ACTIONS(3761),
    [anon_sym_using] = ACTIONS(3761),
    [anon_sym_unsafe] = ACTIONS(3761),
    [anon_sym_static] = ACTIONS(3761),
    [anon_sym_LBRACK] = ACTIONS(3763),
    [anon_sym_LPAREN] = ACTIONS(3763),
    [anon_sym_return] = ACTIONS(3761),
    [anon_sym_namespace] = ACTIONS(3761),
    [anon_sym_class] = ACTIONS(3761),
    [anon_sym_ref] = ACTIONS(3761),
    [anon_sym_struct] = ACTIONS(3761),
    [anon_sym_enum] = ACTIONS(3761),
    [anon_sym_LBRACE] = ACTIONS(3763),
    [anon_sym_interface] = ACTIONS(3761),
    [anon_sym_delegate] = ACTIONS(3761),
    [anon_sym_record] = ACTIONS(3761),
    [anon_sym_abstract] = ACTIONS(3761),
    [anon_sym_async] = ACTIONS(3761),
    [anon_sym_const] = ACTIONS(3761),
    [anon_sym_file] = ACTIONS(3761),
    [anon_sym_fixed] = ACTIONS(3761),
    [anon_sym_internal] = ACTIONS(3761),
    [anon_sym_new] = ACTIONS(3761),
    [anon_sym_override] = ACTIONS(3761),
    [anon_sym_partial] = ACTIONS(3761),
    [anon_sym_private] = ACTIONS(3761),
    [anon_sym_protected] = ACTIONS(3761),
    [anon_sym_public] = ACTIONS(3761),
    [anon_sym_readonly] = ACTIONS(3761),
    [anon_sym_required] = ACTIONS(3761),
    [anon_sym_sealed] = ACTIONS(3761),
    [anon_sym_virtual] = ACTIONS(3761),
    [anon_sym_volatile] = ACTIONS(3761),
    [anon_sym_where] = ACTIONS(3761),
    [anon_sym_notnull] = ACTIONS(3761),
    [anon_sym_unmanaged] = ACTIONS(3761),
    [anon_sym_checked] = ACTIONS(3761),
    [anon_sym_BANG] = ACTIONS(3763),
    [anon_sym_TILDE] = ACTIONS(3763),
    [anon_sym_PLUS_PLUS] = ACTIONS(3763),
    [anon_sym_DASH_DASH] = ACTIONS(3763),
    [anon_sym_true] = ACTIONS(3761),
    [anon_sym_false] = ACTIONS(3761),
    [anon_sym_PLUS] = ACTIONS(3761),
    [anon_sym_DASH] = ACTIONS(3761),
    [anon_sym_STAR] = ACTIONS(3763),
    [anon_sym_CARET] = ACTIONS(3763),
    [anon_sym_AMP] = ACTIONS(3763),
    [anon_sym_this] = ACTIONS(3761),
    [anon_sym_scoped] = ACTIONS(3761),
    [anon_sym_base] = ACTIONS(3761),
    [anon_sym_var] = ACTIONS(3761),
    [sym_predefined_type] = ACTIONS(3761),
    [anon_sym_break] = ACTIONS(3761),
    [anon_sym_unchecked] = ACTIONS(3761),
    [anon_sym_continue] = ACTIONS(3761),
    [anon_sym_do] = ACTIONS(3761),
    [anon_sym_while] = ACTIONS(3761),
    [anon_sym_for] = ACTIONS(3761),
    [anon_sym_lock] = ACTIONS(3761),
    [anon_sym_yield] = ACTIONS(3761),
    [anon_sym_switch] = ACTIONS(3761),
    [anon_sym_default] = ACTIONS(3761),
    [anon_sym_throw] = ACTIONS(3761),
    [anon_sym_try] = ACTIONS(3761),
    [anon_sym_when] = ACTIONS(3761),
    [anon_sym_await] = ACTIONS(3761),
    [anon_sym_foreach] = ACTIONS(3761),
    [anon_sym_goto] = ACTIONS(3761),
    [anon_sym_if] = ACTIONS(3761),
    [anon_sym_DOT_DOT] = ACTIONS(3763),
    [anon_sym_from] = ACTIONS(3761),
    [anon_sym_into] = ACTIONS(3761),
    [anon_sym_join] = ACTIONS(3761),
    [anon_sym_on] = ACTIONS(3761),
    [anon_sym_equals] = ACTIONS(3761),
    [anon_sym_let] = ACTIONS(3761),
    [anon_sym_orderby] = ACTIONS(3761),
    [anon_sym_ascending] = ACTIONS(3761),
    [anon_sym_descending] = ACTIONS(3761),
    [anon_sym_group] = ACTIONS(3761),
    [anon_sym_by] = ACTIONS(3761),
    [anon_sym_select] = ACTIONS(3761),
    [anon_sym_stackalloc] = ACTIONS(3761),
    [anon_sym_sizeof] = ACTIONS(3761),
    [anon_sym_typeof] = ACTIONS(3761),
    [anon_sym___makeref] = ACTIONS(3761),
    [anon_sym___reftype] = ACTIONS(3761),
    [anon_sym___refvalue] = ACTIONS(3761),
    [sym_null_literal] = ACTIONS(3761),
    [anon_sym_SQUOTE] = ACTIONS(3763),
    [sym_integer_literal] = ACTIONS(3761),
    [sym_real_literal] = ACTIONS(3763),
    [anon_sym_DQUOTE] = ACTIONS(3763),
    [sym_verbatim_string_literal] = ACTIONS(3763),
    [aux_sym_preproc_if_token1] = ACTIONS(3763),
    [aux_sym_preproc_if_token3] = ACTIONS(3763),
    [aux_sym_preproc_else_token1] = ACTIONS(3763),
    [aux_sym_preproc_elif_token1] = ACTIONS(3763),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3763),
    [sym_interpolation_verbatim_start] = ACTIONS(3763),
    [sym_interpolation_raw_start] = ACTIONS(3763),
    [sym_raw_string_start] = ACTIONS(3763),
  },
  [2397] = {
    [sym_preproc_region] = STATE(2397),
    [sym_preproc_endregion] = STATE(2397),
    [sym_preproc_line] = STATE(2397),
    [sym_preproc_pragma] = STATE(2397),
    [sym_preproc_nullable] = STATE(2397),
    [sym_preproc_error] = STATE(2397),
    [sym_preproc_warning] = STATE(2397),
    [sym_preproc_define] = STATE(2397),
    [sym_preproc_undef] = STATE(2397),
    [sym__identifier_token] = ACTIONS(3765),
    [anon_sym_extern] = ACTIONS(3765),
    [anon_sym_alias] = ACTIONS(3765),
    [anon_sym_SEMI] = ACTIONS(3767),
    [anon_sym_global] = ACTIONS(3765),
    [anon_sym_using] = ACTIONS(3765),
    [anon_sym_unsafe] = ACTIONS(3765),
    [anon_sym_static] = ACTIONS(3765),
    [anon_sym_LBRACK] = ACTIONS(3767),
    [anon_sym_LPAREN] = ACTIONS(3767),
    [anon_sym_return] = ACTIONS(3765),
    [anon_sym_namespace] = ACTIONS(3765),
    [anon_sym_class] = ACTIONS(3765),
    [anon_sym_ref] = ACTIONS(3765),
    [anon_sym_struct] = ACTIONS(3765),
    [anon_sym_enum] = ACTIONS(3765),
    [anon_sym_LBRACE] = ACTIONS(3767),
    [anon_sym_interface] = ACTIONS(3765),
    [anon_sym_delegate] = ACTIONS(3765),
    [anon_sym_record] = ACTIONS(3765),
    [anon_sym_abstract] = ACTIONS(3765),
    [anon_sym_async] = ACTIONS(3765),
    [anon_sym_const] = ACTIONS(3765),
    [anon_sym_file] = ACTIONS(3765),
    [anon_sym_fixed] = ACTIONS(3765),
    [anon_sym_internal] = ACTIONS(3765),
    [anon_sym_new] = ACTIONS(3765),
    [anon_sym_override] = ACTIONS(3765),
    [anon_sym_partial] = ACTIONS(3765),
    [anon_sym_private] = ACTIONS(3765),
    [anon_sym_protected] = ACTIONS(3765),
    [anon_sym_public] = ACTIONS(3765),
    [anon_sym_readonly] = ACTIONS(3765),
    [anon_sym_required] = ACTIONS(3765),
    [anon_sym_sealed] = ACTIONS(3765),
    [anon_sym_virtual] = ACTIONS(3765),
    [anon_sym_volatile] = ACTIONS(3765),
    [anon_sym_where] = ACTIONS(3765),
    [anon_sym_notnull] = ACTIONS(3765),
    [anon_sym_unmanaged] = ACTIONS(3765),
    [anon_sym_checked] = ACTIONS(3765),
    [anon_sym_BANG] = ACTIONS(3767),
    [anon_sym_TILDE] = ACTIONS(3767),
    [anon_sym_PLUS_PLUS] = ACTIONS(3767),
    [anon_sym_DASH_DASH] = ACTIONS(3767),
    [anon_sym_true] = ACTIONS(3765),
    [anon_sym_false] = ACTIONS(3765),
    [anon_sym_PLUS] = ACTIONS(3765),
    [anon_sym_DASH] = ACTIONS(3765),
    [anon_sym_STAR] = ACTIONS(3767),
    [anon_sym_CARET] = ACTIONS(3767),
    [anon_sym_AMP] = ACTIONS(3767),
    [anon_sym_this] = ACTIONS(3765),
    [anon_sym_scoped] = ACTIONS(3765),
    [anon_sym_base] = ACTIONS(3765),
    [anon_sym_var] = ACTIONS(3765),
    [sym_predefined_type] = ACTIONS(3765),
    [anon_sym_break] = ACTIONS(3765),
    [anon_sym_unchecked] = ACTIONS(3765),
    [anon_sym_continue] = ACTIONS(3765),
    [anon_sym_do] = ACTIONS(3765),
    [anon_sym_while] = ACTIONS(3765),
    [anon_sym_for] = ACTIONS(3765),
    [anon_sym_lock] = ACTIONS(3765),
    [anon_sym_yield] = ACTIONS(3765),
    [anon_sym_switch] = ACTIONS(3765),
    [anon_sym_default] = ACTIONS(3765),
    [anon_sym_throw] = ACTIONS(3765),
    [anon_sym_try] = ACTIONS(3765),
    [anon_sym_when] = ACTIONS(3765),
    [anon_sym_await] = ACTIONS(3765),
    [anon_sym_foreach] = ACTIONS(3765),
    [anon_sym_goto] = ACTIONS(3765),
    [anon_sym_if] = ACTIONS(3765),
    [anon_sym_DOT_DOT] = ACTIONS(3767),
    [anon_sym_from] = ACTIONS(3765),
    [anon_sym_into] = ACTIONS(3765),
    [anon_sym_join] = ACTIONS(3765),
    [anon_sym_on] = ACTIONS(3765),
    [anon_sym_equals] = ACTIONS(3765),
    [anon_sym_let] = ACTIONS(3765),
    [anon_sym_orderby] = ACTIONS(3765),
    [anon_sym_ascending] = ACTIONS(3765),
    [anon_sym_descending] = ACTIONS(3765),
    [anon_sym_group] = ACTIONS(3765),
    [anon_sym_by] = ACTIONS(3765),
    [anon_sym_select] = ACTIONS(3765),
    [anon_sym_stackalloc] = ACTIONS(3765),
    [anon_sym_sizeof] = ACTIONS(3765),
    [anon_sym_typeof] = ACTIONS(3765),
    [anon_sym___makeref] = ACTIONS(3765),
    [anon_sym___reftype] = ACTIONS(3765),
    [anon_sym___refvalue] = ACTIONS(3765),
    [sym_null_literal] = ACTIONS(3765),
    [anon_sym_SQUOTE] = ACTIONS(3767),
    [sym_integer_literal] = ACTIONS(3765),
    [sym_real_literal] = ACTIONS(3767),
    [anon_sym_DQUOTE] = ACTIONS(3767),
    [sym_verbatim_string_literal] = ACTIONS(3767),
    [aux_sym_preproc_if_token1] = ACTIONS(3767),
    [aux_sym_preproc_if_token3] = ACTIONS(3767),
    [aux_sym_preproc_else_token1] = ACTIONS(3767),
    [aux_sym_preproc_elif_token1] = ACTIONS(3767),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3767),
    [sym_interpolation_verbatim_start] = ACTIONS(3767),
    [sym_interpolation_raw_start] = ACTIONS(3767),
    [sym_raw_string_start] = ACTIONS(3767),
  },
  [2398] = {
    [sym_preproc_region] = STATE(2398),
    [sym_preproc_endregion] = STATE(2398),
    [sym_preproc_line] = STATE(2398),
    [sym_preproc_pragma] = STATE(2398),
    [sym_preproc_nullable] = STATE(2398),
    [sym_preproc_error] = STATE(2398),
    [sym_preproc_warning] = STATE(2398),
    [sym_preproc_define] = STATE(2398),
    [sym_preproc_undef] = STATE(2398),
    [sym__identifier_token] = ACTIONS(3769),
    [anon_sym_extern] = ACTIONS(3769),
    [anon_sym_alias] = ACTIONS(3769),
    [anon_sym_SEMI] = ACTIONS(3771),
    [anon_sym_global] = ACTIONS(3769),
    [anon_sym_using] = ACTIONS(3769),
    [anon_sym_unsafe] = ACTIONS(3769),
    [anon_sym_static] = ACTIONS(3769),
    [anon_sym_LBRACK] = ACTIONS(3771),
    [anon_sym_LPAREN] = ACTIONS(3771),
    [anon_sym_return] = ACTIONS(3769),
    [anon_sym_namespace] = ACTIONS(3769),
    [anon_sym_class] = ACTIONS(3769),
    [anon_sym_ref] = ACTIONS(3769),
    [anon_sym_struct] = ACTIONS(3769),
    [anon_sym_enum] = ACTIONS(3769),
    [anon_sym_LBRACE] = ACTIONS(3771),
    [anon_sym_interface] = ACTIONS(3769),
    [anon_sym_delegate] = ACTIONS(3769),
    [anon_sym_record] = ACTIONS(3769),
    [anon_sym_abstract] = ACTIONS(3769),
    [anon_sym_async] = ACTIONS(3769),
    [anon_sym_const] = ACTIONS(3769),
    [anon_sym_file] = ACTIONS(3769),
    [anon_sym_fixed] = ACTIONS(3769),
    [anon_sym_internal] = ACTIONS(3769),
    [anon_sym_new] = ACTIONS(3769),
    [anon_sym_override] = ACTIONS(3769),
    [anon_sym_partial] = ACTIONS(3769),
    [anon_sym_private] = ACTIONS(3769),
    [anon_sym_protected] = ACTIONS(3769),
    [anon_sym_public] = ACTIONS(3769),
    [anon_sym_readonly] = ACTIONS(3769),
    [anon_sym_required] = ACTIONS(3769),
    [anon_sym_sealed] = ACTIONS(3769),
    [anon_sym_virtual] = ACTIONS(3769),
    [anon_sym_volatile] = ACTIONS(3769),
    [anon_sym_where] = ACTIONS(3769),
    [anon_sym_notnull] = ACTIONS(3769),
    [anon_sym_unmanaged] = ACTIONS(3769),
    [anon_sym_checked] = ACTIONS(3769),
    [anon_sym_BANG] = ACTIONS(3771),
    [anon_sym_TILDE] = ACTIONS(3771),
    [anon_sym_PLUS_PLUS] = ACTIONS(3771),
    [anon_sym_DASH_DASH] = ACTIONS(3771),
    [anon_sym_true] = ACTIONS(3769),
    [anon_sym_false] = ACTIONS(3769),
    [anon_sym_PLUS] = ACTIONS(3769),
    [anon_sym_DASH] = ACTIONS(3769),
    [anon_sym_STAR] = ACTIONS(3771),
    [anon_sym_CARET] = ACTIONS(3771),
    [anon_sym_AMP] = ACTIONS(3771),
    [anon_sym_this] = ACTIONS(3769),
    [anon_sym_scoped] = ACTIONS(3769),
    [anon_sym_base] = ACTIONS(3769),
    [anon_sym_var] = ACTIONS(3769),
    [sym_predefined_type] = ACTIONS(3769),
    [anon_sym_break] = ACTIONS(3769),
    [anon_sym_unchecked] = ACTIONS(3769),
    [anon_sym_continue] = ACTIONS(3769),
    [anon_sym_do] = ACTIONS(3769),
    [anon_sym_while] = ACTIONS(3769),
    [anon_sym_for] = ACTIONS(3769),
    [anon_sym_lock] = ACTIONS(3769),
    [anon_sym_yield] = ACTIONS(3769),
    [anon_sym_switch] = ACTIONS(3769),
    [anon_sym_default] = ACTIONS(3769),
    [anon_sym_throw] = ACTIONS(3769),
    [anon_sym_try] = ACTIONS(3769),
    [anon_sym_when] = ACTIONS(3769),
    [anon_sym_await] = ACTIONS(3769),
    [anon_sym_foreach] = ACTIONS(3769),
    [anon_sym_goto] = ACTIONS(3769),
    [anon_sym_if] = ACTIONS(3769),
    [anon_sym_DOT_DOT] = ACTIONS(3771),
    [anon_sym_from] = ACTIONS(3769),
    [anon_sym_into] = ACTIONS(3769),
    [anon_sym_join] = ACTIONS(3769),
    [anon_sym_on] = ACTIONS(3769),
    [anon_sym_equals] = ACTIONS(3769),
    [anon_sym_let] = ACTIONS(3769),
    [anon_sym_orderby] = ACTIONS(3769),
    [anon_sym_ascending] = ACTIONS(3769),
    [anon_sym_descending] = ACTIONS(3769),
    [anon_sym_group] = ACTIONS(3769),
    [anon_sym_by] = ACTIONS(3769),
    [anon_sym_select] = ACTIONS(3769),
    [anon_sym_stackalloc] = ACTIONS(3769),
    [anon_sym_sizeof] = ACTIONS(3769),
    [anon_sym_typeof] = ACTIONS(3769),
    [anon_sym___makeref] = ACTIONS(3769),
    [anon_sym___reftype] = ACTIONS(3769),
    [anon_sym___refvalue] = ACTIONS(3769),
    [sym_null_literal] = ACTIONS(3769),
    [anon_sym_SQUOTE] = ACTIONS(3771),
    [sym_integer_literal] = ACTIONS(3769),
    [sym_real_literal] = ACTIONS(3771),
    [anon_sym_DQUOTE] = ACTIONS(3771),
    [sym_verbatim_string_literal] = ACTIONS(3771),
    [aux_sym_preproc_if_token1] = ACTIONS(3771),
    [aux_sym_preproc_if_token3] = ACTIONS(3771),
    [aux_sym_preproc_else_token1] = ACTIONS(3771),
    [aux_sym_preproc_elif_token1] = ACTIONS(3771),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3771),
    [sym_interpolation_verbatim_start] = ACTIONS(3771),
    [sym_interpolation_raw_start] = ACTIONS(3771),
    [sym_raw_string_start] = ACTIONS(3771),
  },
  [2399] = {
    [sym_preproc_region] = STATE(2399),
    [sym_preproc_endregion] = STATE(2399),
    [sym_preproc_line] = STATE(2399),
    [sym_preproc_pragma] = STATE(2399),
    [sym_preproc_nullable] = STATE(2399),
    [sym_preproc_error] = STATE(2399),
    [sym_preproc_warning] = STATE(2399),
    [sym_preproc_define] = STATE(2399),
    [sym_preproc_undef] = STATE(2399),
    [sym__identifier_token] = ACTIONS(3773),
    [anon_sym_extern] = ACTIONS(3773),
    [anon_sym_alias] = ACTIONS(3773),
    [anon_sym_SEMI] = ACTIONS(3775),
    [anon_sym_global] = ACTIONS(3773),
    [anon_sym_using] = ACTIONS(3773),
    [anon_sym_unsafe] = ACTIONS(3773),
    [anon_sym_static] = ACTIONS(3773),
    [anon_sym_LBRACK] = ACTIONS(3775),
    [anon_sym_LPAREN] = ACTIONS(3775),
    [anon_sym_return] = ACTIONS(3773),
    [anon_sym_namespace] = ACTIONS(3773),
    [anon_sym_class] = ACTIONS(3773),
    [anon_sym_ref] = ACTIONS(3773),
    [anon_sym_struct] = ACTIONS(3773),
    [anon_sym_enum] = ACTIONS(3773),
    [anon_sym_LBRACE] = ACTIONS(3775),
    [anon_sym_interface] = ACTIONS(3773),
    [anon_sym_delegate] = ACTIONS(3773),
    [anon_sym_record] = ACTIONS(3773),
    [anon_sym_abstract] = ACTIONS(3773),
    [anon_sym_async] = ACTIONS(3773),
    [anon_sym_const] = ACTIONS(3773),
    [anon_sym_file] = ACTIONS(3773),
    [anon_sym_fixed] = ACTIONS(3773),
    [anon_sym_internal] = ACTIONS(3773),
    [anon_sym_new] = ACTIONS(3773),
    [anon_sym_override] = ACTIONS(3773),
    [anon_sym_partial] = ACTIONS(3773),
    [anon_sym_private] = ACTIONS(3773),
    [anon_sym_protected] = ACTIONS(3773),
    [anon_sym_public] = ACTIONS(3773),
    [anon_sym_readonly] = ACTIONS(3773),
    [anon_sym_required] = ACTIONS(3773),
    [anon_sym_sealed] = ACTIONS(3773),
    [anon_sym_virtual] = ACTIONS(3773),
    [anon_sym_volatile] = ACTIONS(3773),
    [anon_sym_where] = ACTIONS(3773),
    [anon_sym_notnull] = ACTIONS(3773),
    [anon_sym_unmanaged] = ACTIONS(3773),
    [anon_sym_checked] = ACTIONS(3773),
    [anon_sym_BANG] = ACTIONS(3775),
    [anon_sym_TILDE] = ACTIONS(3775),
    [anon_sym_PLUS_PLUS] = ACTIONS(3775),
    [anon_sym_DASH_DASH] = ACTIONS(3775),
    [anon_sym_true] = ACTIONS(3773),
    [anon_sym_false] = ACTIONS(3773),
    [anon_sym_PLUS] = ACTIONS(3773),
    [anon_sym_DASH] = ACTIONS(3773),
    [anon_sym_STAR] = ACTIONS(3775),
    [anon_sym_CARET] = ACTIONS(3775),
    [anon_sym_AMP] = ACTIONS(3775),
    [anon_sym_this] = ACTIONS(3773),
    [anon_sym_scoped] = ACTIONS(3773),
    [anon_sym_base] = ACTIONS(3773),
    [anon_sym_var] = ACTIONS(3773),
    [sym_predefined_type] = ACTIONS(3773),
    [anon_sym_break] = ACTIONS(3773),
    [anon_sym_unchecked] = ACTIONS(3773),
    [anon_sym_continue] = ACTIONS(3773),
    [anon_sym_do] = ACTIONS(3773),
    [anon_sym_while] = ACTIONS(3773),
    [anon_sym_for] = ACTIONS(3773),
    [anon_sym_lock] = ACTIONS(3773),
    [anon_sym_yield] = ACTIONS(3773),
    [anon_sym_switch] = ACTIONS(3773),
    [anon_sym_default] = ACTIONS(3773),
    [anon_sym_throw] = ACTIONS(3773),
    [anon_sym_try] = ACTIONS(3773),
    [anon_sym_when] = ACTIONS(3773),
    [anon_sym_await] = ACTIONS(3773),
    [anon_sym_foreach] = ACTIONS(3773),
    [anon_sym_goto] = ACTIONS(3773),
    [anon_sym_if] = ACTIONS(3773),
    [anon_sym_DOT_DOT] = ACTIONS(3775),
    [anon_sym_from] = ACTIONS(3773),
    [anon_sym_into] = ACTIONS(3773),
    [anon_sym_join] = ACTIONS(3773),
    [anon_sym_on] = ACTIONS(3773),
    [anon_sym_equals] = ACTIONS(3773),
    [anon_sym_let] = ACTIONS(3773),
    [anon_sym_orderby] = ACTIONS(3773),
    [anon_sym_ascending] = ACTIONS(3773),
    [anon_sym_descending] = ACTIONS(3773),
    [anon_sym_group] = ACTIONS(3773),
    [anon_sym_by] = ACTIONS(3773),
    [anon_sym_select] = ACTIONS(3773),
    [anon_sym_stackalloc] = ACTIONS(3773),
    [anon_sym_sizeof] = ACTIONS(3773),
    [anon_sym_typeof] = ACTIONS(3773),
    [anon_sym___makeref] = ACTIONS(3773),
    [anon_sym___reftype] = ACTIONS(3773),
    [anon_sym___refvalue] = ACTIONS(3773),
    [sym_null_literal] = ACTIONS(3773),
    [anon_sym_SQUOTE] = ACTIONS(3775),
    [sym_integer_literal] = ACTIONS(3773),
    [sym_real_literal] = ACTIONS(3775),
    [anon_sym_DQUOTE] = ACTIONS(3775),
    [sym_verbatim_string_literal] = ACTIONS(3775),
    [aux_sym_preproc_if_token1] = ACTIONS(3775),
    [aux_sym_preproc_if_token3] = ACTIONS(3775),
    [aux_sym_preproc_else_token1] = ACTIONS(3775),
    [aux_sym_preproc_elif_token1] = ACTIONS(3775),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3775),
    [sym_interpolation_verbatim_start] = ACTIONS(3775),
    [sym_interpolation_raw_start] = ACTIONS(3775),
    [sym_raw_string_start] = ACTIONS(3775),
  },
  [2400] = {
    [sym_preproc_region] = STATE(2400),
    [sym_preproc_endregion] = STATE(2400),
    [sym_preproc_line] = STATE(2400),
    [sym_preproc_pragma] = STATE(2400),
    [sym_preproc_nullable] = STATE(2400),
    [sym_preproc_error] = STATE(2400),
    [sym_preproc_warning] = STATE(2400),
    [sym_preproc_define] = STATE(2400),
    [sym_preproc_undef] = STATE(2400),
    [sym__identifier_token] = ACTIONS(3777),
    [anon_sym_extern] = ACTIONS(3777),
    [anon_sym_alias] = ACTIONS(3777),
    [anon_sym_SEMI] = ACTIONS(3779),
    [anon_sym_global] = ACTIONS(3777),
    [anon_sym_using] = ACTIONS(3777),
    [anon_sym_unsafe] = ACTIONS(3777),
    [anon_sym_static] = ACTIONS(3777),
    [anon_sym_LBRACK] = ACTIONS(3779),
    [anon_sym_LPAREN] = ACTIONS(3779),
    [anon_sym_return] = ACTIONS(3777),
    [anon_sym_namespace] = ACTIONS(3777),
    [anon_sym_class] = ACTIONS(3777),
    [anon_sym_ref] = ACTIONS(3777),
    [anon_sym_struct] = ACTIONS(3777),
    [anon_sym_enum] = ACTIONS(3777),
    [anon_sym_LBRACE] = ACTIONS(3779),
    [anon_sym_interface] = ACTIONS(3777),
    [anon_sym_delegate] = ACTIONS(3777),
    [anon_sym_record] = ACTIONS(3777),
    [anon_sym_abstract] = ACTIONS(3777),
    [anon_sym_async] = ACTIONS(3777),
    [anon_sym_const] = ACTIONS(3777),
    [anon_sym_file] = ACTIONS(3777),
    [anon_sym_fixed] = ACTIONS(3777),
    [anon_sym_internal] = ACTIONS(3777),
    [anon_sym_new] = ACTIONS(3777),
    [anon_sym_override] = ACTIONS(3777),
    [anon_sym_partial] = ACTIONS(3777),
    [anon_sym_private] = ACTIONS(3777),
    [anon_sym_protected] = ACTIONS(3777),
    [anon_sym_public] = ACTIONS(3777),
    [anon_sym_readonly] = ACTIONS(3777),
    [anon_sym_required] = ACTIONS(3777),
    [anon_sym_sealed] = ACTIONS(3777),
    [anon_sym_virtual] = ACTIONS(3777),
    [anon_sym_volatile] = ACTIONS(3777),
    [anon_sym_where] = ACTIONS(3777),
    [anon_sym_notnull] = ACTIONS(3777),
    [anon_sym_unmanaged] = ACTIONS(3777),
    [anon_sym_checked] = ACTIONS(3777),
    [anon_sym_BANG] = ACTIONS(3779),
    [anon_sym_TILDE] = ACTIONS(3779),
    [anon_sym_PLUS_PLUS] = ACTIONS(3779),
    [anon_sym_DASH_DASH] = ACTIONS(3779),
    [anon_sym_true] = ACTIONS(3777),
    [anon_sym_false] = ACTIONS(3777),
    [anon_sym_PLUS] = ACTIONS(3777),
    [anon_sym_DASH] = ACTIONS(3777),
    [anon_sym_STAR] = ACTIONS(3779),
    [anon_sym_CARET] = ACTIONS(3779),
    [anon_sym_AMP] = ACTIONS(3779),
    [anon_sym_this] = ACTIONS(3777),
    [anon_sym_scoped] = ACTIONS(3777),
    [anon_sym_base] = ACTIONS(3777),
    [anon_sym_var] = ACTIONS(3777),
    [sym_predefined_type] = ACTIONS(3777),
    [anon_sym_break] = ACTIONS(3777),
    [anon_sym_unchecked] = ACTIONS(3777),
    [anon_sym_continue] = ACTIONS(3777),
    [anon_sym_do] = ACTIONS(3777),
    [anon_sym_while] = ACTIONS(3777),
    [anon_sym_for] = ACTIONS(3777),
    [anon_sym_lock] = ACTIONS(3777),
    [anon_sym_yield] = ACTIONS(3777),
    [anon_sym_switch] = ACTIONS(3777),
    [anon_sym_default] = ACTIONS(3777),
    [anon_sym_throw] = ACTIONS(3777),
    [anon_sym_try] = ACTIONS(3777),
    [anon_sym_when] = ACTIONS(3777),
    [anon_sym_await] = ACTIONS(3777),
    [anon_sym_foreach] = ACTIONS(3777),
    [anon_sym_goto] = ACTIONS(3777),
    [anon_sym_if] = ACTIONS(3777),
    [anon_sym_DOT_DOT] = ACTIONS(3779),
    [anon_sym_from] = ACTIONS(3777),
    [anon_sym_into] = ACTIONS(3777),
    [anon_sym_join] = ACTIONS(3777),
    [anon_sym_on] = ACTIONS(3777),
    [anon_sym_equals] = ACTIONS(3777),
    [anon_sym_let] = ACTIONS(3777),
    [anon_sym_orderby] = ACTIONS(3777),
    [anon_sym_ascending] = ACTIONS(3777),
    [anon_sym_descending] = ACTIONS(3777),
    [anon_sym_group] = ACTIONS(3777),
    [anon_sym_by] = ACTIONS(3777),
    [anon_sym_select] = ACTIONS(3777),
    [anon_sym_stackalloc] = ACTIONS(3777),
    [anon_sym_sizeof] = ACTIONS(3777),
    [anon_sym_typeof] = ACTIONS(3777),
    [anon_sym___makeref] = ACTIONS(3777),
    [anon_sym___reftype] = ACTIONS(3777),
    [anon_sym___refvalue] = ACTIONS(3777),
    [sym_null_literal] = ACTIONS(3777),
    [anon_sym_SQUOTE] = ACTIONS(3779),
    [sym_integer_literal] = ACTIONS(3777),
    [sym_real_literal] = ACTIONS(3779),
    [anon_sym_DQUOTE] = ACTIONS(3779),
    [sym_verbatim_string_literal] = ACTIONS(3779),
    [aux_sym_preproc_if_token1] = ACTIONS(3779),
    [aux_sym_preproc_if_token3] = ACTIONS(3779),
    [aux_sym_preproc_else_token1] = ACTIONS(3779),
    [aux_sym_preproc_elif_token1] = ACTIONS(3779),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3779),
    [sym_interpolation_verbatim_start] = ACTIONS(3779),
    [sym_interpolation_raw_start] = ACTIONS(3779),
    [sym_raw_string_start] = ACTIONS(3779),
  },
  [2401] = {
    [sym_preproc_region] = STATE(2401),
    [sym_preproc_endregion] = STATE(2401),
    [sym_preproc_line] = STATE(2401),
    [sym_preproc_pragma] = STATE(2401),
    [sym_preproc_nullable] = STATE(2401),
    [sym_preproc_error] = STATE(2401),
    [sym_preproc_warning] = STATE(2401),
    [sym_preproc_define] = STATE(2401),
    [sym_preproc_undef] = STATE(2401),
    [sym__identifier_token] = ACTIONS(3781),
    [anon_sym_extern] = ACTIONS(3781),
    [anon_sym_alias] = ACTIONS(3781),
    [anon_sym_SEMI] = ACTIONS(3783),
    [anon_sym_global] = ACTIONS(3781),
    [anon_sym_using] = ACTIONS(3781),
    [anon_sym_unsafe] = ACTIONS(3781),
    [anon_sym_static] = ACTIONS(3781),
    [anon_sym_LBRACK] = ACTIONS(3783),
    [anon_sym_LPAREN] = ACTIONS(3783),
    [anon_sym_return] = ACTIONS(3781),
    [anon_sym_namespace] = ACTIONS(3781),
    [anon_sym_class] = ACTIONS(3781),
    [anon_sym_ref] = ACTIONS(3781),
    [anon_sym_struct] = ACTIONS(3781),
    [anon_sym_enum] = ACTIONS(3781),
    [anon_sym_LBRACE] = ACTIONS(3783),
    [anon_sym_interface] = ACTIONS(3781),
    [anon_sym_delegate] = ACTIONS(3781),
    [anon_sym_record] = ACTIONS(3781),
    [anon_sym_abstract] = ACTIONS(3781),
    [anon_sym_async] = ACTIONS(3781),
    [anon_sym_const] = ACTIONS(3781),
    [anon_sym_file] = ACTIONS(3781),
    [anon_sym_fixed] = ACTIONS(3781),
    [anon_sym_internal] = ACTIONS(3781),
    [anon_sym_new] = ACTIONS(3781),
    [anon_sym_override] = ACTIONS(3781),
    [anon_sym_partial] = ACTIONS(3781),
    [anon_sym_private] = ACTIONS(3781),
    [anon_sym_protected] = ACTIONS(3781),
    [anon_sym_public] = ACTIONS(3781),
    [anon_sym_readonly] = ACTIONS(3781),
    [anon_sym_required] = ACTIONS(3781),
    [anon_sym_sealed] = ACTIONS(3781),
    [anon_sym_virtual] = ACTIONS(3781),
    [anon_sym_volatile] = ACTIONS(3781),
    [anon_sym_where] = ACTIONS(3781),
    [anon_sym_notnull] = ACTIONS(3781),
    [anon_sym_unmanaged] = ACTIONS(3781),
    [anon_sym_checked] = ACTIONS(3781),
    [anon_sym_BANG] = ACTIONS(3783),
    [anon_sym_TILDE] = ACTIONS(3783),
    [anon_sym_PLUS_PLUS] = ACTIONS(3783),
    [anon_sym_DASH_DASH] = ACTIONS(3783),
    [anon_sym_true] = ACTIONS(3781),
    [anon_sym_false] = ACTIONS(3781),
    [anon_sym_PLUS] = ACTIONS(3781),
    [anon_sym_DASH] = ACTIONS(3781),
    [anon_sym_STAR] = ACTIONS(3783),
    [anon_sym_CARET] = ACTIONS(3783),
    [anon_sym_AMP] = ACTIONS(3783),
    [anon_sym_this] = ACTIONS(3781),
    [anon_sym_scoped] = ACTIONS(3781),
    [anon_sym_base] = ACTIONS(3781),
    [anon_sym_var] = ACTIONS(3781),
    [sym_predefined_type] = ACTIONS(3781),
    [anon_sym_break] = ACTIONS(3781),
    [anon_sym_unchecked] = ACTIONS(3781),
    [anon_sym_continue] = ACTIONS(3781),
    [anon_sym_do] = ACTIONS(3781),
    [anon_sym_while] = ACTIONS(3781),
    [anon_sym_for] = ACTIONS(3781),
    [anon_sym_lock] = ACTIONS(3781),
    [anon_sym_yield] = ACTIONS(3781),
    [anon_sym_switch] = ACTIONS(3781),
    [anon_sym_default] = ACTIONS(3781),
    [anon_sym_throw] = ACTIONS(3781),
    [anon_sym_try] = ACTIONS(3781),
    [anon_sym_when] = ACTIONS(3781),
    [anon_sym_await] = ACTIONS(3781),
    [anon_sym_foreach] = ACTIONS(3781),
    [anon_sym_goto] = ACTIONS(3781),
    [anon_sym_if] = ACTIONS(3781),
    [anon_sym_DOT_DOT] = ACTIONS(3783),
    [anon_sym_from] = ACTIONS(3781),
    [anon_sym_into] = ACTIONS(3781),
    [anon_sym_join] = ACTIONS(3781),
    [anon_sym_on] = ACTIONS(3781),
    [anon_sym_equals] = ACTIONS(3781),
    [anon_sym_let] = ACTIONS(3781),
    [anon_sym_orderby] = ACTIONS(3781),
    [anon_sym_ascending] = ACTIONS(3781),
    [anon_sym_descending] = ACTIONS(3781),
    [anon_sym_group] = ACTIONS(3781),
    [anon_sym_by] = ACTIONS(3781),
    [anon_sym_select] = ACTIONS(3781),
    [anon_sym_stackalloc] = ACTIONS(3781),
    [anon_sym_sizeof] = ACTIONS(3781),
    [anon_sym_typeof] = ACTIONS(3781),
    [anon_sym___makeref] = ACTIONS(3781),
    [anon_sym___reftype] = ACTIONS(3781),
    [anon_sym___refvalue] = ACTIONS(3781),
    [sym_null_literal] = ACTIONS(3781),
    [anon_sym_SQUOTE] = ACTIONS(3783),
    [sym_integer_literal] = ACTIONS(3781),
    [sym_real_literal] = ACTIONS(3783),
    [anon_sym_DQUOTE] = ACTIONS(3783),
    [sym_verbatim_string_literal] = ACTIONS(3783),
    [aux_sym_preproc_if_token1] = ACTIONS(3783),
    [aux_sym_preproc_if_token3] = ACTIONS(3783),
    [aux_sym_preproc_else_token1] = ACTIONS(3783),
    [aux_sym_preproc_elif_token1] = ACTIONS(3783),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3783),
    [sym_interpolation_verbatim_start] = ACTIONS(3783),
    [sym_interpolation_raw_start] = ACTIONS(3783),
    [sym_raw_string_start] = ACTIONS(3783),
  },
  [2402] = {
    [sym_preproc_region] = STATE(2402),
    [sym_preproc_endregion] = STATE(2402),
    [sym_preproc_line] = STATE(2402),
    [sym_preproc_pragma] = STATE(2402),
    [sym_preproc_nullable] = STATE(2402),
    [sym_preproc_error] = STATE(2402),
    [sym_preproc_warning] = STATE(2402),
    [sym_preproc_define] = STATE(2402),
    [sym_preproc_undef] = STATE(2402),
    [sym__identifier_token] = ACTIONS(3785),
    [anon_sym_extern] = ACTIONS(3785),
    [anon_sym_alias] = ACTIONS(3785),
    [anon_sym_SEMI] = ACTIONS(3787),
    [anon_sym_global] = ACTIONS(3785),
    [anon_sym_using] = ACTIONS(3785),
    [anon_sym_unsafe] = ACTIONS(3785),
    [anon_sym_static] = ACTIONS(3785),
    [anon_sym_LBRACK] = ACTIONS(3787),
    [anon_sym_LPAREN] = ACTIONS(3787),
    [anon_sym_return] = ACTIONS(3785),
    [anon_sym_namespace] = ACTIONS(3785),
    [anon_sym_class] = ACTIONS(3785),
    [anon_sym_ref] = ACTIONS(3785),
    [anon_sym_struct] = ACTIONS(3785),
    [anon_sym_enum] = ACTIONS(3785),
    [anon_sym_LBRACE] = ACTIONS(3787),
    [anon_sym_interface] = ACTIONS(3785),
    [anon_sym_delegate] = ACTIONS(3785),
    [anon_sym_record] = ACTIONS(3785),
    [anon_sym_abstract] = ACTIONS(3785),
    [anon_sym_async] = ACTIONS(3785),
    [anon_sym_const] = ACTIONS(3785),
    [anon_sym_file] = ACTIONS(3785),
    [anon_sym_fixed] = ACTIONS(3785),
    [anon_sym_internal] = ACTIONS(3785),
    [anon_sym_new] = ACTIONS(3785),
    [anon_sym_override] = ACTIONS(3785),
    [anon_sym_partial] = ACTIONS(3785),
    [anon_sym_private] = ACTIONS(3785),
    [anon_sym_protected] = ACTIONS(3785),
    [anon_sym_public] = ACTIONS(3785),
    [anon_sym_readonly] = ACTIONS(3785),
    [anon_sym_required] = ACTIONS(3785),
    [anon_sym_sealed] = ACTIONS(3785),
    [anon_sym_virtual] = ACTIONS(3785),
    [anon_sym_volatile] = ACTIONS(3785),
    [anon_sym_where] = ACTIONS(3785),
    [anon_sym_notnull] = ACTIONS(3785),
    [anon_sym_unmanaged] = ACTIONS(3785),
    [anon_sym_checked] = ACTIONS(3785),
    [anon_sym_BANG] = ACTIONS(3787),
    [anon_sym_TILDE] = ACTIONS(3787),
    [anon_sym_PLUS_PLUS] = ACTIONS(3787),
    [anon_sym_DASH_DASH] = ACTIONS(3787),
    [anon_sym_true] = ACTIONS(3785),
    [anon_sym_false] = ACTIONS(3785),
    [anon_sym_PLUS] = ACTIONS(3785),
    [anon_sym_DASH] = ACTIONS(3785),
    [anon_sym_STAR] = ACTIONS(3787),
    [anon_sym_CARET] = ACTIONS(3787),
    [anon_sym_AMP] = ACTIONS(3787),
    [anon_sym_this] = ACTIONS(3785),
    [anon_sym_scoped] = ACTIONS(3785),
    [anon_sym_base] = ACTIONS(3785),
    [anon_sym_var] = ACTIONS(3785),
    [sym_predefined_type] = ACTIONS(3785),
    [anon_sym_break] = ACTIONS(3785),
    [anon_sym_unchecked] = ACTIONS(3785),
    [anon_sym_continue] = ACTIONS(3785),
    [anon_sym_do] = ACTIONS(3785),
    [anon_sym_while] = ACTIONS(3785),
    [anon_sym_for] = ACTIONS(3785),
    [anon_sym_lock] = ACTIONS(3785),
    [anon_sym_yield] = ACTIONS(3785),
    [anon_sym_switch] = ACTIONS(3785),
    [anon_sym_default] = ACTIONS(3785),
    [anon_sym_throw] = ACTIONS(3785),
    [anon_sym_try] = ACTIONS(3785),
    [anon_sym_when] = ACTIONS(3785),
    [anon_sym_await] = ACTIONS(3785),
    [anon_sym_foreach] = ACTIONS(3785),
    [anon_sym_goto] = ACTIONS(3785),
    [anon_sym_if] = ACTIONS(3785),
    [anon_sym_DOT_DOT] = ACTIONS(3787),
    [anon_sym_from] = ACTIONS(3785),
    [anon_sym_into] = ACTIONS(3785),
    [anon_sym_join] = ACTIONS(3785),
    [anon_sym_on] = ACTIONS(3785),
    [anon_sym_equals] = ACTIONS(3785),
    [anon_sym_let] = ACTIONS(3785),
    [anon_sym_orderby] = ACTIONS(3785),
    [anon_sym_ascending] = ACTIONS(3785),
    [anon_sym_descending] = ACTIONS(3785),
    [anon_sym_group] = ACTIONS(3785),
    [anon_sym_by] = ACTIONS(3785),
    [anon_sym_select] = ACTIONS(3785),
    [anon_sym_stackalloc] = ACTIONS(3785),
    [anon_sym_sizeof] = ACTIONS(3785),
    [anon_sym_typeof] = ACTIONS(3785),
    [anon_sym___makeref] = ACTIONS(3785),
    [anon_sym___reftype] = ACTIONS(3785),
    [anon_sym___refvalue] = ACTIONS(3785),
    [sym_null_literal] = ACTIONS(3785),
    [anon_sym_SQUOTE] = ACTIONS(3787),
    [sym_integer_literal] = ACTIONS(3785),
    [sym_real_literal] = ACTIONS(3787),
    [anon_sym_DQUOTE] = ACTIONS(3787),
    [sym_verbatim_string_literal] = ACTIONS(3787),
    [aux_sym_preproc_if_token1] = ACTIONS(3787),
    [aux_sym_preproc_if_token3] = ACTIONS(3787),
    [aux_sym_preproc_else_token1] = ACTIONS(3787),
    [aux_sym_preproc_elif_token1] = ACTIONS(3787),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3787),
    [sym_interpolation_verbatim_start] = ACTIONS(3787),
    [sym_interpolation_raw_start] = ACTIONS(3787),
    [sym_raw_string_start] = ACTIONS(3787),
  },
  [2403] = {
    [sym_preproc_region] = STATE(2403),
    [sym_preproc_endregion] = STATE(2403),
    [sym_preproc_line] = STATE(2403),
    [sym_preproc_pragma] = STATE(2403),
    [sym_preproc_nullable] = STATE(2403),
    [sym_preproc_error] = STATE(2403),
    [sym_preproc_warning] = STATE(2403),
    [sym_preproc_define] = STATE(2403),
    [sym_preproc_undef] = STATE(2403),
    [sym__identifier_token] = ACTIONS(3789),
    [anon_sym_extern] = ACTIONS(3789),
    [anon_sym_alias] = ACTIONS(3789),
    [anon_sym_SEMI] = ACTIONS(3791),
    [anon_sym_global] = ACTIONS(3789),
    [anon_sym_using] = ACTIONS(3789),
    [anon_sym_unsafe] = ACTIONS(3789),
    [anon_sym_static] = ACTIONS(3789),
    [anon_sym_LBRACK] = ACTIONS(3791),
    [anon_sym_LPAREN] = ACTIONS(3791),
    [anon_sym_return] = ACTIONS(3789),
    [anon_sym_namespace] = ACTIONS(3789),
    [anon_sym_class] = ACTIONS(3789),
    [anon_sym_ref] = ACTIONS(3789),
    [anon_sym_struct] = ACTIONS(3789),
    [anon_sym_enum] = ACTIONS(3789),
    [anon_sym_LBRACE] = ACTIONS(3791),
    [anon_sym_interface] = ACTIONS(3789),
    [anon_sym_delegate] = ACTIONS(3789),
    [anon_sym_record] = ACTIONS(3789),
    [anon_sym_abstract] = ACTIONS(3789),
    [anon_sym_async] = ACTIONS(3789),
    [anon_sym_const] = ACTIONS(3789),
    [anon_sym_file] = ACTIONS(3789),
    [anon_sym_fixed] = ACTIONS(3789),
    [anon_sym_internal] = ACTIONS(3789),
    [anon_sym_new] = ACTIONS(3789),
    [anon_sym_override] = ACTIONS(3789),
    [anon_sym_partial] = ACTIONS(3789),
    [anon_sym_private] = ACTIONS(3789),
    [anon_sym_protected] = ACTIONS(3789),
    [anon_sym_public] = ACTIONS(3789),
    [anon_sym_readonly] = ACTIONS(3789),
    [anon_sym_required] = ACTIONS(3789),
    [anon_sym_sealed] = ACTIONS(3789),
    [anon_sym_virtual] = ACTIONS(3789),
    [anon_sym_volatile] = ACTIONS(3789),
    [anon_sym_where] = ACTIONS(3789),
    [anon_sym_notnull] = ACTIONS(3789),
    [anon_sym_unmanaged] = ACTIONS(3789),
    [anon_sym_checked] = ACTIONS(3789),
    [anon_sym_BANG] = ACTIONS(3791),
    [anon_sym_TILDE] = ACTIONS(3791),
    [anon_sym_PLUS_PLUS] = ACTIONS(3791),
    [anon_sym_DASH_DASH] = ACTIONS(3791),
    [anon_sym_true] = ACTIONS(3789),
    [anon_sym_false] = ACTIONS(3789),
    [anon_sym_PLUS] = ACTIONS(3789),
    [anon_sym_DASH] = ACTIONS(3789),
    [anon_sym_STAR] = ACTIONS(3791),
    [anon_sym_CARET] = ACTIONS(3791),
    [anon_sym_AMP] = ACTIONS(3791),
    [anon_sym_this] = ACTIONS(3789),
    [anon_sym_scoped] = ACTIONS(3789),
    [anon_sym_base] = ACTIONS(3789),
    [anon_sym_var] = ACTIONS(3789),
    [sym_predefined_type] = ACTIONS(3789),
    [anon_sym_break] = ACTIONS(3789),
    [anon_sym_unchecked] = ACTIONS(3789),
    [anon_sym_continue] = ACTIONS(3789),
    [anon_sym_do] = ACTIONS(3789),
    [anon_sym_while] = ACTIONS(3789),
    [anon_sym_for] = ACTIONS(3789),
    [anon_sym_lock] = ACTIONS(3789),
    [anon_sym_yield] = ACTIONS(3789),
    [anon_sym_switch] = ACTIONS(3789),
    [anon_sym_default] = ACTIONS(3789),
    [anon_sym_throw] = ACTIONS(3789),
    [anon_sym_try] = ACTIONS(3789),
    [anon_sym_when] = ACTIONS(3789),
    [anon_sym_await] = ACTIONS(3789),
    [anon_sym_foreach] = ACTIONS(3789),
    [anon_sym_goto] = ACTIONS(3789),
    [anon_sym_if] = ACTIONS(3789),
    [anon_sym_DOT_DOT] = ACTIONS(3791),
    [anon_sym_from] = ACTIONS(3789),
    [anon_sym_into] = ACTIONS(3789),
    [anon_sym_join] = ACTIONS(3789),
    [anon_sym_on] = ACTIONS(3789),
    [anon_sym_equals] = ACTIONS(3789),
    [anon_sym_let] = ACTIONS(3789),
    [anon_sym_orderby] = ACTIONS(3789),
    [anon_sym_ascending] = ACTIONS(3789),
    [anon_sym_descending] = ACTIONS(3789),
    [anon_sym_group] = ACTIONS(3789),
    [anon_sym_by] = ACTIONS(3789),
    [anon_sym_select] = ACTIONS(3789),
    [anon_sym_stackalloc] = ACTIONS(3789),
    [anon_sym_sizeof] = ACTIONS(3789),
    [anon_sym_typeof] = ACTIONS(3789),
    [anon_sym___makeref] = ACTIONS(3789),
    [anon_sym___reftype] = ACTIONS(3789),
    [anon_sym___refvalue] = ACTIONS(3789),
    [sym_null_literal] = ACTIONS(3789),
    [anon_sym_SQUOTE] = ACTIONS(3791),
    [sym_integer_literal] = ACTIONS(3789),
    [sym_real_literal] = ACTIONS(3791),
    [anon_sym_DQUOTE] = ACTIONS(3791),
    [sym_verbatim_string_literal] = ACTIONS(3791),
    [aux_sym_preproc_if_token1] = ACTIONS(3791),
    [aux_sym_preproc_if_token3] = ACTIONS(3791),
    [aux_sym_preproc_else_token1] = ACTIONS(3791),
    [aux_sym_preproc_elif_token1] = ACTIONS(3791),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3791),
    [sym_interpolation_verbatim_start] = ACTIONS(3791),
    [sym_interpolation_raw_start] = ACTIONS(3791),
    [sym_raw_string_start] = ACTIONS(3791),
  },
  [2404] = {
    [sym_preproc_region] = STATE(2404),
    [sym_preproc_endregion] = STATE(2404),
    [sym_preproc_line] = STATE(2404),
    [sym_preproc_pragma] = STATE(2404),
    [sym_preproc_nullable] = STATE(2404),
    [sym_preproc_error] = STATE(2404),
    [sym_preproc_warning] = STATE(2404),
    [sym_preproc_define] = STATE(2404),
    [sym_preproc_undef] = STATE(2404),
    [sym__identifier_token] = ACTIONS(3793),
    [anon_sym_extern] = ACTIONS(3793),
    [anon_sym_alias] = ACTIONS(3793),
    [anon_sym_SEMI] = ACTIONS(3795),
    [anon_sym_global] = ACTIONS(3793),
    [anon_sym_using] = ACTIONS(3793),
    [anon_sym_unsafe] = ACTIONS(3793),
    [anon_sym_static] = ACTIONS(3793),
    [anon_sym_LBRACK] = ACTIONS(3795),
    [anon_sym_LPAREN] = ACTIONS(3795),
    [anon_sym_return] = ACTIONS(3793),
    [anon_sym_namespace] = ACTIONS(3793),
    [anon_sym_class] = ACTIONS(3793),
    [anon_sym_ref] = ACTIONS(3793),
    [anon_sym_struct] = ACTIONS(3793),
    [anon_sym_enum] = ACTIONS(3793),
    [anon_sym_LBRACE] = ACTIONS(3795),
    [anon_sym_interface] = ACTIONS(3793),
    [anon_sym_delegate] = ACTIONS(3793),
    [anon_sym_record] = ACTIONS(3793),
    [anon_sym_abstract] = ACTIONS(3793),
    [anon_sym_async] = ACTIONS(3793),
    [anon_sym_const] = ACTIONS(3793),
    [anon_sym_file] = ACTIONS(3793),
    [anon_sym_fixed] = ACTIONS(3793),
    [anon_sym_internal] = ACTIONS(3793),
    [anon_sym_new] = ACTIONS(3793),
    [anon_sym_override] = ACTIONS(3793),
    [anon_sym_partial] = ACTIONS(3793),
    [anon_sym_private] = ACTIONS(3793),
    [anon_sym_protected] = ACTIONS(3793),
    [anon_sym_public] = ACTIONS(3793),
    [anon_sym_readonly] = ACTIONS(3793),
    [anon_sym_required] = ACTIONS(3793),
    [anon_sym_sealed] = ACTIONS(3793),
    [anon_sym_virtual] = ACTIONS(3793),
    [anon_sym_volatile] = ACTIONS(3793),
    [anon_sym_where] = ACTIONS(3793),
    [anon_sym_notnull] = ACTIONS(3793),
    [anon_sym_unmanaged] = ACTIONS(3793),
    [anon_sym_checked] = ACTIONS(3793),
    [anon_sym_BANG] = ACTIONS(3795),
    [anon_sym_TILDE] = ACTIONS(3795),
    [anon_sym_PLUS_PLUS] = ACTIONS(3795),
    [anon_sym_DASH_DASH] = ACTIONS(3795),
    [anon_sym_true] = ACTIONS(3793),
    [anon_sym_false] = ACTIONS(3793),
    [anon_sym_PLUS] = ACTIONS(3793),
    [anon_sym_DASH] = ACTIONS(3793),
    [anon_sym_STAR] = ACTIONS(3795),
    [anon_sym_CARET] = ACTIONS(3795),
    [anon_sym_AMP] = ACTIONS(3795),
    [anon_sym_this] = ACTIONS(3793),
    [anon_sym_scoped] = ACTIONS(3793),
    [anon_sym_base] = ACTIONS(3793),
    [anon_sym_var] = ACTIONS(3793),
    [sym_predefined_type] = ACTIONS(3793),
    [anon_sym_break] = ACTIONS(3793),
    [anon_sym_unchecked] = ACTIONS(3793),
    [anon_sym_continue] = ACTIONS(3793),
    [anon_sym_do] = ACTIONS(3793),
    [anon_sym_while] = ACTIONS(3793),
    [anon_sym_for] = ACTIONS(3793),
    [anon_sym_lock] = ACTIONS(3793),
    [anon_sym_yield] = ACTIONS(3793),
    [anon_sym_switch] = ACTIONS(3793),
    [anon_sym_default] = ACTIONS(3793),
    [anon_sym_throw] = ACTIONS(3793),
    [anon_sym_try] = ACTIONS(3793),
    [anon_sym_when] = ACTIONS(3793),
    [anon_sym_await] = ACTIONS(3793),
    [anon_sym_foreach] = ACTIONS(3793),
    [anon_sym_goto] = ACTIONS(3793),
    [anon_sym_if] = ACTIONS(3793),
    [anon_sym_DOT_DOT] = ACTIONS(3795),
    [anon_sym_from] = ACTIONS(3793),
    [anon_sym_into] = ACTIONS(3793),
    [anon_sym_join] = ACTIONS(3793),
    [anon_sym_on] = ACTIONS(3793),
    [anon_sym_equals] = ACTIONS(3793),
    [anon_sym_let] = ACTIONS(3793),
    [anon_sym_orderby] = ACTIONS(3793),
    [anon_sym_ascending] = ACTIONS(3793),
    [anon_sym_descending] = ACTIONS(3793),
    [anon_sym_group] = ACTIONS(3793),
    [anon_sym_by] = ACTIONS(3793),
    [anon_sym_select] = ACTIONS(3793),
    [anon_sym_stackalloc] = ACTIONS(3793),
    [anon_sym_sizeof] = ACTIONS(3793),
    [anon_sym_typeof] = ACTIONS(3793),
    [anon_sym___makeref] = ACTIONS(3793),
    [anon_sym___reftype] = ACTIONS(3793),
    [anon_sym___refvalue] = ACTIONS(3793),
    [sym_null_literal] = ACTIONS(3793),
    [anon_sym_SQUOTE] = ACTIONS(3795),
    [sym_integer_literal] = ACTIONS(3793),
    [sym_real_literal] = ACTIONS(3795),
    [anon_sym_DQUOTE] = ACTIONS(3795),
    [sym_verbatim_string_literal] = ACTIONS(3795),
    [aux_sym_preproc_if_token1] = ACTIONS(3795),
    [aux_sym_preproc_if_token3] = ACTIONS(3795),
    [aux_sym_preproc_else_token1] = ACTIONS(3795),
    [aux_sym_preproc_elif_token1] = ACTIONS(3795),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3795),
    [sym_interpolation_verbatim_start] = ACTIONS(3795),
    [sym_interpolation_raw_start] = ACTIONS(3795),
    [sym_raw_string_start] = ACTIONS(3795),
  },
  [2405] = {
    [sym_preproc_region] = STATE(2405),
    [sym_preproc_endregion] = STATE(2405),
    [sym_preproc_line] = STATE(2405),
    [sym_preproc_pragma] = STATE(2405),
    [sym_preproc_nullable] = STATE(2405),
    [sym_preproc_error] = STATE(2405),
    [sym_preproc_warning] = STATE(2405),
    [sym_preproc_define] = STATE(2405),
    [sym_preproc_undef] = STATE(2405),
    [sym__identifier_token] = ACTIONS(3797),
    [anon_sym_extern] = ACTIONS(3797),
    [anon_sym_alias] = ACTIONS(3797),
    [anon_sym_SEMI] = ACTIONS(3799),
    [anon_sym_global] = ACTIONS(3797),
    [anon_sym_using] = ACTIONS(3797),
    [anon_sym_unsafe] = ACTIONS(3797),
    [anon_sym_static] = ACTIONS(3797),
    [anon_sym_LBRACK] = ACTIONS(3799),
    [anon_sym_LPAREN] = ACTIONS(3799),
    [anon_sym_return] = ACTIONS(3797),
    [anon_sym_namespace] = ACTIONS(3797),
    [anon_sym_class] = ACTIONS(3797),
    [anon_sym_ref] = ACTIONS(3797),
    [anon_sym_struct] = ACTIONS(3797),
    [anon_sym_enum] = ACTIONS(3797),
    [anon_sym_LBRACE] = ACTIONS(3799),
    [anon_sym_interface] = ACTIONS(3797),
    [anon_sym_delegate] = ACTIONS(3797),
    [anon_sym_record] = ACTIONS(3797),
    [anon_sym_abstract] = ACTIONS(3797),
    [anon_sym_async] = ACTIONS(3797),
    [anon_sym_const] = ACTIONS(3797),
    [anon_sym_file] = ACTIONS(3797),
    [anon_sym_fixed] = ACTIONS(3797),
    [anon_sym_internal] = ACTIONS(3797),
    [anon_sym_new] = ACTIONS(3797),
    [anon_sym_override] = ACTIONS(3797),
    [anon_sym_partial] = ACTIONS(3797),
    [anon_sym_private] = ACTIONS(3797),
    [anon_sym_protected] = ACTIONS(3797),
    [anon_sym_public] = ACTIONS(3797),
    [anon_sym_readonly] = ACTIONS(3797),
    [anon_sym_required] = ACTIONS(3797),
    [anon_sym_sealed] = ACTIONS(3797),
    [anon_sym_virtual] = ACTIONS(3797),
    [anon_sym_volatile] = ACTIONS(3797),
    [anon_sym_where] = ACTIONS(3797),
    [anon_sym_notnull] = ACTIONS(3797),
    [anon_sym_unmanaged] = ACTIONS(3797),
    [anon_sym_checked] = ACTIONS(3797),
    [anon_sym_BANG] = ACTIONS(3799),
    [anon_sym_TILDE] = ACTIONS(3799),
    [anon_sym_PLUS_PLUS] = ACTIONS(3799),
    [anon_sym_DASH_DASH] = ACTIONS(3799),
    [anon_sym_true] = ACTIONS(3797),
    [anon_sym_false] = ACTIONS(3797),
    [anon_sym_PLUS] = ACTIONS(3797),
    [anon_sym_DASH] = ACTIONS(3797),
    [anon_sym_STAR] = ACTIONS(3799),
    [anon_sym_CARET] = ACTIONS(3799),
    [anon_sym_AMP] = ACTIONS(3799),
    [anon_sym_this] = ACTIONS(3797),
    [anon_sym_scoped] = ACTIONS(3797),
    [anon_sym_base] = ACTIONS(3797),
    [anon_sym_var] = ACTIONS(3797),
    [sym_predefined_type] = ACTIONS(3797),
    [anon_sym_break] = ACTIONS(3797),
    [anon_sym_unchecked] = ACTIONS(3797),
    [anon_sym_continue] = ACTIONS(3797),
    [anon_sym_do] = ACTIONS(3797),
    [anon_sym_while] = ACTIONS(3797),
    [anon_sym_for] = ACTIONS(3797),
    [anon_sym_lock] = ACTIONS(3797),
    [anon_sym_yield] = ACTIONS(3797),
    [anon_sym_switch] = ACTIONS(3797),
    [anon_sym_default] = ACTIONS(3797),
    [anon_sym_throw] = ACTIONS(3797),
    [anon_sym_try] = ACTIONS(3797),
    [anon_sym_when] = ACTIONS(3797),
    [anon_sym_await] = ACTIONS(3797),
    [anon_sym_foreach] = ACTIONS(3797),
    [anon_sym_goto] = ACTIONS(3797),
    [anon_sym_if] = ACTIONS(3797),
    [anon_sym_DOT_DOT] = ACTIONS(3799),
    [anon_sym_from] = ACTIONS(3797),
    [anon_sym_into] = ACTIONS(3797),
    [anon_sym_join] = ACTIONS(3797),
    [anon_sym_on] = ACTIONS(3797),
    [anon_sym_equals] = ACTIONS(3797),
    [anon_sym_let] = ACTIONS(3797),
    [anon_sym_orderby] = ACTIONS(3797),
    [anon_sym_ascending] = ACTIONS(3797),
    [anon_sym_descending] = ACTIONS(3797),
    [anon_sym_group] = ACTIONS(3797),
    [anon_sym_by] = ACTIONS(3797),
    [anon_sym_select] = ACTIONS(3797),
    [anon_sym_stackalloc] = ACTIONS(3797),
    [anon_sym_sizeof] = ACTIONS(3797),
    [anon_sym_typeof] = ACTIONS(3797),
    [anon_sym___makeref] = ACTIONS(3797),
    [anon_sym___reftype] = ACTIONS(3797),
    [anon_sym___refvalue] = ACTIONS(3797),
    [sym_null_literal] = ACTIONS(3797),
    [anon_sym_SQUOTE] = ACTIONS(3799),
    [sym_integer_literal] = ACTIONS(3797),
    [sym_real_literal] = ACTIONS(3799),
    [anon_sym_DQUOTE] = ACTIONS(3799),
    [sym_verbatim_string_literal] = ACTIONS(3799),
    [aux_sym_preproc_if_token1] = ACTIONS(3799),
    [aux_sym_preproc_if_token3] = ACTIONS(3799),
    [aux_sym_preproc_else_token1] = ACTIONS(3799),
    [aux_sym_preproc_elif_token1] = ACTIONS(3799),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3799),
    [sym_interpolation_verbatim_start] = ACTIONS(3799),
    [sym_interpolation_raw_start] = ACTIONS(3799),
    [sym_raw_string_start] = ACTIONS(3799),
  },
  [2406] = {
    [sym_preproc_region] = STATE(2406),
    [sym_preproc_endregion] = STATE(2406),
    [sym_preproc_line] = STATE(2406),
    [sym_preproc_pragma] = STATE(2406),
    [sym_preproc_nullable] = STATE(2406),
    [sym_preproc_error] = STATE(2406),
    [sym_preproc_warning] = STATE(2406),
    [sym_preproc_define] = STATE(2406),
    [sym_preproc_undef] = STATE(2406),
    [sym__identifier_token] = ACTIONS(3801),
    [anon_sym_extern] = ACTIONS(3801),
    [anon_sym_alias] = ACTIONS(3801),
    [anon_sym_SEMI] = ACTIONS(3803),
    [anon_sym_global] = ACTIONS(3801),
    [anon_sym_using] = ACTIONS(3801),
    [anon_sym_unsafe] = ACTIONS(3801),
    [anon_sym_static] = ACTIONS(3801),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [anon_sym_LPAREN] = ACTIONS(3803),
    [anon_sym_return] = ACTIONS(3801),
    [anon_sym_namespace] = ACTIONS(3801),
    [anon_sym_class] = ACTIONS(3801),
    [anon_sym_ref] = ACTIONS(3801),
    [anon_sym_struct] = ACTIONS(3801),
    [anon_sym_enum] = ACTIONS(3801),
    [anon_sym_LBRACE] = ACTIONS(3803),
    [anon_sym_interface] = ACTIONS(3801),
    [anon_sym_delegate] = ACTIONS(3801),
    [anon_sym_record] = ACTIONS(3801),
    [anon_sym_abstract] = ACTIONS(3801),
    [anon_sym_async] = ACTIONS(3801),
    [anon_sym_const] = ACTIONS(3801),
    [anon_sym_file] = ACTIONS(3801),
    [anon_sym_fixed] = ACTIONS(3801),
    [anon_sym_internal] = ACTIONS(3801),
    [anon_sym_new] = ACTIONS(3801),
    [anon_sym_override] = ACTIONS(3801),
    [anon_sym_partial] = ACTIONS(3801),
    [anon_sym_private] = ACTIONS(3801),
    [anon_sym_protected] = ACTIONS(3801),
    [anon_sym_public] = ACTIONS(3801),
    [anon_sym_readonly] = ACTIONS(3801),
    [anon_sym_required] = ACTIONS(3801),
    [anon_sym_sealed] = ACTIONS(3801),
    [anon_sym_virtual] = ACTIONS(3801),
    [anon_sym_volatile] = ACTIONS(3801),
    [anon_sym_where] = ACTIONS(3801),
    [anon_sym_notnull] = ACTIONS(3801),
    [anon_sym_unmanaged] = ACTIONS(3801),
    [anon_sym_checked] = ACTIONS(3801),
    [anon_sym_BANG] = ACTIONS(3803),
    [anon_sym_TILDE] = ACTIONS(3803),
    [anon_sym_PLUS_PLUS] = ACTIONS(3803),
    [anon_sym_DASH_DASH] = ACTIONS(3803),
    [anon_sym_true] = ACTIONS(3801),
    [anon_sym_false] = ACTIONS(3801),
    [anon_sym_PLUS] = ACTIONS(3801),
    [anon_sym_DASH] = ACTIONS(3801),
    [anon_sym_STAR] = ACTIONS(3803),
    [anon_sym_CARET] = ACTIONS(3803),
    [anon_sym_AMP] = ACTIONS(3803),
    [anon_sym_this] = ACTIONS(3801),
    [anon_sym_scoped] = ACTIONS(3801),
    [anon_sym_base] = ACTIONS(3801),
    [anon_sym_var] = ACTIONS(3801),
    [sym_predefined_type] = ACTIONS(3801),
    [anon_sym_break] = ACTIONS(3801),
    [anon_sym_unchecked] = ACTIONS(3801),
    [anon_sym_continue] = ACTIONS(3801),
    [anon_sym_do] = ACTIONS(3801),
    [anon_sym_while] = ACTIONS(3801),
    [anon_sym_for] = ACTIONS(3801),
    [anon_sym_lock] = ACTIONS(3801),
    [anon_sym_yield] = ACTIONS(3801),
    [anon_sym_switch] = ACTIONS(3801),
    [anon_sym_default] = ACTIONS(3801),
    [anon_sym_throw] = ACTIONS(3801),
    [anon_sym_try] = ACTIONS(3801),
    [anon_sym_when] = ACTIONS(3801),
    [anon_sym_await] = ACTIONS(3801),
    [anon_sym_foreach] = ACTIONS(3801),
    [anon_sym_goto] = ACTIONS(3801),
    [anon_sym_if] = ACTIONS(3801),
    [anon_sym_DOT_DOT] = ACTIONS(3803),
    [anon_sym_from] = ACTIONS(3801),
    [anon_sym_into] = ACTIONS(3801),
    [anon_sym_join] = ACTIONS(3801),
    [anon_sym_on] = ACTIONS(3801),
    [anon_sym_equals] = ACTIONS(3801),
    [anon_sym_let] = ACTIONS(3801),
    [anon_sym_orderby] = ACTIONS(3801),
    [anon_sym_ascending] = ACTIONS(3801),
    [anon_sym_descending] = ACTIONS(3801),
    [anon_sym_group] = ACTIONS(3801),
    [anon_sym_by] = ACTIONS(3801),
    [anon_sym_select] = ACTIONS(3801),
    [anon_sym_stackalloc] = ACTIONS(3801),
    [anon_sym_sizeof] = ACTIONS(3801),
    [anon_sym_typeof] = ACTIONS(3801),
    [anon_sym___makeref] = ACTIONS(3801),
    [anon_sym___reftype] = ACTIONS(3801),
    [anon_sym___refvalue] = ACTIONS(3801),
    [sym_null_literal] = ACTIONS(3801),
    [anon_sym_SQUOTE] = ACTIONS(3803),
    [sym_integer_literal] = ACTIONS(3801),
    [sym_real_literal] = ACTIONS(3803),
    [anon_sym_DQUOTE] = ACTIONS(3803),
    [sym_verbatim_string_literal] = ACTIONS(3803),
    [aux_sym_preproc_if_token1] = ACTIONS(3803),
    [aux_sym_preproc_if_token3] = ACTIONS(3803),
    [aux_sym_preproc_else_token1] = ACTIONS(3803),
    [aux_sym_preproc_elif_token1] = ACTIONS(3803),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3803),
    [sym_interpolation_verbatim_start] = ACTIONS(3803),
    [sym_interpolation_raw_start] = ACTIONS(3803),
    [sym_raw_string_start] = ACTIONS(3803),
  },
  [2407] = {
    [sym_preproc_region] = STATE(2407),
    [sym_preproc_endregion] = STATE(2407),
    [sym_preproc_line] = STATE(2407),
    [sym_preproc_pragma] = STATE(2407),
    [sym_preproc_nullable] = STATE(2407),
    [sym_preproc_error] = STATE(2407),
    [sym_preproc_warning] = STATE(2407),
    [sym_preproc_define] = STATE(2407),
    [sym_preproc_undef] = STATE(2407),
    [sym__identifier_token] = ACTIONS(3805),
    [anon_sym_extern] = ACTIONS(3805),
    [anon_sym_alias] = ACTIONS(3805),
    [anon_sym_SEMI] = ACTIONS(3807),
    [anon_sym_global] = ACTIONS(3805),
    [anon_sym_using] = ACTIONS(3805),
    [anon_sym_unsafe] = ACTIONS(3805),
    [anon_sym_static] = ACTIONS(3805),
    [anon_sym_LBRACK] = ACTIONS(3807),
    [anon_sym_LPAREN] = ACTIONS(3807),
    [anon_sym_return] = ACTIONS(3805),
    [anon_sym_namespace] = ACTIONS(3805),
    [anon_sym_class] = ACTIONS(3805),
    [anon_sym_ref] = ACTIONS(3805),
    [anon_sym_struct] = ACTIONS(3805),
    [anon_sym_enum] = ACTIONS(3805),
    [anon_sym_LBRACE] = ACTIONS(3807),
    [anon_sym_interface] = ACTIONS(3805),
    [anon_sym_delegate] = ACTIONS(3805),
    [anon_sym_record] = ACTIONS(3805),
    [anon_sym_abstract] = ACTIONS(3805),
    [anon_sym_async] = ACTIONS(3805),
    [anon_sym_const] = ACTIONS(3805),
    [anon_sym_file] = ACTIONS(3805),
    [anon_sym_fixed] = ACTIONS(3805),
    [anon_sym_internal] = ACTIONS(3805),
    [anon_sym_new] = ACTIONS(3805),
    [anon_sym_override] = ACTIONS(3805),
    [anon_sym_partial] = ACTIONS(3805),
    [anon_sym_private] = ACTIONS(3805),
    [anon_sym_protected] = ACTIONS(3805),
    [anon_sym_public] = ACTIONS(3805),
    [anon_sym_readonly] = ACTIONS(3805),
    [anon_sym_required] = ACTIONS(3805),
    [anon_sym_sealed] = ACTIONS(3805),
    [anon_sym_virtual] = ACTIONS(3805),
    [anon_sym_volatile] = ACTIONS(3805),
    [anon_sym_where] = ACTIONS(3805),
    [anon_sym_notnull] = ACTIONS(3805),
    [anon_sym_unmanaged] = ACTIONS(3805),
    [anon_sym_checked] = ACTIONS(3805),
    [anon_sym_BANG] = ACTIONS(3807),
    [anon_sym_TILDE] = ACTIONS(3807),
    [anon_sym_PLUS_PLUS] = ACTIONS(3807),
    [anon_sym_DASH_DASH] = ACTIONS(3807),
    [anon_sym_true] = ACTIONS(3805),
    [anon_sym_false] = ACTIONS(3805),
    [anon_sym_PLUS] = ACTIONS(3805),
    [anon_sym_DASH] = ACTIONS(3805),
    [anon_sym_STAR] = ACTIONS(3807),
    [anon_sym_CARET] = ACTIONS(3807),
    [anon_sym_AMP] = ACTIONS(3807),
    [anon_sym_this] = ACTIONS(3805),
    [anon_sym_scoped] = ACTIONS(3805),
    [anon_sym_base] = ACTIONS(3805),
    [anon_sym_var] = ACTIONS(3805),
    [sym_predefined_type] = ACTIONS(3805),
    [anon_sym_break] = ACTIONS(3805),
    [anon_sym_unchecked] = ACTIONS(3805),
    [anon_sym_continue] = ACTIONS(3805),
    [anon_sym_do] = ACTIONS(3805),
    [anon_sym_while] = ACTIONS(3805),
    [anon_sym_for] = ACTIONS(3805),
    [anon_sym_lock] = ACTIONS(3805),
    [anon_sym_yield] = ACTIONS(3805),
    [anon_sym_switch] = ACTIONS(3805),
    [anon_sym_default] = ACTIONS(3805),
    [anon_sym_throw] = ACTIONS(3805),
    [anon_sym_try] = ACTIONS(3805),
    [anon_sym_when] = ACTIONS(3805),
    [anon_sym_await] = ACTIONS(3805),
    [anon_sym_foreach] = ACTIONS(3805),
    [anon_sym_goto] = ACTIONS(3805),
    [anon_sym_if] = ACTIONS(3805),
    [anon_sym_DOT_DOT] = ACTIONS(3807),
    [anon_sym_from] = ACTIONS(3805),
    [anon_sym_into] = ACTIONS(3805),
    [anon_sym_join] = ACTIONS(3805),
    [anon_sym_on] = ACTIONS(3805),
    [anon_sym_equals] = ACTIONS(3805),
    [anon_sym_let] = ACTIONS(3805),
    [anon_sym_orderby] = ACTIONS(3805),
    [anon_sym_ascending] = ACTIONS(3805),
    [anon_sym_descending] = ACTIONS(3805),
    [anon_sym_group] = ACTIONS(3805),
    [anon_sym_by] = ACTIONS(3805),
    [anon_sym_select] = ACTIONS(3805),
    [anon_sym_stackalloc] = ACTIONS(3805),
    [anon_sym_sizeof] = ACTIONS(3805),
    [anon_sym_typeof] = ACTIONS(3805),
    [anon_sym___makeref] = ACTIONS(3805),
    [anon_sym___reftype] = ACTIONS(3805),
    [anon_sym___refvalue] = ACTIONS(3805),
    [sym_null_literal] = ACTIONS(3805),
    [anon_sym_SQUOTE] = ACTIONS(3807),
    [sym_integer_literal] = ACTIONS(3805),
    [sym_real_literal] = ACTIONS(3807),
    [anon_sym_DQUOTE] = ACTIONS(3807),
    [sym_verbatim_string_literal] = ACTIONS(3807),
    [aux_sym_preproc_if_token1] = ACTIONS(3807),
    [aux_sym_preproc_if_token3] = ACTIONS(3807),
    [aux_sym_preproc_else_token1] = ACTIONS(3807),
    [aux_sym_preproc_elif_token1] = ACTIONS(3807),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3807),
    [sym_interpolation_verbatim_start] = ACTIONS(3807),
    [sym_interpolation_raw_start] = ACTIONS(3807),
    [sym_raw_string_start] = ACTIONS(3807),
  },
  [2408] = {
    [sym_preproc_region] = STATE(2408),
    [sym_preproc_endregion] = STATE(2408),
    [sym_preproc_line] = STATE(2408),
    [sym_preproc_pragma] = STATE(2408),
    [sym_preproc_nullable] = STATE(2408),
    [sym_preproc_error] = STATE(2408),
    [sym_preproc_warning] = STATE(2408),
    [sym_preproc_define] = STATE(2408),
    [sym_preproc_undef] = STATE(2408),
    [sym__identifier_token] = ACTIONS(3809),
    [anon_sym_extern] = ACTIONS(3809),
    [anon_sym_alias] = ACTIONS(3809),
    [anon_sym_SEMI] = ACTIONS(3811),
    [anon_sym_global] = ACTIONS(3809),
    [anon_sym_using] = ACTIONS(3809),
    [anon_sym_unsafe] = ACTIONS(3809),
    [anon_sym_static] = ACTIONS(3809),
    [anon_sym_LBRACK] = ACTIONS(3811),
    [anon_sym_LPAREN] = ACTIONS(3811),
    [anon_sym_return] = ACTIONS(3809),
    [anon_sym_namespace] = ACTIONS(3809),
    [anon_sym_class] = ACTIONS(3809),
    [anon_sym_ref] = ACTIONS(3809),
    [anon_sym_struct] = ACTIONS(3809),
    [anon_sym_enum] = ACTIONS(3809),
    [anon_sym_LBRACE] = ACTIONS(3811),
    [anon_sym_interface] = ACTIONS(3809),
    [anon_sym_delegate] = ACTIONS(3809),
    [anon_sym_record] = ACTIONS(3809),
    [anon_sym_abstract] = ACTIONS(3809),
    [anon_sym_async] = ACTIONS(3809),
    [anon_sym_const] = ACTIONS(3809),
    [anon_sym_file] = ACTIONS(3809),
    [anon_sym_fixed] = ACTIONS(3809),
    [anon_sym_internal] = ACTIONS(3809),
    [anon_sym_new] = ACTIONS(3809),
    [anon_sym_override] = ACTIONS(3809),
    [anon_sym_partial] = ACTIONS(3809),
    [anon_sym_private] = ACTIONS(3809),
    [anon_sym_protected] = ACTIONS(3809),
    [anon_sym_public] = ACTIONS(3809),
    [anon_sym_readonly] = ACTIONS(3809),
    [anon_sym_required] = ACTIONS(3809),
    [anon_sym_sealed] = ACTIONS(3809),
    [anon_sym_virtual] = ACTIONS(3809),
    [anon_sym_volatile] = ACTIONS(3809),
    [anon_sym_where] = ACTIONS(3809),
    [anon_sym_notnull] = ACTIONS(3809),
    [anon_sym_unmanaged] = ACTIONS(3809),
    [anon_sym_checked] = ACTIONS(3809),
    [anon_sym_BANG] = ACTIONS(3811),
    [anon_sym_TILDE] = ACTIONS(3811),
    [anon_sym_PLUS_PLUS] = ACTIONS(3811),
    [anon_sym_DASH_DASH] = ACTIONS(3811),
    [anon_sym_true] = ACTIONS(3809),
    [anon_sym_false] = ACTIONS(3809),
    [anon_sym_PLUS] = ACTIONS(3809),
    [anon_sym_DASH] = ACTIONS(3809),
    [anon_sym_STAR] = ACTIONS(3811),
    [anon_sym_CARET] = ACTIONS(3811),
    [anon_sym_AMP] = ACTIONS(3811),
    [anon_sym_this] = ACTIONS(3809),
    [anon_sym_scoped] = ACTIONS(3809),
    [anon_sym_base] = ACTIONS(3809),
    [anon_sym_var] = ACTIONS(3809),
    [sym_predefined_type] = ACTIONS(3809),
    [anon_sym_break] = ACTIONS(3809),
    [anon_sym_unchecked] = ACTIONS(3809),
    [anon_sym_continue] = ACTIONS(3809),
    [anon_sym_do] = ACTIONS(3809),
    [anon_sym_while] = ACTIONS(3809),
    [anon_sym_for] = ACTIONS(3809),
    [anon_sym_lock] = ACTIONS(3809),
    [anon_sym_yield] = ACTIONS(3809),
    [anon_sym_switch] = ACTIONS(3809),
    [anon_sym_default] = ACTIONS(3809),
    [anon_sym_throw] = ACTIONS(3809),
    [anon_sym_try] = ACTIONS(3809),
    [anon_sym_when] = ACTIONS(3809),
    [anon_sym_await] = ACTIONS(3809),
    [anon_sym_foreach] = ACTIONS(3809),
    [anon_sym_goto] = ACTIONS(3809),
    [anon_sym_if] = ACTIONS(3809),
    [anon_sym_DOT_DOT] = ACTIONS(3811),
    [anon_sym_from] = ACTIONS(3809),
    [anon_sym_into] = ACTIONS(3809),
    [anon_sym_join] = ACTIONS(3809),
    [anon_sym_on] = ACTIONS(3809),
    [anon_sym_equals] = ACTIONS(3809),
    [anon_sym_let] = ACTIONS(3809),
    [anon_sym_orderby] = ACTIONS(3809),
    [anon_sym_ascending] = ACTIONS(3809),
    [anon_sym_descending] = ACTIONS(3809),
    [anon_sym_group] = ACTIONS(3809),
    [anon_sym_by] = ACTIONS(3809),
    [anon_sym_select] = ACTIONS(3809),
    [anon_sym_stackalloc] = ACTIONS(3809),
    [anon_sym_sizeof] = ACTIONS(3809),
    [anon_sym_typeof] = ACTIONS(3809),
    [anon_sym___makeref] = ACTIONS(3809),
    [anon_sym___reftype] = ACTIONS(3809),
    [anon_sym___refvalue] = ACTIONS(3809),
    [sym_null_literal] = ACTIONS(3809),
    [anon_sym_SQUOTE] = ACTIONS(3811),
    [sym_integer_literal] = ACTIONS(3809),
    [sym_real_literal] = ACTIONS(3811),
    [anon_sym_DQUOTE] = ACTIONS(3811),
    [sym_verbatim_string_literal] = ACTIONS(3811),
    [aux_sym_preproc_if_token1] = ACTIONS(3811),
    [aux_sym_preproc_if_token3] = ACTIONS(3811),
    [aux_sym_preproc_else_token1] = ACTIONS(3811),
    [aux_sym_preproc_elif_token1] = ACTIONS(3811),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3811),
    [sym_interpolation_verbatim_start] = ACTIONS(3811),
    [sym_interpolation_raw_start] = ACTIONS(3811),
    [sym_raw_string_start] = ACTIONS(3811),
  },
  [2409] = {
    [sym_preproc_region] = STATE(2409),
    [sym_preproc_endregion] = STATE(2409),
    [sym_preproc_line] = STATE(2409),
    [sym_preproc_pragma] = STATE(2409),
    [sym_preproc_nullable] = STATE(2409),
    [sym_preproc_error] = STATE(2409),
    [sym_preproc_warning] = STATE(2409),
    [sym_preproc_define] = STATE(2409),
    [sym_preproc_undef] = STATE(2409),
    [sym__identifier_token] = ACTIONS(3813),
    [anon_sym_extern] = ACTIONS(3813),
    [anon_sym_alias] = ACTIONS(3813),
    [anon_sym_SEMI] = ACTIONS(3815),
    [anon_sym_global] = ACTIONS(3813),
    [anon_sym_using] = ACTIONS(3813),
    [anon_sym_unsafe] = ACTIONS(3813),
    [anon_sym_static] = ACTIONS(3813),
    [anon_sym_LBRACK] = ACTIONS(3815),
    [anon_sym_LPAREN] = ACTIONS(3815),
    [anon_sym_return] = ACTIONS(3813),
    [anon_sym_namespace] = ACTIONS(3813),
    [anon_sym_class] = ACTIONS(3813),
    [anon_sym_ref] = ACTIONS(3813),
    [anon_sym_struct] = ACTIONS(3813),
    [anon_sym_enum] = ACTIONS(3813),
    [anon_sym_LBRACE] = ACTIONS(3815),
    [anon_sym_interface] = ACTIONS(3813),
    [anon_sym_delegate] = ACTIONS(3813),
    [anon_sym_record] = ACTIONS(3813),
    [anon_sym_abstract] = ACTIONS(3813),
    [anon_sym_async] = ACTIONS(3813),
    [anon_sym_const] = ACTIONS(3813),
    [anon_sym_file] = ACTIONS(3813),
    [anon_sym_fixed] = ACTIONS(3813),
    [anon_sym_internal] = ACTIONS(3813),
    [anon_sym_new] = ACTIONS(3813),
    [anon_sym_override] = ACTIONS(3813),
    [anon_sym_partial] = ACTIONS(3813),
    [anon_sym_private] = ACTIONS(3813),
    [anon_sym_protected] = ACTIONS(3813),
    [anon_sym_public] = ACTIONS(3813),
    [anon_sym_readonly] = ACTIONS(3813),
    [anon_sym_required] = ACTIONS(3813),
    [anon_sym_sealed] = ACTIONS(3813),
    [anon_sym_virtual] = ACTIONS(3813),
    [anon_sym_volatile] = ACTIONS(3813),
    [anon_sym_where] = ACTIONS(3813),
    [anon_sym_notnull] = ACTIONS(3813),
    [anon_sym_unmanaged] = ACTIONS(3813),
    [anon_sym_checked] = ACTIONS(3813),
    [anon_sym_BANG] = ACTIONS(3815),
    [anon_sym_TILDE] = ACTIONS(3815),
    [anon_sym_PLUS_PLUS] = ACTIONS(3815),
    [anon_sym_DASH_DASH] = ACTIONS(3815),
    [anon_sym_true] = ACTIONS(3813),
    [anon_sym_false] = ACTIONS(3813),
    [anon_sym_PLUS] = ACTIONS(3813),
    [anon_sym_DASH] = ACTIONS(3813),
    [anon_sym_STAR] = ACTIONS(3815),
    [anon_sym_CARET] = ACTIONS(3815),
    [anon_sym_AMP] = ACTIONS(3815),
    [anon_sym_this] = ACTIONS(3813),
    [anon_sym_scoped] = ACTIONS(3813),
    [anon_sym_base] = ACTIONS(3813),
    [anon_sym_var] = ACTIONS(3813),
    [sym_predefined_type] = ACTIONS(3813),
    [anon_sym_break] = ACTIONS(3813),
    [anon_sym_unchecked] = ACTIONS(3813),
    [anon_sym_continue] = ACTIONS(3813),
    [anon_sym_do] = ACTIONS(3813),
    [anon_sym_while] = ACTIONS(3813),
    [anon_sym_for] = ACTIONS(3813),
    [anon_sym_lock] = ACTIONS(3813),
    [anon_sym_yield] = ACTIONS(3813),
    [anon_sym_switch] = ACTIONS(3813),
    [anon_sym_default] = ACTIONS(3813),
    [anon_sym_throw] = ACTIONS(3813),
    [anon_sym_try] = ACTIONS(3813),
    [anon_sym_when] = ACTIONS(3813),
    [anon_sym_await] = ACTIONS(3813),
    [anon_sym_foreach] = ACTIONS(3813),
    [anon_sym_goto] = ACTIONS(3813),
    [anon_sym_if] = ACTIONS(3813),
    [anon_sym_DOT_DOT] = ACTIONS(3815),
    [anon_sym_from] = ACTIONS(3813),
    [anon_sym_into] = ACTIONS(3813),
    [anon_sym_join] = ACTIONS(3813),
    [anon_sym_on] = ACTIONS(3813),
    [anon_sym_equals] = ACTIONS(3813),
    [anon_sym_let] = ACTIONS(3813),
    [anon_sym_orderby] = ACTIONS(3813),
    [anon_sym_ascending] = ACTIONS(3813),
    [anon_sym_descending] = ACTIONS(3813),
    [anon_sym_group] = ACTIONS(3813),
    [anon_sym_by] = ACTIONS(3813),
    [anon_sym_select] = ACTIONS(3813),
    [anon_sym_stackalloc] = ACTIONS(3813),
    [anon_sym_sizeof] = ACTIONS(3813),
    [anon_sym_typeof] = ACTIONS(3813),
    [anon_sym___makeref] = ACTIONS(3813),
    [anon_sym___reftype] = ACTIONS(3813),
    [anon_sym___refvalue] = ACTIONS(3813),
    [sym_null_literal] = ACTIONS(3813),
    [anon_sym_SQUOTE] = ACTIONS(3815),
    [sym_integer_literal] = ACTIONS(3813),
    [sym_real_literal] = ACTIONS(3815),
    [anon_sym_DQUOTE] = ACTIONS(3815),
    [sym_verbatim_string_literal] = ACTIONS(3815),
    [aux_sym_preproc_if_token1] = ACTIONS(3815),
    [aux_sym_preproc_if_token3] = ACTIONS(3815),
    [aux_sym_preproc_else_token1] = ACTIONS(3815),
    [aux_sym_preproc_elif_token1] = ACTIONS(3815),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3815),
    [sym_interpolation_verbatim_start] = ACTIONS(3815),
    [sym_interpolation_raw_start] = ACTIONS(3815),
    [sym_raw_string_start] = ACTIONS(3815),
  },
  [2410] = {
    [sym_preproc_region] = STATE(2410),
    [sym_preproc_endregion] = STATE(2410),
    [sym_preproc_line] = STATE(2410),
    [sym_preproc_pragma] = STATE(2410),
    [sym_preproc_nullable] = STATE(2410),
    [sym_preproc_error] = STATE(2410),
    [sym_preproc_warning] = STATE(2410),
    [sym_preproc_define] = STATE(2410),
    [sym_preproc_undef] = STATE(2410),
    [sym__identifier_token] = ACTIONS(3817),
    [anon_sym_extern] = ACTIONS(3817),
    [anon_sym_alias] = ACTIONS(3817),
    [anon_sym_SEMI] = ACTIONS(3819),
    [anon_sym_global] = ACTIONS(3817),
    [anon_sym_using] = ACTIONS(3817),
    [anon_sym_unsafe] = ACTIONS(3817),
    [anon_sym_static] = ACTIONS(3817),
    [anon_sym_LBRACK] = ACTIONS(3819),
    [anon_sym_LPAREN] = ACTIONS(3819),
    [anon_sym_return] = ACTIONS(3817),
    [anon_sym_namespace] = ACTIONS(3817),
    [anon_sym_class] = ACTIONS(3817),
    [anon_sym_ref] = ACTIONS(3817),
    [anon_sym_struct] = ACTIONS(3817),
    [anon_sym_enum] = ACTIONS(3817),
    [anon_sym_LBRACE] = ACTIONS(3819),
    [anon_sym_interface] = ACTIONS(3817),
    [anon_sym_delegate] = ACTIONS(3817),
    [anon_sym_record] = ACTIONS(3817),
    [anon_sym_abstract] = ACTIONS(3817),
    [anon_sym_async] = ACTIONS(3817),
    [anon_sym_const] = ACTIONS(3817),
    [anon_sym_file] = ACTIONS(3817),
    [anon_sym_fixed] = ACTIONS(3817),
    [anon_sym_internal] = ACTIONS(3817),
    [anon_sym_new] = ACTIONS(3817),
    [anon_sym_override] = ACTIONS(3817),
    [anon_sym_partial] = ACTIONS(3817),
    [anon_sym_private] = ACTIONS(3817),
    [anon_sym_protected] = ACTIONS(3817),
    [anon_sym_public] = ACTIONS(3817),
    [anon_sym_readonly] = ACTIONS(3817),
    [anon_sym_required] = ACTIONS(3817),
    [anon_sym_sealed] = ACTIONS(3817),
    [anon_sym_virtual] = ACTIONS(3817),
    [anon_sym_volatile] = ACTIONS(3817),
    [anon_sym_where] = ACTIONS(3817),
    [anon_sym_notnull] = ACTIONS(3817),
    [anon_sym_unmanaged] = ACTIONS(3817),
    [anon_sym_checked] = ACTIONS(3817),
    [anon_sym_BANG] = ACTIONS(3819),
    [anon_sym_TILDE] = ACTIONS(3819),
    [anon_sym_PLUS_PLUS] = ACTIONS(3819),
    [anon_sym_DASH_DASH] = ACTIONS(3819),
    [anon_sym_true] = ACTIONS(3817),
    [anon_sym_false] = ACTIONS(3817),
    [anon_sym_PLUS] = ACTIONS(3817),
    [anon_sym_DASH] = ACTIONS(3817),
    [anon_sym_STAR] = ACTIONS(3819),
    [anon_sym_CARET] = ACTIONS(3819),
    [anon_sym_AMP] = ACTIONS(3819),
    [anon_sym_this] = ACTIONS(3817),
    [anon_sym_scoped] = ACTIONS(3817),
    [anon_sym_base] = ACTIONS(3817),
    [anon_sym_var] = ACTIONS(3817),
    [sym_predefined_type] = ACTIONS(3817),
    [anon_sym_break] = ACTIONS(3817),
    [anon_sym_unchecked] = ACTIONS(3817),
    [anon_sym_continue] = ACTIONS(3817),
    [anon_sym_do] = ACTIONS(3817),
    [anon_sym_while] = ACTIONS(3817),
    [anon_sym_for] = ACTIONS(3817),
    [anon_sym_lock] = ACTIONS(3817),
    [anon_sym_yield] = ACTIONS(3817),
    [anon_sym_switch] = ACTIONS(3817),
    [anon_sym_default] = ACTIONS(3817),
    [anon_sym_throw] = ACTIONS(3817),
    [anon_sym_try] = ACTIONS(3817),
    [anon_sym_when] = ACTIONS(3817),
    [anon_sym_await] = ACTIONS(3817),
    [anon_sym_foreach] = ACTIONS(3817),
    [anon_sym_goto] = ACTIONS(3817),
    [anon_sym_if] = ACTIONS(3817),
    [anon_sym_DOT_DOT] = ACTIONS(3819),
    [anon_sym_from] = ACTIONS(3817),
    [anon_sym_into] = ACTIONS(3817),
    [anon_sym_join] = ACTIONS(3817),
    [anon_sym_on] = ACTIONS(3817),
    [anon_sym_equals] = ACTIONS(3817),
    [anon_sym_let] = ACTIONS(3817),
    [anon_sym_orderby] = ACTIONS(3817),
    [anon_sym_ascending] = ACTIONS(3817),
    [anon_sym_descending] = ACTIONS(3817),
    [anon_sym_group] = ACTIONS(3817),
    [anon_sym_by] = ACTIONS(3817),
    [anon_sym_select] = ACTIONS(3817),
    [anon_sym_stackalloc] = ACTIONS(3817),
    [anon_sym_sizeof] = ACTIONS(3817),
    [anon_sym_typeof] = ACTIONS(3817),
    [anon_sym___makeref] = ACTIONS(3817),
    [anon_sym___reftype] = ACTIONS(3817),
    [anon_sym___refvalue] = ACTIONS(3817),
    [sym_null_literal] = ACTIONS(3817),
    [anon_sym_SQUOTE] = ACTIONS(3819),
    [sym_integer_literal] = ACTIONS(3817),
    [sym_real_literal] = ACTIONS(3819),
    [anon_sym_DQUOTE] = ACTIONS(3819),
    [sym_verbatim_string_literal] = ACTIONS(3819),
    [aux_sym_preproc_if_token1] = ACTIONS(3819),
    [aux_sym_preproc_if_token3] = ACTIONS(3819),
    [aux_sym_preproc_else_token1] = ACTIONS(3819),
    [aux_sym_preproc_elif_token1] = ACTIONS(3819),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3819),
    [sym_interpolation_verbatim_start] = ACTIONS(3819),
    [sym_interpolation_raw_start] = ACTIONS(3819),
    [sym_raw_string_start] = ACTIONS(3819),
  },
  [2411] = {
    [sym_preproc_region] = STATE(2411),
    [sym_preproc_endregion] = STATE(2411),
    [sym_preproc_line] = STATE(2411),
    [sym_preproc_pragma] = STATE(2411),
    [sym_preproc_nullable] = STATE(2411),
    [sym_preproc_error] = STATE(2411),
    [sym_preproc_warning] = STATE(2411),
    [sym_preproc_define] = STATE(2411),
    [sym_preproc_undef] = STATE(2411),
    [sym__identifier_token] = ACTIONS(3821),
    [anon_sym_extern] = ACTIONS(3821),
    [anon_sym_alias] = ACTIONS(3821),
    [anon_sym_SEMI] = ACTIONS(3823),
    [anon_sym_global] = ACTIONS(3821),
    [anon_sym_using] = ACTIONS(3821),
    [anon_sym_unsafe] = ACTIONS(3821),
    [anon_sym_static] = ACTIONS(3821),
    [anon_sym_LBRACK] = ACTIONS(3823),
    [anon_sym_LPAREN] = ACTIONS(3823),
    [anon_sym_return] = ACTIONS(3821),
    [anon_sym_namespace] = ACTIONS(3821),
    [anon_sym_class] = ACTIONS(3821),
    [anon_sym_ref] = ACTIONS(3821),
    [anon_sym_struct] = ACTIONS(3821),
    [anon_sym_enum] = ACTIONS(3821),
    [anon_sym_LBRACE] = ACTIONS(3823),
    [anon_sym_interface] = ACTIONS(3821),
    [anon_sym_delegate] = ACTIONS(3821),
    [anon_sym_record] = ACTIONS(3821),
    [anon_sym_abstract] = ACTIONS(3821),
    [anon_sym_async] = ACTIONS(3821),
    [anon_sym_const] = ACTIONS(3821),
    [anon_sym_file] = ACTIONS(3821),
    [anon_sym_fixed] = ACTIONS(3821),
    [anon_sym_internal] = ACTIONS(3821),
    [anon_sym_new] = ACTIONS(3821),
    [anon_sym_override] = ACTIONS(3821),
    [anon_sym_partial] = ACTIONS(3821),
    [anon_sym_private] = ACTIONS(3821),
    [anon_sym_protected] = ACTIONS(3821),
    [anon_sym_public] = ACTIONS(3821),
    [anon_sym_readonly] = ACTIONS(3821),
    [anon_sym_required] = ACTIONS(3821),
    [anon_sym_sealed] = ACTIONS(3821),
    [anon_sym_virtual] = ACTIONS(3821),
    [anon_sym_volatile] = ACTIONS(3821),
    [anon_sym_where] = ACTIONS(3821),
    [anon_sym_notnull] = ACTIONS(3821),
    [anon_sym_unmanaged] = ACTIONS(3821),
    [anon_sym_checked] = ACTIONS(3821),
    [anon_sym_BANG] = ACTIONS(3823),
    [anon_sym_TILDE] = ACTIONS(3823),
    [anon_sym_PLUS_PLUS] = ACTIONS(3823),
    [anon_sym_DASH_DASH] = ACTIONS(3823),
    [anon_sym_true] = ACTIONS(3821),
    [anon_sym_false] = ACTIONS(3821),
    [anon_sym_PLUS] = ACTIONS(3821),
    [anon_sym_DASH] = ACTIONS(3821),
    [anon_sym_STAR] = ACTIONS(3823),
    [anon_sym_CARET] = ACTIONS(3823),
    [anon_sym_AMP] = ACTIONS(3823),
    [anon_sym_this] = ACTIONS(3821),
    [anon_sym_scoped] = ACTIONS(3821),
    [anon_sym_base] = ACTIONS(3821),
    [anon_sym_var] = ACTIONS(3821),
    [sym_predefined_type] = ACTIONS(3821),
    [anon_sym_break] = ACTIONS(3821),
    [anon_sym_unchecked] = ACTIONS(3821),
    [anon_sym_continue] = ACTIONS(3821),
    [anon_sym_do] = ACTIONS(3821),
    [anon_sym_while] = ACTIONS(3821),
    [anon_sym_for] = ACTIONS(3821),
    [anon_sym_lock] = ACTIONS(3821),
    [anon_sym_yield] = ACTIONS(3821),
    [anon_sym_switch] = ACTIONS(3821),
    [anon_sym_default] = ACTIONS(3821),
    [anon_sym_throw] = ACTIONS(3821),
    [anon_sym_try] = ACTIONS(3821),
    [anon_sym_when] = ACTIONS(3821),
    [anon_sym_await] = ACTIONS(3821),
    [anon_sym_foreach] = ACTIONS(3821),
    [anon_sym_goto] = ACTIONS(3821),
    [anon_sym_if] = ACTIONS(3821),
    [anon_sym_DOT_DOT] = ACTIONS(3823),
    [anon_sym_from] = ACTIONS(3821),
    [anon_sym_into] = ACTIONS(3821),
    [anon_sym_join] = ACTIONS(3821),
    [anon_sym_on] = ACTIONS(3821),
    [anon_sym_equals] = ACTIONS(3821),
    [anon_sym_let] = ACTIONS(3821),
    [anon_sym_orderby] = ACTIONS(3821),
    [anon_sym_ascending] = ACTIONS(3821),
    [anon_sym_descending] = ACTIONS(3821),
    [anon_sym_group] = ACTIONS(3821),
    [anon_sym_by] = ACTIONS(3821),
    [anon_sym_select] = ACTIONS(3821),
    [anon_sym_stackalloc] = ACTIONS(3821),
    [anon_sym_sizeof] = ACTIONS(3821),
    [anon_sym_typeof] = ACTIONS(3821),
    [anon_sym___makeref] = ACTIONS(3821),
    [anon_sym___reftype] = ACTIONS(3821),
    [anon_sym___refvalue] = ACTIONS(3821),
    [sym_null_literal] = ACTIONS(3821),
    [anon_sym_SQUOTE] = ACTIONS(3823),
    [sym_integer_literal] = ACTIONS(3821),
    [sym_real_literal] = ACTIONS(3823),
    [anon_sym_DQUOTE] = ACTIONS(3823),
    [sym_verbatim_string_literal] = ACTIONS(3823),
    [aux_sym_preproc_if_token1] = ACTIONS(3823),
    [aux_sym_preproc_if_token3] = ACTIONS(3823),
    [aux_sym_preproc_else_token1] = ACTIONS(3823),
    [aux_sym_preproc_elif_token1] = ACTIONS(3823),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3823),
    [sym_interpolation_verbatim_start] = ACTIONS(3823),
    [sym_interpolation_raw_start] = ACTIONS(3823),
    [sym_raw_string_start] = ACTIONS(3823),
  },
  [2412] = {
    [sym_preproc_region] = STATE(2412),
    [sym_preproc_endregion] = STATE(2412),
    [sym_preproc_line] = STATE(2412),
    [sym_preproc_pragma] = STATE(2412),
    [sym_preproc_nullable] = STATE(2412),
    [sym_preproc_error] = STATE(2412),
    [sym_preproc_warning] = STATE(2412),
    [sym_preproc_define] = STATE(2412),
    [sym_preproc_undef] = STATE(2412),
    [sym__identifier_token] = ACTIONS(3825),
    [anon_sym_extern] = ACTIONS(3825),
    [anon_sym_alias] = ACTIONS(3825),
    [anon_sym_SEMI] = ACTIONS(3827),
    [anon_sym_global] = ACTIONS(3825),
    [anon_sym_using] = ACTIONS(3825),
    [anon_sym_unsafe] = ACTIONS(3825),
    [anon_sym_static] = ACTIONS(3825),
    [anon_sym_LBRACK] = ACTIONS(3827),
    [anon_sym_LPAREN] = ACTIONS(3827),
    [anon_sym_return] = ACTIONS(3825),
    [anon_sym_namespace] = ACTIONS(3825),
    [anon_sym_class] = ACTIONS(3825),
    [anon_sym_ref] = ACTIONS(3825),
    [anon_sym_struct] = ACTIONS(3825),
    [anon_sym_enum] = ACTIONS(3825),
    [anon_sym_LBRACE] = ACTIONS(3827),
    [anon_sym_interface] = ACTIONS(3825),
    [anon_sym_delegate] = ACTIONS(3825),
    [anon_sym_record] = ACTIONS(3825),
    [anon_sym_abstract] = ACTIONS(3825),
    [anon_sym_async] = ACTIONS(3825),
    [anon_sym_const] = ACTIONS(3825),
    [anon_sym_file] = ACTIONS(3825),
    [anon_sym_fixed] = ACTIONS(3825),
    [anon_sym_internal] = ACTIONS(3825),
    [anon_sym_new] = ACTIONS(3825),
    [anon_sym_override] = ACTIONS(3825),
    [anon_sym_partial] = ACTIONS(3825),
    [anon_sym_private] = ACTIONS(3825),
    [anon_sym_protected] = ACTIONS(3825),
    [anon_sym_public] = ACTIONS(3825),
    [anon_sym_readonly] = ACTIONS(3825),
    [anon_sym_required] = ACTIONS(3825),
    [anon_sym_sealed] = ACTIONS(3825),
    [anon_sym_virtual] = ACTIONS(3825),
    [anon_sym_volatile] = ACTIONS(3825),
    [anon_sym_where] = ACTIONS(3825),
    [anon_sym_notnull] = ACTIONS(3825),
    [anon_sym_unmanaged] = ACTIONS(3825),
    [anon_sym_checked] = ACTIONS(3825),
    [anon_sym_BANG] = ACTIONS(3827),
    [anon_sym_TILDE] = ACTIONS(3827),
    [anon_sym_PLUS_PLUS] = ACTIONS(3827),
    [anon_sym_DASH_DASH] = ACTIONS(3827),
    [anon_sym_true] = ACTIONS(3825),
    [anon_sym_false] = ACTIONS(3825),
    [anon_sym_PLUS] = ACTIONS(3825),
    [anon_sym_DASH] = ACTIONS(3825),
    [anon_sym_STAR] = ACTIONS(3827),
    [anon_sym_CARET] = ACTIONS(3827),
    [anon_sym_AMP] = ACTIONS(3827),
    [anon_sym_this] = ACTIONS(3825),
    [anon_sym_scoped] = ACTIONS(3825),
    [anon_sym_base] = ACTIONS(3825),
    [anon_sym_var] = ACTIONS(3825),
    [sym_predefined_type] = ACTIONS(3825),
    [anon_sym_break] = ACTIONS(3825),
    [anon_sym_unchecked] = ACTIONS(3825),
    [anon_sym_continue] = ACTIONS(3825),
    [anon_sym_do] = ACTIONS(3825),
    [anon_sym_while] = ACTIONS(3825),
    [anon_sym_for] = ACTIONS(3825),
    [anon_sym_lock] = ACTIONS(3825),
    [anon_sym_yield] = ACTIONS(3825),
    [anon_sym_switch] = ACTIONS(3825),
    [anon_sym_default] = ACTIONS(3825),
    [anon_sym_throw] = ACTIONS(3825),
    [anon_sym_try] = ACTIONS(3825),
    [anon_sym_when] = ACTIONS(3825),
    [anon_sym_await] = ACTIONS(3825),
    [anon_sym_foreach] = ACTIONS(3825),
    [anon_sym_goto] = ACTIONS(3825),
    [anon_sym_if] = ACTIONS(3825),
    [anon_sym_DOT_DOT] = ACTIONS(3827),
    [anon_sym_from] = ACTIONS(3825),
    [anon_sym_into] = ACTIONS(3825),
    [anon_sym_join] = ACTIONS(3825),
    [anon_sym_on] = ACTIONS(3825),
    [anon_sym_equals] = ACTIONS(3825),
    [anon_sym_let] = ACTIONS(3825),
    [anon_sym_orderby] = ACTIONS(3825),
    [anon_sym_ascending] = ACTIONS(3825),
    [anon_sym_descending] = ACTIONS(3825),
    [anon_sym_group] = ACTIONS(3825),
    [anon_sym_by] = ACTIONS(3825),
    [anon_sym_select] = ACTIONS(3825),
    [anon_sym_stackalloc] = ACTIONS(3825),
    [anon_sym_sizeof] = ACTIONS(3825),
    [anon_sym_typeof] = ACTIONS(3825),
    [anon_sym___makeref] = ACTIONS(3825),
    [anon_sym___reftype] = ACTIONS(3825),
    [anon_sym___refvalue] = ACTIONS(3825),
    [sym_null_literal] = ACTIONS(3825),
    [anon_sym_SQUOTE] = ACTIONS(3827),
    [sym_integer_literal] = ACTIONS(3825),
    [sym_real_literal] = ACTIONS(3827),
    [anon_sym_DQUOTE] = ACTIONS(3827),
    [sym_verbatim_string_literal] = ACTIONS(3827),
    [aux_sym_preproc_if_token1] = ACTIONS(3827),
    [aux_sym_preproc_if_token3] = ACTIONS(3827),
    [aux_sym_preproc_else_token1] = ACTIONS(3827),
    [aux_sym_preproc_elif_token1] = ACTIONS(3827),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3827),
    [sym_interpolation_verbatim_start] = ACTIONS(3827),
    [sym_interpolation_raw_start] = ACTIONS(3827),
    [sym_raw_string_start] = ACTIONS(3827),
  },
  [2413] = {
    [sym_preproc_region] = STATE(2413),
    [sym_preproc_endregion] = STATE(2413),
    [sym_preproc_line] = STATE(2413),
    [sym_preproc_pragma] = STATE(2413),
    [sym_preproc_nullable] = STATE(2413),
    [sym_preproc_error] = STATE(2413),
    [sym_preproc_warning] = STATE(2413),
    [sym_preproc_define] = STATE(2413),
    [sym_preproc_undef] = STATE(2413),
    [sym__identifier_token] = ACTIONS(3829),
    [anon_sym_extern] = ACTIONS(3829),
    [anon_sym_alias] = ACTIONS(3829),
    [anon_sym_SEMI] = ACTIONS(3831),
    [anon_sym_global] = ACTIONS(3829),
    [anon_sym_using] = ACTIONS(3829),
    [anon_sym_unsafe] = ACTIONS(3829),
    [anon_sym_static] = ACTIONS(3829),
    [anon_sym_LBRACK] = ACTIONS(3831),
    [anon_sym_LPAREN] = ACTIONS(3831),
    [anon_sym_return] = ACTIONS(3829),
    [anon_sym_namespace] = ACTIONS(3829),
    [anon_sym_class] = ACTIONS(3829),
    [anon_sym_ref] = ACTIONS(3829),
    [anon_sym_struct] = ACTIONS(3829),
    [anon_sym_enum] = ACTIONS(3829),
    [anon_sym_LBRACE] = ACTIONS(3831),
    [anon_sym_interface] = ACTIONS(3829),
    [anon_sym_delegate] = ACTIONS(3829),
    [anon_sym_record] = ACTIONS(3829),
    [anon_sym_abstract] = ACTIONS(3829),
    [anon_sym_async] = ACTIONS(3829),
    [anon_sym_const] = ACTIONS(3829),
    [anon_sym_file] = ACTIONS(3829),
    [anon_sym_fixed] = ACTIONS(3829),
    [anon_sym_internal] = ACTIONS(3829),
    [anon_sym_new] = ACTIONS(3829),
    [anon_sym_override] = ACTIONS(3829),
    [anon_sym_partial] = ACTIONS(3829),
    [anon_sym_private] = ACTIONS(3829),
    [anon_sym_protected] = ACTIONS(3829),
    [anon_sym_public] = ACTIONS(3829),
    [anon_sym_readonly] = ACTIONS(3829),
    [anon_sym_required] = ACTIONS(3829),
    [anon_sym_sealed] = ACTIONS(3829),
    [anon_sym_virtual] = ACTIONS(3829),
    [anon_sym_volatile] = ACTIONS(3829),
    [anon_sym_where] = ACTIONS(3829),
    [anon_sym_notnull] = ACTIONS(3829),
    [anon_sym_unmanaged] = ACTIONS(3829),
    [anon_sym_checked] = ACTIONS(3829),
    [anon_sym_BANG] = ACTIONS(3831),
    [anon_sym_TILDE] = ACTIONS(3831),
    [anon_sym_PLUS_PLUS] = ACTIONS(3831),
    [anon_sym_DASH_DASH] = ACTIONS(3831),
    [anon_sym_true] = ACTIONS(3829),
    [anon_sym_false] = ACTIONS(3829),
    [anon_sym_PLUS] = ACTIONS(3829),
    [anon_sym_DASH] = ACTIONS(3829),
    [anon_sym_STAR] = ACTIONS(3831),
    [anon_sym_CARET] = ACTIONS(3831),
    [anon_sym_AMP] = ACTIONS(3831),
    [anon_sym_this] = ACTIONS(3829),
    [anon_sym_scoped] = ACTIONS(3829),
    [anon_sym_base] = ACTIONS(3829),
    [anon_sym_var] = ACTIONS(3829),
    [sym_predefined_type] = ACTIONS(3829),
    [anon_sym_break] = ACTIONS(3829),
    [anon_sym_unchecked] = ACTIONS(3829),
    [anon_sym_continue] = ACTIONS(3829),
    [anon_sym_do] = ACTIONS(3829),
    [anon_sym_while] = ACTIONS(3829),
    [anon_sym_for] = ACTIONS(3829),
    [anon_sym_lock] = ACTIONS(3829),
    [anon_sym_yield] = ACTIONS(3829),
    [anon_sym_switch] = ACTIONS(3829),
    [anon_sym_default] = ACTIONS(3829),
    [anon_sym_throw] = ACTIONS(3829),
    [anon_sym_try] = ACTIONS(3829),
    [anon_sym_when] = ACTIONS(3829),
    [anon_sym_await] = ACTIONS(3829),
    [anon_sym_foreach] = ACTIONS(3829),
    [anon_sym_goto] = ACTIONS(3829),
    [anon_sym_if] = ACTIONS(3829),
    [anon_sym_DOT_DOT] = ACTIONS(3831),
    [anon_sym_from] = ACTIONS(3829),
    [anon_sym_into] = ACTIONS(3829),
    [anon_sym_join] = ACTIONS(3829),
    [anon_sym_on] = ACTIONS(3829),
    [anon_sym_equals] = ACTIONS(3829),
    [anon_sym_let] = ACTIONS(3829),
    [anon_sym_orderby] = ACTIONS(3829),
    [anon_sym_ascending] = ACTIONS(3829),
    [anon_sym_descending] = ACTIONS(3829),
    [anon_sym_group] = ACTIONS(3829),
    [anon_sym_by] = ACTIONS(3829),
    [anon_sym_select] = ACTIONS(3829),
    [anon_sym_stackalloc] = ACTIONS(3829),
    [anon_sym_sizeof] = ACTIONS(3829),
    [anon_sym_typeof] = ACTIONS(3829),
    [anon_sym___makeref] = ACTIONS(3829),
    [anon_sym___reftype] = ACTIONS(3829),
    [anon_sym___refvalue] = ACTIONS(3829),
    [sym_null_literal] = ACTIONS(3829),
    [anon_sym_SQUOTE] = ACTIONS(3831),
    [sym_integer_literal] = ACTIONS(3829),
    [sym_real_literal] = ACTIONS(3831),
    [anon_sym_DQUOTE] = ACTIONS(3831),
    [sym_verbatim_string_literal] = ACTIONS(3831),
    [aux_sym_preproc_if_token1] = ACTIONS(3831),
    [aux_sym_preproc_if_token3] = ACTIONS(3831),
    [aux_sym_preproc_else_token1] = ACTIONS(3831),
    [aux_sym_preproc_elif_token1] = ACTIONS(3831),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3831),
    [sym_interpolation_verbatim_start] = ACTIONS(3831),
    [sym_interpolation_raw_start] = ACTIONS(3831),
    [sym_raw_string_start] = ACTIONS(3831),
  },
  [2414] = {
    [sym_preproc_region] = STATE(2414),
    [sym_preproc_endregion] = STATE(2414),
    [sym_preproc_line] = STATE(2414),
    [sym_preproc_pragma] = STATE(2414),
    [sym_preproc_nullable] = STATE(2414),
    [sym_preproc_error] = STATE(2414),
    [sym_preproc_warning] = STATE(2414),
    [sym_preproc_define] = STATE(2414),
    [sym_preproc_undef] = STATE(2414),
    [sym__identifier_token] = ACTIONS(3833),
    [anon_sym_extern] = ACTIONS(3833),
    [anon_sym_alias] = ACTIONS(3833),
    [anon_sym_SEMI] = ACTIONS(3835),
    [anon_sym_global] = ACTIONS(3833),
    [anon_sym_using] = ACTIONS(3833),
    [anon_sym_unsafe] = ACTIONS(3833),
    [anon_sym_static] = ACTIONS(3833),
    [anon_sym_LBRACK] = ACTIONS(3835),
    [anon_sym_LPAREN] = ACTIONS(3835),
    [anon_sym_return] = ACTIONS(3833),
    [anon_sym_namespace] = ACTIONS(3833),
    [anon_sym_class] = ACTIONS(3833),
    [anon_sym_ref] = ACTIONS(3833),
    [anon_sym_struct] = ACTIONS(3833),
    [anon_sym_enum] = ACTIONS(3833),
    [anon_sym_LBRACE] = ACTIONS(3835),
    [anon_sym_interface] = ACTIONS(3833),
    [anon_sym_delegate] = ACTIONS(3833),
    [anon_sym_record] = ACTIONS(3833),
    [anon_sym_abstract] = ACTIONS(3833),
    [anon_sym_async] = ACTIONS(3833),
    [anon_sym_const] = ACTIONS(3833),
    [anon_sym_file] = ACTIONS(3833),
    [anon_sym_fixed] = ACTIONS(3833),
    [anon_sym_internal] = ACTIONS(3833),
    [anon_sym_new] = ACTIONS(3833),
    [anon_sym_override] = ACTIONS(3833),
    [anon_sym_partial] = ACTIONS(3833),
    [anon_sym_private] = ACTIONS(3833),
    [anon_sym_protected] = ACTIONS(3833),
    [anon_sym_public] = ACTIONS(3833),
    [anon_sym_readonly] = ACTIONS(3833),
    [anon_sym_required] = ACTIONS(3833),
    [anon_sym_sealed] = ACTIONS(3833),
    [anon_sym_virtual] = ACTIONS(3833),
    [anon_sym_volatile] = ACTIONS(3833),
    [anon_sym_where] = ACTIONS(3833),
    [anon_sym_notnull] = ACTIONS(3833),
    [anon_sym_unmanaged] = ACTIONS(3833),
    [anon_sym_checked] = ACTIONS(3833),
    [anon_sym_BANG] = ACTIONS(3835),
    [anon_sym_TILDE] = ACTIONS(3835),
    [anon_sym_PLUS_PLUS] = ACTIONS(3835),
    [anon_sym_DASH_DASH] = ACTIONS(3835),
    [anon_sym_true] = ACTIONS(3833),
    [anon_sym_false] = ACTIONS(3833),
    [anon_sym_PLUS] = ACTIONS(3833),
    [anon_sym_DASH] = ACTIONS(3833),
    [anon_sym_STAR] = ACTIONS(3835),
    [anon_sym_CARET] = ACTIONS(3835),
    [anon_sym_AMP] = ACTIONS(3835),
    [anon_sym_this] = ACTIONS(3833),
    [anon_sym_scoped] = ACTIONS(3833),
    [anon_sym_base] = ACTIONS(3833),
    [anon_sym_var] = ACTIONS(3833),
    [sym_predefined_type] = ACTIONS(3833),
    [anon_sym_break] = ACTIONS(3833),
    [anon_sym_unchecked] = ACTIONS(3833),
    [anon_sym_continue] = ACTIONS(3833),
    [anon_sym_do] = ACTIONS(3833),
    [anon_sym_while] = ACTIONS(3833),
    [anon_sym_for] = ACTIONS(3833),
    [anon_sym_lock] = ACTIONS(3833),
    [anon_sym_yield] = ACTIONS(3833),
    [anon_sym_switch] = ACTIONS(3833),
    [anon_sym_default] = ACTIONS(3833),
    [anon_sym_throw] = ACTIONS(3833),
    [anon_sym_try] = ACTIONS(3833),
    [anon_sym_when] = ACTIONS(3833),
    [anon_sym_await] = ACTIONS(3833),
    [anon_sym_foreach] = ACTIONS(3833),
    [anon_sym_goto] = ACTIONS(3833),
    [anon_sym_if] = ACTIONS(3833),
    [anon_sym_DOT_DOT] = ACTIONS(3835),
    [anon_sym_from] = ACTIONS(3833),
    [anon_sym_into] = ACTIONS(3833),
    [anon_sym_join] = ACTIONS(3833),
    [anon_sym_on] = ACTIONS(3833),
    [anon_sym_equals] = ACTIONS(3833),
    [anon_sym_let] = ACTIONS(3833),
    [anon_sym_orderby] = ACTIONS(3833),
    [anon_sym_ascending] = ACTIONS(3833),
    [anon_sym_descending] = ACTIONS(3833),
    [anon_sym_group] = ACTIONS(3833),
    [anon_sym_by] = ACTIONS(3833),
    [anon_sym_select] = ACTIONS(3833),
    [anon_sym_stackalloc] = ACTIONS(3833),
    [anon_sym_sizeof] = ACTIONS(3833),
    [anon_sym_typeof] = ACTIONS(3833),
    [anon_sym___makeref] = ACTIONS(3833),
    [anon_sym___reftype] = ACTIONS(3833),
    [anon_sym___refvalue] = ACTIONS(3833),
    [sym_null_literal] = ACTIONS(3833),
    [anon_sym_SQUOTE] = ACTIONS(3835),
    [sym_integer_literal] = ACTIONS(3833),
    [sym_real_literal] = ACTIONS(3835),
    [anon_sym_DQUOTE] = ACTIONS(3835),
    [sym_verbatim_string_literal] = ACTIONS(3835),
    [aux_sym_preproc_if_token1] = ACTIONS(3835),
    [aux_sym_preproc_if_token3] = ACTIONS(3835),
    [aux_sym_preproc_else_token1] = ACTIONS(3835),
    [aux_sym_preproc_elif_token1] = ACTIONS(3835),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3835),
    [sym_interpolation_verbatim_start] = ACTIONS(3835),
    [sym_interpolation_raw_start] = ACTIONS(3835),
    [sym_raw_string_start] = ACTIONS(3835),
  },
  [2415] = {
    [sym_preproc_region] = STATE(2415),
    [sym_preproc_endregion] = STATE(2415),
    [sym_preproc_line] = STATE(2415),
    [sym_preproc_pragma] = STATE(2415),
    [sym_preproc_nullable] = STATE(2415),
    [sym_preproc_error] = STATE(2415),
    [sym_preproc_warning] = STATE(2415),
    [sym_preproc_define] = STATE(2415),
    [sym_preproc_undef] = STATE(2415),
    [sym__identifier_token] = ACTIONS(3837),
    [anon_sym_extern] = ACTIONS(3837),
    [anon_sym_alias] = ACTIONS(3837),
    [anon_sym_SEMI] = ACTIONS(3839),
    [anon_sym_global] = ACTIONS(3837),
    [anon_sym_using] = ACTIONS(3837),
    [anon_sym_unsafe] = ACTIONS(3837),
    [anon_sym_static] = ACTIONS(3837),
    [anon_sym_LBRACK] = ACTIONS(3839),
    [anon_sym_LPAREN] = ACTIONS(3839),
    [anon_sym_return] = ACTIONS(3837),
    [anon_sym_namespace] = ACTIONS(3837),
    [anon_sym_class] = ACTIONS(3837),
    [anon_sym_ref] = ACTIONS(3837),
    [anon_sym_struct] = ACTIONS(3837),
    [anon_sym_enum] = ACTIONS(3837),
    [anon_sym_LBRACE] = ACTIONS(3839),
    [anon_sym_interface] = ACTIONS(3837),
    [anon_sym_delegate] = ACTIONS(3837),
    [anon_sym_record] = ACTIONS(3837),
    [anon_sym_abstract] = ACTIONS(3837),
    [anon_sym_async] = ACTIONS(3837),
    [anon_sym_const] = ACTIONS(3837),
    [anon_sym_file] = ACTIONS(3837),
    [anon_sym_fixed] = ACTIONS(3837),
    [anon_sym_internal] = ACTIONS(3837),
    [anon_sym_new] = ACTIONS(3837),
    [anon_sym_override] = ACTIONS(3837),
    [anon_sym_partial] = ACTIONS(3837),
    [anon_sym_private] = ACTIONS(3837),
    [anon_sym_protected] = ACTIONS(3837),
    [anon_sym_public] = ACTIONS(3837),
    [anon_sym_readonly] = ACTIONS(3837),
    [anon_sym_required] = ACTIONS(3837),
    [anon_sym_sealed] = ACTIONS(3837),
    [anon_sym_virtual] = ACTIONS(3837),
    [anon_sym_volatile] = ACTIONS(3837),
    [anon_sym_where] = ACTIONS(3837),
    [anon_sym_notnull] = ACTIONS(3837),
    [anon_sym_unmanaged] = ACTIONS(3837),
    [anon_sym_checked] = ACTIONS(3837),
    [anon_sym_BANG] = ACTIONS(3839),
    [anon_sym_TILDE] = ACTIONS(3839),
    [anon_sym_PLUS_PLUS] = ACTIONS(3839),
    [anon_sym_DASH_DASH] = ACTIONS(3839),
    [anon_sym_true] = ACTIONS(3837),
    [anon_sym_false] = ACTIONS(3837),
    [anon_sym_PLUS] = ACTIONS(3837),
    [anon_sym_DASH] = ACTIONS(3837),
    [anon_sym_STAR] = ACTIONS(3839),
    [anon_sym_CARET] = ACTIONS(3839),
    [anon_sym_AMP] = ACTIONS(3839),
    [anon_sym_this] = ACTIONS(3837),
    [anon_sym_scoped] = ACTIONS(3837),
    [anon_sym_base] = ACTIONS(3837),
    [anon_sym_var] = ACTIONS(3837),
    [sym_predefined_type] = ACTIONS(3837),
    [anon_sym_break] = ACTIONS(3837),
    [anon_sym_unchecked] = ACTIONS(3837),
    [anon_sym_continue] = ACTIONS(3837),
    [anon_sym_do] = ACTIONS(3837),
    [anon_sym_while] = ACTIONS(3837),
    [anon_sym_for] = ACTIONS(3837),
    [anon_sym_lock] = ACTIONS(3837),
    [anon_sym_yield] = ACTIONS(3837),
    [anon_sym_switch] = ACTIONS(3837),
    [anon_sym_default] = ACTIONS(3837),
    [anon_sym_throw] = ACTIONS(3837),
    [anon_sym_try] = ACTIONS(3837),
    [anon_sym_when] = ACTIONS(3837),
    [anon_sym_await] = ACTIONS(3837),
    [anon_sym_foreach] = ACTIONS(3837),
    [anon_sym_goto] = ACTIONS(3837),
    [anon_sym_if] = ACTIONS(3837),
    [anon_sym_DOT_DOT] = ACTIONS(3839),
    [anon_sym_from] = ACTIONS(3837),
    [anon_sym_into] = ACTIONS(3837),
    [anon_sym_join] = ACTIONS(3837),
    [anon_sym_on] = ACTIONS(3837),
    [anon_sym_equals] = ACTIONS(3837),
    [anon_sym_let] = ACTIONS(3837),
    [anon_sym_orderby] = ACTIONS(3837),
    [anon_sym_ascending] = ACTIONS(3837),
    [anon_sym_descending] = ACTIONS(3837),
    [anon_sym_group] = ACTIONS(3837),
    [anon_sym_by] = ACTIONS(3837),
    [anon_sym_select] = ACTIONS(3837),
    [anon_sym_stackalloc] = ACTIONS(3837),
    [anon_sym_sizeof] = ACTIONS(3837),
    [anon_sym_typeof] = ACTIONS(3837),
    [anon_sym___makeref] = ACTIONS(3837),
    [anon_sym___reftype] = ACTIONS(3837),
    [anon_sym___refvalue] = ACTIONS(3837),
    [sym_null_literal] = ACTIONS(3837),
    [anon_sym_SQUOTE] = ACTIONS(3839),
    [sym_integer_literal] = ACTIONS(3837),
    [sym_real_literal] = ACTIONS(3839),
    [anon_sym_DQUOTE] = ACTIONS(3839),
    [sym_verbatim_string_literal] = ACTIONS(3839),
    [aux_sym_preproc_if_token1] = ACTIONS(3839),
    [aux_sym_preproc_if_token3] = ACTIONS(3839),
    [aux_sym_preproc_else_token1] = ACTIONS(3839),
    [aux_sym_preproc_elif_token1] = ACTIONS(3839),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3839),
    [sym_interpolation_verbatim_start] = ACTIONS(3839),
    [sym_interpolation_raw_start] = ACTIONS(3839),
    [sym_raw_string_start] = ACTIONS(3839),
  },
  [2416] = {
    [sym_preproc_region] = STATE(2416),
    [sym_preproc_endregion] = STATE(2416),
    [sym_preproc_line] = STATE(2416),
    [sym_preproc_pragma] = STATE(2416),
    [sym_preproc_nullable] = STATE(2416),
    [sym_preproc_error] = STATE(2416),
    [sym_preproc_warning] = STATE(2416),
    [sym_preproc_define] = STATE(2416),
    [sym_preproc_undef] = STATE(2416),
    [sym__identifier_token] = ACTIONS(3841),
    [anon_sym_extern] = ACTIONS(3841),
    [anon_sym_alias] = ACTIONS(3841),
    [anon_sym_SEMI] = ACTIONS(3843),
    [anon_sym_global] = ACTIONS(3841),
    [anon_sym_using] = ACTIONS(3841),
    [anon_sym_unsafe] = ACTIONS(3841),
    [anon_sym_static] = ACTIONS(3841),
    [anon_sym_LBRACK] = ACTIONS(3843),
    [anon_sym_LPAREN] = ACTIONS(3843),
    [anon_sym_return] = ACTIONS(3841),
    [anon_sym_namespace] = ACTIONS(3841),
    [anon_sym_class] = ACTIONS(3841),
    [anon_sym_ref] = ACTIONS(3841),
    [anon_sym_struct] = ACTIONS(3841),
    [anon_sym_enum] = ACTIONS(3841),
    [anon_sym_LBRACE] = ACTIONS(3843),
    [anon_sym_interface] = ACTIONS(3841),
    [anon_sym_delegate] = ACTIONS(3841),
    [anon_sym_record] = ACTIONS(3841),
    [anon_sym_abstract] = ACTIONS(3841),
    [anon_sym_async] = ACTIONS(3841),
    [anon_sym_const] = ACTIONS(3841),
    [anon_sym_file] = ACTIONS(3841),
    [anon_sym_fixed] = ACTIONS(3841),
    [anon_sym_internal] = ACTIONS(3841),
    [anon_sym_new] = ACTIONS(3841),
    [anon_sym_override] = ACTIONS(3841),
    [anon_sym_partial] = ACTIONS(3841),
    [anon_sym_private] = ACTIONS(3841),
    [anon_sym_protected] = ACTIONS(3841),
    [anon_sym_public] = ACTIONS(3841),
    [anon_sym_readonly] = ACTIONS(3841),
    [anon_sym_required] = ACTIONS(3841),
    [anon_sym_sealed] = ACTIONS(3841),
    [anon_sym_virtual] = ACTIONS(3841),
    [anon_sym_volatile] = ACTIONS(3841),
    [anon_sym_where] = ACTIONS(3841),
    [anon_sym_notnull] = ACTIONS(3841),
    [anon_sym_unmanaged] = ACTIONS(3841),
    [anon_sym_checked] = ACTIONS(3841),
    [anon_sym_BANG] = ACTIONS(3843),
    [anon_sym_TILDE] = ACTIONS(3843),
    [anon_sym_PLUS_PLUS] = ACTIONS(3843),
    [anon_sym_DASH_DASH] = ACTIONS(3843),
    [anon_sym_true] = ACTIONS(3841),
    [anon_sym_false] = ACTIONS(3841),
    [anon_sym_PLUS] = ACTIONS(3841),
    [anon_sym_DASH] = ACTIONS(3841),
    [anon_sym_STAR] = ACTIONS(3843),
    [anon_sym_CARET] = ACTIONS(3843),
    [anon_sym_AMP] = ACTIONS(3843),
    [anon_sym_this] = ACTIONS(3841),
    [anon_sym_scoped] = ACTIONS(3841),
    [anon_sym_base] = ACTIONS(3841),
    [anon_sym_var] = ACTIONS(3841),
    [sym_predefined_type] = ACTIONS(3841),
    [anon_sym_break] = ACTIONS(3841),
    [anon_sym_unchecked] = ACTIONS(3841),
    [anon_sym_continue] = ACTIONS(3841),
    [anon_sym_do] = ACTIONS(3841),
    [anon_sym_while] = ACTIONS(3841),
    [anon_sym_for] = ACTIONS(3841),
    [anon_sym_lock] = ACTIONS(3841),
    [anon_sym_yield] = ACTIONS(3841),
    [anon_sym_switch] = ACTIONS(3841),
    [anon_sym_default] = ACTIONS(3841),
    [anon_sym_throw] = ACTIONS(3841),
    [anon_sym_try] = ACTIONS(3841),
    [anon_sym_when] = ACTIONS(3841),
    [anon_sym_await] = ACTIONS(3841),
    [anon_sym_foreach] = ACTIONS(3841),
    [anon_sym_goto] = ACTIONS(3841),
    [anon_sym_if] = ACTIONS(3841),
    [anon_sym_DOT_DOT] = ACTIONS(3843),
    [anon_sym_from] = ACTIONS(3841),
    [anon_sym_into] = ACTIONS(3841),
    [anon_sym_join] = ACTIONS(3841),
    [anon_sym_on] = ACTIONS(3841),
    [anon_sym_equals] = ACTIONS(3841),
    [anon_sym_let] = ACTIONS(3841),
    [anon_sym_orderby] = ACTIONS(3841),
    [anon_sym_ascending] = ACTIONS(3841),
    [anon_sym_descending] = ACTIONS(3841),
    [anon_sym_group] = ACTIONS(3841),
    [anon_sym_by] = ACTIONS(3841),
    [anon_sym_select] = ACTIONS(3841),
    [anon_sym_stackalloc] = ACTIONS(3841),
    [anon_sym_sizeof] = ACTIONS(3841),
    [anon_sym_typeof] = ACTIONS(3841),
    [anon_sym___makeref] = ACTIONS(3841),
    [anon_sym___reftype] = ACTIONS(3841),
    [anon_sym___refvalue] = ACTIONS(3841),
    [sym_null_literal] = ACTIONS(3841),
    [anon_sym_SQUOTE] = ACTIONS(3843),
    [sym_integer_literal] = ACTIONS(3841),
    [sym_real_literal] = ACTIONS(3843),
    [anon_sym_DQUOTE] = ACTIONS(3843),
    [sym_verbatim_string_literal] = ACTIONS(3843),
    [aux_sym_preproc_if_token1] = ACTIONS(3843),
    [aux_sym_preproc_if_token3] = ACTIONS(3843),
    [aux_sym_preproc_else_token1] = ACTIONS(3843),
    [aux_sym_preproc_elif_token1] = ACTIONS(3843),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3843),
    [sym_interpolation_verbatim_start] = ACTIONS(3843),
    [sym_interpolation_raw_start] = ACTIONS(3843),
    [sym_raw_string_start] = ACTIONS(3843),
  },
  [2417] = {
    [sym_preproc_region] = STATE(2417),
    [sym_preproc_endregion] = STATE(2417),
    [sym_preproc_line] = STATE(2417),
    [sym_preproc_pragma] = STATE(2417),
    [sym_preproc_nullable] = STATE(2417),
    [sym_preproc_error] = STATE(2417),
    [sym_preproc_warning] = STATE(2417),
    [sym_preproc_define] = STATE(2417),
    [sym_preproc_undef] = STATE(2417),
    [sym__identifier_token] = ACTIONS(3845),
    [anon_sym_extern] = ACTIONS(3845),
    [anon_sym_alias] = ACTIONS(3845),
    [anon_sym_SEMI] = ACTIONS(3847),
    [anon_sym_global] = ACTIONS(3845),
    [anon_sym_using] = ACTIONS(3845),
    [anon_sym_unsafe] = ACTIONS(3845),
    [anon_sym_static] = ACTIONS(3845),
    [anon_sym_LBRACK] = ACTIONS(3847),
    [anon_sym_LPAREN] = ACTIONS(3847),
    [anon_sym_return] = ACTIONS(3845),
    [anon_sym_namespace] = ACTIONS(3845),
    [anon_sym_class] = ACTIONS(3845),
    [anon_sym_ref] = ACTIONS(3845),
    [anon_sym_struct] = ACTIONS(3845),
    [anon_sym_enum] = ACTIONS(3845),
    [anon_sym_LBRACE] = ACTIONS(3847),
    [anon_sym_interface] = ACTIONS(3845),
    [anon_sym_delegate] = ACTIONS(3845),
    [anon_sym_record] = ACTIONS(3845),
    [anon_sym_abstract] = ACTIONS(3845),
    [anon_sym_async] = ACTIONS(3845),
    [anon_sym_const] = ACTIONS(3845),
    [anon_sym_file] = ACTIONS(3845),
    [anon_sym_fixed] = ACTIONS(3845),
    [anon_sym_internal] = ACTIONS(3845),
    [anon_sym_new] = ACTIONS(3845),
    [anon_sym_override] = ACTIONS(3845),
    [anon_sym_partial] = ACTIONS(3845),
    [anon_sym_private] = ACTIONS(3845),
    [anon_sym_protected] = ACTIONS(3845),
    [anon_sym_public] = ACTIONS(3845),
    [anon_sym_readonly] = ACTIONS(3845),
    [anon_sym_required] = ACTIONS(3845),
    [anon_sym_sealed] = ACTIONS(3845),
    [anon_sym_virtual] = ACTIONS(3845),
    [anon_sym_volatile] = ACTIONS(3845),
    [anon_sym_where] = ACTIONS(3845),
    [anon_sym_notnull] = ACTIONS(3845),
    [anon_sym_unmanaged] = ACTIONS(3845),
    [anon_sym_checked] = ACTIONS(3845),
    [anon_sym_BANG] = ACTIONS(3847),
    [anon_sym_TILDE] = ACTIONS(3847),
    [anon_sym_PLUS_PLUS] = ACTIONS(3847),
    [anon_sym_DASH_DASH] = ACTIONS(3847),
    [anon_sym_true] = ACTIONS(3845),
    [anon_sym_false] = ACTIONS(3845),
    [anon_sym_PLUS] = ACTIONS(3845),
    [anon_sym_DASH] = ACTIONS(3845),
    [anon_sym_STAR] = ACTIONS(3847),
    [anon_sym_CARET] = ACTIONS(3847),
    [anon_sym_AMP] = ACTIONS(3847),
    [anon_sym_this] = ACTIONS(3845),
    [anon_sym_scoped] = ACTIONS(3845),
    [anon_sym_base] = ACTIONS(3845),
    [anon_sym_var] = ACTIONS(3845),
    [sym_predefined_type] = ACTIONS(3845),
    [anon_sym_break] = ACTIONS(3845),
    [anon_sym_unchecked] = ACTIONS(3845),
    [anon_sym_continue] = ACTIONS(3845),
    [anon_sym_do] = ACTIONS(3845),
    [anon_sym_while] = ACTIONS(3845),
    [anon_sym_for] = ACTIONS(3845),
    [anon_sym_lock] = ACTIONS(3845),
    [anon_sym_yield] = ACTIONS(3845),
    [anon_sym_switch] = ACTIONS(3845),
    [anon_sym_default] = ACTIONS(3845),
    [anon_sym_throw] = ACTIONS(3845),
    [anon_sym_try] = ACTIONS(3845),
    [anon_sym_when] = ACTIONS(3845),
    [anon_sym_await] = ACTIONS(3845),
    [anon_sym_foreach] = ACTIONS(3845),
    [anon_sym_goto] = ACTIONS(3845),
    [anon_sym_if] = ACTIONS(3845),
    [anon_sym_DOT_DOT] = ACTIONS(3847),
    [anon_sym_from] = ACTIONS(3845),
    [anon_sym_into] = ACTIONS(3845),
    [anon_sym_join] = ACTIONS(3845),
    [anon_sym_on] = ACTIONS(3845),
    [anon_sym_equals] = ACTIONS(3845),
    [anon_sym_let] = ACTIONS(3845),
    [anon_sym_orderby] = ACTIONS(3845),
    [anon_sym_ascending] = ACTIONS(3845),
    [anon_sym_descending] = ACTIONS(3845),
    [anon_sym_group] = ACTIONS(3845),
    [anon_sym_by] = ACTIONS(3845),
    [anon_sym_select] = ACTIONS(3845),
    [anon_sym_stackalloc] = ACTIONS(3845),
    [anon_sym_sizeof] = ACTIONS(3845),
    [anon_sym_typeof] = ACTIONS(3845),
    [anon_sym___makeref] = ACTIONS(3845),
    [anon_sym___reftype] = ACTIONS(3845),
    [anon_sym___refvalue] = ACTIONS(3845),
    [sym_null_literal] = ACTIONS(3845),
    [anon_sym_SQUOTE] = ACTIONS(3847),
    [sym_integer_literal] = ACTIONS(3845),
    [sym_real_literal] = ACTIONS(3847),
    [anon_sym_DQUOTE] = ACTIONS(3847),
    [sym_verbatim_string_literal] = ACTIONS(3847),
    [aux_sym_preproc_if_token1] = ACTIONS(3847),
    [aux_sym_preproc_if_token3] = ACTIONS(3847),
    [aux_sym_preproc_else_token1] = ACTIONS(3847),
    [aux_sym_preproc_elif_token1] = ACTIONS(3847),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3847),
    [sym_interpolation_verbatim_start] = ACTIONS(3847),
    [sym_interpolation_raw_start] = ACTIONS(3847),
    [sym_raw_string_start] = ACTIONS(3847),
  },
  [2418] = {
    [sym_preproc_region] = STATE(2418),
    [sym_preproc_endregion] = STATE(2418),
    [sym_preproc_line] = STATE(2418),
    [sym_preproc_pragma] = STATE(2418),
    [sym_preproc_nullable] = STATE(2418),
    [sym_preproc_error] = STATE(2418),
    [sym_preproc_warning] = STATE(2418),
    [sym_preproc_define] = STATE(2418),
    [sym_preproc_undef] = STATE(2418),
    [sym__identifier_token] = ACTIONS(3849),
    [anon_sym_extern] = ACTIONS(3849),
    [anon_sym_alias] = ACTIONS(3849),
    [anon_sym_SEMI] = ACTIONS(3851),
    [anon_sym_global] = ACTIONS(3849),
    [anon_sym_using] = ACTIONS(3849),
    [anon_sym_unsafe] = ACTIONS(3849),
    [anon_sym_static] = ACTIONS(3849),
    [anon_sym_LBRACK] = ACTIONS(3851),
    [anon_sym_LPAREN] = ACTIONS(3851),
    [anon_sym_return] = ACTIONS(3849),
    [anon_sym_namespace] = ACTIONS(3849),
    [anon_sym_class] = ACTIONS(3849),
    [anon_sym_ref] = ACTIONS(3849),
    [anon_sym_struct] = ACTIONS(3849),
    [anon_sym_enum] = ACTIONS(3849),
    [anon_sym_LBRACE] = ACTIONS(3851),
    [anon_sym_interface] = ACTIONS(3849),
    [anon_sym_delegate] = ACTIONS(3849),
    [anon_sym_record] = ACTIONS(3849),
    [anon_sym_abstract] = ACTIONS(3849),
    [anon_sym_async] = ACTIONS(3849),
    [anon_sym_const] = ACTIONS(3849),
    [anon_sym_file] = ACTIONS(3849),
    [anon_sym_fixed] = ACTIONS(3849),
    [anon_sym_internal] = ACTIONS(3849),
    [anon_sym_new] = ACTIONS(3849),
    [anon_sym_override] = ACTIONS(3849),
    [anon_sym_partial] = ACTIONS(3849),
    [anon_sym_private] = ACTIONS(3849),
    [anon_sym_protected] = ACTIONS(3849),
    [anon_sym_public] = ACTIONS(3849),
    [anon_sym_readonly] = ACTIONS(3849),
    [anon_sym_required] = ACTIONS(3849),
    [anon_sym_sealed] = ACTIONS(3849),
    [anon_sym_virtual] = ACTIONS(3849),
    [anon_sym_volatile] = ACTIONS(3849),
    [anon_sym_where] = ACTIONS(3849),
    [anon_sym_notnull] = ACTIONS(3849),
    [anon_sym_unmanaged] = ACTIONS(3849),
    [anon_sym_checked] = ACTIONS(3849),
    [anon_sym_BANG] = ACTIONS(3851),
    [anon_sym_TILDE] = ACTIONS(3851),
    [anon_sym_PLUS_PLUS] = ACTIONS(3851),
    [anon_sym_DASH_DASH] = ACTIONS(3851),
    [anon_sym_true] = ACTIONS(3849),
    [anon_sym_false] = ACTIONS(3849),
    [anon_sym_PLUS] = ACTIONS(3849),
    [anon_sym_DASH] = ACTIONS(3849),
    [anon_sym_STAR] = ACTIONS(3851),
    [anon_sym_CARET] = ACTIONS(3851),
    [anon_sym_AMP] = ACTIONS(3851),
    [anon_sym_this] = ACTIONS(3849),
    [anon_sym_scoped] = ACTIONS(3849),
    [anon_sym_base] = ACTIONS(3849),
    [anon_sym_var] = ACTIONS(3849),
    [sym_predefined_type] = ACTIONS(3849),
    [anon_sym_break] = ACTIONS(3849),
    [anon_sym_unchecked] = ACTIONS(3849),
    [anon_sym_continue] = ACTIONS(3849),
    [anon_sym_do] = ACTIONS(3849),
    [anon_sym_while] = ACTIONS(3849),
    [anon_sym_for] = ACTIONS(3849),
    [anon_sym_lock] = ACTIONS(3849),
    [anon_sym_yield] = ACTIONS(3849),
    [anon_sym_switch] = ACTIONS(3849),
    [anon_sym_default] = ACTIONS(3849),
    [anon_sym_throw] = ACTIONS(3849),
    [anon_sym_try] = ACTIONS(3849),
    [anon_sym_when] = ACTIONS(3849),
    [anon_sym_await] = ACTIONS(3849),
    [anon_sym_foreach] = ACTIONS(3849),
    [anon_sym_goto] = ACTIONS(3849),
    [anon_sym_if] = ACTIONS(3849),
    [anon_sym_DOT_DOT] = ACTIONS(3851),
    [anon_sym_from] = ACTIONS(3849),
    [anon_sym_into] = ACTIONS(3849),
    [anon_sym_join] = ACTIONS(3849),
    [anon_sym_on] = ACTIONS(3849),
    [anon_sym_equals] = ACTIONS(3849),
    [anon_sym_let] = ACTIONS(3849),
    [anon_sym_orderby] = ACTIONS(3849),
    [anon_sym_ascending] = ACTIONS(3849),
    [anon_sym_descending] = ACTIONS(3849),
    [anon_sym_group] = ACTIONS(3849),
    [anon_sym_by] = ACTIONS(3849),
    [anon_sym_select] = ACTIONS(3849),
    [anon_sym_stackalloc] = ACTIONS(3849),
    [anon_sym_sizeof] = ACTIONS(3849),
    [anon_sym_typeof] = ACTIONS(3849),
    [anon_sym___makeref] = ACTIONS(3849),
    [anon_sym___reftype] = ACTIONS(3849),
    [anon_sym___refvalue] = ACTIONS(3849),
    [sym_null_literal] = ACTIONS(3849),
    [anon_sym_SQUOTE] = ACTIONS(3851),
    [sym_integer_literal] = ACTIONS(3849),
    [sym_real_literal] = ACTIONS(3851),
    [anon_sym_DQUOTE] = ACTIONS(3851),
    [sym_verbatim_string_literal] = ACTIONS(3851),
    [aux_sym_preproc_if_token1] = ACTIONS(3851),
    [aux_sym_preproc_if_token3] = ACTIONS(3851),
    [aux_sym_preproc_else_token1] = ACTIONS(3851),
    [aux_sym_preproc_elif_token1] = ACTIONS(3851),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3851),
    [sym_interpolation_verbatim_start] = ACTIONS(3851),
    [sym_interpolation_raw_start] = ACTIONS(3851),
    [sym_raw_string_start] = ACTIONS(3851),
  },
  [2419] = {
    [sym_preproc_region] = STATE(2419),
    [sym_preproc_endregion] = STATE(2419),
    [sym_preproc_line] = STATE(2419),
    [sym_preproc_pragma] = STATE(2419),
    [sym_preproc_nullable] = STATE(2419),
    [sym_preproc_error] = STATE(2419),
    [sym_preproc_warning] = STATE(2419),
    [sym_preproc_define] = STATE(2419),
    [sym_preproc_undef] = STATE(2419),
    [sym__identifier_token] = ACTIONS(3853),
    [anon_sym_extern] = ACTIONS(3853),
    [anon_sym_alias] = ACTIONS(3853),
    [anon_sym_SEMI] = ACTIONS(3855),
    [anon_sym_global] = ACTIONS(3853),
    [anon_sym_using] = ACTIONS(3853),
    [anon_sym_unsafe] = ACTIONS(3853),
    [anon_sym_static] = ACTIONS(3853),
    [anon_sym_LBRACK] = ACTIONS(3855),
    [anon_sym_LPAREN] = ACTIONS(3855),
    [anon_sym_return] = ACTIONS(3853),
    [anon_sym_namespace] = ACTIONS(3853),
    [anon_sym_class] = ACTIONS(3853),
    [anon_sym_ref] = ACTIONS(3853),
    [anon_sym_struct] = ACTIONS(3853),
    [anon_sym_enum] = ACTIONS(3853),
    [anon_sym_LBRACE] = ACTIONS(3855),
    [anon_sym_interface] = ACTIONS(3853),
    [anon_sym_delegate] = ACTIONS(3853),
    [anon_sym_record] = ACTIONS(3853),
    [anon_sym_abstract] = ACTIONS(3853),
    [anon_sym_async] = ACTIONS(3853),
    [anon_sym_const] = ACTIONS(3853),
    [anon_sym_file] = ACTIONS(3853),
    [anon_sym_fixed] = ACTIONS(3853),
    [anon_sym_internal] = ACTIONS(3853),
    [anon_sym_new] = ACTIONS(3853),
    [anon_sym_override] = ACTIONS(3853),
    [anon_sym_partial] = ACTIONS(3853),
    [anon_sym_private] = ACTIONS(3853),
    [anon_sym_protected] = ACTIONS(3853),
    [anon_sym_public] = ACTIONS(3853),
    [anon_sym_readonly] = ACTIONS(3853),
    [anon_sym_required] = ACTIONS(3853),
    [anon_sym_sealed] = ACTIONS(3853),
    [anon_sym_virtual] = ACTIONS(3853),
    [anon_sym_volatile] = ACTIONS(3853),
    [anon_sym_where] = ACTIONS(3853),
    [anon_sym_notnull] = ACTIONS(3853),
    [anon_sym_unmanaged] = ACTIONS(3853),
    [anon_sym_checked] = ACTIONS(3853),
    [anon_sym_BANG] = ACTIONS(3855),
    [anon_sym_TILDE] = ACTIONS(3855),
    [anon_sym_PLUS_PLUS] = ACTIONS(3855),
    [anon_sym_DASH_DASH] = ACTIONS(3855),
    [anon_sym_true] = ACTIONS(3853),
    [anon_sym_false] = ACTIONS(3853),
    [anon_sym_PLUS] = ACTIONS(3853),
    [anon_sym_DASH] = ACTIONS(3853),
    [anon_sym_STAR] = ACTIONS(3855),
    [anon_sym_CARET] = ACTIONS(3855),
    [anon_sym_AMP] = ACTIONS(3855),
    [anon_sym_this] = ACTIONS(3853),
    [anon_sym_scoped] = ACTIONS(3853),
    [anon_sym_base] = ACTIONS(3853),
    [anon_sym_var] = ACTIONS(3853),
    [sym_predefined_type] = ACTIONS(3853),
    [anon_sym_break] = ACTIONS(3853),
    [anon_sym_unchecked] = ACTIONS(3853),
    [anon_sym_continue] = ACTIONS(3853),
    [anon_sym_do] = ACTIONS(3853),
    [anon_sym_while] = ACTIONS(3853),
    [anon_sym_for] = ACTIONS(3853),
    [anon_sym_lock] = ACTIONS(3853),
    [anon_sym_yield] = ACTIONS(3853),
    [anon_sym_switch] = ACTIONS(3853),
    [anon_sym_default] = ACTIONS(3853),
    [anon_sym_throw] = ACTIONS(3853),
    [anon_sym_try] = ACTIONS(3853),
    [anon_sym_when] = ACTIONS(3853),
    [anon_sym_await] = ACTIONS(3853),
    [anon_sym_foreach] = ACTIONS(3853),
    [anon_sym_goto] = ACTIONS(3853),
    [anon_sym_if] = ACTIONS(3853),
    [anon_sym_DOT_DOT] = ACTIONS(3855),
    [anon_sym_from] = ACTIONS(3853),
    [anon_sym_into] = ACTIONS(3853),
    [anon_sym_join] = ACTIONS(3853),
    [anon_sym_on] = ACTIONS(3853),
    [anon_sym_equals] = ACTIONS(3853),
    [anon_sym_let] = ACTIONS(3853),
    [anon_sym_orderby] = ACTIONS(3853),
    [anon_sym_ascending] = ACTIONS(3853),
    [anon_sym_descending] = ACTIONS(3853),
    [anon_sym_group] = ACTIONS(3853),
    [anon_sym_by] = ACTIONS(3853),
    [anon_sym_select] = ACTIONS(3853),
    [anon_sym_stackalloc] = ACTIONS(3853),
    [anon_sym_sizeof] = ACTIONS(3853),
    [anon_sym_typeof] = ACTIONS(3853),
    [anon_sym___makeref] = ACTIONS(3853),
    [anon_sym___reftype] = ACTIONS(3853),
    [anon_sym___refvalue] = ACTIONS(3853),
    [sym_null_literal] = ACTIONS(3853),
    [anon_sym_SQUOTE] = ACTIONS(3855),
    [sym_integer_literal] = ACTIONS(3853),
    [sym_real_literal] = ACTIONS(3855),
    [anon_sym_DQUOTE] = ACTIONS(3855),
    [sym_verbatim_string_literal] = ACTIONS(3855),
    [aux_sym_preproc_if_token1] = ACTIONS(3855),
    [aux_sym_preproc_if_token3] = ACTIONS(3855),
    [aux_sym_preproc_else_token1] = ACTIONS(3855),
    [aux_sym_preproc_elif_token1] = ACTIONS(3855),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3855),
    [sym_interpolation_verbatim_start] = ACTIONS(3855),
    [sym_interpolation_raw_start] = ACTIONS(3855),
    [sym_raw_string_start] = ACTIONS(3855),
  },
  [2420] = {
    [sym_preproc_region] = STATE(2420),
    [sym_preproc_endregion] = STATE(2420),
    [sym_preproc_line] = STATE(2420),
    [sym_preproc_pragma] = STATE(2420),
    [sym_preproc_nullable] = STATE(2420),
    [sym_preproc_error] = STATE(2420),
    [sym_preproc_warning] = STATE(2420),
    [sym_preproc_define] = STATE(2420),
    [sym_preproc_undef] = STATE(2420),
    [sym__identifier_token] = ACTIONS(3857),
    [anon_sym_extern] = ACTIONS(3857),
    [anon_sym_alias] = ACTIONS(3857),
    [anon_sym_SEMI] = ACTIONS(3859),
    [anon_sym_global] = ACTIONS(3857),
    [anon_sym_using] = ACTIONS(3857),
    [anon_sym_unsafe] = ACTIONS(3857),
    [anon_sym_static] = ACTIONS(3857),
    [anon_sym_LBRACK] = ACTIONS(3859),
    [anon_sym_LPAREN] = ACTIONS(3859),
    [anon_sym_return] = ACTIONS(3857),
    [anon_sym_namespace] = ACTIONS(3857),
    [anon_sym_class] = ACTIONS(3857),
    [anon_sym_ref] = ACTIONS(3857),
    [anon_sym_struct] = ACTIONS(3857),
    [anon_sym_enum] = ACTIONS(3857),
    [anon_sym_LBRACE] = ACTIONS(3859),
    [anon_sym_interface] = ACTIONS(3857),
    [anon_sym_delegate] = ACTIONS(3857),
    [anon_sym_record] = ACTIONS(3857),
    [anon_sym_abstract] = ACTIONS(3857),
    [anon_sym_async] = ACTIONS(3857),
    [anon_sym_const] = ACTIONS(3857),
    [anon_sym_file] = ACTIONS(3857),
    [anon_sym_fixed] = ACTIONS(3857),
    [anon_sym_internal] = ACTIONS(3857),
    [anon_sym_new] = ACTIONS(3857),
    [anon_sym_override] = ACTIONS(3857),
    [anon_sym_partial] = ACTIONS(3857),
    [anon_sym_private] = ACTIONS(3857),
    [anon_sym_protected] = ACTIONS(3857),
    [anon_sym_public] = ACTIONS(3857),
    [anon_sym_readonly] = ACTIONS(3857),
    [anon_sym_required] = ACTIONS(3857),
    [anon_sym_sealed] = ACTIONS(3857),
    [anon_sym_virtual] = ACTIONS(3857),
    [anon_sym_volatile] = ACTIONS(3857),
    [anon_sym_where] = ACTIONS(3857),
    [anon_sym_notnull] = ACTIONS(3857),
    [anon_sym_unmanaged] = ACTIONS(3857),
    [anon_sym_checked] = ACTIONS(3857),
    [anon_sym_BANG] = ACTIONS(3859),
    [anon_sym_TILDE] = ACTIONS(3859),
    [anon_sym_PLUS_PLUS] = ACTIONS(3859),
    [anon_sym_DASH_DASH] = ACTIONS(3859),
    [anon_sym_true] = ACTIONS(3857),
    [anon_sym_false] = ACTIONS(3857),
    [anon_sym_PLUS] = ACTIONS(3857),
    [anon_sym_DASH] = ACTIONS(3857),
    [anon_sym_STAR] = ACTIONS(3859),
    [anon_sym_CARET] = ACTIONS(3859),
    [anon_sym_AMP] = ACTIONS(3859),
    [anon_sym_this] = ACTIONS(3857),
    [anon_sym_scoped] = ACTIONS(3857),
    [anon_sym_base] = ACTIONS(3857),
    [anon_sym_var] = ACTIONS(3857),
    [sym_predefined_type] = ACTIONS(3857),
    [anon_sym_break] = ACTIONS(3857),
    [anon_sym_unchecked] = ACTIONS(3857),
    [anon_sym_continue] = ACTIONS(3857),
    [anon_sym_do] = ACTIONS(3857),
    [anon_sym_while] = ACTIONS(3857),
    [anon_sym_for] = ACTIONS(3857),
    [anon_sym_lock] = ACTIONS(3857),
    [anon_sym_yield] = ACTIONS(3857),
    [anon_sym_switch] = ACTIONS(3857),
    [anon_sym_default] = ACTIONS(3857),
    [anon_sym_throw] = ACTIONS(3857),
    [anon_sym_try] = ACTIONS(3857),
    [anon_sym_when] = ACTIONS(3857),
    [anon_sym_await] = ACTIONS(3857),
    [anon_sym_foreach] = ACTIONS(3857),
    [anon_sym_goto] = ACTIONS(3857),
    [anon_sym_if] = ACTIONS(3857),
    [anon_sym_DOT_DOT] = ACTIONS(3859),
    [anon_sym_from] = ACTIONS(3857),
    [anon_sym_into] = ACTIONS(3857),
    [anon_sym_join] = ACTIONS(3857),
    [anon_sym_on] = ACTIONS(3857),
    [anon_sym_equals] = ACTIONS(3857),
    [anon_sym_let] = ACTIONS(3857),
    [anon_sym_orderby] = ACTIONS(3857),
    [anon_sym_ascending] = ACTIONS(3857),
    [anon_sym_descending] = ACTIONS(3857),
    [anon_sym_group] = ACTIONS(3857),
    [anon_sym_by] = ACTIONS(3857),
    [anon_sym_select] = ACTIONS(3857),
    [anon_sym_stackalloc] = ACTIONS(3857),
    [anon_sym_sizeof] = ACTIONS(3857),
    [anon_sym_typeof] = ACTIONS(3857),
    [anon_sym___makeref] = ACTIONS(3857),
    [anon_sym___reftype] = ACTIONS(3857),
    [anon_sym___refvalue] = ACTIONS(3857),
    [sym_null_literal] = ACTIONS(3857),
    [anon_sym_SQUOTE] = ACTIONS(3859),
    [sym_integer_literal] = ACTIONS(3857),
    [sym_real_literal] = ACTIONS(3859),
    [anon_sym_DQUOTE] = ACTIONS(3859),
    [sym_verbatim_string_literal] = ACTIONS(3859),
    [aux_sym_preproc_if_token1] = ACTIONS(3859),
    [aux_sym_preproc_if_token3] = ACTIONS(3859),
    [aux_sym_preproc_else_token1] = ACTIONS(3859),
    [aux_sym_preproc_elif_token1] = ACTIONS(3859),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3859),
    [sym_interpolation_verbatim_start] = ACTIONS(3859),
    [sym_interpolation_raw_start] = ACTIONS(3859),
    [sym_raw_string_start] = ACTIONS(3859),
  },
  [2421] = {
    [sym_preproc_region] = STATE(2421),
    [sym_preproc_endregion] = STATE(2421),
    [sym_preproc_line] = STATE(2421),
    [sym_preproc_pragma] = STATE(2421),
    [sym_preproc_nullable] = STATE(2421),
    [sym_preproc_error] = STATE(2421),
    [sym_preproc_warning] = STATE(2421),
    [sym_preproc_define] = STATE(2421),
    [sym_preproc_undef] = STATE(2421),
    [sym__identifier_token] = ACTIONS(3861),
    [anon_sym_extern] = ACTIONS(3861),
    [anon_sym_alias] = ACTIONS(3861),
    [anon_sym_SEMI] = ACTIONS(3863),
    [anon_sym_global] = ACTIONS(3861),
    [anon_sym_using] = ACTIONS(3861),
    [anon_sym_unsafe] = ACTIONS(3861),
    [anon_sym_static] = ACTIONS(3861),
    [anon_sym_LBRACK] = ACTIONS(3863),
    [anon_sym_LPAREN] = ACTIONS(3863),
    [anon_sym_return] = ACTIONS(3861),
    [anon_sym_namespace] = ACTIONS(3861),
    [anon_sym_class] = ACTIONS(3861),
    [anon_sym_ref] = ACTIONS(3861),
    [anon_sym_struct] = ACTIONS(3861),
    [anon_sym_enum] = ACTIONS(3861),
    [anon_sym_LBRACE] = ACTIONS(3863),
    [anon_sym_interface] = ACTIONS(3861),
    [anon_sym_delegate] = ACTIONS(3861),
    [anon_sym_record] = ACTIONS(3861),
    [anon_sym_abstract] = ACTIONS(3861),
    [anon_sym_async] = ACTIONS(3861),
    [anon_sym_const] = ACTIONS(3861),
    [anon_sym_file] = ACTIONS(3861),
    [anon_sym_fixed] = ACTIONS(3861),
    [anon_sym_internal] = ACTIONS(3861),
    [anon_sym_new] = ACTIONS(3861),
    [anon_sym_override] = ACTIONS(3861),
    [anon_sym_partial] = ACTIONS(3861),
    [anon_sym_private] = ACTIONS(3861),
    [anon_sym_protected] = ACTIONS(3861),
    [anon_sym_public] = ACTIONS(3861),
    [anon_sym_readonly] = ACTIONS(3861),
    [anon_sym_required] = ACTIONS(3861),
    [anon_sym_sealed] = ACTIONS(3861),
    [anon_sym_virtual] = ACTIONS(3861),
    [anon_sym_volatile] = ACTIONS(3861),
    [anon_sym_where] = ACTIONS(3861),
    [anon_sym_notnull] = ACTIONS(3861),
    [anon_sym_unmanaged] = ACTIONS(3861),
    [anon_sym_checked] = ACTIONS(3861),
    [anon_sym_BANG] = ACTIONS(3863),
    [anon_sym_TILDE] = ACTIONS(3863),
    [anon_sym_PLUS_PLUS] = ACTIONS(3863),
    [anon_sym_DASH_DASH] = ACTIONS(3863),
    [anon_sym_true] = ACTIONS(3861),
    [anon_sym_false] = ACTIONS(3861),
    [anon_sym_PLUS] = ACTIONS(3861),
    [anon_sym_DASH] = ACTIONS(3861),
    [anon_sym_STAR] = ACTIONS(3863),
    [anon_sym_CARET] = ACTIONS(3863),
    [anon_sym_AMP] = ACTIONS(3863),
    [anon_sym_this] = ACTIONS(3861),
    [anon_sym_scoped] = ACTIONS(3861),
    [anon_sym_base] = ACTIONS(3861),
    [anon_sym_var] = ACTIONS(3861),
    [sym_predefined_type] = ACTIONS(3861),
    [anon_sym_break] = ACTIONS(3861),
    [anon_sym_unchecked] = ACTIONS(3861),
    [anon_sym_continue] = ACTIONS(3861),
    [anon_sym_do] = ACTIONS(3861),
    [anon_sym_while] = ACTIONS(3861),
    [anon_sym_for] = ACTIONS(3861),
    [anon_sym_lock] = ACTIONS(3861),
    [anon_sym_yield] = ACTIONS(3861),
    [anon_sym_switch] = ACTIONS(3861),
    [anon_sym_default] = ACTIONS(3861),
    [anon_sym_throw] = ACTIONS(3861),
    [anon_sym_try] = ACTIONS(3861),
    [anon_sym_when] = ACTIONS(3861),
    [anon_sym_await] = ACTIONS(3861),
    [anon_sym_foreach] = ACTIONS(3861),
    [anon_sym_goto] = ACTIONS(3861),
    [anon_sym_if] = ACTIONS(3861),
    [anon_sym_DOT_DOT] = ACTIONS(3863),
    [anon_sym_from] = ACTIONS(3861),
    [anon_sym_into] = ACTIONS(3861),
    [anon_sym_join] = ACTIONS(3861),
    [anon_sym_on] = ACTIONS(3861),
    [anon_sym_equals] = ACTIONS(3861),
    [anon_sym_let] = ACTIONS(3861),
    [anon_sym_orderby] = ACTIONS(3861),
    [anon_sym_ascending] = ACTIONS(3861),
    [anon_sym_descending] = ACTIONS(3861),
    [anon_sym_group] = ACTIONS(3861),
    [anon_sym_by] = ACTIONS(3861),
    [anon_sym_select] = ACTIONS(3861),
    [anon_sym_stackalloc] = ACTIONS(3861),
    [anon_sym_sizeof] = ACTIONS(3861),
    [anon_sym_typeof] = ACTIONS(3861),
    [anon_sym___makeref] = ACTIONS(3861),
    [anon_sym___reftype] = ACTIONS(3861),
    [anon_sym___refvalue] = ACTIONS(3861),
    [sym_null_literal] = ACTIONS(3861),
    [anon_sym_SQUOTE] = ACTIONS(3863),
    [sym_integer_literal] = ACTIONS(3861),
    [sym_real_literal] = ACTIONS(3863),
    [anon_sym_DQUOTE] = ACTIONS(3863),
    [sym_verbatim_string_literal] = ACTIONS(3863),
    [aux_sym_preproc_if_token1] = ACTIONS(3863),
    [aux_sym_preproc_if_token3] = ACTIONS(3863),
    [aux_sym_preproc_else_token1] = ACTIONS(3863),
    [aux_sym_preproc_elif_token1] = ACTIONS(3863),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3863),
    [sym_interpolation_verbatim_start] = ACTIONS(3863),
    [sym_interpolation_raw_start] = ACTIONS(3863),
    [sym_raw_string_start] = ACTIONS(3863),
  },
  [2422] = {
    [sym_using_directive] = STATE(3324),
    [sym_attribute_list] = STATE(3740),
    [sym_namespace_declaration] = STATE(3324),
    [sym_class_declaration] = STATE(3324),
    [sym_struct_declaration] = STATE(3324),
    [sym_enum_declaration] = STATE(3324),
    [sym_interface_declaration] = STATE(3324),
    [sym_delegate_declaration] = STATE(3324),
    [sym_record_declaration] = STATE(3324),
    [sym_modifier] = STATE(3807),
    [sym_operator_declaration] = STATE(3324),
    [sym_conversion_operator_declaration] = STATE(3324),
    [sym_declaration] = STATE(3327),
    [sym_field_declaration] = STATE(3324),
    [sym_constructor_declaration] = STATE(3324),
    [sym_destructor_declaration] = STATE(3324),
    [sym_method_declaration] = STATE(3324),
    [sym_event_declaration] = STATE(3324),
    [sym_event_field_declaration] = STATE(3324),
    [sym_indexer_declaration] = STATE(3324),
    [sym_property_declaration] = STATE(3324),
    [sym_variable_declaration] = STATE(8996),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(6582),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(6750),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_if] = STATE(3324),
    [sym_preproc_region] = STATE(2422),
    [sym_preproc_endregion] = STATE(2422),
    [sym_preproc_line] = STATE(2422),
    [sym_preproc_pragma] = STATE(2422),
    [sym_preproc_nullable] = STATE(2422),
    [sym_preproc_error] = STATE(2422),
    [sym_preproc_warning] = STATE(2422),
    [sym_preproc_define] = STATE(2422),
    [sym_preproc_undef] = STATE(2422),
    [aux_sym_class_declaration_repeat1] = STATE(2781),
    [aux_sym_class_declaration_repeat2] = STATE(2857),
    [aux_sym_declaration_list_repeat1] = STATE(2422),
    [sym__identifier_token] = ACTIONS(3865),
    [anon_sym_extern] = ACTIONS(3868),
    [anon_sym_alias] = ACTIONS(3871),
    [anon_sym_global] = ACTIONS(3874),
    [anon_sym_using] = ACTIONS(3877),
    [anon_sym_unsafe] = ACTIONS(3880),
    [anon_sym_static] = ACTIONS(3880),
    [anon_sym_LBRACK] = ACTIONS(3883),
    [anon_sym_LPAREN] = ACTIONS(3886),
    [anon_sym_event] = ACTIONS(3889),
    [anon_sym_namespace] = ACTIONS(3892),
    [anon_sym_class] = ACTIONS(3895),
    [anon_sym_ref] = ACTIONS(3898),
    [anon_sym_struct] = ACTIONS(3901),
    [anon_sym_enum] = ACTIONS(3904),
    [anon_sym_RBRACE] = ACTIONS(3907),
    [anon_sym_interface] = ACTIONS(3909),
    [anon_sym_delegate] = ACTIONS(3912),
    [anon_sym_record] = ACTIONS(3915),
    [anon_sym_abstract] = ACTIONS(3880),
    [anon_sym_async] = ACTIONS(3880),
    [anon_sym_const] = ACTIONS(3880),
    [anon_sym_file] = ACTIONS(3918),
    [anon_sym_fixed] = ACTIONS(3880),
    [anon_sym_internal] = ACTIONS(3880),
    [anon_sym_new] = ACTIONS(3880),
    [anon_sym_override] = ACTIONS(3880),
    [anon_sym_partial] = ACTIONS(3880),
    [anon_sym_private] = ACTIONS(3880),
    [anon_sym_protected] = ACTIONS(3880),
    [anon_sym_public] = ACTIONS(3880),
    [anon_sym_readonly] = ACTIONS(3880),
    [anon_sym_required] = ACTIONS(3880),
    [anon_sym_sealed] = ACTIONS(3880),
    [anon_sym_virtual] = ACTIONS(3880),
    [anon_sym_volatile] = ACTIONS(3880),
    [anon_sym_where] = ACTIONS(3871),
    [anon_sym_notnull] = ACTIONS(3871),
    [anon_sym_unmanaged] = ACTIONS(3871),
    [anon_sym_TILDE] = ACTIONS(3921),
    [anon_sym_implicit] = ACTIONS(3924),
    [anon_sym_explicit] = ACTIONS(3924),
    [anon_sym_scoped] = ACTIONS(3927),
    [anon_sym_var] = ACTIONS(3930),
    [sym_predefined_type] = ACTIONS(3933),
    [anon_sym_yield] = ACTIONS(3871),
    [anon_sym_when] = ACTIONS(3871),
    [anon_sym_from] = ACTIONS(3871),
    [anon_sym_into] = ACTIONS(3871),
    [anon_sym_join] = ACTIONS(3871),
    [anon_sym_on] = ACTIONS(3871),
    [anon_sym_equals] = ACTIONS(3871),
    [anon_sym_let] = ACTIONS(3871),
    [anon_sym_orderby] = ACTIONS(3871),
    [anon_sym_ascending] = ACTIONS(3871),
    [anon_sym_descending] = ACTIONS(3871),
    [anon_sym_group] = ACTIONS(3871),
    [anon_sym_by] = ACTIONS(3871),
    [anon_sym_select] = ACTIONS(3871),
    [aux_sym_preproc_if_token1] = ACTIONS(3936),
    [aux_sym_preproc_if_token3] = ACTIONS(3907),
    [aux_sym_preproc_else_token1] = ACTIONS(3907),
    [aux_sym_preproc_elif_token1] = ACTIONS(3907),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2423] = {
    [sym_preproc_region] = STATE(2423),
    [sym_preproc_endregion] = STATE(2423),
    [sym_preproc_line] = STATE(2423),
    [sym_preproc_pragma] = STATE(2423),
    [sym_preproc_nullable] = STATE(2423),
    [sym_preproc_error] = STATE(2423),
    [sym_preproc_warning] = STATE(2423),
    [sym_preproc_define] = STATE(2423),
    [sym_preproc_undef] = STATE(2423),
    [sym__identifier_token] = ACTIONS(3939),
    [anon_sym_extern] = ACTIONS(3939),
    [anon_sym_alias] = ACTIONS(3939),
    [anon_sym_SEMI] = ACTIONS(3941),
    [anon_sym_global] = ACTIONS(3939),
    [anon_sym_using] = ACTIONS(3939),
    [anon_sym_unsafe] = ACTIONS(3939),
    [anon_sym_static] = ACTIONS(3939),
    [anon_sym_LBRACK] = ACTIONS(3941),
    [anon_sym_LPAREN] = ACTIONS(3941),
    [anon_sym_return] = ACTIONS(3939),
    [anon_sym_namespace] = ACTIONS(3939),
    [anon_sym_class] = ACTIONS(3939),
    [anon_sym_ref] = ACTIONS(3939),
    [anon_sym_struct] = ACTIONS(3939),
    [anon_sym_enum] = ACTIONS(3939),
    [anon_sym_LBRACE] = ACTIONS(3941),
    [anon_sym_interface] = ACTIONS(3939),
    [anon_sym_delegate] = ACTIONS(3939),
    [anon_sym_record] = ACTIONS(3939),
    [anon_sym_abstract] = ACTIONS(3939),
    [anon_sym_async] = ACTIONS(3939),
    [anon_sym_const] = ACTIONS(3939),
    [anon_sym_file] = ACTIONS(3939),
    [anon_sym_fixed] = ACTIONS(3939),
    [anon_sym_internal] = ACTIONS(3939),
    [anon_sym_new] = ACTIONS(3939),
    [anon_sym_override] = ACTIONS(3939),
    [anon_sym_partial] = ACTIONS(3939),
    [anon_sym_private] = ACTIONS(3939),
    [anon_sym_protected] = ACTIONS(3939),
    [anon_sym_public] = ACTIONS(3939),
    [anon_sym_readonly] = ACTIONS(3939),
    [anon_sym_required] = ACTIONS(3939),
    [anon_sym_sealed] = ACTIONS(3939),
    [anon_sym_virtual] = ACTIONS(3939),
    [anon_sym_volatile] = ACTIONS(3939),
    [anon_sym_where] = ACTIONS(3939),
    [anon_sym_notnull] = ACTIONS(3939),
    [anon_sym_unmanaged] = ACTIONS(3939),
    [anon_sym_checked] = ACTIONS(3939),
    [anon_sym_BANG] = ACTIONS(3941),
    [anon_sym_TILDE] = ACTIONS(3941),
    [anon_sym_PLUS_PLUS] = ACTIONS(3941),
    [anon_sym_DASH_DASH] = ACTIONS(3941),
    [anon_sym_true] = ACTIONS(3939),
    [anon_sym_false] = ACTIONS(3939),
    [anon_sym_PLUS] = ACTIONS(3939),
    [anon_sym_DASH] = ACTIONS(3939),
    [anon_sym_STAR] = ACTIONS(3941),
    [anon_sym_CARET] = ACTIONS(3941),
    [anon_sym_AMP] = ACTIONS(3941),
    [anon_sym_this] = ACTIONS(3939),
    [anon_sym_scoped] = ACTIONS(3939),
    [anon_sym_base] = ACTIONS(3939),
    [anon_sym_var] = ACTIONS(3939),
    [sym_predefined_type] = ACTIONS(3939),
    [anon_sym_break] = ACTIONS(3939),
    [anon_sym_unchecked] = ACTIONS(3939),
    [anon_sym_continue] = ACTIONS(3939),
    [anon_sym_do] = ACTIONS(3939),
    [anon_sym_while] = ACTIONS(3939),
    [anon_sym_for] = ACTIONS(3939),
    [anon_sym_lock] = ACTIONS(3939),
    [anon_sym_yield] = ACTIONS(3939),
    [anon_sym_switch] = ACTIONS(3939),
    [anon_sym_default] = ACTIONS(3939),
    [anon_sym_throw] = ACTIONS(3939),
    [anon_sym_try] = ACTIONS(3939),
    [anon_sym_when] = ACTIONS(3939),
    [anon_sym_await] = ACTIONS(3939),
    [anon_sym_foreach] = ACTIONS(3939),
    [anon_sym_goto] = ACTIONS(3939),
    [anon_sym_if] = ACTIONS(3939),
    [anon_sym_DOT_DOT] = ACTIONS(3941),
    [anon_sym_from] = ACTIONS(3939),
    [anon_sym_into] = ACTIONS(3939),
    [anon_sym_join] = ACTIONS(3939),
    [anon_sym_on] = ACTIONS(3939),
    [anon_sym_equals] = ACTIONS(3939),
    [anon_sym_let] = ACTIONS(3939),
    [anon_sym_orderby] = ACTIONS(3939),
    [anon_sym_ascending] = ACTIONS(3939),
    [anon_sym_descending] = ACTIONS(3939),
    [anon_sym_group] = ACTIONS(3939),
    [anon_sym_by] = ACTIONS(3939),
    [anon_sym_select] = ACTIONS(3939),
    [anon_sym_stackalloc] = ACTIONS(3939),
    [anon_sym_sizeof] = ACTIONS(3939),
    [anon_sym_typeof] = ACTIONS(3939),
    [anon_sym___makeref] = ACTIONS(3939),
    [anon_sym___reftype] = ACTIONS(3939),
    [anon_sym___refvalue] = ACTIONS(3939),
    [sym_null_literal] = ACTIONS(3939),
    [anon_sym_SQUOTE] = ACTIONS(3941),
    [sym_integer_literal] = ACTIONS(3939),
    [sym_real_literal] = ACTIONS(3941),
    [anon_sym_DQUOTE] = ACTIONS(3941),
    [sym_verbatim_string_literal] = ACTIONS(3941),
    [aux_sym_preproc_if_token1] = ACTIONS(3941),
    [aux_sym_preproc_if_token3] = ACTIONS(3941),
    [aux_sym_preproc_else_token1] = ACTIONS(3941),
    [aux_sym_preproc_elif_token1] = ACTIONS(3941),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3941),
    [sym_interpolation_verbatim_start] = ACTIONS(3941),
    [sym_interpolation_raw_start] = ACTIONS(3941),
    [sym_raw_string_start] = ACTIONS(3941),
  },
  [2424] = {
    [sym_preproc_region] = STATE(2424),
    [sym_preproc_endregion] = STATE(2424),
    [sym_preproc_line] = STATE(2424),
    [sym_preproc_pragma] = STATE(2424),
    [sym_preproc_nullable] = STATE(2424),
    [sym_preproc_error] = STATE(2424),
    [sym_preproc_warning] = STATE(2424),
    [sym_preproc_define] = STATE(2424),
    [sym_preproc_undef] = STATE(2424),
    [sym__identifier_token] = ACTIONS(3943),
    [anon_sym_extern] = ACTIONS(3943),
    [anon_sym_alias] = ACTIONS(3943),
    [anon_sym_SEMI] = ACTIONS(3945),
    [anon_sym_global] = ACTIONS(3943),
    [anon_sym_using] = ACTIONS(3943),
    [anon_sym_unsafe] = ACTIONS(3943),
    [anon_sym_static] = ACTIONS(3943),
    [anon_sym_LBRACK] = ACTIONS(3945),
    [anon_sym_LPAREN] = ACTIONS(3945),
    [anon_sym_return] = ACTIONS(3943),
    [anon_sym_namespace] = ACTIONS(3943),
    [anon_sym_class] = ACTIONS(3943),
    [anon_sym_ref] = ACTIONS(3943),
    [anon_sym_struct] = ACTIONS(3943),
    [anon_sym_enum] = ACTIONS(3943),
    [anon_sym_LBRACE] = ACTIONS(3945),
    [anon_sym_interface] = ACTIONS(3943),
    [anon_sym_delegate] = ACTIONS(3943),
    [anon_sym_record] = ACTIONS(3943),
    [anon_sym_abstract] = ACTIONS(3943),
    [anon_sym_async] = ACTIONS(3943),
    [anon_sym_const] = ACTIONS(3943),
    [anon_sym_file] = ACTIONS(3943),
    [anon_sym_fixed] = ACTIONS(3943),
    [anon_sym_internal] = ACTIONS(3943),
    [anon_sym_new] = ACTIONS(3943),
    [anon_sym_override] = ACTIONS(3943),
    [anon_sym_partial] = ACTIONS(3943),
    [anon_sym_private] = ACTIONS(3943),
    [anon_sym_protected] = ACTIONS(3943),
    [anon_sym_public] = ACTIONS(3943),
    [anon_sym_readonly] = ACTIONS(3943),
    [anon_sym_required] = ACTIONS(3943),
    [anon_sym_sealed] = ACTIONS(3943),
    [anon_sym_virtual] = ACTIONS(3943),
    [anon_sym_volatile] = ACTIONS(3943),
    [anon_sym_where] = ACTIONS(3943),
    [anon_sym_notnull] = ACTIONS(3943),
    [anon_sym_unmanaged] = ACTIONS(3943),
    [anon_sym_checked] = ACTIONS(3943),
    [anon_sym_BANG] = ACTIONS(3945),
    [anon_sym_TILDE] = ACTIONS(3945),
    [anon_sym_PLUS_PLUS] = ACTIONS(3945),
    [anon_sym_DASH_DASH] = ACTIONS(3945),
    [anon_sym_true] = ACTIONS(3943),
    [anon_sym_false] = ACTIONS(3943),
    [anon_sym_PLUS] = ACTIONS(3943),
    [anon_sym_DASH] = ACTIONS(3943),
    [anon_sym_STAR] = ACTIONS(3945),
    [anon_sym_CARET] = ACTIONS(3945),
    [anon_sym_AMP] = ACTIONS(3945),
    [anon_sym_this] = ACTIONS(3943),
    [anon_sym_scoped] = ACTIONS(3943),
    [anon_sym_base] = ACTIONS(3943),
    [anon_sym_var] = ACTIONS(3943),
    [sym_predefined_type] = ACTIONS(3943),
    [anon_sym_break] = ACTIONS(3943),
    [anon_sym_unchecked] = ACTIONS(3943),
    [anon_sym_continue] = ACTIONS(3943),
    [anon_sym_do] = ACTIONS(3943),
    [anon_sym_while] = ACTIONS(3943),
    [anon_sym_for] = ACTIONS(3943),
    [anon_sym_lock] = ACTIONS(3943),
    [anon_sym_yield] = ACTIONS(3943),
    [anon_sym_switch] = ACTIONS(3943),
    [anon_sym_default] = ACTIONS(3943),
    [anon_sym_throw] = ACTIONS(3943),
    [anon_sym_try] = ACTIONS(3943),
    [anon_sym_when] = ACTIONS(3943),
    [anon_sym_await] = ACTIONS(3943),
    [anon_sym_foreach] = ACTIONS(3943),
    [anon_sym_goto] = ACTIONS(3943),
    [anon_sym_if] = ACTIONS(3943),
    [anon_sym_DOT_DOT] = ACTIONS(3945),
    [anon_sym_from] = ACTIONS(3943),
    [anon_sym_into] = ACTIONS(3943),
    [anon_sym_join] = ACTIONS(3943),
    [anon_sym_on] = ACTIONS(3943),
    [anon_sym_equals] = ACTIONS(3943),
    [anon_sym_let] = ACTIONS(3943),
    [anon_sym_orderby] = ACTIONS(3943),
    [anon_sym_ascending] = ACTIONS(3943),
    [anon_sym_descending] = ACTIONS(3943),
    [anon_sym_group] = ACTIONS(3943),
    [anon_sym_by] = ACTIONS(3943),
    [anon_sym_select] = ACTIONS(3943),
    [anon_sym_stackalloc] = ACTIONS(3943),
    [anon_sym_sizeof] = ACTIONS(3943),
    [anon_sym_typeof] = ACTIONS(3943),
    [anon_sym___makeref] = ACTIONS(3943),
    [anon_sym___reftype] = ACTIONS(3943),
    [anon_sym___refvalue] = ACTIONS(3943),
    [sym_null_literal] = ACTIONS(3943),
    [anon_sym_SQUOTE] = ACTIONS(3945),
    [sym_integer_literal] = ACTIONS(3943),
    [sym_real_literal] = ACTIONS(3945),
    [anon_sym_DQUOTE] = ACTIONS(3945),
    [sym_verbatim_string_literal] = ACTIONS(3945),
    [aux_sym_preproc_if_token1] = ACTIONS(3945),
    [aux_sym_preproc_if_token3] = ACTIONS(3945),
    [aux_sym_preproc_else_token1] = ACTIONS(3945),
    [aux_sym_preproc_elif_token1] = ACTIONS(3945),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3945),
    [sym_interpolation_verbatim_start] = ACTIONS(3945),
    [sym_interpolation_raw_start] = ACTIONS(3945),
    [sym_raw_string_start] = ACTIONS(3945),
  },
  [2425] = {
    [sym_preproc_region] = STATE(2425),
    [sym_preproc_endregion] = STATE(2425),
    [sym_preproc_line] = STATE(2425),
    [sym_preproc_pragma] = STATE(2425),
    [sym_preproc_nullable] = STATE(2425),
    [sym_preproc_error] = STATE(2425),
    [sym_preproc_warning] = STATE(2425),
    [sym_preproc_define] = STATE(2425),
    [sym_preproc_undef] = STATE(2425),
    [sym__identifier_token] = ACTIONS(3947),
    [anon_sym_extern] = ACTIONS(3947),
    [anon_sym_alias] = ACTIONS(3947),
    [anon_sym_SEMI] = ACTIONS(3949),
    [anon_sym_global] = ACTIONS(3947),
    [anon_sym_using] = ACTIONS(3947),
    [anon_sym_unsafe] = ACTIONS(3947),
    [anon_sym_static] = ACTIONS(3947),
    [anon_sym_LBRACK] = ACTIONS(3949),
    [anon_sym_LPAREN] = ACTIONS(3949),
    [anon_sym_return] = ACTIONS(3947),
    [anon_sym_namespace] = ACTIONS(3947),
    [anon_sym_class] = ACTIONS(3947),
    [anon_sym_ref] = ACTIONS(3947),
    [anon_sym_struct] = ACTIONS(3947),
    [anon_sym_enum] = ACTIONS(3947),
    [anon_sym_LBRACE] = ACTIONS(3949),
    [anon_sym_interface] = ACTIONS(3947),
    [anon_sym_delegate] = ACTIONS(3947),
    [anon_sym_record] = ACTIONS(3947),
    [anon_sym_abstract] = ACTIONS(3947),
    [anon_sym_async] = ACTIONS(3947),
    [anon_sym_const] = ACTIONS(3947),
    [anon_sym_file] = ACTIONS(3947),
    [anon_sym_fixed] = ACTIONS(3947),
    [anon_sym_internal] = ACTIONS(3947),
    [anon_sym_new] = ACTIONS(3947),
    [anon_sym_override] = ACTIONS(3947),
    [anon_sym_partial] = ACTIONS(3947),
    [anon_sym_private] = ACTIONS(3947),
    [anon_sym_protected] = ACTIONS(3947),
    [anon_sym_public] = ACTIONS(3947),
    [anon_sym_readonly] = ACTIONS(3947),
    [anon_sym_required] = ACTIONS(3947),
    [anon_sym_sealed] = ACTIONS(3947),
    [anon_sym_virtual] = ACTIONS(3947),
    [anon_sym_volatile] = ACTIONS(3947),
    [anon_sym_where] = ACTIONS(3947),
    [anon_sym_notnull] = ACTIONS(3947),
    [anon_sym_unmanaged] = ACTIONS(3947),
    [anon_sym_checked] = ACTIONS(3947),
    [anon_sym_BANG] = ACTIONS(3949),
    [anon_sym_TILDE] = ACTIONS(3949),
    [anon_sym_PLUS_PLUS] = ACTIONS(3949),
    [anon_sym_DASH_DASH] = ACTIONS(3949),
    [anon_sym_true] = ACTIONS(3947),
    [anon_sym_false] = ACTIONS(3947),
    [anon_sym_PLUS] = ACTIONS(3947),
    [anon_sym_DASH] = ACTIONS(3947),
    [anon_sym_STAR] = ACTIONS(3949),
    [anon_sym_CARET] = ACTIONS(3949),
    [anon_sym_AMP] = ACTIONS(3949),
    [anon_sym_this] = ACTIONS(3947),
    [anon_sym_scoped] = ACTIONS(3947),
    [anon_sym_base] = ACTIONS(3947),
    [anon_sym_var] = ACTIONS(3947),
    [sym_predefined_type] = ACTIONS(3947),
    [anon_sym_break] = ACTIONS(3947),
    [anon_sym_unchecked] = ACTIONS(3947),
    [anon_sym_continue] = ACTIONS(3947),
    [anon_sym_do] = ACTIONS(3947),
    [anon_sym_while] = ACTIONS(3947),
    [anon_sym_for] = ACTIONS(3947),
    [anon_sym_lock] = ACTIONS(3947),
    [anon_sym_yield] = ACTIONS(3947),
    [anon_sym_switch] = ACTIONS(3947),
    [anon_sym_default] = ACTIONS(3947),
    [anon_sym_throw] = ACTIONS(3947),
    [anon_sym_try] = ACTIONS(3947),
    [anon_sym_when] = ACTIONS(3947),
    [anon_sym_await] = ACTIONS(3947),
    [anon_sym_foreach] = ACTIONS(3947),
    [anon_sym_goto] = ACTIONS(3947),
    [anon_sym_if] = ACTIONS(3947),
    [anon_sym_DOT_DOT] = ACTIONS(3949),
    [anon_sym_from] = ACTIONS(3947),
    [anon_sym_into] = ACTIONS(3947),
    [anon_sym_join] = ACTIONS(3947),
    [anon_sym_on] = ACTIONS(3947),
    [anon_sym_equals] = ACTIONS(3947),
    [anon_sym_let] = ACTIONS(3947),
    [anon_sym_orderby] = ACTIONS(3947),
    [anon_sym_ascending] = ACTIONS(3947),
    [anon_sym_descending] = ACTIONS(3947),
    [anon_sym_group] = ACTIONS(3947),
    [anon_sym_by] = ACTIONS(3947),
    [anon_sym_select] = ACTIONS(3947),
    [anon_sym_stackalloc] = ACTIONS(3947),
    [anon_sym_sizeof] = ACTIONS(3947),
    [anon_sym_typeof] = ACTIONS(3947),
    [anon_sym___makeref] = ACTIONS(3947),
    [anon_sym___reftype] = ACTIONS(3947),
    [anon_sym___refvalue] = ACTIONS(3947),
    [sym_null_literal] = ACTIONS(3947),
    [anon_sym_SQUOTE] = ACTIONS(3949),
    [sym_integer_literal] = ACTIONS(3947),
    [sym_real_literal] = ACTIONS(3949),
    [anon_sym_DQUOTE] = ACTIONS(3949),
    [sym_verbatim_string_literal] = ACTIONS(3949),
    [aux_sym_preproc_if_token1] = ACTIONS(3949),
    [aux_sym_preproc_if_token3] = ACTIONS(3949),
    [aux_sym_preproc_else_token1] = ACTIONS(3949),
    [aux_sym_preproc_elif_token1] = ACTIONS(3949),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3949),
    [sym_interpolation_verbatim_start] = ACTIONS(3949),
    [sym_interpolation_raw_start] = ACTIONS(3949),
    [sym_raw_string_start] = ACTIONS(3949),
  },
  [2426] = {
    [sym_preproc_region] = STATE(2426),
    [sym_preproc_endregion] = STATE(2426),
    [sym_preproc_line] = STATE(2426),
    [sym_preproc_pragma] = STATE(2426),
    [sym_preproc_nullable] = STATE(2426),
    [sym_preproc_error] = STATE(2426),
    [sym_preproc_warning] = STATE(2426),
    [sym_preproc_define] = STATE(2426),
    [sym_preproc_undef] = STATE(2426),
    [sym__identifier_token] = ACTIONS(3951),
    [anon_sym_extern] = ACTIONS(3951),
    [anon_sym_alias] = ACTIONS(3951),
    [anon_sym_SEMI] = ACTIONS(3953),
    [anon_sym_global] = ACTIONS(3951),
    [anon_sym_using] = ACTIONS(3951),
    [anon_sym_unsafe] = ACTIONS(3951),
    [anon_sym_static] = ACTIONS(3951),
    [anon_sym_LBRACK] = ACTIONS(3953),
    [anon_sym_LPAREN] = ACTIONS(3953),
    [anon_sym_return] = ACTIONS(3951),
    [anon_sym_namespace] = ACTIONS(3951),
    [anon_sym_class] = ACTIONS(3951),
    [anon_sym_ref] = ACTIONS(3951),
    [anon_sym_struct] = ACTIONS(3951),
    [anon_sym_enum] = ACTIONS(3951),
    [anon_sym_LBRACE] = ACTIONS(3953),
    [anon_sym_interface] = ACTIONS(3951),
    [anon_sym_delegate] = ACTIONS(3951),
    [anon_sym_record] = ACTIONS(3951),
    [anon_sym_abstract] = ACTIONS(3951),
    [anon_sym_async] = ACTIONS(3951),
    [anon_sym_const] = ACTIONS(3951),
    [anon_sym_file] = ACTIONS(3951),
    [anon_sym_fixed] = ACTIONS(3951),
    [anon_sym_internal] = ACTIONS(3951),
    [anon_sym_new] = ACTIONS(3951),
    [anon_sym_override] = ACTIONS(3951),
    [anon_sym_partial] = ACTIONS(3951),
    [anon_sym_private] = ACTIONS(3951),
    [anon_sym_protected] = ACTIONS(3951),
    [anon_sym_public] = ACTIONS(3951),
    [anon_sym_readonly] = ACTIONS(3951),
    [anon_sym_required] = ACTIONS(3951),
    [anon_sym_sealed] = ACTIONS(3951),
    [anon_sym_virtual] = ACTIONS(3951),
    [anon_sym_volatile] = ACTIONS(3951),
    [anon_sym_where] = ACTIONS(3951),
    [anon_sym_notnull] = ACTIONS(3951),
    [anon_sym_unmanaged] = ACTIONS(3951),
    [anon_sym_checked] = ACTIONS(3951),
    [anon_sym_BANG] = ACTIONS(3953),
    [anon_sym_TILDE] = ACTIONS(3953),
    [anon_sym_PLUS_PLUS] = ACTIONS(3953),
    [anon_sym_DASH_DASH] = ACTIONS(3953),
    [anon_sym_true] = ACTIONS(3951),
    [anon_sym_false] = ACTIONS(3951),
    [anon_sym_PLUS] = ACTIONS(3951),
    [anon_sym_DASH] = ACTIONS(3951),
    [anon_sym_STAR] = ACTIONS(3953),
    [anon_sym_CARET] = ACTIONS(3953),
    [anon_sym_AMP] = ACTIONS(3953),
    [anon_sym_this] = ACTIONS(3951),
    [anon_sym_scoped] = ACTIONS(3951),
    [anon_sym_base] = ACTIONS(3951),
    [anon_sym_var] = ACTIONS(3951),
    [sym_predefined_type] = ACTIONS(3951),
    [anon_sym_break] = ACTIONS(3951),
    [anon_sym_unchecked] = ACTIONS(3951),
    [anon_sym_continue] = ACTIONS(3951),
    [anon_sym_do] = ACTIONS(3951),
    [anon_sym_while] = ACTIONS(3951),
    [anon_sym_for] = ACTIONS(3951),
    [anon_sym_lock] = ACTIONS(3951),
    [anon_sym_yield] = ACTIONS(3951),
    [anon_sym_switch] = ACTIONS(3951),
    [anon_sym_default] = ACTIONS(3951),
    [anon_sym_throw] = ACTIONS(3951),
    [anon_sym_try] = ACTIONS(3951),
    [anon_sym_when] = ACTIONS(3951),
    [anon_sym_await] = ACTIONS(3951),
    [anon_sym_foreach] = ACTIONS(3951),
    [anon_sym_goto] = ACTIONS(3951),
    [anon_sym_if] = ACTIONS(3951),
    [anon_sym_DOT_DOT] = ACTIONS(3953),
    [anon_sym_from] = ACTIONS(3951),
    [anon_sym_into] = ACTIONS(3951),
    [anon_sym_join] = ACTIONS(3951),
    [anon_sym_on] = ACTIONS(3951),
    [anon_sym_equals] = ACTIONS(3951),
    [anon_sym_let] = ACTIONS(3951),
    [anon_sym_orderby] = ACTIONS(3951),
    [anon_sym_ascending] = ACTIONS(3951),
    [anon_sym_descending] = ACTIONS(3951),
    [anon_sym_group] = ACTIONS(3951),
    [anon_sym_by] = ACTIONS(3951),
    [anon_sym_select] = ACTIONS(3951),
    [anon_sym_stackalloc] = ACTIONS(3951),
    [anon_sym_sizeof] = ACTIONS(3951),
    [anon_sym_typeof] = ACTIONS(3951),
    [anon_sym___makeref] = ACTIONS(3951),
    [anon_sym___reftype] = ACTIONS(3951),
    [anon_sym___refvalue] = ACTIONS(3951),
    [sym_null_literal] = ACTIONS(3951),
    [anon_sym_SQUOTE] = ACTIONS(3953),
    [sym_integer_literal] = ACTIONS(3951),
    [sym_real_literal] = ACTIONS(3953),
    [anon_sym_DQUOTE] = ACTIONS(3953),
    [sym_verbatim_string_literal] = ACTIONS(3953),
    [aux_sym_preproc_if_token1] = ACTIONS(3953),
    [aux_sym_preproc_if_token3] = ACTIONS(3953),
    [aux_sym_preproc_else_token1] = ACTIONS(3953),
    [aux_sym_preproc_elif_token1] = ACTIONS(3953),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3953),
    [sym_interpolation_verbatim_start] = ACTIONS(3953),
    [sym_interpolation_raw_start] = ACTIONS(3953),
    [sym_raw_string_start] = ACTIONS(3953),
  },
  [2427] = {
    [sym_preproc_region] = STATE(2427),
    [sym_preproc_endregion] = STATE(2427),
    [sym_preproc_line] = STATE(2427),
    [sym_preproc_pragma] = STATE(2427),
    [sym_preproc_nullable] = STATE(2427),
    [sym_preproc_error] = STATE(2427),
    [sym_preproc_warning] = STATE(2427),
    [sym_preproc_define] = STATE(2427),
    [sym_preproc_undef] = STATE(2427),
    [sym__identifier_token] = ACTIONS(3955),
    [anon_sym_extern] = ACTIONS(3955),
    [anon_sym_alias] = ACTIONS(3955),
    [anon_sym_SEMI] = ACTIONS(3957),
    [anon_sym_global] = ACTIONS(3955),
    [anon_sym_using] = ACTIONS(3955),
    [anon_sym_unsafe] = ACTIONS(3955),
    [anon_sym_static] = ACTIONS(3955),
    [anon_sym_LBRACK] = ACTIONS(3957),
    [anon_sym_LPAREN] = ACTIONS(3957),
    [anon_sym_return] = ACTIONS(3955),
    [anon_sym_namespace] = ACTIONS(3955),
    [anon_sym_class] = ACTIONS(3955),
    [anon_sym_ref] = ACTIONS(3955),
    [anon_sym_struct] = ACTIONS(3955),
    [anon_sym_enum] = ACTIONS(3955),
    [anon_sym_LBRACE] = ACTIONS(3957),
    [anon_sym_interface] = ACTIONS(3955),
    [anon_sym_delegate] = ACTIONS(3955),
    [anon_sym_record] = ACTIONS(3955),
    [anon_sym_abstract] = ACTIONS(3955),
    [anon_sym_async] = ACTIONS(3955),
    [anon_sym_const] = ACTIONS(3955),
    [anon_sym_file] = ACTIONS(3955),
    [anon_sym_fixed] = ACTIONS(3955),
    [anon_sym_internal] = ACTIONS(3955),
    [anon_sym_new] = ACTIONS(3955),
    [anon_sym_override] = ACTIONS(3955),
    [anon_sym_partial] = ACTIONS(3955),
    [anon_sym_private] = ACTIONS(3955),
    [anon_sym_protected] = ACTIONS(3955),
    [anon_sym_public] = ACTIONS(3955),
    [anon_sym_readonly] = ACTIONS(3955),
    [anon_sym_required] = ACTIONS(3955),
    [anon_sym_sealed] = ACTIONS(3955),
    [anon_sym_virtual] = ACTIONS(3955),
    [anon_sym_volatile] = ACTIONS(3955),
    [anon_sym_where] = ACTIONS(3955),
    [anon_sym_notnull] = ACTIONS(3955),
    [anon_sym_unmanaged] = ACTIONS(3955),
    [anon_sym_checked] = ACTIONS(3955),
    [anon_sym_BANG] = ACTIONS(3957),
    [anon_sym_TILDE] = ACTIONS(3957),
    [anon_sym_PLUS_PLUS] = ACTIONS(3957),
    [anon_sym_DASH_DASH] = ACTIONS(3957),
    [anon_sym_true] = ACTIONS(3955),
    [anon_sym_false] = ACTIONS(3955),
    [anon_sym_PLUS] = ACTIONS(3955),
    [anon_sym_DASH] = ACTIONS(3955),
    [anon_sym_STAR] = ACTIONS(3957),
    [anon_sym_CARET] = ACTIONS(3957),
    [anon_sym_AMP] = ACTIONS(3957),
    [anon_sym_this] = ACTIONS(3955),
    [anon_sym_scoped] = ACTIONS(3955),
    [anon_sym_base] = ACTIONS(3955),
    [anon_sym_var] = ACTIONS(3955),
    [sym_predefined_type] = ACTIONS(3955),
    [anon_sym_break] = ACTIONS(3955),
    [anon_sym_unchecked] = ACTIONS(3955),
    [anon_sym_continue] = ACTIONS(3955),
    [anon_sym_do] = ACTIONS(3955),
    [anon_sym_while] = ACTIONS(3955),
    [anon_sym_for] = ACTIONS(3955),
    [anon_sym_lock] = ACTIONS(3955),
    [anon_sym_yield] = ACTIONS(3955),
    [anon_sym_switch] = ACTIONS(3955),
    [anon_sym_default] = ACTIONS(3955),
    [anon_sym_throw] = ACTIONS(3955),
    [anon_sym_try] = ACTIONS(3955),
    [anon_sym_when] = ACTIONS(3955),
    [anon_sym_await] = ACTIONS(3955),
    [anon_sym_foreach] = ACTIONS(3955),
    [anon_sym_goto] = ACTIONS(3955),
    [anon_sym_if] = ACTIONS(3955),
    [anon_sym_DOT_DOT] = ACTIONS(3957),
    [anon_sym_from] = ACTIONS(3955),
    [anon_sym_into] = ACTIONS(3955),
    [anon_sym_join] = ACTIONS(3955),
    [anon_sym_on] = ACTIONS(3955),
    [anon_sym_equals] = ACTIONS(3955),
    [anon_sym_let] = ACTIONS(3955),
    [anon_sym_orderby] = ACTIONS(3955),
    [anon_sym_ascending] = ACTIONS(3955),
    [anon_sym_descending] = ACTIONS(3955),
    [anon_sym_group] = ACTIONS(3955),
    [anon_sym_by] = ACTIONS(3955),
    [anon_sym_select] = ACTIONS(3955),
    [anon_sym_stackalloc] = ACTIONS(3955),
    [anon_sym_sizeof] = ACTIONS(3955),
    [anon_sym_typeof] = ACTIONS(3955),
    [anon_sym___makeref] = ACTIONS(3955),
    [anon_sym___reftype] = ACTIONS(3955),
    [anon_sym___refvalue] = ACTIONS(3955),
    [sym_null_literal] = ACTIONS(3955),
    [anon_sym_SQUOTE] = ACTIONS(3957),
    [sym_integer_literal] = ACTIONS(3955),
    [sym_real_literal] = ACTIONS(3957),
    [anon_sym_DQUOTE] = ACTIONS(3957),
    [sym_verbatim_string_literal] = ACTIONS(3957),
    [aux_sym_preproc_if_token1] = ACTIONS(3957),
    [aux_sym_preproc_if_token3] = ACTIONS(3957),
    [aux_sym_preproc_else_token1] = ACTIONS(3957),
    [aux_sym_preproc_elif_token1] = ACTIONS(3957),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3957),
    [sym_interpolation_verbatim_start] = ACTIONS(3957),
    [sym_interpolation_raw_start] = ACTIONS(3957),
    [sym_raw_string_start] = ACTIONS(3957),
  },
  [2428] = {
    [sym_preproc_region] = STATE(2428),
    [sym_preproc_endregion] = STATE(2428),
    [sym_preproc_line] = STATE(2428),
    [sym_preproc_pragma] = STATE(2428),
    [sym_preproc_nullable] = STATE(2428),
    [sym_preproc_error] = STATE(2428),
    [sym_preproc_warning] = STATE(2428),
    [sym_preproc_define] = STATE(2428),
    [sym_preproc_undef] = STATE(2428),
    [sym__identifier_token] = ACTIONS(3959),
    [anon_sym_extern] = ACTIONS(3959),
    [anon_sym_alias] = ACTIONS(3959),
    [anon_sym_SEMI] = ACTIONS(3961),
    [anon_sym_global] = ACTIONS(3959),
    [anon_sym_using] = ACTIONS(3959),
    [anon_sym_unsafe] = ACTIONS(3959),
    [anon_sym_static] = ACTIONS(3959),
    [anon_sym_LBRACK] = ACTIONS(3961),
    [anon_sym_LPAREN] = ACTIONS(3961),
    [anon_sym_return] = ACTIONS(3959),
    [anon_sym_namespace] = ACTIONS(3959),
    [anon_sym_class] = ACTIONS(3959),
    [anon_sym_ref] = ACTIONS(3959),
    [anon_sym_struct] = ACTIONS(3959),
    [anon_sym_enum] = ACTIONS(3959),
    [anon_sym_LBRACE] = ACTIONS(3961),
    [anon_sym_interface] = ACTIONS(3959),
    [anon_sym_delegate] = ACTIONS(3959),
    [anon_sym_record] = ACTIONS(3959),
    [anon_sym_abstract] = ACTIONS(3959),
    [anon_sym_async] = ACTIONS(3959),
    [anon_sym_const] = ACTIONS(3959),
    [anon_sym_file] = ACTIONS(3959),
    [anon_sym_fixed] = ACTIONS(3959),
    [anon_sym_internal] = ACTIONS(3959),
    [anon_sym_new] = ACTIONS(3959),
    [anon_sym_override] = ACTIONS(3959),
    [anon_sym_partial] = ACTIONS(3959),
    [anon_sym_private] = ACTIONS(3959),
    [anon_sym_protected] = ACTIONS(3959),
    [anon_sym_public] = ACTIONS(3959),
    [anon_sym_readonly] = ACTIONS(3959),
    [anon_sym_required] = ACTIONS(3959),
    [anon_sym_sealed] = ACTIONS(3959),
    [anon_sym_virtual] = ACTIONS(3959),
    [anon_sym_volatile] = ACTIONS(3959),
    [anon_sym_where] = ACTIONS(3959),
    [anon_sym_notnull] = ACTIONS(3959),
    [anon_sym_unmanaged] = ACTIONS(3959),
    [anon_sym_checked] = ACTIONS(3959),
    [anon_sym_BANG] = ACTIONS(3961),
    [anon_sym_TILDE] = ACTIONS(3961),
    [anon_sym_PLUS_PLUS] = ACTIONS(3961),
    [anon_sym_DASH_DASH] = ACTIONS(3961),
    [anon_sym_true] = ACTIONS(3959),
    [anon_sym_false] = ACTIONS(3959),
    [anon_sym_PLUS] = ACTIONS(3959),
    [anon_sym_DASH] = ACTIONS(3959),
    [anon_sym_STAR] = ACTIONS(3961),
    [anon_sym_CARET] = ACTIONS(3961),
    [anon_sym_AMP] = ACTIONS(3961),
    [anon_sym_this] = ACTIONS(3959),
    [anon_sym_scoped] = ACTIONS(3959),
    [anon_sym_base] = ACTIONS(3959),
    [anon_sym_var] = ACTIONS(3959),
    [sym_predefined_type] = ACTIONS(3959),
    [anon_sym_break] = ACTIONS(3959),
    [anon_sym_unchecked] = ACTIONS(3959),
    [anon_sym_continue] = ACTIONS(3959),
    [anon_sym_do] = ACTIONS(3959),
    [anon_sym_while] = ACTIONS(3959),
    [anon_sym_for] = ACTIONS(3959),
    [anon_sym_lock] = ACTIONS(3959),
    [anon_sym_yield] = ACTIONS(3959),
    [anon_sym_switch] = ACTIONS(3959),
    [anon_sym_default] = ACTIONS(3959),
    [anon_sym_throw] = ACTIONS(3959),
    [anon_sym_try] = ACTIONS(3959),
    [anon_sym_when] = ACTIONS(3959),
    [anon_sym_await] = ACTIONS(3959),
    [anon_sym_foreach] = ACTIONS(3959),
    [anon_sym_goto] = ACTIONS(3959),
    [anon_sym_if] = ACTIONS(3959),
    [anon_sym_DOT_DOT] = ACTIONS(3961),
    [anon_sym_from] = ACTIONS(3959),
    [anon_sym_into] = ACTIONS(3959),
    [anon_sym_join] = ACTIONS(3959),
    [anon_sym_on] = ACTIONS(3959),
    [anon_sym_equals] = ACTIONS(3959),
    [anon_sym_let] = ACTIONS(3959),
    [anon_sym_orderby] = ACTIONS(3959),
    [anon_sym_ascending] = ACTIONS(3959),
    [anon_sym_descending] = ACTIONS(3959),
    [anon_sym_group] = ACTIONS(3959),
    [anon_sym_by] = ACTIONS(3959),
    [anon_sym_select] = ACTIONS(3959),
    [anon_sym_stackalloc] = ACTIONS(3959),
    [anon_sym_sizeof] = ACTIONS(3959),
    [anon_sym_typeof] = ACTIONS(3959),
    [anon_sym___makeref] = ACTIONS(3959),
    [anon_sym___reftype] = ACTIONS(3959),
    [anon_sym___refvalue] = ACTIONS(3959),
    [sym_null_literal] = ACTIONS(3959),
    [anon_sym_SQUOTE] = ACTIONS(3961),
    [sym_integer_literal] = ACTIONS(3959),
    [sym_real_literal] = ACTIONS(3961),
    [anon_sym_DQUOTE] = ACTIONS(3961),
    [sym_verbatim_string_literal] = ACTIONS(3961),
    [aux_sym_preproc_if_token1] = ACTIONS(3961),
    [aux_sym_preproc_if_token3] = ACTIONS(3961),
    [aux_sym_preproc_else_token1] = ACTIONS(3961),
    [aux_sym_preproc_elif_token1] = ACTIONS(3961),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3961),
    [sym_interpolation_verbatim_start] = ACTIONS(3961),
    [sym_interpolation_raw_start] = ACTIONS(3961),
    [sym_raw_string_start] = ACTIONS(3961),
  },
  [2429] = {
    [sym_preproc_region] = STATE(2429),
    [sym_preproc_endregion] = STATE(2429),
    [sym_preproc_line] = STATE(2429),
    [sym_preproc_pragma] = STATE(2429),
    [sym_preproc_nullable] = STATE(2429),
    [sym_preproc_error] = STATE(2429),
    [sym_preproc_warning] = STATE(2429),
    [sym_preproc_define] = STATE(2429),
    [sym_preproc_undef] = STATE(2429),
    [sym__identifier_token] = ACTIONS(3963),
    [anon_sym_extern] = ACTIONS(3963),
    [anon_sym_alias] = ACTIONS(3963),
    [anon_sym_SEMI] = ACTIONS(3965),
    [anon_sym_global] = ACTIONS(3963),
    [anon_sym_using] = ACTIONS(3963),
    [anon_sym_unsafe] = ACTIONS(3963),
    [anon_sym_static] = ACTIONS(3963),
    [anon_sym_LBRACK] = ACTIONS(3965),
    [anon_sym_LPAREN] = ACTIONS(3965),
    [anon_sym_return] = ACTIONS(3963),
    [anon_sym_namespace] = ACTIONS(3963),
    [anon_sym_class] = ACTIONS(3963),
    [anon_sym_ref] = ACTIONS(3963),
    [anon_sym_struct] = ACTIONS(3963),
    [anon_sym_enum] = ACTIONS(3963),
    [anon_sym_LBRACE] = ACTIONS(3965),
    [anon_sym_interface] = ACTIONS(3963),
    [anon_sym_delegate] = ACTIONS(3963),
    [anon_sym_record] = ACTIONS(3963),
    [anon_sym_abstract] = ACTIONS(3963),
    [anon_sym_async] = ACTIONS(3963),
    [anon_sym_const] = ACTIONS(3963),
    [anon_sym_file] = ACTIONS(3963),
    [anon_sym_fixed] = ACTIONS(3963),
    [anon_sym_internal] = ACTIONS(3963),
    [anon_sym_new] = ACTIONS(3963),
    [anon_sym_override] = ACTIONS(3963),
    [anon_sym_partial] = ACTIONS(3963),
    [anon_sym_private] = ACTIONS(3963),
    [anon_sym_protected] = ACTIONS(3963),
    [anon_sym_public] = ACTIONS(3963),
    [anon_sym_readonly] = ACTIONS(3963),
    [anon_sym_required] = ACTIONS(3963),
    [anon_sym_sealed] = ACTIONS(3963),
    [anon_sym_virtual] = ACTIONS(3963),
    [anon_sym_volatile] = ACTIONS(3963),
    [anon_sym_where] = ACTIONS(3963),
    [anon_sym_notnull] = ACTIONS(3963),
    [anon_sym_unmanaged] = ACTIONS(3963),
    [anon_sym_checked] = ACTIONS(3963),
    [anon_sym_BANG] = ACTIONS(3965),
    [anon_sym_TILDE] = ACTIONS(3965),
    [anon_sym_PLUS_PLUS] = ACTIONS(3965),
    [anon_sym_DASH_DASH] = ACTIONS(3965),
    [anon_sym_true] = ACTIONS(3963),
    [anon_sym_false] = ACTIONS(3963),
    [anon_sym_PLUS] = ACTIONS(3963),
    [anon_sym_DASH] = ACTIONS(3963),
    [anon_sym_STAR] = ACTIONS(3965),
    [anon_sym_CARET] = ACTIONS(3965),
    [anon_sym_AMP] = ACTIONS(3965),
    [anon_sym_this] = ACTIONS(3963),
    [anon_sym_scoped] = ACTIONS(3963),
    [anon_sym_base] = ACTIONS(3963),
    [anon_sym_var] = ACTIONS(3963),
    [sym_predefined_type] = ACTIONS(3963),
    [anon_sym_break] = ACTIONS(3963),
    [anon_sym_unchecked] = ACTIONS(3963),
    [anon_sym_continue] = ACTIONS(3963),
    [anon_sym_do] = ACTIONS(3963),
    [anon_sym_while] = ACTIONS(3963),
    [anon_sym_for] = ACTIONS(3963),
    [anon_sym_lock] = ACTIONS(3963),
    [anon_sym_yield] = ACTIONS(3963),
    [anon_sym_switch] = ACTIONS(3963),
    [anon_sym_default] = ACTIONS(3963),
    [anon_sym_throw] = ACTIONS(3963),
    [anon_sym_try] = ACTIONS(3963),
    [anon_sym_when] = ACTIONS(3963),
    [anon_sym_await] = ACTIONS(3963),
    [anon_sym_foreach] = ACTIONS(3963),
    [anon_sym_goto] = ACTIONS(3963),
    [anon_sym_if] = ACTIONS(3963),
    [anon_sym_DOT_DOT] = ACTIONS(3965),
    [anon_sym_from] = ACTIONS(3963),
    [anon_sym_into] = ACTIONS(3963),
    [anon_sym_join] = ACTIONS(3963),
    [anon_sym_on] = ACTIONS(3963),
    [anon_sym_equals] = ACTIONS(3963),
    [anon_sym_let] = ACTIONS(3963),
    [anon_sym_orderby] = ACTIONS(3963),
    [anon_sym_ascending] = ACTIONS(3963),
    [anon_sym_descending] = ACTIONS(3963),
    [anon_sym_group] = ACTIONS(3963),
    [anon_sym_by] = ACTIONS(3963),
    [anon_sym_select] = ACTIONS(3963),
    [anon_sym_stackalloc] = ACTIONS(3963),
    [anon_sym_sizeof] = ACTIONS(3963),
    [anon_sym_typeof] = ACTIONS(3963),
    [anon_sym___makeref] = ACTIONS(3963),
    [anon_sym___reftype] = ACTIONS(3963),
    [anon_sym___refvalue] = ACTIONS(3963),
    [sym_null_literal] = ACTIONS(3963),
    [anon_sym_SQUOTE] = ACTIONS(3965),
    [sym_integer_literal] = ACTIONS(3963),
    [sym_real_literal] = ACTIONS(3965),
    [anon_sym_DQUOTE] = ACTIONS(3965),
    [sym_verbatim_string_literal] = ACTIONS(3965),
    [aux_sym_preproc_if_token1] = ACTIONS(3965),
    [aux_sym_preproc_if_token3] = ACTIONS(3965),
    [aux_sym_preproc_else_token1] = ACTIONS(3965),
    [aux_sym_preproc_elif_token1] = ACTIONS(3965),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3965),
    [sym_interpolation_verbatim_start] = ACTIONS(3965),
    [sym_interpolation_raw_start] = ACTIONS(3965),
    [sym_raw_string_start] = ACTIONS(3965),
  },
  [2430] = {
    [sym_preproc_region] = STATE(2430),
    [sym_preproc_endregion] = STATE(2430),
    [sym_preproc_line] = STATE(2430),
    [sym_preproc_pragma] = STATE(2430),
    [sym_preproc_nullable] = STATE(2430),
    [sym_preproc_error] = STATE(2430),
    [sym_preproc_warning] = STATE(2430),
    [sym_preproc_define] = STATE(2430),
    [sym_preproc_undef] = STATE(2430),
    [sym__identifier_token] = ACTIONS(3967),
    [anon_sym_extern] = ACTIONS(3967),
    [anon_sym_alias] = ACTIONS(3967),
    [anon_sym_SEMI] = ACTIONS(3969),
    [anon_sym_global] = ACTIONS(3967),
    [anon_sym_using] = ACTIONS(3967),
    [anon_sym_unsafe] = ACTIONS(3967),
    [anon_sym_static] = ACTIONS(3967),
    [anon_sym_LBRACK] = ACTIONS(3969),
    [anon_sym_LPAREN] = ACTIONS(3969),
    [anon_sym_return] = ACTIONS(3967),
    [anon_sym_namespace] = ACTIONS(3967),
    [anon_sym_class] = ACTIONS(3967),
    [anon_sym_ref] = ACTIONS(3967),
    [anon_sym_struct] = ACTIONS(3967),
    [anon_sym_enum] = ACTIONS(3967),
    [anon_sym_LBRACE] = ACTIONS(3969),
    [anon_sym_interface] = ACTIONS(3967),
    [anon_sym_delegate] = ACTIONS(3967),
    [anon_sym_record] = ACTIONS(3967),
    [anon_sym_abstract] = ACTIONS(3967),
    [anon_sym_async] = ACTIONS(3967),
    [anon_sym_const] = ACTIONS(3967),
    [anon_sym_file] = ACTIONS(3967),
    [anon_sym_fixed] = ACTIONS(3967),
    [anon_sym_internal] = ACTIONS(3967),
    [anon_sym_new] = ACTIONS(3967),
    [anon_sym_override] = ACTIONS(3967),
    [anon_sym_partial] = ACTIONS(3967),
    [anon_sym_private] = ACTIONS(3967),
    [anon_sym_protected] = ACTIONS(3967),
    [anon_sym_public] = ACTIONS(3967),
    [anon_sym_readonly] = ACTIONS(3967),
    [anon_sym_required] = ACTIONS(3967),
    [anon_sym_sealed] = ACTIONS(3967),
    [anon_sym_virtual] = ACTIONS(3967),
    [anon_sym_volatile] = ACTIONS(3967),
    [anon_sym_where] = ACTIONS(3967),
    [anon_sym_notnull] = ACTIONS(3967),
    [anon_sym_unmanaged] = ACTIONS(3967),
    [anon_sym_checked] = ACTIONS(3967),
    [anon_sym_BANG] = ACTIONS(3969),
    [anon_sym_TILDE] = ACTIONS(3969),
    [anon_sym_PLUS_PLUS] = ACTIONS(3969),
    [anon_sym_DASH_DASH] = ACTIONS(3969),
    [anon_sym_true] = ACTIONS(3967),
    [anon_sym_false] = ACTIONS(3967),
    [anon_sym_PLUS] = ACTIONS(3967),
    [anon_sym_DASH] = ACTIONS(3967),
    [anon_sym_STAR] = ACTIONS(3969),
    [anon_sym_CARET] = ACTIONS(3969),
    [anon_sym_AMP] = ACTIONS(3969),
    [anon_sym_this] = ACTIONS(3967),
    [anon_sym_scoped] = ACTIONS(3967),
    [anon_sym_base] = ACTIONS(3967),
    [anon_sym_var] = ACTIONS(3967),
    [sym_predefined_type] = ACTIONS(3967),
    [anon_sym_break] = ACTIONS(3967),
    [anon_sym_unchecked] = ACTIONS(3967),
    [anon_sym_continue] = ACTIONS(3967),
    [anon_sym_do] = ACTIONS(3967),
    [anon_sym_while] = ACTIONS(3967),
    [anon_sym_for] = ACTIONS(3967),
    [anon_sym_lock] = ACTIONS(3967),
    [anon_sym_yield] = ACTIONS(3967),
    [anon_sym_switch] = ACTIONS(3967),
    [anon_sym_default] = ACTIONS(3967),
    [anon_sym_throw] = ACTIONS(3967),
    [anon_sym_try] = ACTIONS(3967),
    [anon_sym_when] = ACTIONS(3967),
    [anon_sym_await] = ACTIONS(3967),
    [anon_sym_foreach] = ACTIONS(3967),
    [anon_sym_goto] = ACTIONS(3967),
    [anon_sym_if] = ACTIONS(3967),
    [anon_sym_DOT_DOT] = ACTIONS(3969),
    [anon_sym_from] = ACTIONS(3967),
    [anon_sym_into] = ACTIONS(3967),
    [anon_sym_join] = ACTIONS(3967),
    [anon_sym_on] = ACTIONS(3967),
    [anon_sym_equals] = ACTIONS(3967),
    [anon_sym_let] = ACTIONS(3967),
    [anon_sym_orderby] = ACTIONS(3967),
    [anon_sym_ascending] = ACTIONS(3967),
    [anon_sym_descending] = ACTIONS(3967),
    [anon_sym_group] = ACTIONS(3967),
    [anon_sym_by] = ACTIONS(3967),
    [anon_sym_select] = ACTIONS(3967),
    [anon_sym_stackalloc] = ACTIONS(3967),
    [anon_sym_sizeof] = ACTIONS(3967),
    [anon_sym_typeof] = ACTIONS(3967),
    [anon_sym___makeref] = ACTIONS(3967),
    [anon_sym___reftype] = ACTIONS(3967),
    [anon_sym___refvalue] = ACTIONS(3967),
    [sym_null_literal] = ACTIONS(3967),
    [anon_sym_SQUOTE] = ACTIONS(3969),
    [sym_integer_literal] = ACTIONS(3967),
    [sym_real_literal] = ACTIONS(3969),
    [anon_sym_DQUOTE] = ACTIONS(3969),
    [sym_verbatim_string_literal] = ACTIONS(3969),
    [aux_sym_preproc_if_token1] = ACTIONS(3969),
    [aux_sym_preproc_if_token3] = ACTIONS(3969),
    [aux_sym_preproc_else_token1] = ACTIONS(3969),
    [aux_sym_preproc_elif_token1] = ACTIONS(3969),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3969),
    [sym_interpolation_verbatim_start] = ACTIONS(3969),
    [sym_interpolation_raw_start] = ACTIONS(3969),
    [sym_raw_string_start] = ACTIONS(3969),
  },
  [2431] = {
    [sym_preproc_region] = STATE(2431),
    [sym_preproc_endregion] = STATE(2431),
    [sym_preproc_line] = STATE(2431),
    [sym_preproc_pragma] = STATE(2431),
    [sym_preproc_nullable] = STATE(2431),
    [sym_preproc_error] = STATE(2431),
    [sym_preproc_warning] = STATE(2431),
    [sym_preproc_define] = STATE(2431),
    [sym_preproc_undef] = STATE(2431),
    [sym__identifier_token] = ACTIONS(3971),
    [anon_sym_extern] = ACTIONS(3971),
    [anon_sym_alias] = ACTIONS(3971),
    [anon_sym_SEMI] = ACTIONS(3973),
    [anon_sym_global] = ACTIONS(3971),
    [anon_sym_using] = ACTIONS(3971),
    [anon_sym_unsafe] = ACTIONS(3971),
    [anon_sym_static] = ACTIONS(3971),
    [anon_sym_LBRACK] = ACTIONS(3973),
    [anon_sym_LPAREN] = ACTIONS(3973),
    [anon_sym_return] = ACTIONS(3971),
    [anon_sym_namespace] = ACTIONS(3971),
    [anon_sym_class] = ACTIONS(3971),
    [anon_sym_ref] = ACTIONS(3971),
    [anon_sym_struct] = ACTIONS(3971),
    [anon_sym_enum] = ACTIONS(3971),
    [anon_sym_LBRACE] = ACTIONS(3973),
    [anon_sym_interface] = ACTIONS(3971),
    [anon_sym_delegate] = ACTIONS(3971),
    [anon_sym_record] = ACTIONS(3971),
    [anon_sym_abstract] = ACTIONS(3971),
    [anon_sym_async] = ACTIONS(3971),
    [anon_sym_const] = ACTIONS(3971),
    [anon_sym_file] = ACTIONS(3971),
    [anon_sym_fixed] = ACTIONS(3971),
    [anon_sym_internal] = ACTIONS(3971),
    [anon_sym_new] = ACTIONS(3971),
    [anon_sym_override] = ACTIONS(3971),
    [anon_sym_partial] = ACTIONS(3971),
    [anon_sym_private] = ACTIONS(3971),
    [anon_sym_protected] = ACTIONS(3971),
    [anon_sym_public] = ACTIONS(3971),
    [anon_sym_readonly] = ACTIONS(3971),
    [anon_sym_required] = ACTIONS(3971),
    [anon_sym_sealed] = ACTIONS(3971),
    [anon_sym_virtual] = ACTIONS(3971),
    [anon_sym_volatile] = ACTIONS(3971),
    [anon_sym_where] = ACTIONS(3971),
    [anon_sym_notnull] = ACTIONS(3971),
    [anon_sym_unmanaged] = ACTIONS(3971),
    [anon_sym_checked] = ACTIONS(3971),
    [anon_sym_BANG] = ACTIONS(3973),
    [anon_sym_TILDE] = ACTIONS(3973),
    [anon_sym_PLUS_PLUS] = ACTIONS(3973),
    [anon_sym_DASH_DASH] = ACTIONS(3973),
    [anon_sym_true] = ACTIONS(3971),
    [anon_sym_false] = ACTIONS(3971),
    [anon_sym_PLUS] = ACTIONS(3971),
    [anon_sym_DASH] = ACTIONS(3971),
    [anon_sym_STAR] = ACTIONS(3973),
    [anon_sym_CARET] = ACTIONS(3973),
    [anon_sym_AMP] = ACTIONS(3973),
    [anon_sym_this] = ACTIONS(3971),
    [anon_sym_scoped] = ACTIONS(3971),
    [anon_sym_base] = ACTIONS(3971),
    [anon_sym_var] = ACTIONS(3971),
    [sym_predefined_type] = ACTIONS(3971),
    [anon_sym_break] = ACTIONS(3971),
    [anon_sym_unchecked] = ACTIONS(3971),
    [anon_sym_continue] = ACTIONS(3971),
    [anon_sym_do] = ACTIONS(3971),
    [anon_sym_while] = ACTIONS(3971),
    [anon_sym_for] = ACTIONS(3971),
    [anon_sym_lock] = ACTIONS(3971),
    [anon_sym_yield] = ACTIONS(3971),
    [anon_sym_switch] = ACTIONS(3971),
    [anon_sym_default] = ACTIONS(3971),
    [anon_sym_throw] = ACTIONS(3971),
    [anon_sym_try] = ACTIONS(3971),
    [anon_sym_when] = ACTIONS(3971),
    [anon_sym_await] = ACTIONS(3971),
    [anon_sym_foreach] = ACTIONS(3971),
    [anon_sym_goto] = ACTIONS(3971),
    [anon_sym_if] = ACTIONS(3971),
    [anon_sym_DOT_DOT] = ACTIONS(3973),
    [anon_sym_from] = ACTIONS(3971),
    [anon_sym_into] = ACTIONS(3971),
    [anon_sym_join] = ACTIONS(3971),
    [anon_sym_on] = ACTIONS(3971),
    [anon_sym_equals] = ACTIONS(3971),
    [anon_sym_let] = ACTIONS(3971),
    [anon_sym_orderby] = ACTIONS(3971),
    [anon_sym_ascending] = ACTIONS(3971),
    [anon_sym_descending] = ACTIONS(3971),
    [anon_sym_group] = ACTIONS(3971),
    [anon_sym_by] = ACTIONS(3971),
    [anon_sym_select] = ACTIONS(3971),
    [anon_sym_stackalloc] = ACTIONS(3971),
    [anon_sym_sizeof] = ACTIONS(3971),
    [anon_sym_typeof] = ACTIONS(3971),
    [anon_sym___makeref] = ACTIONS(3971),
    [anon_sym___reftype] = ACTIONS(3971),
    [anon_sym___refvalue] = ACTIONS(3971),
    [sym_null_literal] = ACTIONS(3971),
    [anon_sym_SQUOTE] = ACTIONS(3973),
    [sym_integer_literal] = ACTIONS(3971),
    [sym_real_literal] = ACTIONS(3973),
    [anon_sym_DQUOTE] = ACTIONS(3973),
    [sym_verbatim_string_literal] = ACTIONS(3973),
    [aux_sym_preproc_if_token1] = ACTIONS(3973),
    [aux_sym_preproc_if_token3] = ACTIONS(3973),
    [aux_sym_preproc_else_token1] = ACTIONS(3973),
    [aux_sym_preproc_elif_token1] = ACTIONS(3973),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3973),
    [sym_interpolation_verbatim_start] = ACTIONS(3973),
    [sym_interpolation_raw_start] = ACTIONS(3973),
    [sym_raw_string_start] = ACTIONS(3973),
  },
  [2432] = {
    [sym_preproc_region] = STATE(2432),
    [sym_preproc_endregion] = STATE(2432),
    [sym_preproc_line] = STATE(2432),
    [sym_preproc_pragma] = STATE(2432),
    [sym_preproc_nullable] = STATE(2432),
    [sym_preproc_error] = STATE(2432),
    [sym_preproc_warning] = STATE(2432),
    [sym_preproc_define] = STATE(2432),
    [sym_preproc_undef] = STATE(2432),
    [sym__identifier_token] = ACTIONS(3975),
    [anon_sym_extern] = ACTIONS(3975),
    [anon_sym_alias] = ACTIONS(3975),
    [anon_sym_SEMI] = ACTIONS(3977),
    [anon_sym_global] = ACTIONS(3975),
    [anon_sym_using] = ACTIONS(3975),
    [anon_sym_unsafe] = ACTIONS(3975),
    [anon_sym_static] = ACTIONS(3975),
    [anon_sym_LBRACK] = ACTIONS(3977),
    [anon_sym_LPAREN] = ACTIONS(3977),
    [anon_sym_return] = ACTIONS(3975),
    [anon_sym_namespace] = ACTIONS(3975),
    [anon_sym_class] = ACTIONS(3975),
    [anon_sym_ref] = ACTIONS(3975),
    [anon_sym_struct] = ACTIONS(3975),
    [anon_sym_enum] = ACTIONS(3975),
    [anon_sym_LBRACE] = ACTIONS(3977),
    [anon_sym_interface] = ACTIONS(3975),
    [anon_sym_delegate] = ACTIONS(3975),
    [anon_sym_record] = ACTIONS(3975),
    [anon_sym_abstract] = ACTIONS(3975),
    [anon_sym_async] = ACTIONS(3975),
    [anon_sym_const] = ACTIONS(3975),
    [anon_sym_file] = ACTIONS(3975),
    [anon_sym_fixed] = ACTIONS(3975),
    [anon_sym_internal] = ACTIONS(3975),
    [anon_sym_new] = ACTIONS(3975),
    [anon_sym_override] = ACTIONS(3975),
    [anon_sym_partial] = ACTIONS(3975),
    [anon_sym_private] = ACTIONS(3975),
    [anon_sym_protected] = ACTIONS(3975),
    [anon_sym_public] = ACTIONS(3975),
    [anon_sym_readonly] = ACTIONS(3975),
    [anon_sym_required] = ACTIONS(3975),
    [anon_sym_sealed] = ACTIONS(3975),
    [anon_sym_virtual] = ACTIONS(3975),
    [anon_sym_volatile] = ACTIONS(3975),
    [anon_sym_where] = ACTIONS(3975),
    [anon_sym_notnull] = ACTIONS(3975),
    [anon_sym_unmanaged] = ACTIONS(3975),
    [anon_sym_checked] = ACTIONS(3975),
    [anon_sym_BANG] = ACTIONS(3977),
    [anon_sym_TILDE] = ACTIONS(3977),
    [anon_sym_PLUS_PLUS] = ACTIONS(3977),
    [anon_sym_DASH_DASH] = ACTIONS(3977),
    [anon_sym_true] = ACTIONS(3975),
    [anon_sym_false] = ACTIONS(3975),
    [anon_sym_PLUS] = ACTIONS(3975),
    [anon_sym_DASH] = ACTIONS(3975),
    [anon_sym_STAR] = ACTIONS(3977),
    [anon_sym_CARET] = ACTIONS(3977),
    [anon_sym_AMP] = ACTIONS(3977),
    [anon_sym_this] = ACTIONS(3975),
    [anon_sym_scoped] = ACTIONS(3975),
    [anon_sym_base] = ACTIONS(3975),
    [anon_sym_var] = ACTIONS(3975),
    [sym_predefined_type] = ACTIONS(3975),
    [anon_sym_break] = ACTIONS(3975),
    [anon_sym_unchecked] = ACTIONS(3975),
    [anon_sym_continue] = ACTIONS(3975),
    [anon_sym_do] = ACTIONS(3975),
    [anon_sym_while] = ACTIONS(3975),
    [anon_sym_for] = ACTIONS(3975),
    [anon_sym_lock] = ACTIONS(3975),
    [anon_sym_yield] = ACTIONS(3975),
    [anon_sym_switch] = ACTIONS(3975),
    [anon_sym_default] = ACTIONS(3975),
    [anon_sym_throw] = ACTIONS(3975),
    [anon_sym_try] = ACTIONS(3975),
    [anon_sym_when] = ACTIONS(3975),
    [anon_sym_await] = ACTIONS(3975),
    [anon_sym_foreach] = ACTIONS(3975),
    [anon_sym_goto] = ACTIONS(3975),
    [anon_sym_if] = ACTIONS(3975),
    [anon_sym_DOT_DOT] = ACTIONS(3977),
    [anon_sym_from] = ACTIONS(3975),
    [anon_sym_into] = ACTIONS(3975),
    [anon_sym_join] = ACTIONS(3975),
    [anon_sym_on] = ACTIONS(3975),
    [anon_sym_equals] = ACTIONS(3975),
    [anon_sym_let] = ACTIONS(3975),
    [anon_sym_orderby] = ACTIONS(3975),
    [anon_sym_ascending] = ACTIONS(3975),
    [anon_sym_descending] = ACTIONS(3975),
    [anon_sym_group] = ACTIONS(3975),
    [anon_sym_by] = ACTIONS(3975),
    [anon_sym_select] = ACTIONS(3975),
    [anon_sym_stackalloc] = ACTIONS(3975),
    [anon_sym_sizeof] = ACTIONS(3975),
    [anon_sym_typeof] = ACTIONS(3975),
    [anon_sym___makeref] = ACTIONS(3975),
    [anon_sym___reftype] = ACTIONS(3975),
    [anon_sym___refvalue] = ACTIONS(3975),
    [sym_null_literal] = ACTIONS(3975),
    [anon_sym_SQUOTE] = ACTIONS(3977),
    [sym_integer_literal] = ACTIONS(3975),
    [sym_real_literal] = ACTIONS(3977),
    [anon_sym_DQUOTE] = ACTIONS(3977),
    [sym_verbatim_string_literal] = ACTIONS(3977),
    [aux_sym_preproc_if_token1] = ACTIONS(3977),
    [aux_sym_preproc_if_token3] = ACTIONS(3977),
    [aux_sym_preproc_else_token1] = ACTIONS(3977),
    [aux_sym_preproc_elif_token1] = ACTIONS(3977),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3977),
    [sym_interpolation_verbatim_start] = ACTIONS(3977),
    [sym_interpolation_raw_start] = ACTIONS(3977),
    [sym_raw_string_start] = ACTIONS(3977),
  },
  [2433] = {
    [sym_preproc_region] = STATE(2433),
    [sym_preproc_endregion] = STATE(2433),
    [sym_preproc_line] = STATE(2433),
    [sym_preproc_pragma] = STATE(2433),
    [sym_preproc_nullable] = STATE(2433),
    [sym_preproc_error] = STATE(2433),
    [sym_preproc_warning] = STATE(2433),
    [sym_preproc_define] = STATE(2433),
    [sym_preproc_undef] = STATE(2433),
    [sym__identifier_token] = ACTIONS(3979),
    [anon_sym_extern] = ACTIONS(3979),
    [anon_sym_alias] = ACTIONS(3979),
    [anon_sym_SEMI] = ACTIONS(3981),
    [anon_sym_global] = ACTIONS(3979),
    [anon_sym_using] = ACTIONS(3979),
    [anon_sym_unsafe] = ACTIONS(3979),
    [anon_sym_static] = ACTIONS(3979),
    [anon_sym_LBRACK] = ACTIONS(3981),
    [anon_sym_LPAREN] = ACTIONS(3981),
    [anon_sym_return] = ACTIONS(3979),
    [anon_sym_namespace] = ACTIONS(3979),
    [anon_sym_class] = ACTIONS(3979),
    [anon_sym_ref] = ACTIONS(3979),
    [anon_sym_struct] = ACTIONS(3979),
    [anon_sym_enum] = ACTIONS(3979),
    [anon_sym_LBRACE] = ACTIONS(3981),
    [anon_sym_interface] = ACTIONS(3979),
    [anon_sym_delegate] = ACTIONS(3979),
    [anon_sym_record] = ACTIONS(3979),
    [anon_sym_abstract] = ACTIONS(3979),
    [anon_sym_async] = ACTIONS(3979),
    [anon_sym_const] = ACTIONS(3979),
    [anon_sym_file] = ACTIONS(3979),
    [anon_sym_fixed] = ACTIONS(3979),
    [anon_sym_internal] = ACTIONS(3979),
    [anon_sym_new] = ACTIONS(3979),
    [anon_sym_override] = ACTIONS(3979),
    [anon_sym_partial] = ACTIONS(3979),
    [anon_sym_private] = ACTIONS(3979),
    [anon_sym_protected] = ACTIONS(3979),
    [anon_sym_public] = ACTIONS(3979),
    [anon_sym_readonly] = ACTIONS(3979),
    [anon_sym_required] = ACTIONS(3979),
    [anon_sym_sealed] = ACTIONS(3979),
    [anon_sym_virtual] = ACTIONS(3979),
    [anon_sym_volatile] = ACTIONS(3979),
    [anon_sym_where] = ACTIONS(3979),
    [anon_sym_notnull] = ACTIONS(3979),
    [anon_sym_unmanaged] = ACTIONS(3979),
    [anon_sym_checked] = ACTIONS(3979),
    [anon_sym_BANG] = ACTIONS(3981),
    [anon_sym_TILDE] = ACTIONS(3981),
    [anon_sym_PLUS_PLUS] = ACTIONS(3981),
    [anon_sym_DASH_DASH] = ACTIONS(3981),
    [anon_sym_true] = ACTIONS(3979),
    [anon_sym_false] = ACTIONS(3979),
    [anon_sym_PLUS] = ACTIONS(3979),
    [anon_sym_DASH] = ACTIONS(3979),
    [anon_sym_STAR] = ACTIONS(3981),
    [anon_sym_CARET] = ACTIONS(3981),
    [anon_sym_AMP] = ACTIONS(3981),
    [anon_sym_this] = ACTIONS(3979),
    [anon_sym_scoped] = ACTIONS(3979),
    [anon_sym_base] = ACTIONS(3979),
    [anon_sym_var] = ACTIONS(3979),
    [sym_predefined_type] = ACTIONS(3979),
    [anon_sym_break] = ACTIONS(3979),
    [anon_sym_unchecked] = ACTIONS(3979),
    [anon_sym_continue] = ACTIONS(3979),
    [anon_sym_do] = ACTIONS(3979),
    [anon_sym_while] = ACTIONS(3979),
    [anon_sym_for] = ACTIONS(3979),
    [anon_sym_lock] = ACTIONS(3979),
    [anon_sym_yield] = ACTIONS(3979),
    [anon_sym_switch] = ACTIONS(3979),
    [anon_sym_default] = ACTIONS(3979),
    [anon_sym_throw] = ACTIONS(3979),
    [anon_sym_try] = ACTIONS(3979),
    [anon_sym_when] = ACTIONS(3979),
    [anon_sym_await] = ACTIONS(3979),
    [anon_sym_foreach] = ACTIONS(3979),
    [anon_sym_goto] = ACTIONS(3979),
    [anon_sym_if] = ACTIONS(3979),
    [anon_sym_DOT_DOT] = ACTIONS(3981),
    [anon_sym_from] = ACTIONS(3979),
    [anon_sym_into] = ACTIONS(3979),
    [anon_sym_join] = ACTIONS(3979),
    [anon_sym_on] = ACTIONS(3979),
    [anon_sym_equals] = ACTIONS(3979),
    [anon_sym_let] = ACTIONS(3979),
    [anon_sym_orderby] = ACTIONS(3979),
    [anon_sym_ascending] = ACTIONS(3979),
    [anon_sym_descending] = ACTIONS(3979),
    [anon_sym_group] = ACTIONS(3979),
    [anon_sym_by] = ACTIONS(3979),
    [anon_sym_select] = ACTIONS(3979),
    [anon_sym_stackalloc] = ACTIONS(3979),
    [anon_sym_sizeof] = ACTIONS(3979),
    [anon_sym_typeof] = ACTIONS(3979),
    [anon_sym___makeref] = ACTIONS(3979),
    [anon_sym___reftype] = ACTIONS(3979),
    [anon_sym___refvalue] = ACTIONS(3979),
    [sym_null_literal] = ACTIONS(3979),
    [anon_sym_SQUOTE] = ACTIONS(3981),
    [sym_integer_literal] = ACTIONS(3979),
    [sym_real_literal] = ACTIONS(3981),
    [anon_sym_DQUOTE] = ACTIONS(3981),
    [sym_verbatim_string_literal] = ACTIONS(3981),
    [aux_sym_preproc_if_token1] = ACTIONS(3981),
    [aux_sym_preproc_if_token3] = ACTIONS(3981),
    [aux_sym_preproc_else_token1] = ACTIONS(3981),
    [aux_sym_preproc_elif_token1] = ACTIONS(3981),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3981),
    [sym_interpolation_verbatim_start] = ACTIONS(3981),
    [sym_interpolation_raw_start] = ACTIONS(3981),
    [sym_raw_string_start] = ACTIONS(3981),
  },
  [2434] = {
    [sym_preproc_region] = STATE(2434),
    [sym_preproc_endregion] = STATE(2434),
    [sym_preproc_line] = STATE(2434),
    [sym_preproc_pragma] = STATE(2434),
    [sym_preproc_nullable] = STATE(2434),
    [sym_preproc_error] = STATE(2434),
    [sym_preproc_warning] = STATE(2434),
    [sym_preproc_define] = STATE(2434),
    [sym_preproc_undef] = STATE(2434),
    [sym__identifier_token] = ACTIONS(3983),
    [anon_sym_extern] = ACTIONS(3983),
    [anon_sym_alias] = ACTIONS(3983),
    [anon_sym_SEMI] = ACTIONS(3985),
    [anon_sym_global] = ACTIONS(3983),
    [anon_sym_using] = ACTIONS(3983),
    [anon_sym_unsafe] = ACTIONS(3983),
    [anon_sym_static] = ACTIONS(3983),
    [anon_sym_LBRACK] = ACTIONS(3985),
    [anon_sym_LPAREN] = ACTIONS(3985),
    [anon_sym_return] = ACTIONS(3983),
    [anon_sym_namespace] = ACTIONS(3983),
    [anon_sym_class] = ACTIONS(3983),
    [anon_sym_ref] = ACTIONS(3983),
    [anon_sym_struct] = ACTIONS(3983),
    [anon_sym_enum] = ACTIONS(3983),
    [anon_sym_LBRACE] = ACTIONS(3985),
    [anon_sym_interface] = ACTIONS(3983),
    [anon_sym_delegate] = ACTIONS(3983),
    [anon_sym_record] = ACTIONS(3983),
    [anon_sym_abstract] = ACTIONS(3983),
    [anon_sym_async] = ACTIONS(3983),
    [anon_sym_const] = ACTIONS(3983),
    [anon_sym_file] = ACTIONS(3983),
    [anon_sym_fixed] = ACTIONS(3983),
    [anon_sym_internal] = ACTIONS(3983),
    [anon_sym_new] = ACTIONS(3983),
    [anon_sym_override] = ACTIONS(3983),
    [anon_sym_partial] = ACTIONS(3983),
    [anon_sym_private] = ACTIONS(3983),
    [anon_sym_protected] = ACTIONS(3983),
    [anon_sym_public] = ACTIONS(3983),
    [anon_sym_readonly] = ACTIONS(3983),
    [anon_sym_required] = ACTIONS(3983),
    [anon_sym_sealed] = ACTIONS(3983),
    [anon_sym_virtual] = ACTIONS(3983),
    [anon_sym_volatile] = ACTIONS(3983),
    [anon_sym_where] = ACTIONS(3983),
    [anon_sym_notnull] = ACTIONS(3983),
    [anon_sym_unmanaged] = ACTIONS(3983),
    [anon_sym_checked] = ACTIONS(3983),
    [anon_sym_BANG] = ACTIONS(3985),
    [anon_sym_TILDE] = ACTIONS(3985),
    [anon_sym_PLUS_PLUS] = ACTIONS(3985),
    [anon_sym_DASH_DASH] = ACTIONS(3985),
    [anon_sym_true] = ACTIONS(3983),
    [anon_sym_false] = ACTIONS(3983),
    [anon_sym_PLUS] = ACTIONS(3983),
    [anon_sym_DASH] = ACTIONS(3983),
    [anon_sym_STAR] = ACTIONS(3985),
    [anon_sym_CARET] = ACTIONS(3985),
    [anon_sym_AMP] = ACTIONS(3985),
    [anon_sym_this] = ACTIONS(3983),
    [anon_sym_scoped] = ACTIONS(3983),
    [anon_sym_base] = ACTIONS(3983),
    [anon_sym_var] = ACTIONS(3983),
    [sym_predefined_type] = ACTIONS(3983),
    [anon_sym_break] = ACTIONS(3983),
    [anon_sym_unchecked] = ACTIONS(3983),
    [anon_sym_continue] = ACTIONS(3983),
    [anon_sym_do] = ACTIONS(3983),
    [anon_sym_while] = ACTIONS(3983),
    [anon_sym_for] = ACTIONS(3983),
    [anon_sym_lock] = ACTIONS(3983),
    [anon_sym_yield] = ACTIONS(3983),
    [anon_sym_switch] = ACTIONS(3983),
    [anon_sym_default] = ACTIONS(3983),
    [anon_sym_throw] = ACTIONS(3983),
    [anon_sym_try] = ACTIONS(3983),
    [anon_sym_when] = ACTIONS(3983),
    [anon_sym_await] = ACTIONS(3983),
    [anon_sym_foreach] = ACTIONS(3983),
    [anon_sym_goto] = ACTIONS(3983),
    [anon_sym_if] = ACTIONS(3983),
    [anon_sym_DOT_DOT] = ACTIONS(3985),
    [anon_sym_from] = ACTIONS(3983),
    [anon_sym_into] = ACTIONS(3983),
    [anon_sym_join] = ACTIONS(3983),
    [anon_sym_on] = ACTIONS(3983),
    [anon_sym_equals] = ACTIONS(3983),
    [anon_sym_let] = ACTIONS(3983),
    [anon_sym_orderby] = ACTIONS(3983),
    [anon_sym_ascending] = ACTIONS(3983),
    [anon_sym_descending] = ACTIONS(3983),
    [anon_sym_group] = ACTIONS(3983),
    [anon_sym_by] = ACTIONS(3983),
    [anon_sym_select] = ACTIONS(3983),
    [anon_sym_stackalloc] = ACTIONS(3983),
    [anon_sym_sizeof] = ACTIONS(3983),
    [anon_sym_typeof] = ACTIONS(3983),
    [anon_sym___makeref] = ACTIONS(3983),
    [anon_sym___reftype] = ACTIONS(3983),
    [anon_sym___refvalue] = ACTIONS(3983),
    [sym_null_literal] = ACTIONS(3983),
    [anon_sym_SQUOTE] = ACTIONS(3985),
    [sym_integer_literal] = ACTIONS(3983),
    [sym_real_literal] = ACTIONS(3985),
    [anon_sym_DQUOTE] = ACTIONS(3985),
    [sym_verbatim_string_literal] = ACTIONS(3985),
    [aux_sym_preproc_if_token1] = ACTIONS(3985),
    [aux_sym_preproc_if_token3] = ACTIONS(3985),
    [aux_sym_preproc_else_token1] = ACTIONS(3985),
    [aux_sym_preproc_elif_token1] = ACTIONS(3985),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3985),
    [sym_interpolation_verbatim_start] = ACTIONS(3985),
    [sym_interpolation_raw_start] = ACTIONS(3985),
    [sym_raw_string_start] = ACTIONS(3985),
  },
  [2435] = {
    [sym_preproc_region] = STATE(2435),
    [sym_preproc_endregion] = STATE(2435),
    [sym_preproc_line] = STATE(2435),
    [sym_preproc_pragma] = STATE(2435),
    [sym_preproc_nullable] = STATE(2435),
    [sym_preproc_error] = STATE(2435),
    [sym_preproc_warning] = STATE(2435),
    [sym_preproc_define] = STATE(2435),
    [sym_preproc_undef] = STATE(2435),
    [ts_builtin_sym_end] = ACTIONS(3291),
    [sym__identifier_token] = ACTIONS(3289),
    [anon_sym_extern] = ACTIONS(3289),
    [anon_sym_alias] = ACTIONS(3289),
    [anon_sym_SEMI] = ACTIONS(3291),
    [anon_sym_global] = ACTIONS(3289),
    [anon_sym_using] = ACTIONS(3289),
    [anon_sym_unsafe] = ACTIONS(3289),
    [anon_sym_static] = ACTIONS(3289),
    [anon_sym_LBRACK] = ACTIONS(3291),
    [anon_sym_LPAREN] = ACTIONS(3291),
    [anon_sym_return] = ACTIONS(3289),
    [anon_sym_namespace] = ACTIONS(3289),
    [anon_sym_class] = ACTIONS(3289),
    [anon_sym_ref] = ACTIONS(3289),
    [anon_sym_struct] = ACTIONS(3289),
    [anon_sym_enum] = ACTIONS(3289),
    [anon_sym_LBRACE] = ACTIONS(3291),
    [anon_sym_interface] = ACTIONS(3289),
    [anon_sym_delegate] = ACTIONS(3289),
    [anon_sym_record] = ACTIONS(3289),
    [anon_sym_abstract] = ACTIONS(3289),
    [anon_sym_async] = ACTIONS(3289),
    [anon_sym_const] = ACTIONS(3289),
    [anon_sym_file] = ACTIONS(3289),
    [anon_sym_fixed] = ACTIONS(3289),
    [anon_sym_internal] = ACTIONS(3289),
    [anon_sym_new] = ACTIONS(3289),
    [anon_sym_override] = ACTIONS(3289),
    [anon_sym_partial] = ACTIONS(3289),
    [anon_sym_private] = ACTIONS(3289),
    [anon_sym_protected] = ACTIONS(3289),
    [anon_sym_public] = ACTIONS(3289),
    [anon_sym_readonly] = ACTIONS(3289),
    [anon_sym_required] = ACTIONS(3289),
    [anon_sym_sealed] = ACTIONS(3289),
    [anon_sym_virtual] = ACTIONS(3289),
    [anon_sym_volatile] = ACTIONS(3289),
    [anon_sym_where] = ACTIONS(3289),
    [anon_sym_notnull] = ACTIONS(3289),
    [anon_sym_unmanaged] = ACTIONS(3289),
    [anon_sym_checked] = ACTIONS(3289),
    [anon_sym_BANG] = ACTIONS(3291),
    [anon_sym_TILDE] = ACTIONS(3291),
    [anon_sym_PLUS_PLUS] = ACTIONS(3291),
    [anon_sym_DASH_DASH] = ACTIONS(3291),
    [anon_sym_true] = ACTIONS(3289),
    [anon_sym_false] = ACTIONS(3289),
    [anon_sym_PLUS] = ACTIONS(3289),
    [anon_sym_DASH] = ACTIONS(3289),
    [anon_sym_STAR] = ACTIONS(3291),
    [anon_sym_CARET] = ACTIONS(3291),
    [anon_sym_AMP] = ACTIONS(3291),
    [anon_sym_this] = ACTIONS(3289),
    [anon_sym_scoped] = ACTIONS(3289),
    [anon_sym_base] = ACTIONS(3289),
    [anon_sym_var] = ACTIONS(3289),
    [sym_predefined_type] = ACTIONS(3289),
    [anon_sym_break] = ACTIONS(3289),
    [anon_sym_unchecked] = ACTIONS(3289),
    [anon_sym_continue] = ACTIONS(3289),
    [anon_sym_do] = ACTIONS(3289),
    [anon_sym_while] = ACTIONS(3289),
    [anon_sym_for] = ACTIONS(3289),
    [anon_sym_lock] = ACTIONS(3289),
    [anon_sym_yield] = ACTIONS(3289),
    [anon_sym_switch] = ACTIONS(3289),
    [anon_sym_default] = ACTIONS(3289),
    [anon_sym_throw] = ACTIONS(3289),
    [anon_sym_try] = ACTIONS(3289),
    [anon_sym_when] = ACTIONS(3289),
    [anon_sym_await] = ACTIONS(3289),
    [anon_sym_foreach] = ACTIONS(3289),
    [anon_sym_goto] = ACTIONS(3289),
    [anon_sym_if] = ACTIONS(3289),
    [anon_sym_else] = ACTIONS(3289),
    [anon_sym_DOT_DOT] = ACTIONS(3291),
    [anon_sym_from] = ACTIONS(3289),
    [anon_sym_into] = ACTIONS(3289),
    [anon_sym_join] = ACTIONS(3289),
    [anon_sym_on] = ACTIONS(3289),
    [anon_sym_equals] = ACTIONS(3289),
    [anon_sym_let] = ACTIONS(3289),
    [anon_sym_orderby] = ACTIONS(3289),
    [anon_sym_ascending] = ACTIONS(3289),
    [anon_sym_descending] = ACTIONS(3289),
    [anon_sym_group] = ACTIONS(3289),
    [anon_sym_by] = ACTIONS(3289),
    [anon_sym_select] = ACTIONS(3289),
    [anon_sym_stackalloc] = ACTIONS(3289),
    [anon_sym_sizeof] = ACTIONS(3289),
    [anon_sym_typeof] = ACTIONS(3289),
    [anon_sym___makeref] = ACTIONS(3289),
    [anon_sym___reftype] = ACTIONS(3289),
    [anon_sym___refvalue] = ACTIONS(3289),
    [sym_null_literal] = ACTIONS(3289),
    [anon_sym_SQUOTE] = ACTIONS(3291),
    [sym_integer_literal] = ACTIONS(3289),
    [sym_real_literal] = ACTIONS(3291),
    [anon_sym_DQUOTE] = ACTIONS(3291),
    [sym_verbatim_string_literal] = ACTIONS(3291),
    [aux_sym_preproc_if_token1] = ACTIONS(3291),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3291),
    [sym_interpolation_verbatim_start] = ACTIONS(3291),
    [sym_interpolation_raw_start] = ACTIONS(3291),
    [sym_raw_string_start] = ACTIONS(3291),
  },
  [2436] = {
    [sym_preproc_region] = STATE(2436),
    [sym_preproc_endregion] = STATE(2436),
    [sym_preproc_line] = STATE(2436),
    [sym_preproc_pragma] = STATE(2436),
    [sym_preproc_nullable] = STATE(2436),
    [sym_preproc_error] = STATE(2436),
    [sym_preproc_warning] = STATE(2436),
    [sym_preproc_define] = STATE(2436),
    [sym_preproc_undef] = STATE(2436),
    [ts_builtin_sym_end] = ACTIONS(3071),
    [sym__identifier_token] = ACTIONS(3069),
    [anon_sym_extern] = ACTIONS(3069),
    [anon_sym_alias] = ACTIONS(3069),
    [anon_sym_SEMI] = ACTIONS(3071),
    [anon_sym_global] = ACTIONS(3069),
    [anon_sym_using] = ACTIONS(3069),
    [anon_sym_unsafe] = ACTIONS(3069),
    [anon_sym_static] = ACTIONS(3069),
    [anon_sym_LBRACK] = ACTIONS(3071),
    [anon_sym_LPAREN] = ACTIONS(3071),
    [anon_sym_return] = ACTIONS(3069),
    [anon_sym_namespace] = ACTIONS(3069),
    [anon_sym_class] = ACTIONS(3069),
    [anon_sym_ref] = ACTIONS(3069),
    [anon_sym_struct] = ACTIONS(3069),
    [anon_sym_enum] = ACTIONS(3069),
    [anon_sym_LBRACE] = ACTIONS(3071),
    [anon_sym_interface] = ACTIONS(3069),
    [anon_sym_delegate] = ACTIONS(3069),
    [anon_sym_record] = ACTIONS(3069),
    [anon_sym_abstract] = ACTIONS(3069),
    [anon_sym_async] = ACTIONS(3069),
    [anon_sym_const] = ACTIONS(3069),
    [anon_sym_file] = ACTIONS(3069),
    [anon_sym_fixed] = ACTIONS(3069),
    [anon_sym_internal] = ACTIONS(3069),
    [anon_sym_new] = ACTIONS(3069),
    [anon_sym_override] = ACTIONS(3069),
    [anon_sym_partial] = ACTIONS(3069),
    [anon_sym_private] = ACTIONS(3069),
    [anon_sym_protected] = ACTIONS(3069),
    [anon_sym_public] = ACTIONS(3069),
    [anon_sym_readonly] = ACTIONS(3069),
    [anon_sym_required] = ACTIONS(3069),
    [anon_sym_sealed] = ACTIONS(3069),
    [anon_sym_virtual] = ACTIONS(3069),
    [anon_sym_volatile] = ACTIONS(3069),
    [anon_sym_where] = ACTIONS(3069),
    [anon_sym_notnull] = ACTIONS(3069),
    [anon_sym_unmanaged] = ACTIONS(3069),
    [anon_sym_checked] = ACTIONS(3069),
    [anon_sym_BANG] = ACTIONS(3071),
    [anon_sym_TILDE] = ACTIONS(3071),
    [anon_sym_PLUS_PLUS] = ACTIONS(3071),
    [anon_sym_DASH_DASH] = ACTIONS(3071),
    [anon_sym_true] = ACTIONS(3069),
    [anon_sym_false] = ACTIONS(3069),
    [anon_sym_PLUS] = ACTIONS(3069),
    [anon_sym_DASH] = ACTIONS(3069),
    [anon_sym_STAR] = ACTIONS(3071),
    [anon_sym_CARET] = ACTIONS(3071),
    [anon_sym_AMP] = ACTIONS(3071),
    [anon_sym_this] = ACTIONS(3069),
    [anon_sym_scoped] = ACTIONS(3069),
    [anon_sym_base] = ACTIONS(3069),
    [anon_sym_var] = ACTIONS(3069),
    [sym_predefined_type] = ACTIONS(3069),
    [anon_sym_break] = ACTIONS(3069),
    [anon_sym_unchecked] = ACTIONS(3069),
    [anon_sym_continue] = ACTIONS(3069),
    [anon_sym_do] = ACTIONS(3069),
    [anon_sym_while] = ACTIONS(3069),
    [anon_sym_for] = ACTIONS(3069),
    [anon_sym_lock] = ACTIONS(3069),
    [anon_sym_yield] = ACTIONS(3069),
    [anon_sym_switch] = ACTIONS(3069),
    [anon_sym_default] = ACTIONS(3069),
    [anon_sym_throw] = ACTIONS(3069),
    [anon_sym_try] = ACTIONS(3069),
    [anon_sym_when] = ACTIONS(3069),
    [anon_sym_await] = ACTIONS(3069),
    [anon_sym_foreach] = ACTIONS(3069),
    [anon_sym_goto] = ACTIONS(3069),
    [anon_sym_if] = ACTIONS(3069),
    [anon_sym_else] = ACTIONS(3069),
    [anon_sym_DOT_DOT] = ACTIONS(3071),
    [anon_sym_from] = ACTIONS(3069),
    [anon_sym_into] = ACTIONS(3069),
    [anon_sym_join] = ACTIONS(3069),
    [anon_sym_on] = ACTIONS(3069),
    [anon_sym_equals] = ACTIONS(3069),
    [anon_sym_let] = ACTIONS(3069),
    [anon_sym_orderby] = ACTIONS(3069),
    [anon_sym_ascending] = ACTIONS(3069),
    [anon_sym_descending] = ACTIONS(3069),
    [anon_sym_group] = ACTIONS(3069),
    [anon_sym_by] = ACTIONS(3069),
    [anon_sym_select] = ACTIONS(3069),
    [anon_sym_stackalloc] = ACTIONS(3069),
    [anon_sym_sizeof] = ACTIONS(3069),
    [anon_sym_typeof] = ACTIONS(3069),
    [anon_sym___makeref] = ACTIONS(3069),
    [anon_sym___reftype] = ACTIONS(3069),
    [anon_sym___refvalue] = ACTIONS(3069),
    [sym_null_literal] = ACTIONS(3069),
    [anon_sym_SQUOTE] = ACTIONS(3071),
    [sym_integer_literal] = ACTIONS(3069),
    [sym_real_literal] = ACTIONS(3071),
    [anon_sym_DQUOTE] = ACTIONS(3071),
    [sym_verbatim_string_literal] = ACTIONS(3071),
    [aux_sym_preproc_if_token1] = ACTIONS(3071),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3071),
    [sym_interpolation_verbatim_start] = ACTIONS(3071),
    [sym_interpolation_raw_start] = ACTIONS(3071),
    [sym_raw_string_start] = ACTIONS(3071),
  },
  [2437] = {
    [sym_preproc_region] = STATE(2437),
    [sym_preproc_endregion] = STATE(2437),
    [sym_preproc_line] = STATE(2437),
    [sym_preproc_pragma] = STATE(2437),
    [sym_preproc_nullable] = STATE(2437),
    [sym_preproc_error] = STATE(2437),
    [sym_preproc_warning] = STATE(2437),
    [sym_preproc_define] = STATE(2437),
    [sym_preproc_undef] = STATE(2437),
    [ts_builtin_sym_end] = ACTIONS(3383),
    [sym__identifier_token] = ACTIONS(3381),
    [anon_sym_extern] = ACTIONS(3381),
    [anon_sym_alias] = ACTIONS(3381),
    [anon_sym_SEMI] = ACTIONS(3383),
    [anon_sym_global] = ACTIONS(3381),
    [anon_sym_using] = ACTIONS(3381),
    [anon_sym_unsafe] = ACTIONS(3381),
    [anon_sym_static] = ACTIONS(3381),
    [anon_sym_LBRACK] = ACTIONS(3383),
    [anon_sym_LPAREN] = ACTIONS(3383),
    [anon_sym_return] = ACTIONS(3381),
    [anon_sym_namespace] = ACTIONS(3381),
    [anon_sym_class] = ACTIONS(3381),
    [anon_sym_ref] = ACTIONS(3381),
    [anon_sym_struct] = ACTIONS(3381),
    [anon_sym_enum] = ACTIONS(3381),
    [anon_sym_LBRACE] = ACTIONS(3383),
    [anon_sym_interface] = ACTIONS(3381),
    [anon_sym_delegate] = ACTIONS(3381),
    [anon_sym_record] = ACTIONS(3381),
    [anon_sym_abstract] = ACTIONS(3381),
    [anon_sym_async] = ACTIONS(3381),
    [anon_sym_const] = ACTIONS(3381),
    [anon_sym_file] = ACTIONS(3381),
    [anon_sym_fixed] = ACTIONS(3381),
    [anon_sym_internal] = ACTIONS(3381),
    [anon_sym_new] = ACTIONS(3381),
    [anon_sym_override] = ACTIONS(3381),
    [anon_sym_partial] = ACTIONS(3381),
    [anon_sym_private] = ACTIONS(3381),
    [anon_sym_protected] = ACTIONS(3381),
    [anon_sym_public] = ACTIONS(3381),
    [anon_sym_readonly] = ACTIONS(3381),
    [anon_sym_required] = ACTIONS(3381),
    [anon_sym_sealed] = ACTIONS(3381),
    [anon_sym_virtual] = ACTIONS(3381),
    [anon_sym_volatile] = ACTIONS(3381),
    [anon_sym_where] = ACTIONS(3381),
    [anon_sym_notnull] = ACTIONS(3381),
    [anon_sym_unmanaged] = ACTIONS(3381),
    [anon_sym_checked] = ACTIONS(3381),
    [anon_sym_BANG] = ACTIONS(3383),
    [anon_sym_TILDE] = ACTIONS(3383),
    [anon_sym_PLUS_PLUS] = ACTIONS(3383),
    [anon_sym_DASH_DASH] = ACTIONS(3383),
    [anon_sym_true] = ACTIONS(3381),
    [anon_sym_false] = ACTIONS(3381),
    [anon_sym_PLUS] = ACTIONS(3381),
    [anon_sym_DASH] = ACTIONS(3381),
    [anon_sym_STAR] = ACTIONS(3383),
    [anon_sym_CARET] = ACTIONS(3383),
    [anon_sym_AMP] = ACTIONS(3383),
    [anon_sym_this] = ACTIONS(3381),
    [anon_sym_scoped] = ACTIONS(3381),
    [anon_sym_base] = ACTIONS(3381),
    [anon_sym_var] = ACTIONS(3381),
    [sym_predefined_type] = ACTIONS(3381),
    [anon_sym_break] = ACTIONS(3381),
    [anon_sym_unchecked] = ACTIONS(3381),
    [anon_sym_continue] = ACTIONS(3381),
    [anon_sym_do] = ACTIONS(3381),
    [anon_sym_while] = ACTIONS(3381),
    [anon_sym_for] = ACTIONS(3381),
    [anon_sym_lock] = ACTIONS(3381),
    [anon_sym_yield] = ACTIONS(3381),
    [anon_sym_switch] = ACTIONS(3381),
    [anon_sym_default] = ACTIONS(3381),
    [anon_sym_throw] = ACTIONS(3381),
    [anon_sym_try] = ACTIONS(3381),
    [anon_sym_when] = ACTIONS(3381),
    [anon_sym_await] = ACTIONS(3381),
    [anon_sym_foreach] = ACTIONS(3381),
    [anon_sym_goto] = ACTIONS(3381),
    [anon_sym_if] = ACTIONS(3381),
    [anon_sym_else] = ACTIONS(3381),
    [anon_sym_DOT_DOT] = ACTIONS(3383),
    [anon_sym_from] = ACTIONS(3381),
    [anon_sym_into] = ACTIONS(3381),
    [anon_sym_join] = ACTIONS(3381),
    [anon_sym_on] = ACTIONS(3381),
    [anon_sym_equals] = ACTIONS(3381),
    [anon_sym_let] = ACTIONS(3381),
    [anon_sym_orderby] = ACTIONS(3381),
    [anon_sym_ascending] = ACTIONS(3381),
    [anon_sym_descending] = ACTIONS(3381),
    [anon_sym_group] = ACTIONS(3381),
    [anon_sym_by] = ACTIONS(3381),
    [anon_sym_select] = ACTIONS(3381),
    [anon_sym_stackalloc] = ACTIONS(3381),
    [anon_sym_sizeof] = ACTIONS(3381),
    [anon_sym_typeof] = ACTIONS(3381),
    [anon_sym___makeref] = ACTIONS(3381),
    [anon_sym___reftype] = ACTIONS(3381),
    [anon_sym___refvalue] = ACTIONS(3381),
    [sym_null_literal] = ACTIONS(3381),
    [anon_sym_SQUOTE] = ACTIONS(3383),
    [sym_integer_literal] = ACTIONS(3381),
    [sym_real_literal] = ACTIONS(3383),
    [anon_sym_DQUOTE] = ACTIONS(3383),
    [sym_verbatim_string_literal] = ACTIONS(3383),
    [aux_sym_preproc_if_token1] = ACTIONS(3383),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3383),
    [sym_interpolation_verbatim_start] = ACTIONS(3383),
    [sym_interpolation_raw_start] = ACTIONS(3383),
    [sym_raw_string_start] = ACTIONS(3383),
  },
  [2438] = {
    [sym_preproc_region] = STATE(2438),
    [sym_preproc_endregion] = STATE(2438),
    [sym_preproc_line] = STATE(2438),
    [sym_preproc_pragma] = STATE(2438),
    [sym_preproc_nullable] = STATE(2438),
    [sym_preproc_error] = STATE(2438),
    [sym_preproc_warning] = STATE(2438),
    [sym_preproc_define] = STATE(2438),
    [sym_preproc_undef] = STATE(2438),
    [ts_builtin_sym_end] = ACTIONS(3175),
    [sym__identifier_token] = ACTIONS(3173),
    [anon_sym_extern] = ACTIONS(3173),
    [anon_sym_alias] = ACTIONS(3173),
    [anon_sym_SEMI] = ACTIONS(3175),
    [anon_sym_global] = ACTIONS(3173),
    [anon_sym_using] = ACTIONS(3173),
    [anon_sym_unsafe] = ACTIONS(3173),
    [anon_sym_static] = ACTIONS(3173),
    [anon_sym_LBRACK] = ACTIONS(3175),
    [anon_sym_LPAREN] = ACTIONS(3175),
    [anon_sym_return] = ACTIONS(3173),
    [anon_sym_namespace] = ACTIONS(3173),
    [anon_sym_class] = ACTIONS(3173),
    [anon_sym_ref] = ACTIONS(3173),
    [anon_sym_struct] = ACTIONS(3173),
    [anon_sym_enum] = ACTIONS(3173),
    [anon_sym_LBRACE] = ACTIONS(3175),
    [anon_sym_interface] = ACTIONS(3173),
    [anon_sym_delegate] = ACTIONS(3173),
    [anon_sym_record] = ACTIONS(3173),
    [anon_sym_abstract] = ACTIONS(3173),
    [anon_sym_async] = ACTIONS(3173),
    [anon_sym_const] = ACTIONS(3173),
    [anon_sym_file] = ACTIONS(3173),
    [anon_sym_fixed] = ACTIONS(3173),
    [anon_sym_internal] = ACTIONS(3173),
    [anon_sym_new] = ACTIONS(3173),
    [anon_sym_override] = ACTIONS(3173),
    [anon_sym_partial] = ACTIONS(3173),
    [anon_sym_private] = ACTIONS(3173),
    [anon_sym_protected] = ACTIONS(3173),
    [anon_sym_public] = ACTIONS(3173),
    [anon_sym_readonly] = ACTIONS(3173),
    [anon_sym_required] = ACTIONS(3173),
    [anon_sym_sealed] = ACTIONS(3173),
    [anon_sym_virtual] = ACTIONS(3173),
    [anon_sym_volatile] = ACTIONS(3173),
    [anon_sym_where] = ACTIONS(3173),
    [anon_sym_notnull] = ACTIONS(3173),
    [anon_sym_unmanaged] = ACTIONS(3173),
    [anon_sym_checked] = ACTIONS(3173),
    [anon_sym_BANG] = ACTIONS(3175),
    [anon_sym_TILDE] = ACTIONS(3175),
    [anon_sym_PLUS_PLUS] = ACTIONS(3175),
    [anon_sym_DASH_DASH] = ACTIONS(3175),
    [anon_sym_true] = ACTIONS(3173),
    [anon_sym_false] = ACTIONS(3173),
    [anon_sym_PLUS] = ACTIONS(3173),
    [anon_sym_DASH] = ACTIONS(3173),
    [anon_sym_STAR] = ACTIONS(3175),
    [anon_sym_CARET] = ACTIONS(3175),
    [anon_sym_AMP] = ACTIONS(3175),
    [anon_sym_this] = ACTIONS(3173),
    [anon_sym_scoped] = ACTIONS(3173),
    [anon_sym_base] = ACTIONS(3173),
    [anon_sym_var] = ACTIONS(3173),
    [sym_predefined_type] = ACTIONS(3173),
    [anon_sym_break] = ACTIONS(3173),
    [anon_sym_unchecked] = ACTIONS(3173),
    [anon_sym_continue] = ACTIONS(3173),
    [anon_sym_do] = ACTIONS(3173),
    [anon_sym_while] = ACTIONS(3173),
    [anon_sym_for] = ACTIONS(3173),
    [anon_sym_lock] = ACTIONS(3173),
    [anon_sym_yield] = ACTIONS(3173),
    [anon_sym_switch] = ACTIONS(3173),
    [anon_sym_default] = ACTIONS(3173),
    [anon_sym_throw] = ACTIONS(3173),
    [anon_sym_try] = ACTIONS(3173),
    [anon_sym_when] = ACTIONS(3173),
    [anon_sym_await] = ACTIONS(3173),
    [anon_sym_foreach] = ACTIONS(3173),
    [anon_sym_goto] = ACTIONS(3173),
    [anon_sym_if] = ACTIONS(3173),
    [anon_sym_else] = ACTIONS(3173),
    [anon_sym_DOT_DOT] = ACTIONS(3175),
    [anon_sym_from] = ACTIONS(3173),
    [anon_sym_into] = ACTIONS(3173),
    [anon_sym_join] = ACTIONS(3173),
    [anon_sym_on] = ACTIONS(3173),
    [anon_sym_equals] = ACTIONS(3173),
    [anon_sym_let] = ACTIONS(3173),
    [anon_sym_orderby] = ACTIONS(3173),
    [anon_sym_ascending] = ACTIONS(3173),
    [anon_sym_descending] = ACTIONS(3173),
    [anon_sym_group] = ACTIONS(3173),
    [anon_sym_by] = ACTIONS(3173),
    [anon_sym_select] = ACTIONS(3173),
    [anon_sym_stackalloc] = ACTIONS(3173),
    [anon_sym_sizeof] = ACTIONS(3173),
    [anon_sym_typeof] = ACTIONS(3173),
    [anon_sym___makeref] = ACTIONS(3173),
    [anon_sym___reftype] = ACTIONS(3173),
    [anon_sym___refvalue] = ACTIONS(3173),
    [sym_null_literal] = ACTIONS(3173),
    [anon_sym_SQUOTE] = ACTIONS(3175),
    [sym_integer_literal] = ACTIONS(3173),
    [sym_real_literal] = ACTIONS(3175),
    [anon_sym_DQUOTE] = ACTIONS(3175),
    [sym_verbatim_string_literal] = ACTIONS(3175),
    [aux_sym_preproc_if_token1] = ACTIONS(3175),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3175),
    [sym_interpolation_verbatim_start] = ACTIONS(3175),
    [sym_interpolation_raw_start] = ACTIONS(3175),
    [sym_raw_string_start] = ACTIONS(3175),
  },
  [2439] = {
    [sym_preproc_region] = STATE(2439),
    [sym_preproc_endregion] = STATE(2439),
    [sym_preproc_line] = STATE(2439),
    [sym_preproc_pragma] = STATE(2439),
    [sym_preproc_nullable] = STATE(2439),
    [sym_preproc_error] = STATE(2439),
    [sym_preproc_warning] = STATE(2439),
    [sym_preproc_define] = STATE(2439),
    [sym_preproc_undef] = STATE(2439),
    [ts_builtin_sym_end] = ACTIONS(3387),
    [sym__identifier_token] = ACTIONS(3385),
    [anon_sym_extern] = ACTIONS(3385),
    [anon_sym_alias] = ACTIONS(3385),
    [anon_sym_SEMI] = ACTIONS(3387),
    [anon_sym_global] = ACTIONS(3385),
    [anon_sym_using] = ACTIONS(3385),
    [anon_sym_unsafe] = ACTIONS(3385),
    [anon_sym_static] = ACTIONS(3385),
    [anon_sym_LBRACK] = ACTIONS(3387),
    [anon_sym_LPAREN] = ACTIONS(3387),
    [anon_sym_return] = ACTIONS(3385),
    [anon_sym_namespace] = ACTIONS(3385),
    [anon_sym_class] = ACTIONS(3385),
    [anon_sym_ref] = ACTIONS(3385),
    [anon_sym_struct] = ACTIONS(3385),
    [anon_sym_enum] = ACTIONS(3385),
    [anon_sym_LBRACE] = ACTIONS(3387),
    [anon_sym_interface] = ACTIONS(3385),
    [anon_sym_delegate] = ACTIONS(3385),
    [anon_sym_record] = ACTIONS(3385),
    [anon_sym_abstract] = ACTIONS(3385),
    [anon_sym_async] = ACTIONS(3385),
    [anon_sym_const] = ACTIONS(3385),
    [anon_sym_file] = ACTIONS(3385),
    [anon_sym_fixed] = ACTIONS(3385),
    [anon_sym_internal] = ACTIONS(3385),
    [anon_sym_new] = ACTIONS(3385),
    [anon_sym_override] = ACTIONS(3385),
    [anon_sym_partial] = ACTIONS(3385),
    [anon_sym_private] = ACTIONS(3385),
    [anon_sym_protected] = ACTIONS(3385),
    [anon_sym_public] = ACTIONS(3385),
    [anon_sym_readonly] = ACTIONS(3385),
    [anon_sym_required] = ACTIONS(3385),
    [anon_sym_sealed] = ACTIONS(3385),
    [anon_sym_virtual] = ACTIONS(3385),
    [anon_sym_volatile] = ACTIONS(3385),
    [anon_sym_where] = ACTIONS(3385),
    [anon_sym_notnull] = ACTIONS(3385),
    [anon_sym_unmanaged] = ACTIONS(3385),
    [anon_sym_checked] = ACTIONS(3385),
    [anon_sym_BANG] = ACTIONS(3387),
    [anon_sym_TILDE] = ACTIONS(3387),
    [anon_sym_PLUS_PLUS] = ACTIONS(3387),
    [anon_sym_DASH_DASH] = ACTIONS(3387),
    [anon_sym_true] = ACTIONS(3385),
    [anon_sym_false] = ACTIONS(3385),
    [anon_sym_PLUS] = ACTIONS(3385),
    [anon_sym_DASH] = ACTIONS(3385),
    [anon_sym_STAR] = ACTIONS(3387),
    [anon_sym_CARET] = ACTIONS(3387),
    [anon_sym_AMP] = ACTIONS(3387),
    [anon_sym_this] = ACTIONS(3385),
    [anon_sym_scoped] = ACTIONS(3385),
    [anon_sym_base] = ACTIONS(3385),
    [anon_sym_var] = ACTIONS(3385),
    [sym_predefined_type] = ACTIONS(3385),
    [anon_sym_break] = ACTIONS(3385),
    [anon_sym_unchecked] = ACTIONS(3385),
    [anon_sym_continue] = ACTIONS(3385),
    [anon_sym_do] = ACTIONS(3385),
    [anon_sym_while] = ACTIONS(3385),
    [anon_sym_for] = ACTIONS(3385),
    [anon_sym_lock] = ACTIONS(3385),
    [anon_sym_yield] = ACTIONS(3385),
    [anon_sym_switch] = ACTIONS(3385),
    [anon_sym_default] = ACTIONS(3385),
    [anon_sym_throw] = ACTIONS(3385),
    [anon_sym_try] = ACTIONS(3385),
    [anon_sym_when] = ACTIONS(3385),
    [anon_sym_await] = ACTIONS(3385),
    [anon_sym_foreach] = ACTIONS(3385),
    [anon_sym_goto] = ACTIONS(3385),
    [anon_sym_if] = ACTIONS(3385),
    [anon_sym_else] = ACTIONS(3385),
    [anon_sym_DOT_DOT] = ACTIONS(3387),
    [anon_sym_from] = ACTIONS(3385),
    [anon_sym_into] = ACTIONS(3385),
    [anon_sym_join] = ACTIONS(3385),
    [anon_sym_on] = ACTIONS(3385),
    [anon_sym_equals] = ACTIONS(3385),
    [anon_sym_let] = ACTIONS(3385),
    [anon_sym_orderby] = ACTIONS(3385),
    [anon_sym_ascending] = ACTIONS(3385),
    [anon_sym_descending] = ACTIONS(3385),
    [anon_sym_group] = ACTIONS(3385),
    [anon_sym_by] = ACTIONS(3385),
    [anon_sym_select] = ACTIONS(3385),
    [anon_sym_stackalloc] = ACTIONS(3385),
    [anon_sym_sizeof] = ACTIONS(3385),
    [anon_sym_typeof] = ACTIONS(3385),
    [anon_sym___makeref] = ACTIONS(3385),
    [anon_sym___reftype] = ACTIONS(3385),
    [anon_sym___refvalue] = ACTIONS(3385),
    [sym_null_literal] = ACTIONS(3385),
    [anon_sym_SQUOTE] = ACTIONS(3387),
    [sym_integer_literal] = ACTIONS(3385),
    [sym_real_literal] = ACTIONS(3387),
    [anon_sym_DQUOTE] = ACTIONS(3387),
    [sym_verbatim_string_literal] = ACTIONS(3387),
    [aux_sym_preproc_if_token1] = ACTIONS(3387),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3387),
    [sym_interpolation_verbatim_start] = ACTIONS(3387),
    [sym_interpolation_raw_start] = ACTIONS(3387),
    [sym_raw_string_start] = ACTIONS(3387),
  },
  [2440] = {
    [sym_preproc_region] = STATE(2440),
    [sym_preproc_endregion] = STATE(2440),
    [sym_preproc_line] = STATE(2440),
    [sym_preproc_pragma] = STATE(2440),
    [sym_preproc_nullable] = STATE(2440),
    [sym_preproc_error] = STATE(2440),
    [sym_preproc_warning] = STATE(2440),
    [sym_preproc_define] = STATE(2440),
    [sym_preproc_undef] = STATE(2440),
    [ts_builtin_sym_end] = ACTIONS(3087),
    [sym__identifier_token] = ACTIONS(3085),
    [anon_sym_extern] = ACTIONS(3085),
    [anon_sym_alias] = ACTIONS(3085),
    [anon_sym_SEMI] = ACTIONS(3087),
    [anon_sym_global] = ACTIONS(3085),
    [anon_sym_using] = ACTIONS(3085),
    [anon_sym_unsafe] = ACTIONS(3085),
    [anon_sym_static] = ACTIONS(3085),
    [anon_sym_LBRACK] = ACTIONS(3087),
    [anon_sym_LPAREN] = ACTIONS(3087),
    [anon_sym_return] = ACTIONS(3085),
    [anon_sym_namespace] = ACTIONS(3085),
    [anon_sym_class] = ACTIONS(3085),
    [anon_sym_ref] = ACTIONS(3085),
    [anon_sym_struct] = ACTIONS(3085),
    [anon_sym_enum] = ACTIONS(3085),
    [anon_sym_LBRACE] = ACTIONS(3087),
    [anon_sym_interface] = ACTIONS(3085),
    [anon_sym_delegate] = ACTIONS(3085),
    [anon_sym_record] = ACTIONS(3085),
    [anon_sym_abstract] = ACTIONS(3085),
    [anon_sym_async] = ACTIONS(3085),
    [anon_sym_const] = ACTIONS(3085),
    [anon_sym_file] = ACTIONS(3085),
    [anon_sym_fixed] = ACTIONS(3085),
    [anon_sym_internal] = ACTIONS(3085),
    [anon_sym_new] = ACTIONS(3085),
    [anon_sym_override] = ACTIONS(3085),
    [anon_sym_partial] = ACTIONS(3085),
    [anon_sym_private] = ACTIONS(3085),
    [anon_sym_protected] = ACTIONS(3085),
    [anon_sym_public] = ACTIONS(3085),
    [anon_sym_readonly] = ACTIONS(3085),
    [anon_sym_required] = ACTIONS(3085),
    [anon_sym_sealed] = ACTIONS(3085),
    [anon_sym_virtual] = ACTIONS(3085),
    [anon_sym_volatile] = ACTIONS(3085),
    [anon_sym_where] = ACTIONS(3085),
    [anon_sym_notnull] = ACTIONS(3085),
    [anon_sym_unmanaged] = ACTIONS(3085),
    [anon_sym_checked] = ACTIONS(3085),
    [anon_sym_BANG] = ACTIONS(3087),
    [anon_sym_TILDE] = ACTIONS(3087),
    [anon_sym_PLUS_PLUS] = ACTIONS(3087),
    [anon_sym_DASH_DASH] = ACTIONS(3087),
    [anon_sym_true] = ACTIONS(3085),
    [anon_sym_false] = ACTIONS(3085),
    [anon_sym_PLUS] = ACTIONS(3085),
    [anon_sym_DASH] = ACTIONS(3085),
    [anon_sym_STAR] = ACTIONS(3087),
    [anon_sym_CARET] = ACTIONS(3087),
    [anon_sym_AMP] = ACTIONS(3087),
    [anon_sym_this] = ACTIONS(3085),
    [anon_sym_scoped] = ACTIONS(3085),
    [anon_sym_base] = ACTIONS(3085),
    [anon_sym_var] = ACTIONS(3085),
    [sym_predefined_type] = ACTIONS(3085),
    [anon_sym_break] = ACTIONS(3085),
    [anon_sym_unchecked] = ACTIONS(3085),
    [anon_sym_continue] = ACTIONS(3085),
    [anon_sym_do] = ACTIONS(3085),
    [anon_sym_while] = ACTIONS(3085),
    [anon_sym_for] = ACTIONS(3085),
    [anon_sym_lock] = ACTIONS(3085),
    [anon_sym_yield] = ACTIONS(3085),
    [anon_sym_switch] = ACTIONS(3085),
    [anon_sym_default] = ACTIONS(3085),
    [anon_sym_throw] = ACTIONS(3085),
    [anon_sym_try] = ACTIONS(3085),
    [anon_sym_when] = ACTIONS(3085),
    [anon_sym_await] = ACTIONS(3085),
    [anon_sym_foreach] = ACTIONS(3085),
    [anon_sym_goto] = ACTIONS(3085),
    [anon_sym_if] = ACTIONS(3085),
    [anon_sym_else] = ACTIONS(3085),
    [anon_sym_DOT_DOT] = ACTIONS(3087),
    [anon_sym_from] = ACTIONS(3085),
    [anon_sym_into] = ACTIONS(3085),
    [anon_sym_join] = ACTIONS(3085),
    [anon_sym_on] = ACTIONS(3085),
    [anon_sym_equals] = ACTIONS(3085),
    [anon_sym_let] = ACTIONS(3085),
    [anon_sym_orderby] = ACTIONS(3085),
    [anon_sym_ascending] = ACTIONS(3085),
    [anon_sym_descending] = ACTIONS(3085),
    [anon_sym_group] = ACTIONS(3085),
    [anon_sym_by] = ACTIONS(3085),
    [anon_sym_select] = ACTIONS(3085),
    [anon_sym_stackalloc] = ACTIONS(3085),
    [anon_sym_sizeof] = ACTIONS(3085),
    [anon_sym_typeof] = ACTIONS(3085),
    [anon_sym___makeref] = ACTIONS(3085),
    [anon_sym___reftype] = ACTIONS(3085),
    [anon_sym___refvalue] = ACTIONS(3085),
    [sym_null_literal] = ACTIONS(3085),
    [anon_sym_SQUOTE] = ACTIONS(3087),
    [sym_integer_literal] = ACTIONS(3085),
    [sym_real_literal] = ACTIONS(3087),
    [anon_sym_DQUOTE] = ACTIONS(3087),
    [sym_verbatim_string_literal] = ACTIONS(3087),
    [aux_sym_preproc_if_token1] = ACTIONS(3087),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3087),
    [sym_interpolation_verbatim_start] = ACTIONS(3087),
    [sym_interpolation_raw_start] = ACTIONS(3087),
    [sym_raw_string_start] = ACTIONS(3087),
  },
  [2441] = {
    [sym_preproc_region] = STATE(2441),
    [sym_preproc_endregion] = STATE(2441),
    [sym_preproc_line] = STATE(2441),
    [sym_preproc_pragma] = STATE(2441),
    [sym_preproc_nullable] = STATE(2441),
    [sym_preproc_error] = STATE(2441),
    [sym_preproc_warning] = STATE(2441),
    [sym_preproc_define] = STATE(2441),
    [sym_preproc_undef] = STATE(2441),
    [ts_builtin_sym_end] = ACTIONS(3067),
    [sym__identifier_token] = ACTIONS(3065),
    [anon_sym_extern] = ACTIONS(3065),
    [anon_sym_alias] = ACTIONS(3065),
    [anon_sym_SEMI] = ACTIONS(3067),
    [anon_sym_global] = ACTIONS(3065),
    [anon_sym_using] = ACTIONS(3065),
    [anon_sym_unsafe] = ACTIONS(3065),
    [anon_sym_static] = ACTIONS(3065),
    [anon_sym_LBRACK] = ACTIONS(3067),
    [anon_sym_LPAREN] = ACTIONS(3067),
    [anon_sym_return] = ACTIONS(3065),
    [anon_sym_namespace] = ACTIONS(3065),
    [anon_sym_class] = ACTIONS(3065),
    [anon_sym_ref] = ACTIONS(3065),
    [anon_sym_struct] = ACTIONS(3065),
    [anon_sym_enum] = ACTIONS(3065),
    [anon_sym_LBRACE] = ACTIONS(3067),
    [anon_sym_interface] = ACTIONS(3065),
    [anon_sym_delegate] = ACTIONS(3065),
    [anon_sym_record] = ACTIONS(3065),
    [anon_sym_abstract] = ACTIONS(3065),
    [anon_sym_async] = ACTIONS(3065),
    [anon_sym_const] = ACTIONS(3065),
    [anon_sym_file] = ACTIONS(3065),
    [anon_sym_fixed] = ACTIONS(3065),
    [anon_sym_internal] = ACTIONS(3065),
    [anon_sym_new] = ACTIONS(3065),
    [anon_sym_override] = ACTIONS(3065),
    [anon_sym_partial] = ACTIONS(3065),
    [anon_sym_private] = ACTIONS(3065),
    [anon_sym_protected] = ACTIONS(3065),
    [anon_sym_public] = ACTIONS(3065),
    [anon_sym_readonly] = ACTIONS(3065),
    [anon_sym_required] = ACTIONS(3065),
    [anon_sym_sealed] = ACTIONS(3065),
    [anon_sym_virtual] = ACTIONS(3065),
    [anon_sym_volatile] = ACTIONS(3065),
    [anon_sym_where] = ACTIONS(3065),
    [anon_sym_notnull] = ACTIONS(3065),
    [anon_sym_unmanaged] = ACTIONS(3065),
    [anon_sym_checked] = ACTIONS(3065),
    [anon_sym_BANG] = ACTIONS(3067),
    [anon_sym_TILDE] = ACTIONS(3067),
    [anon_sym_PLUS_PLUS] = ACTIONS(3067),
    [anon_sym_DASH_DASH] = ACTIONS(3067),
    [anon_sym_true] = ACTIONS(3065),
    [anon_sym_false] = ACTIONS(3065),
    [anon_sym_PLUS] = ACTIONS(3065),
    [anon_sym_DASH] = ACTIONS(3065),
    [anon_sym_STAR] = ACTIONS(3067),
    [anon_sym_CARET] = ACTIONS(3067),
    [anon_sym_AMP] = ACTIONS(3067),
    [anon_sym_this] = ACTIONS(3065),
    [anon_sym_scoped] = ACTIONS(3065),
    [anon_sym_base] = ACTIONS(3065),
    [anon_sym_var] = ACTIONS(3065),
    [sym_predefined_type] = ACTIONS(3065),
    [anon_sym_break] = ACTIONS(3065),
    [anon_sym_unchecked] = ACTIONS(3065),
    [anon_sym_continue] = ACTIONS(3065),
    [anon_sym_do] = ACTIONS(3065),
    [anon_sym_while] = ACTIONS(3065),
    [anon_sym_for] = ACTIONS(3065),
    [anon_sym_lock] = ACTIONS(3065),
    [anon_sym_yield] = ACTIONS(3065),
    [anon_sym_switch] = ACTIONS(3065),
    [anon_sym_default] = ACTIONS(3065),
    [anon_sym_throw] = ACTIONS(3065),
    [anon_sym_try] = ACTIONS(3065),
    [anon_sym_when] = ACTIONS(3065),
    [anon_sym_await] = ACTIONS(3065),
    [anon_sym_foreach] = ACTIONS(3065),
    [anon_sym_goto] = ACTIONS(3065),
    [anon_sym_if] = ACTIONS(3065),
    [anon_sym_else] = ACTIONS(3065),
    [anon_sym_DOT_DOT] = ACTIONS(3067),
    [anon_sym_from] = ACTIONS(3065),
    [anon_sym_into] = ACTIONS(3065),
    [anon_sym_join] = ACTIONS(3065),
    [anon_sym_on] = ACTIONS(3065),
    [anon_sym_equals] = ACTIONS(3065),
    [anon_sym_let] = ACTIONS(3065),
    [anon_sym_orderby] = ACTIONS(3065),
    [anon_sym_ascending] = ACTIONS(3065),
    [anon_sym_descending] = ACTIONS(3065),
    [anon_sym_group] = ACTIONS(3065),
    [anon_sym_by] = ACTIONS(3065),
    [anon_sym_select] = ACTIONS(3065),
    [anon_sym_stackalloc] = ACTIONS(3065),
    [anon_sym_sizeof] = ACTIONS(3065),
    [anon_sym_typeof] = ACTIONS(3065),
    [anon_sym___makeref] = ACTIONS(3065),
    [anon_sym___reftype] = ACTIONS(3065),
    [anon_sym___refvalue] = ACTIONS(3065),
    [sym_null_literal] = ACTIONS(3065),
    [anon_sym_SQUOTE] = ACTIONS(3067),
    [sym_integer_literal] = ACTIONS(3065),
    [sym_real_literal] = ACTIONS(3067),
    [anon_sym_DQUOTE] = ACTIONS(3067),
    [sym_verbatim_string_literal] = ACTIONS(3067),
    [aux_sym_preproc_if_token1] = ACTIONS(3067),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3067),
    [sym_interpolation_verbatim_start] = ACTIONS(3067),
    [sym_interpolation_raw_start] = ACTIONS(3067),
    [sym_raw_string_start] = ACTIONS(3067),
  },
  [2442] = {
    [sym_preproc_region] = STATE(2442),
    [sym_preproc_endregion] = STATE(2442),
    [sym_preproc_line] = STATE(2442),
    [sym_preproc_pragma] = STATE(2442),
    [sym_preproc_nullable] = STATE(2442),
    [sym_preproc_error] = STATE(2442),
    [sym_preproc_warning] = STATE(2442),
    [sym_preproc_define] = STATE(2442),
    [sym_preproc_undef] = STATE(2442),
    [ts_builtin_sym_end] = ACTIONS(3295),
    [sym__identifier_token] = ACTIONS(3293),
    [anon_sym_extern] = ACTIONS(3293),
    [anon_sym_alias] = ACTIONS(3293),
    [anon_sym_SEMI] = ACTIONS(3295),
    [anon_sym_global] = ACTIONS(3293),
    [anon_sym_using] = ACTIONS(3293),
    [anon_sym_unsafe] = ACTIONS(3293),
    [anon_sym_static] = ACTIONS(3293),
    [anon_sym_LBRACK] = ACTIONS(3295),
    [anon_sym_LPAREN] = ACTIONS(3295),
    [anon_sym_return] = ACTIONS(3293),
    [anon_sym_namespace] = ACTIONS(3293),
    [anon_sym_class] = ACTIONS(3293),
    [anon_sym_ref] = ACTIONS(3293),
    [anon_sym_struct] = ACTIONS(3293),
    [anon_sym_enum] = ACTIONS(3293),
    [anon_sym_LBRACE] = ACTIONS(3295),
    [anon_sym_interface] = ACTIONS(3293),
    [anon_sym_delegate] = ACTIONS(3293),
    [anon_sym_record] = ACTIONS(3293),
    [anon_sym_abstract] = ACTIONS(3293),
    [anon_sym_async] = ACTIONS(3293),
    [anon_sym_const] = ACTIONS(3293),
    [anon_sym_file] = ACTIONS(3293),
    [anon_sym_fixed] = ACTIONS(3293),
    [anon_sym_internal] = ACTIONS(3293),
    [anon_sym_new] = ACTIONS(3293),
    [anon_sym_override] = ACTIONS(3293),
    [anon_sym_partial] = ACTIONS(3293),
    [anon_sym_private] = ACTIONS(3293),
    [anon_sym_protected] = ACTIONS(3293),
    [anon_sym_public] = ACTIONS(3293),
    [anon_sym_readonly] = ACTIONS(3293),
    [anon_sym_required] = ACTIONS(3293),
    [anon_sym_sealed] = ACTIONS(3293),
    [anon_sym_virtual] = ACTIONS(3293),
    [anon_sym_volatile] = ACTIONS(3293),
    [anon_sym_where] = ACTIONS(3293),
    [anon_sym_notnull] = ACTIONS(3293),
    [anon_sym_unmanaged] = ACTIONS(3293),
    [anon_sym_checked] = ACTIONS(3293),
    [anon_sym_BANG] = ACTIONS(3295),
    [anon_sym_TILDE] = ACTIONS(3295),
    [anon_sym_PLUS_PLUS] = ACTIONS(3295),
    [anon_sym_DASH_DASH] = ACTIONS(3295),
    [anon_sym_true] = ACTIONS(3293),
    [anon_sym_false] = ACTIONS(3293),
    [anon_sym_PLUS] = ACTIONS(3293),
    [anon_sym_DASH] = ACTIONS(3293),
    [anon_sym_STAR] = ACTIONS(3295),
    [anon_sym_CARET] = ACTIONS(3295),
    [anon_sym_AMP] = ACTIONS(3295),
    [anon_sym_this] = ACTIONS(3293),
    [anon_sym_scoped] = ACTIONS(3293),
    [anon_sym_base] = ACTIONS(3293),
    [anon_sym_var] = ACTIONS(3293),
    [sym_predefined_type] = ACTIONS(3293),
    [anon_sym_break] = ACTIONS(3293),
    [anon_sym_unchecked] = ACTIONS(3293),
    [anon_sym_continue] = ACTIONS(3293),
    [anon_sym_do] = ACTIONS(3293),
    [anon_sym_while] = ACTIONS(3293),
    [anon_sym_for] = ACTIONS(3293),
    [anon_sym_lock] = ACTIONS(3293),
    [anon_sym_yield] = ACTIONS(3293),
    [anon_sym_switch] = ACTIONS(3293),
    [anon_sym_default] = ACTIONS(3293),
    [anon_sym_throw] = ACTIONS(3293),
    [anon_sym_try] = ACTIONS(3293),
    [anon_sym_when] = ACTIONS(3293),
    [anon_sym_await] = ACTIONS(3293),
    [anon_sym_foreach] = ACTIONS(3293),
    [anon_sym_goto] = ACTIONS(3293),
    [anon_sym_if] = ACTIONS(3293),
    [anon_sym_else] = ACTIONS(3293),
    [anon_sym_DOT_DOT] = ACTIONS(3295),
    [anon_sym_from] = ACTIONS(3293),
    [anon_sym_into] = ACTIONS(3293),
    [anon_sym_join] = ACTIONS(3293),
    [anon_sym_on] = ACTIONS(3293),
    [anon_sym_equals] = ACTIONS(3293),
    [anon_sym_let] = ACTIONS(3293),
    [anon_sym_orderby] = ACTIONS(3293),
    [anon_sym_ascending] = ACTIONS(3293),
    [anon_sym_descending] = ACTIONS(3293),
    [anon_sym_group] = ACTIONS(3293),
    [anon_sym_by] = ACTIONS(3293),
    [anon_sym_select] = ACTIONS(3293),
    [anon_sym_stackalloc] = ACTIONS(3293),
    [anon_sym_sizeof] = ACTIONS(3293),
    [anon_sym_typeof] = ACTIONS(3293),
    [anon_sym___makeref] = ACTIONS(3293),
    [anon_sym___reftype] = ACTIONS(3293),
    [anon_sym___refvalue] = ACTIONS(3293),
    [sym_null_literal] = ACTIONS(3293),
    [anon_sym_SQUOTE] = ACTIONS(3295),
    [sym_integer_literal] = ACTIONS(3293),
    [sym_real_literal] = ACTIONS(3295),
    [anon_sym_DQUOTE] = ACTIONS(3295),
    [sym_verbatim_string_literal] = ACTIONS(3295),
    [aux_sym_preproc_if_token1] = ACTIONS(3295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3295),
    [sym_interpolation_verbatim_start] = ACTIONS(3295),
    [sym_interpolation_raw_start] = ACTIONS(3295),
    [sym_raw_string_start] = ACTIONS(3295),
  },
  [2443] = {
    [sym_preproc_region] = STATE(2443),
    [sym_preproc_endregion] = STATE(2443),
    [sym_preproc_line] = STATE(2443),
    [sym_preproc_pragma] = STATE(2443),
    [sym_preproc_nullable] = STATE(2443),
    [sym_preproc_error] = STATE(2443),
    [sym_preproc_warning] = STATE(2443),
    [sym_preproc_define] = STATE(2443),
    [sym_preproc_undef] = STATE(2443),
    [ts_builtin_sym_end] = ACTIONS(3337),
    [sym__identifier_token] = ACTIONS(3335),
    [anon_sym_extern] = ACTIONS(3335),
    [anon_sym_alias] = ACTIONS(3335),
    [anon_sym_SEMI] = ACTIONS(3337),
    [anon_sym_global] = ACTIONS(3335),
    [anon_sym_using] = ACTIONS(3335),
    [anon_sym_unsafe] = ACTIONS(3335),
    [anon_sym_static] = ACTIONS(3335),
    [anon_sym_LBRACK] = ACTIONS(3337),
    [anon_sym_LPAREN] = ACTIONS(3337),
    [anon_sym_return] = ACTIONS(3335),
    [anon_sym_namespace] = ACTIONS(3335),
    [anon_sym_class] = ACTIONS(3335),
    [anon_sym_ref] = ACTIONS(3335),
    [anon_sym_struct] = ACTIONS(3335),
    [anon_sym_enum] = ACTIONS(3335),
    [anon_sym_LBRACE] = ACTIONS(3337),
    [anon_sym_interface] = ACTIONS(3335),
    [anon_sym_delegate] = ACTIONS(3335),
    [anon_sym_record] = ACTIONS(3335),
    [anon_sym_abstract] = ACTIONS(3335),
    [anon_sym_async] = ACTIONS(3335),
    [anon_sym_const] = ACTIONS(3335),
    [anon_sym_file] = ACTIONS(3335),
    [anon_sym_fixed] = ACTIONS(3335),
    [anon_sym_internal] = ACTIONS(3335),
    [anon_sym_new] = ACTIONS(3335),
    [anon_sym_override] = ACTIONS(3335),
    [anon_sym_partial] = ACTIONS(3335),
    [anon_sym_private] = ACTIONS(3335),
    [anon_sym_protected] = ACTIONS(3335),
    [anon_sym_public] = ACTIONS(3335),
    [anon_sym_readonly] = ACTIONS(3335),
    [anon_sym_required] = ACTIONS(3335),
    [anon_sym_sealed] = ACTIONS(3335),
    [anon_sym_virtual] = ACTIONS(3335),
    [anon_sym_volatile] = ACTIONS(3335),
    [anon_sym_where] = ACTIONS(3335),
    [anon_sym_notnull] = ACTIONS(3335),
    [anon_sym_unmanaged] = ACTIONS(3335),
    [anon_sym_checked] = ACTIONS(3335),
    [anon_sym_BANG] = ACTIONS(3337),
    [anon_sym_TILDE] = ACTIONS(3337),
    [anon_sym_PLUS_PLUS] = ACTIONS(3337),
    [anon_sym_DASH_DASH] = ACTIONS(3337),
    [anon_sym_true] = ACTIONS(3335),
    [anon_sym_false] = ACTIONS(3335),
    [anon_sym_PLUS] = ACTIONS(3335),
    [anon_sym_DASH] = ACTIONS(3335),
    [anon_sym_STAR] = ACTIONS(3337),
    [anon_sym_CARET] = ACTIONS(3337),
    [anon_sym_AMP] = ACTIONS(3337),
    [anon_sym_this] = ACTIONS(3335),
    [anon_sym_scoped] = ACTIONS(3335),
    [anon_sym_base] = ACTIONS(3335),
    [anon_sym_var] = ACTIONS(3335),
    [sym_predefined_type] = ACTIONS(3335),
    [anon_sym_break] = ACTIONS(3335),
    [anon_sym_unchecked] = ACTIONS(3335),
    [anon_sym_continue] = ACTIONS(3335),
    [anon_sym_do] = ACTIONS(3335),
    [anon_sym_while] = ACTIONS(3335),
    [anon_sym_for] = ACTIONS(3335),
    [anon_sym_lock] = ACTIONS(3335),
    [anon_sym_yield] = ACTIONS(3335),
    [anon_sym_switch] = ACTIONS(3335),
    [anon_sym_default] = ACTIONS(3335),
    [anon_sym_throw] = ACTIONS(3335),
    [anon_sym_try] = ACTIONS(3335),
    [anon_sym_when] = ACTIONS(3335),
    [anon_sym_await] = ACTIONS(3335),
    [anon_sym_foreach] = ACTIONS(3335),
    [anon_sym_goto] = ACTIONS(3335),
    [anon_sym_if] = ACTIONS(3335),
    [anon_sym_else] = ACTIONS(3335),
    [anon_sym_DOT_DOT] = ACTIONS(3337),
    [anon_sym_from] = ACTIONS(3335),
    [anon_sym_into] = ACTIONS(3335),
    [anon_sym_join] = ACTIONS(3335),
    [anon_sym_on] = ACTIONS(3335),
    [anon_sym_equals] = ACTIONS(3335),
    [anon_sym_let] = ACTIONS(3335),
    [anon_sym_orderby] = ACTIONS(3335),
    [anon_sym_ascending] = ACTIONS(3335),
    [anon_sym_descending] = ACTIONS(3335),
    [anon_sym_group] = ACTIONS(3335),
    [anon_sym_by] = ACTIONS(3335),
    [anon_sym_select] = ACTIONS(3335),
    [anon_sym_stackalloc] = ACTIONS(3335),
    [anon_sym_sizeof] = ACTIONS(3335),
    [anon_sym_typeof] = ACTIONS(3335),
    [anon_sym___makeref] = ACTIONS(3335),
    [anon_sym___reftype] = ACTIONS(3335),
    [anon_sym___refvalue] = ACTIONS(3335),
    [sym_null_literal] = ACTIONS(3335),
    [anon_sym_SQUOTE] = ACTIONS(3337),
    [sym_integer_literal] = ACTIONS(3335),
    [sym_real_literal] = ACTIONS(3337),
    [anon_sym_DQUOTE] = ACTIONS(3337),
    [sym_verbatim_string_literal] = ACTIONS(3337),
    [aux_sym_preproc_if_token1] = ACTIONS(3337),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3337),
    [sym_interpolation_verbatim_start] = ACTIONS(3337),
    [sym_interpolation_raw_start] = ACTIONS(3337),
    [sym_raw_string_start] = ACTIONS(3337),
  },
  [2444] = {
    [sym_preproc_region] = STATE(2444),
    [sym_preproc_endregion] = STATE(2444),
    [sym_preproc_line] = STATE(2444),
    [sym_preproc_pragma] = STATE(2444),
    [sym_preproc_nullable] = STATE(2444),
    [sym_preproc_error] = STATE(2444),
    [sym_preproc_warning] = STATE(2444),
    [sym_preproc_define] = STATE(2444),
    [sym_preproc_undef] = STATE(2444),
    [ts_builtin_sym_end] = ACTIONS(3391),
    [sym__identifier_token] = ACTIONS(3389),
    [anon_sym_extern] = ACTIONS(3389),
    [anon_sym_alias] = ACTIONS(3389),
    [anon_sym_SEMI] = ACTIONS(3391),
    [anon_sym_global] = ACTIONS(3389),
    [anon_sym_using] = ACTIONS(3389),
    [anon_sym_unsafe] = ACTIONS(3389),
    [anon_sym_static] = ACTIONS(3389),
    [anon_sym_LBRACK] = ACTIONS(3391),
    [anon_sym_LPAREN] = ACTIONS(3391),
    [anon_sym_return] = ACTIONS(3389),
    [anon_sym_namespace] = ACTIONS(3389),
    [anon_sym_class] = ACTIONS(3389),
    [anon_sym_ref] = ACTIONS(3389),
    [anon_sym_struct] = ACTIONS(3389),
    [anon_sym_enum] = ACTIONS(3389),
    [anon_sym_LBRACE] = ACTIONS(3391),
    [anon_sym_interface] = ACTIONS(3389),
    [anon_sym_delegate] = ACTIONS(3389),
    [anon_sym_record] = ACTIONS(3389),
    [anon_sym_abstract] = ACTIONS(3389),
    [anon_sym_async] = ACTIONS(3389),
    [anon_sym_const] = ACTIONS(3389),
    [anon_sym_file] = ACTIONS(3389),
    [anon_sym_fixed] = ACTIONS(3389),
    [anon_sym_internal] = ACTIONS(3389),
    [anon_sym_new] = ACTIONS(3389),
    [anon_sym_override] = ACTIONS(3389),
    [anon_sym_partial] = ACTIONS(3389),
    [anon_sym_private] = ACTIONS(3389),
    [anon_sym_protected] = ACTIONS(3389),
    [anon_sym_public] = ACTIONS(3389),
    [anon_sym_readonly] = ACTIONS(3389),
    [anon_sym_required] = ACTIONS(3389),
    [anon_sym_sealed] = ACTIONS(3389),
    [anon_sym_virtual] = ACTIONS(3389),
    [anon_sym_volatile] = ACTIONS(3389),
    [anon_sym_where] = ACTIONS(3389),
    [anon_sym_notnull] = ACTIONS(3389),
    [anon_sym_unmanaged] = ACTIONS(3389),
    [anon_sym_checked] = ACTIONS(3389),
    [anon_sym_BANG] = ACTIONS(3391),
    [anon_sym_TILDE] = ACTIONS(3391),
    [anon_sym_PLUS_PLUS] = ACTIONS(3391),
    [anon_sym_DASH_DASH] = ACTIONS(3391),
    [anon_sym_true] = ACTIONS(3389),
    [anon_sym_false] = ACTIONS(3389),
    [anon_sym_PLUS] = ACTIONS(3389),
    [anon_sym_DASH] = ACTIONS(3389),
    [anon_sym_STAR] = ACTIONS(3391),
    [anon_sym_CARET] = ACTIONS(3391),
    [anon_sym_AMP] = ACTIONS(3391),
    [anon_sym_this] = ACTIONS(3389),
    [anon_sym_scoped] = ACTIONS(3389),
    [anon_sym_base] = ACTIONS(3389),
    [anon_sym_var] = ACTIONS(3389),
    [sym_predefined_type] = ACTIONS(3389),
    [anon_sym_break] = ACTIONS(3389),
    [anon_sym_unchecked] = ACTIONS(3389),
    [anon_sym_continue] = ACTIONS(3389),
    [anon_sym_do] = ACTIONS(3389),
    [anon_sym_while] = ACTIONS(3389),
    [anon_sym_for] = ACTIONS(3389),
    [anon_sym_lock] = ACTIONS(3389),
    [anon_sym_yield] = ACTIONS(3389),
    [anon_sym_switch] = ACTIONS(3389),
    [anon_sym_default] = ACTIONS(3389),
    [anon_sym_throw] = ACTIONS(3389),
    [anon_sym_try] = ACTIONS(3389),
    [anon_sym_when] = ACTIONS(3389),
    [anon_sym_await] = ACTIONS(3389),
    [anon_sym_foreach] = ACTIONS(3389),
    [anon_sym_goto] = ACTIONS(3389),
    [anon_sym_if] = ACTIONS(3389),
    [anon_sym_else] = ACTIONS(3389),
    [anon_sym_DOT_DOT] = ACTIONS(3391),
    [anon_sym_from] = ACTIONS(3389),
    [anon_sym_into] = ACTIONS(3389),
    [anon_sym_join] = ACTIONS(3389),
    [anon_sym_on] = ACTIONS(3389),
    [anon_sym_equals] = ACTIONS(3389),
    [anon_sym_let] = ACTIONS(3389),
    [anon_sym_orderby] = ACTIONS(3389),
    [anon_sym_ascending] = ACTIONS(3389),
    [anon_sym_descending] = ACTIONS(3389),
    [anon_sym_group] = ACTIONS(3389),
    [anon_sym_by] = ACTIONS(3389),
    [anon_sym_select] = ACTIONS(3389),
    [anon_sym_stackalloc] = ACTIONS(3389),
    [anon_sym_sizeof] = ACTIONS(3389),
    [anon_sym_typeof] = ACTIONS(3389),
    [anon_sym___makeref] = ACTIONS(3389),
    [anon_sym___reftype] = ACTIONS(3389),
    [anon_sym___refvalue] = ACTIONS(3389),
    [sym_null_literal] = ACTIONS(3389),
    [anon_sym_SQUOTE] = ACTIONS(3391),
    [sym_integer_literal] = ACTIONS(3389),
    [sym_real_literal] = ACTIONS(3391),
    [anon_sym_DQUOTE] = ACTIONS(3391),
    [sym_verbatim_string_literal] = ACTIONS(3391),
    [aux_sym_preproc_if_token1] = ACTIONS(3391),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3391),
    [sym_interpolation_verbatim_start] = ACTIONS(3391),
    [sym_interpolation_raw_start] = ACTIONS(3391),
    [sym_raw_string_start] = ACTIONS(3391),
  },
  [2445] = {
    [sym_preproc_region] = STATE(2445),
    [sym_preproc_endregion] = STATE(2445),
    [sym_preproc_line] = STATE(2445),
    [sym_preproc_pragma] = STATE(2445),
    [sym_preproc_nullable] = STATE(2445),
    [sym_preproc_error] = STATE(2445),
    [sym_preproc_warning] = STATE(2445),
    [sym_preproc_define] = STATE(2445),
    [sym_preproc_undef] = STATE(2445),
    [ts_builtin_sym_end] = ACTIONS(3179),
    [sym__identifier_token] = ACTIONS(3177),
    [anon_sym_extern] = ACTIONS(3177),
    [anon_sym_alias] = ACTIONS(3177),
    [anon_sym_SEMI] = ACTIONS(3179),
    [anon_sym_global] = ACTIONS(3177),
    [anon_sym_using] = ACTIONS(3177),
    [anon_sym_unsafe] = ACTIONS(3177),
    [anon_sym_static] = ACTIONS(3177),
    [anon_sym_LBRACK] = ACTIONS(3179),
    [anon_sym_LPAREN] = ACTIONS(3179),
    [anon_sym_return] = ACTIONS(3177),
    [anon_sym_namespace] = ACTIONS(3177),
    [anon_sym_class] = ACTIONS(3177),
    [anon_sym_ref] = ACTIONS(3177),
    [anon_sym_struct] = ACTIONS(3177),
    [anon_sym_enum] = ACTIONS(3177),
    [anon_sym_LBRACE] = ACTIONS(3179),
    [anon_sym_interface] = ACTIONS(3177),
    [anon_sym_delegate] = ACTIONS(3177),
    [anon_sym_record] = ACTIONS(3177),
    [anon_sym_abstract] = ACTIONS(3177),
    [anon_sym_async] = ACTIONS(3177),
    [anon_sym_const] = ACTIONS(3177),
    [anon_sym_file] = ACTIONS(3177),
    [anon_sym_fixed] = ACTIONS(3177),
    [anon_sym_internal] = ACTIONS(3177),
    [anon_sym_new] = ACTIONS(3177),
    [anon_sym_override] = ACTIONS(3177),
    [anon_sym_partial] = ACTIONS(3177),
    [anon_sym_private] = ACTIONS(3177),
    [anon_sym_protected] = ACTIONS(3177),
    [anon_sym_public] = ACTIONS(3177),
    [anon_sym_readonly] = ACTIONS(3177),
    [anon_sym_required] = ACTIONS(3177),
    [anon_sym_sealed] = ACTIONS(3177),
    [anon_sym_virtual] = ACTIONS(3177),
    [anon_sym_volatile] = ACTIONS(3177),
    [anon_sym_where] = ACTIONS(3177),
    [anon_sym_notnull] = ACTIONS(3177),
    [anon_sym_unmanaged] = ACTIONS(3177),
    [anon_sym_checked] = ACTIONS(3177),
    [anon_sym_BANG] = ACTIONS(3179),
    [anon_sym_TILDE] = ACTIONS(3179),
    [anon_sym_PLUS_PLUS] = ACTIONS(3179),
    [anon_sym_DASH_DASH] = ACTIONS(3179),
    [anon_sym_true] = ACTIONS(3177),
    [anon_sym_false] = ACTIONS(3177),
    [anon_sym_PLUS] = ACTIONS(3177),
    [anon_sym_DASH] = ACTIONS(3177),
    [anon_sym_STAR] = ACTIONS(3179),
    [anon_sym_CARET] = ACTIONS(3179),
    [anon_sym_AMP] = ACTIONS(3179),
    [anon_sym_this] = ACTIONS(3177),
    [anon_sym_scoped] = ACTIONS(3177),
    [anon_sym_base] = ACTIONS(3177),
    [anon_sym_var] = ACTIONS(3177),
    [sym_predefined_type] = ACTIONS(3177),
    [anon_sym_break] = ACTIONS(3177),
    [anon_sym_unchecked] = ACTIONS(3177),
    [anon_sym_continue] = ACTIONS(3177),
    [anon_sym_do] = ACTIONS(3177),
    [anon_sym_while] = ACTIONS(3177),
    [anon_sym_for] = ACTIONS(3177),
    [anon_sym_lock] = ACTIONS(3177),
    [anon_sym_yield] = ACTIONS(3177),
    [anon_sym_switch] = ACTIONS(3177),
    [anon_sym_default] = ACTIONS(3177),
    [anon_sym_throw] = ACTIONS(3177),
    [anon_sym_try] = ACTIONS(3177),
    [anon_sym_when] = ACTIONS(3177),
    [anon_sym_await] = ACTIONS(3177),
    [anon_sym_foreach] = ACTIONS(3177),
    [anon_sym_goto] = ACTIONS(3177),
    [anon_sym_if] = ACTIONS(3177),
    [anon_sym_else] = ACTIONS(3177),
    [anon_sym_DOT_DOT] = ACTIONS(3179),
    [anon_sym_from] = ACTIONS(3177),
    [anon_sym_into] = ACTIONS(3177),
    [anon_sym_join] = ACTIONS(3177),
    [anon_sym_on] = ACTIONS(3177),
    [anon_sym_equals] = ACTIONS(3177),
    [anon_sym_let] = ACTIONS(3177),
    [anon_sym_orderby] = ACTIONS(3177),
    [anon_sym_ascending] = ACTIONS(3177),
    [anon_sym_descending] = ACTIONS(3177),
    [anon_sym_group] = ACTIONS(3177),
    [anon_sym_by] = ACTIONS(3177),
    [anon_sym_select] = ACTIONS(3177),
    [anon_sym_stackalloc] = ACTIONS(3177),
    [anon_sym_sizeof] = ACTIONS(3177),
    [anon_sym_typeof] = ACTIONS(3177),
    [anon_sym___makeref] = ACTIONS(3177),
    [anon_sym___reftype] = ACTIONS(3177),
    [anon_sym___refvalue] = ACTIONS(3177),
    [sym_null_literal] = ACTIONS(3177),
    [anon_sym_SQUOTE] = ACTIONS(3179),
    [sym_integer_literal] = ACTIONS(3177),
    [sym_real_literal] = ACTIONS(3179),
    [anon_sym_DQUOTE] = ACTIONS(3179),
    [sym_verbatim_string_literal] = ACTIONS(3179),
    [aux_sym_preproc_if_token1] = ACTIONS(3179),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3179),
    [sym_interpolation_verbatim_start] = ACTIONS(3179),
    [sym_interpolation_raw_start] = ACTIONS(3179),
    [sym_raw_string_start] = ACTIONS(3179),
  },
  [2446] = {
    [sym_preproc_region] = STATE(2446),
    [sym_preproc_endregion] = STATE(2446),
    [sym_preproc_line] = STATE(2446),
    [sym_preproc_pragma] = STATE(2446),
    [sym_preproc_nullable] = STATE(2446),
    [sym_preproc_error] = STATE(2446),
    [sym_preproc_warning] = STATE(2446),
    [sym_preproc_define] = STATE(2446),
    [sym_preproc_undef] = STATE(2446),
    [ts_builtin_sym_end] = ACTIONS(3183),
    [sym__identifier_token] = ACTIONS(3181),
    [anon_sym_extern] = ACTIONS(3181),
    [anon_sym_alias] = ACTIONS(3181),
    [anon_sym_SEMI] = ACTIONS(3183),
    [anon_sym_global] = ACTIONS(3181),
    [anon_sym_using] = ACTIONS(3181),
    [anon_sym_unsafe] = ACTIONS(3181),
    [anon_sym_static] = ACTIONS(3181),
    [anon_sym_LBRACK] = ACTIONS(3183),
    [anon_sym_LPAREN] = ACTIONS(3183),
    [anon_sym_return] = ACTIONS(3181),
    [anon_sym_namespace] = ACTIONS(3181),
    [anon_sym_class] = ACTIONS(3181),
    [anon_sym_ref] = ACTIONS(3181),
    [anon_sym_struct] = ACTIONS(3181),
    [anon_sym_enum] = ACTIONS(3181),
    [anon_sym_LBRACE] = ACTIONS(3183),
    [anon_sym_interface] = ACTIONS(3181),
    [anon_sym_delegate] = ACTIONS(3181),
    [anon_sym_record] = ACTIONS(3181),
    [anon_sym_abstract] = ACTIONS(3181),
    [anon_sym_async] = ACTIONS(3181),
    [anon_sym_const] = ACTIONS(3181),
    [anon_sym_file] = ACTIONS(3181),
    [anon_sym_fixed] = ACTIONS(3181),
    [anon_sym_internal] = ACTIONS(3181),
    [anon_sym_new] = ACTIONS(3181),
    [anon_sym_override] = ACTIONS(3181),
    [anon_sym_partial] = ACTIONS(3181),
    [anon_sym_private] = ACTIONS(3181),
    [anon_sym_protected] = ACTIONS(3181),
    [anon_sym_public] = ACTIONS(3181),
    [anon_sym_readonly] = ACTIONS(3181),
    [anon_sym_required] = ACTIONS(3181),
    [anon_sym_sealed] = ACTIONS(3181),
    [anon_sym_virtual] = ACTIONS(3181),
    [anon_sym_volatile] = ACTIONS(3181),
    [anon_sym_where] = ACTIONS(3181),
    [anon_sym_notnull] = ACTIONS(3181),
    [anon_sym_unmanaged] = ACTIONS(3181),
    [anon_sym_checked] = ACTIONS(3181),
    [anon_sym_BANG] = ACTIONS(3183),
    [anon_sym_TILDE] = ACTIONS(3183),
    [anon_sym_PLUS_PLUS] = ACTIONS(3183),
    [anon_sym_DASH_DASH] = ACTIONS(3183),
    [anon_sym_true] = ACTIONS(3181),
    [anon_sym_false] = ACTIONS(3181),
    [anon_sym_PLUS] = ACTIONS(3181),
    [anon_sym_DASH] = ACTIONS(3181),
    [anon_sym_STAR] = ACTIONS(3183),
    [anon_sym_CARET] = ACTIONS(3183),
    [anon_sym_AMP] = ACTIONS(3183),
    [anon_sym_this] = ACTIONS(3181),
    [anon_sym_scoped] = ACTIONS(3181),
    [anon_sym_base] = ACTIONS(3181),
    [anon_sym_var] = ACTIONS(3181),
    [sym_predefined_type] = ACTIONS(3181),
    [anon_sym_break] = ACTIONS(3181),
    [anon_sym_unchecked] = ACTIONS(3181),
    [anon_sym_continue] = ACTIONS(3181),
    [anon_sym_do] = ACTIONS(3181),
    [anon_sym_while] = ACTIONS(3181),
    [anon_sym_for] = ACTIONS(3181),
    [anon_sym_lock] = ACTIONS(3181),
    [anon_sym_yield] = ACTIONS(3181),
    [anon_sym_switch] = ACTIONS(3181),
    [anon_sym_default] = ACTIONS(3181),
    [anon_sym_throw] = ACTIONS(3181),
    [anon_sym_try] = ACTIONS(3181),
    [anon_sym_when] = ACTIONS(3181),
    [anon_sym_await] = ACTIONS(3181),
    [anon_sym_foreach] = ACTIONS(3181),
    [anon_sym_goto] = ACTIONS(3181),
    [anon_sym_if] = ACTIONS(3181),
    [anon_sym_else] = ACTIONS(3181),
    [anon_sym_DOT_DOT] = ACTIONS(3183),
    [anon_sym_from] = ACTIONS(3181),
    [anon_sym_into] = ACTIONS(3181),
    [anon_sym_join] = ACTIONS(3181),
    [anon_sym_on] = ACTIONS(3181),
    [anon_sym_equals] = ACTIONS(3181),
    [anon_sym_let] = ACTIONS(3181),
    [anon_sym_orderby] = ACTIONS(3181),
    [anon_sym_ascending] = ACTIONS(3181),
    [anon_sym_descending] = ACTIONS(3181),
    [anon_sym_group] = ACTIONS(3181),
    [anon_sym_by] = ACTIONS(3181),
    [anon_sym_select] = ACTIONS(3181),
    [anon_sym_stackalloc] = ACTIONS(3181),
    [anon_sym_sizeof] = ACTIONS(3181),
    [anon_sym_typeof] = ACTIONS(3181),
    [anon_sym___makeref] = ACTIONS(3181),
    [anon_sym___reftype] = ACTIONS(3181),
    [anon_sym___refvalue] = ACTIONS(3181),
    [sym_null_literal] = ACTIONS(3181),
    [anon_sym_SQUOTE] = ACTIONS(3183),
    [sym_integer_literal] = ACTIONS(3181),
    [sym_real_literal] = ACTIONS(3183),
    [anon_sym_DQUOTE] = ACTIONS(3183),
    [sym_verbatim_string_literal] = ACTIONS(3183),
    [aux_sym_preproc_if_token1] = ACTIONS(3183),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3183),
    [sym_interpolation_verbatim_start] = ACTIONS(3183),
    [sym_interpolation_raw_start] = ACTIONS(3183),
    [sym_raw_string_start] = ACTIONS(3183),
  },
  [2447] = {
    [sym_preproc_region] = STATE(2447),
    [sym_preproc_endregion] = STATE(2447),
    [sym_preproc_line] = STATE(2447),
    [sym_preproc_pragma] = STATE(2447),
    [sym_preproc_nullable] = STATE(2447),
    [sym_preproc_error] = STATE(2447),
    [sym_preproc_warning] = STATE(2447),
    [sym_preproc_define] = STATE(2447),
    [sym_preproc_undef] = STATE(2447),
    [ts_builtin_sym_end] = ACTIONS(3187),
    [sym__identifier_token] = ACTIONS(3185),
    [anon_sym_extern] = ACTIONS(3185),
    [anon_sym_alias] = ACTIONS(3185),
    [anon_sym_SEMI] = ACTIONS(3187),
    [anon_sym_global] = ACTIONS(3185),
    [anon_sym_using] = ACTIONS(3185),
    [anon_sym_unsafe] = ACTIONS(3185),
    [anon_sym_static] = ACTIONS(3185),
    [anon_sym_LBRACK] = ACTIONS(3187),
    [anon_sym_LPAREN] = ACTIONS(3187),
    [anon_sym_return] = ACTIONS(3185),
    [anon_sym_namespace] = ACTIONS(3185),
    [anon_sym_class] = ACTIONS(3185),
    [anon_sym_ref] = ACTIONS(3185),
    [anon_sym_struct] = ACTIONS(3185),
    [anon_sym_enum] = ACTIONS(3185),
    [anon_sym_LBRACE] = ACTIONS(3187),
    [anon_sym_interface] = ACTIONS(3185),
    [anon_sym_delegate] = ACTIONS(3185),
    [anon_sym_record] = ACTIONS(3185),
    [anon_sym_abstract] = ACTIONS(3185),
    [anon_sym_async] = ACTIONS(3185),
    [anon_sym_const] = ACTIONS(3185),
    [anon_sym_file] = ACTIONS(3185),
    [anon_sym_fixed] = ACTIONS(3185),
    [anon_sym_internal] = ACTIONS(3185),
    [anon_sym_new] = ACTIONS(3185),
    [anon_sym_override] = ACTIONS(3185),
    [anon_sym_partial] = ACTIONS(3185),
    [anon_sym_private] = ACTIONS(3185),
    [anon_sym_protected] = ACTIONS(3185),
    [anon_sym_public] = ACTIONS(3185),
    [anon_sym_readonly] = ACTIONS(3185),
    [anon_sym_required] = ACTIONS(3185),
    [anon_sym_sealed] = ACTIONS(3185),
    [anon_sym_virtual] = ACTIONS(3185),
    [anon_sym_volatile] = ACTIONS(3185),
    [anon_sym_where] = ACTIONS(3185),
    [anon_sym_notnull] = ACTIONS(3185),
    [anon_sym_unmanaged] = ACTIONS(3185),
    [anon_sym_checked] = ACTIONS(3185),
    [anon_sym_BANG] = ACTIONS(3187),
    [anon_sym_TILDE] = ACTIONS(3187),
    [anon_sym_PLUS_PLUS] = ACTIONS(3187),
    [anon_sym_DASH_DASH] = ACTIONS(3187),
    [anon_sym_true] = ACTIONS(3185),
    [anon_sym_false] = ACTIONS(3185),
    [anon_sym_PLUS] = ACTIONS(3185),
    [anon_sym_DASH] = ACTIONS(3185),
    [anon_sym_STAR] = ACTIONS(3187),
    [anon_sym_CARET] = ACTIONS(3187),
    [anon_sym_AMP] = ACTIONS(3187),
    [anon_sym_this] = ACTIONS(3185),
    [anon_sym_scoped] = ACTIONS(3185),
    [anon_sym_base] = ACTIONS(3185),
    [anon_sym_var] = ACTIONS(3185),
    [sym_predefined_type] = ACTIONS(3185),
    [anon_sym_break] = ACTIONS(3185),
    [anon_sym_unchecked] = ACTIONS(3185),
    [anon_sym_continue] = ACTIONS(3185),
    [anon_sym_do] = ACTIONS(3185),
    [anon_sym_while] = ACTIONS(3185),
    [anon_sym_for] = ACTIONS(3185),
    [anon_sym_lock] = ACTIONS(3185),
    [anon_sym_yield] = ACTIONS(3185),
    [anon_sym_switch] = ACTIONS(3185),
    [anon_sym_default] = ACTIONS(3185),
    [anon_sym_throw] = ACTIONS(3185),
    [anon_sym_try] = ACTIONS(3185),
    [anon_sym_when] = ACTIONS(3185),
    [anon_sym_await] = ACTIONS(3185),
    [anon_sym_foreach] = ACTIONS(3185),
    [anon_sym_goto] = ACTIONS(3185),
    [anon_sym_if] = ACTIONS(3185),
    [anon_sym_else] = ACTIONS(3185),
    [anon_sym_DOT_DOT] = ACTIONS(3187),
    [anon_sym_from] = ACTIONS(3185),
    [anon_sym_into] = ACTIONS(3185),
    [anon_sym_join] = ACTIONS(3185),
    [anon_sym_on] = ACTIONS(3185),
    [anon_sym_equals] = ACTIONS(3185),
    [anon_sym_let] = ACTIONS(3185),
    [anon_sym_orderby] = ACTIONS(3185),
    [anon_sym_ascending] = ACTIONS(3185),
    [anon_sym_descending] = ACTIONS(3185),
    [anon_sym_group] = ACTIONS(3185),
    [anon_sym_by] = ACTIONS(3185),
    [anon_sym_select] = ACTIONS(3185),
    [anon_sym_stackalloc] = ACTIONS(3185),
    [anon_sym_sizeof] = ACTIONS(3185),
    [anon_sym_typeof] = ACTIONS(3185),
    [anon_sym___makeref] = ACTIONS(3185),
    [anon_sym___reftype] = ACTIONS(3185),
    [anon_sym___refvalue] = ACTIONS(3185),
    [sym_null_literal] = ACTIONS(3185),
    [anon_sym_SQUOTE] = ACTIONS(3187),
    [sym_integer_literal] = ACTIONS(3185),
    [sym_real_literal] = ACTIONS(3187),
    [anon_sym_DQUOTE] = ACTIONS(3187),
    [sym_verbatim_string_literal] = ACTIONS(3187),
    [aux_sym_preproc_if_token1] = ACTIONS(3187),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3187),
    [sym_interpolation_verbatim_start] = ACTIONS(3187),
    [sym_interpolation_raw_start] = ACTIONS(3187),
    [sym_raw_string_start] = ACTIONS(3187),
  },
  [2448] = {
    [sym_preproc_region] = STATE(2448),
    [sym_preproc_endregion] = STATE(2448),
    [sym_preproc_line] = STATE(2448),
    [sym_preproc_pragma] = STATE(2448),
    [sym_preproc_nullable] = STATE(2448),
    [sym_preproc_error] = STATE(2448),
    [sym_preproc_warning] = STATE(2448),
    [sym_preproc_define] = STATE(2448),
    [sym_preproc_undef] = STATE(2448),
    [ts_builtin_sym_end] = ACTIONS(3375),
    [sym__identifier_token] = ACTIONS(3373),
    [anon_sym_extern] = ACTIONS(3373),
    [anon_sym_alias] = ACTIONS(3373),
    [anon_sym_SEMI] = ACTIONS(3375),
    [anon_sym_global] = ACTIONS(3373),
    [anon_sym_using] = ACTIONS(3373),
    [anon_sym_unsafe] = ACTIONS(3373),
    [anon_sym_static] = ACTIONS(3373),
    [anon_sym_LBRACK] = ACTIONS(3375),
    [anon_sym_LPAREN] = ACTIONS(3375),
    [anon_sym_return] = ACTIONS(3373),
    [anon_sym_namespace] = ACTIONS(3373),
    [anon_sym_class] = ACTIONS(3373),
    [anon_sym_ref] = ACTIONS(3373),
    [anon_sym_struct] = ACTIONS(3373),
    [anon_sym_enum] = ACTIONS(3373),
    [anon_sym_LBRACE] = ACTIONS(3375),
    [anon_sym_interface] = ACTIONS(3373),
    [anon_sym_delegate] = ACTIONS(3373),
    [anon_sym_record] = ACTIONS(3373),
    [anon_sym_abstract] = ACTIONS(3373),
    [anon_sym_async] = ACTIONS(3373),
    [anon_sym_const] = ACTIONS(3373),
    [anon_sym_file] = ACTIONS(3373),
    [anon_sym_fixed] = ACTIONS(3373),
    [anon_sym_internal] = ACTIONS(3373),
    [anon_sym_new] = ACTIONS(3373),
    [anon_sym_override] = ACTIONS(3373),
    [anon_sym_partial] = ACTIONS(3373),
    [anon_sym_private] = ACTIONS(3373),
    [anon_sym_protected] = ACTIONS(3373),
    [anon_sym_public] = ACTIONS(3373),
    [anon_sym_readonly] = ACTIONS(3373),
    [anon_sym_required] = ACTIONS(3373),
    [anon_sym_sealed] = ACTIONS(3373),
    [anon_sym_virtual] = ACTIONS(3373),
    [anon_sym_volatile] = ACTIONS(3373),
    [anon_sym_where] = ACTIONS(3373),
    [anon_sym_notnull] = ACTIONS(3373),
    [anon_sym_unmanaged] = ACTIONS(3373),
    [anon_sym_checked] = ACTIONS(3373),
    [anon_sym_BANG] = ACTIONS(3375),
    [anon_sym_TILDE] = ACTIONS(3375),
    [anon_sym_PLUS_PLUS] = ACTIONS(3375),
    [anon_sym_DASH_DASH] = ACTIONS(3375),
    [anon_sym_true] = ACTIONS(3373),
    [anon_sym_false] = ACTIONS(3373),
    [anon_sym_PLUS] = ACTIONS(3373),
    [anon_sym_DASH] = ACTIONS(3373),
    [anon_sym_STAR] = ACTIONS(3375),
    [anon_sym_CARET] = ACTIONS(3375),
    [anon_sym_AMP] = ACTIONS(3375),
    [anon_sym_this] = ACTIONS(3373),
    [anon_sym_scoped] = ACTIONS(3373),
    [anon_sym_base] = ACTIONS(3373),
    [anon_sym_var] = ACTIONS(3373),
    [sym_predefined_type] = ACTIONS(3373),
    [anon_sym_break] = ACTIONS(3373),
    [anon_sym_unchecked] = ACTIONS(3373),
    [anon_sym_continue] = ACTIONS(3373),
    [anon_sym_do] = ACTIONS(3373),
    [anon_sym_while] = ACTIONS(3373),
    [anon_sym_for] = ACTIONS(3373),
    [anon_sym_lock] = ACTIONS(3373),
    [anon_sym_yield] = ACTIONS(3373),
    [anon_sym_switch] = ACTIONS(3373),
    [anon_sym_default] = ACTIONS(3373),
    [anon_sym_throw] = ACTIONS(3373),
    [anon_sym_try] = ACTIONS(3373),
    [anon_sym_when] = ACTIONS(3373),
    [anon_sym_await] = ACTIONS(3373),
    [anon_sym_foreach] = ACTIONS(3373),
    [anon_sym_goto] = ACTIONS(3373),
    [anon_sym_if] = ACTIONS(3373),
    [anon_sym_else] = ACTIONS(3373),
    [anon_sym_DOT_DOT] = ACTIONS(3375),
    [anon_sym_from] = ACTIONS(3373),
    [anon_sym_into] = ACTIONS(3373),
    [anon_sym_join] = ACTIONS(3373),
    [anon_sym_on] = ACTIONS(3373),
    [anon_sym_equals] = ACTIONS(3373),
    [anon_sym_let] = ACTIONS(3373),
    [anon_sym_orderby] = ACTIONS(3373),
    [anon_sym_ascending] = ACTIONS(3373),
    [anon_sym_descending] = ACTIONS(3373),
    [anon_sym_group] = ACTIONS(3373),
    [anon_sym_by] = ACTIONS(3373),
    [anon_sym_select] = ACTIONS(3373),
    [anon_sym_stackalloc] = ACTIONS(3373),
    [anon_sym_sizeof] = ACTIONS(3373),
    [anon_sym_typeof] = ACTIONS(3373),
    [anon_sym___makeref] = ACTIONS(3373),
    [anon_sym___reftype] = ACTIONS(3373),
    [anon_sym___refvalue] = ACTIONS(3373),
    [sym_null_literal] = ACTIONS(3373),
    [anon_sym_SQUOTE] = ACTIONS(3375),
    [sym_integer_literal] = ACTIONS(3373),
    [sym_real_literal] = ACTIONS(3375),
    [anon_sym_DQUOTE] = ACTIONS(3375),
    [sym_verbatim_string_literal] = ACTIONS(3375),
    [aux_sym_preproc_if_token1] = ACTIONS(3375),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3375),
    [sym_interpolation_verbatim_start] = ACTIONS(3375),
    [sym_interpolation_raw_start] = ACTIONS(3375),
    [sym_raw_string_start] = ACTIONS(3375),
  },
  [2449] = {
    [sym_preproc_region] = STATE(2449),
    [sym_preproc_endregion] = STATE(2449),
    [sym_preproc_line] = STATE(2449),
    [sym_preproc_pragma] = STATE(2449),
    [sym_preproc_nullable] = STATE(2449),
    [sym_preproc_error] = STATE(2449),
    [sym_preproc_warning] = STATE(2449),
    [sym_preproc_define] = STATE(2449),
    [sym_preproc_undef] = STATE(2449),
    [ts_builtin_sym_end] = ACTIONS(3333),
    [sym__identifier_token] = ACTIONS(3331),
    [anon_sym_extern] = ACTIONS(3331),
    [anon_sym_alias] = ACTIONS(3331),
    [anon_sym_SEMI] = ACTIONS(3333),
    [anon_sym_global] = ACTIONS(3331),
    [anon_sym_using] = ACTIONS(3331),
    [anon_sym_unsafe] = ACTIONS(3331),
    [anon_sym_static] = ACTIONS(3331),
    [anon_sym_LBRACK] = ACTIONS(3333),
    [anon_sym_LPAREN] = ACTIONS(3333),
    [anon_sym_return] = ACTIONS(3331),
    [anon_sym_namespace] = ACTIONS(3331),
    [anon_sym_class] = ACTIONS(3331),
    [anon_sym_ref] = ACTIONS(3331),
    [anon_sym_struct] = ACTIONS(3331),
    [anon_sym_enum] = ACTIONS(3331),
    [anon_sym_LBRACE] = ACTIONS(3333),
    [anon_sym_interface] = ACTIONS(3331),
    [anon_sym_delegate] = ACTIONS(3331),
    [anon_sym_record] = ACTIONS(3331),
    [anon_sym_abstract] = ACTIONS(3331),
    [anon_sym_async] = ACTIONS(3331),
    [anon_sym_const] = ACTIONS(3331),
    [anon_sym_file] = ACTIONS(3331),
    [anon_sym_fixed] = ACTIONS(3331),
    [anon_sym_internal] = ACTIONS(3331),
    [anon_sym_new] = ACTIONS(3331),
    [anon_sym_override] = ACTIONS(3331),
    [anon_sym_partial] = ACTIONS(3331),
    [anon_sym_private] = ACTIONS(3331),
    [anon_sym_protected] = ACTIONS(3331),
    [anon_sym_public] = ACTIONS(3331),
    [anon_sym_readonly] = ACTIONS(3331),
    [anon_sym_required] = ACTIONS(3331),
    [anon_sym_sealed] = ACTIONS(3331),
    [anon_sym_virtual] = ACTIONS(3331),
    [anon_sym_volatile] = ACTIONS(3331),
    [anon_sym_where] = ACTIONS(3331),
    [anon_sym_notnull] = ACTIONS(3331),
    [anon_sym_unmanaged] = ACTIONS(3331),
    [anon_sym_checked] = ACTIONS(3331),
    [anon_sym_BANG] = ACTIONS(3333),
    [anon_sym_TILDE] = ACTIONS(3333),
    [anon_sym_PLUS_PLUS] = ACTIONS(3333),
    [anon_sym_DASH_DASH] = ACTIONS(3333),
    [anon_sym_true] = ACTIONS(3331),
    [anon_sym_false] = ACTIONS(3331),
    [anon_sym_PLUS] = ACTIONS(3331),
    [anon_sym_DASH] = ACTIONS(3331),
    [anon_sym_STAR] = ACTIONS(3333),
    [anon_sym_CARET] = ACTIONS(3333),
    [anon_sym_AMP] = ACTIONS(3333),
    [anon_sym_this] = ACTIONS(3331),
    [anon_sym_scoped] = ACTIONS(3331),
    [anon_sym_base] = ACTIONS(3331),
    [anon_sym_var] = ACTIONS(3331),
    [sym_predefined_type] = ACTIONS(3331),
    [anon_sym_break] = ACTIONS(3331),
    [anon_sym_unchecked] = ACTIONS(3331),
    [anon_sym_continue] = ACTIONS(3331),
    [anon_sym_do] = ACTIONS(3331),
    [anon_sym_while] = ACTIONS(3331),
    [anon_sym_for] = ACTIONS(3331),
    [anon_sym_lock] = ACTIONS(3331),
    [anon_sym_yield] = ACTIONS(3331),
    [anon_sym_switch] = ACTIONS(3331),
    [anon_sym_default] = ACTIONS(3331),
    [anon_sym_throw] = ACTIONS(3331),
    [anon_sym_try] = ACTIONS(3331),
    [anon_sym_when] = ACTIONS(3331),
    [anon_sym_await] = ACTIONS(3331),
    [anon_sym_foreach] = ACTIONS(3331),
    [anon_sym_goto] = ACTIONS(3331),
    [anon_sym_if] = ACTIONS(3331),
    [anon_sym_else] = ACTIONS(3331),
    [anon_sym_DOT_DOT] = ACTIONS(3333),
    [anon_sym_from] = ACTIONS(3331),
    [anon_sym_into] = ACTIONS(3331),
    [anon_sym_join] = ACTIONS(3331),
    [anon_sym_on] = ACTIONS(3331),
    [anon_sym_equals] = ACTIONS(3331),
    [anon_sym_let] = ACTIONS(3331),
    [anon_sym_orderby] = ACTIONS(3331),
    [anon_sym_ascending] = ACTIONS(3331),
    [anon_sym_descending] = ACTIONS(3331),
    [anon_sym_group] = ACTIONS(3331),
    [anon_sym_by] = ACTIONS(3331),
    [anon_sym_select] = ACTIONS(3331),
    [anon_sym_stackalloc] = ACTIONS(3331),
    [anon_sym_sizeof] = ACTIONS(3331),
    [anon_sym_typeof] = ACTIONS(3331),
    [anon_sym___makeref] = ACTIONS(3331),
    [anon_sym___reftype] = ACTIONS(3331),
    [anon_sym___refvalue] = ACTIONS(3331),
    [sym_null_literal] = ACTIONS(3331),
    [anon_sym_SQUOTE] = ACTIONS(3333),
    [sym_integer_literal] = ACTIONS(3331),
    [sym_real_literal] = ACTIONS(3333),
    [anon_sym_DQUOTE] = ACTIONS(3333),
    [sym_verbatim_string_literal] = ACTIONS(3333),
    [aux_sym_preproc_if_token1] = ACTIONS(3333),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3333),
    [sym_interpolation_verbatim_start] = ACTIONS(3333),
    [sym_interpolation_raw_start] = ACTIONS(3333),
    [sym_raw_string_start] = ACTIONS(3333),
  },
  [2450] = {
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7339),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(6820),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(2450),
    [sym_preproc_endregion] = STATE(2450),
    [sym_preproc_line] = STATE(2450),
    [sym_preproc_pragma] = STATE(2450),
    [sym_preproc_nullable] = STATE(2450),
    [sym_preproc_error] = STATE(2450),
    [sym_preproc_warning] = STATE(2450),
    [sym_preproc_define] = STATE(2450),
    [sym_preproc_undef] = STATE(2450),
    [sym__identifier_token] = ACTIONS(3987),
    [anon_sym_alias] = ACTIONS(3990),
    [anon_sym_SEMI] = ACTIONS(3993),
    [anon_sym_global] = ACTIONS(3990),
    [anon_sym_EQ] = ACTIONS(3995),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_COLON] = ACTIONS(3995),
    [anon_sym_COMMA] = ACTIONS(3993),
    [anon_sym_RBRACK] = ACTIONS(3993),
    [anon_sym_LPAREN] = ACTIONS(3997),
    [anon_sym_RPAREN] = ACTIONS(3993),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_LBRACE] = ACTIONS(3993),
    [anon_sym_RBRACE] = ACTIONS(3993),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_file] = ACTIONS(3990),
    [anon_sym_LT] = ACTIONS(3995),
    [anon_sym_GT] = ACTIONS(3995),
    [anon_sym_in] = ACTIONS(3995),
    [anon_sym_where] = ACTIONS(3990),
    [anon_sym_QMARK] = ACTIONS(3995),
    [anon_sym_notnull] = ACTIONS(3990),
    [anon_sym_unmanaged] = ACTIONS(3990),
    [anon_sym_BANG] = ACTIONS(3995),
    [anon_sym_PLUS_PLUS] = ACTIONS(3993),
    [anon_sym_DASH_DASH] = ACTIONS(3993),
    [anon_sym_PLUS] = ACTIONS(3995),
    [anon_sym_DASH] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3995),
    [anon_sym_SLASH] = ACTIONS(3995),
    [anon_sym_PERCENT] = ACTIONS(3995),
    [anon_sym_CARET] = ACTIONS(3995),
    [anon_sym_PIPE] = ACTIONS(3995),
    [anon_sym_AMP] = ACTIONS(3995),
    [anon_sym_LT_LT] = ACTIONS(3995),
    [anon_sym_GT_GT] = ACTIONS(3995),
    [anon_sym_GT_GT_GT] = ACTIONS(3995),
    [anon_sym_EQ_EQ] = ACTIONS(3993),
    [anon_sym_BANG_EQ] = ACTIONS(3993),
    [anon_sym_GT_EQ] = ACTIONS(3993),
    [anon_sym_LT_EQ] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3995),
    [anon_sym_scoped] = ACTIONS(4004),
    [anon_sym_EQ_GT] = ACTIONS(3993),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(4007),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3990),
    [anon_sym_switch] = ACTIONS(3995),
    [anon_sym_when] = ACTIONS(3990),
    [sym_discard] = ACTIONS(3995),
    [anon_sym_DOT_DOT] = ACTIONS(3993),
    [anon_sym_and] = ACTIONS(3995),
    [anon_sym_or] = ACTIONS(3995),
    [anon_sym_PLUS_EQ] = ACTIONS(3993),
    [anon_sym_DASH_EQ] = ACTIONS(3993),
    [anon_sym_STAR_EQ] = ACTIONS(3993),
    [anon_sym_SLASH_EQ] = ACTIONS(3993),
    [anon_sym_PERCENT_EQ] = ACTIONS(3993),
    [anon_sym_AMP_EQ] = ACTIONS(3993),
    [anon_sym_CARET_EQ] = ACTIONS(3993),
    [anon_sym_PIPE_EQ] = ACTIONS(3993),
    [anon_sym_LT_LT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(3993),
    [anon_sym_AMP_AMP] = ACTIONS(3993),
    [anon_sym_PIPE_PIPE] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK] = ACTIONS(3995),
    [anon_sym_from] = ACTIONS(3990),
    [anon_sym_into] = ACTIONS(3990),
    [anon_sym_join] = ACTIONS(3990),
    [anon_sym_on] = ACTIONS(3990),
    [anon_sym_equals] = ACTIONS(3990),
    [anon_sym_let] = ACTIONS(3990),
    [anon_sym_orderby] = ACTIONS(3990),
    [anon_sym_ascending] = ACTIONS(3990),
    [anon_sym_descending] = ACTIONS(3990),
    [anon_sym_group] = ACTIONS(3990),
    [anon_sym_by] = ACTIONS(3990),
    [anon_sym_select] = ACTIONS(3990),
    [anon_sym_as] = ACTIONS(3995),
    [anon_sym_is] = ACTIONS(3995),
    [anon_sym_DASH_GT] = ACTIONS(3993),
    [anon_sym_with] = ACTIONS(3995),
    [aux_sym_preproc_if_token3] = ACTIONS(3993),
    [aux_sym_preproc_else_token1] = ACTIONS(3993),
    [aux_sym_preproc_elif_token1] = ACTIONS(3993),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2451] = {
    [sym_preproc_region] = STATE(2451),
    [sym_preproc_endregion] = STATE(2451),
    [sym_preproc_line] = STATE(2451),
    [sym_preproc_pragma] = STATE(2451),
    [sym_preproc_nullable] = STATE(2451),
    [sym_preproc_error] = STATE(2451),
    [sym_preproc_warning] = STATE(2451),
    [sym_preproc_define] = STATE(2451),
    [sym_preproc_undef] = STATE(2451),
    [ts_builtin_sym_end] = ACTIONS(3091),
    [sym__identifier_token] = ACTIONS(3089),
    [anon_sym_extern] = ACTIONS(3089),
    [anon_sym_alias] = ACTIONS(3089),
    [anon_sym_SEMI] = ACTIONS(3091),
    [anon_sym_global] = ACTIONS(3089),
    [anon_sym_using] = ACTIONS(3089),
    [anon_sym_unsafe] = ACTIONS(3089),
    [anon_sym_static] = ACTIONS(3089),
    [anon_sym_LBRACK] = ACTIONS(3091),
    [anon_sym_LPAREN] = ACTIONS(3091),
    [anon_sym_return] = ACTIONS(3089),
    [anon_sym_namespace] = ACTIONS(3089),
    [anon_sym_class] = ACTIONS(3089),
    [anon_sym_ref] = ACTIONS(3089),
    [anon_sym_struct] = ACTIONS(3089),
    [anon_sym_enum] = ACTIONS(3089),
    [anon_sym_LBRACE] = ACTIONS(3091),
    [anon_sym_interface] = ACTIONS(3089),
    [anon_sym_delegate] = ACTIONS(3089),
    [anon_sym_record] = ACTIONS(3089),
    [anon_sym_abstract] = ACTIONS(3089),
    [anon_sym_async] = ACTIONS(3089),
    [anon_sym_const] = ACTIONS(3089),
    [anon_sym_file] = ACTIONS(3089),
    [anon_sym_fixed] = ACTIONS(3089),
    [anon_sym_internal] = ACTIONS(3089),
    [anon_sym_new] = ACTIONS(3089),
    [anon_sym_override] = ACTIONS(3089),
    [anon_sym_partial] = ACTIONS(3089),
    [anon_sym_private] = ACTIONS(3089),
    [anon_sym_protected] = ACTIONS(3089),
    [anon_sym_public] = ACTIONS(3089),
    [anon_sym_readonly] = ACTIONS(3089),
    [anon_sym_required] = ACTIONS(3089),
    [anon_sym_sealed] = ACTIONS(3089),
    [anon_sym_virtual] = ACTIONS(3089),
    [anon_sym_volatile] = ACTIONS(3089),
    [anon_sym_where] = ACTIONS(3089),
    [anon_sym_notnull] = ACTIONS(3089),
    [anon_sym_unmanaged] = ACTIONS(3089),
    [anon_sym_checked] = ACTIONS(3089),
    [anon_sym_BANG] = ACTIONS(3091),
    [anon_sym_TILDE] = ACTIONS(3091),
    [anon_sym_PLUS_PLUS] = ACTIONS(3091),
    [anon_sym_DASH_DASH] = ACTIONS(3091),
    [anon_sym_true] = ACTIONS(3089),
    [anon_sym_false] = ACTIONS(3089),
    [anon_sym_PLUS] = ACTIONS(3089),
    [anon_sym_DASH] = ACTIONS(3089),
    [anon_sym_STAR] = ACTIONS(3091),
    [anon_sym_CARET] = ACTIONS(3091),
    [anon_sym_AMP] = ACTIONS(3091),
    [anon_sym_this] = ACTIONS(3089),
    [anon_sym_scoped] = ACTIONS(3089),
    [anon_sym_base] = ACTIONS(3089),
    [anon_sym_var] = ACTIONS(3089),
    [sym_predefined_type] = ACTIONS(3089),
    [anon_sym_break] = ACTIONS(3089),
    [anon_sym_unchecked] = ACTIONS(3089),
    [anon_sym_continue] = ACTIONS(3089),
    [anon_sym_do] = ACTIONS(3089),
    [anon_sym_while] = ACTIONS(3089),
    [anon_sym_for] = ACTIONS(3089),
    [anon_sym_lock] = ACTIONS(3089),
    [anon_sym_yield] = ACTIONS(3089),
    [anon_sym_switch] = ACTIONS(3089),
    [anon_sym_default] = ACTIONS(3089),
    [anon_sym_throw] = ACTIONS(3089),
    [anon_sym_try] = ACTIONS(3089),
    [anon_sym_when] = ACTIONS(3089),
    [anon_sym_await] = ACTIONS(3089),
    [anon_sym_foreach] = ACTIONS(3089),
    [anon_sym_goto] = ACTIONS(3089),
    [anon_sym_if] = ACTIONS(3089),
    [anon_sym_else] = ACTIONS(3089),
    [anon_sym_DOT_DOT] = ACTIONS(3091),
    [anon_sym_from] = ACTIONS(3089),
    [anon_sym_into] = ACTIONS(3089),
    [anon_sym_join] = ACTIONS(3089),
    [anon_sym_on] = ACTIONS(3089),
    [anon_sym_equals] = ACTIONS(3089),
    [anon_sym_let] = ACTIONS(3089),
    [anon_sym_orderby] = ACTIONS(3089),
    [anon_sym_ascending] = ACTIONS(3089),
    [anon_sym_descending] = ACTIONS(3089),
    [anon_sym_group] = ACTIONS(3089),
    [anon_sym_by] = ACTIONS(3089),
    [anon_sym_select] = ACTIONS(3089),
    [anon_sym_stackalloc] = ACTIONS(3089),
    [anon_sym_sizeof] = ACTIONS(3089),
    [anon_sym_typeof] = ACTIONS(3089),
    [anon_sym___makeref] = ACTIONS(3089),
    [anon_sym___reftype] = ACTIONS(3089),
    [anon_sym___refvalue] = ACTIONS(3089),
    [sym_null_literal] = ACTIONS(3089),
    [anon_sym_SQUOTE] = ACTIONS(3091),
    [sym_integer_literal] = ACTIONS(3089),
    [sym_real_literal] = ACTIONS(3091),
    [anon_sym_DQUOTE] = ACTIONS(3091),
    [sym_verbatim_string_literal] = ACTIONS(3091),
    [aux_sym_preproc_if_token1] = ACTIONS(3091),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3091),
    [sym_interpolation_verbatim_start] = ACTIONS(3091),
    [sym_interpolation_raw_start] = ACTIONS(3091),
    [sym_raw_string_start] = ACTIONS(3091),
  },
  [2452] = {
    [sym_preproc_region] = STATE(2452),
    [sym_preproc_endregion] = STATE(2452),
    [sym_preproc_line] = STATE(2452),
    [sym_preproc_pragma] = STATE(2452),
    [sym_preproc_nullable] = STATE(2452),
    [sym_preproc_error] = STATE(2452),
    [sym_preproc_warning] = STATE(2452),
    [sym_preproc_define] = STATE(2452),
    [sym_preproc_undef] = STATE(2452),
    [ts_builtin_sym_end] = ACTIONS(3247),
    [sym__identifier_token] = ACTIONS(3245),
    [anon_sym_extern] = ACTIONS(3245),
    [anon_sym_alias] = ACTIONS(3245),
    [anon_sym_SEMI] = ACTIONS(3247),
    [anon_sym_global] = ACTIONS(3245),
    [anon_sym_using] = ACTIONS(3245),
    [anon_sym_unsafe] = ACTIONS(3245),
    [anon_sym_static] = ACTIONS(3245),
    [anon_sym_LBRACK] = ACTIONS(3247),
    [anon_sym_LPAREN] = ACTIONS(3247),
    [anon_sym_return] = ACTIONS(3245),
    [anon_sym_namespace] = ACTIONS(3245),
    [anon_sym_class] = ACTIONS(3245),
    [anon_sym_ref] = ACTIONS(3245),
    [anon_sym_struct] = ACTIONS(3245),
    [anon_sym_enum] = ACTIONS(3245),
    [anon_sym_LBRACE] = ACTIONS(3247),
    [anon_sym_interface] = ACTIONS(3245),
    [anon_sym_delegate] = ACTIONS(3245),
    [anon_sym_record] = ACTIONS(3245),
    [anon_sym_abstract] = ACTIONS(3245),
    [anon_sym_async] = ACTIONS(3245),
    [anon_sym_const] = ACTIONS(3245),
    [anon_sym_file] = ACTIONS(3245),
    [anon_sym_fixed] = ACTIONS(3245),
    [anon_sym_internal] = ACTIONS(3245),
    [anon_sym_new] = ACTIONS(3245),
    [anon_sym_override] = ACTIONS(3245),
    [anon_sym_partial] = ACTIONS(3245),
    [anon_sym_private] = ACTIONS(3245),
    [anon_sym_protected] = ACTIONS(3245),
    [anon_sym_public] = ACTIONS(3245),
    [anon_sym_readonly] = ACTIONS(3245),
    [anon_sym_required] = ACTIONS(3245),
    [anon_sym_sealed] = ACTIONS(3245),
    [anon_sym_virtual] = ACTIONS(3245),
    [anon_sym_volatile] = ACTIONS(3245),
    [anon_sym_where] = ACTIONS(3245),
    [anon_sym_notnull] = ACTIONS(3245),
    [anon_sym_unmanaged] = ACTIONS(3245),
    [anon_sym_checked] = ACTIONS(3245),
    [anon_sym_BANG] = ACTIONS(3247),
    [anon_sym_TILDE] = ACTIONS(3247),
    [anon_sym_PLUS_PLUS] = ACTIONS(3247),
    [anon_sym_DASH_DASH] = ACTIONS(3247),
    [anon_sym_true] = ACTIONS(3245),
    [anon_sym_false] = ACTIONS(3245),
    [anon_sym_PLUS] = ACTIONS(3245),
    [anon_sym_DASH] = ACTIONS(3245),
    [anon_sym_STAR] = ACTIONS(3247),
    [anon_sym_CARET] = ACTIONS(3247),
    [anon_sym_AMP] = ACTIONS(3247),
    [anon_sym_this] = ACTIONS(3245),
    [anon_sym_scoped] = ACTIONS(3245),
    [anon_sym_base] = ACTIONS(3245),
    [anon_sym_var] = ACTIONS(3245),
    [sym_predefined_type] = ACTIONS(3245),
    [anon_sym_break] = ACTIONS(3245),
    [anon_sym_unchecked] = ACTIONS(3245),
    [anon_sym_continue] = ACTIONS(3245),
    [anon_sym_do] = ACTIONS(3245),
    [anon_sym_while] = ACTIONS(3245),
    [anon_sym_for] = ACTIONS(3245),
    [anon_sym_lock] = ACTIONS(3245),
    [anon_sym_yield] = ACTIONS(3245),
    [anon_sym_switch] = ACTIONS(3245),
    [anon_sym_default] = ACTIONS(3245),
    [anon_sym_throw] = ACTIONS(3245),
    [anon_sym_try] = ACTIONS(3245),
    [anon_sym_when] = ACTIONS(3245),
    [anon_sym_await] = ACTIONS(3245),
    [anon_sym_foreach] = ACTIONS(3245),
    [anon_sym_goto] = ACTIONS(3245),
    [anon_sym_if] = ACTIONS(3245),
    [anon_sym_else] = ACTIONS(3245),
    [anon_sym_DOT_DOT] = ACTIONS(3247),
    [anon_sym_from] = ACTIONS(3245),
    [anon_sym_into] = ACTIONS(3245),
    [anon_sym_join] = ACTIONS(3245),
    [anon_sym_on] = ACTIONS(3245),
    [anon_sym_equals] = ACTIONS(3245),
    [anon_sym_let] = ACTIONS(3245),
    [anon_sym_orderby] = ACTIONS(3245),
    [anon_sym_ascending] = ACTIONS(3245),
    [anon_sym_descending] = ACTIONS(3245),
    [anon_sym_group] = ACTIONS(3245),
    [anon_sym_by] = ACTIONS(3245),
    [anon_sym_select] = ACTIONS(3245),
    [anon_sym_stackalloc] = ACTIONS(3245),
    [anon_sym_sizeof] = ACTIONS(3245),
    [anon_sym_typeof] = ACTIONS(3245),
    [anon_sym___makeref] = ACTIONS(3245),
    [anon_sym___reftype] = ACTIONS(3245),
    [anon_sym___refvalue] = ACTIONS(3245),
    [sym_null_literal] = ACTIONS(3245),
    [anon_sym_SQUOTE] = ACTIONS(3247),
    [sym_integer_literal] = ACTIONS(3245),
    [sym_real_literal] = ACTIONS(3247),
    [anon_sym_DQUOTE] = ACTIONS(3247),
    [sym_verbatim_string_literal] = ACTIONS(3247),
    [aux_sym_preproc_if_token1] = ACTIONS(3247),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3247),
    [sym_interpolation_verbatim_start] = ACTIONS(3247),
    [sym_interpolation_raw_start] = ACTIONS(3247),
    [sym_raw_string_start] = ACTIONS(3247),
  },
  [2453] = {
    [sym_catch_clause] = STATE(2648),
    [sym_finally_clause] = STATE(2704),
    [sym_preproc_region] = STATE(2453),
    [sym_preproc_endregion] = STATE(2453),
    [sym_preproc_line] = STATE(2453),
    [sym_preproc_pragma] = STATE(2453),
    [sym_preproc_nullable] = STATE(2453),
    [sym_preproc_error] = STATE(2453),
    [sym_preproc_warning] = STATE(2453),
    [sym_preproc_define] = STATE(2453),
    [sym_preproc_undef] = STATE(2453),
    [aux_sym_try_statement_repeat1] = STATE(2626),
    [sym__identifier_token] = ACTIONS(3011),
    [anon_sym_extern] = ACTIONS(3011),
    [anon_sym_alias] = ACTIONS(3011),
    [anon_sym_SEMI] = ACTIONS(3013),
    [anon_sym_global] = ACTIONS(3011),
    [anon_sym_using] = ACTIONS(3011),
    [anon_sym_unsafe] = ACTIONS(3011),
    [anon_sym_static] = ACTIONS(3011),
    [anon_sym_LBRACK] = ACTIONS(3013),
    [anon_sym_LPAREN] = ACTIONS(3013),
    [anon_sym_return] = ACTIONS(3011),
    [anon_sym_ref] = ACTIONS(3011),
    [anon_sym_LBRACE] = ACTIONS(3013),
    [anon_sym_RBRACE] = ACTIONS(3013),
    [anon_sym_delegate] = ACTIONS(3011),
    [anon_sym_abstract] = ACTIONS(3011),
    [anon_sym_async] = ACTIONS(3011),
    [anon_sym_const] = ACTIONS(3011),
    [anon_sym_file] = ACTIONS(3011),
    [anon_sym_fixed] = ACTIONS(3011),
    [anon_sym_internal] = ACTIONS(3011),
    [anon_sym_new] = ACTIONS(3011),
    [anon_sym_override] = ACTIONS(3011),
    [anon_sym_partial] = ACTIONS(3011),
    [anon_sym_private] = ACTIONS(3011),
    [anon_sym_protected] = ACTIONS(3011),
    [anon_sym_public] = ACTIONS(3011),
    [anon_sym_readonly] = ACTIONS(3011),
    [anon_sym_required] = ACTIONS(3011),
    [anon_sym_sealed] = ACTIONS(3011),
    [anon_sym_virtual] = ACTIONS(3011),
    [anon_sym_volatile] = ACTIONS(3011),
    [anon_sym_where] = ACTIONS(3011),
    [anon_sym_notnull] = ACTIONS(3011),
    [anon_sym_unmanaged] = ACTIONS(3011),
    [anon_sym_checked] = ACTIONS(3011),
    [anon_sym_BANG] = ACTIONS(3013),
    [anon_sym_TILDE] = ACTIONS(3013),
    [anon_sym_PLUS_PLUS] = ACTIONS(3013),
    [anon_sym_DASH_DASH] = ACTIONS(3013),
    [anon_sym_true] = ACTIONS(3011),
    [anon_sym_false] = ACTIONS(3011),
    [anon_sym_PLUS] = ACTIONS(3011),
    [anon_sym_DASH] = ACTIONS(3011),
    [anon_sym_STAR] = ACTIONS(3013),
    [anon_sym_CARET] = ACTIONS(3013),
    [anon_sym_AMP] = ACTIONS(3013),
    [anon_sym_this] = ACTIONS(3011),
    [anon_sym_scoped] = ACTIONS(3011),
    [anon_sym_base] = ACTIONS(3011),
    [anon_sym_var] = ACTIONS(3011),
    [sym_predefined_type] = ACTIONS(3011),
    [anon_sym_break] = ACTIONS(3011),
    [anon_sym_unchecked] = ACTIONS(3011),
    [anon_sym_continue] = ACTIONS(3011),
    [anon_sym_do] = ACTIONS(3011),
    [anon_sym_while] = ACTIONS(3011),
    [anon_sym_for] = ACTIONS(3011),
    [anon_sym_lock] = ACTIONS(3011),
    [anon_sym_yield] = ACTIONS(3011),
    [anon_sym_switch] = ACTIONS(3011),
    [anon_sym_case] = ACTIONS(3011),
    [anon_sym_default] = ACTIONS(3011),
    [anon_sym_throw] = ACTIONS(3011),
    [anon_sym_try] = ACTIONS(3011),
    [anon_sym_catch] = ACTIONS(4010),
    [anon_sym_when] = ACTIONS(3011),
    [anon_sym_finally] = ACTIONS(4012),
    [anon_sym_await] = ACTIONS(3011),
    [anon_sym_foreach] = ACTIONS(3011),
    [anon_sym_goto] = ACTIONS(3011),
    [anon_sym_if] = ACTIONS(3011),
    [anon_sym_else] = ACTIONS(3011),
    [anon_sym_DOT_DOT] = ACTIONS(3013),
    [anon_sym_from] = ACTIONS(3011),
    [anon_sym_into] = ACTIONS(3011),
    [anon_sym_join] = ACTIONS(3011),
    [anon_sym_on] = ACTIONS(3011),
    [anon_sym_equals] = ACTIONS(3011),
    [anon_sym_let] = ACTIONS(3011),
    [anon_sym_orderby] = ACTIONS(3011),
    [anon_sym_ascending] = ACTIONS(3011),
    [anon_sym_descending] = ACTIONS(3011),
    [anon_sym_group] = ACTIONS(3011),
    [anon_sym_by] = ACTIONS(3011),
    [anon_sym_select] = ACTIONS(3011),
    [anon_sym_stackalloc] = ACTIONS(3011),
    [anon_sym_sizeof] = ACTIONS(3011),
    [anon_sym_typeof] = ACTIONS(3011),
    [anon_sym___makeref] = ACTIONS(3011),
    [anon_sym___reftype] = ACTIONS(3011),
    [anon_sym___refvalue] = ACTIONS(3011),
    [sym_null_literal] = ACTIONS(3011),
    [anon_sym_SQUOTE] = ACTIONS(3013),
    [sym_integer_literal] = ACTIONS(3011),
    [sym_real_literal] = ACTIONS(3013),
    [anon_sym_DQUOTE] = ACTIONS(3013),
    [sym_verbatim_string_literal] = ACTIONS(3013),
    [aux_sym_preproc_if_token1] = ACTIONS(3013),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3013),
    [sym_interpolation_verbatim_start] = ACTIONS(3013),
    [sym_interpolation_raw_start] = ACTIONS(3013),
    [sym_raw_string_start] = ACTIONS(3013),
  },
  [2454] = {
    [sym_preproc_region] = STATE(2454),
    [sym_preproc_endregion] = STATE(2454),
    [sym_preproc_line] = STATE(2454),
    [sym_preproc_pragma] = STATE(2454),
    [sym_preproc_nullable] = STATE(2454),
    [sym_preproc_error] = STATE(2454),
    [sym_preproc_warning] = STATE(2454),
    [sym_preproc_define] = STATE(2454),
    [sym_preproc_undef] = STATE(2454),
    [ts_builtin_sym_end] = ACTIONS(3287),
    [sym__identifier_token] = ACTIONS(3285),
    [anon_sym_extern] = ACTIONS(3285),
    [anon_sym_alias] = ACTIONS(3285),
    [anon_sym_SEMI] = ACTIONS(3287),
    [anon_sym_global] = ACTIONS(3285),
    [anon_sym_using] = ACTIONS(3285),
    [anon_sym_unsafe] = ACTIONS(3285),
    [anon_sym_static] = ACTIONS(3285),
    [anon_sym_LBRACK] = ACTIONS(3287),
    [anon_sym_LPAREN] = ACTIONS(3287),
    [anon_sym_return] = ACTIONS(3285),
    [anon_sym_namespace] = ACTIONS(3285),
    [anon_sym_class] = ACTIONS(3285),
    [anon_sym_ref] = ACTIONS(3285),
    [anon_sym_struct] = ACTIONS(3285),
    [anon_sym_enum] = ACTIONS(3285),
    [anon_sym_LBRACE] = ACTIONS(3287),
    [anon_sym_interface] = ACTIONS(3285),
    [anon_sym_delegate] = ACTIONS(3285),
    [anon_sym_record] = ACTIONS(3285),
    [anon_sym_abstract] = ACTIONS(3285),
    [anon_sym_async] = ACTIONS(3285),
    [anon_sym_const] = ACTIONS(3285),
    [anon_sym_file] = ACTIONS(3285),
    [anon_sym_fixed] = ACTIONS(3285),
    [anon_sym_internal] = ACTIONS(3285),
    [anon_sym_new] = ACTIONS(3285),
    [anon_sym_override] = ACTIONS(3285),
    [anon_sym_partial] = ACTIONS(3285),
    [anon_sym_private] = ACTIONS(3285),
    [anon_sym_protected] = ACTIONS(3285),
    [anon_sym_public] = ACTIONS(3285),
    [anon_sym_readonly] = ACTIONS(3285),
    [anon_sym_required] = ACTIONS(3285),
    [anon_sym_sealed] = ACTIONS(3285),
    [anon_sym_virtual] = ACTIONS(3285),
    [anon_sym_volatile] = ACTIONS(3285),
    [anon_sym_where] = ACTIONS(3285),
    [anon_sym_notnull] = ACTIONS(3285),
    [anon_sym_unmanaged] = ACTIONS(3285),
    [anon_sym_checked] = ACTIONS(3285),
    [anon_sym_BANG] = ACTIONS(3287),
    [anon_sym_TILDE] = ACTIONS(3287),
    [anon_sym_PLUS_PLUS] = ACTIONS(3287),
    [anon_sym_DASH_DASH] = ACTIONS(3287),
    [anon_sym_true] = ACTIONS(3285),
    [anon_sym_false] = ACTIONS(3285),
    [anon_sym_PLUS] = ACTIONS(3285),
    [anon_sym_DASH] = ACTIONS(3285),
    [anon_sym_STAR] = ACTIONS(3287),
    [anon_sym_CARET] = ACTIONS(3287),
    [anon_sym_AMP] = ACTIONS(3287),
    [anon_sym_this] = ACTIONS(3285),
    [anon_sym_scoped] = ACTIONS(3285),
    [anon_sym_base] = ACTIONS(3285),
    [anon_sym_var] = ACTIONS(3285),
    [sym_predefined_type] = ACTIONS(3285),
    [anon_sym_break] = ACTIONS(3285),
    [anon_sym_unchecked] = ACTIONS(3285),
    [anon_sym_continue] = ACTIONS(3285),
    [anon_sym_do] = ACTIONS(3285),
    [anon_sym_while] = ACTIONS(3285),
    [anon_sym_for] = ACTIONS(3285),
    [anon_sym_lock] = ACTIONS(3285),
    [anon_sym_yield] = ACTIONS(3285),
    [anon_sym_switch] = ACTIONS(3285),
    [anon_sym_default] = ACTIONS(3285),
    [anon_sym_throw] = ACTIONS(3285),
    [anon_sym_try] = ACTIONS(3285),
    [anon_sym_when] = ACTIONS(3285),
    [anon_sym_await] = ACTIONS(3285),
    [anon_sym_foreach] = ACTIONS(3285),
    [anon_sym_goto] = ACTIONS(3285),
    [anon_sym_if] = ACTIONS(3285),
    [anon_sym_else] = ACTIONS(3285),
    [anon_sym_DOT_DOT] = ACTIONS(3287),
    [anon_sym_from] = ACTIONS(3285),
    [anon_sym_into] = ACTIONS(3285),
    [anon_sym_join] = ACTIONS(3285),
    [anon_sym_on] = ACTIONS(3285),
    [anon_sym_equals] = ACTIONS(3285),
    [anon_sym_let] = ACTIONS(3285),
    [anon_sym_orderby] = ACTIONS(3285),
    [anon_sym_ascending] = ACTIONS(3285),
    [anon_sym_descending] = ACTIONS(3285),
    [anon_sym_group] = ACTIONS(3285),
    [anon_sym_by] = ACTIONS(3285),
    [anon_sym_select] = ACTIONS(3285),
    [anon_sym_stackalloc] = ACTIONS(3285),
    [anon_sym_sizeof] = ACTIONS(3285),
    [anon_sym_typeof] = ACTIONS(3285),
    [anon_sym___makeref] = ACTIONS(3285),
    [anon_sym___reftype] = ACTIONS(3285),
    [anon_sym___refvalue] = ACTIONS(3285),
    [sym_null_literal] = ACTIONS(3285),
    [anon_sym_SQUOTE] = ACTIONS(3287),
    [sym_integer_literal] = ACTIONS(3285),
    [sym_real_literal] = ACTIONS(3287),
    [anon_sym_DQUOTE] = ACTIONS(3287),
    [sym_verbatim_string_literal] = ACTIONS(3287),
    [aux_sym_preproc_if_token1] = ACTIONS(3287),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3287),
    [sym_interpolation_verbatim_start] = ACTIONS(3287),
    [sym_interpolation_raw_start] = ACTIONS(3287),
    [sym_raw_string_start] = ACTIONS(3287),
  },
  [2455] = {
    [sym_preproc_region] = STATE(2455),
    [sym_preproc_endregion] = STATE(2455),
    [sym_preproc_line] = STATE(2455),
    [sym_preproc_pragma] = STATE(2455),
    [sym_preproc_nullable] = STATE(2455),
    [sym_preproc_error] = STATE(2455),
    [sym_preproc_warning] = STATE(2455),
    [sym_preproc_define] = STATE(2455),
    [sym_preproc_undef] = STATE(2455),
    [ts_builtin_sym_end] = ACTIONS(3407),
    [sym__identifier_token] = ACTIONS(3405),
    [anon_sym_extern] = ACTIONS(3405),
    [anon_sym_alias] = ACTIONS(3405),
    [anon_sym_SEMI] = ACTIONS(3407),
    [anon_sym_global] = ACTIONS(3405),
    [anon_sym_using] = ACTIONS(3405),
    [anon_sym_unsafe] = ACTIONS(3405),
    [anon_sym_static] = ACTIONS(3405),
    [anon_sym_LBRACK] = ACTIONS(3407),
    [anon_sym_LPAREN] = ACTIONS(3407),
    [anon_sym_return] = ACTIONS(3405),
    [anon_sym_namespace] = ACTIONS(3405),
    [anon_sym_class] = ACTIONS(3405),
    [anon_sym_ref] = ACTIONS(3405),
    [anon_sym_struct] = ACTIONS(3405),
    [anon_sym_enum] = ACTIONS(3405),
    [anon_sym_LBRACE] = ACTIONS(3407),
    [anon_sym_interface] = ACTIONS(3405),
    [anon_sym_delegate] = ACTIONS(3405),
    [anon_sym_record] = ACTIONS(3405),
    [anon_sym_abstract] = ACTIONS(3405),
    [anon_sym_async] = ACTIONS(3405),
    [anon_sym_const] = ACTIONS(3405),
    [anon_sym_file] = ACTIONS(3405),
    [anon_sym_fixed] = ACTIONS(3405),
    [anon_sym_internal] = ACTIONS(3405),
    [anon_sym_new] = ACTIONS(3405),
    [anon_sym_override] = ACTIONS(3405),
    [anon_sym_partial] = ACTIONS(3405),
    [anon_sym_private] = ACTIONS(3405),
    [anon_sym_protected] = ACTIONS(3405),
    [anon_sym_public] = ACTIONS(3405),
    [anon_sym_readonly] = ACTIONS(3405),
    [anon_sym_required] = ACTIONS(3405),
    [anon_sym_sealed] = ACTIONS(3405),
    [anon_sym_virtual] = ACTIONS(3405),
    [anon_sym_volatile] = ACTIONS(3405),
    [anon_sym_where] = ACTIONS(3405),
    [anon_sym_notnull] = ACTIONS(3405),
    [anon_sym_unmanaged] = ACTIONS(3405),
    [anon_sym_checked] = ACTIONS(3405),
    [anon_sym_BANG] = ACTIONS(3407),
    [anon_sym_TILDE] = ACTIONS(3407),
    [anon_sym_PLUS_PLUS] = ACTIONS(3407),
    [anon_sym_DASH_DASH] = ACTIONS(3407),
    [anon_sym_true] = ACTIONS(3405),
    [anon_sym_false] = ACTIONS(3405),
    [anon_sym_PLUS] = ACTIONS(3405),
    [anon_sym_DASH] = ACTIONS(3405),
    [anon_sym_STAR] = ACTIONS(3407),
    [anon_sym_CARET] = ACTIONS(3407),
    [anon_sym_AMP] = ACTIONS(3407),
    [anon_sym_this] = ACTIONS(3405),
    [anon_sym_scoped] = ACTIONS(3405),
    [anon_sym_base] = ACTIONS(3405),
    [anon_sym_var] = ACTIONS(3405),
    [sym_predefined_type] = ACTIONS(3405),
    [anon_sym_break] = ACTIONS(3405),
    [anon_sym_unchecked] = ACTIONS(3405),
    [anon_sym_continue] = ACTIONS(3405),
    [anon_sym_do] = ACTIONS(3405),
    [anon_sym_while] = ACTIONS(3405),
    [anon_sym_for] = ACTIONS(3405),
    [anon_sym_lock] = ACTIONS(3405),
    [anon_sym_yield] = ACTIONS(3405),
    [anon_sym_switch] = ACTIONS(3405),
    [anon_sym_default] = ACTIONS(3405),
    [anon_sym_throw] = ACTIONS(3405),
    [anon_sym_try] = ACTIONS(3405),
    [anon_sym_when] = ACTIONS(3405),
    [anon_sym_await] = ACTIONS(3405),
    [anon_sym_foreach] = ACTIONS(3405),
    [anon_sym_goto] = ACTIONS(3405),
    [anon_sym_if] = ACTIONS(3405),
    [anon_sym_else] = ACTIONS(3405),
    [anon_sym_DOT_DOT] = ACTIONS(3407),
    [anon_sym_from] = ACTIONS(3405),
    [anon_sym_into] = ACTIONS(3405),
    [anon_sym_join] = ACTIONS(3405),
    [anon_sym_on] = ACTIONS(3405),
    [anon_sym_equals] = ACTIONS(3405),
    [anon_sym_let] = ACTIONS(3405),
    [anon_sym_orderby] = ACTIONS(3405),
    [anon_sym_ascending] = ACTIONS(3405),
    [anon_sym_descending] = ACTIONS(3405),
    [anon_sym_group] = ACTIONS(3405),
    [anon_sym_by] = ACTIONS(3405),
    [anon_sym_select] = ACTIONS(3405),
    [anon_sym_stackalloc] = ACTIONS(3405),
    [anon_sym_sizeof] = ACTIONS(3405),
    [anon_sym_typeof] = ACTIONS(3405),
    [anon_sym___makeref] = ACTIONS(3405),
    [anon_sym___reftype] = ACTIONS(3405),
    [anon_sym___refvalue] = ACTIONS(3405),
    [sym_null_literal] = ACTIONS(3405),
    [anon_sym_SQUOTE] = ACTIONS(3407),
    [sym_integer_literal] = ACTIONS(3405),
    [sym_real_literal] = ACTIONS(3407),
    [anon_sym_DQUOTE] = ACTIONS(3407),
    [sym_verbatim_string_literal] = ACTIONS(3407),
    [aux_sym_preproc_if_token1] = ACTIONS(3407),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3407),
    [sym_interpolation_verbatim_start] = ACTIONS(3407),
    [sym_interpolation_raw_start] = ACTIONS(3407),
    [sym_raw_string_start] = ACTIONS(3407),
  },
  [2456] = {
    [sym_preproc_region] = STATE(2456),
    [sym_preproc_endregion] = STATE(2456),
    [sym_preproc_line] = STATE(2456),
    [sym_preproc_pragma] = STATE(2456),
    [sym_preproc_nullable] = STATE(2456),
    [sym_preproc_error] = STATE(2456),
    [sym_preproc_warning] = STATE(2456),
    [sym_preproc_define] = STATE(2456),
    [sym_preproc_undef] = STATE(2456),
    [ts_builtin_sym_end] = ACTIONS(3251),
    [sym__identifier_token] = ACTIONS(3249),
    [anon_sym_extern] = ACTIONS(3249),
    [anon_sym_alias] = ACTIONS(3249),
    [anon_sym_SEMI] = ACTIONS(3251),
    [anon_sym_global] = ACTIONS(3249),
    [anon_sym_using] = ACTIONS(3249),
    [anon_sym_unsafe] = ACTIONS(3249),
    [anon_sym_static] = ACTIONS(3249),
    [anon_sym_LBRACK] = ACTIONS(3251),
    [anon_sym_LPAREN] = ACTIONS(3251),
    [anon_sym_return] = ACTIONS(3249),
    [anon_sym_namespace] = ACTIONS(3249),
    [anon_sym_class] = ACTIONS(3249),
    [anon_sym_ref] = ACTIONS(3249),
    [anon_sym_struct] = ACTIONS(3249),
    [anon_sym_enum] = ACTIONS(3249),
    [anon_sym_LBRACE] = ACTIONS(3251),
    [anon_sym_interface] = ACTIONS(3249),
    [anon_sym_delegate] = ACTIONS(3249),
    [anon_sym_record] = ACTIONS(3249),
    [anon_sym_abstract] = ACTIONS(3249),
    [anon_sym_async] = ACTIONS(3249),
    [anon_sym_const] = ACTIONS(3249),
    [anon_sym_file] = ACTIONS(3249),
    [anon_sym_fixed] = ACTIONS(3249),
    [anon_sym_internal] = ACTIONS(3249),
    [anon_sym_new] = ACTIONS(3249),
    [anon_sym_override] = ACTIONS(3249),
    [anon_sym_partial] = ACTIONS(3249),
    [anon_sym_private] = ACTIONS(3249),
    [anon_sym_protected] = ACTIONS(3249),
    [anon_sym_public] = ACTIONS(3249),
    [anon_sym_readonly] = ACTIONS(3249),
    [anon_sym_required] = ACTIONS(3249),
    [anon_sym_sealed] = ACTIONS(3249),
    [anon_sym_virtual] = ACTIONS(3249),
    [anon_sym_volatile] = ACTIONS(3249),
    [anon_sym_where] = ACTIONS(3249),
    [anon_sym_notnull] = ACTIONS(3249),
    [anon_sym_unmanaged] = ACTIONS(3249),
    [anon_sym_checked] = ACTIONS(3249),
    [anon_sym_BANG] = ACTIONS(3251),
    [anon_sym_TILDE] = ACTIONS(3251),
    [anon_sym_PLUS_PLUS] = ACTIONS(3251),
    [anon_sym_DASH_DASH] = ACTIONS(3251),
    [anon_sym_true] = ACTIONS(3249),
    [anon_sym_false] = ACTIONS(3249),
    [anon_sym_PLUS] = ACTIONS(3249),
    [anon_sym_DASH] = ACTIONS(3249),
    [anon_sym_STAR] = ACTIONS(3251),
    [anon_sym_CARET] = ACTIONS(3251),
    [anon_sym_AMP] = ACTIONS(3251),
    [anon_sym_this] = ACTIONS(3249),
    [anon_sym_scoped] = ACTIONS(3249),
    [anon_sym_base] = ACTIONS(3249),
    [anon_sym_var] = ACTIONS(3249),
    [sym_predefined_type] = ACTIONS(3249),
    [anon_sym_break] = ACTIONS(3249),
    [anon_sym_unchecked] = ACTIONS(3249),
    [anon_sym_continue] = ACTIONS(3249),
    [anon_sym_do] = ACTIONS(3249),
    [anon_sym_while] = ACTIONS(3249),
    [anon_sym_for] = ACTIONS(3249),
    [anon_sym_lock] = ACTIONS(3249),
    [anon_sym_yield] = ACTIONS(3249),
    [anon_sym_switch] = ACTIONS(3249),
    [anon_sym_default] = ACTIONS(3249),
    [anon_sym_throw] = ACTIONS(3249),
    [anon_sym_try] = ACTIONS(3249),
    [anon_sym_when] = ACTIONS(3249),
    [anon_sym_await] = ACTIONS(3249),
    [anon_sym_foreach] = ACTIONS(3249),
    [anon_sym_goto] = ACTIONS(3249),
    [anon_sym_if] = ACTIONS(3249),
    [anon_sym_else] = ACTIONS(3249),
    [anon_sym_DOT_DOT] = ACTIONS(3251),
    [anon_sym_from] = ACTIONS(3249),
    [anon_sym_into] = ACTIONS(3249),
    [anon_sym_join] = ACTIONS(3249),
    [anon_sym_on] = ACTIONS(3249),
    [anon_sym_equals] = ACTIONS(3249),
    [anon_sym_let] = ACTIONS(3249),
    [anon_sym_orderby] = ACTIONS(3249),
    [anon_sym_ascending] = ACTIONS(3249),
    [anon_sym_descending] = ACTIONS(3249),
    [anon_sym_group] = ACTIONS(3249),
    [anon_sym_by] = ACTIONS(3249),
    [anon_sym_select] = ACTIONS(3249),
    [anon_sym_stackalloc] = ACTIONS(3249),
    [anon_sym_sizeof] = ACTIONS(3249),
    [anon_sym_typeof] = ACTIONS(3249),
    [anon_sym___makeref] = ACTIONS(3249),
    [anon_sym___reftype] = ACTIONS(3249),
    [anon_sym___refvalue] = ACTIONS(3249),
    [sym_null_literal] = ACTIONS(3249),
    [anon_sym_SQUOTE] = ACTIONS(3251),
    [sym_integer_literal] = ACTIONS(3249),
    [sym_real_literal] = ACTIONS(3251),
    [anon_sym_DQUOTE] = ACTIONS(3251),
    [sym_verbatim_string_literal] = ACTIONS(3251),
    [aux_sym_preproc_if_token1] = ACTIONS(3251),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3251),
    [sym_interpolation_verbatim_start] = ACTIONS(3251),
    [sym_interpolation_raw_start] = ACTIONS(3251),
    [sym_raw_string_start] = ACTIONS(3251),
  },
  [2457] = {
    [sym_preproc_region] = STATE(2457),
    [sym_preproc_endregion] = STATE(2457),
    [sym_preproc_line] = STATE(2457),
    [sym_preproc_pragma] = STATE(2457),
    [sym_preproc_nullable] = STATE(2457),
    [sym_preproc_error] = STATE(2457),
    [sym_preproc_warning] = STATE(2457),
    [sym_preproc_define] = STATE(2457),
    [sym_preproc_undef] = STATE(2457),
    [ts_builtin_sym_end] = ACTIONS(3255),
    [sym__identifier_token] = ACTIONS(3253),
    [anon_sym_extern] = ACTIONS(3253),
    [anon_sym_alias] = ACTIONS(3253),
    [anon_sym_SEMI] = ACTIONS(3255),
    [anon_sym_global] = ACTIONS(3253),
    [anon_sym_using] = ACTIONS(3253),
    [anon_sym_unsafe] = ACTIONS(3253),
    [anon_sym_static] = ACTIONS(3253),
    [anon_sym_LBRACK] = ACTIONS(3255),
    [anon_sym_LPAREN] = ACTIONS(3255),
    [anon_sym_return] = ACTIONS(3253),
    [anon_sym_namespace] = ACTIONS(3253),
    [anon_sym_class] = ACTIONS(3253),
    [anon_sym_ref] = ACTIONS(3253),
    [anon_sym_struct] = ACTIONS(3253),
    [anon_sym_enum] = ACTIONS(3253),
    [anon_sym_LBRACE] = ACTIONS(3255),
    [anon_sym_interface] = ACTIONS(3253),
    [anon_sym_delegate] = ACTIONS(3253),
    [anon_sym_record] = ACTIONS(3253),
    [anon_sym_abstract] = ACTIONS(3253),
    [anon_sym_async] = ACTIONS(3253),
    [anon_sym_const] = ACTIONS(3253),
    [anon_sym_file] = ACTIONS(3253),
    [anon_sym_fixed] = ACTIONS(3253),
    [anon_sym_internal] = ACTIONS(3253),
    [anon_sym_new] = ACTIONS(3253),
    [anon_sym_override] = ACTIONS(3253),
    [anon_sym_partial] = ACTIONS(3253),
    [anon_sym_private] = ACTIONS(3253),
    [anon_sym_protected] = ACTIONS(3253),
    [anon_sym_public] = ACTIONS(3253),
    [anon_sym_readonly] = ACTIONS(3253),
    [anon_sym_required] = ACTIONS(3253),
    [anon_sym_sealed] = ACTIONS(3253),
    [anon_sym_virtual] = ACTIONS(3253),
    [anon_sym_volatile] = ACTIONS(3253),
    [anon_sym_where] = ACTIONS(3253),
    [anon_sym_notnull] = ACTIONS(3253),
    [anon_sym_unmanaged] = ACTIONS(3253),
    [anon_sym_checked] = ACTIONS(3253),
    [anon_sym_BANG] = ACTIONS(3255),
    [anon_sym_TILDE] = ACTIONS(3255),
    [anon_sym_PLUS_PLUS] = ACTIONS(3255),
    [anon_sym_DASH_DASH] = ACTIONS(3255),
    [anon_sym_true] = ACTIONS(3253),
    [anon_sym_false] = ACTIONS(3253),
    [anon_sym_PLUS] = ACTIONS(3253),
    [anon_sym_DASH] = ACTIONS(3253),
    [anon_sym_STAR] = ACTIONS(3255),
    [anon_sym_CARET] = ACTIONS(3255),
    [anon_sym_AMP] = ACTIONS(3255),
    [anon_sym_this] = ACTIONS(3253),
    [anon_sym_scoped] = ACTIONS(3253),
    [anon_sym_base] = ACTIONS(3253),
    [anon_sym_var] = ACTIONS(3253),
    [sym_predefined_type] = ACTIONS(3253),
    [anon_sym_break] = ACTIONS(3253),
    [anon_sym_unchecked] = ACTIONS(3253),
    [anon_sym_continue] = ACTIONS(3253),
    [anon_sym_do] = ACTIONS(3253),
    [anon_sym_while] = ACTIONS(3253),
    [anon_sym_for] = ACTIONS(3253),
    [anon_sym_lock] = ACTIONS(3253),
    [anon_sym_yield] = ACTIONS(3253),
    [anon_sym_switch] = ACTIONS(3253),
    [anon_sym_default] = ACTIONS(3253),
    [anon_sym_throw] = ACTIONS(3253),
    [anon_sym_try] = ACTIONS(3253),
    [anon_sym_when] = ACTIONS(3253),
    [anon_sym_await] = ACTIONS(3253),
    [anon_sym_foreach] = ACTIONS(3253),
    [anon_sym_goto] = ACTIONS(3253),
    [anon_sym_if] = ACTIONS(3253),
    [anon_sym_else] = ACTIONS(3253),
    [anon_sym_DOT_DOT] = ACTIONS(3255),
    [anon_sym_from] = ACTIONS(3253),
    [anon_sym_into] = ACTIONS(3253),
    [anon_sym_join] = ACTIONS(3253),
    [anon_sym_on] = ACTIONS(3253),
    [anon_sym_equals] = ACTIONS(3253),
    [anon_sym_let] = ACTIONS(3253),
    [anon_sym_orderby] = ACTIONS(3253),
    [anon_sym_ascending] = ACTIONS(3253),
    [anon_sym_descending] = ACTIONS(3253),
    [anon_sym_group] = ACTIONS(3253),
    [anon_sym_by] = ACTIONS(3253),
    [anon_sym_select] = ACTIONS(3253),
    [anon_sym_stackalloc] = ACTIONS(3253),
    [anon_sym_sizeof] = ACTIONS(3253),
    [anon_sym_typeof] = ACTIONS(3253),
    [anon_sym___makeref] = ACTIONS(3253),
    [anon_sym___reftype] = ACTIONS(3253),
    [anon_sym___refvalue] = ACTIONS(3253),
    [sym_null_literal] = ACTIONS(3253),
    [anon_sym_SQUOTE] = ACTIONS(3255),
    [sym_integer_literal] = ACTIONS(3253),
    [sym_real_literal] = ACTIONS(3255),
    [anon_sym_DQUOTE] = ACTIONS(3255),
    [sym_verbatim_string_literal] = ACTIONS(3255),
    [aux_sym_preproc_if_token1] = ACTIONS(3255),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3255),
    [sym_interpolation_verbatim_start] = ACTIONS(3255),
    [sym_interpolation_raw_start] = ACTIONS(3255),
    [sym_raw_string_start] = ACTIONS(3255),
  },
  [2458] = {
    [sym_preproc_region] = STATE(2458),
    [sym_preproc_endregion] = STATE(2458),
    [sym_preproc_line] = STATE(2458),
    [sym_preproc_pragma] = STATE(2458),
    [sym_preproc_nullable] = STATE(2458),
    [sym_preproc_error] = STATE(2458),
    [sym_preproc_warning] = STATE(2458),
    [sym_preproc_define] = STATE(2458),
    [sym_preproc_undef] = STATE(2458),
    [ts_builtin_sym_end] = ACTIONS(3263),
    [sym__identifier_token] = ACTIONS(3261),
    [anon_sym_extern] = ACTIONS(3261),
    [anon_sym_alias] = ACTIONS(3261),
    [anon_sym_SEMI] = ACTIONS(3263),
    [anon_sym_global] = ACTIONS(3261),
    [anon_sym_using] = ACTIONS(3261),
    [anon_sym_unsafe] = ACTIONS(3261),
    [anon_sym_static] = ACTIONS(3261),
    [anon_sym_LBRACK] = ACTIONS(3263),
    [anon_sym_LPAREN] = ACTIONS(3263),
    [anon_sym_return] = ACTIONS(3261),
    [anon_sym_namespace] = ACTIONS(3261),
    [anon_sym_class] = ACTIONS(3261),
    [anon_sym_ref] = ACTIONS(3261),
    [anon_sym_struct] = ACTIONS(3261),
    [anon_sym_enum] = ACTIONS(3261),
    [anon_sym_LBRACE] = ACTIONS(3263),
    [anon_sym_interface] = ACTIONS(3261),
    [anon_sym_delegate] = ACTIONS(3261),
    [anon_sym_record] = ACTIONS(3261),
    [anon_sym_abstract] = ACTIONS(3261),
    [anon_sym_async] = ACTIONS(3261),
    [anon_sym_const] = ACTIONS(3261),
    [anon_sym_file] = ACTIONS(3261),
    [anon_sym_fixed] = ACTIONS(3261),
    [anon_sym_internal] = ACTIONS(3261),
    [anon_sym_new] = ACTIONS(3261),
    [anon_sym_override] = ACTIONS(3261),
    [anon_sym_partial] = ACTIONS(3261),
    [anon_sym_private] = ACTIONS(3261),
    [anon_sym_protected] = ACTIONS(3261),
    [anon_sym_public] = ACTIONS(3261),
    [anon_sym_readonly] = ACTIONS(3261),
    [anon_sym_required] = ACTIONS(3261),
    [anon_sym_sealed] = ACTIONS(3261),
    [anon_sym_virtual] = ACTIONS(3261),
    [anon_sym_volatile] = ACTIONS(3261),
    [anon_sym_where] = ACTIONS(3261),
    [anon_sym_notnull] = ACTIONS(3261),
    [anon_sym_unmanaged] = ACTIONS(3261),
    [anon_sym_checked] = ACTIONS(3261),
    [anon_sym_BANG] = ACTIONS(3263),
    [anon_sym_TILDE] = ACTIONS(3263),
    [anon_sym_PLUS_PLUS] = ACTIONS(3263),
    [anon_sym_DASH_DASH] = ACTIONS(3263),
    [anon_sym_true] = ACTIONS(3261),
    [anon_sym_false] = ACTIONS(3261),
    [anon_sym_PLUS] = ACTIONS(3261),
    [anon_sym_DASH] = ACTIONS(3261),
    [anon_sym_STAR] = ACTIONS(3263),
    [anon_sym_CARET] = ACTIONS(3263),
    [anon_sym_AMP] = ACTIONS(3263),
    [anon_sym_this] = ACTIONS(3261),
    [anon_sym_scoped] = ACTIONS(3261),
    [anon_sym_base] = ACTIONS(3261),
    [anon_sym_var] = ACTIONS(3261),
    [sym_predefined_type] = ACTIONS(3261),
    [anon_sym_break] = ACTIONS(3261),
    [anon_sym_unchecked] = ACTIONS(3261),
    [anon_sym_continue] = ACTIONS(3261),
    [anon_sym_do] = ACTIONS(3261),
    [anon_sym_while] = ACTIONS(3261),
    [anon_sym_for] = ACTIONS(3261),
    [anon_sym_lock] = ACTIONS(3261),
    [anon_sym_yield] = ACTIONS(3261),
    [anon_sym_switch] = ACTIONS(3261),
    [anon_sym_default] = ACTIONS(3261),
    [anon_sym_throw] = ACTIONS(3261),
    [anon_sym_try] = ACTIONS(3261),
    [anon_sym_when] = ACTIONS(3261),
    [anon_sym_await] = ACTIONS(3261),
    [anon_sym_foreach] = ACTIONS(3261),
    [anon_sym_goto] = ACTIONS(3261),
    [anon_sym_if] = ACTIONS(3261),
    [anon_sym_else] = ACTIONS(3261),
    [anon_sym_DOT_DOT] = ACTIONS(3263),
    [anon_sym_from] = ACTIONS(3261),
    [anon_sym_into] = ACTIONS(3261),
    [anon_sym_join] = ACTIONS(3261),
    [anon_sym_on] = ACTIONS(3261),
    [anon_sym_equals] = ACTIONS(3261),
    [anon_sym_let] = ACTIONS(3261),
    [anon_sym_orderby] = ACTIONS(3261),
    [anon_sym_ascending] = ACTIONS(3261),
    [anon_sym_descending] = ACTIONS(3261),
    [anon_sym_group] = ACTIONS(3261),
    [anon_sym_by] = ACTIONS(3261),
    [anon_sym_select] = ACTIONS(3261),
    [anon_sym_stackalloc] = ACTIONS(3261),
    [anon_sym_sizeof] = ACTIONS(3261),
    [anon_sym_typeof] = ACTIONS(3261),
    [anon_sym___makeref] = ACTIONS(3261),
    [anon_sym___reftype] = ACTIONS(3261),
    [anon_sym___refvalue] = ACTIONS(3261),
    [sym_null_literal] = ACTIONS(3261),
    [anon_sym_SQUOTE] = ACTIONS(3263),
    [sym_integer_literal] = ACTIONS(3261),
    [sym_real_literal] = ACTIONS(3263),
    [anon_sym_DQUOTE] = ACTIONS(3263),
    [sym_verbatim_string_literal] = ACTIONS(3263),
    [aux_sym_preproc_if_token1] = ACTIONS(3263),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3263),
    [sym_interpolation_verbatim_start] = ACTIONS(3263),
    [sym_interpolation_raw_start] = ACTIONS(3263),
    [sym_raw_string_start] = ACTIONS(3263),
  },
  [2459] = {
    [sym_preproc_region] = STATE(2459),
    [sym_preproc_endregion] = STATE(2459),
    [sym_preproc_line] = STATE(2459),
    [sym_preproc_pragma] = STATE(2459),
    [sym_preproc_nullable] = STATE(2459),
    [sym_preproc_error] = STATE(2459),
    [sym_preproc_warning] = STATE(2459),
    [sym_preproc_define] = STATE(2459),
    [sym_preproc_undef] = STATE(2459),
    [ts_builtin_sym_end] = ACTIONS(3267),
    [sym__identifier_token] = ACTIONS(3265),
    [anon_sym_extern] = ACTIONS(3265),
    [anon_sym_alias] = ACTIONS(3265),
    [anon_sym_SEMI] = ACTIONS(3267),
    [anon_sym_global] = ACTIONS(3265),
    [anon_sym_using] = ACTIONS(3265),
    [anon_sym_unsafe] = ACTIONS(3265),
    [anon_sym_static] = ACTIONS(3265),
    [anon_sym_LBRACK] = ACTIONS(3267),
    [anon_sym_LPAREN] = ACTIONS(3267),
    [anon_sym_return] = ACTIONS(3265),
    [anon_sym_namespace] = ACTIONS(3265),
    [anon_sym_class] = ACTIONS(3265),
    [anon_sym_ref] = ACTIONS(3265),
    [anon_sym_struct] = ACTIONS(3265),
    [anon_sym_enum] = ACTIONS(3265),
    [anon_sym_LBRACE] = ACTIONS(3267),
    [anon_sym_interface] = ACTIONS(3265),
    [anon_sym_delegate] = ACTIONS(3265),
    [anon_sym_record] = ACTIONS(3265),
    [anon_sym_abstract] = ACTIONS(3265),
    [anon_sym_async] = ACTIONS(3265),
    [anon_sym_const] = ACTIONS(3265),
    [anon_sym_file] = ACTIONS(3265),
    [anon_sym_fixed] = ACTIONS(3265),
    [anon_sym_internal] = ACTIONS(3265),
    [anon_sym_new] = ACTIONS(3265),
    [anon_sym_override] = ACTIONS(3265),
    [anon_sym_partial] = ACTIONS(3265),
    [anon_sym_private] = ACTIONS(3265),
    [anon_sym_protected] = ACTIONS(3265),
    [anon_sym_public] = ACTIONS(3265),
    [anon_sym_readonly] = ACTIONS(3265),
    [anon_sym_required] = ACTIONS(3265),
    [anon_sym_sealed] = ACTIONS(3265),
    [anon_sym_virtual] = ACTIONS(3265),
    [anon_sym_volatile] = ACTIONS(3265),
    [anon_sym_where] = ACTIONS(3265),
    [anon_sym_notnull] = ACTIONS(3265),
    [anon_sym_unmanaged] = ACTIONS(3265),
    [anon_sym_checked] = ACTIONS(3265),
    [anon_sym_BANG] = ACTIONS(3267),
    [anon_sym_TILDE] = ACTIONS(3267),
    [anon_sym_PLUS_PLUS] = ACTIONS(3267),
    [anon_sym_DASH_DASH] = ACTIONS(3267),
    [anon_sym_true] = ACTIONS(3265),
    [anon_sym_false] = ACTIONS(3265),
    [anon_sym_PLUS] = ACTIONS(3265),
    [anon_sym_DASH] = ACTIONS(3265),
    [anon_sym_STAR] = ACTIONS(3267),
    [anon_sym_CARET] = ACTIONS(3267),
    [anon_sym_AMP] = ACTIONS(3267),
    [anon_sym_this] = ACTIONS(3265),
    [anon_sym_scoped] = ACTIONS(3265),
    [anon_sym_base] = ACTIONS(3265),
    [anon_sym_var] = ACTIONS(3265),
    [sym_predefined_type] = ACTIONS(3265),
    [anon_sym_break] = ACTIONS(3265),
    [anon_sym_unchecked] = ACTIONS(3265),
    [anon_sym_continue] = ACTIONS(3265),
    [anon_sym_do] = ACTIONS(3265),
    [anon_sym_while] = ACTIONS(3265),
    [anon_sym_for] = ACTIONS(3265),
    [anon_sym_lock] = ACTIONS(3265),
    [anon_sym_yield] = ACTIONS(3265),
    [anon_sym_switch] = ACTIONS(3265),
    [anon_sym_default] = ACTIONS(3265),
    [anon_sym_throw] = ACTIONS(3265),
    [anon_sym_try] = ACTIONS(3265),
    [anon_sym_when] = ACTIONS(3265),
    [anon_sym_await] = ACTIONS(3265),
    [anon_sym_foreach] = ACTIONS(3265),
    [anon_sym_goto] = ACTIONS(3265),
    [anon_sym_if] = ACTIONS(3265),
    [anon_sym_else] = ACTIONS(3265),
    [anon_sym_DOT_DOT] = ACTIONS(3267),
    [anon_sym_from] = ACTIONS(3265),
    [anon_sym_into] = ACTIONS(3265),
    [anon_sym_join] = ACTIONS(3265),
    [anon_sym_on] = ACTIONS(3265),
    [anon_sym_equals] = ACTIONS(3265),
    [anon_sym_let] = ACTIONS(3265),
    [anon_sym_orderby] = ACTIONS(3265),
    [anon_sym_ascending] = ACTIONS(3265),
    [anon_sym_descending] = ACTIONS(3265),
    [anon_sym_group] = ACTIONS(3265),
    [anon_sym_by] = ACTIONS(3265),
    [anon_sym_select] = ACTIONS(3265),
    [anon_sym_stackalloc] = ACTIONS(3265),
    [anon_sym_sizeof] = ACTIONS(3265),
    [anon_sym_typeof] = ACTIONS(3265),
    [anon_sym___makeref] = ACTIONS(3265),
    [anon_sym___reftype] = ACTIONS(3265),
    [anon_sym___refvalue] = ACTIONS(3265),
    [sym_null_literal] = ACTIONS(3265),
    [anon_sym_SQUOTE] = ACTIONS(3267),
    [sym_integer_literal] = ACTIONS(3265),
    [sym_real_literal] = ACTIONS(3267),
    [anon_sym_DQUOTE] = ACTIONS(3267),
    [sym_verbatim_string_literal] = ACTIONS(3267),
    [aux_sym_preproc_if_token1] = ACTIONS(3267),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3267),
    [sym_interpolation_verbatim_start] = ACTIONS(3267),
    [sym_interpolation_raw_start] = ACTIONS(3267),
    [sym_raw_string_start] = ACTIONS(3267),
  },
  [2460] = {
    [sym_preproc_region] = STATE(2460),
    [sym_preproc_endregion] = STATE(2460),
    [sym_preproc_line] = STATE(2460),
    [sym_preproc_pragma] = STATE(2460),
    [sym_preproc_nullable] = STATE(2460),
    [sym_preproc_error] = STATE(2460),
    [sym_preproc_warning] = STATE(2460),
    [sym_preproc_define] = STATE(2460),
    [sym_preproc_undef] = STATE(2460),
    [ts_builtin_sym_end] = ACTIONS(3303),
    [sym__identifier_token] = ACTIONS(3301),
    [anon_sym_extern] = ACTIONS(3301),
    [anon_sym_alias] = ACTIONS(3301),
    [anon_sym_SEMI] = ACTIONS(3303),
    [anon_sym_global] = ACTIONS(3301),
    [anon_sym_using] = ACTIONS(3301),
    [anon_sym_unsafe] = ACTIONS(3301),
    [anon_sym_static] = ACTIONS(3301),
    [anon_sym_LBRACK] = ACTIONS(3303),
    [anon_sym_LPAREN] = ACTIONS(3303),
    [anon_sym_return] = ACTIONS(3301),
    [anon_sym_namespace] = ACTIONS(3301),
    [anon_sym_class] = ACTIONS(3301),
    [anon_sym_ref] = ACTIONS(3301),
    [anon_sym_struct] = ACTIONS(3301),
    [anon_sym_enum] = ACTIONS(3301),
    [anon_sym_LBRACE] = ACTIONS(3303),
    [anon_sym_interface] = ACTIONS(3301),
    [anon_sym_delegate] = ACTIONS(3301),
    [anon_sym_record] = ACTIONS(3301),
    [anon_sym_abstract] = ACTIONS(3301),
    [anon_sym_async] = ACTIONS(3301),
    [anon_sym_const] = ACTIONS(3301),
    [anon_sym_file] = ACTIONS(3301),
    [anon_sym_fixed] = ACTIONS(3301),
    [anon_sym_internal] = ACTIONS(3301),
    [anon_sym_new] = ACTIONS(3301),
    [anon_sym_override] = ACTIONS(3301),
    [anon_sym_partial] = ACTIONS(3301),
    [anon_sym_private] = ACTIONS(3301),
    [anon_sym_protected] = ACTIONS(3301),
    [anon_sym_public] = ACTIONS(3301),
    [anon_sym_readonly] = ACTIONS(3301),
    [anon_sym_required] = ACTIONS(3301),
    [anon_sym_sealed] = ACTIONS(3301),
    [anon_sym_virtual] = ACTIONS(3301),
    [anon_sym_volatile] = ACTIONS(3301),
    [anon_sym_where] = ACTIONS(3301),
    [anon_sym_notnull] = ACTIONS(3301),
    [anon_sym_unmanaged] = ACTIONS(3301),
    [anon_sym_checked] = ACTIONS(3301),
    [anon_sym_BANG] = ACTIONS(3303),
    [anon_sym_TILDE] = ACTIONS(3303),
    [anon_sym_PLUS_PLUS] = ACTIONS(3303),
    [anon_sym_DASH_DASH] = ACTIONS(3303),
    [anon_sym_true] = ACTIONS(3301),
    [anon_sym_false] = ACTIONS(3301),
    [anon_sym_PLUS] = ACTIONS(3301),
    [anon_sym_DASH] = ACTIONS(3301),
    [anon_sym_STAR] = ACTIONS(3303),
    [anon_sym_CARET] = ACTIONS(3303),
    [anon_sym_AMP] = ACTIONS(3303),
    [anon_sym_this] = ACTIONS(3301),
    [anon_sym_scoped] = ACTIONS(3301),
    [anon_sym_base] = ACTIONS(3301),
    [anon_sym_var] = ACTIONS(3301),
    [sym_predefined_type] = ACTIONS(3301),
    [anon_sym_break] = ACTIONS(3301),
    [anon_sym_unchecked] = ACTIONS(3301),
    [anon_sym_continue] = ACTIONS(3301),
    [anon_sym_do] = ACTIONS(3301),
    [anon_sym_while] = ACTIONS(3301),
    [anon_sym_for] = ACTIONS(3301),
    [anon_sym_lock] = ACTIONS(3301),
    [anon_sym_yield] = ACTIONS(3301),
    [anon_sym_switch] = ACTIONS(3301),
    [anon_sym_default] = ACTIONS(3301),
    [anon_sym_throw] = ACTIONS(3301),
    [anon_sym_try] = ACTIONS(3301),
    [anon_sym_when] = ACTIONS(3301),
    [anon_sym_await] = ACTIONS(3301),
    [anon_sym_foreach] = ACTIONS(3301),
    [anon_sym_goto] = ACTIONS(3301),
    [anon_sym_if] = ACTIONS(3301),
    [anon_sym_else] = ACTIONS(3301),
    [anon_sym_DOT_DOT] = ACTIONS(3303),
    [anon_sym_from] = ACTIONS(3301),
    [anon_sym_into] = ACTIONS(3301),
    [anon_sym_join] = ACTIONS(3301),
    [anon_sym_on] = ACTIONS(3301),
    [anon_sym_equals] = ACTIONS(3301),
    [anon_sym_let] = ACTIONS(3301),
    [anon_sym_orderby] = ACTIONS(3301),
    [anon_sym_ascending] = ACTIONS(3301),
    [anon_sym_descending] = ACTIONS(3301),
    [anon_sym_group] = ACTIONS(3301),
    [anon_sym_by] = ACTIONS(3301),
    [anon_sym_select] = ACTIONS(3301),
    [anon_sym_stackalloc] = ACTIONS(3301),
    [anon_sym_sizeof] = ACTIONS(3301),
    [anon_sym_typeof] = ACTIONS(3301),
    [anon_sym___makeref] = ACTIONS(3301),
    [anon_sym___reftype] = ACTIONS(3301),
    [anon_sym___refvalue] = ACTIONS(3301),
    [sym_null_literal] = ACTIONS(3301),
    [anon_sym_SQUOTE] = ACTIONS(3303),
    [sym_integer_literal] = ACTIONS(3301),
    [sym_real_literal] = ACTIONS(3303),
    [anon_sym_DQUOTE] = ACTIONS(3303),
    [sym_verbatim_string_literal] = ACTIONS(3303),
    [aux_sym_preproc_if_token1] = ACTIONS(3303),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3303),
    [sym_interpolation_verbatim_start] = ACTIONS(3303),
    [sym_interpolation_raw_start] = ACTIONS(3303),
    [sym_raw_string_start] = ACTIONS(3303),
  },
  [2461] = {
    [sym_preproc_region] = STATE(2461),
    [sym_preproc_endregion] = STATE(2461),
    [sym_preproc_line] = STATE(2461),
    [sym_preproc_pragma] = STATE(2461),
    [sym_preproc_nullable] = STATE(2461),
    [sym_preproc_error] = STATE(2461),
    [sym_preproc_warning] = STATE(2461),
    [sym_preproc_define] = STATE(2461),
    [sym_preproc_undef] = STATE(2461),
    [ts_builtin_sym_end] = ACTIONS(3099),
    [sym__identifier_token] = ACTIONS(3097),
    [anon_sym_extern] = ACTIONS(3097),
    [anon_sym_alias] = ACTIONS(3097),
    [anon_sym_SEMI] = ACTIONS(3099),
    [anon_sym_global] = ACTIONS(3097),
    [anon_sym_using] = ACTIONS(3097),
    [anon_sym_unsafe] = ACTIONS(3097),
    [anon_sym_static] = ACTIONS(3097),
    [anon_sym_LBRACK] = ACTIONS(3099),
    [anon_sym_LPAREN] = ACTIONS(3099),
    [anon_sym_return] = ACTIONS(3097),
    [anon_sym_namespace] = ACTIONS(3097),
    [anon_sym_class] = ACTIONS(3097),
    [anon_sym_ref] = ACTIONS(3097),
    [anon_sym_struct] = ACTIONS(3097),
    [anon_sym_enum] = ACTIONS(3097),
    [anon_sym_LBRACE] = ACTIONS(3099),
    [anon_sym_interface] = ACTIONS(3097),
    [anon_sym_delegate] = ACTIONS(3097),
    [anon_sym_record] = ACTIONS(3097),
    [anon_sym_abstract] = ACTIONS(3097),
    [anon_sym_async] = ACTIONS(3097),
    [anon_sym_const] = ACTIONS(3097),
    [anon_sym_file] = ACTIONS(3097),
    [anon_sym_fixed] = ACTIONS(3097),
    [anon_sym_internal] = ACTIONS(3097),
    [anon_sym_new] = ACTIONS(3097),
    [anon_sym_override] = ACTIONS(3097),
    [anon_sym_partial] = ACTIONS(3097),
    [anon_sym_private] = ACTIONS(3097),
    [anon_sym_protected] = ACTIONS(3097),
    [anon_sym_public] = ACTIONS(3097),
    [anon_sym_readonly] = ACTIONS(3097),
    [anon_sym_required] = ACTIONS(3097),
    [anon_sym_sealed] = ACTIONS(3097),
    [anon_sym_virtual] = ACTIONS(3097),
    [anon_sym_volatile] = ACTIONS(3097),
    [anon_sym_where] = ACTIONS(3097),
    [anon_sym_notnull] = ACTIONS(3097),
    [anon_sym_unmanaged] = ACTIONS(3097),
    [anon_sym_checked] = ACTIONS(3097),
    [anon_sym_BANG] = ACTIONS(3099),
    [anon_sym_TILDE] = ACTIONS(3099),
    [anon_sym_PLUS_PLUS] = ACTIONS(3099),
    [anon_sym_DASH_DASH] = ACTIONS(3099),
    [anon_sym_true] = ACTIONS(3097),
    [anon_sym_false] = ACTIONS(3097),
    [anon_sym_PLUS] = ACTIONS(3097),
    [anon_sym_DASH] = ACTIONS(3097),
    [anon_sym_STAR] = ACTIONS(3099),
    [anon_sym_CARET] = ACTIONS(3099),
    [anon_sym_AMP] = ACTIONS(3099),
    [anon_sym_this] = ACTIONS(3097),
    [anon_sym_scoped] = ACTIONS(3097),
    [anon_sym_base] = ACTIONS(3097),
    [anon_sym_var] = ACTIONS(3097),
    [sym_predefined_type] = ACTIONS(3097),
    [anon_sym_break] = ACTIONS(3097),
    [anon_sym_unchecked] = ACTIONS(3097),
    [anon_sym_continue] = ACTIONS(3097),
    [anon_sym_do] = ACTIONS(3097),
    [anon_sym_while] = ACTIONS(3097),
    [anon_sym_for] = ACTIONS(3097),
    [anon_sym_lock] = ACTIONS(3097),
    [anon_sym_yield] = ACTIONS(3097),
    [anon_sym_switch] = ACTIONS(3097),
    [anon_sym_default] = ACTIONS(3097),
    [anon_sym_throw] = ACTIONS(3097),
    [anon_sym_try] = ACTIONS(3097),
    [anon_sym_when] = ACTIONS(3097),
    [anon_sym_await] = ACTIONS(3097),
    [anon_sym_foreach] = ACTIONS(3097),
    [anon_sym_goto] = ACTIONS(3097),
    [anon_sym_if] = ACTIONS(3097),
    [anon_sym_else] = ACTIONS(3097),
    [anon_sym_DOT_DOT] = ACTIONS(3099),
    [anon_sym_from] = ACTIONS(3097),
    [anon_sym_into] = ACTIONS(3097),
    [anon_sym_join] = ACTIONS(3097),
    [anon_sym_on] = ACTIONS(3097),
    [anon_sym_equals] = ACTIONS(3097),
    [anon_sym_let] = ACTIONS(3097),
    [anon_sym_orderby] = ACTIONS(3097),
    [anon_sym_ascending] = ACTIONS(3097),
    [anon_sym_descending] = ACTIONS(3097),
    [anon_sym_group] = ACTIONS(3097),
    [anon_sym_by] = ACTIONS(3097),
    [anon_sym_select] = ACTIONS(3097),
    [anon_sym_stackalloc] = ACTIONS(3097),
    [anon_sym_sizeof] = ACTIONS(3097),
    [anon_sym_typeof] = ACTIONS(3097),
    [anon_sym___makeref] = ACTIONS(3097),
    [anon_sym___reftype] = ACTIONS(3097),
    [anon_sym___refvalue] = ACTIONS(3097),
    [sym_null_literal] = ACTIONS(3097),
    [anon_sym_SQUOTE] = ACTIONS(3099),
    [sym_integer_literal] = ACTIONS(3097),
    [sym_real_literal] = ACTIONS(3099),
    [anon_sym_DQUOTE] = ACTIONS(3099),
    [sym_verbatim_string_literal] = ACTIONS(3099),
    [aux_sym_preproc_if_token1] = ACTIONS(3099),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3099),
    [sym_interpolation_verbatim_start] = ACTIONS(3099),
    [sym_interpolation_raw_start] = ACTIONS(3099),
    [sym_raw_string_start] = ACTIONS(3099),
  },
  [2462] = {
    [sym_preproc_region] = STATE(2462),
    [sym_preproc_endregion] = STATE(2462),
    [sym_preproc_line] = STATE(2462),
    [sym_preproc_pragma] = STATE(2462),
    [sym_preproc_nullable] = STATE(2462),
    [sym_preproc_error] = STATE(2462),
    [sym_preproc_warning] = STATE(2462),
    [sym_preproc_define] = STATE(2462),
    [sym_preproc_undef] = STATE(2462),
    [ts_builtin_sym_end] = ACTIONS(3059),
    [sym__identifier_token] = ACTIONS(3057),
    [anon_sym_extern] = ACTIONS(3057),
    [anon_sym_alias] = ACTIONS(3057),
    [anon_sym_SEMI] = ACTIONS(3059),
    [anon_sym_global] = ACTIONS(3057),
    [anon_sym_using] = ACTIONS(3057),
    [anon_sym_unsafe] = ACTIONS(3057),
    [anon_sym_static] = ACTIONS(3057),
    [anon_sym_LBRACK] = ACTIONS(3059),
    [anon_sym_LPAREN] = ACTIONS(3059),
    [anon_sym_return] = ACTIONS(3057),
    [anon_sym_namespace] = ACTIONS(3057),
    [anon_sym_class] = ACTIONS(3057),
    [anon_sym_ref] = ACTIONS(3057),
    [anon_sym_struct] = ACTIONS(3057),
    [anon_sym_enum] = ACTIONS(3057),
    [anon_sym_LBRACE] = ACTIONS(3059),
    [anon_sym_interface] = ACTIONS(3057),
    [anon_sym_delegate] = ACTIONS(3057),
    [anon_sym_record] = ACTIONS(3057),
    [anon_sym_abstract] = ACTIONS(3057),
    [anon_sym_async] = ACTIONS(3057),
    [anon_sym_const] = ACTIONS(3057),
    [anon_sym_file] = ACTIONS(3057),
    [anon_sym_fixed] = ACTIONS(3057),
    [anon_sym_internal] = ACTIONS(3057),
    [anon_sym_new] = ACTIONS(3057),
    [anon_sym_override] = ACTIONS(3057),
    [anon_sym_partial] = ACTIONS(3057),
    [anon_sym_private] = ACTIONS(3057),
    [anon_sym_protected] = ACTIONS(3057),
    [anon_sym_public] = ACTIONS(3057),
    [anon_sym_readonly] = ACTIONS(3057),
    [anon_sym_required] = ACTIONS(3057),
    [anon_sym_sealed] = ACTIONS(3057),
    [anon_sym_virtual] = ACTIONS(3057),
    [anon_sym_volatile] = ACTIONS(3057),
    [anon_sym_where] = ACTIONS(3057),
    [anon_sym_notnull] = ACTIONS(3057),
    [anon_sym_unmanaged] = ACTIONS(3057),
    [anon_sym_checked] = ACTIONS(3057),
    [anon_sym_BANG] = ACTIONS(3059),
    [anon_sym_TILDE] = ACTIONS(3059),
    [anon_sym_PLUS_PLUS] = ACTIONS(3059),
    [anon_sym_DASH_DASH] = ACTIONS(3059),
    [anon_sym_true] = ACTIONS(3057),
    [anon_sym_false] = ACTIONS(3057),
    [anon_sym_PLUS] = ACTIONS(3057),
    [anon_sym_DASH] = ACTIONS(3057),
    [anon_sym_STAR] = ACTIONS(3059),
    [anon_sym_CARET] = ACTIONS(3059),
    [anon_sym_AMP] = ACTIONS(3059),
    [anon_sym_this] = ACTIONS(3057),
    [anon_sym_scoped] = ACTIONS(3057),
    [anon_sym_base] = ACTIONS(3057),
    [anon_sym_var] = ACTIONS(3057),
    [sym_predefined_type] = ACTIONS(3057),
    [anon_sym_break] = ACTIONS(3057),
    [anon_sym_unchecked] = ACTIONS(3057),
    [anon_sym_continue] = ACTIONS(3057),
    [anon_sym_do] = ACTIONS(3057),
    [anon_sym_while] = ACTIONS(3057),
    [anon_sym_for] = ACTIONS(3057),
    [anon_sym_lock] = ACTIONS(3057),
    [anon_sym_yield] = ACTIONS(3057),
    [anon_sym_switch] = ACTIONS(3057),
    [anon_sym_default] = ACTIONS(3057),
    [anon_sym_throw] = ACTIONS(3057),
    [anon_sym_try] = ACTIONS(3057),
    [anon_sym_when] = ACTIONS(3057),
    [anon_sym_await] = ACTIONS(3057),
    [anon_sym_foreach] = ACTIONS(3057),
    [anon_sym_goto] = ACTIONS(3057),
    [anon_sym_if] = ACTIONS(3057),
    [anon_sym_else] = ACTIONS(3057),
    [anon_sym_DOT_DOT] = ACTIONS(3059),
    [anon_sym_from] = ACTIONS(3057),
    [anon_sym_into] = ACTIONS(3057),
    [anon_sym_join] = ACTIONS(3057),
    [anon_sym_on] = ACTIONS(3057),
    [anon_sym_equals] = ACTIONS(3057),
    [anon_sym_let] = ACTIONS(3057),
    [anon_sym_orderby] = ACTIONS(3057),
    [anon_sym_ascending] = ACTIONS(3057),
    [anon_sym_descending] = ACTIONS(3057),
    [anon_sym_group] = ACTIONS(3057),
    [anon_sym_by] = ACTIONS(3057),
    [anon_sym_select] = ACTIONS(3057),
    [anon_sym_stackalloc] = ACTIONS(3057),
    [anon_sym_sizeof] = ACTIONS(3057),
    [anon_sym_typeof] = ACTIONS(3057),
    [anon_sym___makeref] = ACTIONS(3057),
    [anon_sym___reftype] = ACTIONS(3057),
    [anon_sym___refvalue] = ACTIONS(3057),
    [sym_null_literal] = ACTIONS(3057),
    [anon_sym_SQUOTE] = ACTIONS(3059),
    [sym_integer_literal] = ACTIONS(3057),
    [sym_real_literal] = ACTIONS(3059),
    [anon_sym_DQUOTE] = ACTIONS(3059),
    [sym_verbatim_string_literal] = ACTIONS(3059),
    [aux_sym_preproc_if_token1] = ACTIONS(3059),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3059),
    [sym_interpolation_verbatim_start] = ACTIONS(3059),
    [sym_interpolation_raw_start] = ACTIONS(3059),
    [sym_raw_string_start] = ACTIONS(3059),
  },
  [2463] = {
    [sym_preproc_region] = STATE(2463),
    [sym_preproc_endregion] = STATE(2463),
    [sym_preproc_line] = STATE(2463),
    [sym_preproc_pragma] = STATE(2463),
    [sym_preproc_nullable] = STATE(2463),
    [sym_preproc_error] = STATE(2463),
    [sym_preproc_warning] = STATE(2463),
    [sym_preproc_define] = STATE(2463),
    [sym_preproc_undef] = STATE(2463),
    [ts_builtin_sym_end] = ACTIONS(3311),
    [sym__identifier_token] = ACTIONS(3309),
    [anon_sym_extern] = ACTIONS(3309),
    [anon_sym_alias] = ACTIONS(3309),
    [anon_sym_SEMI] = ACTIONS(3311),
    [anon_sym_global] = ACTIONS(3309),
    [anon_sym_using] = ACTIONS(3309),
    [anon_sym_unsafe] = ACTIONS(3309),
    [anon_sym_static] = ACTIONS(3309),
    [anon_sym_LBRACK] = ACTIONS(3311),
    [anon_sym_LPAREN] = ACTIONS(3311),
    [anon_sym_return] = ACTIONS(3309),
    [anon_sym_namespace] = ACTIONS(3309),
    [anon_sym_class] = ACTIONS(3309),
    [anon_sym_ref] = ACTIONS(3309),
    [anon_sym_struct] = ACTIONS(3309),
    [anon_sym_enum] = ACTIONS(3309),
    [anon_sym_LBRACE] = ACTIONS(3311),
    [anon_sym_interface] = ACTIONS(3309),
    [anon_sym_delegate] = ACTIONS(3309),
    [anon_sym_record] = ACTIONS(3309),
    [anon_sym_abstract] = ACTIONS(3309),
    [anon_sym_async] = ACTIONS(3309),
    [anon_sym_const] = ACTIONS(3309),
    [anon_sym_file] = ACTIONS(3309),
    [anon_sym_fixed] = ACTIONS(3309),
    [anon_sym_internal] = ACTIONS(3309),
    [anon_sym_new] = ACTIONS(3309),
    [anon_sym_override] = ACTIONS(3309),
    [anon_sym_partial] = ACTIONS(3309),
    [anon_sym_private] = ACTIONS(3309),
    [anon_sym_protected] = ACTIONS(3309),
    [anon_sym_public] = ACTIONS(3309),
    [anon_sym_readonly] = ACTIONS(3309),
    [anon_sym_required] = ACTIONS(3309),
    [anon_sym_sealed] = ACTIONS(3309),
    [anon_sym_virtual] = ACTIONS(3309),
    [anon_sym_volatile] = ACTIONS(3309),
    [anon_sym_where] = ACTIONS(3309),
    [anon_sym_notnull] = ACTIONS(3309),
    [anon_sym_unmanaged] = ACTIONS(3309),
    [anon_sym_checked] = ACTIONS(3309),
    [anon_sym_BANG] = ACTIONS(3311),
    [anon_sym_TILDE] = ACTIONS(3311),
    [anon_sym_PLUS_PLUS] = ACTIONS(3311),
    [anon_sym_DASH_DASH] = ACTIONS(3311),
    [anon_sym_true] = ACTIONS(3309),
    [anon_sym_false] = ACTIONS(3309),
    [anon_sym_PLUS] = ACTIONS(3309),
    [anon_sym_DASH] = ACTIONS(3309),
    [anon_sym_STAR] = ACTIONS(3311),
    [anon_sym_CARET] = ACTIONS(3311),
    [anon_sym_AMP] = ACTIONS(3311),
    [anon_sym_this] = ACTIONS(3309),
    [anon_sym_scoped] = ACTIONS(3309),
    [anon_sym_base] = ACTIONS(3309),
    [anon_sym_var] = ACTIONS(3309),
    [sym_predefined_type] = ACTIONS(3309),
    [anon_sym_break] = ACTIONS(3309),
    [anon_sym_unchecked] = ACTIONS(3309),
    [anon_sym_continue] = ACTIONS(3309),
    [anon_sym_do] = ACTIONS(3309),
    [anon_sym_while] = ACTIONS(3309),
    [anon_sym_for] = ACTIONS(3309),
    [anon_sym_lock] = ACTIONS(3309),
    [anon_sym_yield] = ACTIONS(3309),
    [anon_sym_switch] = ACTIONS(3309),
    [anon_sym_default] = ACTIONS(3309),
    [anon_sym_throw] = ACTIONS(3309),
    [anon_sym_try] = ACTIONS(3309),
    [anon_sym_when] = ACTIONS(3309),
    [anon_sym_await] = ACTIONS(3309),
    [anon_sym_foreach] = ACTIONS(3309),
    [anon_sym_goto] = ACTIONS(3309),
    [anon_sym_if] = ACTIONS(3309),
    [anon_sym_else] = ACTIONS(3309),
    [anon_sym_DOT_DOT] = ACTIONS(3311),
    [anon_sym_from] = ACTIONS(3309),
    [anon_sym_into] = ACTIONS(3309),
    [anon_sym_join] = ACTIONS(3309),
    [anon_sym_on] = ACTIONS(3309),
    [anon_sym_equals] = ACTIONS(3309),
    [anon_sym_let] = ACTIONS(3309),
    [anon_sym_orderby] = ACTIONS(3309),
    [anon_sym_ascending] = ACTIONS(3309),
    [anon_sym_descending] = ACTIONS(3309),
    [anon_sym_group] = ACTIONS(3309),
    [anon_sym_by] = ACTIONS(3309),
    [anon_sym_select] = ACTIONS(3309),
    [anon_sym_stackalloc] = ACTIONS(3309),
    [anon_sym_sizeof] = ACTIONS(3309),
    [anon_sym_typeof] = ACTIONS(3309),
    [anon_sym___makeref] = ACTIONS(3309),
    [anon_sym___reftype] = ACTIONS(3309),
    [anon_sym___refvalue] = ACTIONS(3309),
    [sym_null_literal] = ACTIONS(3309),
    [anon_sym_SQUOTE] = ACTIONS(3311),
    [sym_integer_literal] = ACTIONS(3309),
    [sym_real_literal] = ACTIONS(3311),
    [anon_sym_DQUOTE] = ACTIONS(3311),
    [sym_verbatim_string_literal] = ACTIONS(3311),
    [aux_sym_preproc_if_token1] = ACTIONS(3311),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3311),
    [sym_interpolation_verbatim_start] = ACTIONS(3311),
    [sym_interpolation_raw_start] = ACTIONS(3311),
    [sym_raw_string_start] = ACTIONS(3311),
  },
  [2464] = {
    [sym_preproc_region] = STATE(2464),
    [sym_preproc_endregion] = STATE(2464),
    [sym_preproc_line] = STATE(2464),
    [sym_preproc_pragma] = STATE(2464),
    [sym_preproc_nullable] = STATE(2464),
    [sym_preproc_error] = STATE(2464),
    [sym_preproc_warning] = STATE(2464),
    [sym_preproc_define] = STATE(2464),
    [sym_preproc_undef] = STATE(2464),
    [ts_builtin_sym_end] = ACTIONS(3275),
    [sym__identifier_token] = ACTIONS(3273),
    [anon_sym_extern] = ACTIONS(3273),
    [anon_sym_alias] = ACTIONS(3273),
    [anon_sym_SEMI] = ACTIONS(3275),
    [anon_sym_global] = ACTIONS(3273),
    [anon_sym_using] = ACTIONS(3273),
    [anon_sym_unsafe] = ACTIONS(3273),
    [anon_sym_static] = ACTIONS(3273),
    [anon_sym_LBRACK] = ACTIONS(3275),
    [anon_sym_LPAREN] = ACTIONS(3275),
    [anon_sym_return] = ACTIONS(3273),
    [anon_sym_namespace] = ACTIONS(3273),
    [anon_sym_class] = ACTIONS(3273),
    [anon_sym_ref] = ACTIONS(3273),
    [anon_sym_struct] = ACTIONS(3273),
    [anon_sym_enum] = ACTIONS(3273),
    [anon_sym_LBRACE] = ACTIONS(3275),
    [anon_sym_interface] = ACTIONS(3273),
    [anon_sym_delegate] = ACTIONS(3273),
    [anon_sym_record] = ACTIONS(3273),
    [anon_sym_abstract] = ACTIONS(3273),
    [anon_sym_async] = ACTIONS(3273),
    [anon_sym_const] = ACTIONS(3273),
    [anon_sym_file] = ACTIONS(3273),
    [anon_sym_fixed] = ACTIONS(3273),
    [anon_sym_internal] = ACTIONS(3273),
    [anon_sym_new] = ACTIONS(3273),
    [anon_sym_override] = ACTIONS(3273),
    [anon_sym_partial] = ACTIONS(3273),
    [anon_sym_private] = ACTIONS(3273),
    [anon_sym_protected] = ACTIONS(3273),
    [anon_sym_public] = ACTIONS(3273),
    [anon_sym_readonly] = ACTIONS(3273),
    [anon_sym_required] = ACTIONS(3273),
    [anon_sym_sealed] = ACTIONS(3273),
    [anon_sym_virtual] = ACTIONS(3273),
    [anon_sym_volatile] = ACTIONS(3273),
    [anon_sym_where] = ACTIONS(3273),
    [anon_sym_notnull] = ACTIONS(3273),
    [anon_sym_unmanaged] = ACTIONS(3273),
    [anon_sym_checked] = ACTIONS(3273),
    [anon_sym_BANG] = ACTIONS(3275),
    [anon_sym_TILDE] = ACTIONS(3275),
    [anon_sym_PLUS_PLUS] = ACTIONS(3275),
    [anon_sym_DASH_DASH] = ACTIONS(3275),
    [anon_sym_true] = ACTIONS(3273),
    [anon_sym_false] = ACTIONS(3273),
    [anon_sym_PLUS] = ACTIONS(3273),
    [anon_sym_DASH] = ACTIONS(3273),
    [anon_sym_STAR] = ACTIONS(3275),
    [anon_sym_CARET] = ACTIONS(3275),
    [anon_sym_AMP] = ACTIONS(3275),
    [anon_sym_this] = ACTIONS(3273),
    [anon_sym_scoped] = ACTIONS(3273),
    [anon_sym_base] = ACTIONS(3273),
    [anon_sym_var] = ACTIONS(3273),
    [sym_predefined_type] = ACTIONS(3273),
    [anon_sym_break] = ACTIONS(3273),
    [anon_sym_unchecked] = ACTIONS(3273),
    [anon_sym_continue] = ACTIONS(3273),
    [anon_sym_do] = ACTIONS(3273),
    [anon_sym_while] = ACTIONS(3273),
    [anon_sym_for] = ACTIONS(3273),
    [anon_sym_lock] = ACTIONS(3273),
    [anon_sym_yield] = ACTIONS(3273),
    [anon_sym_switch] = ACTIONS(3273),
    [anon_sym_default] = ACTIONS(3273),
    [anon_sym_throw] = ACTIONS(3273),
    [anon_sym_try] = ACTIONS(3273),
    [anon_sym_when] = ACTIONS(3273),
    [anon_sym_await] = ACTIONS(3273),
    [anon_sym_foreach] = ACTIONS(3273),
    [anon_sym_goto] = ACTIONS(3273),
    [anon_sym_if] = ACTIONS(3273),
    [anon_sym_else] = ACTIONS(3273),
    [anon_sym_DOT_DOT] = ACTIONS(3275),
    [anon_sym_from] = ACTIONS(3273),
    [anon_sym_into] = ACTIONS(3273),
    [anon_sym_join] = ACTIONS(3273),
    [anon_sym_on] = ACTIONS(3273),
    [anon_sym_equals] = ACTIONS(3273),
    [anon_sym_let] = ACTIONS(3273),
    [anon_sym_orderby] = ACTIONS(3273),
    [anon_sym_ascending] = ACTIONS(3273),
    [anon_sym_descending] = ACTIONS(3273),
    [anon_sym_group] = ACTIONS(3273),
    [anon_sym_by] = ACTIONS(3273),
    [anon_sym_select] = ACTIONS(3273),
    [anon_sym_stackalloc] = ACTIONS(3273),
    [anon_sym_sizeof] = ACTIONS(3273),
    [anon_sym_typeof] = ACTIONS(3273),
    [anon_sym___makeref] = ACTIONS(3273),
    [anon_sym___reftype] = ACTIONS(3273),
    [anon_sym___refvalue] = ACTIONS(3273),
    [sym_null_literal] = ACTIONS(3273),
    [anon_sym_SQUOTE] = ACTIONS(3275),
    [sym_integer_literal] = ACTIONS(3273),
    [sym_real_literal] = ACTIONS(3275),
    [anon_sym_DQUOTE] = ACTIONS(3275),
    [sym_verbatim_string_literal] = ACTIONS(3275),
    [aux_sym_preproc_if_token1] = ACTIONS(3275),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3275),
    [sym_interpolation_verbatim_start] = ACTIONS(3275),
    [sym_interpolation_raw_start] = ACTIONS(3275),
    [sym_raw_string_start] = ACTIONS(3275),
  },
  [2465] = {
    [sym_preproc_region] = STATE(2465),
    [sym_preproc_endregion] = STATE(2465),
    [sym_preproc_line] = STATE(2465),
    [sym_preproc_pragma] = STATE(2465),
    [sym_preproc_nullable] = STATE(2465),
    [sym_preproc_error] = STATE(2465),
    [sym_preproc_warning] = STATE(2465),
    [sym_preproc_define] = STATE(2465),
    [sym_preproc_undef] = STATE(2465),
    [ts_builtin_sym_end] = ACTIONS(3103),
    [sym__identifier_token] = ACTIONS(3101),
    [anon_sym_extern] = ACTIONS(3101),
    [anon_sym_alias] = ACTIONS(3101),
    [anon_sym_SEMI] = ACTIONS(3103),
    [anon_sym_global] = ACTIONS(3101),
    [anon_sym_using] = ACTIONS(3101),
    [anon_sym_unsafe] = ACTIONS(3101),
    [anon_sym_static] = ACTIONS(3101),
    [anon_sym_LBRACK] = ACTIONS(3103),
    [anon_sym_LPAREN] = ACTIONS(3103),
    [anon_sym_return] = ACTIONS(3101),
    [anon_sym_namespace] = ACTIONS(3101),
    [anon_sym_class] = ACTIONS(3101),
    [anon_sym_ref] = ACTIONS(3101),
    [anon_sym_struct] = ACTIONS(3101),
    [anon_sym_enum] = ACTIONS(3101),
    [anon_sym_LBRACE] = ACTIONS(3103),
    [anon_sym_interface] = ACTIONS(3101),
    [anon_sym_delegate] = ACTIONS(3101),
    [anon_sym_record] = ACTIONS(3101),
    [anon_sym_abstract] = ACTIONS(3101),
    [anon_sym_async] = ACTIONS(3101),
    [anon_sym_const] = ACTIONS(3101),
    [anon_sym_file] = ACTIONS(3101),
    [anon_sym_fixed] = ACTIONS(3101),
    [anon_sym_internal] = ACTIONS(3101),
    [anon_sym_new] = ACTIONS(3101),
    [anon_sym_override] = ACTIONS(3101),
    [anon_sym_partial] = ACTIONS(3101),
    [anon_sym_private] = ACTIONS(3101),
    [anon_sym_protected] = ACTIONS(3101),
    [anon_sym_public] = ACTIONS(3101),
    [anon_sym_readonly] = ACTIONS(3101),
    [anon_sym_required] = ACTIONS(3101),
    [anon_sym_sealed] = ACTIONS(3101),
    [anon_sym_virtual] = ACTIONS(3101),
    [anon_sym_volatile] = ACTIONS(3101),
    [anon_sym_where] = ACTIONS(3101),
    [anon_sym_notnull] = ACTIONS(3101),
    [anon_sym_unmanaged] = ACTIONS(3101),
    [anon_sym_checked] = ACTIONS(3101),
    [anon_sym_BANG] = ACTIONS(3103),
    [anon_sym_TILDE] = ACTIONS(3103),
    [anon_sym_PLUS_PLUS] = ACTIONS(3103),
    [anon_sym_DASH_DASH] = ACTIONS(3103),
    [anon_sym_true] = ACTIONS(3101),
    [anon_sym_false] = ACTIONS(3101),
    [anon_sym_PLUS] = ACTIONS(3101),
    [anon_sym_DASH] = ACTIONS(3101),
    [anon_sym_STAR] = ACTIONS(3103),
    [anon_sym_CARET] = ACTIONS(3103),
    [anon_sym_AMP] = ACTIONS(3103),
    [anon_sym_this] = ACTIONS(3101),
    [anon_sym_scoped] = ACTIONS(3101),
    [anon_sym_base] = ACTIONS(3101),
    [anon_sym_var] = ACTIONS(3101),
    [sym_predefined_type] = ACTIONS(3101),
    [anon_sym_break] = ACTIONS(3101),
    [anon_sym_unchecked] = ACTIONS(3101),
    [anon_sym_continue] = ACTIONS(3101),
    [anon_sym_do] = ACTIONS(3101),
    [anon_sym_while] = ACTIONS(3101),
    [anon_sym_for] = ACTIONS(3101),
    [anon_sym_lock] = ACTIONS(3101),
    [anon_sym_yield] = ACTIONS(3101),
    [anon_sym_switch] = ACTIONS(3101),
    [anon_sym_default] = ACTIONS(3101),
    [anon_sym_throw] = ACTIONS(3101),
    [anon_sym_try] = ACTIONS(3101),
    [anon_sym_when] = ACTIONS(3101),
    [anon_sym_await] = ACTIONS(3101),
    [anon_sym_foreach] = ACTIONS(3101),
    [anon_sym_goto] = ACTIONS(3101),
    [anon_sym_if] = ACTIONS(3101),
    [anon_sym_else] = ACTIONS(3101),
    [anon_sym_DOT_DOT] = ACTIONS(3103),
    [anon_sym_from] = ACTIONS(3101),
    [anon_sym_into] = ACTIONS(3101),
    [anon_sym_join] = ACTIONS(3101),
    [anon_sym_on] = ACTIONS(3101),
    [anon_sym_equals] = ACTIONS(3101),
    [anon_sym_let] = ACTIONS(3101),
    [anon_sym_orderby] = ACTIONS(3101),
    [anon_sym_ascending] = ACTIONS(3101),
    [anon_sym_descending] = ACTIONS(3101),
    [anon_sym_group] = ACTIONS(3101),
    [anon_sym_by] = ACTIONS(3101),
    [anon_sym_select] = ACTIONS(3101),
    [anon_sym_stackalloc] = ACTIONS(3101),
    [anon_sym_sizeof] = ACTIONS(3101),
    [anon_sym_typeof] = ACTIONS(3101),
    [anon_sym___makeref] = ACTIONS(3101),
    [anon_sym___reftype] = ACTIONS(3101),
    [anon_sym___refvalue] = ACTIONS(3101),
    [sym_null_literal] = ACTIONS(3101),
    [anon_sym_SQUOTE] = ACTIONS(3103),
    [sym_integer_literal] = ACTIONS(3101),
    [sym_real_literal] = ACTIONS(3103),
    [anon_sym_DQUOTE] = ACTIONS(3103),
    [sym_verbatim_string_literal] = ACTIONS(3103),
    [aux_sym_preproc_if_token1] = ACTIONS(3103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3103),
    [sym_interpolation_verbatim_start] = ACTIONS(3103),
    [sym_interpolation_raw_start] = ACTIONS(3103),
    [sym_raw_string_start] = ACTIONS(3103),
  },
  [2466] = {
    [sym_preproc_region] = STATE(2466),
    [sym_preproc_endregion] = STATE(2466),
    [sym_preproc_line] = STATE(2466),
    [sym_preproc_pragma] = STATE(2466),
    [sym_preproc_nullable] = STATE(2466),
    [sym_preproc_error] = STATE(2466),
    [sym_preproc_warning] = STATE(2466),
    [sym_preproc_define] = STATE(2466),
    [sym_preproc_undef] = STATE(2466),
    [ts_builtin_sym_end] = ACTIONS(3107),
    [sym__identifier_token] = ACTIONS(3105),
    [anon_sym_extern] = ACTIONS(3105),
    [anon_sym_alias] = ACTIONS(3105),
    [anon_sym_SEMI] = ACTIONS(3107),
    [anon_sym_global] = ACTIONS(3105),
    [anon_sym_using] = ACTIONS(3105),
    [anon_sym_unsafe] = ACTIONS(3105),
    [anon_sym_static] = ACTIONS(3105),
    [anon_sym_LBRACK] = ACTIONS(3107),
    [anon_sym_LPAREN] = ACTIONS(3107),
    [anon_sym_return] = ACTIONS(3105),
    [anon_sym_namespace] = ACTIONS(3105),
    [anon_sym_class] = ACTIONS(3105),
    [anon_sym_ref] = ACTIONS(3105),
    [anon_sym_struct] = ACTIONS(3105),
    [anon_sym_enum] = ACTIONS(3105),
    [anon_sym_LBRACE] = ACTIONS(3107),
    [anon_sym_interface] = ACTIONS(3105),
    [anon_sym_delegate] = ACTIONS(3105),
    [anon_sym_record] = ACTIONS(3105),
    [anon_sym_abstract] = ACTIONS(3105),
    [anon_sym_async] = ACTIONS(3105),
    [anon_sym_const] = ACTIONS(3105),
    [anon_sym_file] = ACTIONS(3105),
    [anon_sym_fixed] = ACTIONS(3105),
    [anon_sym_internal] = ACTIONS(3105),
    [anon_sym_new] = ACTIONS(3105),
    [anon_sym_override] = ACTIONS(3105),
    [anon_sym_partial] = ACTIONS(3105),
    [anon_sym_private] = ACTIONS(3105),
    [anon_sym_protected] = ACTIONS(3105),
    [anon_sym_public] = ACTIONS(3105),
    [anon_sym_readonly] = ACTIONS(3105),
    [anon_sym_required] = ACTIONS(3105),
    [anon_sym_sealed] = ACTIONS(3105),
    [anon_sym_virtual] = ACTIONS(3105),
    [anon_sym_volatile] = ACTIONS(3105),
    [anon_sym_where] = ACTIONS(3105),
    [anon_sym_notnull] = ACTIONS(3105),
    [anon_sym_unmanaged] = ACTIONS(3105),
    [anon_sym_checked] = ACTIONS(3105),
    [anon_sym_BANG] = ACTIONS(3107),
    [anon_sym_TILDE] = ACTIONS(3107),
    [anon_sym_PLUS_PLUS] = ACTIONS(3107),
    [anon_sym_DASH_DASH] = ACTIONS(3107),
    [anon_sym_true] = ACTIONS(3105),
    [anon_sym_false] = ACTIONS(3105),
    [anon_sym_PLUS] = ACTIONS(3105),
    [anon_sym_DASH] = ACTIONS(3105),
    [anon_sym_STAR] = ACTIONS(3107),
    [anon_sym_CARET] = ACTIONS(3107),
    [anon_sym_AMP] = ACTIONS(3107),
    [anon_sym_this] = ACTIONS(3105),
    [anon_sym_scoped] = ACTIONS(3105),
    [anon_sym_base] = ACTIONS(3105),
    [anon_sym_var] = ACTIONS(3105),
    [sym_predefined_type] = ACTIONS(3105),
    [anon_sym_break] = ACTIONS(3105),
    [anon_sym_unchecked] = ACTIONS(3105),
    [anon_sym_continue] = ACTIONS(3105),
    [anon_sym_do] = ACTIONS(3105),
    [anon_sym_while] = ACTIONS(3105),
    [anon_sym_for] = ACTIONS(3105),
    [anon_sym_lock] = ACTIONS(3105),
    [anon_sym_yield] = ACTIONS(3105),
    [anon_sym_switch] = ACTIONS(3105),
    [anon_sym_default] = ACTIONS(3105),
    [anon_sym_throw] = ACTIONS(3105),
    [anon_sym_try] = ACTIONS(3105),
    [anon_sym_when] = ACTIONS(3105),
    [anon_sym_await] = ACTIONS(3105),
    [anon_sym_foreach] = ACTIONS(3105),
    [anon_sym_goto] = ACTIONS(3105),
    [anon_sym_if] = ACTIONS(3105),
    [anon_sym_else] = ACTIONS(3105),
    [anon_sym_DOT_DOT] = ACTIONS(3107),
    [anon_sym_from] = ACTIONS(3105),
    [anon_sym_into] = ACTIONS(3105),
    [anon_sym_join] = ACTIONS(3105),
    [anon_sym_on] = ACTIONS(3105),
    [anon_sym_equals] = ACTIONS(3105),
    [anon_sym_let] = ACTIONS(3105),
    [anon_sym_orderby] = ACTIONS(3105),
    [anon_sym_ascending] = ACTIONS(3105),
    [anon_sym_descending] = ACTIONS(3105),
    [anon_sym_group] = ACTIONS(3105),
    [anon_sym_by] = ACTIONS(3105),
    [anon_sym_select] = ACTIONS(3105),
    [anon_sym_stackalloc] = ACTIONS(3105),
    [anon_sym_sizeof] = ACTIONS(3105),
    [anon_sym_typeof] = ACTIONS(3105),
    [anon_sym___makeref] = ACTIONS(3105),
    [anon_sym___reftype] = ACTIONS(3105),
    [anon_sym___refvalue] = ACTIONS(3105),
    [sym_null_literal] = ACTIONS(3105),
    [anon_sym_SQUOTE] = ACTIONS(3107),
    [sym_integer_literal] = ACTIONS(3105),
    [sym_real_literal] = ACTIONS(3107),
    [anon_sym_DQUOTE] = ACTIONS(3107),
    [sym_verbatim_string_literal] = ACTIONS(3107),
    [aux_sym_preproc_if_token1] = ACTIONS(3107),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3107),
    [sym_interpolation_verbatim_start] = ACTIONS(3107),
    [sym_interpolation_raw_start] = ACTIONS(3107),
    [sym_raw_string_start] = ACTIONS(3107),
  },
  [2467] = {
    [sym_preproc_region] = STATE(2467),
    [sym_preproc_endregion] = STATE(2467),
    [sym_preproc_line] = STATE(2467),
    [sym_preproc_pragma] = STATE(2467),
    [sym_preproc_nullable] = STATE(2467),
    [sym_preproc_error] = STATE(2467),
    [sym_preproc_warning] = STATE(2467),
    [sym_preproc_define] = STATE(2467),
    [sym_preproc_undef] = STATE(2467),
    [ts_builtin_sym_end] = ACTIONS(3367),
    [sym__identifier_token] = ACTIONS(3365),
    [anon_sym_extern] = ACTIONS(3365),
    [anon_sym_alias] = ACTIONS(3365),
    [anon_sym_SEMI] = ACTIONS(3367),
    [anon_sym_global] = ACTIONS(3365),
    [anon_sym_using] = ACTIONS(3365),
    [anon_sym_unsafe] = ACTIONS(3365),
    [anon_sym_static] = ACTIONS(3365),
    [anon_sym_LBRACK] = ACTIONS(3367),
    [anon_sym_LPAREN] = ACTIONS(3367),
    [anon_sym_return] = ACTIONS(3365),
    [anon_sym_namespace] = ACTIONS(3365),
    [anon_sym_class] = ACTIONS(3365),
    [anon_sym_ref] = ACTIONS(3365),
    [anon_sym_struct] = ACTIONS(3365),
    [anon_sym_enum] = ACTIONS(3365),
    [anon_sym_LBRACE] = ACTIONS(3367),
    [anon_sym_interface] = ACTIONS(3365),
    [anon_sym_delegate] = ACTIONS(3365),
    [anon_sym_record] = ACTIONS(3365),
    [anon_sym_abstract] = ACTIONS(3365),
    [anon_sym_async] = ACTIONS(3365),
    [anon_sym_const] = ACTIONS(3365),
    [anon_sym_file] = ACTIONS(3365),
    [anon_sym_fixed] = ACTIONS(3365),
    [anon_sym_internal] = ACTIONS(3365),
    [anon_sym_new] = ACTIONS(3365),
    [anon_sym_override] = ACTIONS(3365),
    [anon_sym_partial] = ACTIONS(3365),
    [anon_sym_private] = ACTIONS(3365),
    [anon_sym_protected] = ACTIONS(3365),
    [anon_sym_public] = ACTIONS(3365),
    [anon_sym_readonly] = ACTIONS(3365),
    [anon_sym_required] = ACTIONS(3365),
    [anon_sym_sealed] = ACTIONS(3365),
    [anon_sym_virtual] = ACTIONS(3365),
    [anon_sym_volatile] = ACTIONS(3365),
    [anon_sym_where] = ACTIONS(3365),
    [anon_sym_notnull] = ACTIONS(3365),
    [anon_sym_unmanaged] = ACTIONS(3365),
    [anon_sym_checked] = ACTIONS(3365),
    [anon_sym_BANG] = ACTIONS(3367),
    [anon_sym_TILDE] = ACTIONS(3367),
    [anon_sym_PLUS_PLUS] = ACTIONS(3367),
    [anon_sym_DASH_DASH] = ACTIONS(3367),
    [anon_sym_true] = ACTIONS(3365),
    [anon_sym_false] = ACTIONS(3365),
    [anon_sym_PLUS] = ACTIONS(3365),
    [anon_sym_DASH] = ACTIONS(3365),
    [anon_sym_STAR] = ACTIONS(3367),
    [anon_sym_CARET] = ACTIONS(3367),
    [anon_sym_AMP] = ACTIONS(3367),
    [anon_sym_this] = ACTIONS(3365),
    [anon_sym_scoped] = ACTIONS(3365),
    [anon_sym_base] = ACTIONS(3365),
    [anon_sym_var] = ACTIONS(3365),
    [sym_predefined_type] = ACTIONS(3365),
    [anon_sym_break] = ACTIONS(3365),
    [anon_sym_unchecked] = ACTIONS(3365),
    [anon_sym_continue] = ACTIONS(3365),
    [anon_sym_do] = ACTIONS(3365),
    [anon_sym_while] = ACTIONS(3365),
    [anon_sym_for] = ACTIONS(3365),
    [anon_sym_lock] = ACTIONS(3365),
    [anon_sym_yield] = ACTIONS(3365),
    [anon_sym_switch] = ACTIONS(3365),
    [anon_sym_default] = ACTIONS(3365),
    [anon_sym_throw] = ACTIONS(3365),
    [anon_sym_try] = ACTIONS(3365),
    [anon_sym_when] = ACTIONS(3365),
    [anon_sym_await] = ACTIONS(3365),
    [anon_sym_foreach] = ACTIONS(3365),
    [anon_sym_goto] = ACTIONS(3365),
    [anon_sym_if] = ACTIONS(3365),
    [anon_sym_else] = ACTIONS(3365),
    [anon_sym_DOT_DOT] = ACTIONS(3367),
    [anon_sym_from] = ACTIONS(3365),
    [anon_sym_into] = ACTIONS(3365),
    [anon_sym_join] = ACTIONS(3365),
    [anon_sym_on] = ACTIONS(3365),
    [anon_sym_equals] = ACTIONS(3365),
    [anon_sym_let] = ACTIONS(3365),
    [anon_sym_orderby] = ACTIONS(3365),
    [anon_sym_ascending] = ACTIONS(3365),
    [anon_sym_descending] = ACTIONS(3365),
    [anon_sym_group] = ACTIONS(3365),
    [anon_sym_by] = ACTIONS(3365),
    [anon_sym_select] = ACTIONS(3365),
    [anon_sym_stackalloc] = ACTIONS(3365),
    [anon_sym_sizeof] = ACTIONS(3365),
    [anon_sym_typeof] = ACTIONS(3365),
    [anon_sym___makeref] = ACTIONS(3365),
    [anon_sym___reftype] = ACTIONS(3365),
    [anon_sym___refvalue] = ACTIONS(3365),
    [sym_null_literal] = ACTIONS(3365),
    [anon_sym_SQUOTE] = ACTIONS(3367),
    [sym_integer_literal] = ACTIONS(3365),
    [sym_real_literal] = ACTIONS(3367),
    [anon_sym_DQUOTE] = ACTIONS(3367),
    [sym_verbatim_string_literal] = ACTIONS(3367),
    [aux_sym_preproc_if_token1] = ACTIONS(3367),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3367),
    [sym_interpolation_verbatim_start] = ACTIONS(3367),
    [sym_interpolation_raw_start] = ACTIONS(3367),
    [sym_raw_string_start] = ACTIONS(3367),
  },
  [2468] = {
    [sym_preproc_region] = STATE(2468),
    [sym_preproc_endregion] = STATE(2468),
    [sym_preproc_line] = STATE(2468),
    [sym_preproc_pragma] = STATE(2468),
    [sym_preproc_nullable] = STATE(2468),
    [sym_preproc_error] = STATE(2468),
    [sym_preproc_warning] = STATE(2468),
    [sym_preproc_define] = STATE(2468),
    [sym_preproc_undef] = STATE(2468),
    [ts_builtin_sym_end] = ACTIONS(3271),
    [sym__identifier_token] = ACTIONS(3269),
    [anon_sym_extern] = ACTIONS(3269),
    [anon_sym_alias] = ACTIONS(3269),
    [anon_sym_SEMI] = ACTIONS(3271),
    [anon_sym_global] = ACTIONS(3269),
    [anon_sym_using] = ACTIONS(3269),
    [anon_sym_unsafe] = ACTIONS(3269),
    [anon_sym_static] = ACTIONS(3269),
    [anon_sym_LBRACK] = ACTIONS(3271),
    [anon_sym_LPAREN] = ACTIONS(3271),
    [anon_sym_return] = ACTIONS(3269),
    [anon_sym_namespace] = ACTIONS(3269),
    [anon_sym_class] = ACTIONS(3269),
    [anon_sym_ref] = ACTIONS(3269),
    [anon_sym_struct] = ACTIONS(3269),
    [anon_sym_enum] = ACTIONS(3269),
    [anon_sym_LBRACE] = ACTIONS(3271),
    [anon_sym_interface] = ACTIONS(3269),
    [anon_sym_delegate] = ACTIONS(3269),
    [anon_sym_record] = ACTIONS(3269),
    [anon_sym_abstract] = ACTIONS(3269),
    [anon_sym_async] = ACTIONS(3269),
    [anon_sym_const] = ACTIONS(3269),
    [anon_sym_file] = ACTIONS(3269),
    [anon_sym_fixed] = ACTIONS(3269),
    [anon_sym_internal] = ACTIONS(3269),
    [anon_sym_new] = ACTIONS(3269),
    [anon_sym_override] = ACTIONS(3269),
    [anon_sym_partial] = ACTIONS(3269),
    [anon_sym_private] = ACTIONS(3269),
    [anon_sym_protected] = ACTIONS(3269),
    [anon_sym_public] = ACTIONS(3269),
    [anon_sym_readonly] = ACTIONS(3269),
    [anon_sym_required] = ACTIONS(3269),
    [anon_sym_sealed] = ACTIONS(3269),
    [anon_sym_virtual] = ACTIONS(3269),
    [anon_sym_volatile] = ACTIONS(3269),
    [anon_sym_where] = ACTIONS(3269),
    [anon_sym_notnull] = ACTIONS(3269),
    [anon_sym_unmanaged] = ACTIONS(3269),
    [anon_sym_checked] = ACTIONS(3269),
    [anon_sym_BANG] = ACTIONS(3271),
    [anon_sym_TILDE] = ACTIONS(3271),
    [anon_sym_PLUS_PLUS] = ACTIONS(3271),
    [anon_sym_DASH_DASH] = ACTIONS(3271),
    [anon_sym_true] = ACTIONS(3269),
    [anon_sym_false] = ACTIONS(3269),
    [anon_sym_PLUS] = ACTIONS(3269),
    [anon_sym_DASH] = ACTIONS(3269),
    [anon_sym_STAR] = ACTIONS(3271),
    [anon_sym_CARET] = ACTIONS(3271),
    [anon_sym_AMP] = ACTIONS(3271),
    [anon_sym_this] = ACTIONS(3269),
    [anon_sym_scoped] = ACTIONS(3269),
    [anon_sym_base] = ACTIONS(3269),
    [anon_sym_var] = ACTIONS(3269),
    [sym_predefined_type] = ACTIONS(3269),
    [anon_sym_break] = ACTIONS(3269),
    [anon_sym_unchecked] = ACTIONS(3269),
    [anon_sym_continue] = ACTIONS(3269),
    [anon_sym_do] = ACTIONS(3269),
    [anon_sym_while] = ACTIONS(3269),
    [anon_sym_for] = ACTIONS(3269),
    [anon_sym_lock] = ACTIONS(3269),
    [anon_sym_yield] = ACTIONS(3269),
    [anon_sym_switch] = ACTIONS(3269),
    [anon_sym_default] = ACTIONS(3269),
    [anon_sym_throw] = ACTIONS(3269),
    [anon_sym_try] = ACTIONS(3269),
    [anon_sym_when] = ACTIONS(3269),
    [anon_sym_await] = ACTIONS(3269),
    [anon_sym_foreach] = ACTIONS(3269),
    [anon_sym_goto] = ACTIONS(3269),
    [anon_sym_if] = ACTIONS(3269),
    [anon_sym_else] = ACTIONS(3269),
    [anon_sym_DOT_DOT] = ACTIONS(3271),
    [anon_sym_from] = ACTIONS(3269),
    [anon_sym_into] = ACTIONS(3269),
    [anon_sym_join] = ACTIONS(3269),
    [anon_sym_on] = ACTIONS(3269),
    [anon_sym_equals] = ACTIONS(3269),
    [anon_sym_let] = ACTIONS(3269),
    [anon_sym_orderby] = ACTIONS(3269),
    [anon_sym_ascending] = ACTIONS(3269),
    [anon_sym_descending] = ACTIONS(3269),
    [anon_sym_group] = ACTIONS(3269),
    [anon_sym_by] = ACTIONS(3269),
    [anon_sym_select] = ACTIONS(3269),
    [anon_sym_stackalloc] = ACTIONS(3269),
    [anon_sym_sizeof] = ACTIONS(3269),
    [anon_sym_typeof] = ACTIONS(3269),
    [anon_sym___makeref] = ACTIONS(3269),
    [anon_sym___reftype] = ACTIONS(3269),
    [anon_sym___refvalue] = ACTIONS(3269),
    [sym_null_literal] = ACTIONS(3269),
    [anon_sym_SQUOTE] = ACTIONS(3271),
    [sym_integer_literal] = ACTIONS(3269),
    [sym_real_literal] = ACTIONS(3271),
    [anon_sym_DQUOTE] = ACTIONS(3271),
    [sym_verbatim_string_literal] = ACTIONS(3271),
    [aux_sym_preproc_if_token1] = ACTIONS(3271),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3271),
    [sym_interpolation_verbatim_start] = ACTIONS(3271),
    [sym_interpolation_raw_start] = ACTIONS(3271),
    [sym_raw_string_start] = ACTIONS(3271),
  },
  [2469] = {
    [sym_preproc_region] = STATE(2469),
    [sym_preproc_endregion] = STATE(2469),
    [sym_preproc_line] = STATE(2469),
    [sym_preproc_pragma] = STATE(2469),
    [sym_preproc_nullable] = STATE(2469),
    [sym_preproc_error] = STATE(2469),
    [sym_preproc_warning] = STATE(2469),
    [sym_preproc_define] = STATE(2469),
    [sym_preproc_undef] = STATE(2469),
    [ts_builtin_sym_end] = ACTIONS(3307),
    [sym__identifier_token] = ACTIONS(3305),
    [anon_sym_extern] = ACTIONS(3305),
    [anon_sym_alias] = ACTIONS(3305),
    [anon_sym_SEMI] = ACTIONS(3307),
    [anon_sym_global] = ACTIONS(3305),
    [anon_sym_using] = ACTIONS(3305),
    [anon_sym_unsafe] = ACTIONS(3305),
    [anon_sym_static] = ACTIONS(3305),
    [anon_sym_LBRACK] = ACTIONS(3307),
    [anon_sym_LPAREN] = ACTIONS(3307),
    [anon_sym_return] = ACTIONS(3305),
    [anon_sym_namespace] = ACTIONS(3305),
    [anon_sym_class] = ACTIONS(3305),
    [anon_sym_ref] = ACTIONS(3305),
    [anon_sym_struct] = ACTIONS(3305),
    [anon_sym_enum] = ACTIONS(3305),
    [anon_sym_LBRACE] = ACTIONS(3307),
    [anon_sym_interface] = ACTIONS(3305),
    [anon_sym_delegate] = ACTIONS(3305),
    [anon_sym_record] = ACTIONS(3305),
    [anon_sym_abstract] = ACTIONS(3305),
    [anon_sym_async] = ACTIONS(3305),
    [anon_sym_const] = ACTIONS(3305),
    [anon_sym_file] = ACTIONS(3305),
    [anon_sym_fixed] = ACTIONS(3305),
    [anon_sym_internal] = ACTIONS(3305),
    [anon_sym_new] = ACTIONS(3305),
    [anon_sym_override] = ACTIONS(3305),
    [anon_sym_partial] = ACTIONS(3305),
    [anon_sym_private] = ACTIONS(3305),
    [anon_sym_protected] = ACTIONS(3305),
    [anon_sym_public] = ACTIONS(3305),
    [anon_sym_readonly] = ACTIONS(3305),
    [anon_sym_required] = ACTIONS(3305),
    [anon_sym_sealed] = ACTIONS(3305),
    [anon_sym_virtual] = ACTIONS(3305),
    [anon_sym_volatile] = ACTIONS(3305),
    [anon_sym_where] = ACTIONS(3305),
    [anon_sym_notnull] = ACTIONS(3305),
    [anon_sym_unmanaged] = ACTIONS(3305),
    [anon_sym_checked] = ACTIONS(3305),
    [anon_sym_BANG] = ACTIONS(3307),
    [anon_sym_TILDE] = ACTIONS(3307),
    [anon_sym_PLUS_PLUS] = ACTIONS(3307),
    [anon_sym_DASH_DASH] = ACTIONS(3307),
    [anon_sym_true] = ACTIONS(3305),
    [anon_sym_false] = ACTIONS(3305),
    [anon_sym_PLUS] = ACTIONS(3305),
    [anon_sym_DASH] = ACTIONS(3305),
    [anon_sym_STAR] = ACTIONS(3307),
    [anon_sym_CARET] = ACTIONS(3307),
    [anon_sym_AMP] = ACTIONS(3307),
    [anon_sym_this] = ACTIONS(3305),
    [anon_sym_scoped] = ACTIONS(3305),
    [anon_sym_base] = ACTIONS(3305),
    [anon_sym_var] = ACTIONS(3305),
    [sym_predefined_type] = ACTIONS(3305),
    [anon_sym_break] = ACTIONS(3305),
    [anon_sym_unchecked] = ACTIONS(3305),
    [anon_sym_continue] = ACTIONS(3305),
    [anon_sym_do] = ACTIONS(3305),
    [anon_sym_while] = ACTIONS(3305),
    [anon_sym_for] = ACTIONS(3305),
    [anon_sym_lock] = ACTIONS(3305),
    [anon_sym_yield] = ACTIONS(3305),
    [anon_sym_switch] = ACTIONS(3305),
    [anon_sym_default] = ACTIONS(3305),
    [anon_sym_throw] = ACTIONS(3305),
    [anon_sym_try] = ACTIONS(3305),
    [anon_sym_when] = ACTIONS(3305),
    [anon_sym_await] = ACTIONS(3305),
    [anon_sym_foreach] = ACTIONS(3305),
    [anon_sym_goto] = ACTIONS(3305),
    [anon_sym_if] = ACTIONS(3305),
    [anon_sym_else] = ACTIONS(3305),
    [anon_sym_DOT_DOT] = ACTIONS(3307),
    [anon_sym_from] = ACTIONS(3305),
    [anon_sym_into] = ACTIONS(3305),
    [anon_sym_join] = ACTIONS(3305),
    [anon_sym_on] = ACTIONS(3305),
    [anon_sym_equals] = ACTIONS(3305),
    [anon_sym_let] = ACTIONS(3305),
    [anon_sym_orderby] = ACTIONS(3305),
    [anon_sym_ascending] = ACTIONS(3305),
    [anon_sym_descending] = ACTIONS(3305),
    [anon_sym_group] = ACTIONS(3305),
    [anon_sym_by] = ACTIONS(3305),
    [anon_sym_select] = ACTIONS(3305),
    [anon_sym_stackalloc] = ACTIONS(3305),
    [anon_sym_sizeof] = ACTIONS(3305),
    [anon_sym_typeof] = ACTIONS(3305),
    [anon_sym___makeref] = ACTIONS(3305),
    [anon_sym___reftype] = ACTIONS(3305),
    [anon_sym___refvalue] = ACTIONS(3305),
    [sym_null_literal] = ACTIONS(3305),
    [anon_sym_SQUOTE] = ACTIONS(3307),
    [sym_integer_literal] = ACTIONS(3305),
    [sym_real_literal] = ACTIONS(3307),
    [anon_sym_DQUOTE] = ACTIONS(3307),
    [sym_verbatim_string_literal] = ACTIONS(3307),
    [aux_sym_preproc_if_token1] = ACTIONS(3307),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3307),
    [sym_interpolation_verbatim_start] = ACTIONS(3307),
    [sym_interpolation_raw_start] = ACTIONS(3307),
    [sym_raw_string_start] = ACTIONS(3307),
  },
  [2470] = {
    [sym_catch_clause] = STATE(2648),
    [sym_finally_clause] = STATE(2691),
    [sym_preproc_region] = STATE(2470),
    [sym_preproc_endregion] = STATE(2470),
    [sym_preproc_line] = STATE(2470),
    [sym_preproc_pragma] = STATE(2470),
    [sym_preproc_nullable] = STATE(2470),
    [sym_preproc_error] = STATE(2470),
    [sym_preproc_warning] = STATE(2470),
    [sym_preproc_define] = STATE(2470),
    [sym_preproc_undef] = STATE(2470),
    [aux_sym_try_statement_repeat1] = STATE(2453),
    [sym__identifier_token] = ACTIONS(3003),
    [anon_sym_extern] = ACTIONS(3003),
    [anon_sym_alias] = ACTIONS(3003),
    [anon_sym_SEMI] = ACTIONS(3005),
    [anon_sym_global] = ACTIONS(3003),
    [anon_sym_using] = ACTIONS(3003),
    [anon_sym_unsafe] = ACTIONS(3003),
    [anon_sym_static] = ACTIONS(3003),
    [anon_sym_LBRACK] = ACTIONS(3005),
    [anon_sym_LPAREN] = ACTIONS(3005),
    [anon_sym_return] = ACTIONS(3003),
    [anon_sym_ref] = ACTIONS(3003),
    [anon_sym_LBRACE] = ACTIONS(3005),
    [anon_sym_RBRACE] = ACTIONS(3005),
    [anon_sym_delegate] = ACTIONS(3003),
    [anon_sym_abstract] = ACTIONS(3003),
    [anon_sym_async] = ACTIONS(3003),
    [anon_sym_const] = ACTIONS(3003),
    [anon_sym_file] = ACTIONS(3003),
    [anon_sym_fixed] = ACTIONS(3003),
    [anon_sym_internal] = ACTIONS(3003),
    [anon_sym_new] = ACTIONS(3003),
    [anon_sym_override] = ACTIONS(3003),
    [anon_sym_partial] = ACTIONS(3003),
    [anon_sym_private] = ACTIONS(3003),
    [anon_sym_protected] = ACTIONS(3003),
    [anon_sym_public] = ACTIONS(3003),
    [anon_sym_readonly] = ACTIONS(3003),
    [anon_sym_required] = ACTIONS(3003),
    [anon_sym_sealed] = ACTIONS(3003),
    [anon_sym_virtual] = ACTIONS(3003),
    [anon_sym_volatile] = ACTIONS(3003),
    [anon_sym_where] = ACTIONS(3003),
    [anon_sym_notnull] = ACTIONS(3003),
    [anon_sym_unmanaged] = ACTIONS(3003),
    [anon_sym_checked] = ACTIONS(3003),
    [anon_sym_BANG] = ACTIONS(3005),
    [anon_sym_TILDE] = ACTIONS(3005),
    [anon_sym_PLUS_PLUS] = ACTIONS(3005),
    [anon_sym_DASH_DASH] = ACTIONS(3005),
    [anon_sym_true] = ACTIONS(3003),
    [anon_sym_false] = ACTIONS(3003),
    [anon_sym_PLUS] = ACTIONS(3003),
    [anon_sym_DASH] = ACTIONS(3003),
    [anon_sym_STAR] = ACTIONS(3005),
    [anon_sym_CARET] = ACTIONS(3005),
    [anon_sym_AMP] = ACTIONS(3005),
    [anon_sym_this] = ACTIONS(3003),
    [anon_sym_scoped] = ACTIONS(3003),
    [anon_sym_base] = ACTIONS(3003),
    [anon_sym_var] = ACTIONS(3003),
    [sym_predefined_type] = ACTIONS(3003),
    [anon_sym_break] = ACTIONS(3003),
    [anon_sym_unchecked] = ACTIONS(3003),
    [anon_sym_continue] = ACTIONS(3003),
    [anon_sym_do] = ACTIONS(3003),
    [anon_sym_while] = ACTIONS(3003),
    [anon_sym_for] = ACTIONS(3003),
    [anon_sym_lock] = ACTIONS(3003),
    [anon_sym_yield] = ACTIONS(3003),
    [anon_sym_switch] = ACTIONS(3003),
    [anon_sym_case] = ACTIONS(3003),
    [anon_sym_default] = ACTIONS(3003),
    [anon_sym_throw] = ACTIONS(3003),
    [anon_sym_try] = ACTIONS(3003),
    [anon_sym_catch] = ACTIONS(4010),
    [anon_sym_when] = ACTIONS(3003),
    [anon_sym_finally] = ACTIONS(4012),
    [anon_sym_await] = ACTIONS(3003),
    [anon_sym_foreach] = ACTIONS(3003),
    [anon_sym_goto] = ACTIONS(3003),
    [anon_sym_if] = ACTIONS(3003),
    [anon_sym_else] = ACTIONS(3003),
    [anon_sym_DOT_DOT] = ACTIONS(3005),
    [anon_sym_from] = ACTIONS(3003),
    [anon_sym_into] = ACTIONS(3003),
    [anon_sym_join] = ACTIONS(3003),
    [anon_sym_on] = ACTIONS(3003),
    [anon_sym_equals] = ACTIONS(3003),
    [anon_sym_let] = ACTIONS(3003),
    [anon_sym_orderby] = ACTIONS(3003),
    [anon_sym_ascending] = ACTIONS(3003),
    [anon_sym_descending] = ACTIONS(3003),
    [anon_sym_group] = ACTIONS(3003),
    [anon_sym_by] = ACTIONS(3003),
    [anon_sym_select] = ACTIONS(3003),
    [anon_sym_stackalloc] = ACTIONS(3003),
    [anon_sym_sizeof] = ACTIONS(3003),
    [anon_sym_typeof] = ACTIONS(3003),
    [anon_sym___makeref] = ACTIONS(3003),
    [anon_sym___reftype] = ACTIONS(3003),
    [anon_sym___refvalue] = ACTIONS(3003),
    [sym_null_literal] = ACTIONS(3003),
    [anon_sym_SQUOTE] = ACTIONS(3005),
    [sym_integer_literal] = ACTIONS(3003),
    [sym_real_literal] = ACTIONS(3005),
    [anon_sym_DQUOTE] = ACTIONS(3005),
    [sym_verbatim_string_literal] = ACTIONS(3005),
    [aux_sym_preproc_if_token1] = ACTIONS(3005),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3005),
    [sym_interpolation_verbatim_start] = ACTIONS(3005),
    [sym_interpolation_raw_start] = ACTIONS(3005),
    [sym_raw_string_start] = ACTIONS(3005),
  },
  [2471] = {
    [sym_preproc_region] = STATE(2471),
    [sym_preproc_endregion] = STATE(2471),
    [sym_preproc_line] = STATE(2471),
    [sym_preproc_pragma] = STATE(2471),
    [sym_preproc_nullable] = STATE(2471),
    [sym_preproc_error] = STATE(2471),
    [sym_preproc_warning] = STATE(2471),
    [sym_preproc_define] = STATE(2471),
    [sym_preproc_undef] = STATE(2471),
    [ts_builtin_sym_end] = ACTIONS(3111),
    [sym__identifier_token] = ACTIONS(3109),
    [anon_sym_extern] = ACTIONS(3109),
    [anon_sym_alias] = ACTIONS(3109),
    [anon_sym_SEMI] = ACTIONS(3111),
    [anon_sym_global] = ACTIONS(3109),
    [anon_sym_using] = ACTIONS(3109),
    [anon_sym_unsafe] = ACTIONS(3109),
    [anon_sym_static] = ACTIONS(3109),
    [anon_sym_LBRACK] = ACTIONS(3111),
    [anon_sym_LPAREN] = ACTIONS(3111),
    [anon_sym_return] = ACTIONS(3109),
    [anon_sym_namespace] = ACTIONS(3109),
    [anon_sym_class] = ACTIONS(3109),
    [anon_sym_ref] = ACTIONS(3109),
    [anon_sym_struct] = ACTIONS(3109),
    [anon_sym_enum] = ACTIONS(3109),
    [anon_sym_LBRACE] = ACTIONS(3111),
    [anon_sym_interface] = ACTIONS(3109),
    [anon_sym_delegate] = ACTIONS(3109),
    [anon_sym_record] = ACTIONS(3109),
    [anon_sym_abstract] = ACTIONS(3109),
    [anon_sym_async] = ACTIONS(3109),
    [anon_sym_const] = ACTIONS(3109),
    [anon_sym_file] = ACTIONS(3109),
    [anon_sym_fixed] = ACTIONS(3109),
    [anon_sym_internal] = ACTIONS(3109),
    [anon_sym_new] = ACTIONS(3109),
    [anon_sym_override] = ACTIONS(3109),
    [anon_sym_partial] = ACTIONS(3109),
    [anon_sym_private] = ACTIONS(3109),
    [anon_sym_protected] = ACTIONS(3109),
    [anon_sym_public] = ACTIONS(3109),
    [anon_sym_readonly] = ACTIONS(3109),
    [anon_sym_required] = ACTIONS(3109),
    [anon_sym_sealed] = ACTIONS(3109),
    [anon_sym_virtual] = ACTIONS(3109),
    [anon_sym_volatile] = ACTIONS(3109),
    [anon_sym_where] = ACTIONS(3109),
    [anon_sym_notnull] = ACTIONS(3109),
    [anon_sym_unmanaged] = ACTIONS(3109),
    [anon_sym_checked] = ACTIONS(3109),
    [anon_sym_BANG] = ACTIONS(3111),
    [anon_sym_TILDE] = ACTIONS(3111),
    [anon_sym_PLUS_PLUS] = ACTIONS(3111),
    [anon_sym_DASH_DASH] = ACTIONS(3111),
    [anon_sym_true] = ACTIONS(3109),
    [anon_sym_false] = ACTIONS(3109),
    [anon_sym_PLUS] = ACTIONS(3109),
    [anon_sym_DASH] = ACTIONS(3109),
    [anon_sym_STAR] = ACTIONS(3111),
    [anon_sym_CARET] = ACTIONS(3111),
    [anon_sym_AMP] = ACTIONS(3111),
    [anon_sym_this] = ACTIONS(3109),
    [anon_sym_scoped] = ACTIONS(3109),
    [anon_sym_base] = ACTIONS(3109),
    [anon_sym_var] = ACTIONS(3109),
    [sym_predefined_type] = ACTIONS(3109),
    [anon_sym_break] = ACTIONS(3109),
    [anon_sym_unchecked] = ACTIONS(3109),
    [anon_sym_continue] = ACTIONS(3109),
    [anon_sym_do] = ACTIONS(3109),
    [anon_sym_while] = ACTIONS(3109),
    [anon_sym_for] = ACTIONS(3109),
    [anon_sym_lock] = ACTIONS(3109),
    [anon_sym_yield] = ACTIONS(3109),
    [anon_sym_switch] = ACTIONS(3109),
    [anon_sym_default] = ACTIONS(3109),
    [anon_sym_throw] = ACTIONS(3109),
    [anon_sym_try] = ACTIONS(3109),
    [anon_sym_when] = ACTIONS(3109),
    [anon_sym_await] = ACTIONS(3109),
    [anon_sym_foreach] = ACTIONS(3109),
    [anon_sym_goto] = ACTIONS(3109),
    [anon_sym_if] = ACTIONS(3109),
    [anon_sym_else] = ACTIONS(3109),
    [anon_sym_DOT_DOT] = ACTIONS(3111),
    [anon_sym_from] = ACTIONS(3109),
    [anon_sym_into] = ACTIONS(3109),
    [anon_sym_join] = ACTIONS(3109),
    [anon_sym_on] = ACTIONS(3109),
    [anon_sym_equals] = ACTIONS(3109),
    [anon_sym_let] = ACTIONS(3109),
    [anon_sym_orderby] = ACTIONS(3109),
    [anon_sym_ascending] = ACTIONS(3109),
    [anon_sym_descending] = ACTIONS(3109),
    [anon_sym_group] = ACTIONS(3109),
    [anon_sym_by] = ACTIONS(3109),
    [anon_sym_select] = ACTIONS(3109),
    [anon_sym_stackalloc] = ACTIONS(3109),
    [anon_sym_sizeof] = ACTIONS(3109),
    [anon_sym_typeof] = ACTIONS(3109),
    [anon_sym___makeref] = ACTIONS(3109),
    [anon_sym___reftype] = ACTIONS(3109),
    [anon_sym___refvalue] = ACTIONS(3109),
    [sym_null_literal] = ACTIONS(3109),
    [anon_sym_SQUOTE] = ACTIONS(3111),
    [sym_integer_literal] = ACTIONS(3109),
    [sym_real_literal] = ACTIONS(3111),
    [anon_sym_DQUOTE] = ACTIONS(3111),
    [sym_verbatim_string_literal] = ACTIONS(3111),
    [aux_sym_preproc_if_token1] = ACTIONS(3111),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3111),
    [sym_interpolation_verbatim_start] = ACTIONS(3111),
    [sym_interpolation_raw_start] = ACTIONS(3111),
    [sym_raw_string_start] = ACTIONS(3111),
  },
  [2472] = {
    [sym_preproc_region] = STATE(2472),
    [sym_preproc_endregion] = STATE(2472),
    [sym_preproc_line] = STATE(2472),
    [sym_preproc_pragma] = STATE(2472),
    [sym_preproc_nullable] = STATE(2472),
    [sym_preproc_error] = STATE(2472),
    [sym_preproc_warning] = STATE(2472),
    [sym_preproc_define] = STATE(2472),
    [sym_preproc_undef] = STATE(2472),
    [ts_builtin_sym_end] = ACTIONS(3319),
    [sym__identifier_token] = ACTIONS(3317),
    [anon_sym_extern] = ACTIONS(3317),
    [anon_sym_alias] = ACTIONS(3317),
    [anon_sym_SEMI] = ACTIONS(3319),
    [anon_sym_global] = ACTIONS(3317),
    [anon_sym_using] = ACTIONS(3317),
    [anon_sym_unsafe] = ACTIONS(3317),
    [anon_sym_static] = ACTIONS(3317),
    [anon_sym_LBRACK] = ACTIONS(3319),
    [anon_sym_LPAREN] = ACTIONS(3319),
    [anon_sym_return] = ACTIONS(3317),
    [anon_sym_namespace] = ACTIONS(3317),
    [anon_sym_class] = ACTIONS(3317),
    [anon_sym_ref] = ACTIONS(3317),
    [anon_sym_struct] = ACTIONS(3317),
    [anon_sym_enum] = ACTIONS(3317),
    [anon_sym_LBRACE] = ACTIONS(3319),
    [anon_sym_interface] = ACTIONS(3317),
    [anon_sym_delegate] = ACTIONS(3317),
    [anon_sym_record] = ACTIONS(3317),
    [anon_sym_abstract] = ACTIONS(3317),
    [anon_sym_async] = ACTIONS(3317),
    [anon_sym_const] = ACTIONS(3317),
    [anon_sym_file] = ACTIONS(3317),
    [anon_sym_fixed] = ACTIONS(3317),
    [anon_sym_internal] = ACTIONS(3317),
    [anon_sym_new] = ACTIONS(3317),
    [anon_sym_override] = ACTIONS(3317),
    [anon_sym_partial] = ACTIONS(3317),
    [anon_sym_private] = ACTIONS(3317),
    [anon_sym_protected] = ACTIONS(3317),
    [anon_sym_public] = ACTIONS(3317),
    [anon_sym_readonly] = ACTIONS(3317),
    [anon_sym_required] = ACTIONS(3317),
    [anon_sym_sealed] = ACTIONS(3317),
    [anon_sym_virtual] = ACTIONS(3317),
    [anon_sym_volatile] = ACTIONS(3317),
    [anon_sym_where] = ACTIONS(3317),
    [anon_sym_notnull] = ACTIONS(3317),
    [anon_sym_unmanaged] = ACTIONS(3317),
    [anon_sym_checked] = ACTIONS(3317),
    [anon_sym_BANG] = ACTIONS(3319),
    [anon_sym_TILDE] = ACTIONS(3319),
    [anon_sym_PLUS_PLUS] = ACTIONS(3319),
    [anon_sym_DASH_DASH] = ACTIONS(3319),
    [anon_sym_true] = ACTIONS(3317),
    [anon_sym_false] = ACTIONS(3317),
    [anon_sym_PLUS] = ACTIONS(3317),
    [anon_sym_DASH] = ACTIONS(3317),
    [anon_sym_STAR] = ACTIONS(3319),
    [anon_sym_CARET] = ACTIONS(3319),
    [anon_sym_AMP] = ACTIONS(3319),
    [anon_sym_this] = ACTIONS(3317),
    [anon_sym_scoped] = ACTIONS(3317),
    [anon_sym_base] = ACTIONS(3317),
    [anon_sym_var] = ACTIONS(3317),
    [sym_predefined_type] = ACTIONS(3317),
    [anon_sym_break] = ACTIONS(3317),
    [anon_sym_unchecked] = ACTIONS(3317),
    [anon_sym_continue] = ACTIONS(3317),
    [anon_sym_do] = ACTIONS(3317),
    [anon_sym_while] = ACTIONS(3317),
    [anon_sym_for] = ACTIONS(3317),
    [anon_sym_lock] = ACTIONS(3317),
    [anon_sym_yield] = ACTIONS(3317),
    [anon_sym_switch] = ACTIONS(3317),
    [anon_sym_default] = ACTIONS(3317),
    [anon_sym_throw] = ACTIONS(3317),
    [anon_sym_try] = ACTIONS(3317),
    [anon_sym_when] = ACTIONS(3317),
    [anon_sym_await] = ACTIONS(3317),
    [anon_sym_foreach] = ACTIONS(3317),
    [anon_sym_goto] = ACTIONS(3317),
    [anon_sym_if] = ACTIONS(3317),
    [anon_sym_else] = ACTIONS(4014),
    [anon_sym_DOT_DOT] = ACTIONS(3319),
    [anon_sym_from] = ACTIONS(3317),
    [anon_sym_into] = ACTIONS(3317),
    [anon_sym_join] = ACTIONS(3317),
    [anon_sym_on] = ACTIONS(3317),
    [anon_sym_equals] = ACTIONS(3317),
    [anon_sym_let] = ACTIONS(3317),
    [anon_sym_orderby] = ACTIONS(3317),
    [anon_sym_ascending] = ACTIONS(3317),
    [anon_sym_descending] = ACTIONS(3317),
    [anon_sym_group] = ACTIONS(3317),
    [anon_sym_by] = ACTIONS(3317),
    [anon_sym_select] = ACTIONS(3317),
    [anon_sym_stackalloc] = ACTIONS(3317),
    [anon_sym_sizeof] = ACTIONS(3317),
    [anon_sym_typeof] = ACTIONS(3317),
    [anon_sym___makeref] = ACTIONS(3317),
    [anon_sym___reftype] = ACTIONS(3317),
    [anon_sym___refvalue] = ACTIONS(3317),
    [sym_null_literal] = ACTIONS(3317),
    [anon_sym_SQUOTE] = ACTIONS(3319),
    [sym_integer_literal] = ACTIONS(3317),
    [sym_real_literal] = ACTIONS(3319),
    [anon_sym_DQUOTE] = ACTIONS(3319),
    [sym_verbatim_string_literal] = ACTIONS(3319),
    [aux_sym_preproc_if_token1] = ACTIONS(3319),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3319),
    [sym_interpolation_verbatim_start] = ACTIONS(3319),
    [sym_interpolation_raw_start] = ACTIONS(3319),
    [sym_raw_string_start] = ACTIONS(3319),
  },
  [2473] = {
    [sym_preproc_region] = STATE(2473),
    [sym_preproc_endregion] = STATE(2473),
    [sym_preproc_line] = STATE(2473),
    [sym_preproc_pragma] = STATE(2473),
    [sym_preproc_nullable] = STATE(2473),
    [sym_preproc_error] = STATE(2473),
    [sym_preproc_warning] = STATE(2473),
    [sym_preproc_define] = STATE(2473),
    [sym_preproc_undef] = STATE(2473),
    [ts_builtin_sym_end] = ACTIONS(3325),
    [sym__identifier_token] = ACTIONS(3323),
    [anon_sym_extern] = ACTIONS(3323),
    [anon_sym_alias] = ACTIONS(3323),
    [anon_sym_SEMI] = ACTIONS(3325),
    [anon_sym_global] = ACTIONS(3323),
    [anon_sym_using] = ACTIONS(3323),
    [anon_sym_unsafe] = ACTIONS(3323),
    [anon_sym_static] = ACTIONS(3323),
    [anon_sym_LBRACK] = ACTIONS(3325),
    [anon_sym_LPAREN] = ACTIONS(3325),
    [anon_sym_return] = ACTIONS(3323),
    [anon_sym_namespace] = ACTIONS(3323),
    [anon_sym_class] = ACTIONS(3323),
    [anon_sym_ref] = ACTIONS(3323),
    [anon_sym_struct] = ACTIONS(3323),
    [anon_sym_enum] = ACTIONS(3323),
    [anon_sym_LBRACE] = ACTIONS(3325),
    [anon_sym_interface] = ACTIONS(3323),
    [anon_sym_delegate] = ACTIONS(3323),
    [anon_sym_record] = ACTIONS(3323),
    [anon_sym_abstract] = ACTIONS(3323),
    [anon_sym_async] = ACTIONS(3323),
    [anon_sym_const] = ACTIONS(3323),
    [anon_sym_file] = ACTIONS(3323),
    [anon_sym_fixed] = ACTIONS(3323),
    [anon_sym_internal] = ACTIONS(3323),
    [anon_sym_new] = ACTIONS(3323),
    [anon_sym_override] = ACTIONS(3323),
    [anon_sym_partial] = ACTIONS(3323),
    [anon_sym_private] = ACTIONS(3323),
    [anon_sym_protected] = ACTIONS(3323),
    [anon_sym_public] = ACTIONS(3323),
    [anon_sym_readonly] = ACTIONS(3323),
    [anon_sym_required] = ACTIONS(3323),
    [anon_sym_sealed] = ACTIONS(3323),
    [anon_sym_virtual] = ACTIONS(3323),
    [anon_sym_volatile] = ACTIONS(3323),
    [anon_sym_where] = ACTIONS(3323),
    [anon_sym_notnull] = ACTIONS(3323),
    [anon_sym_unmanaged] = ACTIONS(3323),
    [anon_sym_checked] = ACTIONS(3323),
    [anon_sym_BANG] = ACTIONS(3325),
    [anon_sym_TILDE] = ACTIONS(3325),
    [anon_sym_PLUS_PLUS] = ACTIONS(3325),
    [anon_sym_DASH_DASH] = ACTIONS(3325),
    [anon_sym_true] = ACTIONS(3323),
    [anon_sym_false] = ACTIONS(3323),
    [anon_sym_PLUS] = ACTIONS(3323),
    [anon_sym_DASH] = ACTIONS(3323),
    [anon_sym_STAR] = ACTIONS(3325),
    [anon_sym_CARET] = ACTIONS(3325),
    [anon_sym_AMP] = ACTIONS(3325),
    [anon_sym_this] = ACTIONS(3323),
    [anon_sym_scoped] = ACTIONS(3323),
    [anon_sym_base] = ACTIONS(3323),
    [anon_sym_var] = ACTIONS(3323),
    [sym_predefined_type] = ACTIONS(3323),
    [anon_sym_break] = ACTIONS(3323),
    [anon_sym_unchecked] = ACTIONS(3323),
    [anon_sym_continue] = ACTIONS(3323),
    [anon_sym_do] = ACTIONS(3323),
    [anon_sym_while] = ACTIONS(3323),
    [anon_sym_for] = ACTIONS(3323),
    [anon_sym_lock] = ACTIONS(3323),
    [anon_sym_yield] = ACTIONS(3323),
    [anon_sym_switch] = ACTIONS(3323),
    [anon_sym_default] = ACTIONS(3323),
    [anon_sym_throw] = ACTIONS(3323),
    [anon_sym_try] = ACTIONS(3323),
    [anon_sym_when] = ACTIONS(3323),
    [anon_sym_await] = ACTIONS(3323),
    [anon_sym_foreach] = ACTIONS(3323),
    [anon_sym_goto] = ACTIONS(3323),
    [anon_sym_if] = ACTIONS(3323),
    [anon_sym_else] = ACTIONS(3323),
    [anon_sym_DOT_DOT] = ACTIONS(3325),
    [anon_sym_from] = ACTIONS(3323),
    [anon_sym_into] = ACTIONS(3323),
    [anon_sym_join] = ACTIONS(3323),
    [anon_sym_on] = ACTIONS(3323),
    [anon_sym_equals] = ACTIONS(3323),
    [anon_sym_let] = ACTIONS(3323),
    [anon_sym_orderby] = ACTIONS(3323),
    [anon_sym_ascending] = ACTIONS(3323),
    [anon_sym_descending] = ACTIONS(3323),
    [anon_sym_group] = ACTIONS(3323),
    [anon_sym_by] = ACTIONS(3323),
    [anon_sym_select] = ACTIONS(3323),
    [anon_sym_stackalloc] = ACTIONS(3323),
    [anon_sym_sizeof] = ACTIONS(3323),
    [anon_sym_typeof] = ACTIONS(3323),
    [anon_sym___makeref] = ACTIONS(3323),
    [anon_sym___reftype] = ACTIONS(3323),
    [anon_sym___refvalue] = ACTIONS(3323),
    [sym_null_literal] = ACTIONS(3323),
    [anon_sym_SQUOTE] = ACTIONS(3325),
    [sym_integer_literal] = ACTIONS(3323),
    [sym_real_literal] = ACTIONS(3325),
    [anon_sym_DQUOTE] = ACTIONS(3325),
    [sym_verbatim_string_literal] = ACTIONS(3325),
    [aux_sym_preproc_if_token1] = ACTIONS(3325),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3325),
    [sym_interpolation_verbatim_start] = ACTIONS(3325),
    [sym_interpolation_raw_start] = ACTIONS(3325),
    [sym_raw_string_start] = ACTIONS(3325),
  },
  [2474] = {
    [sym_preproc_region] = STATE(2474),
    [sym_preproc_endregion] = STATE(2474),
    [sym_preproc_line] = STATE(2474),
    [sym_preproc_pragma] = STATE(2474),
    [sym_preproc_nullable] = STATE(2474),
    [sym_preproc_error] = STATE(2474),
    [sym_preproc_warning] = STATE(2474),
    [sym_preproc_define] = STATE(2474),
    [sym_preproc_undef] = STATE(2474),
    [ts_builtin_sym_end] = ACTIONS(3341),
    [sym__identifier_token] = ACTIONS(3339),
    [anon_sym_extern] = ACTIONS(3339),
    [anon_sym_alias] = ACTIONS(3339),
    [anon_sym_SEMI] = ACTIONS(3341),
    [anon_sym_global] = ACTIONS(3339),
    [anon_sym_using] = ACTIONS(3339),
    [anon_sym_unsafe] = ACTIONS(3339),
    [anon_sym_static] = ACTIONS(3339),
    [anon_sym_LBRACK] = ACTIONS(3341),
    [anon_sym_LPAREN] = ACTIONS(3341),
    [anon_sym_return] = ACTIONS(3339),
    [anon_sym_namespace] = ACTIONS(3339),
    [anon_sym_class] = ACTIONS(3339),
    [anon_sym_ref] = ACTIONS(3339),
    [anon_sym_struct] = ACTIONS(3339),
    [anon_sym_enum] = ACTIONS(3339),
    [anon_sym_LBRACE] = ACTIONS(3341),
    [anon_sym_interface] = ACTIONS(3339),
    [anon_sym_delegate] = ACTIONS(3339),
    [anon_sym_record] = ACTIONS(3339),
    [anon_sym_abstract] = ACTIONS(3339),
    [anon_sym_async] = ACTIONS(3339),
    [anon_sym_const] = ACTIONS(3339),
    [anon_sym_file] = ACTIONS(3339),
    [anon_sym_fixed] = ACTIONS(3339),
    [anon_sym_internal] = ACTIONS(3339),
    [anon_sym_new] = ACTIONS(3339),
    [anon_sym_override] = ACTIONS(3339),
    [anon_sym_partial] = ACTIONS(3339),
    [anon_sym_private] = ACTIONS(3339),
    [anon_sym_protected] = ACTIONS(3339),
    [anon_sym_public] = ACTIONS(3339),
    [anon_sym_readonly] = ACTIONS(3339),
    [anon_sym_required] = ACTIONS(3339),
    [anon_sym_sealed] = ACTIONS(3339),
    [anon_sym_virtual] = ACTIONS(3339),
    [anon_sym_volatile] = ACTIONS(3339),
    [anon_sym_where] = ACTIONS(3339),
    [anon_sym_notnull] = ACTIONS(3339),
    [anon_sym_unmanaged] = ACTIONS(3339),
    [anon_sym_checked] = ACTIONS(3339),
    [anon_sym_BANG] = ACTIONS(3341),
    [anon_sym_TILDE] = ACTIONS(3341),
    [anon_sym_PLUS_PLUS] = ACTIONS(3341),
    [anon_sym_DASH_DASH] = ACTIONS(3341),
    [anon_sym_true] = ACTIONS(3339),
    [anon_sym_false] = ACTIONS(3339),
    [anon_sym_PLUS] = ACTIONS(3339),
    [anon_sym_DASH] = ACTIONS(3339),
    [anon_sym_STAR] = ACTIONS(3341),
    [anon_sym_CARET] = ACTIONS(3341),
    [anon_sym_AMP] = ACTIONS(3341),
    [anon_sym_this] = ACTIONS(3339),
    [anon_sym_scoped] = ACTIONS(3339),
    [anon_sym_base] = ACTIONS(3339),
    [anon_sym_var] = ACTIONS(3339),
    [sym_predefined_type] = ACTIONS(3339),
    [anon_sym_break] = ACTIONS(3339),
    [anon_sym_unchecked] = ACTIONS(3339),
    [anon_sym_continue] = ACTIONS(3339),
    [anon_sym_do] = ACTIONS(3339),
    [anon_sym_while] = ACTIONS(3339),
    [anon_sym_for] = ACTIONS(3339),
    [anon_sym_lock] = ACTIONS(3339),
    [anon_sym_yield] = ACTIONS(3339),
    [anon_sym_switch] = ACTIONS(3339),
    [anon_sym_default] = ACTIONS(3339),
    [anon_sym_throw] = ACTIONS(3339),
    [anon_sym_try] = ACTIONS(3339),
    [anon_sym_when] = ACTIONS(3339),
    [anon_sym_await] = ACTIONS(3339),
    [anon_sym_foreach] = ACTIONS(3339),
    [anon_sym_goto] = ACTIONS(3339),
    [anon_sym_if] = ACTIONS(3339),
    [anon_sym_else] = ACTIONS(3339),
    [anon_sym_DOT_DOT] = ACTIONS(3341),
    [anon_sym_from] = ACTIONS(3339),
    [anon_sym_into] = ACTIONS(3339),
    [anon_sym_join] = ACTIONS(3339),
    [anon_sym_on] = ACTIONS(3339),
    [anon_sym_equals] = ACTIONS(3339),
    [anon_sym_let] = ACTIONS(3339),
    [anon_sym_orderby] = ACTIONS(3339),
    [anon_sym_ascending] = ACTIONS(3339),
    [anon_sym_descending] = ACTIONS(3339),
    [anon_sym_group] = ACTIONS(3339),
    [anon_sym_by] = ACTIONS(3339),
    [anon_sym_select] = ACTIONS(3339),
    [anon_sym_stackalloc] = ACTIONS(3339),
    [anon_sym_sizeof] = ACTIONS(3339),
    [anon_sym_typeof] = ACTIONS(3339),
    [anon_sym___makeref] = ACTIONS(3339),
    [anon_sym___reftype] = ACTIONS(3339),
    [anon_sym___refvalue] = ACTIONS(3339),
    [sym_null_literal] = ACTIONS(3339),
    [anon_sym_SQUOTE] = ACTIONS(3341),
    [sym_integer_literal] = ACTIONS(3339),
    [sym_real_literal] = ACTIONS(3341),
    [anon_sym_DQUOTE] = ACTIONS(3341),
    [sym_verbatim_string_literal] = ACTIONS(3341),
    [aux_sym_preproc_if_token1] = ACTIONS(3341),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3341),
    [sym_interpolation_verbatim_start] = ACTIONS(3341),
    [sym_interpolation_raw_start] = ACTIONS(3341),
    [sym_raw_string_start] = ACTIONS(3341),
  },
  [2475] = {
    [sym_preproc_region] = STATE(2475),
    [sym_preproc_endregion] = STATE(2475),
    [sym_preproc_line] = STATE(2475),
    [sym_preproc_pragma] = STATE(2475),
    [sym_preproc_nullable] = STATE(2475),
    [sym_preproc_error] = STATE(2475),
    [sym_preproc_warning] = STATE(2475),
    [sym_preproc_define] = STATE(2475),
    [sym_preproc_undef] = STATE(2475),
    [ts_builtin_sym_end] = ACTIONS(3167),
    [sym__identifier_token] = ACTIONS(3165),
    [anon_sym_extern] = ACTIONS(3165),
    [anon_sym_alias] = ACTIONS(3165),
    [anon_sym_SEMI] = ACTIONS(3167),
    [anon_sym_global] = ACTIONS(3165),
    [anon_sym_using] = ACTIONS(3165),
    [anon_sym_unsafe] = ACTIONS(3165),
    [anon_sym_static] = ACTIONS(3165),
    [anon_sym_LBRACK] = ACTIONS(3167),
    [anon_sym_LPAREN] = ACTIONS(3167),
    [anon_sym_return] = ACTIONS(3165),
    [anon_sym_namespace] = ACTIONS(3165),
    [anon_sym_class] = ACTIONS(3165),
    [anon_sym_ref] = ACTIONS(3165),
    [anon_sym_struct] = ACTIONS(3165),
    [anon_sym_enum] = ACTIONS(3165),
    [anon_sym_LBRACE] = ACTIONS(3167),
    [anon_sym_interface] = ACTIONS(3165),
    [anon_sym_delegate] = ACTIONS(3165),
    [anon_sym_record] = ACTIONS(3165),
    [anon_sym_abstract] = ACTIONS(3165),
    [anon_sym_async] = ACTIONS(3165),
    [anon_sym_const] = ACTIONS(3165),
    [anon_sym_file] = ACTIONS(3165),
    [anon_sym_fixed] = ACTIONS(3165),
    [anon_sym_internal] = ACTIONS(3165),
    [anon_sym_new] = ACTIONS(3165),
    [anon_sym_override] = ACTIONS(3165),
    [anon_sym_partial] = ACTIONS(3165),
    [anon_sym_private] = ACTIONS(3165),
    [anon_sym_protected] = ACTIONS(3165),
    [anon_sym_public] = ACTIONS(3165),
    [anon_sym_readonly] = ACTIONS(3165),
    [anon_sym_required] = ACTIONS(3165),
    [anon_sym_sealed] = ACTIONS(3165),
    [anon_sym_virtual] = ACTIONS(3165),
    [anon_sym_volatile] = ACTIONS(3165),
    [anon_sym_where] = ACTIONS(3165),
    [anon_sym_notnull] = ACTIONS(3165),
    [anon_sym_unmanaged] = ACTIONS(3165),
    [anon_sym_checked] = ACTIONS(3165),
    [anon_sym_BANG] = ACTIONS(3167),
    [anon_sym_TILDE] = ACTIONS(3167),
    [anon_sym_PLUS_PLUS] = ACTIONS(3167),
    [anon_sym_DASH_DASH] = ACTIONS(3167),
    [anon_sym_true] = ACTIONS(3165),
    [anon_sym_false] = ACTIONS(3165),
    [anon_sym_PLUS] = ACTIONS(3165),
    [anon_sym_DASH] = ACTIONS(3165),
    [anon_sym_STAR] = ACTIONS(3167),
    [anon_sym_CARET] = ACTIONS(3167),
    [anon_sym_AMP] = ACTIONS(3167),
    [anon_sym_this] = ACTIONS(3165),
    [anon_sym_scoped] = ACTIONS(3165),
    [anon_sym_base] = ACTIONS(3165),
    [anon_sym_var] = ACTIONS(3165),
    [sym_predefined_type] = ACTIONS(3165),
    [anon_sym_break] = ACTIONS(3165),
    [anon_sym_unchecked] = ACTIONS(3165),
    [anon_sym_continue] = ACTIONS(3165),
    [anon_sym_do] = ACTIONS(3165),
    [anon_sym_while] = ACTIONS(3165),
    [anon_sym_for] = ACTIONS(3165),
    [anon_sym_lock] = ACTIONS(3165),
    [anon_sym_yield] = ACTIONS(3165),
    [anon_sym_switch] = ACTIONS(3165),
    [anon_sym_default] = ACTIONS(3165),
    [anon_sym_throw] = ACTIONS(3165),
    [anon_sym_try] = ACTIONS(3165),
    [anon_sym_when] = ACTIONS(3165),
    [anon_sym_await] = ACTIONS(3165),
    [anon_sym_foreach] = ACTIONS(3165),
    [anon_sym_goto] = ACTIONS(3165),
    [anon_sym_if] = ACTIONS(3165),
    [anon_sym_else] = ACTIONS(3165),
    [anon_sym_DOT_DOT] = ACTIONS(3167),
    [anon_sym_from] = ACTIONS(3165),
    [anon_sym_into] = ACTIONS(3165),
    [anon_sym_join] = ACTIONS(3165),
    [anon_sym_on] = ACTIONS(3165),
    [anon_sym_equals] = ACTIONS(3165),
    [anon_sym_let] = ACTIONS(3165),
    [anon_sym_orderby] = ACTIONS(3165),
    [anon_sym_ascending] = ACTIONS(3165),
    [anon_sym_descending] = ACTIONS(3165),
    [anon_sym_group] = ACTIONS(3165),
    [anon_sym_by] = ACTIONS(3165),
    [anon_sym_select] = ACTIONS(3165),
    [anon_sym_stackalloc] = ACTIONS(3165),
    [anon_sym_sizeof] = ACTIONS(3165),
    [anon_sym_typeof] = ACTIONS(3165),
    [anon_sym___makeref] = ACTIONS(3165),
    [anon_sym___reftype] = ACTIONS(3165),
    [anon_sym___refvalue] = ACTIONS(3165),
    [sym_null_literal] = ACTIONS(3165),
    [anon_sym_SQUOTE] = ACTIONS(3167),
    [sym_integer_literal] = ACTIONS(3165),
    [sym_real_literal] = ACTIONS(3167),
    [anon_sym_DQUOTE] = ACTIONS(3167),
    [sym_verbatim_string_literal] = ACTIONS(3167),
    [aux_sym_preproc_if_token1] = ACTIONS(3167),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3167),
    [sym_interpolation_verbatim_start] = ACTIONS(3167),
    [sym_interpolation_raw_start] = ACTIONS(3167),
    [sym_raw_string_start] = ACTIONS(3167),
  },
  [2476] = {
    [sym_preproc_region] = STATE(2476),
    [sym_preproc_endregion] = STATE(2476),
    [sym_preproc_line] = STATE(2476),
    [sym_preproc_pragma] = STATE(2476),
    [sym_preproc_nullable] = STATE(2476),
    [sym_preproc_error] = STATE(2476),
    [sym_preproc_warning] = STATE(2476),
    [sym_preproc_define] = STATE(2476),
    [sym_preproc_undef] = STATE(2476),
    [ts_builtin_sym_end] = ACTIONS(3357),
    [sym__identifier_token] = ACTIONS(3355),
    [anon_sym_extern] = ACTIONS(3355),
    [anon_sym_alias] = ACTIONS(3355),
    [anon_sym_SEMI] = ACTIONS(3357),
    [anon_sym_global] = ACTIONS(3355),
    [anon_sym_using] = ACTIONS(3355),
    [anon_sym_unsafe] = ACTIONS(3355),
    [anon_sym_static] = ACTIONS(3355),
    [anon_sym_LBRACK] = ACTIONS(3357),
    [anon_sym_LPAREN] = ACTIONS(3357),
    [anon_sym_return] = ACTIONS(3355),
    [anon_sym_namespace] = ACTIONS(3355),
    [anon_sym_class] = ACTIONS(3355),
    [anon_sym_ref] = ACTIONS(3355),
    [anon_sym_struct] = ACTIONS(3355),
    [anon_sym_enum] = ACTIONS(3355),
    [anon_sym_LBRACE] = ACTIONS(3357),
    [anon_sym_interface] = ACTIONS(3355),
    [anon_sym_delegate] = ACTIONS(3355),
    [anon_sym_record] = ACTIONS(3355),
    [anon_sym_abstract] = ACTIONS(3355),
    [anon_sym_async] = ACTIONS(3355),
    [anon_sym_const] = ACTIONS(3355),
    [anon_sym_file] = ACTIONS(3355),
    [anon_sym_fixed] = ACTIONS(3355),
    [anon_sym_internal] = ACTIONS(3355),
    [anon_sym_new] = ACTIONS(3355),
    [anon_sym_override] = ACTIONS(3355),
    [anon_sym_partial] = ACTIONS(3355),
    [anon_sym_private] = ACTIONS(3355),
    [anon_sym_protected] = ACTIONS(3355),
    [anon_sym_public] = ACTIONS(3355),
    [anon_sym_readonly] = ACTIONS(3355),
    [anon_sym_required] = ACTIONS(3355),
    [anon_sym_sealed] = ACTIONS(3355),
    [anon_sym_virtual] = ACTIONS(3355),
    [anon_sym_volatile] = ACTIONS(3355),
    [anon_sym_where] = ACTIONS(3355),
    [anon_sym_notnull] = ACTIONS(3355),
    [anon_sym_unmanaged] = ACTIONS(3355),
    [anon_sym_checked] = ACTIONS(3355),
    [anon_sym_BANG] = ACTIONS(3357),
    [anon_sym_TILDE] = ACTIONS(3357),
    [anon_sym_PLUS_PLUS] = ACTIONS(3357),
    [anon_sym_DASH_DASH] = ACTIONS(3357),
    [anon_sym_true] = ACTIONS(3355),
    [anon_sym_false] = ACTIONS(3355),
    [anon_sym_PLUS] = ACTIONS(3355),
    [anon_sym_DASH] = ACTIONS(3355),
    [anon_sym_STAR] = ACTIONS(3357),
    [anon_sym_CARET] = ACTIONS(3357),
    [anon_sym_AMP] = ACTIONS(3357),
    [anon_sym_this] = ACTIONS(3355),
    [anon_sym_scoped] = ACTIONS(3355),
    [anon_sym_base] = ACTIONS(3355),
    [anon_sym_var] = ACTIONS(3355),
    [sym_predefined_type] = ACTIONS(3355),
    [anon_sym_break] = ACTIONS(3355),
    [anon_sym_unchecked] = ACTIONS(3355),
    [anon_sym_continue] = ACTIONS(3355),
    [anon_sym_do] = ACTIONS(3355),
    [anon_sym_while] = ACTIONS(3355),
    [anon_sym_for] = ACTIONS(3355),
    [anon_sym_lock] = ACTIONS(3355),
    [anon_sym_yield] = ACTIONS(3355),
    [anon_sym_switch] = ACTIONS(3355),
    [anon_sym_default] = ACTIONS(3355),
    [anon_sym_throw] = ACTIONS(3355),
    [anon_sym_try] = ACTIONS(3355),
    [anon_sym_when] = ACTIONS(3355),
    [anon_sym_await] = ACTIONS(3355),
    [anon_sym_foreach] = ACTIONS(3355),
    [anon_sym_goto] = ACTIONS(3355),
    [anon_sym_if] = ACTIONS(3355),
    [anon_sym_else] = ACTIONS(3355),
    [anon_sym_DOT_DOT] = ACTIONS(3357),
    [anon_sym_from] = ACTIONS(3355),
    [anon_sym_into] = ACTIONS(3355),
    [anon_sym_join] = ACTIONS(3355),
    [anon_sym_on] = ACTIONS(3355),
    [anon_sym_equals] = ACTIONS(3355),
    [anon_sym_let] = ACTIONS(3355),
    [anon_sym_orderby] = ACTIONS(3355),
    [anon_sym_ascending] = ACTIONS(3355),
    [anon_sym_descending] = ACTIONS(3355),
    [anon_sym_group] = ACTIONS(3355),
    [anon_sym_by] = ACTIONS(3355),
    [anon_sym_select] = ACTIONS(3355),
    [anon_sym_stackalloc] = ACTIONS(3355),
    [anon_sym_sizeof] = ACTIONS(3355),
    [anon_sym_typeof] = ACTIONS(3355),
    [anon_sym___makeref] = ACTIONS(3355),
    [anon_sym___reftype] = ACTIONS(3355),
    [anon_sym___refvalue] = ACTIONS(3355),
    [sym_null_literal] = ACTIONS(3355),
    [anon_sym_SQUOTE] = ACTIONS(3357),
    [sym_integer_literal] = ACTIONS(3355),
    [sym_real_literal] = ACTIONS(3357),
    [anon_sym_DQUOTE] = ACTIONS(3357),
    [sym_verbatim_string_literal] = ACTIONS(3357),
    [aux_sym_preproc_if_token1] = ACTIONS(3357),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3357),
    [sym_interpolation_verbatim_start] = ACTIONS(3357),
    [sym_interpolation_raw_start] = ACTIONS(3357),
    [sym_raw_string_start] = ACTIONS(3357),
  },
  [2477] = {
    [sym_preproc_region] = STATE(2477),
    [sym_preproc_endregion] = STATE(2477),
    [sym_preproc_line] = STATE(2477),
    [sym_preproc_pragma] = STATE(2477),
    [sym_preproc_nullable] = STATE(2477),
    [sym_preproc_error] = STATE(2477),
    [sym_preproc_warning] = STATE(2477),
    [sym_preproc_define] = STATE(2477),
    [sym_preproc_undef] = STATE(2477),
    [ts_builtin_sym_end] = ACTIONS(3051),
    [sym__identifier_token] = ACTIONS(3049),
    [anon_sym_extern] = ACTIONS(3049),
    [anon_sym_alias] = ACTIONS(3049),
    [anon_sym_SEMI] = ACTIONS(3051),
    [anon_sym_global] = ACTIONS(3049),
    [anon_sym_using] = ACTIONS(3049),
    [anon_sym_unsafe] = ACTIONS(3049),
    [anon_sym_static] = ACTIONS(3049),
    [anon_sym_LBRACK] = ACTIONS(3051),
    [anon_sym_LPAREN] = ACTIONS(3051),
    [anon_sym_return] = ACTIONS(3049),
    [anon_sym_namespace] = ACTIONS(3049),
    [anon_sym_class] = ACTIONS(3049),
    [anon_sym_ref] = ACTIONS(3049),
    [anon_sym_struct] = ACTIONS(3049),
    [anon_sym_enum] = ACTIONS(3049),
    [anon_sym_LBRACE] = ACTIONS(3051),
    [anon_sym_interface] = ACTIONS(3049),
    [anon_sym_delegate] = ACTIONS(3049),
    [anon_sym_record] = ACTIONS(3049),
    [anon_sym_abstract] = ACTIONS(3049),
    [anon_sym_async] = ACTIONS(3049),
    [anon_sym_const] = ACTIONS(3049),
    [anon_sym_file] = ACTIONS(3049),
    [anon_sym_fixed] = ACTIONS(3049),
    [anon_sym_internal] = ACTIONS(3049),
    [anon_sym_new] = ACTIONS(3049),
    [anon_sym_override] = ACTIONS(3049),
    [anon_sym_partial] = ACTIONS(3049),
    [anon_sym_private] = ACTIONS(3049),
    [anon_sym_protected] = ACTIONS(3049),
    [anon_sym_public] = ACTIONS(3049),
    [anon_sym_readonly] = ACTIONS(3049),
    [anon_sym_required] = ACTIONS(3049),
    [anon_sym_sealed] = ACTIONS(3049),
    [anon_sym_virtual] = ACTIONS(3049),
    [anon_sym_volatile] = ACTIONS(3049),
    [anon_sym_where] = ACTIONS(3049),
    [anon_sym_notnull] = ACTIONS(3049),
    [anon_sym_unmanaged] = ACTIONS(3049),
    [anon_sym_checked] = ACTIONS(3049),
    [anon_sym_BANG] = ACTIONS(3051),
    [anon_sym_TILDE] = ACTIONS(3051),
    [anon_sym_PLUS_PLUS] = ACTIONS(3051),
    [anon_sym_DASH_DASH] = ACTIONS(3051),
    [anon_sym_true] = ACTIONS(3049),
    [anon_sym_false] = ACTIONS(3049),
    [anon_sym_PLUS] = ACTIONS(3049),
    [anon_sym_DASH] = ACTIONS(3049),
    [anon_sym_STAR] = ACTIONS(3051),
    [anon_sym_CARET] = ACTIONS(3051),
    [anon_sym_AMP] = ACTIONS(3051),
    [anon_sym_this] = ACTIONS(3049),
    [anon_sym_scoped] = ACTIONS(3049),
    [anon_sym_base] = ACTIONS(3049),
    [anon_sym_var] = ACTIONS(3049),
    [sym_predefined_type] = ACTIONS(3049),
    [anon_sym_break] = ACTIONS(3049),
    [anon_sym_unchecked] = ACTIONS(3049),
    [anon_sym_continue] = ACTIONS(3049),
    [anon_sym_do] = ACTIONS(3049),
    [anon_sym_while] = ACTIONS(3049),
    [anon_sym_for] = ACTIONS(3049),
    [anon_sym_lock] = ACTIONS(3049),
    [anon_sym_yield] = ACTIONS(3049),
    [anon_sym_switch] = ACTIONS(3049),
    [anon_sym_default] = ACTIONS(3049),
    [anon_sym_throw] = ACTIONS(3049),
    [anon_sym_try] = ACTIONS(3049),
    [anon_sym_when] = ACTIONS(3049),
    [anon_sym_await] = ACTIONS(3049),
    [anon_sym_foreach] = ACTIONS(3049),
    [anon_sym_goto] = ACTIONS(3049),
    [anon_sym_if] = ACTIONS(3049),
    [anon_sym_else] = ACTIONS(3049),
    [anon_sym_DOT_DOT] = ACTIONS(3051),
    [anon_sym_from] = ACTIONS(3049),
    [anon_sym_into] = ACTIONS(3049),
    [anon_sym_join] = ACTIONS(3049),
    [anon_sym_on] = ACTIONS(3049),
    [anon_sym_equals] = ACTIONS(3049),
    [anon_sym_let] = ACTIONS(3049),
    [anon_sym_orderby] = ACTIONS(3049),
    [anon_sym_ascending] = ACTIONS(3049),
    [anon_sym_descending] = ACTIONS(3049),
    [anon_sym_group] = ACTIONS(3049),
    [anon_sym_by] = ACTIONS(3049),
    [anon_sym_select] = ACTIONS(3049),
    [anon_sym_stackalloc] = ACTIONS(3049),
    [anon_sym_sizeof] = ACTIONS(3049),
    [anon_sym_typeof] = ACTIONS(3049),
    [anon_sym___makeref] = ACTIONS(3049),
    [anon_sym___reftype] = ACTIONS(3049),
    [anon_sym___refvalue] = ACTIONS(3049),
    [sym_null_literal] = ACTIONS(3049),
    [anon_sym_SQUOTE] = ACTIONS(3051),
    [sym_integer_literal] = ACTIONS(3049),
    [sym_real_literal] = ACTIONS(3051),
    [anon_sym_DQUOTE] = ACTIONS(3051),
    [sym_verbatim_string_literal] = ACTIONS(3051),
    [aux_sym_preproc_if_token1] = ACTIONS(3051),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3051),
    [sym_interpolation_verbatim_start] = ACTIONS(3051),
    [sym_interpolation_raw_start] = ACTIONS(3051),
    [sym_raw_string_start] = ACTIONS(3051),
  },
  [2478] = {
    [sym_preproc_region] = STATE(2478),
    [sym_preproc_endregion] = STATE(2478),
    [sym_preproc_line] = STATE(2478),
    [sym_preproc_pragma] = STATE(2478),
    [sym_preproc_nullable] = STATE(2478),
    [sym_preproc_error] = STATE(2478),
    [sym_preproc_warning] = STATE(2478),
    [sym_preproc_define] = STATE(2478),
    [sym_preproc_undef] = STATE(2478),
    [ts_builtin_sym_end] = ACTIONS(3395),
    [sym__identifier_token] = ACTIONS(3393),
    [anon_sym_extern] = ACTIONS(3393),
    [anon_sym_alias] = ACTIONS(3393),
    [anon_sym_SEMI] = ACTIONS(3395),
    [anon_sym_global] = ACTIONS(3393),
    [anon_sym_using] = ACTIONS(3393),
    [anon_sym_unsafe] = ACTIONS(3393),
    [anon_sym_static] = ACTIONS(3393),
    [anon_sym_LBRACK] = ACTIONS(3395),
    [anon_sym_LPAREN] = ACTIONS(3395),
    [anon_sym_return] = ACTIONS(3393),
    [anon_sym_namespace] = ACTIONS(3393),
    [anon_sym_class] = ACTIONS(3393),
    [anon_sym_ref] = ACTIONS(3393),
    [anon_sym_struct] = ACTIONS(3393),
    [anon_sym_enum] = ACTIONS(3393),
    [anon_sym_LBRACE] = ACTIONS(3395),
    [anon_sym_interface] = ACTIONS(3393),
    [anon_sym_delegate] = ACTIONS(3393),
    [anon_sym_record] = ACTIONS(3393),
    [anon_sym_abstract] = ACTIONS(3393),
    [anon_sym_async] = ACTIONS(3393),
    [anon_sym_const] = ACTIONS(3393),
    [anon_sym_file] = ACTIONS(3393),
    [anon_sym_fixed] = ACTIONS(3393),
    [anon_sym_internal] = ACTIONS(3393),
    [anon_sym_new] = ACTIONS(3393),
    [anon_sym_override] = ACTIONS(3393),
    [anon_sym_partial] = ACTIONS(3393),
    [anon_sym_private] = ACTIONS(3393),
    [anon_sym_protected] = ACTIONS(3393),
    [anon_sym_public] = ACTIONS(3393),
    [anon_sym_readonly] = ACTIONS(3393),
    [anon_sym_required] = ACTIONS(3393),
    [anon_sym_sealed] = ACTIONS(3393),
    [anon_sym_virtual] = ACTIONS(3393),
    [anon_sym_volatile] = ACTIONS(3393),
    [anon_sym_where] = ACTIONS(3393),
    [anon_sym_notnull] = ACTIONS(3393),
    [anon_sym_unmanaged] = ACTIONS(3393),
    [anon_sym_checked] = ACTIONS(3393),
    [anon_sym_BANG] = ACTIONS(3395),
    [anon_sym_TILDE] = ACTIONS(3395),
    [anon_sym_PLUS_PLUS] = ACTIONS(3395),
    [anon_sym_DASH_DASH] = ACTIONS(3395),
    [anon_sym_true] = ACTIONS(3393),
    [anon_sym_false] = ACTIONS(3393),
    [anon_sym_PLUS] = ACTIONS(3393),
    [anon_sym_DASH] = ACTIONS(3393),
    [anon_sym_STAR] = ACTIONS(3395),
    [anon_sym_CARET] = ACTIONS(3395),
    [anon_sym_AMP] = ACTIONS(3395),
    [anon_sym_this] = ACTIONS(3393),
    [anon_sym_scoped] = ACTIONS(3393),
    [anon_sym_base] = ACTIONS(3393),
    [anon_sym_var] = ACTIONS(3393),
    [sym_predefined_type] = ACTIONS(3393),
    [anon_sym_break] = ACTIONS(3393),
    [anon_sym_unchecked] = ACTIONS(3393),
    [anon_sym_continue] = ACTIONS(3393),
    [anon_sym_do] = ACTIONS(3393),
    [anon_sym_while] = ACTIONS(3393),
    [anon_sym_for] = ACTIONS(3393),
    [anon_sym_lock] = ACTIONS(3393),
    [anon_sym_yield] = ACTIONS(3393),
    [anon_sym_switch] = ACTIONS(3393),
    [anon_sym_default] = ACTIONS(3393),
    [anon_sym_throw] = ACTIONS(3393),
    [anon_sym_try] = ACTIONS(3393),
    [anon_sym_when] = ACTIONS(3393),
    [anon_sym_await] = ACTIONS(3393),
    [anon_sym_foreach] = ACTIONS(3393),
    [anon_sym_goto] = ACTIONS(3393),
    [anon_sym_if] = ACTIONS(3393),
    [anon_sym_else] = ACTIONS(3393),
    [anon_sym_DOT_DOT] = ACTIONS(3395),
    [anon_sym_from] = ACTIONS(3393),
    [anon_sym_into] = ACTIONS(3393),
    [anon_sym_join] = ACTIONS(3393),
    [anon_sym_on] = ACTIONS(3393),
    [anon_sym_equals] = ACTIONS(3393),
    [anon_sym_let] = ACTIONS(3393),
    [anon_sym_orderby] = ACTIONS(3393),
    [anon_sym_ascending] = ACTIONS(3393),
    [anon_sym_descending] = ACTIONS(3393),
    [anon_sym_group] = ACTIONS(3393),
    [anon_sym_by] = ACTIONS(3393),
    [anon_sym_select] = ACTIONS(3393),
    [anon_sym_stackalloc] = ACTIONS(3393),
    [anon_sym_sizeof] = ACTIONS(3393),
    [anon_sym_typeof] = ACTIONS(3393),
    [anon_sym___makeref] = ACTIONS(3393),
    [anon_sym___reftype] = ACTIONS(3393),
    [anon_sym___refvalue] = ACTIONS(3393),
    [sym_null_literal] = ACTIONS(3393),
    [anon_sym_SQUOTE] = ACTIONS(3395),
    [sym_integer_literal] = ACTIONS(3393),
    [sym_real_literal] = ACTIONS(3395),
    [anon_sym_DQUOTE] = ACTIONS(3395),
    [sym_verbatim_string_literal] = ACTIONS(3395),
    [aux_sym_preproc_if_token1] = ACTIONS(3395),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3395),
    [sym_interpolation_verbatim_start] = ACTIONS(3395),
    [sym_interpolation_raw_start] = ACTIONS(3395),
    [sym_raw_string_start] = ACTIONS(3395),
  },
  [2479] = {
    [sym_preproc_region] = STATE(2479),
    [sym_preproc_endregion] = STATE(2479),
    [sym_preproc_line] = STATE(2479),
    [sym_preproc_pragma] = STATE(2479),
    [sym_preproc_nullable] = STATE(2479),
    [sym_preproc_error] = STATE(2479),
    [sym_preproc_warning] = STATE(2479),
    [sym_preproc_define] = STATE(2479),
    [sym_preproc_undef] = STATE(2479),
    [ts_builtin_sym_end] = ACTIONS(3075),
    [sym__identifier_token] = ACTIONS(3073),
    [anon_sym_extern] = ACTIONS(3073),
    [anon_sym_alias] = ACTIONS(3073),
    [anon_sym_SEMI] = ACTIONS(3075),
    [anon_sym_global] = ACTIONS(3073),
    [anon_sym_using] = ACTIONS(3073),
    [anon_sym_unsafe] = ACTIONS(3073),
    [anon_sym_static] = ACTIONS(3073),
    [anon_sym_LBRACK] = ACTIONS(3075),
    [anon_sym_LPAREN] = ACTIONS(3075),
    [anon_sym_return] = ACTIONS(3073),
    [anon_sym_namespace] = ACTIONS(3073),
    [anon_sym_class] = ACTIONS(3073),
    [anon_sym_ref] = ACTIONS(3073),
    [anon_sym_struct] = ACTIONS(3073),
    [anon_sym_enum] = ACTIONS(3073),
    [anon_sym_LBRACE] = ACTIONS(3075),
    [anon_sym_interface] = ACTIONS(3073),
    [anon_sym_delegate] = ACTIONS(3073),
    [anon_sym_record] = ACTIONS(3073),
    [anon_sym_abstract] = ACTIONS(3073),
    [anon_sym_async] = ACTIONS(3073),
    [anon_sym_const] = ACTIONS(3073),
    [anon_sym_file] = ACTIONS(3073),
    [anon_sym_fixed] = ACTIONS(3073),
    [anon_sym_internal] = ACTIONS(3073),
    [anon_sym_new] = ACTIONS(3073),
    [anon_sym_override] = ACTIONS(3073),
    [anon_sym_partial] = ACTIONS(3073),
    [anon_sym_private] = ACTIONS(3073),
    [anon_sym_protected] = ACTIONS(3073),
    [anon_sym_public] = ACTIONS(3073),
    [anon_sym_readonly] = ACTIONS(3073),
    [anon_sym_required] = ACTIONS(3073),
    [anon_sym_sealed] = ACTIONS(3073),
    [anon_sym_virtual] = ACTIONS(3073),
    [anon_sym_volatile] = ACTIONS(3073),
    [anon_sym_where] = ACTIONS(3073),
    [anon_sym_notnull] = ACTIONS(3073),
    [anon_sym_unmanaged] = ACTIONS(3073),
    [anon_sym_checked] = ACTIONS(3073),
    [anon_sym_BANG] = ACTIONS(3075),
    [anon_sym_TILDE] = ACTIONS(3075),
    [anon_sym_PLUS_PLUS] = ACTIONS(3075),
    [anon_sym_DASH_DASH] = ACTIONS(3075),
    [anon_sym_true] = ACTIONS(3073),
    [anon_sym_false] = ACTIONS(3073),
    [anon_sym_PLUS] = ACTIONS(3073),
    [anon_sym_DASH] = ACTIONS(3073),
    [anon_sym_STAR] = ACTIONS(3075),
    [anon_sym_CARET] = ACTIONS(3075),
    [anon_sym_AMP] = ACTIONS(3075),
    [anon_sym_this] = ACTIONS(3073),
    [anon_sym_scoped] = ACTIONS(3073),
    [anon_sym_base] = ACTIONS(3073),
    [anon_sym_var] = ACTIONS(3073),
    [sym_predefined_type] = ACTIONS(3073),
    [anon_sym_break] = ACTIONS(3073),
    [anon_sym_unchecked] = ACTIONS(3073),
    [anon_sym_continue] = ACTIONS(3073),
    [anon_sym_do] = ACTIONS(3073),
    [anon_sym_while] = ACTIONS(3073),
    [anon_sym_for] = ACTIONS(3073),
    [anon_sym_lock] = ACTIONS(3073),
    [anon_sym_yield] = ACTIONS(3073),
    [anon_sym_switch] = ACTIONS(3073),
    [anon_sym_default] = ACTIONS(3073),
    [anon_sym_throw] = ACTIONS(3073),
    [anon_sym_try] = ACTIONS(3073),
    [anon_sym_when] = ACTIONS(3073),
    [anon_sym_await] = ACTIONS(3073),
    [anon_sym_foreach] = ACTIONS(3073),
    [anon_sym_goto] = ACTIONS(3073),
    [anon_sym_if] = ACTIONS(3073),
    [anon_sym_else] = ACTIONS(3073),
    [anon_sym_DOT_DOT] = ACTIONS(3075),
    [anon_sym_from] = ACTIONS(3073),
    [anon_sym_into] = ACTIONS(3073),
    [anon_sym_join] = ACTIONS(3073),
    [anon_sym_on] = ACTIONS(3073),
    [anon_sym_equals] = ACTIONS(3073),
    [anon_sym_let] = ACTIONS(3073),
    [anon_sym_orderby] = ACTIONS(3073),
    [anon_sym_ascending] = ACTIONS(3073),
    [anon_sym_descending] = ACTIONS(3073),
    [anon_sym_group] = ACTIONS(3073),
    [anon_sym_by] = ACTIONS(3073),
    [anon_sym_select] = ACTIONS(3073),
    [anon_sym_stackalloc] = ACTIONS(3073),
    [anon_sym_sizeof] = ACTIONS(3073),
    [anon_sym_typeof] = ACTIONS(3073),
    [anon_sym___makeref] = ACTIONS(3073),
    [anon_sym___reftype] = ACTIONS(3073),
    [anon_sym___refvalue] = ACTIONS(3073),
    [sym_null_literal] = ACTIONS(3073),
    [anon_sym_SQUOTE] = ACTIONS(3075),
    [sym_integer_literal] = ACTIONS(3073),
    [sym_real_literal] = ACTIONS(3075),
    [anon_sym_DQUOTE] = ACTIONS(3075),
    [sym_verbatim_string_literal] = ACTIONS(3075),
    [aux_sym_preproc_if_token1] = ACTIONS(3075),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3075),
    [sym_interpolation_verbatim_start] = ACTIONS(3075),
    [sym_interpolation_raw_start] = ACTIONS(3075),
    [sym_raw_string_start] = ACTIONS(3075),
  },
  [2480] = {
    [sym_preproc_region] = STATE(2480),
    [sym_preproc_endregion] = STATE(2480),
    [sym_preproc_line] = STATE(2480),
    [sym_preproc_pragma] = STATE(2480),
    [sym_preproc_nullable] = STATE(2480),
    [sym_preproc_error] = STATE(2480),
    [sym_preproc_warning] = STATE(2480),
    [sym_preproc_define] = STATE(2480),
    [sym_preproc_undef] = STATE(2480),
    [ts_builtin_sym_end] = ACTIONS(3345),
    [sym__identifier_token] = ACTIONS(3343),
    [anon_sym_extern] = ACTIONS(3343),
    [anon_sym_alias] = ACTIONS(3343),
    [anon_sym_SEMI] = ACTIONS(3345),
    [anon_sym_global] = ACTIONS(3343),
    [anon_sym_using] = ACTIONS(3343),
    [anon_sym_unsafe] = ACTIONS(3343),
    [anon_sym_static] = ACTIONS(3343),
    [anon_sym_LBRACK] = ACTIONS(3345),
    [anon_sym_LPAREN] = ACTIONS(3345),
    [anon_sym_return] = ACTIONS(3343),
    [anon_sym_namespace] = ACTIONS(3343),
    [anon_sym_class] = ACTIONS(3343),
    [anon_sym_ref] = ACTIONS(3343),
    [anon_sym_struct] = ACTIONS(3343),
    [anon_sym_enum] = ACTIONS(3343),
    [anon_sym_LBRACE] = ACTIONS(3345),
    [anon_sym_interface] = ACTIONS(3343),
    [anon_sym_delegate] = ACTIONS(3343),
    [anon_sym_record] = ACTIONS(3343),
    [anon_sym_abstract] = ACTIONS(3343),
    [anon_sym_async] = ACTIONS(3343),
    [anon_sym_const] = ACTIONS(3343),
    [anon_sym_file] = ACTIONS(3343),
    [anon_sym_fixed] = ACTIONS(3343),
    [anon_sym_internal] = ACTIONS(3343),
    [anon_sym_new] = ACTIONS(3343),
    [anon_sym_override] = ACTIONS(3343),
    [anon_sym_partial] = ACTIONS(3343),
    [anon_sym_private] = ACTIONS(3343),
    [anon_sym_protected] = ACTIONS(3343),
    [anon_sym_public] = ACTIONS(3343),
    [anon_sym_readonly] = ACTIONS(3343),
    [anon_sym_required] = ACTIONS(3343),
    [anon_sym_sealed] = ACTIONS(3343),
    [anon_sym_virtual] = ACTIONS(3343),
    [anon_sym_volatile] = ACTIONS(3343),
    [anon_sym_where] = ACTIONS(3343),
    [anon_sym_notnull] = ACTIONS(3343),
    [anon_sym_unmanaged] = ACTIONS(3343),
    [anon_sym_checked] = ACTIONS(3343),
    [anon_sym_BANG] = ACTIONS(3345),
    [anon_sym_TILDE] = ACTIONS(3345),
    [anon_sym_PLUS_PLUS] = ACTIONS(3345),
    [anon_sym_DASH_DASH] = ACTIONS(3345),
    [anon_sym_true] = ACTIONS(3343),
    [anon_sym_false] = ACTIONS(3343),
    [anon_sym_PLUS] = ACTIONS(3343),
    [anon_sym_DASH] = ACTIONS(3343),
    [anon_sym_STAR] = ACTIONS(3345),
    [anon_sym_CARET] = ACTIONS(3345),
    [anon_sym_AMP] = ACTIONS(3345),
    [anon_sym_this] = ACTIONS(3343),
    [anon_sym_scoped] = ACTIONS(3343),
    [anon_sym_base] = ACTIONS(3343),
    [anon_sym_var] = ACTIONS(3343),
    [sym_predefined_type] = ACTIONS(3343),
    [anon_sym_break] = ACTIONS(3343),
    [anon_sym_unchecked] = ACTIONS(3343),
    [anon_sym_continue] = ACTIONS(3343),
    [anon_sym_do] = ACTIONS(3343),
    [anon_sym_while] = ACTIONS(3343),
    [anon_sym_for] = ACTIONS(3343),
    [anon_sym_lock] = ACTIONS(3343),
    [anon_sym_yield] = ACTIONS(3343),
    [anon_sym_switch] = ACTIONS(3343),
    [anon_sym_default] = ACTIONS(3343),
    [anon_sym_throw] = ACTIONS(3343),
    [anon_sym_try] = ACTIONS(3343),
    [anon_sym_when] = ACTIONS(3343),
    [anon_sym_await] = ACTIONS(3343),
    [anon_sym_foreach] = ACTIONS(3343),
    [anon_sym_goto] = ACTIONS(3343),
    [anon_sym_if] = ACTIONS(3343),
    [anon_sym_else] = ACTIONS(3343),
    [anon_sym_DOT_DOT] = ACTIONS(3345),
    [anon_sym_from] = ACTIONS(3343),
    [anon_sym_into] = ACTIONS(3343),
    [anon_sym_join] = ACTIONS(3343),
    [anon_sym_on] = ACTIONS(3343),
    [anon_sym_equals] = ACTIONS(3343),
    [anon_sym_let] = ACTIONS(3343),
    [anon_sym_orderby] = ACTIONS(3343),
    [anon_sym_ascending] = ACTIONS(3343),
    [anon_sym_descending] = ACTIONS(3343),
    [anon_sym_group] = ACTIONS(3343),
    [anon_sym_by] = ACTIONS(3343),
    [anon_sym_select] = ACTIONS(3343),
    [anon_sym_stackalloc] = ACTIONS(3343),
    [anon_sym_sizeof] = ACTIONS(3343),
    [anon_sym_typeof] = ACTIONS(3343),
    [anon_sym___makeref] = ACTIONS(3343),
    [anon_sym___reftype] = ACTIONS(3343),
    [anon_sym___refvalue] = ACTIONS(3343),
    [sym_null_literal] = ACTIONS(3343),
    [anon_sym_SQUOTE] = ACTIONS(3345),
    [sym_integer_literal] = ACTIONS(3343),
    [sym_real_literal] = ACTIONS(3345),
    [anon_sym_DQUOTE] = ACTIONS(3345),
    [sym_verbatim_string_literal] = ACTIONS(3345),
    [aux_sym_preproc_if_token1] = ACTIONS(3345),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3345),
    [sym_interpolation_verbatim_start] = ACTIONS(3345),
    [sym_interpolation_raw_start] = ACTIONS(3345),
    [sym_raw_string_start] = ACTIONS(3345),
  },
  [2481] = {
    [sym_preproc_region] = STATE(2481),
    [sym_preproc_endregion] = STATE(2481),
    [sym_preproc_line] = STATE(2481),
    [sym_preproc_pragma] = STATE(2481),
    [sym_preproc_nullable] = STATE(2481),
    [sym_preproc_error] = STATE(2481),
    [sym_preproc_warning] = STATE(2481),
    [sym_preproc_define] = STATE(2481),
    [sym_preproc_undef] = STATE(2481),
    [ts_builtin_sym_end] = ACTIONS(3349),
    [sym__identifier_token] = ACTIONS(3347),
    [anon_sym_extern] = ACTIONS(3347),
    [anon_sym_alias] = ACTIONS(3347),
    [anon_sym_SEMI] = ACTIONS(3349),
    [anon_sym_global] = ACTIONS(3347),
    [anon_sym_using] = ACTIONS(3347),
    [anon_sym_unsafe] = ACTIONS(3347),
    [anon_sym_static] = ACTIONS(3347),
    [anon_sym_LBRACK] = ACTIONS(3349),
    [anon_sym_LPAREN] = ACTIONS(3349),
    [anon_sym_return] = ACTIONS(3347),
    [anon_sym_namespace] = ACTIONS(3347),
    [anon_sym_class] = ACTIONS(3347),
    [anon_sym_ref] = ACTIONS(3347),
    [anon_sym_struct] = ACTIONS(3347),
    [anon_sym_enum] = ACTIONS(3347),
    [anon_sym_LBRACE] = ACTIONS(3349),
    [anon_sym_interface] = ACTIONS(3347),
    [anon_sym_delegate] = ACTIONS(3347),
    [anon_sym_record] = ACTIONS(3347),
    [anon_sym_abstract] = ACTIONS(3347),
    [anon_sym_async] = ACTIONS(3347),
    [anon_sym_const] = ACTIONS(3347),
    [anon_sym_file] = ACTIONS(3347),
    [anon_sym_fixed] = ACTIONS(3347),
    [anon_sym_internal] = ACTIONS(3347),
    [anon_sym_new] = ACTIONS(3347),
    [anon_sym_override] = ACTIONS(3347),
    [anon_sym_partial] = ACTIONS(3347),
    [anon_sym_private] = ACTIONS(3347),
    [anon_sym_protected] = ACTIONS(3347),
    [anon_sym_public] = ACTIONS(3347),
    [anon_sym_readonly] = ACTIONS(3347),
    [anon_sym_required] = ACTIONS(3347),
    [anon_sym_sealed] = ACTIONS(3347),
    [anon_sym_virtual] = ACTIONS(3347),
    [anon_sym_volatile] = ACTIONS(3347),
    [anon_sym_where] = ACTIONS(3347),
    [anon_sym_notnull] = ACTIONS(3347),
    [anon_sym_unmanaged] = ACTIONS(3347),
    [anon_sym_checked] = ACTIONS(3347),
    [anon_sym_BANG] = ACTIONS(3349),
    [anon_sym_TILDE] = ACTIONS(3349),
    [anon_sym_PLUS_PLUS] = ACTIONS(3349),
    [anon_sym_DASH_DASH] = ACTIONS(3349),
    [anon_sym_true] = ACTIONS(3347),
    [anon_sym_false] = ACTIONS(3347),
    [anon_sym_PLUS] = ACTIONS(3347),
    [anon_sym_DASH] = ACTIONS(3347),
    [anon_sym_STAR] = ACTIONS(3349),
    [anon_sym_CARET] = ACTIONS(3349),
    [anon_sym_AMP] = ACTIONS(3349),
    [anon_sym_this] = ACTIONS(3347),
    [anon_sym_scoped] = ACTIONS(3347),
    [anon_sym_base] = ACTIONS(3347),
    [anon_sym_var] = ACTIONS(3347),
    [sym_predefined_type] = ACTIONS(3347),
    [anon_sym_break] = ACTIONS(3347),
    [anon_sym_unchecked] = ACTIONS(3347),
    [anon_sym_continue] = ACTIONS(3347),
    [anon_sym_do] = ACTIONS(3347),
    [anon_sym_while] = ACTIONS(3347),
    [anon_sym_for] = ACTIONS(3347),
    [anon_sym_lock] = ACTIONS(3347),
    [anon_sym_yield] = ACTIONS(3347),
    [anon_sym_switch] = ACTIONS(3347),
    [anon_sym_default] = ACTIONS(3347),
    [anon_sym_throw] = ACTIONS(3347),
    [anon_sym_try] = ACTIONS(3347),
    [anon_sym_when] = ACTIONS(3347),
    [anon_sym_await] = ACTIONS(3347),
    [anon_sym_foreach] = ACTIONS(3347),
    [anon_sym_goto] = ACTIONS(3347),
    [anon_sym_if] = ACTIONS(3347),
    [anon_sym_else] = ACTIONS(3347),
    [anon_sym_DOT_DOT] = ACTIONS(3349),
    [anon_sym_from] = ACTIONS(3347),
    [anon_sym_into] = ACTIONS(3347),
    [anon_sym_join] = ACTIONS(3347),
    [anon_sym_on] = ACTIONS(3347),
    [anon_sym_equals] = ACTIONS(3347),
    [anon_sym_let] = ACTIONS(3347),
    [anon_sym_orderby] = ACTIONS(3347),
    [anon_sym_ascending] = ACTIONS(3347),
    [anon_sym_descending] = ACTIONS(3347),
    [anon_sym_group] = ACTIONS(3347),
    [anon_sym_by] = ACTIONS(3347),
    [anon_sym_select] = ACTIONS(3347),
    [anon_sym_stackalloc] = ACTIONS(3347),
    [anon_sym_sizeof] = ACTIONS(3347),
    [anon_sym_typeof] = ACTIONS(3347),
    [anon_sym___makeref] = ACTIONS(3347),
    [anon_sym___reftype] = ACTIONS(3347),
    [anon_sym___refvalue] = ACTIONS(3347),
    [sym_null_literal] = ACTIONS(3347),
    [anon_sym_SQUOTE] = ACTIONS(3349),
    [sym_integer_literal] = ACTIONS(3347),
    [sym_real_literal] = ACTIONS(3349),
    [anon_sym_DQUOTE] = ACTIONS(3349),
    [sym_verbatim_string_literal] = ACTIONS(3349),
    [aux_sym_preproc_if_token1] = ACTIONS(3349),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3349),
    [sym_interpolation_verbatim_start] = ACTIONS(3349),
    [sym_interpolation_raw_start] = ACTIONS(3349),
    [sym_raw_string_start] = ACTIONS(3349),
  },
  [2482] = {
    [sym_preproc_region] = STATE(2482),
    [sym_preproc_endregion] = STATE(2482),
    [sym_preproc_line] = STATE(2482),
    [sym_preproc_pragma] = STATE(2482),
    [sym_preproc_nullable] = STATE(2482),
    [sym_preproc_error] = STATE(2482),
    [sym_preproc_warning] = STATE(2482),
    [sym_preproc_define] = STATE(2482),
    [sym_preproc_undef] = STATE(2482),
    [ts_builtin_sym_end] = ACTIONS(3079),
    [sym__identifier_token] = ACTIONS(3077),
    [anon_sym_extern] = ACTIONS(3077),
    [anon_sym_alias] = ACTIONS(3077),
    [anon_sym_SEMI] = ACTIONS(3079),
    [anon_sym_global] = ACTIONS(3077),
    [anon_sym_using] = ACTIONS(3077),
    [anon_sym_unsafe] = ACTIONS(3077),
    [anon_sym_static] = ACTIONS(3077),
    [anon_sym_LBRACK] = ACTIONS(3079),
    [anon_sym_LPAREN] = ACTIONS(3079),
    [anon_sym_return] = ACTIONS(3077),
    [anon_sym_namespace] = ACTIONS(3077),
    [anon_sym_class] = ACTIONS(3077),
    [anon_sym_ref] = ACTIONS(3077),
    [anon_sym_struct] = ACTIONS(3077),
    [anon_sym_enum] = ACTIONS(3077),
    [anon_sym_LBRACE] = ACTIONS(3079),
    [anon_sym_interface] = ACTIONS(3077),
    [anon_sym_delegate] = ACTIONS(3077),
    [anon_sym_record] = ACTIONS(3077),
    [anon_sym_abstract] = ACTIONS(3077),
    [anon_sym_async] = ACTIONS(3077),
    [anon_sym_const] = ACTIONS(3077),
    [anon_sym_file] = ACTIONS(3077),
    [anon_sym_fixed] = ACTIONS(3077),
    [anon_sym_internal] = ACTIONS(3077),
    [anon_sym_new] = ACTIONS(3077),
    [anon_sym_override] = ACTIONS(3077),
    [anon_sym_partial] = ACTIONS(3077),
    [anon_sym_private] = ACTIONS(3077),
    [anon_sym_protected] = ACTIONS(3077),
    [anon_sym_public] = ACTIONS(3077),
    [anon_sym_readonly] = ACTIONS(3077),
    [anon_sym_required] = ACTIONS(3077),
    [anon_sym_sealed] = ACTIONS(3077),
    [anon_sym_virtual] = ACTIONS(3077),
    [anon_sym_volatile] = ACTIONS(3077),
    [anon_sym_where] = ACTIONS(3077),
    [anon_sym_notnull] = ACTIONS(3077),
    [anon_sym_unmanaged] = ACTIONS(3077),
    [anon_sym_checked] = ACTIONS(3077),
    [anon_sym_BANG] = ACTIONS(3079),
    [anon_sym_TILDE] = ACTIONS(3079),
    [anon_sym_PLUS_PLUS] = ACTIONS(3079),
    [anon_sym_DASH_DASH] = ACTIONS(3079),
    [anon_sym_true] = ACTIONS(3077),
    [anon_sym_false] = ACTIONS(3077),
    [anon_sym_PLUS] = ACTIONS(3077),
    [anon_sym_DASH] = ACTIONS(3077),
    [anon_sym_STAR] = ACTIONS(3079),
    [anon_sym_CARET] = ACTIONS(3079),
    [anon_sym_AMP] = ACTIONS(3079),
    [anon_sym_this] = ACTIONS(3077),
    [anon_sym_scoped] = ACTIONS(3077),
    [anon_sym_base] = ACTIONS(3077),
    [anon_sym_var] = ACTIONS(3077),
    [sym_predefined_type] = ACTIONS(3077),
    [anon_sym_break] = ACTIONS(3077),
    [anon_sym_unchecked] = ACTIONS(3077),
    [anon_sym_continue] = ACTIONS(3077),
    [anon_sym_do] = ACTIONS(3077),
    [anon_sym_while] = ACTIONS(3077),
    [anon_sym_for] = ACTIONS(3077),
    [anon_sym_lock] = ACTIONS(3077),
    [anon_sym_yield] = ACTIONS(3077),
    [anon_sym_switch] = ACTIONS(3077),
    [anon_sym_default] = ACTIONS(3077),
    [anon_sym_throw] = ACTIONS(3077),
    [anon_sym_try] = ACTIONS(3077),
    [anon_sym_when] = ACTIONS(3077),
    [anon_sym_await] = ACTIONS(3077),
    [anon_sym_foreach] = ACTIONS(3077),
    [anon_sym_goto] = ACTIONS(3077),
    [anon_sym_if] = ACTIONS(3077),
    [anon_sym_else] = ACTIONS(3077),
    [anon_sym_DOT_DOT] = ACTIONS(3079),
    [anon_sym_from] = ACTIONS(3077),
    [anon_sym_into] = ACTIONS(3077),
    [anon_sym_join] = ACTIONS(3077),
    [anon_sym_on] = ACTIONS(3077),
    [anon_sym_equals] = ACTIONS(3077),
    [anon_sym_let] = ACTIONS(3077),
    [anon_sym_orderby] = ACTIONS(3077),
    [anon_sym_ascending] = ACTIONS(3077),
    [anon_sym_descending] = ACTIONS(3077),
    [anon_sym_group] = ACTIONS(3077),
    [anon_sym_by] = ACTIONS(3077),
    [anon_sym_select] = ACTIONS(3077),
    [anon_sym_stackalloc] = ACTIONS(3077),
    [anon_sym_sizeof] = ACTIONS(3077),
    [anon_sym_typeof] = ACTIONS(3077),
    [anon_sym___makeref] = ACTIONS(3077),
    [anon_sym___reftype] = ACTIONS(3077),
    [anon_sym___refvalue] = ACTIONS(3077),
    [sym_null_literal] = ACTIONS(3077),
    [anon_sym_SQUOTE] = ACTIONS(3079),
    [sym_integer_literal] = ACTIONS(3077),
    [sym_real_literal] = ACTIONS(3079),
    [anon_sym_DQUOTE] = ACTIONS(3079),
    [sym_verbatim_string_literal] = ACTIONS(3079),
    [aux_sym_preproc_if_token1] = ACTIONS(3079),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3079),
    [sym_interpolation_verbatim_start] = ACTIONS(3079),
    [sym_interpolation_raw_start] = ACTIONS(3079),
    [sym_raw_string_start] = ACTIONS(3079),
  },
  [2483] = {
    [sym_preproc_region] = STATE(2483),
    [sym_preproc_endregion] = STATE(2483),
    [sym_preproc_line] = STATE(2483),
    [sym_preproc_pragma] = STATE(2483),
    [sym_preproc_nullable] = STATE(2483),
    [sym_preproc_error] = STATE(2483),
    [sym_preproc_warning] = STATE(2483),
    [sym_preproc_define] = STATE(2483),
    [sym_preproc_undef] = STATE(2483),
    [ts_builtin_sym_end] = ACTIONS(3353),
    [sym__identifier_token] = ACTIONS(3351),
    [anon_sym_extern] = ACTIONS(3351),
    [anon_sym_alias] = ACTIONS(3351),
    [anon_sym_SEMI] = ACTIONS(3353),
    [anon_sym_global] = ACTIONS(3351),
    [anon_sym_using] = ACTIONS(3351),
    [anon_sym_unsafe] = ACTIONS(3351),
    [anon_sym_static] = ACTIONS(3351),
    [anon_sym_LBRACK] = ACTIONS(3353),
    [anon_sym_LPAREN] = ACTIONS(3353),
    [anon_sym_return] = ACTIONS(3351),
    [anon_sym_namespace] = ACTIONS(3351),
    [anon_sym_class] = ACTIONS(3351),
    [anon_sym_ref] = ACTIONS(3351),
    [anon_sym_struct] = ACTIONS(3351),
    [anon_sym_enum] = ACTIONS(3351),
    [anon_sym_LBRACE] = ACTIONS(3353),
    [anon_sym_interface] = ACTIONS(3351),
    [anon_sym_delegate] = ACTIONS(3351),
    [anon_sym_record] = ACTIONS(3351),
    [anon_sym_abstract] = ACTIONS(3351),
    [anon_sym_async] = ACTIONS(3351),
    [anon_sym_const] = ACTIONS(3351),
    [anon_sym_file] = ACTIONS(3351),
    [anon_sym_fixed] = ACTIONS(3351),
    [anon_sym_internal] = ACTIONS(3351),
    [anon_sym_new] = ACTIONS(3351),
    [anon_sym_override] = ACTIONS(3351),
    [anon_sym_partial] = ACTIONS(3351),
    [anon_sym_private] = ACTIONS(3351),
    [anon_sym_protected] = ACTIONS(3351),
    [anon_sym_public] = ACTIONS(3351),
    [anon_sym_readonly] = ACTIONS(3351),
    [anon_sym_required] = ACTIONS(3351),
    [anon_sym_sealed] = ACTIONS(3351),
    [anon_sym_virtual] = ACTIONS(3351),
    [anon_sym_volatile] = ACTIONS(3351),
    [anon_sym_where] = ACTIONS(3351),
    [anon_sym_notnull] = ACTIONS(3351),
    [anon_sym_unmanaged] = ACTIONS(3351),
    [anon_sym_checked] = ACTIONS(3351),
    [anon_sym_BANG] = ACTIONS(3353),
    [anon_sym_TILDE] = ACTIONS(3353),
    [anon_sym_PLUS_PLUS] = ACTIONS(3353),
    [anon_sym_DASH_DASH] = ACTIONS(3353),
    [anon_sym_true] = ACTIONS(3351),
    [anon_sym_false] = ACTIONS(3351),
    [anon_sym_PLUS] = ACTIONS(3351),
    [anon_sym_DASH] = ACTIONS(3351),
    [anon_sym_STAR] = ACTIONS(3353),
    [anon_sym_CARET] = ACTIONS(3353),
    [anon_sym_AMP] = ACTIONS(3353),
    [anon_sym_this] = ACTIONS(3351),
    [anon_sym_scoped] = ACTIONS(3351),
    [anon_sym_base] = ACTIONS(3351),
    [anon_sym_var] = ACTIONS(3351),
    [sym_predefined_type] = ACTIONS(3351),
    [anon_sym_break] = ACTIONS(3351),
    [anon_sym_unchecked] = ACTIONS(3351),
    [anon_sym_continue] = ACTIONS(3351),
    [anon_sym_do] = ACTIONS(3351),
    [anon_sym_while] = ACTIONS(3351),
    [anon_sym_for] = ACTIONS(3351),
    [anon_sym_lock] = ACTIONS(3351),
    [anon_sym_yield] = ACTIONS(3351),
    [anon_sym_switch] = ACTIONS(3351),
    [anon_sym_default] = ACTIONS(3351),
    [anon_sym_throw] = ACTIONS(3351),
    [anon_sym_try] = ACTIONS(3351),
    [anon_sym_when] = ACTIONS(3351),
    [anon_sym_await] = ACTIONS(3351),
    [anon_sym_foreach] = ACTIONS(3351),
    [anon_sym_goto] = ACTIONS(3351),
    [anon_sym_if] = ACTIONS(3351),
    [anon_sym_else] = ACTIONS(3351),
    [anon_sym_DOT_DOT] = ACTIONS(3353),
    [anon_sym_from] = ACTIONS(3351),
    [anon_sym_into] = ACTIONS(3351),
    [anon_sym_join] = ACTIONS(3351),
    [anon_sym_on] = ACTIONS(3351),
    [anon_sym_equals] = ACTIONS(3351),
    [anon_sym_let] = ACTIONS(3351),
    [anon_sym_orderby] = ACTIONS(3351),
    [anon_sym_ascending] = ACTIONS(3351),
    [anon_sym_descending] = ACTIONS(3351),
    [anon_sym_group] = ACTIONS(3351),
    [anon_sym_by] = ACTIONS(3351),
    [anon_sym_select] = ACTIONS(3351),
    [anon_sym_stackalloc] = ACTIONS(3351),
    [anon_sym_sizeof] = ACTIONS(3351),
    [anon_sym_typeof] = ACTIONS(3351),
    [anon_sym___makeref] = ACTIONS(3351),
    [anon_sym___reftype] = ACTIONS(3351),
    [anon_sym___refvalue] = ACTIONS(3351),
    [sym_null_literal] = ACTIONS(3351),
    [anon_sym_SQUOTE] = ACTIONS(3353),
    [sym_integer_literal] = ACTIONS(3351),
    [sym_real_literal] = ACTIONS(3353),
    [anon_sym_DQUOTE] = ACTIONS(3353),
    [sym_verbatim_string_literal] = ACTIONS(3353),
    [aux_sym_preproc_if_token1] = ACTIONS(3353),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3353),
    [sym_interpolation_verbatim_start] = ACTIONS(3353),
    [sym_interpolation_raw_start] = ACTIONS(3353),
    [sym_raw_string_start] = ACTIONS(3353),
  },
  [2484] = {
    [sym_preproc_region] = STATE(2484),
    [sym_preproc_endregion] = STATE(2484),
    [sym_preproc_line] = STATE(2484),
    [sym_preproc_pragma] = STATE(2484),
    [sym_preproc_nullable] = STATE(2484),
    [sym_preproc_error] = STATE(2484),
    [sym_preproc_warning] = STATE(2484),
    [sym_preproc_define] = STATE(2484),
    [sym_preproc_undef] = STATE(2484),
    [ts_builtin_sym_end] = ACTIONS(3171),
    [sym__identifier_token] = ACTIONS(3169),
    [anon_sym_extern] = ACTIONS(3169),
    [anon_sym_alias] = ACTIONS(3169),
    [anon_sym_SEMI] = ACTIONS(3171),
    [anon_sym_global] = ACTIONS(3169),
    [anon_sym_using] = ACTIONS(3169),
    [anon_sym_unsafe] = ACTIONS(3169),
    [anon_sym_static] = ACTIONS(3169),
    [anon_sym_LBRACK] = ACTIONS(3171),
    [anon_sym_LPAREN] = ACTIONS(3171),
    [anon_sym_return] = ACTIONS(3169),
    [anon_sym_namespace] = ACTIONS(3169),
    [anon_sym_class] = ACTIONS(3169),
    [anon_sym_ref] = ACTIONS(3169),
    [anon_sym_struct] = ACTIONS(3169),
    [anon_sym_enum] = ACTIONS(3169),
    [anon_sym_LBRACE] = ACTIONS(3171),
    [anon_sym_interface] = ACTIONS(3169),
    [anon_sym_delegate] = ACTIONS(3169),
    [anon_sym_record] = ACTIONS(3169),
    [anon_sym_abstract] = ACTIONS(3169),
    [anon_sym_async] = ACTIONS(3169),
    [anon_sym_const] = ACTIONS(3169),
    [anon_sym_file] = ACTIONS(3169),
    [anon_sym_fixed] = ACTIONS(3169),
    [anon_sym_internal] = ACTIONS(3169),
    [anon_sym_new] = ACTIONS(3169),
    [anon_sym_override] = ACTIONS(3169),
    [anon_sym_partial] = ACTIONS(3169),
    [anon_sym_private] = ACTIONS(3169),
    [anon_sym_protected] = ACTIONS(3169),
    [anon_sym_public] = ACTIONS(3169),
    [anon_sym_readonly] = ACTIONS(3169),
    [anon_sym_required] = ACTIONS(3169),
    [anon_sym_sealed] = ACTIONS(3169),
    [anon_sym_virtual] = ACTIONS(3169),
    [anon_sym_volatile] = ACTIONS(3169),
    [anon_sym_where] = ACTIONS(3169),
    [anon_sym_notnull] = ACTIONS(3169),
    [anon_sym_unmanaged] = ACTIONS(3169),
    [anon_sym_checked] = ACTIONS(3169),
    [anon_sym_BANG] = ACTIONS(3171),
    [anon_sym_TILDE] = ACTIONS(3171),
    [anon_sym_PLUS_PLUS] = ACTIONS(3171),
    [anon_sym_DASH_DASH] = ACTIONS(3171),
    [anon_sym_true] = ACTIONS(3169),
    [anon_sym_false] = ACTIONS(3169),
    [anon_sym_PLUS] = ACTIONS(3169),
    [anon_sym_DASH] = ACTIONS(3169),
    [anon_sym_STAR] = ACTIONS(3171),
    [anon_sym_CARET] = ACTIONS(3171),
    [anon_sym_AMP] = ACTIONS(3171),
    [anon_sym_this] = ACTIONS(3169),
    [anon_sym_scoped] = ACTIONS(3169),
    [anon_sym_base] = ACTIONS(3169),
    [anon_sym_var] = ACTIONS(3169),
    [sym_predefined_type] = ACTIONS(3169),
    [anon_sym_break] = ACTIONS(3169),
    [anon_sym_unchecked] = ACTIONS(3169),
    [anon_sym_continue] = ACTIONS(3169),
    [anon_sym_do] = ACTIONS(3169),
    [anon_sym_while] = ACTIONS(3169),
    [anon_sym_for] = ACTIONS(3169),
    [anon_sym_lock] = ACTIONS(3169),
    [anon_sym_yield] = ACTIONS(3169),
    [anon_sym_switch] = ACTIONS(3169),
    [anon_sym_default] = ACTIONS(3169),
    [anon_sym_throw] = ACTIONS(3169),
    [anon_sym_try] = ACTIONS(3169),
    [anon_sym_when] = ACTIONS(3169),
    [anon_sym_await] = ACTIONS(3169),
    [anon_sym_foreach] = ACTIONS(3169),
    [anon_sym_goto] = ACTIONS(3169),
    [anon_sym_if] = ACTIONS(3169),
    [anon_sym_else] = ACTIONS(3169),
    [anon_sym_DOT_DOT] = ACTIONS(3171),
    [anon_sym_from] = ACTIONS(3169),
    [anon_sym_into] = ACTIONS(3169),
    [anon_sym_join] = ACTIONS(3169),
    [anon_sym_on] = ACTIONS(3169),
    [anon_sym_equals] = ACTIONS(3169),
    [anon_sym_let] = ACTIONS(3169),
    [anon_sym_orderby] = ACTIONS(3169),
    [anon_sym_ascending] = ACTIONS(3169),
    [anon_sym_descending] = ACTIONS(3169),
    [anon_sym_group] = ACTIONS(3169),
    [anon_sym_by] = ACTIONS(3169),
    [anon_sym_select] = ACTIONS(3169),
    [anon_sym_stackalloc] = ACTIONS(3169),
    [anon_sym_sizeof] = ACTIONS(3169),
    [anon_sym_typeof] = ACTIONS(3169),
    [anon_sym___makeref] = ACTIONS(3169),
    [anon_sym___reftype] = ACTIONS(3169),
    [anon_sym___refvalue] = ACTIONS(3169),
    [sym_null_literal] = ACTIONS(3169),
    [anon_sym_SQUOTE] = ACTIONS(3171),
    [sym_integer_literal] = ACTIONS(3169),
    [sym_real_literal] = ACTIONS(3171),
    [anon_sym_DQUOTE] = ACTIONS(3171),
    [sym_verbatim_string_literal] = ACTIONS(3171),
    [aux_sym_preproc_if_token1] = ACTIONS(3171),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3171),
    [sym_interpolation_verbatim_start] = ACTIONS(3171),
    [sym_interpolation_raw_start] = ACTIONS(3171),
    [sym_raw_string_start] = ACTIONS(3171),
  },
  [2485] = {
    [sym_preproc_region] = STATE(2485),
    [sym_preproc_endregion] = STATE(2485),
    [sym_preproc_line] = STATE(2485),
    [sym_preproc_pragma] = STATE(2485),
    [sym_preproc_nullable] = STATE(2485),
    [sym_preproc_error] = STATE(2485),
    [sym_preproc_warning] = STATE(2485),
    [sym_preproc_define] = STATE(2485),
    [sym_preproc_undef] = STATE(2485),
    [ts_builtin_sym_end] = ACTIONS(3115),
    [sym__identifier_token] = ACTIONS(3113),
    [anon_sym_extern] = ACTIONS(3113),
    [anon_sym_alias] = ACTIONS(3113),
    [anon_sym_SEMI] = ACTIONS(3115),
    [anon_sym_global] = ACTIONS(3113),
    [anon_sym_using] = ACTIONS(3113),
    [anon_sym_unsafe] = ACTIONS(3113),
    [anon_sym_static] = ACTIONS(3113),
    [anon_sym_LBRACK] = ACTIONS(3115),
    [anon_sym_LPAREN] = ACTIONS(3115),
    [anon_sym_return] = ACTIONS(3113),
    [anon_sym_namespace] = ACTIONS(3113),
    [anon_sym_class] = ACTIONS(3113),
    [anon_sym_ref] = ACTIONS(3113),
    [anon_sym_struct] = ACTIONS(3113),
    [anon_sym_enum] = ACTIONS(3113),
    [anon_sym_LBRACE] = ACTIONS(3115),
    [anon_sym_interface] = ACTIONS(3113),
    [anon_sym_delegate] = ACTIONS(3113),
    [anon_sym_record] = ACTIONS(3113),
    [anon_sym_abstract] = ACTIONS(3113),
    [anon_sym_async] = ACTIONS(3113),
    [anon_sym_const] = ACTIONS(3113),
    [anon_sym_file] = ACTIONS(3113),
    [anon_sym_fixed] = ACTIONS(3113),
    [anon_sym_internal] = ACTIONS(3113),
    [anon_sym_new] = ACTIONS(3113),
    [anon_sym_override] = ACTIONS(3113),
    [anon_sym_partial] = ACTIONS(3113),
    [anon_sym_private] = ACTIONS(3113),
    [anon_sym_protected] = ACTIONS(3113),
    [anon_sym_public] = ACTIONS(3113),
    [anon_sym_readonly] = ACTIONS(3113),
    [anon_sym_required] = ACTIONS(3113),
    [anon_sym_sealed] = ACTIONS(3113),
    [anon_sym_virtual] = ACTIONS(3113),
    [anon_sym_volatile] = ACTIONS(3113),
    [anon_sym_where] = ACTIONS(3113),
    [anon_sym_notnull] = ACTIONS(3113),
    [anon_sym_unmanaged] = ACTIONS(3113),
    [anon_sym_checked] = ACTIONS(3113),
    [anon_sym_BANG] = ACTIONS(3115),
    [anon_sym_TILDE] = ACTIONS(3115),
    [anon_sym_PLUS_PLUS] = ACTIONS(3115),
    [anon_sym_DASH_DASH] = ACTIONS(3115),
    [anon_sym_true] = ACTIONS(3113),
    [anon_sym_false] = ACTIONS(3113),
    [anon_sym_PLUS] = ACTIONS(3113),
    [anon_sym_DASH] = ACTIONS(3113),
    [anon_sym_STAR] = ACTIONS(3115),
    [anon_sym_CARET] = ACTIONS(3115),
    [anon_sym_AMP] = ACTIONS(3115),
    [anon_sym_this] = ACTIONS(3113),
    [anon_sym_scoped] = ACTIONS(3113),
    [anon_sym_base] = ACTIONS(3113),
    [anon_sym_var] = ACTIONS(3113),
    [sym_predefined_type] = ACTIONS(3113),
    [anon_sym_break] = ACTIONS(3113),
    [anon_sym_unchecked] = ACTIONS(3113),
    [anon_sym_continue] = ACTIONS(3113),
    [anon_sym_do] = ACTIONS(3113),
    [anon_sym_while] = ACTIONS(3113),
    [anon_sym_for] = ACTIONS(3113),
    [anon_sym_lock] = ACTIONS(3113),
    [anon_sym_yield] = ACTIONS(3113),
    [anon_sym_switch] = ACTIONS(3113),
    [anon_sym_default] = ACTIONS(3113),
    [anon_sym_throw] = ACTIONS(3113),
    [anon_sym_try] = ACTIONS(3113),
    [anon_sym_when] = ACTIONS(3113),
    [anon_sym_await] = ACTIONS(3113),
    [anon_sym_foreach] = ACTIONS(3113),
    [anon_sym_goto] = ACTIONS(3113),
    [anon_sym_if] = ACTIONS(3113),
    [anon_sym_else] = ACTIONS(3113),
    [anon_sym_DOT_DOT] = ACTIONS(3115),
    [anon_sym_from] = ACTIONS(3113),
    [anon_sym_into] = ACTIONS(3113),
    [anon_sym_join] = ACTIONS(3113),
    [anon_sym_on] = ACTIONS(3113),
    [anon_sym_equals] = ACTIONS(3113),
    [anon_sym_let] = ACTIONS(3113),
    [anon_sym_orderby] = ACTIONS(3113),
    [anon_sym_ascending] = ACTIONS(3113),
    [anon_sym_descending] = ACTIONS(3113),
    [anon_sym_group] = ACTIONS(3113),
    [anon_sym_by] = ACTIONS(3113),
    [anon_sym_select] = ACTIONS(3113),
    [anon_sym_stackalloc] = ACTIONS(3113),
    [anon_sym_sizeof] = ACTIONS(3113),
    [anon_sym_typeof] = ACTIONS(3113),
    [anon_sym___makeref] = ACTIONS(3113),
    [anon_sym___reftype] = ACTIONS(3113),
    [anon_sym___refvalue] = ACTIONS(3113),
    [sym_null_literal] = ACTIONS(3113),
    [anon_sym_SQUOTE] = ACTIONS(3115),
    [sym_integer_literal] = ACTIONS(3113),
    [sym_real_literal] = ACTIONS(3115),
    [anon_sym_DQUOTE] = ACTIONS(3115),
    [sym_verbatim_string_literal] = ACTIONS(3115),
    [aux_sym_preproc_if_token1] = ACTIONS(3115),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3115),
    [sym_interpolation_verbatim_start] = ACTIONS(3115),
    [sym_interpolation_raw_start] = ACTIONS(3115),
    [sym_raw_string_start] = ACTIONS(3115),
  },
  [2486] = {
    [sym_preproc_region] = STATE(2486),
    [sym_preproc_endregion] = STATE(2486),
    [sym_preproc_line] = STATE(2486),
    [sym_preproc_pragma] = STATE(2486),
    [sym_preproc_nullable] = STATE(2486),
    [sym_preproc_error] = STATE(2486),
    [sym_preproc_warning] = STATE(2486),
    [sym_preproc_define] = STATE(2486),
    [sym_preproc_undef] = STATE(2486),
    [ts_builtin_sym_end] = ACTIONS(3119),
    [sym__identifier_token] = ACTIONS(3117),
    [anon_sym_extern] = ACTIONS(3117),
    [anon_sym_alias] = ACTIONS(3117),
    [anon_sym_SEMI] = ACTIONS(3119),
    [anon_sym_global] = ACTIONS(3117),
    [anon_sym_using] = ACTIONS(3117),
    [anon_sym_unsafe] = ACTIONS(3117),
    [anon_sym_static] = ACTIONS(3117),
    [anon_sym_LBRACK] = ACTIONS(3119),
    [anon_sym_LPAREN] = ACTIONS(3119),
    [anon_sym_return] = ACTIONS(3117),
    [anon_sym_namespace] = ACTIONS(3117),
    [anon_sym_class] = ACTIONS(3117),
    [anon_sym_ref] = ACTIONS(3117),
    [anon_sym_struct] = ACTIONS(3117),
    [anon_sym_enum] = ACTIONS(3117),
    [anon_sym_LBRACE] = ACTIONS(3119),
    [anon_sym_interface] = ACTIONS(3117),
    [anon_sym_delegate] = ACTIONS(3117),
    [anon_sym_record] = ACTIONS(3117),
    [anon_sym_abstract] = ACTIONS(3117),
    [anon_sym_async] = ACTIONS(3117),
    [anon_sym_const] = ACTIONS(3117),
    [anon_sym_file] = ACTIONS(3117),
    [anon_sym_fixed] = ACTIONS(3117),
    [anon_sym_internal] = ACTIONS(3117),
    [anon_sym_new] = ACTIONS(3117),
    [anon_sym_override] = ACTIONS(3117),
    [anon_sym_partial] = ACTIONS(3117),
    [anon_sym_private] = ACTIONS(3117),
    [anon_sym_protected] = ACTIONS(3117),
    [anon_sym_public] = ACTIONS(3117),
    [anon_sym_readonly] = ACTIONS(3117),
    [anon_sym_required] = ACTIONS(3117),
    [anon_sym_sealed] = ACTIONS(3117),
    [anon_sym_virtual] = ACTIONS(3117),
    [anon_sym_volatile] = ACTIONS(3117),
    [anon_sym_where] = ACTIONS(3117),
    [anon_sym_notnull] = ACTIONS(3117),
    [anon_sym_unmanaged] = ACTIONS(3117),
    [anon_sym_checked] = ACTIONS(3117),
    [anon_sym_BANG] = ACTIONS(3119),
    [anon_sym_TILDE] = ACTIONS(3119),
    [anon_sym_PLUS_PLUS] = ACTIONS(3119),
    [anon_sym_DASH_DASH] = ACTIONS(3119),
    [anon_sym_true] = ACTIONS(3117),
    [anon_sym_false] = ACTIONS(3117),
    [anon_sym_PLUS] = ACTIONS(3117),
    [anon_sym_DASH] = ACTIONS(3117),
    [anon_sym_STAR] = ACTIONS(3119),
    [anon_sym_CARET] = ACTIONS(3119),
    [anon_sym_AMP] = ACTIONS(3119),
    [anon_sym_this] = ACTIONS(3117),
    [anon_sym_scoped] = ACTIONS(3117),
    [anon_sym_base] = ACTIONS(3117),
    [anon_sym_var] = ACTIONS(3117),
    [sym_predefined_type] = ACTIONS(3117),
    [anon_sym_break] = ACTIONS(3117),
    [anon_sym_unchecked] = ACTIONS(3117),
    [anon_sym_continue] = ACTIONS(3117),
    [anon_sym_do] = ACTIONS(3117),
    [anon_sym_while] = ACTIONS(3117),
    [anon_sym_for] = ACTIONS(3117),
    [anon_sym_lock] = ACTIONS(3117),
    [anon_sym_yield] = ACTIONS(3117),
    [anon_sym_switch] = ACTIONS(3117),
    [anon_sym_default] = ACTIONS(3117),
    [anon_sym_throw] = ACTIONS(3117),
    [anon_sym_try] = ACTIONS(3117),
    [anon_sym_when] = ACTIONS(3117),
    [anon_sym_await] = ACTIONS(3117),
    [anon_sym_foreach] = ACTIONS(3117),
    [anon_sym_goto] = ACTIONS(3117),
    [anon_sym_if] = ACTIONS(3117),
    [anon_sym_else] = ACTIONS(3117),
    [anon_sym_DOT_DOT] = ACTIONS(3119),
    [anon_sym_from] = ACTIONS(3117),
    [anon_sym_into] = ACTIONS(3117),
    [anon_sym_join] = ACTIONS(3117),
    [anon_sym_on] = ACTIONS(3117),
    [anon_sym_equals] = ACTIONS(3117),
    [anon_sym_let] = ACTIONS(3117),
    [anon_sym_orderby] = ACTIONS(3117),
    [anon_sym_ascending] = ACTIONS(3117),
    [anon_sym_descending] = ACTIONS(3117),
    [anon_sym_group] = ACTIONS(3117),
    [anon_sym_by] = ACTIONS(3117),
    [anon_sym_select] = ACTIONS(3117),
    [anon_sym_stackalloc] = ACTIONS(3117),
    [anon_sym_sizeof] = ACTIONS(3117),
    [anon_sym_typeof] = ACTIONS(3117),
    [anon_sym___makeref] = ACTIONS(3117),
    [anon_sym___reftype] = ACTIONS(3117),
    [anon_sym___refvalue] = ACTIONS(3117),
    [sym_null_literal] = ACTIONS(3117),
    [anon_sym_SQUOTE] = ACTIONS(3119),
    [sym_integer_literal] = ACTIONS(3117),
    [sym_real_literal] = ACTIONS(3119),
    [anon_sym_DQUOTE] = ACTIONS(3119),
    [sym_verbatim_string_literal] = ACTIONS(3119),
    [aux_sym_preproc_if_token1] = ACTIONS(3119),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3119),
    [sym_interpolation_verbatim_start] = ACTIONS(3119),
    [sym_interpolation_raw_start] = ACTIONS(3119),
    [sym_raw_string_start] = ACTIONS(3119),
  },
  [2487] = {
    [sym_preproc_region] = STATE(2487),
    [sym_preproc_endregion] = STATE(2487),
    [sym_preproc_line] = STATE(2487),
    [sym_preproc_pragma] = STATE(2487),
    [sym_preproc_nullable] = STATE(2487),
    [sym_preproc_error] = STATE(2487),
    [sym_preproc_warning] = STATE(2487),
    [sym_preproc_define] = STATE(2487),
    [sym_preproc_undef] = STATE(2487),
    [ts_builtin_sym_end] = ACTIONS(3371),
    [sym__identifier_token] = ACTIONS(3369),
    [anon_sym_extern] = ACTIONS(3369),
    [anon_sym_alias] = ACTIONS(3369),
    [anon_sym_SEMI] = ACTIONS(3371),
    [anon_sym_global] = ACTIONS(3369),
    [anon_sym_using] = ACTIONS(3369),
    [anon_sym_unsafe] = ACTIONS(3369),
    [anon_sym_static] = ACTIONS(3369),
    [anon_sym_LBRACK] = ACTIONS(3371),
    [anon_sym_LPAREN] = ACTIONS(3371),
    [anon_sym_return] = ACTIONS(3369),
    [anon_sym_namespace] = ACTIONS(3369),
    [anon_sym_class] = ACTIONS(3369),
    [anon_sym_ref] = ACTIONS(3369),
    [anon_sym_struct] = ACTIONS(3369),
    [anon_sym_enum] = ACTIONS(3369),
    [anon_sym_LBRACE] = ACTIONS(3371),
    [anon_sym_interface] = ACTIONS(3369),
    [anon_sym_delegate] = ACTIONS(3369),
    [anon_sym_record] = ACTIONS(3369),
    [anon_sym_abstract] = ACTIONS(3369),
    [anon_sym_async] = ACTIONS(3369),
    [anon_sym_const] = ACTIONS(3369),
    [anon_sym_file] = ACTIONS(3369),
    [anon_sym_fixed] = ACTIONS(3369),
    [anon_sym_internal] = ACTIONS(3369),
    [anon_sym_new] = ACTIONS(3369),
    [anon_sym_override] = ACTIONS(3369),
    [anon_sym_partial] = ACTIONS(3369),
    [anon_sym_private] = ACTIONS(3369),
    [anon_sym_protected] = ACTIONS(3369),
    [anon_sym_public] = ACTIONS(3369),
    [anon_sym_readonly] = ACTIONS(3369),
    [anon_sym_required] = ACTIONS(3369),
    [anon_sym_sealed] = ACTIONS(3369),
    [anon_sym_virtual] = ACTIONS(3369),
    [anon_sym_volatile] = ACTIONS(3369),
    [anon_sym_where] = ACTIONS(3369),
    [anon_sym_notnull] = ACTIONS(3369),
    [anon_sym_unmanaged] = ACTIONS(3369),
    [anon_sym_checked] = ACTIONS(3369),
    [anon_sym_BANG] = ACTIONS(3371),
    [anon_sym_TILDE] = ACTIONS(3371),
    [anon_sym_PLUS_PLUS] = ACTIONS(3371),
    [anon_sym_DASH_DASH] = ACTIONS(3371),
    [anon_sym_true] = ACTIONS(3369),
    [anon_sym_false] = ACTIONS(3369),
    [anon_sym_PLUS] = ACTIONS(3369),
    [anon_sym_DASH] = ACTIONS(3369),
    [anon_sym_STAR] = ACTIONS(3371),
    [anon_sym_CARET] = ACTIONS(3371),
    [anon_sym_AMP] = ACTIONS(3371),
    [anon_sym_this] = ACTIONS(3369),
    [anon_sym_scoped] = ACTIONS(3369),
    [anon_sym_base] = ACTIONS(3369),
    [anon_sym_var] = ACTIONS(3369),
    [sym_predefined_type] = ACTIONS(3369),
    [anon_sym_break] = ACTIONS(3369),
    [anon_sym_unchecked] = ACTIONS(3369),
    [anon_sym_continue] = ACTIONS(3369),
    [anon_sym_do] = ACTIONS(3369),
    [anon_sym_while] = ACTIONS(3369),
    [anon_sym_for] = ACTIONS(3369),
    [anon_sym_lock] = ACTIONS(3369),
    [anon_sym_yield] = ACTIONS(3369),
    [anon_sym_switch] = ACTIONS(3369),
    [anon_sym_default] = ACTIONS(3369),
    [anon_sym_throw] = ACTIONS(3369),
    [anon_sym_try] = ACTIONS(3369),
    [anon_sym_when] = ACTIONS(3369),
    [anon_sym_await] = ACTIONS(3369),
    [anon_sym_foreach] = ACTIONS(3369),
    [anon_sym_goto] = ACTIONS(3369),
    [anon_sym_if] = ACTIONS(3369),
    [anon_sym_else] = ACTIONS(3369),
    [anon_sym_DOT_DOT] = ACTIONS(3371),
    [anon_sym_from] = ACTIONS(3369),
    [anon_sym_into] = ACTIONS(3369),
    [anon_sym_join] = ACTIONS(3369),
    [anon_sym_on] = ACTIONS(3369),
    [anon_sym_equals] = ACTIONS(3369),
    [anon_sym_let] = ACTIONS(3369),
    [anon_sym_orderby] = ACTIONS(3369),
    [anon_sym_ascending] = ACTIONS(3369),
    [anon_sym_descending] = ACTIONS(3369),
    [anon_sym_group] = ACTIONS(3369),
    [anon_sym_by] = ACTIONS(3369),
    [anon_sym_select] = ACTIONS(3369),
    [anon_sym_stackalloc] = ACTIONS(3369),
    [anon_sym_sizeof] = ACTIONS(3369),
    [anon_sym_typeof] = ACTIONS(3369),
    [anon_sym___makeref] = ACTIONS(3369),
    [anon_sym___reftype] = ACTIONS(3369),
    [anon_sym___refvalue] = ACTIONS(3369),
    [sym_null_literal] = ACTIONS(3369),
    [anon_sym_SQUOTE] = ACTIONS(3371),
    [sym_integer_literal] = ACTIONS(3369),
    [sym_real_literal] = ACTIONS(3371),
    [anon_sym_DQUOTE] = ACTIONS(3371),
    [sym_verbatim_string_literal] = ACTIONS(3371),
    [aux_sym_preproc_if_token1] = ACTIONS(3371),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3371),
    [sym_interpolation_verbatim_start] = ACTIONS(3371),
    [sym_interpolation_raw_start] = ACTIONS(3371),
    [sym_raw_string_start] = ACTIONS(3371),
  },
  [2488] = {
    [sym_preproc_region] = STATE(2488),
    [sym_preproc_endregion] = STATE(2488),
    [sym_preproc_line] = STATE(2488),
    [sym_preproc_pragma] = STATE(2488),
    [sym_preproc_nullable] = STATE(2488),
    [sym_preproc_error] = STATE(2488),
    [sym_preproc_warning] = STATE(2488),
    [sym_preproc_define] = STATE(2488),
    [sym_preproc_undef] = STATE(2488),
    [ts_builtin_sym_end] = ACTIONS(3379),
    [sym__identifier_token] = ACTIONS(3377),
    [anon_sym_extern] = ACTIONS(3377),
    [anon_sym_alias] = ACTIONS(3377),
    [anon_sym_SEMI] = ACTIONS(3379),
    [anon_sym_global] = ACTIONS(3377),
    [anon_sym_using] = ACTIONS(3377),
    [anon_sym_unsafe] = ACTIONS(3377),
    [anon_sym_static] = ACTIONS(3377),
    [anon_sym_LBRACK] = ACTIONS(3379),
    [anon_sym_LPAREN] = ACTIONS(3379),
    [anon_sym_return] = ACTIONS(3377),
    [anon_sym_namespace] = ACTIONS(3377),
    [anon_sym_class] = ACTIONS(3377),
    [anon_sym_ref] = ACTIONS(3377),
    [anon_sym_struct] = ACTIONS(3377),
    [anon_sym_enum] = ACTIONS(3377),
    [anon_sym_LBRACE] = ACTIONS(3379),
    [anon_sym_interface] = ACTIONS(3377),
    [anon_sym_delegate] = ACTIONS(3377),
    [anon_sym_record] = ACTIONS(3377),
    [anon_sym_abstract] = ACTIONS(3377),
    [anon_sym_async] = ACTIONS(3377),
    [anon_sym_const] = ACTIONS(3377),
    [anon_sym_file] = ACTIONS(3377),
    [anon_sym_fixed] = ACTIONS(3377),
    [anon_sym_internal] = ACTIONS(3377),
    [anon_sym_new] = ACTIONS(3377),
    [anon_sym_override] = ACTIONS(3377),
    [anon_sym_partial] = ACTIONS(3377),
    [anon_sym_private] = ACTIONS(3377),
    [anon_sym_protected] = ACTIONS(3377),
    [anon_sym_public] = ACTIONS(3377),
    [anon_sym_readonly] = ACTIONS(3377),
    [anon_sym_required] = ACTIONS(3377),
    [anon_sym_sealed] = ACTIONS(3377),
    [anon_sym_virtual] = ACTIONS(3377),
    [anon_sym_volatile] = ACTIONS(3377),
    [anon_sym_where] = ACTIONS(3377),
    [anon_sym_notnull] = ACTIONS(3377),
    [anon_sym_unmanaged] = ACTIONS(3377),
    [anon_sym_checked] = ACTIONS(3377),
    [anon_sym_BANG] = ACTIONS(3379),
    [anon_sym_TILDE] = ACTIONS(3379),
    [anon_sym_PLUS_PLUS] = ACTIONS(3379),
    [anon_sym_DASH_DASH] = ACTIONS(3379),
    [anon_sym_true] = ACTIONS(3377),
    [anon_sym_false] = ACTIONS(3377),
    [anon_sym_PLUS] = ACTIONS(3377),
    [anon_sym_DASH] = ACTIONS(3377),
    [anon_sym_STAR] = ACTIONS(3379),
    [anon_sym_CARET] = ACTIONS(3379),
    [anon_sym_AMP] = ACTIONS(3379),
    [anon_sym_this] = ACTIONS(3377),
    [anon_sym_scoped] = ACTIONS(3377),
    [anon_sym_base] = ACTIONS(3377),
    [anon_sym_var] = ACTIONS(3377),
    [sym_predefined_type] = ACTIONS(3377),
    [anon_sym_break] = ACTIONS(3377),
    [anon_sym_unchecked] = ACTIONS(3377),
    [anon_sym_continue] = ACTIONS(3377),
    [anon_sym_do] = ACTIONS(3377),
    [anon_sym_while] = ACTIONS(3377),
    [anon_sym_for] = ACTIONS(3377),
    [anon_sym_lock] = ACTIONS(3377),
    [anon_sym_yield] = ACTIONS(3377),
    [anon_sym_switch] = ACTIONS(3377),
    [anon_sym_default] = ACTIONS(3377),
    [anon_sym_throw] = ACTIONS(3377),
    [anon_sym_try] = ACTIONS(3377),
    [anon_sym_when] = ACTIONS(3377),
    [anon_sym_await] = ACTIONS(3377),
    [anon_sym_foreach] = ACTIONS(3377),
    [anon_sym_goto] = ACTIONS(3377),
    [anon_sym_if] = ACTIONS(3377),
    [anon_sym_else] = ACTIONS(3377),
    [anon_sym_DOT_DOT] = ACTIONS(3379),
    [anon_sym_from] = ACTIONS(3377),
    [anon_sym_into] = ACTIONS(3377),
    [anon_sym_join] = ACTIONS(3377),
    [anon_sym_on] = ACTIONS(3377),
    [anon_sym_equals] = ACTIONS(3377),
    [anon_sym_let] = ACTIONS(3377),
    [anon_sym_orderby] = ACTIONS(3377),
    [anon_sym_ascending] = ACTIONS(3377),
    [anon_sym_descending] = ACTIONS(3377),
    [anon_sym_group] = ACTIONS(3377),
    [anon_sym_by] = ACTIONS(3377),
    [anon_sym_select] = ACTIONS(3377),
    [anon_sym_stackalloc] = ACTIONS(3377),
    [anon_sym_sizeof] = ACTIONS(3377),
    [anon_sym_typeof] = ACTIONS(3377),
    [anon_sym___makeref] = ACTIONS(3377),
    [anon_sym___reftype] = ACTIONS(3377),
    [anon_sym___refvalue] = ACTIONS(3377),
    [sym_null_literal] = ACTIONS(3377),
    [anon_sym_SQUOTE] = ACTIONS(3379),
    [sym_integer_literal] = ACTIONS(3377),
    [sym_real_literal] = ACTIONS(3379),
    [anon_sym_DQUOTE] = ACTIONS(3379),
    [sym_verbatim_string_literal] = ACTIONS(3379),
    [aux_sym_preproc_if_token1] = ACTIONS(3379),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3379),
    [sym_interpolation_verbatim_start] = ACTIONS(3379),
    [sym_interpolation_raw_start] = ACTIONS(3379),
    [sym_raw_string_start] = ACTIONS(3379),
  },
  [2489] = {
    [sym_preproc_region] = STATE(2489),
    [sym_preproc_endregion] = STATE(2489),
    [sym_preproc_line] = STATE(2489),
    [sym_preproc_pragma] = STATE(2489),
    [sym_preproc_nullable] = STATE(2489),
    [sym_preproc_error] = STATE(2489),
    [sym_preproc_warning] = STATE(2489),
    [sym_preproc_define] = STATE(2489),
    [sym_preproc_undef] = STATE(2489),
    [ts_builtin_sym_end] = ACTIONS(3123),
    [sym__identifier_token] = ACTIONS(3121),
    [anon_sym_extern] = ACTIONS(3121),
    [anon_sym_alias] = ACTIONS(3121),
    [anon_sym_SEMI] = ACTIONS(3123),
    [anon_sym_global] = ACTIONS(3121),
    [anon_sym_using] = ACTIONS(3121),
    [anon_sym_unsafe] = ACTIONS(3121),
    [anon_sym_static] = ACTIONS(3121),
    [anon_sym_LBRACK] = ACTIONS(3123),
    [anon_sym_LPAREN] = ACTIONS(3123),
    [anon_sym_return] = ACTIONS(3121),
    [anon_sym_namespace] = ACTIONS(3121),
    [anon_sym_class] = ACTIONS(3121),
    [anon_sym_ref] = ACTIONS(3121),
    [anon_sym_struct] = ACTIONS(3121),
    [anon_sym_enum] = ACTIONS(3121),
    [anon_sym_LBRACE] = ACTIONS(3123),
    [anon_sym_interface] = ACTIONS(3121),
    [anon_sym_delegate] = ACTIONS(3121),
    [anon_sym_record] = ACTIONS(3121),
    [anon_sym_abstract] = ACTIONS(3121),
    [anon_sym_async] = ACTIONS(3121),
    [anon_sym_const] = ACTIONS(3121),
    [anon_sym_file] = ACTIONS(3121),
    [anon_sym_fixed] = ACTIONS(3121),
    [anon_sym_internal] = ACTIONS(3121),
    [anon_sym_new] = ACTIONS(3121),
    [anon_sym_override] = ACTIONS(3121),
    [anon_sym_partial] = ACTIONS(3121),
    [anon_sym_private] = ACTIONS(3121),
    [anon_sym_protected] = ACTIONS(3121),
    [anon_sym_public] = ACTIONS(3121),
    [anon_sym_readonly] = ACTIONS(3121),
    [anon_sym_required] = ACTIONS(3121),
    [anon_sym_sealed] = ACTIONS(3121),
    [anon_sym_virtual] = ACTIONS(3121),
    [anon_sym_volatile] = ACTIONS(3121),
    [anon_sym_where] = ACTIONS(3121),
    [anon_sym_notnull] = ACTIONS(3121),
    [anon_sym_unmanaged] = ACTIONS(3121),
    [anon_sym_checked] = ACTIONS(3121),
    [anon_sym_BANG] = ACTIONS(3123),
    [anon_sym_TILDE] = ACTIONS(3123),
    [anon_sym_PLUS_PLUS] = ACTIONS(3123),
    [anon_sym_DASH_DASH] = ACTIONS(3123),
    [anon_sym_true] = ACTIONS(3121),
    [anon_sym_false] = ACTIONS(3121),
    [anon_sym_PLUS] = ACTIONS(3121),
    [anon_sym_DASH] = ACTIONS(3121),
    [anon_sym_STAR] = ACTIONS(3123),
    [anon_sym_CARET] = ACTIONS(3123),
    [anon_sym_AMP] = ACTIONS(3123),
    [anon_sym_this] = ACTIONS(3121),
    [anon_sym_scoped] = ACTIONS(3121),
    [anon_sym_base] = ACTIONS(3121),
    [anon_sym_var] = ACTIONS(3121),
    [sym_predefined_type] = ACTIONS(3121),
    [anon_sym_break] = ACTIONS(3121),
    [anon_sym_unchecked] = ACTIONS(3121),
    [anon_sym_continue] = ACTIONS(3121),
    [anon_sym_do] = ACTIONS(3121),
    [anon_sym_while] = ACTIONS(3121),
    [anon_sym_for] = ACTIONS(3121),
    [anon_sym_lock] = ACTIONS(3121),
    [anon_sym_yield] = ACTIONS(3121),
    [anon_sym_switch] = ACTIONS(3121),
    [anon_sym_default] = ACTIONS(3121),
    [anon_sym_throw] = ACTIONS(3121),
    [anon_sym_try] = ACTIONS(3121),
    [anon_sym_when] = ACTIONS(3121),
    [anon_sym_await] = ACTIONS(3121),
    [anon_sym_foreach] = ACTIONS(3121),
    [anon_sym_goto] = ACTIONS(3121),
    [anon_sym_if] = ACTIONS(3121),
    [anon_sym_else] = ACTIONS(3121),
    [anon_sym_DOT_DOT] = ACTIONS(3123),
    [anon_sym_from] = ACTIONS(3121),
    [anon_sym_into] = ACTIONS(3121),
    [anon_sym_join] = ACTIONS(3121),
    [anon_sym_on] = ACTIONS(3121),
    [anon_sym_equals] = ACTIONS(3121),
    [anon_sym_let] = ACTIONS(3121),
    [anon_sym_orderby] = ACTIONS(3121),
    [anon_sym_ascending] = ACTIONS(3121),
    [anon_sym_descending] = ACTIONS(3121),
    [anon_sym_group] = ACTIONS(3121),
    [anon_sym_by] = ACTIONS(3121),
    [anon_sym_select] = ACTIONS(3121),
    [anon_sym_stackalloc] = ACTIONS(3121),
    [anon_sym_sizeof] = ACTIONS(3121),
    [anon_sym_typeof] = ACTIONS(3121),
    [anon_sym___makeref] = ACTIONS(3121),
    [anon_sym___reftype] = ACTIONS(3121),
    [anon_sym___refvalue] = ACTIONS(3121),
    [sym_null_literal] = ACTIONS(3121),
    [anon_sym_SQUOTE] = ACTIONS(3123),
    [sym_integer_literal] = ACTIONS(3121),
    [sym_real_literal] = ACTIONS(3123),
    [anon_sym_DQUOTE] = ACTIONS(3123),
    [sym_verbatim_string_literal] = ACTIONS(3123),
    [aux_sym_preproc_if_token1] = ACTIONS(3123),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3123),
    [sym_interpolation_verbatim_start] = ACTIONS(3123),
    [sym_interpolation_raw_start] = ACTIONS(3123),
    [sym_raw_string_start] = ACTIONS(3123),
  },
  [2490] = {
    [sym_preproc_region] = STATE(2490),
    [sym_preproc_endregion] = STATE(2490),
    [sym_preproc_line] = STATE(2490),
    [sym_preproc_pragma] = STATE(2490),
    [sym_preproc_nullable] = STATE(2490),
    [sym_preproc_error] = STATE(2490),
    [sym_preproc_warning] = STATE(2490),
    [sym_preproc_define] = STATE(2490),
    [sym_preproc_undef] = STATE(2490),
    [ts_builtin_sym_end] = ACTIONS(3127),
    [sym__identifier_token] = ACTIONS(3125),
    [anon_sym_extern] = ACTIONS(3125),
    [anon_sym_alias] = ACTIONS(3125),
    [anon_sym_SEMI] = ACTIONS(3127),
    [anon_sym_global] = ACTIONS(3125),
    [anon_sym_using] = ACTIONS(3125),
    [anon_sym_unsafe] = ACTIONS(3125),
    [anon_sym_static] = ACTIONS(3125),
    [anon_sym_LBRACK] = ACTIONS(3127),
    [anon_sym_LPAREN] = ACTIONS(3127),
    [anon_sym_return] = ACTIONS(3125),
    [anon_sym_namespace] = ACTIONS(3125),
    [anon_sym_class] = ACTIONS(3125),
    [anon_sym_ref] = ACTIONS(3125),
    [anon_sym_struct] = ACTIONS(3125),
    [anon_sym_enum] = ACTIONS(3125),
    [anon_sym_LBRACE] = ACTIONS(3127),
    [anon_sym_interface] = ACTIONS(3125),
    [anon_sym_delegate] = ACTIONS(3125),
    [anon_sym_record] = ACTIONS(3125),
    [anon_sym_abstract] = ACTIONS(3125),
    [anon_sym_async] = ACTIONS(3125),
    [anon_sym_const] = ACTIONS(3125),
    [anon_sym_file] = ACTIONS(3125),
    [anon_sym_fixed] = ACTIONS(3125),
    [anon_sym_internal] = ACTIONS(3125),
    [anon_sym_new] = ACTIONS(3125),
    [anon_sym_override] = ACTIONS(3125),
    [anon_sym_partial] = ACTIONS(3125),
    [anon_sym_private] = ACTIONS(3125),
    [anon_sym_protected] = ACTIONS(3125),
    [anon_sym_public] = ACTIONS(3125),
    [anon_sym_readonly] = ACTIONS(3125),
    [anon_sym_required] = ACTIONS(3125),
    [anon_sym_sealed] = ACTIONS(3125),
    [anon_sym_virtual] = ACTIONS(3125),
    [anon_sym_volatile] = ACTIONS(3125),
    [anon_sym_where] = ACTIONS(3125),
    [anon_sym_notnull] = ACTIONS(3125),
    [anon_sym_unmanaged] = ACTIONS(3125),
    [anon_sym_checked] = ACTIONS(3125),
    [anon_sym_BANG] = ACTIONS(3127),
    [anon_sym_TILDE] = ACTIONS(3127),
    [anon_sym_PLUS_PLUS] = ACTIONS(3127),
    [anon_sym_DASH_DASH] = ACTIONS(3127),
    [anon_sym_true] = ACTIONS(3125),
    [anon_sym_false] = ACTIONS(3125),
    [anon_sym_PLUS] = ACTIONS(3125),
    [anon_sym_DASH] = ACTIONS(3125),
    [anon_sym_STAR] = ACTIONS(3127),
    [anon_sym_CARET] = ACTIONS(3127),
    [anon_sym_AMP] = ACTIONS(3127),
    [anon_sym_this] = ACTIONS(3125),
    [anon_sym_scoped] = ACTIONS(3125),
    [anon_sym_base] = ACTIONS(3125),
    [anon_sym_var] = ACTIONS(3125),
    [sym_predefined_type] = ACTIONS(3125),
    [anon_sym_break] = ACTIONS(3125),
    [anon_sym_unchecked] = ACTIONS(3125),
    [anon_sym_continue] = ACTIONS(3125),
    [anon_sym_do] = ACTIONS(3125),
    [anon_sym_while] = ACTIONS(3125),
    [anon_sym_for] = ACTIONS(3125),
    [anon_sym_lock] = ACTIONS(3125),
    [anon_sym_yield] = ACTIONS(3125),
    [anon_sym_switch] = ACTIONS(3125),
    [anon_sym_default] = ACTIONS(3125),
    [anon_sym_throw] = ACTIONS(3125),
    [anon_sym_try] = ACTIONS(3125),
    [anon_sym_when] = ACTIONS(3125),
    [anon_sym_await] = ACTIONS(3125),
    [anon_sym_foreach] = ACTIONS(3125),
    [anon_sym_goto] = ACTIONS(3125),
    [anon_sym_if] = ACTIONS(3125),
    [anon_sym_else] = ACTIONS(3125),
    [anon_sym_DOT_DOT] = ACTIONS(3127),
    [anon_sym_from] = ACTIONS(3125),
    [anon_sym_into] = ACTIONS(3125),
    [anon_sym_join] = ACTIONS(3125),
    [anon_sym_on] = ACTIONS(3125),
    [anon_sym_equals] = ACTIONS(3125),
    [anon_sym_let] = ACTIONS(3125),
    [anon_sym_orderby] = ACTIONS(3125),
    [anon_sym_ascending] = ACTIONS(3125),
    [anon_sym_descending] = ACTIONS(3125),
    [anon_sym_group] = ACTIONS(3125),
    [anon_sym_by] = ACTIONS(3125),
    [anon_sym_select] = ACTIONS(3125),
    [anon_sym_stackalloc] = ACTIONS(3125),
    [anon_sym_sizeof] = ACTIONS(3125),
    [anon_sym_typeof] = ACTIONS(3125),
    [anon_sym___makeref] = ACTIONS(3125),
    [anon_sym___reftype] = ACTIONS(3125),
    [anon_sym___refvalue] = ACTIONS(3125),
    [sym_null_literal] = ACTIONS(3125),
    [anon_sym_SQUOTE] = ACTIONS(3127),
    [sym_integer_literal] = ACTIONS(3125),
    [sym_real_literal] = ACTIONS(3127),
    [anon_sym_DQUOTE] = ACTIONS(3127),
    [sym_verbatim_string_literal] = ACTIONS(3127),
    [aux_sym_preproc_if_token1] = ACTIONS(3127),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3127),
    [sym_interpolation_verbatim_start] = ACTIONS(3127),
    [sym_interpolation_raw_start] = ACTIONS(3127),
    [sym_raw_string_start] = ACTIONS(3127),
  },
  [2491] = {
    [sym_preproc_region] = STATE(2491),
    [sym_preproc_endregion] = STATE(2491),
    [sym_preproc_line] = STATE(2491),
    [sym_preproc_pragma] = STATE(2491),
    [sym_preproc_nullable] = STATE(2491),
    [sym_preproc_error] = STATE(2491),
    [sym_preproc_warning] = STATE(2491),
    [sym_preproc_define] = STATE(2491),
    [sym_preproc_undef] = STATE(2491),
    [ts_builtin_sym_end] = ACTIONS(3159),
    [sym__identifier_token] = ACTIONS(3157),
    [anon_sym_extern] = ACTIONS(3157),
    [anon_sym_alias] = ACTIONS(3157),
    [anon_sym_SEMI] = ACTIONS(3159),
    [anon_sym_global] = ACTIONS(3157),
    [anon_sym_using] = ACTIONS(3157),
    [anon_sym_unsafe] = ACTIONS(3157),
    [anon_sym_static] = ACTIONS(3157),
    [anon_sym_LBRACK] = ACTIONS(3159),
    [anon_sym_LPAREN] = ACTIONS(3159),
    [anon_sym_return] = ACTIONS(3157),
    [anon_sym_namespace] = ACTIONS(3157),
    [anon_sym_class] = ACTIONS(3157),
    [anon_sym_ref] = ACTIONS(3157),
    [anon_sym_struct] = ACTIONS(3157),
    [anon_sym_enum] = ACTIONS(3157),
    [anon_sym_LBRACE] = ACTIONS(3159),
    [anon_sym_interface] = ACTIONS(3157),
    [anon_sym_delegate] = ACTIONS(3157),
    [anon_sym_record] = ACTIONS(3157),
    [anon_sym_abstract] = ACTIONS(3157),
    [anon_sym_async] = ACTIONS(3157),
    [anon_sym_const] = ACTIONS(3157),
    [anon_sym_file] = ACTIONS(3157),
    [anon_sym_fixed] = ACTIONS(3157),
    [anon_sym_internal] = ACTIONS(3157),
    [anon_sym_new] = ACTIONS(3157),
    [anon_sym_override] = ACTIONS(3157),
    [anon_sym_partial] = ACTIONS(3157),
    [anon_sym_private] = ACTIONS(3157),
    [anon_sym_protected] = ACTIONS(3157),
    [anon_sym_public] = ACTIONS(3157),
    [anon_sym_readonly] = ACTIONS(3157),
    [anon_sym_required] = ACTIONS(3157),
    [anon_sym_sealed] = ACTIONS(3157),
    [anon_sym_virtual] = ACTIONS(3157),
    [anon_sym_volatile] = ACTIONS(3157),
    [anon_sym_where] = ACTIONS(3157),
    [anon_sym_notnull] = ACTIONS(3157),
    [anon_sym_unmanaged] = ACTIONS(3157),
    [anon_sym_checked] = ACTIONS(3157),
    [anon_sym_BANG] = ACTIONS(3159),
    [anon_sym_TILDE] = ACTIONS(3159),
    [anon_sym_PLUS_PLUS] = ACTIONS(3159),
    [anon_sym_DASH_DASH] = ACTIONS(3159),
    [anon_sym_true] = ACTIONS(3157),
    [anon_sym_false] = ACTIONS(3157),
    [anon_sym_PLUS] = ACTIONS(3157),
    [anon_sym_DASH] = ACTIONS(3157),
    [anon_sym_STAR] = ACTIONS(3159),
    [anon_sym_CARET] = ACTIONS(3159),
    [anon_sym_AMP] = ACTIONS(3159),
    [anon_sym_this] = ACTIONS(3157),
    [anon_sym_scoped] = ACTIONS(3157),
    [anon_sym_base] = ACTIONS(3157),
    [anon_sym_var] = ACTIONS(3157),
    [sym_predefined_type] = ACTIONS(3157),
    [anon_sym_break] = ACTIONS(3157),
    [anon_sym_unchecked] = ACTIONS(3157),
    [anon_sym_continue] = ACTIONS(3157),
    [anon_sym_do] = ACTIONS(3157),
    [anon_sym_while] = ACTIONS(3157),
    [anon_sym_for] = ACTIONS(3157),
    [anon_sym_lock] = ACTIONS(3157),
    [anon_sym_yield] = ACTIONS(3157),
    [anon_sym_switch] = ACTIONS(3157),
    [anon_sym_default] = ACTIONS(3157),
    [anon_sym_throw] = ACTIONS(3157),
    [anon_sym_try] = ACTIONS(3157),
    [anon_sym_when] = ACTIONS(3157),
    [anon_sym_await] = ACTIONS(3157),
    [anon_sym_foreach] = ACTIONS(3157),
    [anon_sym_goto] = ACTIONS(3157),
    [anon_sym_if] = ACTIONS(3157),
    [anon_sym_else] = ACTIONS(3157),
    [anon_sym_DOT_DOT] = ACTIONS(3159),
    [anon_sym_from] = ACTIONS(3157),
    [anon_sym_into] = ACTIONS(3157),
    [anon_sym_join] = ACTIONS(3157),
    [anon_sym_on] = ACTIONS(3157),
    [anon_sym_equals] = ACTIONS(3157),
    [anon_sym_let] = ACTIONS(3157),
    [anon_sym_orderby] = ACTIONS(3157),
    [anon_sym_ascending] = ACTIONS(3157),
    [anon_sym_descending] = ACTIONS(3157),
    [anon_sym_group] = ACTIONS(3157),
    [anon_sym_by] = ACTIONS(3157),
    [anon_sym_select] = ACTIONS(3157),
    [anon_sym_stackalloc] = ACTIONS(3157),
    [anon_sym_sizeof] = ACTIONS(3157),
    [anon_sym_typeof] = ACTIONS(3157),
    [anon_sym___makeref] = ACTIONS(3157),
    [anon_sym___reftype] = ACTIONS(3157),
    [anon_sym___refvalue] = ACTIONS(3157),
    [sym_null_literal] = ACTIONS(3157),
    [anon_sym_SQUOTE] = ACTIONS(3159),
    [sym_integer_literal] = ACTIONS(3157),
    [sym_real_literal] = ACTIONS(3159),
    [anon_sym_DQUOTE] = ACTIONS(3159),
    [sym_verbatim_string_literal] = ACTIONS(3159),
    [aux_sym_preproc_if_token1] = ACTIONS(3159),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3159),
    [sym_interpolation_verbatim_start] = ACTIONS(3159),
    [sym_interpolation_raw_start] = ACTIONS(3159),
    [sym_raw_string_start] = ACTIONS(3159),
  },
  [2492] = {
    [sym_preproc_region] = STATE(2492),
    [sym_preproc_endregion] = STATE(2492),
    [sym_preproc_line] = STATE(2492),
    [sym_preproc_pragma] = STATE(2492),
    [sym_preproc_nullable] = STATE(2492),
    [sym_preproc_error] = STATE(2492),
    [sym_preproc_warning] = STATE(2492),
    [sym_preproc_define] = STATE(2492),
    [sym_preproc_undef] = STATE(2492),
    [ts_builtin_sym_end] = ACTIONS(3083),
    [sym__identifier_token] = ACTIONS(3081),
    [anon_sym_extern] = ACTIONS(3081),
    [anon_sym_alias] = ACTIONS(3081),
    [anon_sym_SEMI] = ACTIONS(3083),
    [anon_sym_global] = ACTIONS(3081),
    [anon_sym_using] = ACTIONS(3081),
    [anon_sym_unsafe] = ACTIONS(3081),
    [anon_sym_static] = ACTIONS(3081),
    [anon_sym_LBRACK] = ACTIONS(3083),
    [anon_sym_LPAREN] = ACTIONS(3083),
    [anon_sym_return] = ACTIONS(3081),
    [anon_sym_namespace] = ACTIONS(3081),
    [anon_sym_class] = ACTIONS(3081),
    [anon_sym_ref] = ACTIONS(3081),
    [anon_sym_struct] = ACTIONS(3081),
    [anon_sym_enum] = ACTIONS(3081),
    [anon_sym_LBRACE] = ACTIONS(3083),
    [anon_sym_interface] = ACTIONS(3081),
    [anon_sym_delegate] = ACTIONS(3081),
    [anon_sym_record] = ACTIONS(3081),
    [anon_sym_abstract] = ACTIONS(3081),
    [anon_sym_async] = ACTIONS(3081),
    [anon_sym_const] = ACTIONS(3081),
    [anon_sym_file] = ACTIONS(3081),
    [anon_sym_fixed] = ACTIONS(3081),
    [anon_sym_internal] = ACTIONS(3081),
    [anon_sym_new] = ACTIONS(3081),
    [anon_sym_override] = ACTIONS(3081),
    [anon_sym_partial] = ACTIONS(3081),
    [anon_sym_private] = ACTIONS(3081),
    [anon_sym_protected] = ACTIONS(3081),
    [anon_sym_public] = ACTIONS(3081),
    [anon_sym_readonly] = ACTIONS(3081),
    [anon_sym_required] = ACTIONS(3081),
    [anon_sym_sealed] = ACTIONS(3081),
    [anon_sym_virtual] = ACTIONS(3081),
    [anon_sym_volatile] = ACTIONS(3081),
    [anon_sym_where] = ACTIONS(3081),
    [anon_sym_notnull] = ACTIONS(3081),
    [anon_sym_unmanaged] = ACTIONS(3081),
    [anon_sym_checked] = ACTIONS(3081),
    [anon_sym_BANG] = ACTIONS(3083),
    [anon_sym_TILDE] = ACTIONS(3083),
    [anon_sym_PLUS_PLUS] = ACTIONS(3083),
    [anon_sym_DASH_DASH] = ACTIONS(3083),
    [anon_sym_true] = ACTIONS(3081),
    [anon_sym_false] = ACTIONS(3081),
    [anon_sym_PLUS] = ACTIONS(3081),
    [anon_sym_DASH] = ACTIONS(3081),
    [anon_sym_STAR] = ACTIONS(3083),
    [anon_sym_CARET] = ACTIONS(3083),
    [anon_sym_AMP] = ACTIONS(3083),
    [anon_sym_this] = ACTIONS(3081),
    [anon_sym_scoped] = ACTIONS(3081),
    [anon_sym_base] = ACTIONS(3081),
    [anon_sym_var] = ACTIONS(3081),
    [sym_predefined_type] = ACTIONS(3081),
    [anon_sym_break] = ACTIONS(3081),
    [anon_sym_unchecked] = ACTIONS(3081),
    [anon_sym_continue] = ACTIONS(3081),
    [anon_sym_do] = ACTIONS(3081),
    [anon_sym_while] = ACTIONS(3081),
    [anon_sym_for] = ACTIONS(3081),
    [anon_sym_lock] = ACTIONS(3081),
    [anon_sym_yield] = ACTIONS(3081),
    [anon_sym_switch] = ACTIONS(3081),
    [anon_sym_default] = ACTIONS(3081),
    [anon_sym_throw] = ACTIONS(3081),
    [anon_sym_try] = ACTIONS(3081),
    [anon_sym_when] = ACTIONS(3081),
    [anon_sym_await] = ACTIONS(3081),
    [anon_sym_foreach] = ACTIONS(3081),
    [anon_sym_goto] = ACTIONS(3081),
    [anon_sym_if] = ACTIONS(3081),
    [anon_sym_else] = ACTIONS(3081),
    [anon_sym_DOT_DOT] = ACTIONS(3083),
    [anon_sym_from] = ACTIONS(3081),
    [anon_sym_into] = ACTIONS(3081),
    [anon_sym_join] = ACTIONS(3081),
    [anon_sym_on] = ACTIONS(3081),
    [anon_sym_equals] = ACTIONS(3081),
    [anon_sym_let] = ACTIONS(3081),
    [anon_sym_orderby] = ACTIONS(3081),
    [anon_sym_ascending] = ACTIONS(3081),
    [anon_sym_descending] = ACTIONS(3081),
    [anon_sym_group] = ACTIONS(3081),
    [anon_sym_by] = ACTIONS(3081),
    [anon_sym_select] = ACTIONS(3081),
    [anon_sym_stackalloc] = ACTIONS(3081),
    [anon_sym_sizeof] = ACTIONS(3081),
    [anon_sym_typeof] = ACTIONS(3081),
    [anon_sym___makeref] = ACTIONS(3081),
    [anon_sym___reftype] = ACTIONS(3081),
    [anon_sym___refvalue] = ACTIONS(3081),
    [sym_null_literal] = ACTIONS(3081),
    [anon_sym_SQUOTE] = ACTIONS(3083),
    [sym_integer_literal] = ACTIONS(3081),
    [sym_real_literal] = ACTIONS(3083),
    [anon_sym_DQUOTE] = ACTIONS(3083),
    [sym_verbatim_string_literal] = ACTIONS(3083),
    [aux_sym_preproc_if_token1] = ACTIONS(3083),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3083),
    [sym_interpolation_verbatim_start] = ACTIONS(3083),
    [sym_interpolation_raw_start] = ACTIONS(3083),
    [sym_raw_string_start] = ACTIONS(3083),
  },
  [2493] = {
    [sym_preproc_region] = STATE(2493),
    [sym_preproc_endregion] = STATE(2493),
    [sym_preproc_line] = STATE(2493),
    [sym_preproc_pragma] = STATE(2493),
    [sym_preproc_nullable] = STATE(2493),
    [sym_preproc_error] = STATE(2493),
    [sym_preproc_warning] = STATE(2493),
    [sym_preproc_define] = STATE(2493),
    [sym_preproc_undef] = STATE(2493),
    [ts_builtin_sym_end] = ACTIONS(3279),
    [sym__identifier_token] = ACTIONS(3277),
    [anon_sym_extern] = ACTIONS(3277),
    [anon_sym_alias] = ACTIONS(3277),
    [anon_sym_SEMI] = ACTIONS(3279),
    [anon_sym_global] = ACTIONS(3277),
    [anon_sym_using] = ACTIONS(3277),
    [anon_sym_unsafe] = ACTIONS(3277),
    [anon_sym_static] = ACTIONS(3277),
    [anon_sym_LBRACK] = ACTIONS(3279),
    [anon_sym_LPAREN] = ACTIONS(3279),
    [anon_sym_return] = ACTIONS(3277),
    [anon_sym_namespace] = ACTIONS(3277),
    [anon_sym_class] = ACTIONS(3277),
    [anon_sym_ref] = ACTIONS(3277),
    [anon_sym_struct] = ACTIONS(3277),
    [anon_sym_enum] = ACTIONS(3277),
    [anon_sym_LBRACE] = ACTIONS(3279),
    [anon_sym_interface] = ACTIONS(3277),
    [anon_sym_delegate] = ACTIONS(3277),
    [anon_sym_record] = ACTIONS(3277),
    [anon_sym_abstract] = ACTIONS(3277),
    [anon_sym_async] = ACTIONS(3277),
    [anon_sym_const] = ACTIONS(3277),
    [anon_sym_file] = ACTIONS(3277),
    [anon_sym_fixed] = ACTIONS(3277),
    [anon_sym_internal] = ACTIONS(3277),
    [anon_sym_new] = ACTIONS(3277),
    [anon_sym_override] = ACTIONS(3277),
    [anon_sym_partial] = ACTIONS(3277),
    [anon_sym_private] = ACTIONS(3277),
    [anon_sym_protected] = ACTIONS(3277),
    [anon_sym_public] = ACTIONS(3277),
    [anon_sym_readonly] = ACTIONS(3277),
    [anon_sym_required] = ACTIONS(3277),
    [anon_sym_sealed] = ACTIONS(3277),
    [anon_sym_virtual] = ACTIONS(3277),
    [anon_sym_volatile] = ACTIONS(3277),
    [anon_sym_where] = ACTIONS(3277),
    [anon_sym_notnull] = ACTIONS(3277),
    [anon_sym_unmanaged] = ACTIONS(3277),
    [anon_sym_checked] = ACTIONS(3277),
    [anon_sym_BANG] = ACTIONS(3279),
    [anon_sym_TILDE] = ACTIONS(3279),
    [anon_sym_PLUS_PLUS] = ACTIONS(3279),
    [anon_sym_DASH_DASH] = ACTIONS(3279),
    [anon_sym_true] = ACTIONS(3277),
    [anon_sym_false] = ACTIONS(3277),
    [anon_sym_PLUS] = ACTIONS(3277),
    [anon_sym_DASH] = ACTIONS(3277),
    [anon_sym_STAR] = ACTIONS(3279),
    [anon_sym_CARET] = ACTIONS(3279),
    [anon_sym_AMP] = ACTIONS(3279),
    [anon_sym_this] = ACTIONS(3277),
    [anon_sym_scoped] = ACTIONS(3277),
    [anon_sym_base] = ACTIONS(3277),
    [anon_sym_var] = ACTIONS(3277),
    [sym_predefined_type] = ACTIONS(3277),
    [anon_sym_break] = ACTIONS(3277),
    [anon_sym_unchecked] = ACTIONS(3277),
    [anon_sym_continue] = ACTIONS(3277),
    [anon_sym_do] = ACTIONS(3277),
    [anon_sym_while] = ACTIONS(3277),
    [anon_sym_for] = ACTIONS(3277),
    [anon_sym_lock] = ACTIONS(3277),
    [anon_sym_yield] = ACTIONS(3277),
    [anon_sym_switch] = ACTIONS(3277),
    [anon_sym_default] = ACTIONS(3277),
    [anon_sym_throw] = ACTIONS(3277),
    [anon_sym_try] = ACTIONS(3277),
    [anon_sym_when] = ACTIONS(3277),
    [anon_sym_await] = ACTIONS(3277),
    [anon_sym_foreach] = ACTIONS(3277),
    [anon_sym_goto] = ACTIONS(3277),
    [anon_sym_if] = ACTIONS(3277),
    [anon_sym_else] = ACTIONS(3277),
    [anon_sym_DOT_DOT] = ACTIONS(3279),
    [anon_sym_from] = ACTIONS(3277),
    [anon_sym_into] = ACTIONS(3277),
    [anon_sym_join] = ACTIONS(3277),
    [anon_sym_on] = ACTIONS(3277),
    [anon_sym_equals] = ACTIONS(3277),
    [anon_sym_let] = ACTIONS(3277),
    [anon_sym_orderby] = ACTIONS(3277),
    [anon_sym_ascending] = ACTIONS(3277),
    [anon_sym_descending] = ACTIONS(3277),
    [anon_sym_group] = ACTIONS(3277),
    [anon_sym_by] = ACTIONS(3277),
    [anon_sym_select] = ACTIONS(3277),
    [anon_sym_stackalloc] = ACTIONS(3277),
    [anon_sym_sizeof] = ACTIONS(3277),
    [anon_sym_typeof] = ACTIONS(3277),
    [anon_sym___makeref] = ACTIONS(3277),
    [anon_sym___reftype] = ACTIONS(3277),
    [anon_sym___refvalue] = ACTIONS(3277),
    [sym_null_literal] = ACTIONS(3277),
    [anon_sym_SQUOTE] = ACTIONS(3279),
    [sym_integer_literal] = ACTIONS(3277),
    [sym_real_literal] = ACTIONS(3279),
    [anon_sym_DQUOTE] = ACTIONS(3279),
    [sym_verbatim_string_literal] = ACTIONS(3279),
    [aux_sym_preproc_if_token1] = ACTIONS(3279),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3279),
    [sym_interpolation_verbatim_start] = ACTIONS(3279),
    [sym_interpolation_raw_start] = ACTIONS(3279),
    [sym_raw_string_start] = ACTIONS(3279),
  },
  [2494] = {
    [sym_preproc_region] = STATE(2494),
    [sym_preproc_endregion] = STATE(2494),
    [sym_preproc_line] = STATE(2494),
    [sym_preproc_pragma] = STATE(2494),
    [sym_preproc_nullable] = STATE(2494),
    [sym_preproc_error] = STATE(2494),
    [sym_preproc_warning] = STATE(2494),
    [sym_preproc_define] = STATE(2494),
    [sym_preproc_undef] = STATE(2494),
    [ts_builtin_sym_end] = ACTIONS(3163),
    [sym__identifier_token] = ACTIONS(3161),
    [anon_sym_extern] = ACTIONS(3161),
    [anon_sym_alias] = ACTIONS(3161),
    [anon_sym_SEMI] = ACTIONS(3163),
    [anon_sym_global] = ACTIONS(3161),
    [anon_sym_using] = ACTIONS(3161),
    [anon_sym_unsafe] = ACTIONS(3161),
    [anon_sym_static] = ACTIONS(3161),
    [anon_sym_LBRACK] = ACTIONS(3163),
    [anon_sym_LPAREN] = ACTIONS(3163),
    [anon_sym_return] = ACTIONS(3161),
    [anon_sym_namespace] = ACTIONS(3161),
    [anon_sym_class] = ACTIONS(3161),
    [anon_sym_ref] = ACTIONS(3161),
    [anon_sym_struct] = ACTIONS(3161),
    [anon_sym_enum] = ACTIONS(3161),
    [anon_sym_LBRACE] = ACTIONS(3163),
    [anon_sym_interface] = ACTIONS(3161),
    [anon_sym_delegate] = ACTIONS(3161),
    [anon_sym_record] = ACTIONS(3161),
    [anon_sym_abstract] = ACTIONS(3161),
    [anon_sym_async] = ACTIONS(3161),
    [anon_sym_const] = ACTIONS(3161),
    [anon_sym_file] = ACTIONS(3161),
    [anon_sym_fixed] = ACTIONS(3161),
    [anon_sym_internal] = ACTIONS(3161),
    [anon_sym_new] = ACTIONS(3161),
    [anon_sym_override] = ACTIONS(3161),
    [anon_sym_partial] = ACTIONS(3161),
    [anon_sym_private] = ACTIONS(3161),
    [anon_sym_protected] = ACTIONS(3161),
    [anon_sym_public] = ACTIONS(3161),
    [anon_sym_readonly] = ACTIONS(3161),
    [anon_sym_required] = ACTIONS(3161),
    [anon_sym_sealed] = ACTIONS(3161),
    [anon_sym_virtual] = ACTIONS(3161),
    [anon_sym_volatile] = ACTIONS(3161),
    [anon_sym_where] = ACTIONS(3161),
    [anon_sym_notnull] = ACTIONS(3161),
    [anon_sym_unmanaged] = ACTIONS(3161),
    [anon_sym_checked] = ACTIONS(3161),
    [anon_sym_BANG] = ACTIONS(3163),
    [anon_sym_TILDE] = ACTIONS(3163),
    [anon_sym_PLUS_PLUS] = ACTIONS(3163),
    [anon_sym_DASH_DASH] = ACTIONS(3163),
    [anon_sym_true] = ACTIONS(3161),
    [anon_sym_false] = ACTIONS(3161),
    [anon_sym_PLUS] = ACTIONS(3161),
    [anon_sym_DASH] = ACTIONS(3161),
    [anon_sym_STAR] = ACTIONS(3163),
    [anon_sym_CARET] = ACTIONS(3163),
    [anon_sym_AMP] = ACTIONS(3163),
    [anon_sym_this] = ACTIONS(3161),
    [anon_sym_scoped] = ACTIONS(3161),
    [anon_sym_base] = ACTIONS(3161),
    [anon_sym_var] = ACTIONS(3161),
    [sym_predefined_type] = ACTIONS(3161),
    [anon_sym_break] = ACTIONS(3161),
    [anon_sym_unchecked] = ACTIONS(3161),
    [anon_sym_continue] = ACTIONS(3161),
    [anon_sym_do] = ACTIONS(3161),
    [anon_sym_while] = ACTIONS(3161),
    [anon_sym_for] = ACTIONS(3161),
    [anon_sym_lock] = ACTIONS(3161),
    [anon_sym_yield] = ACTIONS(3161),
    [anon_sym_switch] = ACTIONS(3161),
    [anon_sym_default] = ACTIONS(3161),
    [anon_sym_throw] = ACTIONS(3161),
    [anon_sym_try] = ACTIONS(3161),
    [anon_sym_when] = ACTIONS(3161),
    [anon_sym_await] = ACTIONS(3161),
    [anon_sym_foreach] = ACTIONS(3161),
    [anon_sym_goto] = ACTIONS(3161),
    [anon_sym_if] = ACTIONS(3161),
    [anon_sym_else] = ACTIONS(3161),
    [anon_sym_DOT_DOT] = ACTIONS(3163),
    [anon_sym_from] = ACTIONS(3161),
    [anon_sym_into] = ACTIONS(3161),
    [anon_sym_join] = ACTIONS(3161),
    [anon_sym_on] = ACTIONS(3161),
    [anon_sym_equals] = ACTIONS(3161),
    [anon_sym_let] = ACTIONS(3161),
    [anon_sym_orderby] = ACTIONS(3161),
    [anon_sym_ascending] = ACTIONS(3161),
    [anon_sym_descending] = ACTIONS(3161),
    [anon_sym_group] = ACTIONS(3161),
    [anon_sym_by] = ACTIONS(3161),
    [anon_sym_select] = ACTIONS(3161),
    [anon_sym_stackalloc] = ACTIONS(3161),
    [anon_sym_sizeof] = ACTIONS(3161),
    [anon_sym_typeof] = ACTIONS(3161),
    [anon_sym___makeref] = ACTIONS(3161),
    [anon_sym___reftype] = ACTIONS(3161),
    [anon_sym___refvalue] = ACTIONS(3161),
    [sym_null_literal] = ACTIONS(3161),
    [anon_sym_SQUOTE] = ACTIONS(3163),
    [sym_integer_literal] = ACTIONS(3161),
    [sym_real_literal] = ACTIONS(3163),
    [anon_sym_DQUOTE] = ACTIONS(3163),
    [sym_verbatim_string_literal] = ACTIONS(3163),
    [aux_sym_preproc_if_token1] = ACTIONS(3163),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3163),
    [sym_interpolation_verbatim_start] = ACTIONS(3163),
    [sym_interpolation_raw_start] = ACTIONS(3163),
    [sym_raw_string_start] = ACTIONS(3163),
  },
  [2495] = {
    [sym_preproc_region] = STATE(2495),
    [sym_preproc_endregion] = STATE(2495),
    [sym_preproc_line] = STATE(2495),
    [sym_preproc_pragma] = STATE(2495),
    [sym_preproc_nullable] = STATE(2495),
    [sym_preproc_error] = STATE(2495),
    [sym_preproc_warning] = STATE(2495),
    [sym_preproc_define] = STATE(2495),
    [sym_preproc_undef] = STATE(2495),
    [ts_builtin_sym_end] = ACTIONS(3399),
    [sym__identifier_token] = ACTIONS(3397),
    [anon_sym_extern] = ACTIONS(3397),
    [anon_sym_alias] = ACTIONS(3397),
    [anon_sym_SEMI] = ACTIONS(3399),
    [anon_sym_global] = ACTIONS(3397),
    [anon_sym_using] = ACTIONS(3397),
    [anon_sym_unsafe] = ACTIONS(3397),
    [anon_sym_static] = ACTIONS(3397),
    [anon_sym_LBRACK] = ACTIONS(3399),
    [anon_sym_LPAREN] = ACTIONS(3399),
    [anon_sym_return] = ACTIONS(3397),
    [anon_sym_namespace] = ACTIONS(3397),
    [anon_sym_class] = ACTIONS(3397),
    [anon_sym_ref] = ACTIONS(3397),
    [anon_sym_struct] = ACTIONS(3397),
    [anon_sym_enum] = ACTIONS(3397),
    [anon_sym_LBRACE] = ACTIONS(3399),
    [anon_sym_interface] = ACTIONS(3397),
    [anon_sym_delegate] = ACTIONS(3397),
    [anon_sym_record] = ACTIONS(3397),
    [anon_sym_abstract] = ACTIONS(3397),
    [anon_sym_async] = ACTIONS(3397),
    [anon_sym_const] = ACTIONS(3397),
    [anon_sym_file] = ACTIONS(3397),
    [anon_sym_fixed] = ACTIONS(3397),
    [anon_sym_internal] = ACTIONS(3397),
    [anon_sym_new] = ACTIONS(3397),
    [anon_sym_override] = ACTIONS(3397),
    [anon_sym_partial] = ACTIONS(3397),
    [anon_sym_private] = ACTIONS(3397),
    [anon_sym_protected] = ACTIONS(3397),
    [anon_sym_public] = ACTIONS(3397),
    [anon_sym_readonly] = ACTIONS(3397),
    [anon_sym_required] = ACTIONS(3397),
    [anon_sym_sealed] = ACTIONS(3397),
    [anon_sym_virtual] = ACTIONS(3397),
    [anon_sym_volatile] = ACTIONS(3397),
    [anon_sym_where] = ACTIONS(3397),
    [anon_sym_notnull] = ACTIONS(3397),
    [anon_sym_unmanaged] = ACTIONS(3397),
    [anon_sym_checked] = ACTIONS(3397),
    [anon_sym_BANG] = ACTIONS(3399),
    [anon_sym_TILDE] = ACTIONS(3399),
    [anon_sym_PLUS_PLUS] = ACTIONS(3399),
    [anon_sym_DASH_DASH] = ACTIONS(3399),
    [anon_sym_true] = ACTIONS(3397),
    [anon_sym_false] = ACTIONS(3397),
    [anon_sym_PLUS] = ACTIONS(3397),
    [anon_sym_DASH] = ACTIONS(3397),
    [anon_sym_STAR] = ACTIONS(3399),
    [anon_sym_CARET] = ACTIONS(3399),
    [anon_sym_AMP] = ACTIONS(3399),
    [anon_sym_this] = ACTIONS(3397),
    [anon_sym_scoped] = ACTIONS(3397),
    [anon_sym_base] = ACTIONS(3397),
    [anon_sym_var] = ACTIONS(3397),
    [sym_predefined_type] = ACTIONS(3397),
    [anon_sym_break] = ACTIONS(3397),
    [anon_sym_unchecked] = ACTIONS(3397),
    [anon_sym_continue] = ACTIONS(3397),
    [anon_sym_do] = ACTIONS(3397),
    [anon_sym_while] = ACTIONS(3397),
    [anon_sym_for] = ACTIONS(3397),
    [anon_sym_lock] = ACTIONS(3397),
    [anon_sym_yield] = ACTIONS(3397),
    [anon_sym_switch] = ACTIONS(3397),
    [anon_sym_default] = ACTIONS(3397),
    [anon_sym_throw] = ACTIONS(3397),
    [anon_sym_try] = ACTIONS(3397),
    [anon_sym_when] = ACTIONS(3397),
    [anon_sym_await] = ACTIONS(3397),
    [anon_sym_foreach] = ACTIONS(3397),
    [anon_sym_goto] = ACTIONS(3397),
    [anon_sym_if] = ACTIONS(3397),
    [anon_sym_else] = ACTIONS(3397),
    [anon_sym_DOT_DOT] = ACTIONS(3399),
    [anon_sym_from] = ACTIONS(3397),
    [anon_sym_into] = ACTIONS(3397),
    [anon_sym_join] = ACTIONS(3397),
    [anon_sym_on] = ACTIONS(3397),
    [anon_sym_equals] = ACTIONS(3397),
    [anon_sym_let] = ACTIONS(3397),
    [anon_sym_orderby] = ACTIONS(3397),
    [anon_sym_ascending] = ACTIONS(3397),
    [anon_sym_descending] = ACTIONS(3397),
    [anon_sym_group] = ACTIONS(3397),
    [anon_sym_by] = ACTIONS(3397),
    [anon_sym_select] = ACTIONS(3397),
    [anon_sym_stackalloc] = ACTIONS(3397),
    [anon_sym_sizeof] = ACTIONS(3397),
    [anon_sym_typeof] = ACTIONS(3397),
    [anon_sym___makeref] = ACTIONS(3397),
    [anon_sym___reftype] = ACTIONS(3397),
    [anon_sym___refvalue] = ACTIONS(3397),
    [sym_null_literal] = ACTIONS(3397),
    [anon_sym_SQUOTE] = ACTIONS(3399),
    [sym_integer_literal] = ACTIONS(3397),
    [sym_real_literal] = ACTIONS(3399),
    [anon_sym_DQUOTE] = ACTIONS(3399),
    [sym_verbatim_string_literal] = ACTIONS(3399),
    [aux_sym_preproc_if_token1] = ACTIONS(3399),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3399),
    [sym_interpolation_verbatim_start] = ACTIONS(3399),
    [sym_interpolation_raw_start] = ACTIONS(3399),
    [sym_raw_string_start] = ACTIONS(3399),
  },
  [2496] = {
    [sym_preproc_region] = STATE(2496),
    [sym_preproc_endregion] = STATE(2496),
    [sym_preproc_line] = STATE(2496),
    [sym_preproc_pragma] = STATE(2496),
    [sym_preproc_nullable] = STATE(2496),
    [sym_preproc_error] = STATE(2496),
    [sym_preproc_warning] = STATE(2496),
    [sym_preproc_define] = STATE(2496),
    [sym_preproc_undef] = STATE(2496),
    [ts_builtin_sym_end] = ACTIONS(3013),
    [sym__identifier_token] = ACTIONS(3011),
    [anon_sym_extern] = ACTIONS(3011),
    [anon_sym_alias] = ACTIONS(3011),
    [anon_sym_SEMI] = ACTIONS(3013),
    [anon_sym_global] = ACTIONS(3011),
    [anon_sym_using] = ACTIONS(3011),
    [anon_sym_unsafe] = ACTIONS(3011),
    [anon_sym_static] = ACTIONS(3011),
    [anon_sym_LBRACK] = ACTIONS(3013),
    [anon_sym_LPAREN] = ACTIONS(3013),
    [anon_sym_return] = ACTIONS(3011),
    [anon_sym_namespace] = ACTIONS(3011),
    [anon_sym_class] = ACTIONS(3011),
    [anon_sym_ref] = ACTIONS(3011),
    [anon_sym_struct] = ACTIONS(3011),
    [anon_sym_enum] = ACTIONS(3011),
    [anon_sym_LBRACE] = ACTIONS(3013),
    [anon_sym_interface] = ACTIONS(3011),
    [anon_sym_delegate] = ACTIONS(3011),
    [anon_sym_record] = ACTIONS(3011),
    [anon_sym_abstract] = ACTIONS(3011),
    [anon_sym_async] = ACTIONS(3011),
    [anon_sym_const] = ACTIONS(3011),
    [anon_sym_file] = ACTIONS(3011),
    [anon_sym_fixed] = ACTIONS(3011),
    [anon_sym_internal] = ACTIONS(3011),
    [anon_sym_new] = ACTIONS(3011),
    [anon_sym_override] = ACTIONS(3011),
    [anon_sym_partial] = ACTIONS(3011),
    [anon_sym_private] = ACTIONS(3011),
    [anon_sym_protected] = ACTIONS(3011),
    [anon_sym_public] = ACTIONS(3011),
    [anon_sym_readonly] = ACTIONS(3011),
    [anon_sym_required] = ACTIONS(3011),
    [anon_sym_sealed] = ACTIONS(3011),
    [anon_sym_virtual] = ACTIONS(3011),
    [anon_sym_volatile] = ACTIONS(3011),
    [anon_sym_where] = ACTIONS(3011),
    [anon_sym_notnull] = ACTIONS(3011),
    [anon_sym_unmanaged] = ACTIONS(3011),
    [anon_sym_checked] = ACTIONS(3011),
    [anon_sym_BANG] = ACTIONS(3013),
    [anon_sym_TILDE] = ACTIONS(3013),
    [anon_sym_PLUS_PLUS] = ACTIONS(3013),
    [anon_sym_DASH_DASH] = ACTIONS(3013),
    [anon_sym_true] = ACTIONS(3011),
    [anon_sym_false] = ACTIONS(3011),
    [anon_sym_PLUS] = ACTIONS(3011),
    [anon_sym_DASH] = ACTIONS(3011),
    [anon_sym_STAR] = ACTIONS(3013),
    [anon_sym_CARET] = ACTIONS(3013),
    [anon_sym_AMP] = ACTIONS(3013),
    [anon_sym_this] = ACTIONS(3011),
    [anon_sym_scoped] = ACTIONS(3011),
    [anon_sym_base] = ACTIONS(3011),
    [anon_sym_var] = ACTIONS(3011),
    [sym_predefined_type] = ACTIONS(3011),
    [anon_sym_break] = ACTIONS(3011),
    [anon_sym_unchecked] = ACTIONS(3011),
    [anon_sym_continue] = ACTIONS(3011),
    [anon_sym_do] = ACTIONS(3011),
    [anon_sym_while] = ACTIONS(3011),
    [anon_sym_for] = ACTIONS(3011),
    [anon_sym_lock] = ACTIONS(3011),
    [anon_sym_yield] = ACTIONS(3011),
    [anon_sym_switch] = ACTIONS(3011),
    [anon_sym_default] = ACTIONS(3011),
    [anon_sym_throw] = ACTIONS(3011),
    [anon_sym_try] = ACTIONS(3011),
    [anon_sym_when] = ACTIONS(3011),
    [anon_sym_await] = ACTIONS(3011),
    [anon_sym_foreach] = ACTIONS(3011),
    [anon_sym_goto] = ACTIONS(3011),
    [anon_sym_if] = ACTIONS(3011),
    [anon_sym_else] = ACTIONS(3011),
    [anon_sym_DOT_DOT] = ACTIONS(3013),
    [anon_sym_from] = ACTIONS(3011),
    [anon_sym_into] = ACTIONS(3011),
    [anon_sym_join] = ACTIONS(3011),
    [anon_sym_on] = ACTIONS(3011),
    [anon_sym_equals] = ACTIONS(3011),
    [anon_sym_let] = ACTIONS(3011),
    [anon_sym_orderby] = ACTIONS(3011),
    [anon_sym_ascending] = ACTIONS(3011),
    [anon_sym_descending] = ACTIONS(3011),
    [anon_sym_group] = ACTIONS(3011),
    [anon_sym_by] = ACTIONS(3011),
    [anon_sym_select] = ACTIONS(3011),
    [anon_sym_stackalloc] = ACTIONS(3011),
    [anon_sym_sizeof] = ACTIONS(3011),
    [anon_sym_typeof] = ACTIONS(3011),
    [anon_sym___makeref] = ACTIONS(3011),
    [anon_sym___reftype] = ACTIONS(3011),
    [anon_sym___refvalue] = ACTIONS(3011),
    [sym_null_literal] = ACTIONS(3011),
    [anon_sym_SQUOTE] = ACTIONS(3013),
    [sym_integer_literal] = ACTIONS(3011),
    [sym_real_literal] = ACTIONS(3013),
    [anon_sym_DQUOTE] = ACTIONS(3013),
    [sym_verbatim_string_literal] = ACTIONS(3013),
    [aux_sym_preproc_if_token1] = ACTIONS(3013),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3013),
    [sym_interpolation_verbatim_start] = ACTIONS(3013),
    [sym_interpolation_raw_start] = ACTIONS(3013),
    [sym_raw_string_start] = ACTIONS(3013),
  },
  [2497] = {
    [sym_preproc_region] = STATE(2497),
    [sym_preproc_endregion] = STATE(2497),
    [sym_preproc_line] = STATE(2497),
    [sym_preproc_pragma] = STATE(2497),
    [sym_preproc_nullable] = STATE(2497),
    [sym_preproc_error] = STATE(2497),
    [sym_preproc_warning] = STATE(2497),
    [sym_preproc_define] = STATE(2497),
    [sym_preproc_undef] = STATE(2497),
    [ts_builtin_sym_end] = ACTIONS(3131),
    [sym__identifier_token] = ACTIONS(3129),
    [anon_sym_extern] = ACTIONS(3129),
    [anon_sym_alias] = ACTIONS(3129),
    [anon_sym_SEMI] = ACTIONS(3131),
    [anon_sym_global] = ACTIONS(3129),
    [anon_sym_using] = ACTIONS(3129),
    [anon_sym_unsafe] = ACTIONS(3129),
    [anon_sym_static] = ACTIONS(3129),
    [anon_sym_LBRACK] = ACTIONS(3131),
    [anon_sym_LPAREN] = ACTIONS(3131),
    [anon_sym_return] = ACTIONS(3129),
    [anon_sym_namespace] = ACTIONS(3129),
    [anon_sym_class] = ACTIONS(3129),
    [anon_sym_ref] = ACTIONS(3129),
    [anon_sym_struct] = ACTIONS(3129),
    [anon_sym_enum] = ACTIONS(3129),
    [anon_sym_LBRACE] = ACTIONS(3131),
    [anon_sym_interface] = ACTIONS(3129),
    [anon_sym_delegate] = ACTIONS(3129),
    [anon_sym_record] = ACTIONS(3129),
    [anon_sym_abstract] = ACTIONS(3129),
    [anon_sym_async] = ACTIONS(3129),
    [anon_sym_const] = ACTIONS(3129),
    [anon_sym_file] = ACTIONS(3129),
    [anon_sym_fixed] = ACTIONS(3129),
    [anon_sym_internal] = ACTIONS(3129),
    [anon_sym_new] = ACTIONS(3129),
    [anon_sym_override] = ACTIONS(3129),
    [anon_sym_partial] = ACTIONS(3129),
    [anon_sym_private] = ACTIONS(3129),
    [anon_sym_protected] = ACTIONS(3129),
    [anon_sym_public] = ACTIONS(3129),
    [anon_sym_readonly] = ACTIONS(3129),
    [anon_sym_required] = ACTIONS(3129),
    [anon_sym_sealed] = ACTIONS(3129),
    [anon_sym_virtual] = ACTIONS(3129),
    [anon_sym_volatile] = ACTIONS(3129),
    [anon_sym_where] = ACTIONS(3129),
    [anon_sym_notnull] = ACTIONS(3129),
    [anon_sym_unmanaged] = ACTIONS(3129),
    [anon_sym_checked] = ACTIONS(3129),
    [anon_sym_BANG] = ACTIONS(3131),
    [anon_sym_TILDE] = ACTIONS(3131),
    [anon_sym_PLUS_PLUS] = ACTIONS(3131),
    [anon_sym_DASH_DASH] = ACTIONS(3131),
    [anon_sym_true] = ACTIONS(3129),
    [anon_sym_false] = ACTIONS(3129),
    [anon_sym_PLUS] = ACTIONS(3129),
    [anon_sym_DASH] = ACTIONS(3129),
    [anon_sym_STAR] = ACTIONS(3131),
    [anon_sym_CARET] = ACTIONS(3131),
    [anon_sym_AMP] = ACTIONS(3131),
    [anon_sym_this] = ACTIONS(3129),
    [anon_sym_scoped] = ACTIONS(3129),
    [anon_sym_base] = ACTIONS(3129),
    [anon_sym_var] = ACTIONS(3129),
    [sym_predefined_type] = ACTIONS(3129),
    [anon_sym_break] = ACTIONS(3129),
    [anon_sym_unchecked] = ACTIONS(3129),
    [anon_sym_continue] = ACTIONS(3129),
    [anon_sym_do] = ACTIONS(3129),
    [anon_sym_while] = ACTIONS(3129),
    [anon_sym_for] = ACTIONS(3129),
    [anon_sym_lock] = ACTIONS(3129),
    [anon_sym_yield] = ACTIONS(3129),
    [anon_sym_switch] = ACTIONS(3129),
    [anon_sym_default] = ACTIONS(3129),
    [anon_sym_throw] = ACTIONS(3129),
    [anon_sym_try] = ACTIONS(3129),
    [anon_sym_when] = ACTIONS(3129),
    [anon_sym_await] = ACTIONS(3129),
    [anon_sym_foreach] = ACTIONS(3129),
    [anon_sym_goto] = ACTIONS(3129),
    [anon_sym_if] = ACTIONS(3129),
    [anon_sym_else] = ACTIONS(3129),
    [anon_sym_DOT_DOT] = ACTIONS(3131),
    [anon_sym_from] = ACTIONS(3129),
    [anon_sym_into] = ACTIONS(3129),
    [anon_sym_join] = ACTIONS(3129),
    [anon_sym_on] = ACTIONS(3129),
    [anon_sym_equals] = ACTIONS(3129),
    [anon_sym_let] = ACTIONS(3129),
    [anon_sym_orderby] = ACTIONS(3129),
    [anon_sym_ascending] = ACTIONS(3129),
    [anon_sym_descending] = ACTIONS(3129),
    [anon_sym_group] = ACTIONS(3129),
    [anon_sym_by] = ACTIONS(3129),
    [anon_sym_select] = ACTIONS(3129),
    [anon_sym_stackalloc] = ACTIONS(3129),
    [anon_sym_sizeof] = ACTIONS(3129),
    [anon_sym_typeof] = ACTIONS(3129),
    [anon_sym___makeref] = ACTIONS(3129),
    [anon_sym___reftype] = ACTIONS(3129),
    [anon_sym___refvalue] = ACTIONS(3129),
    [sym_null_literal] = ACTIONS(3129),
    [anon_sym_SQUOTE] = ACTIONS(3131),
    [sym_integer_literal] = ACTIONS(3129),
    [sym_real_literal] = ACTIONS(3131),
    [anon_sym_DQUOTE] = ACTIONS(3131),
    [sym_verbatim_string_literal] = ACTIONS(3131),
    [aux_sym_preproc_if_token1] = ACTIONS(3131),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3131),
    [sym_interpolation_verbatim_start] = ACTIONS(3131),
    [sym_interpolation_raw_start] = ACTIONS(3131),
    [sym_raw_string_start] = ACTIONS(3131),
  },
  [2498] = {
    [sym_preproc_region] = STATE(2498),
    [sym_preproc_endregion] = STATE(2498),
    [sym_preproc_line] = STATE(2498),
    [sym_preproc_pragma] = STATE(2498),
    [sym_preproc_nullable] = STATE(2498),
    [sym_preproc_error] = STATE(2498),
    [sym_preproc_warning] = STATE(2498),
    [sym_preproc_define] = STATE(2498),
    [sym_preproc_undef] = STATE(2498),
    [ts_builtin_sym_end] = ACTIONS(3055),
    [sym__identifier_token] = ACTIONS(3053),
    [anon_sym_extern] = ACTIONS(3053),
    [anon_sym_alias] = ACTIONS(3053),
    [anon_sym_SEMI] = ACTIONS(3055),
    [anon_sym_global] = ACTIONS(3053),
    [anon_sym_using] = ACTIONS(3053),
    [anon_sym_unsafe] = ACTIONS(3053),
    [anon_sym_static] = ACTIONS(3053),
    [anon_sym_LBRACK] = ACTIONS(3055),
    [anon_sym_LPAREN] = ACTIONS(3055),
    [anon_sym_return] = ACTIONS(3053),
    [anon_sym_namespace] = ACTIONS(3053),
    [anon_sym_class] = ACTIONS(3053),
    [anon_sym_ref] = ACTIONS(3053),
    [anon_sym_struct] = ACTIONS(3053),
    [anon_sym_enum] = ACTIONS(3053),
    [anon_sym_LBRACE] = ACTIONS(3055),
    [anon_sym_interface] = ACTIONS(3053),
    [anon_sym_delegate] = ACTIONS(3053),
    [anon_sym_record] = ACTIONS(3053),
    [anon_sym_abstract] = ACTIONS(3053),
    [anon_sym_async] = ACTIONS(3053),
    [anon_sym_const] = ACTIONS(3053),
    [anon_sym_file] = ACTIONS(3053),
    [anon_sym_fixed] = ACTIONS(3053),
    [anon_sym_internal] = ACTIONS(3053),
    [anon_sym_new] = ACTIONS(3053),
    [anon_sym_override] = ACTIONS(3053),
    [anon_sym_partial] = ACTIONS(3053),
    [anon_sym_private] = ACTIONS(3053),
    [anon_sym_protected] = ACTIONS(3053),
    [anon_sym_public] = ACTIONS(3053),
    [anon_sym_readonly] = ACTIONS(3053),
    [anon_sym_required] = ACTIONS(3053),
    [anon_sym_sealed] = ACTIONS(3053),
    [anon_sym_virtual] = ACTIONS(3053),
    [anon_sym_volatile] = ACTIONS(3053),
    [anon_sym_where] = ACTIONS(3053),
    [anon_sym_notnull] = ACTIONS(3053),
    [anon_sym_unmanaged] = ACTIONS(3053),
    [anon_sym_checked] = ACTIONS(3053),
    [anon_sym_BANG] = ACTIONS(3055),
    [anon_sym_TILDE] = ACTIONS(3055),
    [anon_sym_PLUS_PLUS] = ACTIONS(3055),
    [anon_sym_DASH_DASH] = ACTIONS(3055),
    [anon_sym_true] = ACTIONS(3053),
    [anon_sym_false] = ACTIONS(3053),
    [anon_sym_PLUS] = ACTIONS(3053),
    [anon_sym_DASH] = ACTIONS(3053),
    [anon_sym_STAR] = ACTIONS(3055),
    [anon_sym_CARET] = ACTIONS(3055),
    [anon_sym_AMP] = ACTIONS(3055),
    [anon_sym_this] = ACTIONS(3053),
    [anon_sym_scoped] = ACTIONS(3053),
    [anon_sym_base] = ACTIONS(3053),
    [anon_sym_var] = ACTIONS(3053),
    [sym_predefined_type] = ACTIONS(3053),
    [anon_sym_break] = ACTIONS(3053),
    [anon_sym_unchecked] = ACTIONS(3053),
    [anon_sym_continue] = ACTIONS(3053),
    [anon_sym_do] = ACTIONS(3053),
    [anon_sym_while] = ACTIONS(3053),
    [anon_sym_for] = ACTIONS(3053),
    [anon_sym_lock] = ACTIONS(3053),
    [anon_sym_yield] = ACTIONS(3053),
    [anon_sym_switch] = ACTIONS(3053),
    [anon_sym_default] = ACTIONS(3053),
    [anon_sym_throw] = ACTIONS(3053),
    [anon_sym_try] = ACTIONS(3053),
    [anon_sym_when] = ACTIONS(3053),
    [anon_sym_await] = ACTIONS(3053),
    [anon_sym_foreach] = ACTIONS(3053),
    [anon_sym_goto] = ACTIONS(3053),
    [anon_sym_if] = ACTIONS(3053),
    [anon_sym_else] = ACTIONS(3053),
    [anon_sym_DOT_DOT] = ACTIONS(3055),
    [anon_sym_from] = ACTIONS(3053),
    [anon_sym_into] = ACTIONS(3053),
    [anon_sym_join] = ACTIONS(3053),
    [anon_sym_on] = ACTIONS(3053),
    [anon_sym_equals] = ACTIONS(3053),
    [anon_sym_let] = ACTIONS(3053),
    [anon_sym_orderby] = ACTIONS(3053),
    [anon_sym_ascending] = ACTIONS(3053),
    [anon_sym_descending] = ACTIONS(3053),
    [anon_sym_group] = ACTIONS(3053),
    [anon_sym_by] = ACTIONS(3053),
    [anon_sym_select] = ACTIONS(3053),
    [anon_sym_stackalloc] = ACTIONS(3053),
    [anon_sym_sizeof] = ACTIONS(3053),
    [anon_sym_typeof] = ACTIONS(3053),
    [anon_sym___makeref] = ACTIONS(3053),
    [anon_sym___reftype] = ACTIONS(3053),
    [anon_sym___refvalue] = ACTIONS(3053),
    [sym_null_literal] = ACTIONS(3053),
    [anon_sym_SQUOTE] = ACTIONS(3055),
    [sym_integer_literal] = ACTIONS(3053),
    [sym_real_literal] = ACTIONS(3055),
    [anon_sym_DQUOTE] = ACTIONS(3055),
    [sym_verbatim_string_literal] = ACTIONS(3055),
    [aux_sym_preproc_if_token1] = ACTIONS(3055),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3055),
    [sym_interpolation_verbatim_start] = ACTIONS(3055),
    [sym_interpolation_raw_start] = ACTIONS(3055),
    [sym_raw_string_start] = ACTIONS(3055),
  },
  [2499] = {
    [sym_preproc_region] = STATE(2499),
    [sym_preproc_endregion] = STATE(2499),
    [sym_preproc_line] = STATE(2499),
    [sym_preproc_pragma] = STATE(2499),
    [sym_preproc_nullable] = STATE(2499),
    [sym_preproc_error] = STATE(2499),
    [sym_preproc_warning] = STATE(2499),
    [sym_preproc_define] = STATE(2499),
    [sym_preproc_undef] = STATE(2499),
    [ts_builtin_sym_end] = ACTIONS(3329),
    [sym__identifier_token] = ACTIONS(3327),
    [anon_sym_extern] = ACTIONS(3327),
    [anon_sym_alias] = ACTIONS(3327),
    [anon_sym_SEMI] = ACTIONS(3329),
    [anon_sym_global] = ACTIONS(3327),
    [anon_sym_using] = ACTIONS(3327),
    [anon_sym_unsafe] = ACTIONS(3327),
    [anon_sym_static] = ACTIONS(3327),
    [anon_sym_LBRACK] = ACTIONS(3329),
    [anon_sym_LPAREN] = ACTIONS(3329),
    [anon_sym_return] = ACTIONS(3327),
    [anon_sym_namespace] = ACTIONS(3327),
    [anon_sym_class] = ACTIONS(3327),
    [anon_sym_ref] = ACTIONS(3327),
    [anon_sym_struct] = ACTIONS(3327),
    [anon_sym_enum] = ACTIONS(3327),
    [anon_sym_LBRACE] = ACTIONS(3329),
    [anon_sym_interface] = ACTIONS(3327),
    [anon_sym_delegate] = ACTIONS(3327),
    [anon_sym_record] = ACTIONS(3327),
    [anon_sym_abstract] = ACTIONS(3327),
    [anon_sym_async] = ACTIONS(3327),
    [anon_sym_const] = ACTIONS(3327),
    [anon_sym_file] = ACTIONS(3327),
    [anon_sym_fixed] = ACTIONS(3327),
    [anon_sym_internal] = ACTIONS(3327),
    [anon_sym_new] = ACTIONS(3327),
    [anon_sym_override] = ACTIONS(3327),
    [anon_sym_partial] = ACTIONS(3327),
    [anon_sym_private] = ACTIONS(3327),
    [anon_sym_protected] = ACTIONS(3327),
    [anon_sym_public] = ACTIONS(3327),
    [anon_sym_readonly] = ACTIONS(3327),
    [anon_sym_required] = ACTIONS(3327),
    [anon_sym_sealed] = ACTIONS(3327),
    [anon_sym_virtual] = ACTIONS(3327),
    [anon_sym_volatile] = ACTIONS(3327),
    [anon_sym_where] = ACTIONS(3327),
    [anon_sym_notnull] = ACTIONS(3327),
    [anon_sym_unmanaged] = ACTIONS(3327),
    [anon_sym_checked] = ACTIONS(3327),
    [anon_sym_BANG] = ACTIONS(3329),
    [anon_sym_TILDE] = ACTIONS(3329),
    [anon_sym_PLUS_PLUS] = ACTIONS(3329),
    [anon_sym_DASH_DASH] = ACTIONS(3329),
    [anon_sym_true] = ACTIONS(3327),
    [anon_sym_false] = ACTIONS(3327),
    [anon_sym_PLUS] = ACTIONS(3327),
    [anon_sym_DASH] = ACTIONS(3327),
    [anon_sym_STAR] = ACTIONS(3329),
    [anon_sym_CARET] = ACTIONS(3329),
    [anon_sym_AMP] = ACTIONS(3329),
    [anon_sym_this] = ACTIONS(3327),
    [anon_sym_scoped] = ACTIONS(3327),
    [anon_sym_base] = ACTIONS(3327),
    [anon_sym_var] = ACTIONS(3327),
    [sym_predefined_type] = ACTIONS(3327),
    [anon_sym_break] = ACTIONS(3327),
    [anon_sym_unchecked] = ACTIONS(3327),
    [anon_sym_continue] = ACTIONS(3327),
    [anon_sym_do] = ACTIONS(3327),
    [anon_sym_while] = ACTIONS(3327),
    [anon_sym_for] = ACTIONS(3327),
    [anon_sym_lock] = ACTIONS(3327),
    [anon_sym_yield] = ACTIONS(3327),
    [anon_sym_switch] = ACTIONS(3327),
    [anon_sym_default] = ACTIONS(3327),
    [anon_sym_throw] = ACTIONS(3327),
    [anon_sym_try] = ACTIONS(3327),
    [anon_sym_when] = ACTIONS(3327),
    [anon_sym_await] = ACTIONS(3327),
    [anon_sym_foreach] = ACTIONS(3327),
    [anon_sym_goto] = ACTIONS(3327),
    [anon_sym_if] = ACTIONS(3327),
    [anon_sym_else] = ACTIONS(3327),
    [anon_sym_DOT_DOT] = ACTIONS(3329),
    [anon_sym_from] = ACTIONS(3327),
    [anon_sym_into] = ACTIONS(3327),
    [anon_sym_join] = ACTIONS(3327),
    [anon_sym_on] = ACTIONS(3327),
    [anon_sym_equals] = ACTIONS(3327),
    [anon_sym_let] = ACTIONS(3327),
    [anon_sym_orderby] = ACTIONS(3327),
    [anon_sym_ascending] = ACTIONS(3327),
    [anon_sym_descending] = ACTIONS(3327),
    [anon_sym_group] = ACTIONS(3327),
    [anon_sym_by] = ACTIONS(3327),
    [anon_sym_select] = ACTIONS(3327),
    [anon_sym_stackalloc] = ACTIONS(3327),
    [anon_sym_sizeof] = ACTIONS(3327),
    [anon_sym_typeof] = ACTIONS(3327),
    [anon_sym___makeref] = ACTIONS(3327),
    [anon_sym___reftype] = ACTIONS(3327),
    [anon_sym___refvalue] = ACTIONS(3327),
    [sym_null_literal] = ACTIONS(3327),
    [anon_sym_SQUOTE] = ACTIONS(3329),
    [sym_integer_literal] = ACTIONS(3327),
    [sym_real_literal] = ACTIONS(3329),
    [anon_sym_DQUOTE] = ACTIONS(3329),
    [sym_verbatim_string_literal] = ACTIONS(3329),
    [aux_sym_preproc_if_token1] = ACTIONS(3329),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3329),
    [sym_interpolation_verbatim_start] = ACTIONS(3329),
    [sym_interpolation_raw_start] = ACTIONS(3329),
    [sym_raw_string_start] = ACTIONS(3329),
  },
  [2500] = {
    [sym_preproc_region] = STATE(2500),
    [sym_preproc_endregion] = STATE(2500),
    [sym_preproc_line] = STATE(2500),
    [sym_preproc_pragma] = STATE(2500),
    [sym_preproc_nullable] = STATE(2500),
    [sym_preproc_error] = STATE(2500),
    [sym_preproc_warning] = STATE(2500),
    [sym_preproc_define] = STATE(2500),
    [sym_preproc_undef] = STATE(2500),
    [ts_builtin_sym_end] = ACTIONS(3135),
    [sym__identifier_token] = ACTIONS(3133),
    [anon_sym_extern] = ACTIONS(3133),
    [anon_sym_alias] = ACTIONS(3133),
    [anon_sym_SEMI] = ACTIONS(3135),
    [anon_sym_global] = ACTIONS(3133),
    [anon_sym_using] = ACTIONS(3133),
    [anon_sym_unsafe] = ACTIONS(3133),
    [anon_sym_static] = ACTIONS(3133),
    [anon_sym_LBRACK] = ACTIONS(3135),
    [anon_sym_LPAREN] = ACTIONS(3135),
    [anon_sym_return] = ACTIONS(3133),
    [anon_sym_namespace] = ACTIONS(3133),
    [anon_sym_class] = ACTIONS(3133),
    [anon_sym_ref] = ACTIONS(3133),
    [anon_sym_struct] = ACTIONS(3133),
    [anon_sym_enum] = ACTIONS(3133),
    [anon_sym_LBRACE] = ACTIONS(3135),
    [anon_sym_interface] = ACTIONS(3133),
    [anon_sym_delegate] = ACTIONS(3133),
    [anon_sym_record] = ACTIONS(3133),
    [anon_sym_abstract] = ACTIONS(3133),
    [anon_sym_async] = ACTIONS(3133),
    [anon_sym_const] = ACTIONS(3133),
    [anon_sym_file] = ACTIONS(3133),
    [anon_sym_fixed] = ACTIONS(3133),
    [anon_sym_internal] = ACTIONS(3133),
    [anon_sym_new] = ACTIONS(3133),
    [anon_sym_override] = ACTIONS(3133),
    [anon_sym_partial] = ACTIONS(3133),
    [anon_sym_private] = ACTIONS(3133),
    [anon_sym_protected] = ACTIONS(3133),
    [anon_sym_public] = ACTIONS(3133),
    [anon_sym_readonly] = ACTIONS(3133),
    [anon_sym_required] = ACTIONS(3133),
    [anon_sym_sealed] = ACTIONS(3133),
    [anon_sym_virtual] = ACTIONS(3133),
    [anon_sym_volatile] = ACTIONS(3133),
    [anon_sym_where] = ACTIONS(3133),
    [anon_sym_notnull] = ACTIONS(3133),
    [anon_sym_unmanaged] = ACTIONS(3133),
    [anon_sym_checked] = ACTIONS(3133),
    [anon_sym_BANG] = ACTIONS(3135),
    [anon_sym_TILDE] = ACTIONS(3135),
    [anon_sym_PLUS_PLUS] = ACTIONS(3135),
    [anon_sym_DASH_DASH] = ACTIONS(3135),
    [anon_sym_true] = ACTIONS(3133),
    [anon_sym_false] = ACTIONS(3133),
    [anon_sym_PLUS] = ACTIONS(3133),
    [anon_sym_DASH] = ACTIONS(3133),
    [anon_sym_STAR] = ACTIONS(3135),
    [anon_sym_CARET] = ACTIONS(3135),
    [anon_sym_AMP] = ACTIONS(3135),
    [anon_sym_this] = ACTIONS(3133),
    [anon_sym_scoped] = ACTIONS(3133),
    [anon_sym_base] = ACTIONS(3133),
    [anon_sym_var] = ACTIONS(3133),
    [sym_predefined_type] = ACTIONS(3133),
    [anon_sym_break] = ACTIONS(3133),
    [anon_sym_unchecked] = ACTIONS(3133),
    [anon_sym_continue] = ACTIONS(3133),
    [anon_sym_do] = ACTIONS(3133),
    [anon_sym_while] = ACTIONS(3133),
    [anon_sym_for] = ACTIONS(3133),
    [anon_sym_lock] = ACTIONS(3133),
    [anon_sym_yield] = ACTIONS(3133),
    [anon_sym_switch] = ACTIONS(3133),
    [anon_sym_default] = ACTIONS(3133),
    [anon_sym_throw] = ACTIONS(3133),
    [anon_sym_try] = ACTIONS(3133),
    [anon_sym_when] = ACTIONS(3133),
    [anon_sym_await] = ACTIONS(3133),
    [anon_sym_foreach] = ACTIONS(3133),
    [anon_sym_goto] = ACTIONS(3133),
    [anon_sym_if] = ACTIONS(3133),
    [anon_sym_else] = ACTIONS(3133),
    [anon_sym_DOT_DOT] = ACTIONS(3135),
    [anon_sym_from] = ACTIONS(3133),
    [anon_sym_into] = ACTIONS(3133),
    [anon_sym_join] = ACTIONS(3133),
    [anon_sym_on] = ACTIONS(3133),
    [anon_sym_equals] = ACTIONS(3133),
    [anon_sym_let] = ACTIONS(3133),
    [anon_sym_orderby] = ACTIONS(3133),
    [anon_sym_ascending] = ACTIONS(3133),
    [anon_sym_descending] = ACTIONS(3133),
    [anon_sym_group] = ACTIONS(3133),
    [anon_sym_by] = ACTIONS(3133),
    [anon_sym_select] = ACTIONS(3133),
    [anon_sym_stackalloc] = ACTIONS(3133),
    [anon_sym_sizeof] = ACTIONS(3133),
    [anon_sym_typeof] = ACTIONS(3133),
    [anon_sym___makeref] = ACTIONS(3133),
    [anon_sym___reftype] = ACTIONS(3133),
    [anon_sym___refvalue] = ACTIONS(3133),
    [sym_null_literal] = ACTIONS(3133),
    [anon_sym_SQUOTE] = ACTIONS(3135),
    [sym_integer_literal] = ACTIONS(3133),
    [sym_real_literal] = ACTIONS(3135),
    [anon_sym_DQUOTE] = ACTIONS(3135),
    [sym_verbatim_string_literal] = ACTIONS(3135),
    [aux_sym_preproc_if_token1] = ACTIONS(3135),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3135),
    [sym_interpolation_verbatim_start] = ACTIONS(3135),
    [sym_interpolation_raw_start] = ACTIONS(3135),
    [sym_raw_string_start] = ACTIONS(3135),
  },
  [2501] = {
    [sym_preproc_region] = STATE(2501),
    [sym_preproc_endregion] = STATE(2501),
    [sym_preproc_line] = STATE(2501),
    [sym_preproc_pragma] = STATE(2501),
    [sym_preproc_nullable] = STATE(2501),
    [sym_preproc_error] = STATE(2501),
    [sym_preproc_warning] = STATE(2501),
    [sym_preproc_define] = STATE(2501),
    [sym_preproc_undef] = STATE(2501),
    [ts_builtin_sym_end] = ACTIONS(3139),
    [sym__identifier_token] = ACTIONS(3137),
    [anon_sym_extern] = ACTIONS(3137),
    [anon_sym_alias] = ACTIONS(3137),
    [anon_sym_SEMI] = ACTIONS(3139),
    [anon_sym_global] = ACTIONS(3137),
    [anon_sym_using] = ACTIONS(3137),
    [anon_sym_unsafe] = ACTIONS(3137),
    [anon_sym_static] = ACTIONS(3137),
    [anon_sym_LBRACK] = ACTIONS(3139),
    [anon_sym_LPAREN] = ACTIONS(3139),
    [anon_sym_return] = ACTIONS(3137),
    [anon_sym_namespace] = ACTIONS(3137),
    [anon_sym_class] = ACTIONS(3137),
    [anon_sym_ref] = ACTIONS(3137),
    [anon_sym_struct] = ACTIONS(3137),
    [anon_sym_enum] = ACTIONS(3137),
    [anon_sym_LBRACE] = ACTIONS(3139),
    [anon_sym_interface] = ACTIONS(3137),
    [anon_sym_delegate] = ACTIONS(3137),
    [anon_sym_record] = ACTIONS(3137),
    [anon_sym_abstract] = ACTIONS(3137),
    [anon_sym_async] = ACTIONS(3137),
    [anon_sym_const] = ACTIONS(3137),
    [anon_sym_file] = ACTIONS(3137),
    [anon_sym_fixed] = ACTIONS(3137),
    [anon_sym_internal] = ACTIONS(3137),
    [anon_sym_new] = ACTIONS(3137),
    [anon_sym_override] = ACTIONS(3137),
    [anon_sym_partial] = ACTIONS(3137),
    [anon_sym_private] = ACTIONS(3137),
    [anon_sym_protected] = ACTIONS(3137),
    [anon_sym_public] = ACTIONS(3137),
    [anon_sym_readonly] = ACTIONS(3137),
    [anon_sym_required] = ACTIONS(3137),
    [anon_sym_sealed] = ACTIONS(3137),
    [anon_sym_virtual] = ACTIONS(3137),
    [anon_sym_volatile] = ACTIONS(3137),
    [anon_sym_where] = ACTIONS(3137),
    [anon_sym_notnull] = ACTIONS(3137),
    [anon_sym_unmanaged] = ACTIONS(3137),
    [anon_sym_checked] = ACTIONS(3137),
    [anon_sym_BANG] = ACTIONS(3139),
    [anon_sym_TILDE] = ACTIONS(3139),
    [anon_sym_PLUS_PLUS] = ACTIONS(3139),
    [anon_sym_DASH_DASH] = ACTIONS(3139),
    [anon_sym_true] = ACTIONS(3137),
    [anon_sym_false] = ACTIONS(3137),
    [anon_sym_PLUS] = ACTIONS(3137),
    [anon_sym_DASH] = ACTIONS(3137),
    [anon_sym_STAR] = ACTIONS(3139),
    [anon_sym_CARET] = ACTIONS(3139),
    [anon_sym_AMP] = ACTIONS(3139),
    [anon_sym_this] = ACTIONS(3137),
    [anon_sym_scoped] = ACTIONS(3137),
    [anon_sym_base] = ACTIONS(3137),
    [anon_sym_var] = ACTIONS(3137),
    [sym_predefined_type] = ACTIONS(3137),
    [anon_sym_break] = ACTIONS(3137),
    [anon_sym_unchecked] = ACTIONS(3137),
    [anon_sym_continue] = ACTIONS(3137),
    [anon_sym_do] = ACTIONS(3137),
    [anon_sym_while] = ACTIONS(3137),
    [anon_sym_for] = ACTIONS(3137),
    [anon_sym_lock] = ACTIONS(3137),
    [anon_sym_yield] = ACTIONS(3137),
    [anon_sym_switch] = ACTIONS(3137),
    [anon_sym_default] = ACTIONS(3137),
    [anon_sym_throw] = ACTIONS(3137),
    [anon_sym_try] = ACTIONS(3137),
    [anon_sym_when] = ACTIONS(3137),
    [anon_sym_await] = ACTIONS(3137),
    [anon_sym_foreach] = ACTIONS(3137),
    [anon_sym_goto] = ACTIONS(3137),
    [anon_sym_if] = ACTIONS(3137),
    [anon_sym_else] = ACTIONS(3137),
    [anon_sym_DOT_DOT] = ACTIONS(3139),
    [anon_sym_from] = ACTIONS(3137),
    [anon_sym_into] = ACTIONS(3137),
    [anon_sym_join] = ACTIONS(3137),
    [anon_sym_on] = ACTIONS(3137),
    [anon_sym_equals] = ACTIONS(3137),
    [anon_sym_let] = ACTIONS(3137),
    [anon_sym_orderby] = ACTIONS(3137),
    [anon_sym_ascending] = ACTIONS(3137),
    [anon_sym_descending] = ACTIONS(3137),
    [anon_sym_group] = ACTIONS(3137),
    [anon_sym_by] = ACTIONS(3137),
    [anon_sym_select] = ACTIONS(3137),
    [anon_sym_stackalloc] = ACTIONS(3137),
    [anon_sym_sizeof] = ACTIONS(3137),
    [anon_sym_typeof] = ACTIONS(3137),
    [anon_sym___makeref] = ACTIONS(3137),
    [anon_sym___reftype] = ACTIONS(3137),
    [anon_sym___refvalue] = ACTIONS(3137),
    [sym_null_literal] = ACTIONS(3137),
    [anon_sym_SQUOTE] = ACTIONS(3139),
    [sym_integer_literal] = ACTIONS(3137),
    [sym_real_literal] = ACTIONS(3139),
    [anon_sym_DQUOTE] = ACTIONS(3139),
    [sym_verbatim_string_literal] = ACTIONS(3139),
    [aux_sym_preproc_if_token1] = ACTIONS(3139),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3139),
    [sym_interpolation_verbatim_start] = ACTIONS(3139),
    [sym_interpolation_raw_start] = ACTIONS(3139),
    [sym_raw_string_start] = ACTIONS(3139),
  },
  [2502] = {
    [sym_preproc_region] = STATE(2502),
    [sym_preproc_endregion] = STATE(2502),
    [sym_preproc_line] = STATE(2502),
    [sym_preproc_pragma] = STATE(2502),
    [sym_preproc_nullable] = STATE(2502),
    [sym_preproc_error] = STATE(2502),
    [sym_preproc_warning] = STATE(2502),
    [sym_preproc_define] = STATE(2502),
    [sym_preproc_undef] = STATE(2502),
    [ts_builtin_sym_end] = ACTIONS(3361),
    [sym__identifier_token] = ACTIONS(3359),
    [anon_sym_extern] = ACTIONS(3359),
    [anon_sym_alias] = ACTIONS(3359),
    [anon_sym_SEMI] = ACTIONS(3361),
    [anon_sym_global] = ACTIONS(3359),
    [anon_sym_using] = ACTIONS(3359),
    [anon_sym_unsafe] = ACTIONS(3359),
    [anon_sym_static] = ACTIONS(3359),
    [anon_sym_LBRACK] = ACTIONS(3361),
    [anon_sym_LPAREN] = ACTIONS(3361),
    [anon_sym_return] = ACTIONS(3359),
    [anon_sym_namespace] = ACTIONS(3359),
    [anon_sym_class] = ACTIONS(3359),
    [anon_sym_ref] = ACTIONS(3359),
    [anon_sym_struct] = ACTIONS(3359),
    [anon_sym_enum] = ACTIONS(3359),
    [anon_sym_LBRACE] = ACTIONS(3361),
    [anon_sym_interface] = ACTIONS(3359),
    [anon_sym_delegate] = ACTIONS(3359),
    [anon_sym_record] = ACTIONS(3359),
    [anon_sym_abstract] = ACTIONS(3359),
    [anon_sym_async] = ACTIONS(3359),
    [anon_sym_const] = ACTIONS(3359),
    [anon_sym_file] = ACTIONS(3359),
    [anon_sym_fixed] = ACTIONS(3359),
    [anon_sym_internal] = ACTIONS(3359),
    [anon_sym_new] = ACTIONS(3359),
    [anon_sym_override] = ACTIONS(3359),
    [anon_sym_partial] = ACTIONS(3359),
    [anon_sym_private] = ACTIONS(3359),
    [anon_sym_protected] = ACTIONS(3359),
    [anon_sym_public] = ACTIONS(3359),
    [anon_sym_readonly] = ACTIONS(3359),
    [anon_sym_required] = ACTIONS(3359),
    [anon_sym_sealed] = ACTIONS(3359),
    [anon_sym_virtual] = ACTIONS(3359),
    [anon_sym_volatile] = ACTIONS(3359),
    [anon_sym_where] = ACTIONS(3359),
    [anon_sym_notnull] = ACTIONS(3359),
    [anon_sym_unmanaged] = ACTIONS(3359),
    [anon_sym_checked] = ACTIONS(3359),
    [anon_sym_BANG] = ACTIONS(3361),
    [anon_sym_TILDE] = ACTIONS(3361),
    [anon_sym_PLUS_PLUS] = ACTIONS(3361),
    [anon_sym_DASH_DASH] = ACTIONS(3361),
    [anon_sym_true] = ACTIONS(3359),
    [anon_sym_false] = ACTIONS(3359),
    [anon_sym_PLUS] = ACTIONS(3359),
    [anon_sym_DASH] = ACTIONS(3359),
    [anon_sym_STAR] = ACTIONS(3361),
    [anon_sym_CARET] = ACTIONS(3361),
    [anon_sym_AMP] = ACTIONS(3361),
    [anon_sym_this] = ACTIONS(3359),
    [anon_sym_scoped] = ACTIONS(3359),
    [anon_sym_base] = ACTIONS(3359),
    [anon_sym_var] = ACTIONS(3359),
    [sym_predefined_type] = ACTIONS(3359),
    [anon_sym_break] = ACTIONS(3359),
    [anon_sym_unchecked] = ACTIONS(3359),
    [anon_sym_continue] = ACTIONS(3359),
    [anon_sym_do] = ACTIONS(3359),
    [anon_sym_while] = ACTIONS(3359),
    [anon_sym_for] = ACTIONS(3359),
    [anon_sym_lock] = ACTIONS(3359),
    [anon_sym_yield] = ACTIONS(3359),
    [anon_sym_switch] = ACTIONS(3359),
    [anon_sym_default] = ACTIONS(3359),
    [anon_sym_throw] = ACTIONS(3359),
    [anon_sym_try] = ACTIONS(3359),
    [anon_sym_when] = ACTIONS(3359),
    [anon_sym_await] = ACTIONS(3359),
    [anon_sym_foreach] = ACTIONS(3359),
    [anon_sym_goto] = ACTIONS(3359),
    [anon_sym_if] = ACTIONS(3359),
    [anon_sym_else] = ACTIONS(3359),
    [anon_sym_DOT_DOT] = ACTIONS(3361),
    [anon_sym_from] = ACTIONS(3359),
    [anon_sym_into] = ACTIONS(3359),
    [anon_sym_join] = ACTIONS(3359),
    [anon_sym_on] = ACTIONS(3359),
    [anon_sym_equals] = ACTIONS(3359),
    [anon_sym_let] = ACTIONS(3359),
    [anon_sym_orderby] = ACTIONS(3359),
    [anon_sym_ascending] = ACTIONS(3359),
    [anon_sym_descending] = ACTIONS(3359),
    [anon_sym_group] = ACTIONS(3359),
    [anon_sym_by] = ACTIONS(3359),
    [anon_sym_select] = ACTIONS(3359),
    [anon_sym_stackalloc] = ACTIONS(3359),
    [anon_sym_sizeof] = ACTIONS(3359),
    [anon_sym_typeof] = ACTIONS(3359),
    [anon_sym___makeref] = ACTIONS(3359),
    [anon_sym___reftype] = ACTIONS(3359),
    [anon_sym___refvalue] = ACTIONS(3359),
    [sym_null_literal] = ACTIONS(3359),
    [anon_sym_SQUOTE] = ACTIONS(3361),
    [sym_integer_literal] = ACTIONS(3359),
    [sym_real_literal] = ACTIONS(3361),
    [anon_sym_DQUOTE] = ACTIONS(3361),
    [sym_verbatim_string_literal] = ACTIONS(3361),
    [aux_sym_preproc_if_token1] = ACTIONS(3361),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3361),
    [sym_interpolation_verbatim_start] = ACTIONS(3361),
    [sym_interpolation_raw_start] = ACTIONS(3361),
    [sym_raw_string_start] = ACTIONS(3361),
  },
  [2503] = {
    [sym_preproc_region] = STATE(2503),
    [sym_preproc_endregion] = STATE(2503),
    [sym_preproc_line] = STATE(2503),
    [sym_preproc_pragma] = STATE(2503),
    [sym_preproc_nullable] = STATE(2503),
    [sym_preproc_error] = STATE(2503),
    [sym_preproc_warning] = STATE(2503),
    [sym_preproc_define] = STATE(2503),
    [sym_preproc_undef] = STATE(2503),
    [ts_builtin_sym_end] = ACTIONS(3283),
    [sym__identifier_token] = ACTIONS(3281),
    [anon_sym_extern] = ACTIONS(3281),
    [anon_sym_alias] = ACTIONS(3281),
    [anon_sym_SEMI] = ACTIONS(3283),
    [anon_sym_global] = ACTIONS(3281),
    [anon_sym_using] = ACTIONS(3281),
    [anon_sym_unsafe] = ACTIONS(3281),
    [anon_sym_static] = ACTIONS(3281),
    [anon_sym_LBRACK] = ACTIONS(3283),
    [anon_sym_LPAREN] = ACTIONS(3283),
    [anon_sym_return] = ACTIONS(3281),
    [anon_sym_namespace] = ACTIONS(3281),
    [anon_sym_class] = ACTIONS(3281),
    [anon_sym_ref] = ACTIONS(3281),
    [anon_sym_struct] = ACTIONS(3281),
    [anon_sym_enum] = ACTIONS(3281),
    [anon_sym_LBRACE] = ACTIONS(3283),
    [anon_sym_interface] = ACTIONS(3281),
    [anon_sym_delegate] = ACTIONS(3281),
    [anon_sym_record] = ACTIONS(3281),
    [anon_sym_abstract] = ACTIONS(3281),
    [anon_sym_async] = ACTIONS(3281),
    [anon_sym_const] = ACTIONS(3281),
    [anon_sym_file] = ACTIONS(3281),
    [anon_sym_fixed] = ACTIONS(3281),
    [anon_sym_internal] = ACTIONS(3281),
    [anon_sym_new] = ACTIONS(3281),
    [anon_sym_override] = ACTIONS(3281),
    [anon_sym_partial] = ACTIONS(3281),
    [anon_sym_private] = ACTIONS(3281),
    [anon_sym_protected] = ACTIONS(3281),
    [anon_sym_public] = ACTIONS(3281),
    [anon_sym_readonly] = ACTIONS(3281),
    [anon_sym_required] = ACTIONS(3281),
    [anon_sym_sealed] = ACTIONS(3281),
    [anon_sym_virtual] = ACTIONS(3281),
    [anon_sym_volatile] = ACTIONS(3281),
    [anon_sym_where] = ACTIONS(3281),
    [anon_sym_notnull] = ACTIONS(3281),
    [anon_sym_unmanaged] = ACTIONS(3281),
    [anon_sym_checked] = ACTIONS(3281),
    [anon_sym_BANG] = ACTIONS(3283),
    [anon_sym_TILDE] = ACTIONS(3283),
    [anon_sym_PLUS_PLUS] = ACTIONS(3283),
    [anon_sym_DASH_DASH] = ACTIONS(3283),
    [anon_sym_true] = ACTIONS(3281),
    [anon_sym_false] = ACTIONS(3281),
    [anon_sym_PLUS] = ACTIONS(3281),
    [anon_sym_DASH] = ACTIONS(3281),
    [anon_sym_STAR] = ACTIONS(3283),
    [anon_sym_CARET] = ACTIONS(3283),
    [anon_sym_AMP] = ACTIONS(3283),
    [anon_sym_this] = ACTIONS(3281),
    [anon_sym_scoped] = ACTIONS(3281),
    [anon_sym_base] = ACTIONS(3281),
    [anon_sym_var] = ACTIONS(3281),
    [sym_predefined_type] = ACTIONS(3281),
    [anon_sym_break] = ACTIONS(3281),
    [anon_sym_unchecked] = ACTIONS(3281),
    [anon_sym_continue] = ACTIONS(3281),
    [anon_sym_do] = ACTIONS(3281),
    [anon_sym_while] = ACTIONS(3281),
    [anon_sym_for] = ACTIONS(3281),
    [anon_sym_lock] = ACTIONS(3281),
    [anon_sym_yield] = ACTIONS(3281),
    [anon_sym_switch] = ACTIONS(3281),
    [anon_sym_default] = ACTIONS(3281),
    [anon_sym_throw] = ACTIONS(3281),
    [anon_sym_try] = ACTIONS(3281),
    [anon_sym_when] = ACTIONS(3281),
    [anon_sym_await] = ACTIONS(3281),
    [anon_sym_foreach] = ACTIONS(3281),
    [anon_sym_goto] = ACTIONS(3281),
    [anon_sym_if] = ACTIONS(3281),
    [anon_sym_else] = ACTIONS(3281),
    [anon_sym_DOT_DOT] = ACTIONS(3283),
    [anon_sym_from] = ACTIONS(3281),
    [anon_sym_into] = ACTIONS(3281),
    [anon_sym_join] = ACTIONS(3281),
    [anon_sym_on] = ACTIONS(3281),
    [anon_sym_equals] = ACTIONS(3281),
    [anon_sym_let] = ACTIONS(3281),
    [anon_sym_orderby] = ACTIONS(3281),
    [anon_sym_ascending] = ACTIONS(3281),
    [anon_sym_descending] = ACTIONS(3281),
    [anon_sym_group] = ACTIONS(3281),
    [anon_sym_by] = ACTIONS(3281),
    [anon_sym_select] = ACTIONS(3281),
    [anon_sym_stackalloc] = ACTIONS(3281),
    [anon_sym_sizeof] = ACTIONS(3281),
    [anon_sym_typeof] = ACTIONS(3281),
    [anon_sym___makeref] = ACTIONS(3281),
    [anon_sym___reftype] = ACTIONS(3281),
    [anon_sym___refvalue] = ACTIONS(3281),
    [sym_null_literal] = ACTIONS(3281),
    [anon_sym_SQUOTE] = ACTIONS(3283),
    [sym_integer_literal] = ACTIONS(3281),
    [sym_real_literal] = ACTIONS(3283),
    [anon_sym_DQUOTE] = ACTIONS(3283),
    [sym_verbatim_string_literal] = ACTIONS(3283),
    [aux_sym_preproc_if_token1] = ACTIONS(3283),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3283),
    [sym_interpolation_verbatim_start] = ACTIONS(3283),
    [sym_interpolation_raw_start] = ACTIONS(3283),
    [sym_raw_string_start] = ACTIONS(3283),
  },
  [2504] = {
    [sym_preproc_region] = STATE(2504),
    [sym_preproc_endregion] = STATE(2504),
    [sym_preproc_line] = STATE(2504),
    [sym_preproc_pragma] = STATE(2504),
    [sym_preproc_nullable] = STATE(2504),
    [sym_preproc_error] = STATE(2504),
    [sym_preproc_warning] = STATE(2504),
    [sym_preproc_define] = STATE(2504),
    [sym_preproc_undef] = STATE(2504),
    [ts_builtin_sym_end] = ACTIONS(3315),
    [sym__identifier_token] = ACTIONS(3313),
    [anon_sym_extern] = ACTIONS(3313),
    [anon_sym_alias] = ACTIONS(3313),
    [anon_sym_SEMI] = ACTIONS(3315),
    [anon_sym_global] = ACTIONS(3313),
    [anon_sym_using] = ACTIONS(3313),
    [anon_sym_unsafe] = ACTIONS(3313),
    [anon_sym_static] = ACTIONS(3313),
    [anon_sym_LBRACK] = ACTIONS(3315),
    [anon_sym_LPAREN] = ACTIONS(3315),
    [anon_sym_return] = ACTIONS(3313),
    [anon_sym_namespace] = ACTIONS(3313),
    [anon_sym_class] = ACTIONS(3313),
    [anon_sym_ref] = ACTIONS(3313),
    [anon_sym_struct] = ACTIONS(3313),
    [anon_sym_enum] = ACTIONS(3313),
    [anon_sym_LBRACE] = ACTIONS(3315),
    [anon_sym_interface] = ACTIONS(3313),
    [anon_sym_delegate] = ACTIONS(3313),
    [anon_sym_record] = ACTIONS(3313),
    [anon_sym_abstract] = ACTIONS(3313),
    [anon_sym_async] = ACTIONS(3313),
    [anon_sym_const] = ACTIONS(3313),
    [anon_sym_file] = ACTIONS(3313),
    [anon_sym_fixed] = ACTIONS(3313),
    [anon_sym_internal] = ACTIONS(3313),
    [anon_sym_new] = ACTIONS(3313),
    [anon_sym_override] = ACTIONS(3313),
    [anon_sym_partial] = ACTIONS(3313),
    [anon_sym_private] = ACTIONS(3313),
    [anon_sym_protected] = ACTIONS(3313),
    [anon_sym_public] = ACTIONS(3313),
    [anon_sym_readonly] = ACTIONS(3313),
    [anon_sym_required] = ACTIONS(3313),
    [anon_sym_sealed] = ACTIONS(3313),
    [anon_sym_virtual] = ACTIONS(3313),
    [anon_sym_volatile] = ACTIONS(3313),
    [anon_sym_where] = ACTIONS(3313),
    [anon_sym_notnull] = ACTIONS(3313),
    [anon_sym_unmanaged] = ACTIONS(3313),
    [anon_sym_checked] = ACTIONS(3313),
    [anon_sym_BANG] = ACTIONS(3315),
    [anon_sym_TILDE] = ACTIONS(3315),
    [anon_sym_PLUS_PLUS] = ACTIONS(3315),
    [anon_sym_DASH_DASH] = ACTIONS(3315),
    [anon_sym_true] = ACTIONS(3313),
    [anon_sym_false] = ACTIONS(3313),
    [anon_sym_PLUS] = ACTIONS(3313),
    [anon_sym_DASH] = ACTIONS(3313),
    [anon_sym_STAR] = ACTIONS(3315),
    [anon_sym_CARET] = ACTIONS(3315),
    [anon_sym_AMP] = ACTIONS(3315),
    [anon_sym_this] = ACTIONS(3313),
    [anon_sym_scoped] = ACTIONS(3313),
    [anon_sym_base] = ACTIONS(3313),
    [anon_sym_var] = ACTIONS(3313),
    [sym_predefined_type] = ACTIONS(3313),
    [anon_sym_break] = ACTIONS(3313),
    [anon_sym_unchecked] = ACTIONS(3313),
    [anon_sym_continue] = ACTIONS(3313),
    [anon_sym_do] = ACTIONS(3313),
    [anon_sym_while] = ACTIONS(3313),
    [anon_sym_for] = ACTIONS(3313),
    [anon_sym_lock] = ACTIONS(3313),
    [anon_sym_yield] = ACTIONS(3313),
    [anon_sym_switch] = ACTIONS(3313),
    [anon_sym_default] = ACTIONS(3313),
    [anon_sym_throw] = ACTIONS(3313),
    [anon_sym_try] = ACTIONS(3313),
    [anon_sym_when] = ACTIONS(3313),
    [anon_sym_await] = ACTIONS(3313),
    [anon_sym_foreach] = ACTIONS(3313),
    [anon_sym_goto] = ACTIONS(3313),
    [anon_sym_if] = ACTIONS(3313),
    [anon_sym_else] = ACTIONS(3313),
    [anon_sym_DOT_DOT] = ACTIONS(3315),
    [anon_sym_from] = ACTIONS(3313),
    [anon_sym_into] = ACTIONS(3313),
    [anon_sym_join] = ACTIONS(3313),
    [anon_sym_on] = ACTIONS(3313),
    [anon_sym_equals] = ACTIONS(3313),
    [anon_sym_let] = ACTIONS(3313),
    [anon_sym_orderby] = ACTIONS(3313),
    [anon_sym_ascending] = ACTIONS(3313),
    [anon_sym_descending] = ACTIONS(3313),
    [anon_sym_group] = ACTIONS(3313),
    [anon_sym_by] = ACTIONS(3313),
    [anon_sym_select] = ACTIONS(3313),
    [anon_sym_stackalloc] = ACTIONS(3313),
    [anon_sym_sizeof] = ACTIONS(3313),
    [anon_sym_typeof] = ACTIONS(3313),
    [anon_sym___makeref] = ACTIONS(3313),
    [anon_sym___reftype] = ACTIONS(3313),
    [anon_sym___refvalue] = ACTIONS(3313),
    [sym_null_literal] = ACTIONS(3313),
    [anon_sym_SQUOTE] = ACTIONS(3315),
    [sym_integer_literal] = ACTIONS(3313),
    [sym_real_literal] = ACTIONS(3315),
    [anon_sym_DQUOTE] = ACTIONS(3315),
    [sym_verbatim_string_literal] = ACTIONS(3315),
    [aux_sym_preproc_if_token1] = ACTIONS(3315),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3315),
    [sym_interpolation_verbatim_start] = ACTIONS(3315),
    [sym_interpolation_raw_start] = ACTIONS(3315),
    [sym_raw_string_start] = ACTIONS(3315),
  },
  [2505] = {
    [sym_preproc_region] = STATE(2505),
    [sym_preproc_endregion] = STATE(2505),
    [sym_preproc_line] = STATE(2505),
    [sym_preproc_pragma] = STATE(2505),
    [sym_preproc_nullable] = STATE(2505),
    [sym_preproc_error] = STATE(2505),
    [sym_preproc_warning] = STATE(2505),
    [sym_preproc_define] = STATE(2505),
    [sym_preproc_undef] = STATE(2505),
    [ts_builtin_sym_end] = ACTIONS(3403),
    [sym__identifier_token] = ACTIONS(3401),
    [anon_sym_extern] = ACTIONS(3401),
    [anon_sym_alias] = ACTIONS(3401),
    [anon_sym_SEMI] = ACTIONS(3403),
    [anon_sym_global] = ACTIONS(3401),
    [anon_sym_using] = ACTIONS(3401),
    [anon_sym_unsafe] = ACTIONS(3401),
    [anon_sym_static] = ACTIONS(3401),
    [anon_sym_LBRACK] = ACTIONS(3403),
    [anon_sym_LPAREN] = ACTIONS(3403),
    [anon_sym_return] = ACTIONS(3401),
    [anon_sym_namespace] = ACTIONS(3401),
    [anon_sym_class] = ACTIONS(3401),
    [anon_sym_ref] = ACTIONS(3401),
    [anon_sym_struct] = ACTIONS(3401),
    [anon_sym_enum] = ACTIONS(3401),
    [anon_sym_LBRACE] = ACTIONS(3403),
    [anon_sym_interface] = ACTIONS(3401),
    [anon_sym_delegate] = ACTIONS(3401),
    [anon_sym_record] = ACTIONS(3401),
    [anon_sym_abstract] = ACTIONS(3401),
    [anon_sym_async] = ACTIONS(3401),
    [anon_sym_const] = ACTIONS(3401),
    [anon_sym_file] = ACTIONS(3401),
    [anon_sym_fixed] = ACTIONS(3401),
    [anon_sym_internal] = ACTIONS(3401),
    [anon_sym_new] = ACTIONS(3401),
    [anon_sym_override] = ACTIONS(3401),
    [anon_sym_partial] = ACTIONS(3401),
    [anon_sym_private] = ACTIONS(3401),
    [anon_sym_protected] = ACTIONS(3401),
    [anon_sym_public] = ACTIONS(3401),
    [anon_sym_readonly] = ACTIONS(3401),
    [anon_sym_required] = ACTIONS(3401),
    [anon_sym_sealed] = ACTIONS(3401),
    [anon_sym_virtual] = ACTIONS(3401),
    [anon_sym_volatile] = ACTIONS(3401),
    [anon_sym_where] = ACTIONS(3401),
    [anon_sym_notnull] = ACTIONS(3401),
    [anon_sym_unmanaged] = ACTIONS(3401),
    [anon_sym_checked] = ACTIONS(3401),
    [anon_sym_BANG] = ACTIONS(3403),
    [anon_sym_TILDE] = ACTIONS(3403),
    [anon_sym_PLUS_PLUS] = ACTIONS(3403),
    [anon_sym_DASH_DASH] = ACTIONS(3403),
    [anon_sym_true] = ACTIONS(3401),
    [anon_sym_false] = ACTIONS(3401),
    [anon_sym_PLUS] = ACTIONS(3401),
    [anon_sym_DASH] = ACTIONS(3401),
    [anon_sym_STAR] = ACTIONS(3403),
    [anon_sym_CARET] = ACTIONS(3403),
    [anon_sym_AMP] = ACTIONS(3403),
    [anon_sym_this] = ACTIONS(3401),
    [anon_sym_scoped] = ACTIONS(3401),
    [anon_sym_base] = ACTIONS(3401),
    [anon_sym_var] = ACTIONS(3401),
    [sym_predefined_type] = ACTIONS(3401),
    [anon_sym_break] = ACTIONS(3401),
    [anon_sym_unchecked] = ACTIONS(3401),
    [anon_sym_continue] = ACTIONS(3401),
    [anon_sym_do] = ACTIONS(3401),
    [anon_sym_while] = ACTIONS(3401),
    [anon_sym_for] = ACTIONS(3401),
    [anon_sym_lock] = ACTIONS(3401),
    [anon_sym_yield] = ACTIONS(3401),
    [anon_sym_switch] = ACTIONS(3401),
    [anon_sym_default] = ACTIONS(3401),
    [anon_sym_throw] = ACTIONS(3401),
    [anon_sym_try] = ACTIONS(3401),
    [anon_sym_when] = ACTIONS(3401),
    [anon_sym_await] = ACTIONS(3401),
    [anon_sym_foreach] = ACTIONS(3401),
    [anon_sym_goto] = ACTIONS(3401),
    [anon_sym_if] = ACTIONS(3401),
    [anon_sym_else] = ACTIONS(3401),
    [anon_sym_DOT_DOT] = ACTIONS(3403),
    [anon_sym_from] = ACTIONS(3401),
    [anon_sym_into] = ACTIONS(3401),
    [anon_sym_join] = ACTIONS(3401),
    [anon_sym_on] = ACTIONS(3401),
    [anon_sym_equals] = ACTIONS(3401),
    [anon_sym_let] = ACTIONS(3401),
    [anon_sym_orderby] = ACTIONS(3401),
    [anon_sym_ascending] = ACTIONS(3401),
    [anon_sym_descending] = ACTIONS(3401),
    [anon_sym_group] = ACTIONS(3401),
    [anon_sym_by] = ACTIONS(3401),
    [anon_sym_select] = ACTIONS(3401),
    [anon_sym_stackalloc] = ACTIONS(3401),
    [anon_sym_sizeof] = ACTIONS(3401),
    [anon_sym_typeof] = ACTIONS(3401),
    [anon_sym___makeref] = ACTIONS(3401),
    [anon_sym___reftype] = ACTIONS(3401),
    [anon_sym___refvalue] = ACTIONS(3401),
    [sym_null_literal] = ACTIONS(3401),
    [anon_sym_SQUOTE] = ACTIONS(3403),
    [sym_integer_literal] = ACTIONS(3401),
    [sym_real_literal] = ACTIONS(3403),
    [anon_sym_DQUOTE] = ACTIONS(3403),
    [sym_verbatim_string_literal] = ACTIONS(3403),
    [aux_sym_preproc_if_token1] = ACTIONS(3403),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3403),
    [sym_interpolation_verbatim_start] = ACTIONS(3403),
    [sym_interpolation_raw_start] = ACTIONS(3403),
    [sym_raw_string_start] = ACTIONS(3403),
  },
  [2506] = {
    [sym_preproc_region] = STATE(2506),
    [sym_preproc_endregion] = STATE(2506),
    [sym_preproc_line] = STATE(2506),
    [sym_preproc_pragma] = STATE(2506),
    [sym_preproc_nullable] = STATE(2506),
    [sym_preproc_error] = STATE(2506),
    [sym_preproc_warning] = STATE(2506),
    [sym_preproc_define] = STATE(2506),
    [sym_preproc_undef] = STATE(2506),
    [ts_builtin_sym_end] = ACTIONS(3095),
    [sym__identifier_token] = ACTIONS(3093),
    [anon_sym_extern] = ACTIONS(3093),
    [anon_sym_alias] = ACTIONS(3093),
    [anon_sym_SEMI] = ACTIONS(3095),
    [anon_sym_global] = ACTIONS(3093),
    [anon_sym_using] = ACTIONS(3093),
    [anon_sym_unsafe] = ACTIONS(3093),
    [anon_sym_static] = ACTIONS(3093),
    [anon_sym_LBRACK] = ACTIONS(3095),
    [anon_sym_LPAREN] = ACTIONS(3095),
    [anon_sym_return] = ACTIONS(3093),
    [anon_sym_namespace] = ACTIONS(3093),
    [anon_sym_class] = ACTIONS(3093),
    [anon_sym_ref] = ACTIONS(3093),
    [anon_sym_struct] = ACTIONS(3093),
    [anon_sym_enum] = ACTIONS(3093),
    [anon_sym_LBRACE] = ACTIONS(3095),
    [anon_sym_interface] = ACTIONS(3093),
    [anon_sym_delegate] = ACTIONS(3093),
    [anon_sym_record] = ACTIONS(3093),
    [anon_sym_abstract] = ACTIONS(3093),
    [anon_sym_async] = ACTIONS(3093),
    [anon_sym_const] = ACTIONS(3093),
    [anon_sym_file] = ACTIONS(3093),
    [anon_sym_fixed] = ACTIONS(3093),
    [anon_sym_internal] = ACTIONS(3093),
    [anon_sym_new] = ACTIONS(3093),
    [anon_sym_override] = ACTIONS(3093),
    [anon_sym_partial] = ACTIONS(3093),
    [anon_sym_private] = ACTIONS(3093),
    [anon_sym_protected] = ACTIONS(3093),
    [anon_sym_public] = ACTIONS(3093),
    [anon_sym_readonly] = ACTIONS(3093),
    [anon_sym_required] = ACTIONS(3093),
    [anon_sym_sealed] = ACTIONS(3093),
    [anon_sym_virtual] = ACTIONS(3093),
    [anon_sym_volatile] = ACTIONS(3093),
    [anon_sym_where] = ACTIONS(3093),
    [anon_sym_notnull] = ACTIONS(3093),
    [anon_sym_unmanaged] = ACTIONS(3093),
    [anon_sym_checked] = ACTIONS(3093),
    [anon_sym_BANG] = ACTIONS(3095),
    [anon_sym_TILDE] = ACTIONS(3095),
    [anon_sym_PLUS_PLUS] = ACTIONS(3095),
    [anon_sym_DASH_DASH] = ACTIONS(3095),
    [anon_sym_true] = ACTIONS(3093),
    [anon_sym_false] = ACTIONS(3093),
    [anon_sym_PLUS] = ACTIONS(3093),
    [anon_sym_DASH] = ACTIONS(3093),
    [anon_sym_STAR] = ACTIONS(3095),
    [anon_sym_CARET] = ACTIONS(3095),
    [anon_sym_AMP] = ACTIONS(3095),
    [anon_sym_this] = ACTIONS(3093),
    [anon_sym_scoped] = ACTIONS(3093),
    [anon_sym_base] = ACTIONS(3093),
    [anon_sym_var] = ACTIONS(3093),
    [sym_predefined_type] = ACTIONS(3093),
    [anon_sym_break] = ACTIONS(3093),
    [anon_sym_unchecked] = ACTIONS(3093),
    [anon_sym_continue] = ACTIONS(3093),
    [anon_sym_do] = ACTIONS(3093),
    [anon_sym_while] = ACTIONS(3093),
    [anon_sym_for] = ACTIONS(3093),
    [anon_sym_lock] = ACTIONS(3093),
    [anon_sym_yield] = ACTIONS(3093),
    [anon_sym_switch] = ACTIONS(3093),
    [anon_sym_default] = ACTIONS(3093),
    [anon_sym_throw] = ACTIONS(3093),
    [anon_sym_try] = ACTIONS(3093),
    [anon_sym_when] = ACTIONS(3093),
    [anon_sym_await] = ACTIONS(3093),
    [anon_sym_foreach] = ACTIONS(3093),
    [anon_sym_goto] = ACTIONS(3093),
    [anon_sym_if] = ACTIONS(3093),
    [anon_sym_else] = ACTIONS(3093),
    [anon_sym_DOT_DOT] = ACTIONS(3095),
    [anon_sym_from] = ACTIONS(3093),
    [anon_sym_into] = ACTIONS(3093),
    [anon_sym_join] = ACTIONS(3093),
    [anon_sym_on] = ACTIONS(3093),
    [anon_sym_equals] = ACTIONS(3093),
    [anon_sym_let] = ACTIONS(3093),
    [anon_sym_orderby] = ACTIONS(3093),
    [anon_sym_ascending] = ACTIONS(3093),
    [anon_sym_descending] = ACTIONS(3093),
    [anon_sym_group] = ACTIONS(3093),
    [anon_sym_by] = ACTIONS(3093),
    [anon_sym_select] = ACTIONS(3093),
    [anon_sym_stackalloc] = ACTIONS(3093),
    [anon_sym_sizeof] = ACTIONS(3093),
    [anon_sym_typeof] = ACTIONS(3093),
    [anon_sym___makeref] = ACTIONS(3093),
    [anon_sym___reftype] = ACTIONS(3093),
    [anon_sym___refvalue] = ACTIONS(3093),
    [sym_null_literal] = ACTIONS(3093),
    [anon_sym_SQUOTE] = ACTIONS(3095),
    [sym_integer_literal] = ACTIONS(3093),
    [sym_real_literal] = ACTIONS(3095),
    [anon_sym_DQUOTE] = ACTIONS(3095),
    [sym_verbatim_string_literal] = ACTIONS(3095),
    [aux_sym_preproc_if_token1] = ACTIONS(3095),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3095),
    [sym_interpolation_verbatim_start] = ACTIONS(3095),
    [sym_interpolation_raw_start] = ACTIONS(3095),
    [sym_raw_string_start] = ACTIONS(3095),
  },
  [2507] = {
    [sym_preproc_region] = STATE(2507),
    [sym_preproc_endregion] = STATE(2507),
    [sym_preproc_line] = STATE(2507),
    [sym_preproc_pragma] = STATE(2507),
    [sym_preproc_nullable] = STATE(2507),
    [sym_preproc_error] = STATE(2507),
    [sym_preproc_warning] = STATE(2507),
    [sym_preproc_define] = STATE(2507),
    [sym_preproc_undef] = STATE(2507),
    [ts_builtin_sym_end] = ACTIONS(3143),
    [sym__identifier_token] = ACTIONS(3141),
    [anon_sym_extern] = ACTIONS(3141),
    [anon_sym_alias] = ACTIONS(3141),
    [anon_sym_SEMI] = ACTIONS(3143),
    [anon_sym_global] = ACTIONS(3141),
    [anon_sym_using] = ACTIONS(3141),
    [anon_sym_unsafe] = ACTIONS(3141),
    [anon_sym_static] = ACTIONS(3141),
    [anon_sym_LBRACK] = ACTIONS(3143),
    [anon_sym_LPAREN] = ACTIONS(3143),
    [anon_sym_return] = ACTIONS(3141),
    [anon_sym_namespace] = ACTIONS(3141),
    [anon_sym_class] = ACTIONS(3141),
    [anon_sym_ref] = ACTIONS(3141),
    [anon_sym_struct] = ACTIONS(3141),
    [anon_sym_enum] = ACTIONS(3141),
    [anon_sym_LBRACE] = ACTIONS(3143),
    [anon_sym_interface] = ACTIONS(3141),
    [anon_sym_delegate] = ACTIONS(3141),
    [anon_sym_record] = ACTIONS(3141),
    [anon_sym_abstract] = ACTIONS(3141),
    [anon_sym_async] = ACTIONS(3141),
    [anon_sym_const] = ACTIONS(3141),
    [anon_sym_file] = ACTIONS(3141),
    [anon_sym_fixed] = ACTIONS(3141),
    [anon_sym_internal] = ACTIONS(3141),
    [anon_sym_new] = ACTIONS(3141),
    [anon_sym_override] = ACTIONS(3141),
    [anon_sym_partial] = ACTIONS(3141),
    [anon_sym_private] = ACTIONS(3141),
    [anon_sym_protected] = ACTIONS(3141),
    [anon_sym_public] = ACTIONS(3141),
    [anon_sym_readonly] = ACTIONS(3141),
    [anon_sym_required] = ACTIONS(3141),
    [anon_sym_sealed] = ACTIONS(3141),
    [anon_sym_virtual] = ACTIONS(3141),
    [anon_sym_volatile] = ACTIONS(3141),
    [anon_sym_where] = ACTIONS(3141),
    [anon_sym_notnull] = ACTIONS(3141),
    [anon_sym_unmanaged] = ACTIONS(3141),
    [anon_sym_checked] = ACTIONS(3141),
    [anon_sym_BANG] = ACTIONS(3143),
    [anon_sym_TILDE] = ACTIONS(3143),
    [anon_sym_PLUS_PLUS] = ACTIONS(3143),
    [anon_sym_DASH_DASH] = ACTIONS(3143),
    [anon_sym_true] = ACTIONS(3141),
    [anon_sym_false] = ACTIONS(3141),
    [anon_sym_PLUS] = ACTIONS(3141),
    [anon_sym_DASH] = ACTIONS(3141),
    [anon_sym_STAR] = ACTIONS(3143),
    [anon_sym_CARET] = ACTIONS(3143),
    [anon_sym_AMP] = ACTIONS(3143),
    [anon_sym_this] = ACTIONS(3141),
    [anon_sym_scoped] = ACTIONS(3141),
    [anon_sym_base] = ACTIONS(3141),
    [anon_sym_var] = ACTIONS(3141),
    [sym_predefined_type] = ACTIONS(3141),
    [anon_sym_break] = ACTIONS(3141),
    [anon_sym_unchecked] = ACTIONS(3141),
    [anon_sym_continue] = ACTIONS(3141),
    [anon_sym_do] = ACTIONS(3141),
    [anon_sym_while] = ACTIONS(3141),
    [anon_sym_for] = ACTIONS(3141),
    [anon_sym_lock] = ACTIONS(3141),
    [anon_sym_yield] = ACTIONS(3141),
    [anon_sym_switch] = ACTIONS(3141),
    [anon_sym_default] = ACTIONS(3141),
    [anon_sym_throw] = ACTIONS(3141),
    [anon_sym_try] = ACTIONS(3141),
    [anon_sym_when] = ACTIONS(3141),
    [anon_sym_await] = ACTIONS(3141),
    [anon_sym_foreach] = ACTIONS(3141),
    [anon_sym_goto] = ACTIONS(3141),
    [anon_sym_if] = ACTIONS(3141),
    [anon_sym_else] = ACTIONS(3141),
    [anon_sym_DOT_DOT] = ACTIONS(3143),
    [anon_sym_from] = ACTIONS(3141),
    [anon_sym_into] = ACTIONS(3141),
    [anon_sym_join] = ACTIONS(3141),
    [anon_sym_on] = ACTIONS(3141),
    [anon_sym_equals] = ACTIONS(3141),
    [anon_sym_let] = ACTIONS(3141),
    [anon_sym_orderby] = ACTIONS(3141),
    [anon_sym_ascending] = ACTIONS(3141),
    [anon_sym_descending] = ACTIONS(3141),
    [anon_sym_group] = ACTIONS(3141),
    [anon_sym_by] = ACTIONS(3141),
    [anon_sym_select] = ACTIONS(3141),
    [anon_sym_stackalloc] = ACTIONS(3141),
    [anon_sym_sizeof] = ACTIONS(3141),
    [anon_sym_typeof] = ACTIONS(3141),
    [anon_sym___makeref] = ACTIONS(3141),
    [anon_sym___reftype] = ACTIONS(3141),
    [anon_sym___refvalue] = ACTIONS(3141),
    [sym_null_literal] = ACTIONS(3141),
    [anon_sym_SQUOTE] = ACTIONS(3143),
    [sym_integer_literal] = ACTIONS(3141),
    [sym_real_literal] = ACTIONS(3143),
    [anon_sym_DQUOTE] = ACTIONS(3143),
    [sym_verbatim_string_literal] = ACTIONS(3143),
    [aux_sym_preproc_if_token1] = ACTIONS(3143),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3143),
    [sym_interpolation_verbatim_start] = ACTIONS(3143),
    [sym_interpolation_raw_start] = ACTIONS(3143),
    [sym_raw_string_start] = ACTIONS(3143),
  },
  [2508] = {
    [sym_preproc_region] = STATE(2508),
    [sym_preproc_endregion] = STATE(2508),
    [sym_preproc_line] = STATE(2508),
    [sym_preproc_pragma] = STATE(2508),
    [sym_preproc_nullable] = STATE(2508),
    [sym_preproc_error] = STATE(2508),
    [sym_preproc_warning] = STATE(2508),
    [sym_preproc_define] = STATE(2508),
    [sym_preproc_undef] = STATE(2508),
    [ts_builtin_sym_end] = ACTIONS(3063),
    [sym__identifier_token] = ACTIONS(3061),
    [anon_sym_extern] = ACTIONS(3061),
    [anon_sym_alias] = ACTIONS(3061),
    [anon_sym_SEMI] = ACTIONS(3063),
    [anon_sym_global] = ACTIONS(3061),
    [anon_sym_using] = ACTIONS(3061),
    [anon_sym_unsafe] = ACTIONS(3061),
    [anon_sym_static] = ACTIONS(3061),
    [anon_sym_LBRACK] = ACTIONS(3063),
    [anon_sym_LPAREN] = ACTIONS(3063),
    [anon_sym_return] = ACTIONS(3061),
    [anon_sym_namespace] = ACTIONS(3061),
    [anon_sym_class] = ACTIONS(3061),
    [anon_sym_ref] = ACTIONS(3061),
    [anon_sym_struct] = ACTIONS(3061),
    [anon_sym_enum] = ACTIONS(3061),
    [anon_sym_LBRACE] = ACTIONS(3063),
    [anon_sym_interface] = ACTIONS(3061),
    [anon_sym_delegate] = ACTIONS(3061),
    [anon_sym_record] = ACTIONS(3061),
    [anon_sym_abstract] = ACTIONS(3061),
    [anon_sym_async] = ACTIONS(3061),
    [anon_sym_const] = ACTIONS(3061),
    [anon_sym_file] = ACTIONS(3061),
    [anon_sym_fixed] = ACTIONS(3061),
    [anon_sym_internal] = ACTIONS(3061),
    [anon_sym_new] = ACTIONS(3061),
    [anon_sym_override] = ACTIONS(3061),
    [anon_sym_partial] = ACTIONS(3061),
    [anon_sym_private] = ACTIONS(3061),
    [anon_sym_protected] = ACTIONS(3061),
    [anon_sym_public] = ACTIONS(3061),
    [anon_sym_readonly] = ACTIONS(3061),
    [anon_sym_required] = ACTIONS(3061),
    [anon_sym_sealed] = ACTIONS(3061),
    [anon_sym_virtual] = ACTIONS(3061),
    [anon_sym_volatile] = ACTIONS(3061),
    [anon_sym_where] = ACTIONS(3061),
    [anon_sym_notnull] = ACTIONS(3061),
    [anon_sym_unmanaged] = ACTIONS(3061),
    [anon_sym_checked] = ACTIONS(3061),
    [anon_sym_BANG] = ACTIONS(3063),
    [anon_sym_TILDE] = ACTIONS(3063),
    [anon_sym_PLUS_PLUS] = ACTIONS(3063),
    [anon_sym_DASH_DASH] = ACTIONS(3063),
    [anon_sym_true] = ACTIONS(3061),
    [anon_sym_false] = ACTIONS(3061),
    [anon_sym_PLUS] = ACTIONS(3061),
    [anon_sym_DASH] = ACTIONS(3061),
    [anon_sym_STAR] = ACTIONS(3063),
    [anon_sym_CARET] = ACTIONS(3063),
    [anon_sym_AMP] = ACTIONS(3063),
    [anon_sym_this] = ACTIONS(3061),
    [anon_sym_scoped] = ACTIONS(3061),
    [anon_sym_base] = ACTIONS(3061),
    [anon_sym_var] = ACTIONS(3061),
    [sym_predefined_type] = ACTIONS(3061),
    [anon_sym_break] = ACTIONS(3061),
    [anon_sym_unchecked] = ACTIONS(3061),
    [anon_sym_continue] = ACTIONS(3061),
    [anon_sym_do] = ACTIONS(3061),
    [anon_sym_while] = ACTIONS(3061),
    [anon_sym_for] = ACTIONS(3061),
    [anon_sym_lock] = ACTIONS(3061),
    [anon_sym_yield] = ACTIONS(3061),
    [anon_sym_switch] = ACTIONS(3061),
    [anon_sym_default] = ACTIONS(3061),
    [anon_sym_throw] = ACTIONS(3061),
    [anon_sym_try] = ACTIONS(3061),
    [anon_sym_when] = ACTIONS(3061),
    [anon_sym_await] = ACTIONS(3061),
    [anon_sym_foreach] = ACTIONS(3061),
    [anon_sym_goto] = ACTIONS(3061),
    [anon_sym_if] = ACTIONS(3061),
    [anon_sym_else] = ACTIONS(3061),
    [anon_sym_DOT_DOT] = ACTIONS(3063),
    [anon_sym_from] = ACTIONS(3061),
    [anon_sym_into] = ACTIONS(3061),
    [anon_sym_join] = ACTIONS(3061),
    [anon_sym_on] = ACTIONS(3061),
    [anon_sym_equals] = ACTIONS(3061),
    [anon_sym_let] = ACTIONS(3061),
    [anon_sym_orderby] = ACTIONS(3061),
    [anon_sym_ascending] = ACTIONS(3061),
    [anon_sym_descending] = ACTIONS(3061),
    [anon_sym_group] = ACTIONS(3061),
    [anon_sym_by] = ACTIONS(3061),
    [anon_sym_select] = ACTIONS(3061),
    [anon_sym_stackalloc] = ACTIONS(3061),
    [anon_sym_sizeof] = ACTIONS(3061),
    [anon_sym_typeof] = ACTIONS(3061),
    [anon_sym___makeref] = ACTIONS(3061),
    [anon_sym___reftype] = ACTIONS(3061),
    [anon_sym___refvalue] = ACTIONS(3061),
    [sym_null_literal] = ACTIONS(3061),
    [anon_sym_SQUOTE] = ACTIONS(3063),
    [sym_integer_literal] = ACTIONS(3061),
    [sym_real_literal] = ACTIONS(3063),
    [anon_sym_DQUOTE] = ACTIONS(3063),
    [sym_verbatim_string_literal] = ACTIONS(3063),
    [aux_sym_preproc_if_token1] = ACTIONS(3063),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3063),
    [sym_interpolation_verbatim_start] = ACTIONS(3063),
    [sym_interpolation_raw_start] = ACTIONS(3063),
    [sym_raw_string_start] = ACTIONS(3063),
  },
  [2509] = {
    [sym_preproc_region] = STATE(2509),
    [sym_preproc_endregion] = STATE(2509),
    [sym_preproc_line] = STATE(2509),
    [sym_preproc_pragma] = STATE(2509),
    [sym_preproc_nullable] = STATE(2509),
    [sym_preproc_error] = STATE(2509),
    [sym_preproc_warning] = STATE(2509),
    [sym_preproc_define] = STATE(2509),
    [sym_preproc_undef] = STATE(2509),
    [ts_builtin_sym_end] = ACTIONS(3147),
    [sym__identifier_token] = ACTIONS(3145),
    [anon_sym_extern] = ACTIONS(3145),
    [anon_sym_alias] = ACTIONS(3145),
    [anon_sym_SEMI] = ACTIONS(3147),
    [anon_sym_global] = ACTIONS(3145),
    [anon_sym_using] = ACTIONS(3145),
    [anon_sym_unsafe] = ACTIONS(3145),
    [anon_sym_static] = ACTIONS(3145),
    [anon_sym_LBRACK] = ACTIONS(3147),
    [anon_sym_LPAREN] = ACTIONS(3147),
    [anon_sym_return] = ACTIONS(3145),
    [anon_sym_namespace] = ACTIONS(3145),
    [anon_sym_class] = ACTIONS(3145),
    [anon_sym_ref] = ACTIONS(3145),
    [anon_sym_struct] = ACTIONS(3145),
    [anon_sym_enum] = ACTIONS(3145),
    [anon_sym_LBRACE] = ACTIONS(3147),
    [anon_sym_interface] = ACTIONS(3145),
    [anon_sym_delegate] = ACTIONS(3145),
    [anon_sym_record] = ACTIONS(3145),
    [anon_sym_abstract] = ACTIONS(3145),
    [anon_sym_async] = ACTIONS(3145),
    [anon_sym_const] = ACTIONS(3145),
    [anon_sym_file] = ACTIONS(3145),
    [anon_sym_fixed] = ACTIONS(3145),
    [anon_sym_internal] = ACTIONS(3145),
    [anon_sym_new] = ACTIONS(3145),
    [anon_sym_override] = ACTIONS(3145),
    [anon_sym_partial] = ACTIONS(3145),
    [anon_sym_private] = ACTIONS(3145),
    [anon_sym_protected] = ACTIONS(3145),
    [anon_sym_public] = ACTIONS(3145),
    [anon_sym_readonly] = ACTIONS(3145),
    [anon_sym_required] = ACTIONS(3145),
    [anon_sym_sealed] = ACTIONS(3145),
    [anon_sym_virtual] = ACTIONS(3145),
    [anon_sym_volatile] = ACTIONS(3145),
    [anon_sym_where] = ACTIONS(3145),
    [anon_sym_notnull] = ACTIONS(3145),
    [anon_sym_unmanaged] = ACTIONS(3145),
    [anon_sym_checked] = ACTIONS(3145),
    [anon_sym_BANG] = ACTIONS(3147),
    [anon_sym_TILDE] = ACTIONS(3147),
    [anon_sym_PLUS_PLUS] = ACTIONS(3147),
    [anon_sym_DASH_DASH] = ACTIONS(3147),
    [anon_sym_true] = ACTIONS(3145),
    [anon_sym_false] = ACTIONS(3145),
    [anon_sym_PLUS] = ACTIONS(3145),
    [anon_sym_DASH] = ACTIONS(3145),
    [anon_sym_STAR] = ACTIONS(3147),
    [anon_sym_CARET] = ACTIONS(3147),
    [anon_sym_AMP] = ACTIONS(3147),
    [anon_sym_this] = ACTIONS(3145),
    [anon_sym_scoped] = ACTIONS(3145),
    [anon_sym_base] = ACTIONS(3145),
    [anon_sym_var] = ACTIONS(3145),
    [sym_predefined_type] = ACTIONS(3145),
    [anon_sym_break] = ACTIONS(3145),
    [anon_sym_unchecked] = ACTIONS(3145),
    [anon_sym_continue] = ACTIONS(3145),
    [anon_sym_do] = ACTIONS(3145),
    [anon_sym_while] = ACTIONS(3145),
    [anon_sym_for] = ACTIONS(3145),
    [anon_sym_lock] = ACTIONS(3145),
    [anon_sym_yield] = ACTIONS(3145),
    [anon_sym_switch] = ACTIONS(3145),
    [anon_sym_default] = ACTIONS(3145),
    [anon_sym_throw] = ACTIONS(3145),
    [anon_sym_try] = ACTIONS(3145),
    [anon_sym_when] = ACTIONS(3145),
    [anon_sym_await] = ACTIONS(3145),
    [anon_sym_foreach] = ACTIONS(3145),
    [anon_sym_goto] = ACTIONS(3145),
    [anon_sym_if] = ACTIONS(3145),
    [anon_sym_else] = ACTIONS(3145),
    [anon_sym_DOT_DOT] = ACTIONS(3147),
    [anon_sym_from] = ACTIONS(3145),
    [anon_sym_into] = ACTIONS(3145),
    [anon_sym_join] = ACTIONS(3145),
    [anon_sym_on] = ACTIONS(3145),
    [anon_sym_equals] = ACTIONS(3145),
    [anon_sym_let] = ACTIONS(3145),
    [anon_sym_orderby] = ACTIONS(3145),
    [anon_sym_ascending] = ACTIONS(3145),
    [anon_sym_descending] = ACTIONS(3145),
    [anon_sym_group] = ACTIONS(3145),
    [anon_sym_by] = ACTIONS(3145),
    [anon_sym_select] = ACTIONS(3145),
    [anon_sym_stackalloc] = ACTIONS(3145),
    [anon_sym_sizeof] = ACTIONS(3145),
    [anon_sym_typeof] = ACTIONS(3145),
    [anon_sym___makeref] = ACTIONS(3145),
    [anon_sym___reftype] = ACTIONS(3145),
    [anon_sym___refvalue] = ACTIONS(3145),
    [sym_null_literal] = ACTIONS(3145),
    [anon_sym_SQUOTE] = ACTIONS(3147),
    [sym_integer_literal] = ACTIONS(3145),
    [sym_real_literal] = ACTIONS(3147),
    [anon_sym_DQUOTE] = ACTIONS(3147),
    [sym_verbatim_string_literal] = ACTIONS(3147),
    [aux_sym_preproc_if_token1] = ACTIONS(3147),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3147),
    [sym_interpolation_verbatim_start] = ACTIONS(3147),
    [sym_interpolation_raw_start] = ACTIONS(3147),
    [sym_raw_string_start] = ACTIONS(3147),
  },
  [2510] = {
    [sym_preproc_region] = STATE(2510),
    [sym_preproc_endregion] = STATE(2510),
    [sym_preproc_line] = STATE(2510),
    [sym_preproc_pragma] = STATE(2510),
    [sym_preproc_nullable] = STATE(2510),
    [sym_preproc_error] = STATE(2510),
    [sym_preproc_warning] = STATE(2510),
    [sym_preproc_define] = STATE(2510),
    [sym_preproc_undef] = STATE(2510),
    [ts_builtin_sym_end] = ACTIONS(3151),
    [sym__identifier_token] = ACTIONS(3149),
    [anon_sym_extern] = ACTIONS(3149),
    [anon_sym_alias] = ACTIONS(3149),
    [anon_sym_SEMI] = ACTIONS(3151),
    [anon_sym_global] = ACTIONS(3149),
    [anon_sym_using] = ACTIONS(3149),
    [anon_sym_unsafe] = ACTIONS(3149),
    [anon_sym_static] = ACTIONS(3149),
    [anon_sym_LBRACK] = ACTIONS(3151),
    [anon_sym_LPAREN] = ACTIONS(3151),
    [anon_sym_return] = ACTIONS(3149),
    [anon_sym_namespace] = ACTIONS(3149),
    [anon_sym_class] = ACTIONS(3149),
    [anon_sym_ref] = ACTIONS(3149),
    [anon_sym_struct] = ACTIONS(3149),
    [anon_sym_enum] = ACTIONS(3149),
    [anon_sym_LBRACE] = ACTIONS(3151),
    [anon_sym_interface] = ACTIONS(3149),
    [anon_sym_delegate] = ACTIONS(3149),
    [anon_sym_record] = ACTIONS(3149),
    [anon_sym_abstract] = ACTIONS(3149),
    [anon_sym_async] = ACTIONS(3149),
    [anon_sym_const] = ACTIONS(3149),
    [anon_sym_file] = ACTIONS(3149),
    [anon_sym_fixed] = ACTIONS(3149),
    [anon_sym_internal] = ACTIONS(3149),
    [anon_sym_new] = ACTIONS(3149),
    [anon_sym_override] = ACTIONS(3149),
    [anon_sym_partial] = ACTIONS(3149),
    [anon_sym_private] = ACTIONS(3149),
    [anon_sym_protected] = ACTIONS(3149),
    [anon_sym_public] = ACTIONS(3149),
    [anon_sym_readonly] = ACTIONS(3149),
    [anon_sym_required] = ACTIONS(3149),
    [anon_sym_sealed] = ACTIONS(3149),
    [anon_sym_virtual] = ACTIONS(3149),
    [anon_sym_volatile] = ACTIONS(3149),
    [anon_sym_where] = ACTIONS(3149),
    [anon_sym_notnull] = ACTIONS(3149),
    [anon_sym_unmanaged] = ACTIONS(3149),
    [anon_sym_checked] = ACTIONS(3149),
    [anon_sym_BANG] = ACTIONS(3151),
    [anon_sym_TILDE] = ACTIONS(3151),
    [anon_sym_PLUS_PLUS] = ACTIONS(3151),
    [anon_sym_DASH_DASH] = ACTIONS(3151),
    [anon_sym_true] = ACTIONS(3149),
    [anon_sym_false] = ACTIONS(3149),
    [anon_sym_PLUS] = ACTIONS(3149),
    [anon_sym_DASH] = ACTIONS(3149),
    [anon_sym_STAR] = ACTIONS(3151),
    [anon_sym_CARET] = ACTIONS(3151),
    [anon_sym_AMP] = ACTIONS(3151),
    [anon_sym_this] = ACTIONS(3149),
    [anon_sym_scoped] = ACTIONS(3149),
    [anon_sym_base] = ACTIONS(3149),
    [anon_sym_var] = ACTIONS(3149),
    [sym_predefined_type] = ACTIONS(3149),
    [anon_sym_break] = ACTIONS(3149),
    [anon_sym_unchecked] = ACTIONS(3149),
    [anon_sym_continue] = ACTIONS(3149),
    [anon_sym_do] = ACTIONS(3149),
    [anon_sym_while] = ACTIONS(3149),
    [anon_sym_for] = ACTIONS(3149),
    [anon_sym_lock] = ACTIONS(3149),
    [anon_sym_yield] = ACTIONS(3149),
    [anon_sym_switch] = ACTIONS(3149),
    [anon_sym_default] = ACTIONS(3149),
    [anon_sym_throw] = ACTIONS(3149),
    [anon_sym_try] = ACTIONS(3149),
    [anon_sym_when] = ACTIONS(3149),
    [anon_sym_await] = ACTIONS(3149),
    [anon_sym_foreach] = ACTIONS(3149),
    [anon_sym_goto] = ACTIONS(3149),
    [anon_sym_if] = ACTIONS(3149),
    [anon_sym_else] = ACTIONS(3149),
    [anon_sym_DOT_DOT] = ACTIONS(3151),
    [anon_sym_from] = ACTIONS(3149),
    [anon_sym_into] = ACTIONS(3149),
    [anon_sym_join] = ACTIONS(3149),
    [anon_sym_on] = ACTIONS(3149),
    [anon_sym_equals] = ACTIONS(3149),
    [anon_sym_let] = ACTIONS(3149),
    [anon_sym_orderby] = ACTIONS(3149),
    [anon_sym_ascending] = ACTIONS(3149),
    [anon_sym_descending] = ACTIONS(3149),
    [anon_sym_group] = ACTIONS(3149),
    [anon_sym_by] = ACTIONS(3149),
    [anon_sym_select] = ACTIONS(3149),
    [anon_sym_stackalloc] = ACTIONS(3149),
    [anon_sym_sizeof] = ACTIONS(3149),
    [anon_sym_typeof] = ACTIONS(3149),
    [anon_sym___makeref] = ACTIONS(3149),
    [anon_sym___reftype] = ACTIONS(3149),
    [anon_sym___refvalue] = ACTIONS(3149),
    [sym_null_literal] = ACTIONS(3149),
    [anon_sym_SQUOTE] = ACTIONS(3151),
    [sym_integer_literal] = ACTIONS(3149),
    [sym_real_literal] = ACTIONS(3151),
    [anon_sym_DQUOTE] = ACTIONS(3151),
    [sym_verbatim_string_literal] = ACTIONS(3151),
    [aux_sym_preproc_if_token1] = ACTIONS(3151),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3151),
    [sym_interpolation_verbatim_start] = ACTIONS(3151),
    [sym_interpolation_raw_start] = ACTIONS(3151),
    [sym_raw_string_start] = ACTIONS(3151),
  },
  [2511] = {
    [sym_preproc_region] = STATE(2511),
    [sym_preproc_endregion] = STATE(2511),
    [sym_preproc_line] = STATE(2511),
    [sym_preproc_pragma] = STATE(2511),
    [sym_preproc_nullable] = STATE(2511),
    [sym_preproc_error] = STATE(2511),
    [sym_preproc_warning] = STATE(2511),
    [sym_preproc_define] = STATE(2511),
    [sym_preproc_undef] = STATE(2511),
    [ts_builtin_sym_end] = ACTIONS(3299),
    [sym__identifier_token] = ACTIONS(3297),
    [anon_sym_extern] = ACTIONS(3297),
    [anon_sym_alias] = ACTIONS(3297),
    [anon_sym_SEMI] = ACTIONS(3299),
    [anon_sym_global] = ACTIONS(3297),
    [anon_sym_using] = ACTIONS(3297),
    [anon_sym_unsafe] = ACTIONS(3297),
    [anon_sym_static] = ACTIONS(3297),
    [anon_sym_LBRACK] = ACTIONS(3299),
    [anon_sym_LPAREN] = ACTIONS(3299),
    [anon_sym_return] = ACTIONS(3297),
    [anon_sym_namespace] = ACTIONS(3297),
    [anon_sym_class] = ACTIONS(3297),
    [anon_sym_ref] = ACTIONS(3297),
    [anon_sym_struct] = ACTIONS(3297),
    [anon_sym_enum] = ACTIONS(3297),
    [anon_sym_LBRACE] = ACTIONS(3299),
    [anon_sym_interface] = ACTIONS(3297),
    [anon_sym_delegate] = ACTIONS(3297),
    [anon_sym_record] = ACTIONS(3297),
    [anon_sym_abstract] = ACTIONS(3297),
    [anon_sym_async] = ACTIONS(3297),
    [anon_sym_const] = ACTIONS(3297),
    [anon_sym_file] = ACTIONS(3297),
    [anon_sym_fixed] = ACTIONS(3297),
    [anon_sym_internal] = ACTIONS(3297),
    [anon_sym_new] = ACTIONS(3297),
    [anon_sym_override] = ACTIONS(3297),
    [anon_sym_partial] = ACTIONS(3297),
    [anon_sym_private] = ACTIONS(3297),
    [anon_sym_protected] = ACTIONS(3297),
    [anon_sym_public] = ACTIONS(3297),
    [anon_sym_readonly] = ACTIONS(3297),
    [anon_sym_required] = ACTIONS(3297),
    [anon_sym_sealed] = ACTIONS(3297),
    [anon_sym_virtual] = ACTIONS(3297),
    [anon_sym_volatile] = ACTIONS(3297),
    [anon_sym_where] = ACTIONS(3297),
    [anon_sym_notnull] = ACTIONS(3297),
    [anon_sym_unmanaged] = ACTIONS(3297),
    [anon_sym_checked] = ACTIONS(3297),
    [anon_sym_BANG] = ACTIONS(3299),
    [anon_sym_TILDE] = ACTIONS(3299),
    [anon_sym_PLUS_PLUS] = ACTIONS(3299),
    [anon_sym_DASH_DASH] = ACTIONS(3299),
    [anon_sym_true] = ACTIONS(3297),
    [anon_sym_false] = ACTIONS(3297),
    [anon_sym_PLUS] = ACTIONS(3297),
    [anon_sym_DASH] = ACTIONS(3297),
    [anon_sym_STAR] = ACTIONS(3299),
    [anon_sym_CARET] = ACTIONS(3299),
    [anon_sym_AMP] = ACTIONS(3299),
    [anon_sym_this] = ACTIONS(3297),
    [anon_sym_scoped] = ACTIONS(3297),
    [anon_sym_base] = ACTIONS(3297),
    [anon_sym_var] = ACTIONS(3297),
    [sym_predefined_type] = ACTIONS(3297),
    [anon_sym_break] = ACTIONS(3297),
    [anon_sym_unchecked] = ACTIONS(3297),
    [anon_sym_continue] = ACTIONS(3297),
    [anon_sym_do] = ACTIONS(3297),
    [anon_sym_while] = ACTIONS(3297),
    [anon_sym_for] = ACTIONS(3297),
    [anon_sym_lock] = ACTIONS(3297),
    [anon_sym_yield] = ACTIONS(3297),
    [anon_sym_switch] = ACTIONS(3297),
    [anon_sym_default] = ACTIONS(3297),
    [anon_sym_throw] = ACTIONS(3297),
    [anon_sym_try] = ACTIONS(3297),
    [anon_sym_when] = ACTIONS(3297),
    [anon_sym_await] = ACTIONS(3297),
    [anon_sym_foreach] = ACTIONS(3297),
    [anon_sym_goto] = ACTIONS(3297),
    [anon_sym_if] = ACTIONS(3297),
    [anon_sym_else] = ACTIONS(3297),
    [anon_sym_DOT_DOT] = ACTIONS(3299),
    [anon_sym_from] = ACTIONS(3297),
    [anon_sym_into] = ACTIONS(3297),
    [anon_sym_join] = ACTIONS(3297),
    [anon_sym_on] = ACTIONS(3297),
    [anon_sym_equals] = ACTIONS(3297),
    [anon_sym_let] = ACTIONS(3297),
    [anon_sym_orderby] = ACTIONS(3297),
    [anon_sym_ascending] = ACTIONS(3297),
    [anon_sym_descending] = ACTIONS(3297),
    [anon_sym_group] = ACTIONS(3297),
    [anon_sym_by] = ACTIONS(3297),
    [anon_sym_select] = ACTIONS(3297),
    [anon_sym_stackalloc] = ACTIONS(3297),
    [anon_sym_sizeof] = ACTIONS(3297),
    [anon_sym_typeof] = ACTIONS(3297),
    [anon_sym___makeref] = ACTIONS(3297),
    [anon_sym___reftype] = ACTIONS(3297),
    [anon_sym___refvalue] = ACTIONS(3297),
    [sym_null_literal] = ACTIONS(3297),
    [anon_sym_SQUOTE] = ACTIONS(3299),
    [sym_integer_literal] = ACTIONS(3297),
    [sym_real_literal] = ACTIONS(3299),
    [anon_sym_DQUOTE] = ACTIONS(3299),
    [sym_verbatim_string_literal] = ACTIONS(3299),
    [aux_sym_preproc_if_token1] = ACTIONS(3299),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3299),
    [sym_interpolation_verbatim_start] = ACTIONS(3299),
    [sym_interpolation_raw_start] = ACTIONS(3299),
    [sym_raw_string_start] = ACTIONS(3299),
  },
  [2512] = {
    [sym_preproc_region] = STATE(2512),
    [sym_preproc_endregion] = STATE(2512),
    [sym_preproc_line] = STATE(2512),
    [sym_preproc_pragma] = STATE(2512),
    [sym_preproc_nullable] = STATE(2512),
    [sym_preproc_error] = STATE(2512),
    [sym_preproc_warning] = STATE(2512),
    [sym_preproc_define] = STATE(2512),
    [sym_preproc_undef] = STATE(2512),
    [ts_builtin_sym_end] = ACTIONS(3155),
    [sym__identifier_token] = ACTIONS(3153),
    [anon_sym_extern] = ACTIONS(3153),
    [anon_sym_alias] = ACTIONS(3153),
    [anon_sym_SEMI] = ACTIONS(3155),
    [anon_sym_global] = ACTIONS(3153),
    [anon_sym_using] = ACTIONS(3153),
    [anon_sym_unsafe] = ACTIONS(3153),
    [anon_sym_static] = ACTIONS(3153),
    [anon_sym_LBRACK] = ACTIONS(3155),
    [anon_sym_LPAREN] = ACTIONS(3155),
    [anon_sym_return] = ACTIONS(3153),
    [anon_sym_namespace] = ACTIONS(3153),
    [anon_sym_class] = ACTIONS(3153),
    [anon_sym_ref] = ACTIONS(3153),
    [anon_sym_struct] = ACTIONS(3153),
    [anon_sym_enum] = ACTIONS(3153),
    [anon_sym_LBRACE] = ACTIONS(3155),
    [anon_sym_interface] = ACTIONS(3153),
    [anon_sym_delegate] = ACTIONS(3153),
    [anon_sym_record] = ACTIONS(3153),
    [anon_sym_abstract] = ACTIONS(3153),
    [anon_sym_async] = ACTIONS(3153),
    [anon_sym_const] = ACTIONS(3153),
    [anon_sym_file] = ACTIONS(3153),
    [anon_sym_fixed] = ACTIONS(3153),
    [anon_sym_internal] = ACTIONS(3153),
    [anon_sym_new] = ACTIONS(3153),
    [anon_sym_override] = ACTIONS(3153),
    [anon_sym_partial] = ACTIONS(3153),
    [anon_sym_private] = ACTIONS(3153),
    [anon_sym_protected] = ACTIONS(3153),
    [anon_sym_public] = ACTIONS(3153),
    [anon_sym_readonly] = ACTIONS(3153),
    [anon_sym_required] = ACTIONS(3153),
    [anon_sym_sealed] = ACTIONS(3153),
    [anon_sym_virtual] = ACTIONS(3153),
    [anon_sym_volatile] = ACTIONS(3153),
    [anon_sym_where] = ACTIONS(3153),
    [anon_sym_notnull] = ACTIONS(3153),
    [anon_sym_unmanaged] = ACTIONS(3153),
    [anon_sym_checked] = ACTIONS(3153),
    [anon_sym_BANG] = ACTIONS(3155),
    [anon_sym_TILDE] = ACTIONS(3155),
    [anon_sym_PLUS_PLUS] = ACTIONS(3155),
    [anon_sym_DASH_DASH] = ACTIONS(3155),
    [anon_sym_true] = ACTIONS(3153),
    [anon_sym_false] = ACTIONS(3153),
    [anon_sym_PLUS] = ACTIONS(3153),
    [anon_sym_DASH] = ACTIONS(3153),
    [anon_sym_STAR] = ACTIONS(3155),
    [anon_sym_CARET] = ACTIONS(3155),
    [anon_sym_AMP] = ACTIONS(3155),
    [anon_sym_this] = ACTIONS(3153),
    [anon_sym_scoped] = ACTIONS(3153),
    [anon_sym_base] = ACTIONS(3153),
    [anon_sym_var] = ACTIONS(3153),
    [sym_predefined_type] = ACTIONS(3153),
    [anon_sym_break] = ACTIONS(3153),
    [anon_sym_unchecked] = ACTIONS(3153),
    [anon_sym_continue] = ACTIONS(3153),
    [anon_sym_do] = ACTIONS(3153),
    [anon_sym_while] = ACTIONS(3153),
    [anon_sym_for] = ACTIONS(3153),
    [anon_sym_lock] = ACTIONS(3153),
    [anon_sym_yield] = ACTIONS(3153),
    [anon_sym_switch] = ACTIONS(3153),
    [anon_sym_default] = ACTIONS(3153),
    [anon_sym_throw] = ACTIONS(3153),
    [anon_sym_try] = ACTIONS(3153),
    [anon_sym_when] = ACTIONS(3153),
    [anon_sym_await] = ACTIONS(3153),
    [anon_sym_foreach] = ACTIONS(3153),
    [anon_sym_goto] = ACTIONS(3153),
    [anon_sym_if] = ACTIONS(3153),
    [anon_sym_else] = ACTIONS(3153),
    [anon_sym_DOT_DOT] = ACTIONS(3155),
    [anon_sym_from] = ACTIONS(3153),
    [anon_sym_into] = ACTIONS(3153),
    [anon_sym_join] = ACTIONS(3153),
    [anon_sym_on] = ACTIONS(3153),
    [anon_sym_equals] = ACTIONS(3153),
    [anon_sym_let] = ACTIONS(3153),
    [anon_sym_orderby] = ACTIONS(3153),
    [anon_sym_ascending] = ACTIONS(3153),
    [anon_sym_descending] = ACTIONS(3153),
    [anon_sym_group] = ACTIONS(3153),
    [anon_sym_by] = ACTIONS(3153),
    [anon_sym_select] = ACTIONS(3153),
    [anon_sym_stackalloc] = ACTIONS(3153),
    [anon_sym_sizeof] = ACTIONS(3153),
    [anon_sym_typeof] = ACTIONS(3153),
    [anon_sym___makeref] = ACTIONS(3153),
    [anon_sym___reftype] = ACTIONS(3153),
    [anon_sym___refvalue] = ACTIONS(3153),
    [sym_null_literal] = ACTIONS(3153),
    [anon_sym_SQUOTE] = ACTIONS(3155),
    [sym_integer_literal] = ACTIONS(3153),
    [sym_real_literal] = ACTIONS(3155),
    [anon_sym_DQUOTE] = ACTIONS(3155),
    [sym_verbatim_string_literal] = ACTIONS(3155),
    [aux_sym_preproc_if_token1] = ACTIONS(3155),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3155),
    [sym_interpolation_verbatim_start] = ACTIONS(3155),
    [sym_interpolation_raw_start] = ACTIONS(3155),
    [sym_raw_string_start] = ACTIONS(3155),
  },
  [2513] = {
    [sym_preproc_region] = STATE(2513),
    [sym_preproc_endregion] = STATE(2513),
    [sym_preproc_line] = STATE(2513),
    [sym_preproc_pragma] = STATE(2513),
    [sym_preproc_nullable] = STATE(2513),
    [sym_preproc_error] = STATE(2513),
    [sym_preproc_warning] = STATE(2513),
    [sym_preproc_define] = STATE(2513),
    [sym_preproc_undef] = STATE(2513),
    [ts_builtin_sym_end] = ACTIONS(3191),
    [sym__identifier_token] = ACTIONS(3189),
    [anon_sym_extern] = ACTIONS(3189),
    [anon_sym_alias] = ACTIONS(3189),
    [anon_sym_SEMI] = ACTIONS(3191),
    [anon_sym_global] = ACTIONS(3189),
    [anon_sym_using] = ACTIONS(3189),
    [anon_sym_unsafe] = ACTIONS(3189),
    [anon_sym_static] = ACTIONS(3189),
    [anon_sym_LBRACK] = ACTIONS(3191),
    [anon_sym_LPAREN] = ACTIONS(3191),
    [anon_sym_return] = ACTIONS(3189),
    [anon_sym_namespace] = ACTIONS(3189),
    [anon_sym_class] = ACTIONS(3189),
    [anon_sym_ref] = ACTIONS(3189),
    [anon_sym_struct] = ACTIONS(3189),
    [anon_sym_enum] = ACTIONS(3189),
    [anon_sym_LBRACE] = ACTIONS(3191),
    [anon_sym_interface] = ACTIONS(3189),
    [anon_sym_delegate] = ACTIONS(3189),
    [anon_sym_record] = ACTIONS(3189),
    [anon_sym_abstract] = ACTIONS(3189),
    [anon_sym_async] = ACTIONS(3189),
    [anon_sym_const] = ACTIONS(3189),
    [anon_sym_file] = ACTIONS(3189),
    [anon_sym_fixed] = ACTIONS(3189),
    [anon_sym_internal] = ACTIONS(3189),
    [anon_sym_new] = ACTIONS(3189),
    [anon_sym_override] = ACTIONS(3189),
    [anon_sym_partial] = ACTIONS(3189),
    [anon_sym_private] = ACTIONS(3189),
    [anon_sym_protected] = ACTIONS(3189),
    [anon_sym_public] = ACTIONS(3189),
    [anon_sym_readonly] = ACTIONS(3189),
    [anon_sym_required] = ACTIONS(3189),
    [anon_sym_sealed] = ACTIONS(3189),
    [anon_sym_virtual] = ACTIONS(3189),
    [anon_sym_volatile] = ACTIONS(3189),
    [anon_sym_where] = ACTIONS(3189),
    [anon_sym_notnull] = ACTIONS(3189),
    [anon_sym_unmanaged] = ACTIONS(3189),
    [anon_sym_checked] = ACTIONS(3189),
    [anon_sym_BANG] = ACTIONS(3191),
    [anon_sym_TILDE] = ACTIONS(3191),
    [anon_sym_PLUS_PLUS] = ACTIONS(3191),
    [anon_sym_DASH_DASH] = ACTIONS(3191),
    [anon_sym_true] = ACTIONS(3189),
    [anon_sym_false] = ACTIONS(3189),
    [anon_sym_PLUS] = ACTIONS(3189),
    [anon_sym_DASH] = ACTIONS(3189),
    [anon_sym_STAR] = ACTIONS(3191),
    [anon_sym_CARET] = ACTIONS(3191),
    [anon_sym_AMP] = ACTIONS(3191),
    [anon_sym_this] = ACTIONS(3189),
    [anon_sym_scoped] = ACTIONS(3189),
    [anon_sym_base] = ACTIONS(3189),
    [anon_sym_var] = ACTIONS(3189),
    [sym_predefined_type] = ACTIONS(3189),
    [anon_sym_break] = ACTIONS(3189),
    [anon_sym_unchecked] = ACTIONS(3189),
    [anon_sym_continue] = ACTIONS(3189),
    [anon_sym_do] = ACTIONS(3189),
    [anon_sym_while] = ACTIONS(3189),
    [anon_sym_for] = ACTIONS(3189),
    [anon_sym_lock] = ACTIONS(3189),
    [anon_sym_yield] = ACTIONS(3189),
    [anon_sym_switch] = ACTIONS(3189),
    [anon_sym_default] = ACTIONS(3189),
    [anon_sym_throw] = ACTIONS(3189),
    [anon_sym_try] = ACTIONS(3189),
    [anon_sym_when] = ACTIONS(3189),
    [anon_sym_await] = ACTIONS(3189),
    [anon_sym_foreach] = ACTIONS(3189),
    [anon_sym_goto] = ACTIONS(3189),
    [anon_sym_if] = ACTIONS(3189),
    [anon_sym_else] = ACTIONS(3189),
    [anon_sym_DOT_DOT] = ACTIONS(3191),
    [anon_sym_from] = ACTIONS(3189),
    [anon_sym_into] = ACTIONS(3189),
    [anon_sym_join] = ACTIONS(3189),
    [anon_sym_on] = ACTIONS(3189),
    [anon_sym_equals] = ACTIONS(3189),
    [anon_sym_let] = ACTIONS(3189),
    [anon_sym_orderby] = ACTIONS(3189),
    [anon_sym_ascending] = ACTIONS(3189),
    [anon_sym_descending] = ACTIONS(3189),
    [anon_sym_group] = ACTIONS(3189),
    [anon_sym_by] = ACTIONS(3189),
    [anon_sym_select] = ACTIONS(3189),
    [anon_sym_stackalloc] = ACTIONS(3189),
    [anon_sym_sizeof] = ACTIONS(3189),
    [anon_sym_typeof] = ACTIONS(3189),
    [anon_sym___makeref] = ACTIONS(3189),
    [anon_sym___reftype] = ACTIONS(3189),
    [anon_sym___refvalue] = ACTIONS(3189),
    [sym_null_literal] = ACTIONS(3189),
    [anon_sym_SQUOTE] = ACTIONS(3191),
    [sym_integer_literal] = ACTIONS(3189),
    [sym_real_literal] = ACTIONS(3191),
    [anon_sym_DQUOTE] = ACTIONS(3191),
    [sym_verbatim_string_literal] = ACTIONS(3191),
    [aux_sym_preproc_if_token1] = ACTIONS(3191),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3191),
    [sym_interpolation_verbatim_start] = ACTIONS(3191),
    [sym_interpolation_raw_start] = ACTIONS(3191),
    [sym_raw_string_start] = ACTIONS(3191),
  },
  [2514] = {
    [sym_preproc_region] = STATE(2514),
    [sym_preproc_endregion] = STATE(2514),
    [sym_preproc_line] = STATE(2514),
    [sym_preproc_pragma] = STATE(2514),
    [sym_preproc_nullable] = STATE(2514),
    [sym_preproc_error] = STATE(2514),
    [sym_preproc_warning] = STATE(2514),
    [sym_preproc_define] = STATE(2514),
    [sym_preproc_undef] = STATE(2514),
    [ts_builtin_sym_end] = ACTIONS(3559),
    [sym__identifier_token] = ACTIONS(3557),
    [anon_sym_extern] = ACTIONS(3557),
    [anon_sym_alias] = ACTIONS(3557),
    [anon_sym_SEMI] = ACTIONS(3559),
    [anon_sym_global] = ACTIONS(3557),
    [anon_sym_using] = ACTIONS(3557),
    [anon_sym_unsafe] = ACTIONS(3557),
    [anon_sym_static] = ACTIONS(3557),
    [anon_sym_LBRACK] = ACTIONS(3559),
    [anon_sym_LPAREN] = ACTIONS(3559),
    [anon_sym_return] = ACTIONS(3557),
    [anon_sym_namespace] = ACTIONS(3557),
    [anon_sym_class] = ACTIONS(3557),
    [anon_sym_ref] = ACTIONS(3557),
    [anon_sym_struct] = ACTIONS(3557),
    [anon_sym_enum] = ACTIONS(3557),
    [anon_sym_LBRACE] = ACTIONS(3559),
    [anon_sym_interface] = ACTIONS(3557),
    [anon_sym_delegate] = ACTIONS(3557),
    [anon_sym_record] = ACTIONS(3557),
    [anon_sym_abstract] = ACTIONS(3557),
    [anon_sym_async] = ACTIONS(3557),
    [anon_sym_const] = ACTIONS(3557),
    [anon_sym_file] = ACTIONS(3557),
    [anon_sym_fixed] = ACTIONS(3557),
    [anon_sym_internal] = ACTIONS(3557),
    [anon_sym_new] = ACTIONS(3557),
    [anon_sym_override] = ACTIONS(3557),
    [anon_sym_partial] = ACTIONS(3557),
    [anon_sym_private] = ACTIONS(3557),
    [anon_sym_protected] = ACTIONS(3557),
    [anon_sym_public] = ACTIONS(3557),
    [anon_sym_readonly] = ACTIONS(3557),
    [anon_sym_required] = ACTIONS(3557),
    [anon_sym_sealed] = ACTIONS(3557),
    [anon_sym_virtual] = ACTIONS(3557),
    [anon_sym_volatile] = ACTIONS(3557),
    [anon_sym_where] = ACTIONS(3557),
    [anon_sym_notnull] = ACTIONS(3557),
    [anon_sym_unmanaged] = ACTIONS(3557),
    [anon_sym_checked] = ACTIONS(3557),
    [anon_sym_BANG] = ACTIONS(3559),
    [anon_sym_TILDE] = ACTIONS(3559),
    [anon_sym_PLUS_PLUS] = ACTIONS(3559),
    [anon_sym_DASH_DASH] = ACTIONS(3559),
    [anon_sym_true] = ACTIONS(3557),
    [anon_sym_false] = ACTIONS(3557),
    [anon_sym_PLUS] = ACTIONS(3557),
    [anon_sym_DASH] = ACTIONS(3557),
    [anon_sym_STAR] = ACTIONS(3559),
    [anon_sym_CARET] = ACTIONS(3559),
    [anon_sym_AMP] = ACTIONS(3559),
    [anon_sym_this] = ACTIONS(3557),
    [anon_sym_scoped] = ACTIONS(3557),
    [anon_sym_base] = ACTIONS(3557),
    [anon_sym_var] = ACTIONS(3557),
    [sym_predefined_type] = ACTIONS(3557),
    [anon_sym_break] = ACTIONS(3557),
    [anon_sym_unchecked] = ACTIONS(3557),
    [anon_sym_continue] = ACTIONS(3557),
    [anon_sym_do] = ACTIONS(3557),
    [anon_sym_while] = ACTIONS(3557),
    [anon_sym_for] = ACTIONS(3557),
    [anon_sym_lock] = ACTIONS(3557),
    [anon_sym_yield] = ACTIONS(3557),
    [anon_sym_switch] = ACTIONS(3557),
    [anon_sym_default] = ACTIONS(3557),
    [anon_sym_throw] = ACTIONS(3557),
    [anon_sym_try] = ACTIONS(3557),
    [anon_sym_when] = ACTIONS(3557),
    [anon_sym_await] = ACTIONS(3557),
    [anon_sym_foreach] = ACTIONS(3557),
    [anon_sym_goto] = ACTIONS(3557),
    [anon_sym_if] = ACTIONS(3557),
    [anon_sym_DOT_DOT] = ACTIONS(3559),
    [anon_sym_from] = ACTIONS(3557),
    [anon_sym_into] = ACTIONS(3557),
    [anon_sym_join] = ACTIONS(3557),
    [anon_sym_on] = ACTIONS(3557),
    [anon_sym_equals] = ACTIONS(3557),
    [anon_sym_let] = ACTIONS(3557),
    [anon_sym_orderby] = ACTIONS(3557),
    [anon_sym_ascending] = ACTIONS(3557),
    [anon_sym_descending] = ACTIONS(3557),
    [anon_sym_group] = ACTIONS(3557),
    [anon_sym_by] = ACTIONS(3557),
    [anon_sym_select] = ACTIONS(3557),
    [anon_sym_stackalloc] = ACTIONS(3557),
    [anon_sym_sizeof] = ACTIONS(3557),
    [anon_sym_typeof] = ACTIONS(3557),
    [anon_sym___makeref] = ACTIONS(3557),
    [anon_sym___reftype] = ACTIONS(3557),
    [anon_sym___refvalue] = ACTIONS(3557),
    [sym_null_literal] = ACTIONS(3557),
    [anon_sym_SQUOTE] = ACTIONS(3559),
    [sym_integer_literal] = ACTIONS(3557),
    [sym_real_literal] = ACTIONS(3559),
    [anon_sym_DQUOTE] = ACTIONS(3559),
    [sym_verbatim_string_literal] = ACTIONS(3559),
    [aux_sym_preproc_if_token1] = ACTIONS(3559),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3559),
    [sym_interpolation_verbatim_start] = ACTIONS(3559),
    [sym_interpolation_raw_start] = ACTIONS(3559),
    [sym_raw_string_start] = ACTIONS(3559),
  },
  [2515] = {
    [sym_preproc_region] = STATE(2515),
    [sym_preproc_endregion] = STATE(2515),
    [sym_preproc_line] = STATE(2515),
    [sym_preproc_pragma] = STATE(2515),
    [sym_preproc_nullable] = STATE(2515),
    [sym_preproc_error] = STATE(2515),
    [sym_preproc_warning] = STATE(2515),
    [sym_preproc_define] = STATE(2515),
    [sym_preproc_undef] = STATE(2515),
    [ts_builtin_sym_end] = ACTIONS(3715),
    [sym__identifier_token] = ACTIONS(3713),
    [anon_sym_extern] = ACTIONS(3713),
    [anon_sym_alias] = ACTIONS(3713),
    [anon_sym_SEMI] = ACTIONS(3715),
    [anon_sym_global] = ACTIONS(3713),
    [anon_sym_using] = ACTIONS(3713),
    [anon_sym_unsafe] = ACTIONS(3713),
    [anon_sym_static] = ACTIONS(3713),
    [anon_sym_LBRACK] = ACTIONS(3715),
    [anon_sym_LPAREN] = ACTIONS(3715),
    [anon_sym_return] = ACTIONS(3713),
    [anon_sym_namespace] = ACTIONS(3713),
    [anon_sym_class] = ACTIONS(3713),
    [anon_sym_ref] = ACTIONS(3713),
    [anon_sym_struct] = ACTIONS(3713),
    [anon_sym_enum] = ACTIONS(3713),
    [anon_sym_LBRACE] = ACTIONS(3715),
    [anon_sym_interface] = ACTIONS(3713),
    [anon_sym_delegate] = ACTIONS(3713),
    [anon_sym_record] = ACTIONS(3713),
    [anon_sym_abstract] = ACTIONS(3713),
    [anon_sym_async] = ACTIONS(3713),
    [anon_sym_const] = ACTIONS(3713),
    [anon_sym_file] = ACTIONS(3713),
    [anon_sym_fixed] = ACTIONS(3713),
    [anon_sym_internal] = ACTIONS(3713),
    [anon_sym_new] = ACTIONS(3713),
    [anon_sym_override] = ACTIONS(3713),
    [anon_sym_partial] = ACTIONS(3713),
    [anon_sym_private] = ACTIONS(3713),
    [anon_sym_protected] = ACTIONS(3713),
    [anon_sym_public] = ACTIONS(3713),
    [anon_sym_readonly] = ACTIONS(3713),
    [anon_sym_required] = ACTIONS(3713),
    [anon_sym_sealed] = ACTIONS(3713),
    [anon_sym_virtual] = ACTIONS(3713),
    [anon_sym_volatile] = ACTIONS(3713),
    [anon_sym_where] = ACTIONS(3713),
    [anon_sym_notnull] = ACTIONS(3713),
    [anon_sym_unmanaged] = ACTIONS(3713),
    [anon_sym_checked] = ACTIONS(3713),
    [anon_sym_BANG] = ACTIONS(3715),
    [anon_sym_TILDE] = ACTIONS(3715),
    [anon_sym_PLUS_PLUS] = ACTIONS(3715),
    [anon_sym_DASH_DASH] = ACTIONS(3715),
    [anon_sym_true] = ACTIONS(3713),
    [anon_sym_false] = ACTIONS(3713),
    [anon_sym_PLUS] = ACTIONS(3713),
    [anon_sym_DASH] = ACTIONS(3713),
    [anon_sym_STAR] = ACTIONS(3715),
    [anon_sym_CARET] = ACTIONS(3715),
    [anon_sym_AMP] = ACTIONS(3715),
    [anon_sym_this] = ACTIONS(3713),
    [anon_sym_scoped] = ACTIONS(3713),
    [anon_sym_base] = ACTIONS(3713),
    [anon_sym_var] = ACTIONS(3713),
    [sym_predefined_type] = ACTIONS(3713),
    [anon_sym_break] = ACTIONS(3713),
    [anon_sym_unchecked] = ACTIONS(3713),
    [anon_sym_continue] = ACTIONS(3713),
    [anon_sym_do] = ACTIONS(3713),
    [anon_sym_while] = ACTIONS(3713),
    [anon_sym_for] = ACTIONS(3713),
    [anon_sym_lock] = ACTIONS(3713),
    [anon_sym_yield] = ACTIONS(3713),
    [anon_sym_switch] = ACTIONS(3713),
    [anon_sym_default] = ACTIONS(3713),
    [anon_sym_throw] = ACTIONS(3713),
    [anon_sym_try] = ACTIONS(3713),
    [anon_sym_when] = ACTIONS(3713),
    [anon_sym_await] = ACTIONS(3713),
    [anon_sym_foreach] = ACTIONS(3713),
    [anon_sym_goto] = ACTIONS(3713),
    [anon_sym_if] = ACTIONS(3713),
    [anon_sym_DOT_DOT] = ACTIONS(3715),
    [anon_sym_from] = ACTIONS(3713),
    [anon_sym_into] = ACTIONS(3713),
    [anon_sym_join] = ACTIONS(3713),
    [anon_sym_on] = ACTIONS(3713),
    [anon_sym_equals] = ACTIONS(3713),
    [anon_sym_let] = ACTIONS(3713),
    [anon_sym_orderby] = ACTIONS(3713),
    [anon_sym_ascending] = ACTIONS(3713),
    [anon_sym_descending] = ACTIONS(3713),
    [anon_sym_group] = ACTIONS(3713),
    [anon_sym_by] = ACTIONS(3713),
    [anon_sym_select] = ACTIONS(3713),
    [anon_sym_stackalloc] = ACTIONS(3713),
    [anon_sym_sizeof] = ACTIONS(3713),
    [anon_sym_typeof] = ACTIONS(3713),
    [anon_sym___makeref] = ACTIONS(3713),
    [anon_sym___reftype] = ACTIONS(3713),
    [anon_sym___refvalue] = ACTIONS(3713),
    [sym_null_literal] = ACTIONS(3713),
    [anon_sym_SQUOTE] = ACTIONS(3715),
    [sym_integer_literal] = ACTIONS(3713),
    [sym_real_literal] = ACTIONS(3715),
    [anon_sym_DQUOTE] = ACTIONS(3715),
    [sym_verbatim_string_literal] = ACTIONS(3715),
    [aux_sym_preproc_if_token1] = ACTIONS(3715),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3715),
    [sym_interpolation_verbatim_start] = ACTIONS(3715),
    [sym_interpolation_raw_start] = ACTIONS(3715),
    [sym_raw_string_start] = ACTIONS(3715),
  },
  [2516] = {
    [sym_preproc_region] = STATE(2516),
    [sym_preproc_endregion] = STATE(2516),
    [sym_preproc_line] = STATE(2516),
    [sym_preproc_pragma] = STATE(2516),
    [sym_preproc_nullable] = STATE(2516),
    [sym_preproc_error] = STATE(2516),
    [sym_preproc_warning] = STATE(2516),
    [sym_preproc_define] = STATE(2516),
    [sym_preproc_undef] = STATE(2516),
    [ts_builtin_sym_end] = ACTIONS(3719),
    [sym__identifier_token] = ACTIONS(3717),
    [anon_sym_extern] = ACTIONS(3717),
    [anon_sym_alias] = ACTIONS(3717),
    [anon_sym_SEMI] = ACTIONS(3719),
    [anon_sym_global] = ACTIONS(3717),
    [anon_sym_using] = ACTIONS(3717),
    [anon_sym_unsafe] = ACTIONS(3717),
    [anon_sym_static] = ACTIONS(3717),
    [anon_sym_LBRACK] = ACTIONS(3719),
    [anon_sym_LPAREN] = ACTIONS(3719),
    [anon_sym_return] = ACTIONS(3717),
    [anon_sym_namespace] = ACTIONS(3717),
    [anon_sym_class] = ACTIONS(3717),
    [anon_sym_ref] = ACTIONS(3717),
    [anon_sym_struct] = ACTIONS(3717),
    [anon_sym_enum] = ACTIONS(3717),
    [anon_sym_LBRACE] = ACTIONS(3719),
    [anon_sym_interface] = ACTIONS(3717),
    [anon_sym_delegate] = ACTIONS(3717),
    [anon_sym_record] = ACTIONS(3717),
    [anon_sym_abstract] = ACTIONS(3717),
    [anon_sym_async] = ACTIONS(3717),
    [anon_sym_const] = ACTIONS(3717),
    [anon_sym_file] = ACTIONS(3717),
    [anon_sym_fixed] = ACTIONS(3717),
    [anon_sym_internal] = ACTIONS(3717),
    [anon_sym_new] = ACTIONS(3717),
    [anon_sym_override] = ACTIONS(3717),
    [anon_sym_partial] = ACTIONS(3717),
    [anon_sym_private] = ACTIONS(3717),
    [anon_sym_protected] = ACTIONS(3717),
    [anon_sym_public] = ACTIONS(3717),
    [anon_sym_readonly] = ACTIONS(3717),
    [anon_sym_required] = ACTIONS(3717),
    [anon_sym_sealed] = ACTIONS(3717),
    [anon_sym_virtual] = ACTIONS(3717),
    [anon_sym_volatile] = ACTIONS(3717),
    [anon_sym_where] = ACTIONS(3717),
    [anon_sym_notnull] = ACTIONS(3717),
    [anon_sym_unmanaged] = ACTIONS(3717),
    [anon_sym_checked] = ACTIONS(3717),
    [anon_sym_BANG] = ACTIONS(3719),
    [anon_sym_TILDE] = ACTIONS(3719),
    [anon_sym_PLUS_PLUS] = ACTIONS(3719),
    [anon_sym_DASH_DASH] = ACTIONS(3719),
    [anon_sym_true] = ACTIONS(3717),
    [anon_sym_false] = ACTIONS(3717),
    [anon_sym_PLUS] = ACTIONS(3717),
    [anon_sym_DASH] = ACTIONS(3717),
    [anon_sym_STAR] = ACTIONS(3719),
    [anon_sym_CARET] = ACTIONS(3719),
    [anon_sym_AMP] = ACTIONS(3719),
    [anon_sym_this] = ACTIONS(3717),
    [anon_sym_scoped] = ACTIONS(3717),
    [anon_sym_base] = ACTIONS(3717),
    [anon_sym_var] = ACTIONS(3717),
    [sym_predefined_type] = ACTIONS(3717),
    [anon_sym_break] = ACTIONS(3717),
    [anon_sym_unchecked] = ACTIONS(3717),
    [anon_sym_continue] = ACTIONS(3717),
    [anon_sym_do] = ACTIONS(3717),
    [anon_sym_while] = ACTIONS(3717),
    [anon_sym_for] = ACTIONS(3717),
    [anon_sym_lock] = ACTIONS(3717),
    [anon_sym_yield] = ACTIONS(3717),
    [anon_sym_switch] = ACTIONS(3717),
    [anon_sym_default] = ACTIONS(3717),
    [anon_sym_throw] = ACTIONS(3717),
    [anon_sym_try] = ACTIONS(3717),
    [anon_sym_when] = ACTIONS(3717),
    [anon_sym_await] = ACTIONS(3717),
    [anon_sym_foreach] = ACTIONS(3717),
    [anon_sym_goto] = ACTIONS(3717),
    [anon_sym_if] = ACTIONS(3717),
    [anon_sym_DOT_DOT] = ACTIONS(3719),
    [anon_sym_from] = ACTIONS(3717),
    [anon_sym_into] = ACTIONS(3717),
    [anon_sym_join] = ACTIONS(3717),
    [anon_sym_on] = ACTIONS(3717),
    [anon_sym_equals] = ACTIONS(3717),
    [anon_sym_let] = ACTIONS(3717),
    [anon_sym_orderby] = ACTIONS(3717),
    [anon_sym_ascending] = ACTIONS(3717),
    [anon_sym_descending] = ACTIONS(3717),
    [anon_sym_group] = ACTIONS(3717),
    [anon_sym_by] = ACTIONS(3717),
    [anon_sym_select] = ACTIONS(3717),
    [anon_sym_stackalloc] = ACTIONS(3717),
    [anon_sym_sizeof] = ACTIONS(3717),
    [anon_sym_typeof] = ACTIONS(3717),
    [anon_sym___makeref] = ACTIONS(3717),
    [anon_sym___reftype] = ACTIONS(3717),
    [anon_sym___refvalue] = ACTIONS(3717),
    [sym_null_literal] = ACTIONS(3717),
    [anon_sym_SQUOTE] = ACTIONS(3719),
    [sym_integer_literal] = ACTIONS(3717),
    [sym_real_literal] = ACTIONS(3719),
    [anon_sym_DQUOTE] = ACTIONS(3719),
    [sym_verbatim_string_literal] = ACTIONS(3719),
    [aux_sym_preproc_if_token1] = ACTIONS(3719),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3719),
    [sym_interpolation_verbatim_start] = ACTIONS(3719),
    [sym_interpolation_raw_start] = ACTIONS(3719),
    [sym_raw_string_start] = ACTIONS(3719),
  },
  [2517] = {
    [sym_preproc_region] = STATE(2517),
    [sym_preproc_endregion] = STATE(2517),
    [sym_preproc_line] = STATE(2517),
    [sym_preproc_pragma] = STATE(2517),
    [sym_preproc_nullable] = STATE(2517),
    [sym_preproc_error] = STATE(2517),
    [sym_preproc_warning] = STATE(2517),
    [sym_preproc_define] = STATE(2517),
    [sym_preproc_undef] = STATE(2517),
    [ts_builtin_sym_end] = ACTIONS(3723),
    [sym__identifier_token] = ACTIONS(3721),
    [anon_sym_extern] = ACTIONS(3721),
    [anon_sym_alias] = ACTIONS(3721),
    [anon_sym_SEMI] = ACTIONS(3723),
    [anon_sym_global] = ACTIONS(3721),
    [anon_sym_using] = ACTIONS(3721),
    [anon_sym_unsafe] = ACTIONS(3721),
    [anon_sym_static] = ACTIONS(3721),
    [anon_sym_LBRACK] = ACTIONS(3723),
    [anon_sym_LPAREN] = ACTIONS(3723),
    [anon_sym_return] = ACTIONS(3721),
    [anon_sym_namespace] = ACTIONS(3721),
    [anon_sym_class] = ACTIONS(3721),
    [anon_sym_ref] = ACTIONS(3721),
    [anon_sym_struct] = ACTIONS(3721),
    [anon_sym_enum] = ACTIONS(3721),
    [anon_sym_LBRACE] = ACTIONS(3723),
    [anon_sym_interface] = ACTIONS(3721),
    [anon_sym_delegate] = ACTIONS(3721),
    [anon_sym_record] = ACTIONS(3721),
    [anon_sym_abstract] = ACTIONS(3721),
    [anon_sym_async] = ACTIONS(3721),
    [anon_sym_const] = ACTIONS(3721),
    [anon_sym_file] = ACTIONS(3721),
    [anon_sym_fixed] = ACTIONS(3721),
    [anon_sym_internal] = ACTIONS(3721),
    [anon_sym_new] = ACTIONS(3721),
    [anon_sym_override] = ACTIONS(3721),
    [anon_sym_partial] = ACTIONS(3721),
    [anon_sym_private] = ACTIONS(3721),
    [anon_sym_protected] = ACTIONS(3721),
    [anon_sym_public] = ACTIONS(3721),
    [anon_sym_readonly] = ACTIONS(3721),
    [anon_sym_required] = ACTIONS(3721),
    [anon_sym_sealed] = ACTIONS(3721),
    [anon_sym_virtual] = ACTIONS(3721),
    [anon_sym_volatile] = ACTIONS(3721),
    [anon_sym_where] = ACTIONS(3721),
    [anon_sym_notnull] = ACTIONS(3721),
    [anon_sym_unmanaged] = ACTIONS(3721),
    [anon_sym_checked] = ACTIONS(3721),
    [anon_sym_BANG] = ACTIONS(3723),
    [anon_sym_TILDE] = ACTIONS(3723),
    [anon_sym_PLUS_PLUS] = ACTIONS(3723),
    [anon_sym_DASH_DASH] = ACTIONS(3723),
    [anon_sym_true] = ACTIONS(3721),
    [anon_sym_false] = ACTIONS(3721),
    [anon_sym_PLUS] = ACTIONS(3721),
    [anon_sym_DASH] = ACTIONS(3721),
    [anon_sym_STAR] = ACTIONS(3723),
    [anon_sym_CARET] = ACTIONS(3723),
    [anon_sym_AMP] = ACTIONS(3723),
    [anon_sym_this] = ACTIONS(3721),
    [anon_sym_scoped] = ACTIONS(3721),
    [anon_sym_base] = ACTIONS(3721),
    [anon_sym_var] = ACTIONS(3721),
    [sym_predefined_type] = ACTIONS(3721),
    [anon_sym_break] = ACTIONS(3721),
    [anon_sym_unchecked] = ACTIONS(3721),
    [anon_sym_continue] = ACTIONS(3721),
    [anon_sym_do] = ACTIONS(3721),
    [anon_sym_while] = ACTIONS(3721),
    [anon_sym_for] = ACTIONS(3721),
    [anon_sym_lock] = ACTIONS(3721),
    [anon_sym_yield] = ACTIONS(3721),
    [anon_sym_switch] = ACTIONS(3721),
    [anon_sym_default] = ACTIONS(3721),
    [anon_sym_throw] = ACTIONS(3721),
    [anon_sym_try] = ACTIONS(3721),
    [anon_sym_when] = ACTIONS(3721),
    [anon_sym_await] = ACTIONS(3721),
    [anon_sym_foreach] = ACTIONS(3721),
    [anon_sym_goto] = ACTIONS(3721),
    [anon_sym_if] = ACTIONS(3721),
    [anon_sym_DOT_DOT] = ACTIONS(3723),
    [anon_sym_from] = ACTIONS(3721),
    [anon_sym_into] = ACTIONS(3721),
    [anon_sym_join] = ACTIONS(3721),
    [anon_sym_on] = ACTIONS(3721),
    [anon_sym_equals] = ACTIONS(3721),
    [anon_sym_let] = ACTIONS(3721),
    [anon_sym_orderby] = ACTIONS(3721),
    [anon_sym_ascending] = ACTIONS(3721),
    [anon_sym_descending] = ACTIONS(3721),
    [anon_sym_group] = ACTIONS(3721),
    [anon_sym_by] = ACTIONS(3721),
    [anon_sym_select] = ACTIONS(3721),
    [anon_sym_stackalloc] = ACTIONS(3721),
    [anon_sym_sizeof] = ACTIONS(3721),
    [anon_sym_typeof] = ACTIONS(3721),
    [anon_sym___makeref] = ACTIONS(3721),
    [anon_sym___reftype] = ACTIONS(3721),
    [anon_sym___refvalue] = ACTIONS(3721),
    [sym_null_literal] = ACTIONS(3721),
    [anon_sym_SQUOTE] = ACTIONS(3723),
    [sym_integer_literal] = ACTIONS(3721),
    [sym_real_literal] = ACTIONS(3723),
    [anon_sym_DQUOTE] = ACTIONS(3723),
    [sym_verbatim_string_literal] = ACTIONS(3723),
    [aux_sym_preproc_if_token1] = ACTIONS(3723),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3723),
    [sym_interpolation_verbatim_start] = ACTIONS(3723),
    [sym_interpolation_raw_start] = ACTIONS(3723),
    [sym_raw_string_start] = ACTIONS(3723),
  },
  [2518] = {
    [sym_preproc_region] = STATE(2518),
    [sym_preproc_endregion] = STATE(2518),
    [sym_preproc_line] = STATE(2518),
    [sym_preproc_pragma] = STATE(2518),
    [sym_preproc_nullable] = STATE(2518),
    [sym_preproc_error] = STATE(2518),
    [sym_preproc_warning] = STATE(2518),
    [sym_preproc_define] = STATE(2518),
    [sym_preproc_undef] = STATE(2518),
    [ts_builtin_sym_end] = ACTIONS(3727),
    [sym__identifier_token] = ACTIONS(3725),
    [anon_sym_extern] = ACTIONS(3725),
    [anon_sym_alias] = ACTIONS(3725),
    [anon_sym_SEMI] = ACTIONS(3727),
    [anon_sym_global] = ACTIONS(3725),
    [anon_sym_using] = ACTIONS(3725),
    [anon_sym_unsafe] = ACTIONS(3725),
    [anon_sym_static] = ACTIONS(3725),
    [anon_sym_LBRACK] = ACTIONS(3727),
    [anon_sym_LPAREN] = ACTIONS(3727),
    [anon_sym_return] = ACTIONS(3725),
    [anon_sym_namespace] = ACTIONS(3725),
    [anon_sym_class] = ACTIONS(3725),
    [anon_sym_ref] = ACTIONS(3725),
    [anon_sym_struct] = ACTIONS(3725),
    [anon_sym_enum] = ACTIONS(3725),
    [anon_sym_LBRACE] = ACTIONS(3727),
    [anon_sym_interface] = ACTIONS(3725),
    [anon_sym_delegate] = ACTIONS(3725),
    [anon_sym_record] = ACTIONS(3725),
    [anon_sym_abstract] = ACTIONS(3725),
    [anon_sym_async] = ACTIONS(3725),
    [anon_sym_const] = ACTIONS(3725),
    [anon_sym_file] = ACTIONS(3725),
    [anon_sym_fixed] = ACTIONS(3725),
    [anon_sym_internal] = ACTIONS(3725),
    [anon_sym_new] = ACTIONS(3725),
    [anon_sym_override] = ACTIONS(3725),
    [anon_sym_partial] = ACTIONS(3725),
    [anon_sym_private] = ACTIONS(3725),
    [anon_sym_protected] = ACTIONS(3725),
    [anon_sym_public] = ACTIONS(3725),
    [anon_sym_readonly] = ACTIONS(3725),
    [anon_sym_required] = ACTIONS(3725),
    [anon_sym_sealed] = ACTIONS(3725),
    [anon_sym_virtual] = ACTIONS(3725),
    [anon_sym_volatile] = ACTIONS(3725),
    [anon_sym_where] = ACTIONS(3725),
    [anon_sym_notnull] = ACTIONS(3725),
    [anon_sym_unmanaged] = ACTIONS(3725),
    [anon_sym_checked] = ACTIONS(3725),
    [anon_sym_BANG] = ACTIONS(3727),
    [anon_sym_TILDE] = ACTIONS(3727),
    [anon_sym_PLUS_PLUS] = ACTIONS(3727),
    [anon_sym_DASH_DASH] = ACTIONS(3727),
    [anon_sym_true] = ACTIONS(3725),
    [anon_sym_false] = ACTIONS(3725),
    [anon_sym_PLUS] = ACTIONS(3725),
    [anon_sym_DASH] = ACTIONS(3725),
    [anon_sym_STAR] = ACTIONS(3727),
    [anon_sym_CARET] = ACTIONS(3727),
    [anon_sym_AMP] = ACTIONS(3727),
    [anon_sym_this] = ACTIONS(3725),
    [anon_sym_scoped] = ACTIONS(3725),
    [anon_sym_base] = ACTIONS(3725),
    [anon_sym_var] = ACTIONS(3725),
    [sym_predefined_type] = ACTIONS(3725),
    [anon_sym_break] = ACTIONS(3725),
    [anon_sym_unchecked] = ACTIONS(3725),
    [anon_sym_continue] = ACTIONS(3725),
    [anon_sym_do] = ACTIONS(3725),
    [anon_sym_while] = ACTIONS(3725),
    [anon_sym_for] = ACTIONS(3725),
    [anon_sym_lock] = ACTIONS(3725),
    [anon_sym_yield] = ACTIONS(3725),
    [anon_sym_switch] = ACTIONS(3725),
    [anon_sym_default] = ACTIONS(3725),
    [anon_sym_throw] = ACTIONS(3725),
    [anon_sym_try] = ACTIONS(3725),
    [anon_sym_when] = ACTIONS(3725),
    [anon_sym_await] = ACTIONS(3725),
    [anon_sym_foreach] = ACTIONS(3725),
    [anon_sym_goto] = ACTIONS(3725),
    [anon_sym_if] = ACTIONS(3725),
    [anon_sym_DOT_DOT] = ACTIONS(3727),
    [anon_sym_from] = ACTIONS(3725),
    [anon_sym_into] = ACTIONS(3725),
    [anon_sym_join] = ACTIONS(3725),
    [anon_sym_on] = ACTIONS(3725),
    [anon_sym_equals] = ACTIONS(3725),
    [anon_sym_let] = ACTIONS(3725),
    [anon_sym_orderby] = ACTIONS(3725),
    [anon_sym_ascending] = ACTIONS(3725),
    [anon_sym_descending] = ACTIONS(3725),
    [anon_sym_group] = ACTIONS(3725),
    [anon_sym_by] = ACTIONS(3725),
    [anon_sym_select] = ACTIONS(3725),
    [anon_sym_stackalloc] = ACTIONS(3725),
    [anon_sym_sizeof] = ACTIONS(3725),
    [anon_sym_typeof] = ACTIONS(3725),
    [anon_sym___makeref] = ACTIONS(3725),
    [anon_sym___reftype] = ACTIONS(3725),
    [anon_sym___refvalue] = ACTIONS(3725),
    [sym_null_literal] = ACTIONS(3725),
    [anon_sym_SQUOTE] = ACTIONS(3727),
    [sym_integer_literal] = ACTIONS(3725),
    [sym_real_literal] = ACTIONS(3727),
    [anon_sym_DQUOTE] = ACTIONS(3727),
    [sym_verbatim_string_literal] = ACTIONS(3727),
    [aux_sym_preproc_if_token1] = ACTIONS(3727),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3727),
    [sym_interpolation_verbatim_start] = ACTIONS(3727),
    [sym_interpolation_raw_start] = ACTIONS(3727),
    [sym_raw_string_start] = ACTIONS(3727),
  },
  [2519] = {
    [sym_preproc_region] = STATE(2519),
    [sym_preproc_endregion] = STATE(2519),
    [sym_preproc_line] = STATE(2519),
    [sym_preproc_pragma] = STATE(2519),
    [sym_preproc_nullable] = STATE(2519),
    [sym_preproc_error] = STATE(2519),
    [sym_preproc_warning] = STATE(2519),
    [sym_preproc_define] = STATE(2519),
    [sym_preproc_undef] = STATE(2519),
    [ts_builtin_sym_end] = ACTIONS(3731),
    [sym__identifier_token] = ACTIONS(3729),
    [anon_sym_extern] = ACTIONS(3729),
    [anon_sym_alias] = ACTIONS(3729),
    [anon_sym_SEMI] = ACTIONS(3731),
    [anon_sym_global] = ACTIONS(3729),
    [anon_sym_using] = ACTIONS(3729),
    [anon_sym_unsafe] = ACTIONS(3729),
    [anon_sym_static] = ACTIONS(3729),
    [anon_sym_LBRACK] = ACTIONS(3731),
    [anon_sym_LPAREN] = ACTIONS(3731),
    [anon_sym_return] = ACTIONS(3729),
    [anon_sym_namespace] = ACTIONS(3729),
    [anon_sym_class] = ACTIONS(3729),
    [anon_sym_ref] = ACTIONS(3729),
    [anon_sym_struct] = ACTIONS(3729),
    [anon_sym_enum] = ACTIONS(3729),
    [anon_sym_LBRACE] = ACTIONS(3731),
    [anon_sym_interface] = ACTIONS(3729),
    [anon_sym_delegate] = ACTIONS(3729),
    [anon_sym_record] = ACTIONS(3729),
    [anon_sym_abstract] = ACTIONS(3729),
    [anon_sym_async] = ACTIONS(3729),
    [anon_sym_const] = ACTIONS(3729),
    [anon_sym_file] = ACTIONS(3729),
    [anon_sym_fixed] = ACTIONS(3729),
    [anon_sym_internal] = ACTIONS(3729),
    [anon_sym_new] = ACTIONS(3729),
    [anon_sym_override] = ACTIONS(3729),
    [anon_sym_partial] = ACTIONS(3729),
    [anon_sym_private] = ACTIONS(3729),
    [anon_sym_protected] = ACTIONS(3729),
    [anon_sym_public] = ACTIONS(3729),
    [anon_sym_readonly] = ACTIONS(3729),
    [anon_sym_required] = ACTIONS(3729),
    [anon_sym_sealed] = ACTIONS(3729),
    [anon_sym_virtual] = ACTIONS(3729),
    [anon_sym_volatile] = ACTIONS(3729),
    [anon_sym_where] = ACTIONS(3729),
    [anon_sym_notnull] = ACTIONS(3729),
    [anon_sym_unmanaged] = ACTIONS(3729),
    [anon_sym_checked] = ACTIONS(3729),
    [anon_sym_BANG] = ACTIONS(3731),
    [anon_sym_TILDE] = ACTIONS(3731),
    [anon_sym_PLUS_PLUS] = ACTIONS(3731),
    [anon_sym_DASH_DASH] = ACTIONS(3731),
    [anon_sym_true] = ACTIONS(3729),
    [anon_sym_false] = ACTIONS(3729),
    [anon_sym_PLUS] = ACTIONS(3729),
    [anon_sym_DASH] = ACTIONS(3729),
    [anon_sym_STAR] = ACTIONS(3731),
    [anon_sym_CARET] = ACTIONS(3731),
    [anon_sym_AMP] = ACTIONS(3731),
    [anon_sym_this] = ACTIONS(3729),
    [anon_sym_scoped] = ACTIONS(3729),
    [anon_sym_base] = ACTIONS(3729),
    [anon_sym_var] = ACTIONS(3729),
    [sym_predefined_type] = ACTIONS(3729),
    [anon_sym_break] = ACTIONS(3729),
    [anon_sym_unchecked] = ACTIONS(3729),
    [anon_sym_continue] = ACTIONS(3729),
    [anon_sym_do] = ACTIONS(3729),
    [anon_sym_while] = ACTIONS(3729),
    [anon_sym_for] = ACTIONS(3729),
    [anon_sym_lock] = ACTIONS(3729),
    [anon_sym_yield] = ACTIONS(3729),
    [anon_sym_switch] = ACTIONS(3729),
    [anon_sym_default] = ACTIONS(3729),
    [anon_sym_throw] = ACTIONS(3729),
    [anon_sym_try] = ACTIONS(3729),
    [anon_sym_when] = ACTIONS(3729),
    [anon_sym_await] = ACTIONS(3729),
    [anon_sym_foreach] = ACTIONS(3729),
    [anon_sym_goto] = ACTIONS(3729),
    [anon_sym_if] = ACTIONS(3729),
    [anon_sym_DOT_DOT] = ACTIONS(3731),
    [anon_sym_from] = ACTIONS(3729),
    [anon_sym_into] = ACTIONS(3729),
    [anon_sym_join] = ACTIONS(3729),
    [anon_sym_on] = ACTIONS(3729),
    [anon_sym_equals] = ACTIONS(3729),
    [anon_sym_let] = ACTIONS(3729),
    [anon_sym_orderby] = ACTIONS(3729),
    [anon_sym_ascending] = ACTIONS(3729),
    [anon_sym_descending] = ACTIONS(3729),
    [anon_sym_group] = ACTIONS(3729),
    [anon_sym_by] = ACTIONS(3729),
    [anon_sym_select] = ACTIONS(3729),
    [anon_sym_stackalloc] = ACTIONS(3729),
    [anon_sym_sizeof] = ACTIONS(3729),
    [anon_sym_typeof] = ACTIONS(3729),
    [anon_sym___makeref] = ACTIONS(3729),
    [anon_sym___reftype] = ACTIONS(3729),
    [anon_sym___refvalue] = ACTIONS(3729),
    [sym_null_literal] = ACTIONS(3729),
    [anon_sym_SQUOTE] = ACTIONS(3731),
    [sym_integer_literal] = ACTIONS(3729),
    [sym_real_literal] = ACTIONS(3731),
    [anon_sym_DQUOTE] = ACTIONS(3731),
    [sym_verbatim_string_literal] = ACTIONS(3731),
    [aux_sym_preproc_if_token1] = ACTIONS(3731),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3731),
    [sym_interpolation_verbatim_start] = ACTIONS(3731),
    [sym_interpolation_raw_start] = ACTIONS(3731),
    [sym_raw_string_start] = ACTIONS(3731),
  },
  [2520] = {
    [sym_preproc_region] = STATE(2520),
    [sym_preproc_endregion] = STATE(2520),
    [sym_preproc_line] = STATE(2520),
    [sym_preproc_pragma] = STATE(2520),
    [sym_preproc_nullable] = STATE(2520),
    [sym_preproc_error] = STATE(2520),
    [sym_preproc_warning] = STATE(2520),
    [sym_preproc_define] = STATE(2520),
    [sym_preproc_undef] = STATE(2520),
    [ts_builtin_sym_end] = ACTIONS(3735),
    [sym__identifier_token] = ACTIONS(3733),
    [anon_sym_extern] = ACTIONS(3733),
    [anon_sym_alias] = ACTIONS(3733),
    [anon_sym_SEMI] = ACTIONS(3735),
    [anon_sym_global] = ACTIONS(3733),
    [anon_sym_using] = ACTIONS(3733),
    [anon_sym_unsafe] = ACTIONS(3733),
    [anon_sym_static] = ACTIONS(3733),
    [anon_sym_LBRACK] = ACTIONS(3735),
    [anon_sym_LPAREN] = ACTIONS(3735),
    [anon_sym_return] = ACTIONS(3733),
    [anon_sym_namespace] = ACTIONS(3733),
    [anon_sym_class] = ACTIONS(3733),
    [anon_sym_ref] = ACTIONS(3733),
    [anon_sym_struct] = ACTIONS(3733),
    [anon_sym_enum] = ACTIONS(3733),
    [anon_sym_LBRACE] = ACTIONS(3735),
    [anon_sym_interface] = ACTIONS(3733),
    [anon_sym_delegate] = ACTIONS(3733),
    [anon_sym_record] = ACTIONS(3733),
    [anon_sym_abstract] = ACTIONS(3733),
    [anon_sym_async] = ACTIONS(3733),
    [anon_sym_const] = ACTIONS(3733),
    [anon_sym_file] = ACTIONS(3733),
    [anon_sym_fixed] = ACTIONS(3733),
    [anon_sym_internal] = ACTIONS(3733),
    [anon_sym_new] = ACTIONS(3733),
    [anon_sym_override] = ACTIONS(3733),
    [anon_sym_partial] = ACTIONS(3733),
    [anon_sym_private] = ACTIONS(3733),
    [anon_sym_protected] = ACTIONS(3733),
    [anon_sym_public] = ACTIONS(3733),
    [anon_sym_readonly] = ACTIONS(3733),
    [anon_sym_required] = ACTIONS(3733),
    [anon_sym_sealed] = ACTIONS(3733),
    [anon_sym_virtual] = ACTIONS(3733),
    [anon_sym_volatile] = ACTIONS(3733),
    [anon_sym_where] = ACTIONS(3733),
    [anon_sym_notnull] = ACTIONS(3733),
    [anon_sym_unmanaged] = ACTIONS(3733),
    [anon_sym_checked] = ACTIONS(3733),
    [anon_sym_BANG] = ACTIONS(3735),
    [anon_sym_TILDE] = ACTIONS(3735),
    [anon_sym_PLUS_PLUS] = ACTIONS(3735),
    [anon_sym_DASH_DASH] = ACTIONS(3735),
    [anon_sym_true] = ACTIONS(3733),
    [anon_sym_false] = ACTIONS(3733),
    [anon_sym_PLUS] = ACTIONS(3733),
    [anon_sym_DASH] = ACTIONS(3733),
    [anon_sym_STAR] = ACTIONS(3735),
    [anon_sym_CARET] = ACTIONS(3735),
    [anon_sym_AMP] = ACTIONS(3735),
    [anon_sym_this] = ACTIONS(3733),
    [anon_sym_scoped] = ACTIONS(3733),
    [anon_sym_base] = ACTIONS(3733),
    [anon_sym_var] = ACTIONS(3733),
    [sym_predefined_type] = ACTIONS(3733),
    [anon_sym_break] = ACTIONS(3733),
    [anon_sym_unchecked] = ACTIONS(3733),
    [anon_sym_continue] = ACTIONS(3733),
    [anon_sym_do] = ACTIONS(3733),
    [anon_sym_while] = ACTIONS(3733),
    [anon_sym_for] = ACTIONS(3733),
    [anon_sym_lock] = ACTIONS(3733),
    [anon_sym_yield] = ACTIONS(3733),
    [anon_sym_switch] = ACTIONS(3733),
    [anon_sym_default] = ACTIONS(3733),
    [anon_sym_throw] = ACTIONS(3733),
    [anon_sym_try] = ACTIONS(3733),
    [anon_sym_when] = ACTIONS(3733),
    [anon_sym_await] = ACTIONS(3733),
    [anon_sym_foreach] = ACTIONS(3733),
    [anon_sym_goto] = ACTIONS(3733),
    [anon_sym_if] = ACTIONS(3733),
    [anon_sym_DOT_DOT] = ACTIONS(3735),
    [anon_sym_from] = ACTIONS(3733),
    [anon_sym_into] = ACTIONS(3733),
    [anon_sym_join] = ACTIONS(3733),
    [anon_sym_on] = ACTIONS(3733),
    [anon_sym_equals] = ACTIONS(3733),
    [anon_sym_let] = ACTIONS(3733),
    [anon_sym_orderby] = ACTIONS(3733),
    [anon_sym_ascending] = ACTIONS(3733),
    [anon_sym_descending] = ACTIONS(3733),
    [anon_sym_group] = ACTIONS(3733),
    [anon_sym_by] = ACTIONS(3733),
    [anon_sym_select] = ACTIONS(3733),
    [anon_sym_stackalloc] = ACTIONS(3733),
    [anon_sym_sizeof] = ACTIONS(3733),
    [anon_sym_typeof] = ACTIONS(3733),
    [anon_sym___makeref] = ACTIONS(3733),
    [anon_sym___reftype] = ACTIONS(3733),
    [anon_sym___refvalue] = ACTIONS(3733),
    [sym_null_literal] = ACTIONS(3733),
    [anon_sym_SQUOTE] = ACTIONS(3735),
    [sym_integer_literal] = ACTIONS(3733),
    [sym_real_literal] = ACTIONS(3735),
    [anon_sym_DQUOTE] = ACTIONS(3735),
    [sym_verbatim_string_literal] = ACTIONS(3735),
    [aux_sym_preproc_if_token1] = ACTIONS(3735),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3735),
    [sym_interpolation_verbatim_start] = ACTIONS(3735),
    [sym_interpolation_raw_start] = ACTIONS(3735),
    [sym_raw_string_start] = ACTIONS(3735),
  },
  [2521] = {
    [sym_preproc_region] = STATE(2521),
    [sym_preproc_endregion] = STATE(2521),
    [sym_preproc_line] = STATE(2521),
    [sym_preproc_pragma] = STATE(2521),
    [sym_preproc_nullable] = STATE(2521),
    [sym_preproc_error] = STATE(2521),
    [sym_preproc_warning] = STATE(2521),
    [sym_preproc_define] = STATE(2521),
    [sym_preproc_undef] = STATE(2521),
    [ts_builtin_sym_end] = ACTIONS(3739),
    [sym__identifier_token] = ACTIONS(3737),
    [anon_sym_extern] = ACTIONS(3737),
    [anon_sym_alias] = ACTIONS(3737),
    [anon_sym_SEMI] = ACTIONS(3739),
    [anon_sym_global] = ACTIONS(3737),
    [anon_sym_using] = ACTIONS(3737),
    [anon_sym_unsafe] = ACTIONS(3737),
    [anon_sym_static] = ACTIONS(3737),
    [anon_sym_LBRACK] = ACTIONS(3739),
    [anon_sym_LPAREN] = ACTIONS(3739),
    [anon_sym_return] = ACTIONS(3737),
    [anon_sym_namespace] = ACTIONS(3737),
    [anon_sym_class] = ACTIONS(3737),
    [anon_sym_ref] = ACTIONS(3737),
    [anon_sym_struct] = ACTIONS(3737),
    [anon_sym_enum] = ACTIONS(3737),
    [anon_sym_LBRACE] = ACTIONS(3739),
    [anon_sym_interface] = ACTIONS(3737),
    [anon_sym_delegate] = ACTIONS(3737),
    [anon_sym_record] = ACTIONS(3737),
    [anon_sym_abstract] = ACTIONS(3737),
    [anon_sym_async] = ACTIONS(3737),
    [anon_sym_const] = ACTIONS(3737),
    [anon_sym_file] = ACTIONS(3737),
    [anon_sym_fixed] = ACTIONS(3737),
    [anon_sym_internal] = ACTIONS(3737),
    [anon_sym_new] = ACTIONS(3737),
    [anon_sym_override] = ACTIONS(3737),
    [anon_sym_partial] = ACTIONS(3737),
    [anon_sym_private] = ACTIONS(3737),
    [anon_sym_protected] = ACTIONS(3737),
    [anon_sym_public] = ACTIONS(3737),
    [anon_sym_readonly] = ACTIONS(3737),
    [anon_sym_required] = ACTIONS(3737),
    [anon_sym_sealed] = ACTIONS(3737),
    [anon_sym_virtual] = ACTIONS(3737),
    [anon_sym_volatile] = ACTIONS(3737),
    [anon_sym_where] = ACTIONS(3737),
    [anon_sym_notnull] = ACTIONS(3737),
    [anon_sym_unmanaged] = ACTIONS(3737),
    [anon_sym_checked] = ACTIONS(3737),
    [anon_sym_BANG] = ACTIONS(3739),
    [anon_sym_TILDE] = ACTIONS(3739),
    [anon_sym_PLUS_PLUS] = ACTIONS(3739),
    [anon_sym_DASH_DASH] = ACTIONS(3739),
    [anon_sym_true] = ACTIONS(3737),
    [anon_sym_false] = ACTIONS(3737),
    [anon_sym_PLUS] = ACTIONS(3737),
    [anon_sym_DASH] = ACTIONS(3737),
    [anon_sym_STAR] = ACTIONS(3739),
    [anon_sym_CARET] = ACTIONS(3739),
    [anon_sym_AMP] = ACTIONS(3739),
    [anon_sym_this] = ACTIONS(3737),
    [anon_sym_scoped] = ACTIONS(3737),
    [anon_sym_base] = ACTIONS(3737),
    [anon_sym_var] = ACTIONS(3737),
    [sym_predefined_type] = ACTIONS(3737),
    [anon_sym_break] = ACTIONS(3737),
    [anon_sym_unchecked] = ACTIONS(3737),
    [anon_sym_continue] = ACTIONS(3737),
    [anon_sym_do] = ACTIONS(3737),
    [anon_sym_while] = ACTIONS(3737),
    [anon_sym_for] = ACTIONS(3737),
    [anon_sym_lock] = ACTIONS(3737),
    [anon_sym_yield] = ACTIONS(3737),
    [anon_sym_switch] = ACTIONS(3737),
    [anon_sym_default] = ACTIONS(3737),
    [anon_sym_throw] = ACTIONS(3737),
    [anon_sym_try] = ACTIONS(3737),
    [anon_sym_when] = ACTIONS(3737),
    [anon_sym_await] = ACTIONS(3737),
    [anon_sym_foreach] = ACTIONS(3737),
    [anon_sym_goto] = ACTIONS(3737),
    [anon_sym_if] = ACTIONS(3737),
    [anon_sym_DOT_DOT] = ACTIONS(3739),
    [anon_sym_from] = ACTIONS(3737),
    [anon_sym_into] = ACTIONS(3737),
    [anon_sym_join] = ACTIONS(3737),
    [anon_sym_on] = ACTIONS(3737),
    [anon_sym_equals] = ACTIONS(3737),
    [anon_sym_let] = ACTIONS(3737),
    [anon_sym_orderby] = ACTIONS(3737),
    [anon_sym_ascending] = ACTIONS(3737),
    [anon_sym_descending] = ACTIONS(3737),
    [anon_sym_group] = ACTIONS(3737),
    [anon_sym_by] = ACTIONS(3737),
    [anon_sym_select] = ACTIONS(3737),
    [anon_sym_stackalloc] = ACTIONS(3737),
    [anon_sym_sizeof] = ACTIONS(3737),
    [anon_sym_typeof] = ACTIONS(3737),
    [anon_sym___makeref] = ACTIONS(3737),
    [anon_sym___reftype] = ACTIONS(3737),
    [anon_sym___refvalue] = ACTIONS(3737),
    [sym_null_literal] = ACTIONS(3737),
    [anon_sym_SQUOTE] = ACTIONS(3739),
    [sym_integer_literal] = ACTIONS(3737),
    [sym_real_literal] = ACTIONS(3739),
    [anon_sym_DQUOTE] = ACTIONS(3739),
    [sym_verbatim_string_literal] = ACTIONS(3739),
    [aux_sym_preproc_if_token1] = ACTIONS(3739),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3739),
    [sym_interpolation_verbatim_start] = ACTIONS(3739),
    [sym_interpolation_raw_start] = ACTIONS(3739),
    [sym_raw_string_start] = ACTIONS(3739),
  },
  [2522] = {
    [sym_preproc_region] = STATE(2522),
    [sym_preproc_endregion] = STATE(2522),
    [sym_preproc_line] = STATE(2522),
    [sym_preproc_pragma] = STATE(2522),
    [sym_preproc_nullable] = STATE(2522),
    [sym_preproc_error] = STATE(2522),
    [sym_preproc_warning] = STATE(2522),
    [sym_preproc_define] = STATE(2522),
    [sym_preproc_undef] = STATE(2522),
    [ts_builtin_sym_end] = ACTIONS(3743),
    [sym__identifier_token] = ACTIONS(3741),
    [anon_sym_extern] = ACTIONS(3741),
    [anon_sym_alias] = ACTIONS(3741),
    [anon_sym_SEMI] = ACTIONS(3743),
    [anon_sym_global] = ACTIONS(3741),
    [anon_sym_using] = ACTIONS(3741),
    [anon_sym_unsafe] = ACTIONS(3741),
    [anon_sym_static] = ACTIONS(3741),
    [anon_sym_LBRACK] = ACTIONS(3743),
    [anon_sym_LPAREN] = ACTIONS(3743),
    [anon_sym_return] = ACTIONS(3741),
    [anon_sym_namespace] = ACTIONS(3741),
    [anon_sym_class] = ACTIONS(3741),
    [anon_sym_ref] = ACTIONS(3741),
    [anon_sym_struct] = ACTIONS(3741),
    [anon_sym_enum] = ACTIONS(3741),
    [anon_sym_LBRACE] = ACTIONS(3743),
    [anon_sym_interface] = ACTIONS(3741),
    [anon_sym_delegate] = ACTIONS(3741),
    [anon_sym_record] = ACTIONS(3741),
    [anon_sym_abstract] = ACTIONS(3741),
    [anon_sym_async] = ACTIONS(3741),
    [anon_sym_const] = ACTIONS(3741),
    [anon_sym_file] = ACTIONS(3741),
    [anon_sym_fixed] = ACTIONS(3741),
    [anon_sym_internal] = ACTIONS(3741),
    [anon_sym_new] = ACTIONS(3741),
    [anon_sym_override] = ACTIONS(3741),
    [anon_sym_partial] = ACTIONS(3741),
    [anon_sym_private] = ACTIONS(3741),
    [anon_sym_protected] = ACTIONS(3741),
    [anon_sym_public] = ACTIONS(3741),
    [anon_sym_readonly] = ACTIONS(3741),
    [anon_sym_required] = ACTIONS(3741),
    [anon_sym_sealed] = ACTIONS(3741),
    [anon_sym_virtual] = ACTIONS(3741),
    [anon_sym_volatile] = ACTIONS(3741),
    [anon_sym_where] = ACTIONS(3741),
    [anon_sym_notnull] = ACTIONS(3741),
    [anon_sym_unmanaged] = ACTIONS(3741),
    [anon_sym_checked] = ACTIONS(3741),
    [anon_sym_BANG] = ACTIONS(3743),
    [anon_sym_TILDE] = ACTIONS(3743),
    [anon_sym_PLUS_PLUS] = ACTIONS(3743),
    [anon_sym_DASH_DASH] = ACTIONS(3743),
    [anon_sym_true] = ACTIONS(3741),
    [anon_sym_false] = ACTIONS(3741),
    [anon_sym_PLUS] = ACTIONS(3741),
    [anon_sym_DASH] = ACTIONS(3741),
    [anon_sym_STAR] = ACTIONS(3743),
    [anon_sym_CARET] = ACTIONS(3743),
    [anon_sym_AMP] = ACTIONS(3743),
    [anon_sym_this] = ACTIONS(3741),
    [anon_sym_scoped] = ACTIONS(3741),
    [anon_sym_base] = ACTIONS(3741),
    [anon_sym_var] = ACTIONS(3741),
    [sym_predefined_type] = ACTIONS(3741),
    [anon_sym_break] = ACTIONS(3741),
    [anon_sym_unchecked] = ACTIONS(3741),
    [anon_sym_continue] = ACTIONS(3741),
    [anon_sym_do] = ACTIONS(3741),
    [anon_sym_while] = ACTIONS(3741),
    [anon_sym_for] = ACTIONS(3741),
    [anon_sym_lock] = ACTIONS(3741),
    [anon_sym_yield] = ACTIONS(3741),
    [anon_sym_switch] = ACTIONS(3741),
    [anon_sym_default] = ACTIONS(3741),
    [anon_sym_throw] = ACTIONS(3741),
    [anon_sym_try] = ACTIONS(3741),
    [anon_sym_when] = ACTIONS(3741),
    [anon_sym_await] = ACTIONS(3741),
    [anon_sym_foreach] = ACTIONS(3741),
    [anon_sym_goto] = ACTIONS(3741),
    [anon_sym_if] = ACTIONS(3741),
    [anon_sym_DOT_DOT] = ACTIONS(3743),
    [anon_sym_from] = ACTIONS(3741),
    [anon_sym_into] = ACTIONS(3741),
    [anon_sym_join] = ACTIONS(3741),
    [anon_sym_on] = ACTIONS(3741),
    [anon_sym_equals] = ACTIONS(3741),
    [anon_sym_let] = ACTIONS(3741),
    [anon_sym_orderby] = ACTIONS(3741),
    [anon_sym_ascending] = ACTIONS(3741),
    [anon_sym_descending] = ACTIONS(3741),
    [anon_sym_group] = ACTIONS(3741),
    [anon_sym_by] = ACTIONS(3741),
    [anon_sym_select] = ACTIONS(3741),
    [anon_sym_stackalloc] = ACTIONS(3741),
    [anon_sym_sizeof] = ACTIONS(3741),
    [anon_sym_typeof] = ACTIONS(3741),
    [anon_sym___makeref] = ACTIONS(3741),
    [anon_sym___reftype] = ACTIONS(3741),
    [anon_sym___refvalue] = ACTIONS(3741),
    [sym_null_literal] = ACTIONS(3741),
    [anon_sym_SQUOTE] = ACTIONS(3743),
    [sym_integer_literal] = ACTIONS(3741),
    [sym_real_literal] = ACTIONS(3743),
    [anon_sym_DQUOTE] = ACTIONS(3743),
    [sym_verbatim_string_literal] = ACTIONS(3743),
    [aux_sym_preproc_if_token1] = ACTIONS(3743),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3743),
    [sym_interpolation_verbatim_start] = ACTIONS(3743),
    [sym_interpolation_raw_start] = ACTIONS(3743),
    [sym_raw_string_start] = ACTIONS(3743),
  },
  [2523] = {
    [sym_preproc_region] = STATE(2523),
    [sym_preproc_endregion] = STATE(2523),
    [sym_preproc_line] = STATE(2523),
    [sym_preproc_pragma] = STATE(2523),
    [sym_preproc_nullable] = STATE(2523),
    [sym_preproc_error] = STATE(2523),
    [sym_preproc_warning] = STATE(2523),
    [sym_preproc_define] = STATE(2523),
    [sym_preproc_undef] = STATE(2523),
    [ts_builtin_sym_end] = ACTIONS(3747),
    [sym__identifier_token] = ACTIONS(3745),
    [anon_sym_extern] = ACTIONS(3745),
    [anon_sym_alias] = ACTIONS(3745),
    [anon_sym_SEMI] = ACTIONS(3747),
    [anon_sym_global] = ACTIONS(3745),
    [anon_sym_using] = ACTIONS(3745),
    [anon_sym_unsafe] = ACTIONS(3745),
    [anon_sym_static] = ACTIONS(3745),
    [anon_sym_LBRACK] = ACTIONS(3747),
    [anon_sym_LPAREN] = ACTIONS(3747),
    [anon_sym_return] = ACTIONS(3745),
    [anon_sym_namespace] = ACTIONS(3745),
    [anon_sym_class] = ACTIONS(3745),
    [anon_sym_ref] = ACTIONS(3745),
    [anon_sym_struct] = ACTIONS(3745),
    [anon_sym_enum] = ACTIONS(3745),
    [anon_sym_LBRACE] = ACTIONS(3747),
    [anon_sym_interface] = ACTIONS(3745),
    [anon_sym_delegate] = ACTIONS(3745),
    [anon_sym_record] = ACTIONS(3745),
    [anon_sym_abstract] = ACTIONS(3745),
    [anon_sym_async] = ACTIONS(3745),
    [anon_sym_const] = ACTIONS(3745),
    [anon_sym_file] = ACTIONS(3745),
    [anon_sym_fixed] = ACTIONS(3745),
    [anon_sym_internal] = ACTIONS(3745),
    [anon_sym_new] = ACTIONS(3745),
    [anon_sym_override] = ACTIONS(3745),
    [anon_sym_partial] = ACTIONS(3745),
    [anon_sym_private] = ACTIONS(3745),
    [anon_sym_protected] = ACTIONS(3745),
    [anon_sym_public] = ACTIONS(3745),
    [anon_sym_readonly] = ACTIONS(3745),
    [anon_sym_required] = ACTIONS(3745),
    [anon_sym_sealed] = ACTIONS(3745),
    [anon_sym_virtual] = ACTIONS(3745),
    [anon_sym_volatile] = ACTIONS(3745),
    [anon_sym_where] = ACTIONS(3745),
    [anon_sym_notnull] = ACTIONS(3745),
    [anon_sym_unmanaged] = ACTIONS(3745),
    [anon_sym_checked] = ACTIONS(3745),
    [anon_sym_BANG] = ACTIONS(3747),
    [anon_sym_TILDE] = ACTIONS(3747),
    [anon_sym_PLUS_PLUS] = ACTIONS(3747),
    [anon_sym_DASH_DASH] = ACTIONS(3747),
    [anon_sym_true] = ACTIONS(3745),
    [anon_sym_false] = ACTIONS(3745),
    [anon_sym_PLUS] = ACTIONS(3745),
    [anon_sym_DASH] = ACTIONS(3745),
    [anon_sym_STAR] = ACTIONS(3747),
    [anon_sym_CARET] = ACTIONS(3747),
    [anon_sym_AMP] = ACTIONS(3747),
    [anon_sym_this] = ACTIONS(3745),
    [anon_sym_scoped] = ACTIONS(3745),
    [anon_sym_base] = ACTIONS(3745),
    [anon_sym_var] = ACTIONS(3745),
    [sym_predefined_type] = ACTIONS(3745),
    [anon_sym_break] = ACTIONS(3745),
    [anon_sym_unchecked] = ACTIONS(3745),
    [anon_sym_continue] = ACTIONS(3745),
    [anon_sym_do] = ACTIONS(3745),
    [anon_sym_while] = ACTIONS(3745),
    [anon_sym_for] = ACTIONS(3745),
    [anon_sym_lock] = ACTIONS(3745),
    [anon_sym_yield] = ACTIONS(3745),
    [anon_sym_switch] = ACTIONS(3745),
    [anon_sym_default] = ACTIONS(3745),
    [anon_sym_throw] = ACTIONS(3745),
    [anon_sym_try] = ACTIONS(3745),
    [anon_sym_when] = ACTIONS(3745),
    [anon_sym_await] = ACTIONS(3745),
    [anon_sym_foreach] = ACTIONS(3745),
    [anon_sym_goto] = ACTIONS(3745),
    [anon_sym_if] = ACTIONS(3745),
    [anon_sym_DOT_DOT] = ACTIONS(3747),
    [anon_sym_from] = ACTIONS(3745),
    [anon_sym_into] = ACTIONS(3745),
    [anon_sym_join] = ACTIONS(3745),
    [anon_sym_on] = ACTIONS(3745),
    [anon_sym_equals] = ACTIONS(3745),
    [anon_sym_let] = ACTIONS(3745),
    [anon_sym_orderby] = ACTIONS(3745),
    [anon_sym_ascending] = ACTIONS(3745),
    [anon_sym_descending] = ACTIONS(3745),
    [anon_sym_group] = ACTIONS(3745),
    [anon_sym_by] = ACTIONS(3745),
    [anon_sym_select] = ACTIONS(3745),
    [anon_sym_stackalloc] = ACTIONS(3745),
    [anon_sym_sizeof] = ACTIONS(3745),
    [anon_sym_typeof] = ACTIONS(3745),
    [anon_sym___makeref] = ACTIONS(3745),
    [anon_sym___reftype] = ACTIONS(3745),
    [anon_sym___refvalue] = ACTIONS(3745),
    [sym_null_literal] = ACTIONS(3745),
    [anon_sym_SQUOTE] = ACTIONS(3747),
    [sym_integer_literal] = ACTIONS(3745),
    [sym_real_literal] = ACTIONS(3747),
    [anon_sym_DQUOTE] = ACTIONS(3747),
    [sym_verbatim_string_literal] = ACTIONS(3747),
    [aux_sym_preproc_if_token1] = ACTIONS(3747),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3747),
    [sym_interpolation_verbatim_start] = ACTIONS(3747),
    [sym_interpolation_raw_start] = ACTIONS(3747),
    [sym_raw_string_start] = ACTIONS(3747),
  },
  [2524] = {
    [sym_preproc_region] = STATE(2524),
    [sym_preproc_endregion] = STATE(2524),
    [sym_preproc_line] = STATE(2524),
    [sym_preproc_pragma] = STATE(2524),
    [sym_preproc_nullable] = STATE(2524),
    [sym_preproc_error] = STATE(2524),
    [sym_preproc_warning] = STATE(2524),
    [sym_preproc_define] = STATE(2524),
    [sym_preproc_undef] = STATE(2524),
    [ts_builtin_sym_end] = ACTIONS(3751),
    [sym__identifier_token] = ACTIONS(3749),
    [anon_sym_extern] = ACTIONS(3749),
    [anon_sym_alias] = ACTIONS(3749),
    [anon_sym_SEMI] = ACTIONS(3751),
    [anon_sym_global] = ACTIONS(3749),
    [anon_sym_using] = ACTIONS(3749),
    [anon_sym_unsafe] = ACTIONS(3749),
    [anon_sym_static] = ACTIONS(3749),
    [anon_sym_LBRACK] = ACTIONS(3751),
    [anon_sym_LPAREN] = ACTIONS(3751),
    [anon_sym_return] = ACTIONS(3749),
    [anon_sym_namespace] = ACTIONS(3749),
    [anon_sym_class] = ACTIONS(3749),
    [anon_sym_ref] = ACTIONS(3749),
    [anon_sym_struct] = ACTIONS(3749),
    [anon_sym_enum] = ACTIONS(3749),
    [anon_sym_LBRACE] = ACTIONS(3751),
    [anon_sym_interface] = ACTIONS(3749),
    [anon_sym_delegate] = ACTIONS(3749),
    [anon_sym_record] = ACTIONS(3749),
    [anon_sym_abstract] = ACTIONS(3749),
    [anon_sym_async] = ACTIONS(3749),
    [anon_sym_const] = ACTIONS(3749),
    [anon_sym_file] = ACTIONS(3749),
    [anon_sym_fixed] = ACTIONS(3749),
    [anon_sym_internal] = ACTIONS(3749),
    [anon_sym_new] = ACTIONS(3749),
    [anon_sym_override] = ACTIONS(3749),
    [anon_sym_partial] = ACTIONS(3749),
    [anon_sym_private] = ACTIONS(3749),
    [anon_sym_protected] = ACTIONS(3749),
    [anon_sym_public] = ACTIONS(3749),
    [anon_sym_readonly] = ACTIONS(3749),
    [anon_sym_required] = ACTIONS(3749),
    [anon_sym_sealed] = ACTIONS(3749),
    [anon_sym_virtual] = ACTIONS(3749),
    [anon_sym_volatile] = ACTIONS(3749),
    [anon_sym_where] = ACTIONS(3749),
    [anon_sym_notnull] = ACTIONS(3749),
    [anon_sym_unmanaged] = ACTIONS(3749),
    [anon_sym_checked] = ACTIONS(3749),
    [anon_sym_BANG] = ACTIONS(3751),
    [anon_sym_TILDE] = ACTIONS(3751),
    [anon_sym_PLUS_PLUS] = ACTIONS(3751),
    [anon_sym_DASH_DASH] = ACTIONS(3751),
    [anon_sym_true] = ACTIONS(3749),
    [anon_sym_false] = ACTIONS(3749),
    [anon_sym_PLUS] = ACTIONS(3749),
    [anon_sym_DASH] = ACTIONS(3749),
    [anon_sym_STAR] = ACTIONS(3751),
    [anon_sym_CARET] = ACTIONS(3751),
    [anon_sym_AMP] = ACTIONS(3751),
    [anon_sym_this] = ACTIONS(3749),
    [anon_sym_scoped] = ACTIONS(3749),
    [anon_sym_base] = ACTIONS(3749),
    [anon_sym_var] = ACTIONS(3749),
    [sym_predefined_type] = ACTIONS(3749),
    [anon_sym_break] = ACTIONS(3749),
    [anon_sym_unchecked] = ACTIONS(3749),
    [anon_sym_continue] = ACTIONS(3749),
    [anon_sym_do] = ACTIONS(3749),
    [anon_sym_while] = ACTIONS(3749),
    [anon_sym_for] = ACTIONS(3749),
    [anon_sym_lock] = ACTIONS(3749),
    [anon_sym_yield] = ACTIONS(3749),
    [anon_sym_switch] = ACTIONS(3749),
    [anon_sym_default] = ACTIONS(3749),
    [anon_sym_throw] = ACTIONS(3749),
    [anon_sym_try] = ACTIONS(3749),
    [anon_sym_when] = ACTIONS(3749),
    [anon_sym_await] = ACTIONS(3749),
    [anon_sym_foreach] = ACTIONS(3749),
    [anon_sym_goto] = ACTIONS(3749),
    [anon_sym_if] = ACTIONS(3749),
    [anon_sym_DOT_DOT] = ACTIONS(3751),
    [anon_sym_from] = ACTIONS(3749),
    [anon_sym_into] = ACTIONS(3749),
    [anon_sym_join] = ACTIONS(3749),
    [anon_sym_on] = ACTIONS(3749),
    [anon_sym_equals] = ACTIONS(3749),
    [anon_sym_let] = ACTIONS(3749),
    [anon_sym_orderby] = ACTIONS(3749),
    [anon_sym_ascending] = ACTIONS(3749),
    [anon_sym_descending] = ACTIONS(3749),
    [anon_sym_group] = ACTIONS(3749),
    [anon_sym_by] = ACTIONS(3749),
    [anon_sym_select] = ACTIONS(3749),
    [anon_sym_stackalloc] = ACTIONS(3749),
    [anon_sym_sizeof] = ACTIONS(3749),
    [anon_sym_typeof] = ACTIONS(3749),
    [anon_sym___makeref] = ACTIONS(3749),
    [anon_sym___reftype] = ACTIONS(3749),
    [anon_sym___refvalue] = ACTIONS(3749),
    [sym_null_literal] = ACTIONS(3749),
    [anon_sym_SQUOTE] = ACTIONS(3751),
    [sym_integer_literal] = ACTIONS(3749),
    [sym_real_literal] = ACTIONS(3751),
    [anon_sym_DQUOTE] = ACTIONS(3751),
    [sym_verbatim_string_literal] = ACTIONS(3751),
    [aux_sym_preproc_if_token1] = ACTIONS(3751),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3751),
    [sym_interpolation_verbatim_start] = ACTIONS(3751),
    [sym_interpolation_raw_start] = ACTIONS(3751),
    [sym_raw_string_start] = ACTIONS(3751),
  },
  [2525] = {
    [sym_preproc_region] = STATE(2525),
    [sym_preproc_endregion] = STATE(2525),
    [sym_preproc_line] = STATE(2525),
    [sym_preproc_pragma] = STATE(2525),
    [sym_preproc_nullable] = STATE(2525),
    [sym_preproc_error] = STATE(2525),
    [sym_preproc_warning] = STATE(2525),
    [sym_preproc_define] = STATE(2525),
    [sym_preproc_undef] = STATE(2525),
    [ts_builtin_sym_end] = ACTIONS(3755),
    [sym__identifier_token] = ACTIONS(3753),
    [anon_sym_extern] = ACTIONS(3753),
    [anon_sym_alias] = ACTIONS(3753),
    [anon_sym_SEMI] = ACTIONS(3755),
    [anon_sym_global] = ACTIONS(3753),
    [anon_sym_using] = ACTIONS(3753),
    [anon_sym_unsafe] = ACTIONS(3753),
    [anon_sym_static] = ACTIONS(3753),
    [anon_sym_LBRACK] = ACTIONS(3755),
    [anon_sym_LPAREN] = ACTIONS(3755),
    [anon_sym_return] = ACTIONS(3753),
    [anon_sym_namespace] = ACTIONS(3753),
    [anon_sym_class] = ACTIONS(3753),
    [anon_sym_ref] = ACTIONS(3753),
    [anon_sym_struct] = ACTIONS(3753),
    [anon_sym_enum] = ACTIONS(3753),
    [anon_sym_LBRACE] = ACTIONS(3755),
    [anon_sym_interface] = ACTIONS(3753),
    [anon_sym_delegate] = ACTIONS(3753),
    [anon_sym_record] = ACTIONS(3753),
    [anon_sym_abstract] = ACTIONS(3753),
    [anon_sym_async] = ACTIONS(3753),
    [anon_sym_const] = ACTIONS(3753),
    [anon_sym_file] = ACTIONS(3753),
    [anon_sym_fixed] = ACTIONS(3753),
    [anon_sym_internal] = ACTIONS(3753),
    [anon_sym_new] = ACTIONS(3753),
    [anon_sym_override] = ACTIONS(3753),
    [anon_sym_partial] = ACTIONS(3753),
    [anon_sym_private] = ACTIONS(3753),
    [anon_sym_protected] = ACTIONS(3753),
    [anon_sym_public] = ACTIONS(3753),
    [anon_sym_readonly] = ACTIONS(3753),
    [anon_sym_required] = ACTIONS(3753),
    [anon_sym_sealed] = ACTIONS(3753),
    [anon_sym_virtual] = ACTIONS(3753),
    [anon_sym_volatile] = ACTIONS(3753),
    [anon_sym_where] = ACTIONS(3753),
    [anon_sym_notnull] = ACTIONS(3753),
    [anon_sym_unmanaged] = ACTIONS(3753),
    [anon_sym_checked] = ACTIONS(3753),
    [anon_sym_BANG] = ACTIONS(3755),
    [anon_sym_TILDE] = ACTIONS(3755),
    [anon_sym_PLUS_PLUS] = ACTIONS(3755),
    [anon_sym_DASH_DASH] = ACTIONS(3755),
    [anon_sym_true] = ACTIONS(3753),
    [anon_sym_false] = ACTIONS(3753),
    [anon_sym_PLUS] = ACTIONS(3753),
    [anon_sym_DASH] = ACTIONS(3753),
    [anon_sym_STAR] = ACTIONS(3755),
    [anon_sym_CARET] = ACTIONS(3755),
    [anon_sym_AMP] = ACTIONS(3755),
    [anon_sym_this] = ACTIONS(3753),
    [anon_sym_scoped] = ACTIONS(3753),
    [anon_sym_base] = ACTIONS(3753),
    [anon_sym_var] = ACTIONS(3753),
    [sym_predefined_type] = ACTIONS(3753),
    [anon_sym_break] = ACTIONS(3753),
    [anon_sym_unchecked] = ACTIONS(3753),
    [anon_sym_continue] = ACTIONS(3753),
    [anon_sym_do] = ACTIONS(3753),
    [anon_sym_while] = ACTIONS(3753),
    [anon_sym_for] = ACTIONS(3753),
    [anon_sym_lock] = ACTIONS(3753),
    [anon_sym_yield] = ACTIONS(3753),
    [anon_sym_switch] = ACTIONS(3753),
    [anon_sym_default] = ACTIONS(3753),
    [anon_sym_throw] = ACTIONS(3753),
    [anon_sym_try] = ACTIONS(3753),
    [anon_sym_when] = ACTIONS(3753),
    [anon_sym_await] = ACTIONS(3753),
    [anon_sym_foreach] = ACTIONS(3753),
    [anon_sym_goto] = ACTIONS(3753),
    [anon_sym_if] = ACTIONS(3753),
    [anon_sym_DOT_DOT] = ACTIONS(3755),
    [anon_sym_from] = ACTIONS(3753),
    [anon_sym_into] = ACTIONS(3753),
    [anon_sym_join] = ACTIONS(3753),
    [anon_sym_on] = ACTIONS(3753),
    [anon_sym_equals] = ACTIONS(3753),
    [anon_sym_let] = ACTIONS(3753),
    [anon_sym_orderby] = ACTIONS(3753),
    [anon_sym_ascending] = ACTIONS(3753),
    [anon_sym_descending] = ACTIONS(3753),
    [anon_sym_group] = ACTIONS(3753),
    [anon_sym_by] = ACTIONS(3753),
    [anon_sym_select] = ACTIONS(3753),
    [anon_sym_stackalloc] = ACTIONS(3753),
    [anon_sym_sizeof] = ACTIONS(3753),
    [anon_sym_typeof] = ACTIONS(3753),
    [anon_sym___makeref] = ACTIONS(3753),
    [anon_sym___reftype] = ACTIONS(3753),
    [anon_sym___refvalue] = ACTIONS(3753),
    [sym_null_literal] = ACTIONS(3753),
    [anon_sym_SQUOTE] = ACTIONS(3755),
    [sym_integer_literal] = ACTIONS(3753),
    [sym_real_literal] = ACTIONS(3755),
    [anon_sym_DQUOTE] = ACTIONS(3755),
    [sym_verbatim_string_literal] = ACTIONS(3755),
    [aux_sym_preproc_if_token1] = ACTIONS(3755),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3755),
    [sym_interpolation_verbatim_start] = ACTIONS(3755),
    [sym_interpolation_raw_start] = ACTIONS(3755),
    [sym_raw_string_start] = ACTIONS(3755),
  },
  [2526] = {
    [sym_preproc_region] = STATE(2526),
    [sym_preproc_endregion] = STATE(2526),
    [sym_preproc_line] = STATE(2526),
    [sym_preproc_pragma] = STATE(2526),
    [sym_preproc_nullable] = STATE(2526),
    [sym_preproc_error] = STATE(2526),
    [sym_preproc_warning] = STATE(2526),
    [sym_preproc_define] = STATE(2526),
    [sym_preproc_undef] = STATE(2526),
    [ts_builtin_sym_end] = ACTIONS(3759),
    [sym__identifier_token] = ACTIONS(3757),
    [anon_sym_extern] = ACTIONS(3757),
    [anon_sym_alias] = ACTIONS(3757),
    [anon_sym_SEMI] = ACTIONS(3759),
    [anon_sym_global] = ACTIONS(3757),
    [anon_sym_using] = ACTIONS(3757),
    [anon_sym_unsafe] = ACTIONS(3757),
    [anon_sym_static] = ACTIONS(3757),
    [anon_sym_LBRACK] = ACTIONS(3759),
    [anon_sym_LPAREN] = ACTIONS(3759),
    [anon_sym_return] = ACTIONS(3757),
    [anon_sym_namespace] = ACTIONS(3757),
    [anon_sym_class] = ACTIONS(3757),
    [anon_sym_ref] = ACTIONS(3757),
    [anon_sym_struct] = ACTIONS(3757),
    [anon_sym_enum] = ACTIONS(3757),
    [anon_sym_LBRACE] = ACTIONS(3759),
    [anon_sym_interface] = ACTIONS(3757),
    [anon_sym_delegate] = ACTIONS(3757),
    [anon_sym_record] = ACTIONS(3757),
    [anon_sym_abstract] = ACTIONS(3757),
    [anon_sym_async] = ACTIONS(3757),
    [anon_sym_const] = ACTIONS(3757),
    [anon_sym_file] = ACTIONS(3757),
    [anon_sym_fixed] = ACTIONS(3757),
    [anon_sym_internal] = ACTIONS(3757),
    [anon_sym_new] = ACTIONS(3757),
    [anon_sym_override] = ACTIONS(3757),
    [anon_sym_partial] = ACTIONS(3757),
    [anon_sym_private] = ACTIONS(3757),
    [anon_sym_protected] = ACTIONS(3757),
    [anon_sym_public] = ACTIONS(3757),
    [anon_sym_readonly] = ACTIONS(3757),
    [anon_sym_required] = ACTIONS(3757),
    [anon_sym_sealed] = ACTIONS(3757),
    [anon_sym_virtual] = ACTIONS(3757),
    [anon_sym_volatile] = ACTIONS(3757),
    [anon_sym_where] = ACTIONS(3757),
    [anon_sym_notnull] = ACTIONS(3757),
    [anon_sym_unmanaged] = ACTIONS(3757),
    [anon_sym_checked] = ACTIONS(3757),
    [anon_sym_BANG] = ACTIONS(3759),
    [anon_sym_TILDE] = ACTIONS(3759),
    [anon_sym_PLUS_PLUS] = ACTIONS(3759),
    [anon_sym_DASH_DASH] = ACTIONS(3759),
    [anon_sym_true] = ACTIONS(3757),
    [anon_sym_false] = ACTIONS(3757),
    [anon_sym_PLUS] = ACTIONS(3757),
    [anon_sym_DASH] = ACTIONS(3757),
    [anon_sym_STAR] = ACTIONS(3759),
    [anon_sym_CARET] = ACTIONS(3759),
    [anon_sym_AMP] = ACTIONS(3759),
    [anon_sym_this] = ACTIONS(3757),
    [anon_sym_scoped] = ACTIONS(3757),
    [anon_sym_base] = ACTIONS(3757),
    [anon_sym_var] = ACTIONS(3757),
    [sym_predefined_type] = ACTIONS(3757),
    [anon_sym_break] = ACTIONS(3757),
    [anon_sym_unchecked] = ACTIONS(3757),
    [anon_sym_continue] = ACTIONS(3757),
    [anon_sym_do] = ACTIONS(3757),
    [anon_sym_while] = ACTIONS(3757),
    [anon_sym_for] = ACTIONS(3757),
    [anon_sym_lock] = ACTIONS(3757),
    [anon_sym_yield] = ACTIONS(3757),
    [anon_sym_switch] = ACTIONS(3757),
    [anon_sym_default] = ACTIONS(3757),
    [anon_sym_throw] = ACTIONS(3757),
    [anon_sym_try] = ACTIONS(3757),
    [anon_sym_when] = ACTIONS(3757),
    [anon_sym_await] = ACTIONS(3757),
    [anon_sym_foreach] = ACTIONS(3757),
    [anon_sym_goto] = ACTIONS(3757),
    [anon_sym_if] = ACTIONS(3757),
    [anon_sym_DOT_DOT] = ACTIONS(3759),
    [anon_sym_from] = ACTIONS(3757),
    [anon_sym_into] = ACTIONS(3757),
    [anon_sym_join] = ACTIONS(3757),
    [anon_sym_on] = ACTIONS(3757),
    [anon_sym_equals] = ACTIONS(3757),
    [anon_sym_let] = ACTIONS(3757),
    [anon_sym_orderby] = ACTIONS(3757),
    [anon_sym_ascending] = ACTIONS(3757),
    [anon_sym_descending] = ACTIONS(3757),
    [anon_sym_group] = ACTIONS(3757),
    [anon_sym_by] = ACTIONS(3757),
    [anon_sym_select] = ACTIONS(3757),
    [anon_sym_stackalloc] = ACTIONS(3757),
    [anon_sym_sizeof] = ACTIONS(3757),
    [anon_sym_typeof] = ACTIONS(3757),
    [anon_sym___makeref] = ACTIONS(3757),
    [anon_sym___reftype] = ACTIONS(3757),
    [anon_sym___refvalue] = ACTIONS(3757),
    [sym_null_literal] = ACTIONS(3757),
    [anon_sym_SQUOTE] = ACTIONS(3759),
    [sym_integer_literal] = ACTIONS(3757),
    [sym_real_literal] = ACTIONS(3759),
    [anon_sym_DQUOTE] = ACTIONS(3759),
    [sym_verbatim_string_literal] = ACTIONS(3759),
    [aux_sym_preproc_if_token1] = ACTIONS(3759),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3759),
    [sym_interpolation_verbatim_start] = ACTIONS(3759),
    [sym_interpolation_raw_start] = ACTIONS(3759),
    [sym_raw_string_start] = ACTIONS(3759),
  },
  [2527] = {
    [sym_preproc_region] = STATE(2527),
    [sym_preproc_endregion] = STATE(2527),
    [sym_preproc_line] = STATE(2527),
    [sym_preproc_pragma] = STATE(2527),
    [sym_preproc_nullable] = STATE(2527),
    [sym_preproc_error] = STATE(2527),
    [sym_preproc_warning] = STATE(2527),
    [sym_preproc_define] = STATE(2527),
    [sym_preproc_undef] = STATE(2527),
    [ts_builtin_sym_end] = ACTIONS(3763),
    [sym__identifier_token] = ACTIONS(3761),
    [anon_sym_extern] = ACTIONS(3761),
    [anon_sym_alias] = ACTIONS(3761),
    [anon_sym_SEMI] = ACTIONS(3763),
    [anon_sym_global] = ACTIONS(3761),
    [anon_sym_using] = ACTIONS(3761),
    [anon_sym_unsafe] = ACTIONS(3761),
    [anon_sym_static] = ACTIONS(3761),
    [anon_sym_LBRACK] = ACTIONS(3763),
    [anon_sym_LPAREN] = ACTIONS(3763),
    [anon_sym_return] = ACTIONS(3761),
    [anon_sym_namespace] = ACTIONS(3761),
    [anon_sym_class] = ACTIONS(3761),
    [anon_sym_ref] = ACTIONS(3761),
    [anon_sym_struct] = ACTIONS(3761),
    [anon_sym_enum] = ACTIONS(3761),
    [anon_sym_LBRACE] = ACTIONS(3763),
    [anon_sym_interface] = ACTIONS(3761),
    [anon_sym_delegate] = ACTIONS(3761),
    [anon_sym_record] = ACTIONS(3761),
    [anon_sym_abstract] = ACTIONS(3761),
    [anon_sym_async] = ACTIONS(3761),
    [anon_sym_const] = ACTIONS(3761),
    [anon_sym_file] = ACTIONS(3761),
    [anon_sym_fixed] = ACTIONS(3761),
    [anon_sym_internal] = ACTIONS(3761),
    [anon_sym_new] = ACTIONS(3761),
    [anon_sym_override] = ACTIONS(3761),
    [anon_sym_partial] = ACTIONS(3761),
    [anon_sym_private] = ACTIONS(3761),
    [anon_sym_protected] = ACTIONS(3761),
    [anon_sym_public] = ACTIONS(3761),
    [anon_sym_readonly] = ACTIONS(3761),
    [anon_sym_required] = ACTIONS(3761),
    [anon_sym_sealed] = ACTIONS(3761),
    [anon_sym_virtual] = ACTIONS(3761),
    [anon_sym_volatile] = ACTIONS(3761),
    [anon_sym_where] = ACTIONS(3761),
    [anon_sym_notnull] = ACTIONS(3761),
    [anon_sym_unmanaged] = ACTIONS(3761),
    [anon_sym_checked] = ACTIONS(3761),
    [anon_sym_BANG] = ACTIONS(3763),
    [anon_sym_TILDE] = ACTIONS(3763),
    [anon_sym_PLUS_PLUS] = ACTIONS(3763),
    [anon_sym_DASH_DASH] = ACTIONS(3763),
    [anon_sym_true] = ACTIONS(3761),
    [anon_sym_false] = ACTIONS(3761),
    [anon_sym_PLUS] = ACTIONS(3761),
    [anon_sym_DASH] = ACTIONS(3761),
    [anon_sym_STAR] = ACTIONS(3763),
    [anon_sym_CARET] = ACTIONS(3763),
    [anon_sym_AMP] = ACTIONS(3763),
    [anon_sym_this] = ACTIONS(3761),
    [anon_sym_scoped] = ACTIONS(3761),
    [anon_sym_base] = ACTIONS(3761),
    [anon_sym_var] = ACTIONS(3761),
    [sym_predefined_type] = ACTIONS(3761),
    [anon_sym_break] = ACTIONS(3761),
    [anon_sym_unchecked] = ACTIONS(3761),
    [anon_sym_continue] = ACTIONS(3761),
    [anon_sym_do] = ACTIONS(3761),
    [anon_sym_while] = ACTIONS(3761),
    [anon_sym_for] = ACTIONS(3761),
    [anon_sym_lock] = ACTIONS(3761),
    [anon_sym_yield] = ACTIONS(3761),
    [anon_sym_switch] = ACTIONS(3761),
    [anon_sym_default] = ACTIONS(3761),
    [anon_sym_throw] = ACTIONS(3761),
    [anon_sym_try] = ACTIONS(3761),
    [anon_sym_when] = ACTIONS(3761),
    [anon_sym_await] = ACTIONS(3761),
    [anon_sym_foreach] = ACTIONS(3761),
    [anon_sym_goto] = ACTIONS(3761),
    [anon_sym_if] = ACTIONS(3761),
    [anon_sym_DOT_DOT] = ACTIONS(3763),
    [anon_sym_from] = ACTIONS(3761),
    [anon_sym_into] = ACTIONS(3761),
    [anon_sym_join] = ACTIONS(3761),
    [anon_sym_on] = ACTIONS(3761),
    [anon_sym_equals] = ACTIONS(3761),
    [anon_sym_let] = ACTIONS(3761),
    [anon_sym_orderby] = ACTIONS(3761),
    [anon_sym_ascending] = ACTIONS(3761),
    [anon_sym_descending] = ACTIONS(3761),
    [anon_sym_group] = ACTIONS(3761),
    [anon_sym_by] = ACTIONS(3761),
    [anon_sym_select] = ACTIONS(3761),
    [anon_sym_stackalloc] = ACTIONS(3761),
    [anon_sym_sizeof] = ACTIONS(3761),
    [anon_sym_typeof] = ACTIONS(3761),
    [anon_sym___makeref] = ACTIONS(3761),
    [anon_sym___reftype] = ACTIONS(3761),
    [anon_sym___refvalue] = ACTIONS(3761),
    [sym_null_literal] = ACTIONS(3761),
    [anon_sym_SQUOTE] = ACTIONS(3763),
    [sym_integer_literal] = ACTIONS(3761),
    [sym_real_literal] = ACTIONS(3763),
    [anon_sym_DQUOTE] = ACTIONS(3763),
    [sym_verbatim_string_literal] = ACTIONS(3763),
    [aux_sym_preproc_if_token1] = ACTIONS(3763),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3763),
    [sym_interpolation_verbatim_start] = ACTIONS(3763),
    [sym_interpolation_raw_start] = ACTIONS(3763),
    [sym_raw_string_start] = ACTIONS(3763),
  },
  [2528] = {
    [sym_preproc_region] = STATE(2528),
    [sym_preproc_endregion] = STATE(2528),
    [sym_preproc_line] = STATE(2528),
    [sym_preproc_pragma] = STATE(2528),
    [sym_preproc_nullable] = STATE(2528),
    [sym_preproc_error] = STATE(2528),
    [sym_preproc_warning] = STATE(2528),
    [sym_preproc_define] = STATE(2528),
    [sym_preproc_undef] = STATE(2528),
    [ts_builtin_sym_end] = ACTIONS(3767),
    [sym__identifier_token] = ACTIONS(3765),
    [anon_sym_extern] = ACTIONS(3765),
    [anon_sym_alias] = ACTIONS(3765),
    [anon_sym_SEMI] = ACTIONS(3767),
    [anon_sym_global] = ACTIONS(3765),
    [anon_sym_using] = ACTIONS(3765),
    [anon_sym_unsafe] = ACTIONS(3765),
    [anon_sym_static] = ACTIONS(3765),
    [anon_sym_LBRACK] = ACTIONS(3767),
    [anon_sym_LPAREN] = ACTIONS(3767),
    [anon_sym_return] = ACTIONS(3765),
    [anon_sym_namespace] = ACTIONS(3765),
    [anon_sym_class] = ACTIONS(3765),
    [anon_sym_ref] = ACTIONS(3765),
    [anon_sym_struct] = ACTIONS(3765),
    [anon_sym_enum] = ACTIONS(3765),
    [anon_sym_LBRACE] = ACTIONS(3767),
    [anon_sym_interface] = ACTIONS(3765),
    [anon_sym_delegate] = ACTIONS(3765),
    [anon_sym_record] = ACTIONS(3765),
    [anon_sym_abstract] = ACTIONS(3765),
    [anon_sym_async] = ACTIONS(3765),
    [anon_sym_const] = ACTIONS(3765),
    [anon_sym_file] = ACTIONS(3765),
    [anon_sym_fixed] = ACTIONS(3765),
    [anon_sym_internal] = ACTIONS(3765),
    [anon_sym_new] = ACTIONS(3765),
    [anon_sym_override] = ACTIONS(3765),
    [anon_sym_partial] = ACTIONS(3765),
    [anon_sym_private] = ACTIONS(3765),
    [anon_sym_protected] = ACTIONS(3765),
    [anon_sym_public] = ACTIONS(3765),
    [anon_sym_readonly] = ACTIONS(3765),
    [anon_sym_required] = ACTIONS(3765),
    [anon_sym_sealed] = ACTIONS(3765),
    [anon_sym_virtual] = ACTIONS(3765),
    [anon_sym_volatile] = ACTIONS(3765),
    [anon_sym_where] = ACTIONS(3765),
    [anon_sym_notnull] = ACTIONS(3765),
    [anon_sym_unmanaged] = ACTIONS(3765),
    [anon_sym_checked] = ACTIONS(3765),
    [anon_sym_BANG] = ACTIONS(3767),
    [anon_sym_TILDE] = ACTIONS(3767),
    [anon_sym_PLUS_PLUS] = ACTIONS(3767),
    [anon_sym_DASH_DASH] = ACTIONS(3767),
    [anon_sym_true] = ACTIONS(3765),
    [anon_sym_false] = ACTIONS(3765),
    [anon_sym_PLUS] = ACTIONS(3765),
    [anon_sym_DASH] = ACTIONS(3765),
    [anon_sym_STAR] = ACTIONS(3767),
    [anon_sym_CARET] = ACTIONS(3767),
    [anon_sym_AMP] = ACTIONS(3767),
    [anon_sym_this] = ACTIONS(3765),
    [anon_sym_scoped] = ACTIONS(3765),
    [anon_sym_base] = ACTIONS(3765),
    [anon_sym_var] = ACTIONS(3765),
    [sym_predefined_type] = ACTIONS(3765),
    [anon_sym_break] = ACTIONS(3765),
    [anon_sym_unchecked] = ACTIONS(3765),
    [anon_sym_continue] = ACTIONS(3765),
    [anon_sym_do] = ACTIONS(3765),
    [anon_sym_while] = ACTIONS(3765),
    [anon_sym_for] = ACTIONS(3765),
    [anon_sym_lock] = ACTIONS(3765),
    [anon_sym_yield] = ACTIONS(3765),
    [anon_sym_switch] = ACTIONS(3765),
    [anon_sym_default] = ACTIONS(3765),
    [anon_sym_throw] = ACTIONS(3765),
    [anon_sym_try] = ACTIONS(3765),
    [anon_sym_when] = ACTIONS(3765),
    [anon_sym_await] = ACTIONS(3765),
    [anon_sym_foreach] = ACTIONS(3765),
    [anon_sym_goto] = ACTIONS(3765),
    [anon_sym_if] = ACTIONS(3765),
    [anon_sym_DOT_DOT] = ACTIONS(3767),
    [anon_sym_from] = ACTIONS(3765),
    [anon_sym_into] = ACTIONS(3765),
    [anon_sym_join] = ACTIONS(3765),
    [anon_sym_on] = ACTIONS(3765),
    [anon_sym_equals] = ACTIONS(3765),
    [anon_sym_let] = ACTIONS(3765),
    [anon_sym_orderby] = ACTIONS(3765),
    [anon_sym_ascending] = ACTIONS(3765),
    [anon_sym_descending] = ACTIONS(3765),
    [anon_sym_group] = ACTIONS(3765),
    [anon_sym_by] = ACTIONS(3765),
    [anon_sym_select] = ACTIONS(3765),
    [anon_sym_stackalloc] = ACTIONS(3765),
    [anon_sym_sizeof] = ACTIONS(3765),
    [anon_sym_typeof] = ACTIONS(3765),
    [anon_sym___makeref] = ACTIONS(3765),
    [anon_sym___reftype] = ACTIONS(3765),
    [anon_sym___refvalue] = ACTIONS(3765),
    [sym_null_literal] = ACTIONS(3765),
    [anon_sym_SQUOTE] = ACTIONS(3767),
    [sym_integer_literal] = ACTIONS(3765),
    [sym_real_literal] = ACTIONS(3767),
    [anon_sym_DQUOTE] = ACTIONS(3767),
    [sym_verbatim_string_literal] = ACTIONS(3767),
    [aux_sym_preproc_if_token1] = ACTIONS(3767),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3767),
    [sym_interpolation_verbatim_start] = ACTIONS(3767),
    [sym_interpolation_raw_start] = ACTIONS(3767),
    [sym_raw_string_start] = ACTIONS(3767),
  },
  [2529] = {
    [sym_preproc_region] = STATE(2529),
    [sym_preproc_endregion] = STATE(2529),
    [sym_preproc_line] = STATE(2529),
    [sym_preproc_pragma] = STATE(2529),
    [sym_preproc_nullable] = STATE(2529),
    [sym_preproc_error] = STATE(2529),
    [sym_preproc_warning] = STATE(2529),
    [sym_preproc_define] = STATE(2529),
    [sym_preproc_undef] = STATE(2529),
    [ts_builtin_sym_end] = ACTIONS(3507),
    [sym__identifier_token] = ACTIONS(3505),
    [anon_sym_extern] = ACTIONS(3505),
    [anon_sym_alias] = ACTIONS(3505),
    [anon_sym_SEMI] = ACTIONS(3507),
    [anon_sym_global] = ACTIONS(3505),
    [anon_sym_using] = ACTIONS(3505),
    [anon_sym_unsafe] = ACTIONS(3505),
    [anon_sym_static] = ACTIONS(3505),
    [anon_sym_LBRACK] = ACTIONS(3507),
    [anon_sym_LPAREN] = ACTIONS(3507),
    [anon_sym_return] = ACTIONS(3505),
    [anon_sym_namespace] = ACTIONS(3505),
    [anon_sym_class] = ACTIONS(3505),
    [anon_sym_ref] = ACTIONS(3505),
    [anon_sym_struct] = ACTIONS(3505),
    [anon_sym_enum] = ACTIONS(3505),
    [anon_sym_LBRACE] = ACTIONS(3507),
    [anon_sym_interface] = ACTIONS(3505),
    [anon_sym_delegate] = ACTIONS(3505),
    [anon_sym_record] = ACTIONS(3505),
    [anon_sym_abstract] = ACTIONS(3505),
    [anon_sym_async] = ACTIONS(3505),
    [anon_sym_const] = ACTIONS(3505),
    [anon_sym_file] = ACTIONS(3505),
    [anon_sym_fixed] = ACTIONS(3505),
    [anon_sym_internal] = ACTIONS(3505),
    [anon_sym_new] = ACTIONS(3505),
    [anon_sym_override] = ACTIONS(3505),
    [anon_sym_partial] = ACTIONS(3505),
    [anon_sym_private] = ACTIONS(3505),
    [anon_sym_protected] = ACTIONS(3505),
    [anon_sym_public] = ACTIONS(3505),
    [anon_sym_readonly] = ACTIONS(3505),
    [anon_sym_required] = ACTIONS(3505),
    [anon_sym_sealed] = ACTIONS(3505),
    [anon_sym_virtual] = ACTIONS(3505),
    [anon_sym_volatile] = ACTIONS(3505),
    [anon_sym_where] = ACTIONS(3505),
    [anon_sym_notnull] = ACTIONS(3505),
    [anon_sym_unmanaged] = ACTIONS(3505),
    [anon_sym_checked] = ACTIONS(3505),
    [anon_sym_BANG] = ACTIONS(3507),
    [anon_sym_TILDE] = ACTIONS(3507),
    [anon_sym_PLUS_PLUS] = ACTIONS(3507),
    [anon_sym_DASH_DASH] = ACTIONS(3507),
    [anon_sym_true] = ACTIONS(3505),
    [anon_sym_false] = ACTIONS(3505),
    [anon_sym_PLUS] = ACTIONS(3505),
    [anon_sym_DASH] = ACTIONS(3505),
    [anon_sym_STAR] = ACTIONS(3507),
    [anon_sym_CARET] = ACTIONS(3507),
    [anon_sym_AMP] = ACTIONS(3507),
    [anon_sym_this] = ACTIONS(3505),
    [anon_sym_scoped] = ACTIONS(3505),
    [anon_sym_base] = ACTIONS(3505),
    [anon_sym_var] = ACTIONS(3505),
    [sym_predefined_type] = ACTIONS(3505),
    [anon_sym_break] = ACTIONS(3505),
    [anon_sym_unchecked] = ACTIONS(3505),
    [anon_sym_continue] = ACTIONS(3505),
    [anon_sym_do] = ACTIONS(3505),
    [anon_sym_while] = ACTIONS(3505),
    [anon_sym_for] = ACTIONS(3505),
    [anon_sym_lock] = ACTIONS(3505),
    [anon_sym_yield] = ACTIONS(3505),
    [anon_sym_switch] = ACTIONS(3505),
    [anon_sym_default] = ACTIONS(3505),
    [anon_sym_throw] = ACTIONS(3505),
    [anon_sym_try] = ACTIONS(3505),
    [anon_sym_when] = ACTIONS(3505),
    [anon_sym_await] = ACTIONS(3505),
    [anon_sym_foreach] = ACTIONS(3505),
    [anon_sym_goto] = ACTIONS(3505),
    [anon_sym_if] = ACTIONS(3505),
    [anon_sym_DOT_DOT] = ACTIONS(3507),
    [anon_sym_from] = ACTIONS(3505),
    [anon_sym_into] = ACTIONS(3505),
    [anon_sym_join] = ACTIONS(3505),
    [anon_sym_on] = ACTIONS(3505),
    [anon_sym_equals] = ACTIONS(3505),
    [anon_sym_let] = ACTIONS(3505),
    [anon_sym_orderby] = ACTIONS(3505),
    [anon_sym_ascending] = ACTIONS(3505),
    [anon_sym_descending] = ACTIONS(3505),
    [anon_sym_group] = ACTIONS(3505),
    [anon_sym_by] = ACTIONS(3505),
    [anon_sym_select] = ACTIONS(3505),
    [anon_sym_stackalloc] = ACTIONS(3505),
    [anon_sym_sizeof] = ACTIONS(3505),
    [anon_sym_typeof] = ACTIONS(3505),
    [anon_sym___makeref] = ACTIONS(3505),
    [anon_sym___reftype] = ACTIONS(3505),
    [anon_sym___refvalue] = ACTIONS(3505),
    [sym_null_literal] = ACTIONS(3505),
    [anon_sym_SQUOTE] = ACTIONS(3507),
    [sym_integer_literal] = ACTIONS(3505),
    [sym_real_literal] = ACTIONS(3507),
    [anon_sym_DQUOTE] = ACTIONS(3507),
    [sym_verbatim_string_literal] = ACTIONS(3507),
    [aux_sym_preproc_if_token1] = ACTIONS(3507),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3507),
    [sym_interpolation_verbatim_start] = ACTIONS(3507),
    [sym_interpolation_raw_start] = ACTIONS(3507),
    [sym_raw_string_start] = ACTIONS(3507),
  },
  [2530] = {
    [sym_preproc_region] = STATE(2530),
    [sym_preproc_endregion] = STATE(2530),
    [sym_preproc_line] = STATE(2530),
    [sym_preproc_pragma] = STATE(2530),
    [sym_preproc_nullable] = STATE(2530),
    [sym_preproc_error] = STATE(2530),
    [sym_preproc_warning] = STATE(2530),
    [sym_preproc_define] = STATE(2530),
    [sym_preproc_undef] = STATE(2530),
    [ts_builtin_sym_end] = ACTIONS(3965),
    [sym__identifier_token] = ACTIONS(3963),
    [anon_sym_extern] = ACTIONS(3963),
    [anon_sym_alias] = ACTIONS(3963),
    [anon_sym_SEMI] = ACTIONS(3965),
    [anon_sym_global] = ACTIONS(3963),
    [anon_sym_using] = ACTIONS(3963),
    [anon_sym_unsafe] = ACTIONS(3963),
    [anon_sym_static] = ACTIONS(3963),
    [anon_sym_LBRACK] = ACTIONS(3965),
    [anon_sym_LPAREN] = ACTIONS(3965),
    [anon_sym_return] = ACTIONS(3963),
    [anon_sym_namespace] = ACTIONS(3963),
    [anon_sym_class] = ACTIONS(3963),
    [anon_sym_ref] = ACTIONS(3963),
    [anon_sym_struct] = ACTIONS(3963),
    [anon_sym_enum] = ACTIONS(3963),
    [anon_sym_LBRACE] = ACTIONS(3965),
    [anon_sym_interface] = ACTIONS(3963),
    [anon_sym_delegate] = ACTIONS(3963),
    [anon_sym_record] = ACTIONS(3963),
    [anon_sym_abstract] = ACTIONS(3963),
    [anon_sym_async] = ACTIONS(3963),
    [anon_sym_const] = ACTIONS(3963),
    [anon_sym_file] = ACTIONS(3963),
    [anon_sym_fixed] = ACTIONS(3963),
    [anon_sym_internal] = ACTIONS(3963),
    [anon_sym_new] = ACTIONS(3963),
    [anon_sym_override] = ACTIONS(3963),
    [anon_sym_partial] = ACTIONS(3963),
    [anon_sym_private] = ACTIONS(3963),
    [anon_sym_protected] = ACTIONS(3963),
    [anon_sym_public] = ACTIONS(3963),
    [anon_sym_readonly] = ACTIONS(3963),
    [anon_sym_required] = ACTIONS(3963),
    [anon_sym_sealed] = ACTIONS(3963),
    [anon_sym_virtual] = ACTIONS(3963),
    [anon_sym_volatile] = ACTIONS(3963),
    [anon_sym_where] = ACTIONS(3963),
    [anon_sym_notnull] = ACTIONS(3963),
    [anon_sym_unmanaged] = ACTIONS(3963),
    [anon_sym_checked] = ACTIONS(3963),
    [anon_sym_BANG] = ACTIONS(3965),
    [anon_sym_TILDE] = ACTIONS(3965),
    [anon_sym_PLUS_PLUS] = ACTIONS(3965),
    [anon_sym_DASH_DASH] = ACTIONS(3965),
    [anon_sym_true] = ACTIONS(3963),
    [anon_sym_false] = ACTIONS(3963),
    [anon_sym_PLUS] = ACTIONS(3963),
    [anon_sym_DASH] = ACTIONS(3963),
    [anon_sym_STAR] = ACTIONS(3965),
    [anon_sym_CARET] = ACTIONS(3965),
    [anon_sym_AMP] = ACTIONS(3965),
    [anon_sym_this] = ACTIONS(3963),
    [anon_sym_scoped] = ACTIONS(3963),
    [anon_sym_base] = ACTIONS(3963),
    [anon_sym_var] = ACTIONS(3963),
    [sym_predefined_type] = ACTIONS(3963),
    [anon_sym_break] = ACTIONS(3963),
    [anon_sym_unchecked] = ACTIONS(3963),
    [anon_sym_continue] = ACTIONS(3963),
    [anon_sym_do] = ACTIONS(3963),
    [anon_sym_while] = ACTIONS(3963),
    [anon_sym_for] = ACTIONS(3963),
    [anon_sym_lock] = ACTIONS(3963),
    [anon_sym_yield] = ACTIONS(3963),
    [anon_sym_switch] = ACTIONS(3963),
    [anon_sym_default] = ACTIONS(3963),
    [anon_sym_throw] = ACTIONS(3963),
    [anon_sym_try] = ACTIONS(3963),
    [anon_sym_when] = ACTIONS(3963),
    [anon_sym_await] = ACTIONS(3963),
    [anon_sym_foreach] = ACTIONS(3963),
    [anon_sym_goto] = ACTIONS(3963),
    [anon_sym_if] = ACTIONS(3963),
    [anon_sym_DOT_DOT] = ACTIONS(3965),
    [anon_sym_from] = ACTIONS(3963),
    [anon_sym_into] = ACTIONS(3963),
    [anon_sym_join] = ACTIONS(3963),
    [anon_sym_on] = ACTIONS(3963),
    [anon_sym_equals] = ACTIONS(3963),
    [anon_sym_let] = ACTIONS(3963),
    [anon_sym_orderby] = ACTIONS(3963),
    [anon_sym_ascending] = ACTIONS(3963),
    [anon_sym_descending] = ACTIONS(3963),
    [anon_sym_group] = ACTIONS(3963),
    [anon_sym_by] = ACTIONS(3963),
    [anon_sym_select] = ACTIONS(3963),
    [anon_sym_stackalloc] = ACTIONS(3963),
    [anon_sym_sizeof] = ACTIONS(3963),
    [anon_sym_typeof] = ACTIONS(3963),
    [anon_sym___makeref] = ACTIONS(3963),
    [anon_sym___reftype] = ACTIONS(3963),
    [anon_sym___refvalue] = ACTIONS(3963),
    [sym_null_literal] = ACTIONS(3963),
    [anon_sym_SQUOTE] = ACTIONS(3965),
    [sym_integer_literal] = ACTIONS(3963),
    [sym_real_literal] = ACTIONS(3965),
    [anon_sym_DQUOTE] = ACTIONS(3965),
    [sym_verbatim_string_literal] = ACTIONS(3965),
    [aux_sym_preproc_if_token1] = ACTIONS(3965),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3965),
    [sym_interpolation_verbatim_start] = ACTIONS(3965),
    [sym_interpolation_raw_start] = ACTIONS(3965),
    [sym_raw_string_start] = ACTIONS(3965),
  },
  [2531] = {
    [sym_preproc_region] = STATE(2531),
    [sym_preproc_endregion] = STATE(2531),
    [sym_preproc_line] = STATE(2531),
    [sym_preproc_pragma] = STATE(2531),
    [sym_preproc_nullable] = STATE(2531),
    [sym_preproc_error] = STATE(2531),
    [sym_preproc_warning] = STATE(2531),
    [sym_preproc_define] = STATE(2531),
    [sym_preproc_undef] = STATE(2531),
    [ts_builtin_sym_end] = ACTIONS(3969),
    [sym__identifier_token] = ACTIONS(3967),
    [anon_sym_extern] = ACTIONS(3967),
    [anon_sym_alias] = ACTIONS(3967),
    [anon_sym_SEMI] = ACTIONS(3969),
    [anon_sym_global] = ACTIONS(3967),
    [anon_sym_using] = ACTIONS(3967),
    [anon_sym_unsafe] = ACTIONS(3967),
    [anon_sym_static] = ACTIONS(3967),
    [anon_sym_LBRACK] = ACTIONS(3969),
    [anon_sym_LPAREN] = ACTIONS(3969),
    [anon_sym_return] = ACTIONS(3967),
    [anon_sym_namespace] = ACTIONS(3967),
    [anon_sym_class] = ACTIONS(3967),
    [anon_sym_ref] = ACTIONS(3967),
    [anon_sym_struct] = ACTIONS(3967),
    [anon_sym_enum] = ACTIONS(3967),
    [anon_sym_LBRACE] = ACTIONS(3969),
    [anon_sym_interface] = ACTIONS(3967),
    [anon_sym_delegate] = ACTIONS(3967),
    [anon_sym_record] = ACTIONS(3967),
    [anon_sym_abstract] = ACTIONS(3967),
    [anon_sym_async] = ACTIONS(3967),
    [anon_sym_const] = ACTIONS(3967),
    [anon_sym_file] = ACTIONS(3967),
    [anon_sym_fixed] = ACTIONS(3967),
    [anon_sym_internal] = ACTIONS(3967),
    [anon_sym_new] = ACTIONS(3967),
    [anon_sym_override] = ACTIONS(3967),
    [anon_sym_partial] = ACTIONS(3967),
    [anon_sym_private] = ACTIONS(3967),
    [anon_sym_protected] = ACTIONS(3967),
    [anon_sym_public] = ACTIONS(3967),
    [anon_sym_readonly] = ACTIONS(3967),
    [anon_sym_required] = ACTIONS(3967),
    [anon_sym_sealed] = ACTIONS(3967),
    [anon_sym_virtual] = ACTIONS(3967),
    [anon_sym_volatile] = ACTIONS(3967),
    [anon_sym_where] = ACTIONS(3967),
    [anon_sym_notnull] = ACTIONS(3967),
    [anon_sym_unmanaged] = ACTIONS(3967),
    [anon_sym_checked] = ACTIONS(3967),
    [anon_sym_BANG] = ACTIONS(3969),
    [anon_sym_TILDE] = ACTIONS(3969),
    [anon_sym_PLUS_PLUS] = ACTIONS(3969),
    [anon_sym_DASH_DASH] = ACTIONS(3969),
    [anon_sym_true] = ACTIONS(3967),
    [anon_sym_false] = ACTIONS(3967),
    [anon_sym_PLUS] = ACTIONS(3967),
    [anon_sym_DASH] = ACTIONS(3967),
    [anon_sym_STAR] = ACTIONS(3969),
    [anon_sym_CARET] = ACTIONS(3969),
    [anon_sym_AMP] = ACTIONS(3969),
    [anon_sym_this] = ACTIONS(3967),
    [anon_sym_scoped] = ACTIONS(3967),
    [anon_sym_base] = ACTIONS(3967),
    [anon_sym_var] = ACTIONS(3967),
    [sym_predefined_type] = ACTIONS(3967),
    [anon_sym_break] = ACTIONS(3967),
    [anon_sym_unchecked] = ACTIONS(3967),
    [anon_sym_continue] = ACTIONS(3967),
    [anon_sym_do] = ACTIONS(3967),
    [anon_sym_while] = ACTIONS(3967),
    [anon_sym_for] = ACTIONS(3967),
    [anon_sym_lock] = ACTIONS(3967),
    [anon_sym_yield] = ACTIONS(3967),
    [anon_sym_switch] = ACTIONS(3967),
    [anon_sym_default] = ACTIONS(3967),
    [anon_sym_throw] = ACTIONS(3967),
    [anon_sym_try] = ACTIONS(3967),
    [anon_sym_when] = ACTIONS(3967),
    [anon_sym_await] = ACTIONS(3967),
    [anon_sym_foreach] = ACTIONS(3967),
    [anon_sym_goto] = ACTIONS(3967),
    [anon_sym_if] = ACTIONS(3967),
    [anon_sym_DOT_DOT] = ACTIONS(3969),
    [anon_sym_from] = ACTIONS(3967),
    [anon_sym_into] = ACTIONS(3967),
    [anon_sym_join] = ACTIONS(3967),
    [anon_sym_on] = ACTIONS(3967),
    [anon_sym_equals] = ACTIONS(3967),
    [anon_sym_let] = ACTIONS(3967),
    [anon_sym_orderby] = ACTIONS(3967),
    [anon_sym_ascending] = ACTIONS(3967),
    [anon_sym_descending] = ACTIONS(3967),
    [anon_sym_group] = ACTIONS(3967),
    [anon_sym_by] = ACTIONS(3967),
    [anon_sym_select] = ACTIONS(3967),
    [anon_sym_stackalloc] = ACTIONS(3967),
    [anon_sym_sizeof] = ACTIONS(3967),
    [anon_sym_typeof] = ACTIONS(3967),
    [anon_sym___makeref] = ACTIONS(3967),
    [anon_sym___reftype] = ACTIONS(3967),
    [anon_sym___refvalue] = ACTIONS(3967),
    [sym_null_literal] = ACTIONS(3967),
    [anon_sym_SQUOTE] = ACTIONS(3969),
    [sym_integer_literal] = ACTIONS(3967),
    [sym_real_literal] = ACTIONS(3969),
    [anon_sym_DQUOTE] = ACTIONS(3969),
    [sym_verbatim_string_literal] = ACTIONS(3969),
    [aux_sym_preproc_if_token1] = ACTIONS(3969),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3969),
    [sym_interpolation_verbatim_start] = ACTIONS(3969),
    [sym_interpolation_raw_start] = ACTIONS(3969),
    [sym_raw_string_start] = ACTIONS(3969),
  },
  [2532] = {
    [sym_preproc_region] = STATE(2532),
    [sym_preproc_endregion] = STATE(2532),
    [sym_preproc_line] = STATE(2532),
    [sym_preproc_pragma] = STATE(2532),
    [sym_preproc_nullable] = STATE(2532),
    [sym_preproc_error] = STATE(2532),
    [sym_preproc_warning] = STATE(2532),
    [sym_preproc_define] = STATE(2532),
    [sym_preproc_undef] = STATE(2532),
    [ts_builtin_sym_end] = ACTIONS(3973),
    [sym__identifier_token] = ACTIONS(3971),
    [anon_sym_extern] = ACTIONS(3971),
    [anon_sym_alias] = ACTIONS(3971),
    [anon_sym_SEMI] = ACTIONS(3973),
    [anon_sym_global] = ACTIONS(3971),
    [anon_sym_using] = ACTIONS(3971),
    [anon_sym_unsafe] = ACTIONS(3971),
    [anon_sym_static] = ACTIONS(3971),
    [anon_sym_LBRACK] = ACTIONS(3973),
    [anon_sym_LPAREN] = ACTIONS(3973),
    [anon_sym_return] = ACTIONS(3971),
    [anon_sym_namespace] = ACTIONS(3971),
    [anon_sym_class] = ACTIONS(3971),
    [anon_sym_ref] = ACTIONS(3971),
    [anon_sym_struct] = ACTIONS(3971),
    [anon_sym_enum] = ACTIONS(3971),
    [anon_sym_LBRACE] = ACTIONS(3973),
    [anon_sym_interface] = ACTIONS(3971),
    [anon_sym_delegate] = ACTIONS(3971),
    [anon_sym_record] = ACTIONS(3971),
    [anon_sym_abstract] = ACTIONS(3971),
    [anon_sym_async] = ACTIONS(3971),
    [anon_sym_const] = ACTIONS(3971),
    [anon_sym_file] = ACTIONS(3971),
    [anon_sym_fixed] = ACTIONS(3971),
    [anon_sym_internal] = ACTIONS(3971),
    [anon_sym_new] = ACTIONS(3971),
    [anon_sym_override] = ACTIONS(3971),
    [anon_sym_partial] = ACTIONS(3971),
    [anon_sym_private] = ACTIONS(3971),
    [anon_sym_protected] = ACTIONS(3971),
    [anon_sym_public] = ACTIONS(3971),
    [anon_sym_readonly] = ACTIONS(3971),
    [anon_sym_required] = ACTIONS(3971),
    [anon_sym_sealed] = ACTIONS(3971),
    [anon_sym_virtual] = ACTIONS(3971),
    [anon_sym_volatile] = ACTIONS(3971),
    [anon_sym_where] = ACTIONS(3971),
    [anon_sym_notnull] = ACTIONS(3971),
    [anon_sym_unmanaged] = ACTIONS(3971),
    [anon_sym_checked] = ACTIONS(3971),
    [anon_sym_BANG] = ACTIONS(3973),
    [anon_sym_TILDE] = ACTIONS(3973),
    [anon_sym_PLUS_PLUS] = ACTIONS(3973),
    [anon_sym_DASH_DASH] = ACTIONS(3973),
    [anon_sym_true] = ACTIONS(3971),
    [anon_sym_false] = ACTIONS(3971),
    [anon_sym_PLUS] = ACTIONS(3971),
    [anon_sym_DASH] = ACTIONS(3971),
    [anon_sym_STAR] = ACTIONS(3973),
    [anon_sym_CARET] = ACTIONS(3973),
    [anon_sym_AMP] = ACTIONS(3973),
    [anon_sym_this] = ACTIONS(3971),
    [anon_sym_scoped] = ACTIONS(3971),
    [anon_sym_base] = ACTIONS(3971),
    [anon_sym_var] = ACTIONS(3971),
    [sym_predefined_type] = ACTIONS(3971),
    [anon_sym_break] = ACTIONS(3971),
    [anon_sym_unchecked] = ACTIONS(3971),
    [anon_sym_continue] = ACTIONS(3971),
    [anon_sym_do] = ACTIONS(3971),
    [anon_sym_while] = ACTIONS(3971),
    [anon_sym_for] = ACTIONS(3971),
    [anon_sym_lock] = ACTIONS(3971),
    [anon_sym_yield] = ACTIONS(3971),
    [anon_sym_switch] = ACTIONS(3971),
    [anon_sym_default] = ACTIONS(3971),
    [anon_sym_throw] = ACTIONS(3971),
    [anon_sym_try] = ACTIONS(3971),
    [anon_sym_when] = ACTIONS(3971),
    [anon_sym_await] = ACTIONS(3971),
    [anon_sym_foreach] = ACTIONS(3971),
    [anon_sym_goto] = ACTIONS(3971),
    [anon_sym_if] = ACTIONS(3971),
    [anon_sym_DOT_DOT] = ACTIONS(3973),
    [anon_sym_from] = ACTIONS(3971),
    [anon_sym_into] = ACTIONS(3971),
    [anon_sym_join] = ACTIONS(3971),
    [anon_sym_on] = ACTIONS(3971),
    [anon_sym_equals] = ACTIONS(3971),
    [anon_sym_let] = ACTIONS(3971),
    [anon_sym_orderby] = ACTIONS(3971),
    [anon_sym_ascending] = ACTIONS(3971),
    [anon_sym_descending] = ACTIONS(3971),
    [anon_sym_group] = ACTIONS(3971),
    [anon_sym_by] = ACTIONS(3971),
    [anon_sym_select] = ACTIONS(3971),
    [anon_sym_stackalloc] = ACTIONS(3971),
    [anon_sym_sizeof] = ACTIONS(3971),
    [anon_sym_typeof] = ACTIONS(3971),
    [anon_sym___makeref] = ACTIONS(3971),
    [anon_sym___reftype] = ACTIONS(3971),
    [anon_sym___refvalue] = ACTIONS(3971),
    [sym_null_literal] = ACTIONS(3971),
    [anon_sym_SQUOTE] = ACTIONS(3973),
    [sym_integer_literal] = ACTIONS(3971),
    [sym_real_literal] = ACTIONS(3973),
    [anon_sym_DQUOTE] = ACTIONS(3973),
    [sym_verbatim_string_literal] = ACTIONS(3973),
    [aux_sym_preproc_if_token1] = ACTIONS(3973),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3973),
    [sym_interpolation_verbatim_start] = ACTIONS(3973),
    [sym_interpolation_raw_start] = ACTIONS(3973),
    [sym_raw_string_start] = ACTIONS(3973),
  },
  [2533] = {
    [sym_preproc_region] = STATE(2533),
    [sym_preproc_endregion] = STATE(2533),
    [sym_preproc_line] = STATE(2533),
    [sym_preproc_pragma] = STATE(2533),
    [sym_preproc_nullable] = STATE(2533),
    [sym_preproc_error] = STATE(2533),
    [sym_preproc_warning] = STATE(2533),
    [sym_preproc_define] = STATE(2533),
    [sym_preproc_undef] = STATE(2533),
    [ts_builtin_sym_end] = ACTIONS(3977),
    [sym__identifier_token] = ACTIONS(3975),
    [anon_sym_extern] = ACTIONS(3975),
    [anon_sym_alias] = ACTIONS(3975),
    [anon_sym_SEMI] = ACTIONS(3977),
    [anon_sym_global] = ACTIONS(3975),
    [anon_sym_using] = ACTIONS(3975),
    [anon_sym_unsafe] = ACTIONS(3975),
    [anon_sym_static] = ACTIONS(3975),
    [anon_sym_LBRACK] = ACTIONS(3977),
    [anon_sym_LPAREN] = ACTIONS(3977),
    [anon_sym_return] = ACTIONS(3975),
    [anon_sym_namespace] = ACTIONS(3975),
    [anon_sym_class] = ACTIONS(3975),
    [anon_sym_ref] = ACTIONS(3975),
    [anon_sym_struct] = ACTIONS(3975),
    [anon_sym_enum] = ACTIONS(3975),
    [anon_sym_LBRACE] = ACTIONS(3977),
    [anon_sym_interface] = ACTIONS(3975),
    [anon_sym_delegate] = ACTIONS(3975),
    [anon_sym_record] = ACTIONS(3975),
    [anon_sym_abstract] = ACTIONS(3975),
    [anon_sym_async] = ACTIONS(3975),
    [anon_sym_const] = ACTIONS(3975),
    [anon_sym_file] = ACTIONS(3975),
    [anon_sym_fixed] = ACTIONS(3975),
    [anon_sym_internal] = ACTIONS(3975),
    [anon_sym_new] = ACTIONS(3975),
    [anon_sym_override] = ACTIONS(3975),
    [anon_sym_partial] = ACTIONS(3975),
    [anon_sym_private] = ACTIONS(3975),
    [anon_sym_protected] = ACTIONS(3975),
    [anon_sym_public] = ACTIONS(3975),
    [anon_sym_readonly] = ACTIONS(3975),
    [anon_sym_required] = ACTIONS(3975),
    [anon_sym_sealed] = ACTIONS(3975),
    [anon_sym_virtual] = ACTIONS(3975),
    [anon_sym_volatile] = ACTIONS(3975),
    [anon_sym_where] = ACTIONS(3975),
    [anon_sym_notnull] = ACTIONS(3975),
    [anon_sym_unmanaged] = ACTIONS(3975),
    [anon_sym_checked] = ACTIONS(3975),
    [anon_sym_BANG] = ACTIONS(3977),
    [anon_sym_TILDE] = ACTIONS(3977),
    [anon_sym_PLUS_PLUS] = ACTIONS(3977),
    [anon_sym_DASH_DASH] = ACTIONS(3977),
    [anon_sym_true] = ACTIONS(3975),
    [anon_sym_false] = ACTIONS(3975),
    [anon_sym_PLUS] = ACTIONS(3975),
    [anon_sym_DASH] = ACTIONS(3975),
    [anon_sym_STAR] = ACTIONS(3977),
    [anon_sym_CARET] = ACTIONS(3977),
    [anon_sym_AMP] = ACTIONS(3977),
    [anon_sym_this] = ACTIONS(3975),
    [anon_sym_scoped] = ACTIONS(3975),
    [anon_sym_base] = ACTIONS(3975),
    [anon_sym_var] = ACTIONS(3975),
    [sym_predefined_type] = ACTIONS(3975),
    [anon_sym_break] = ACTIONS(3975),
    [anon_sym_unchecked] = ACTIONS(3975),
    [anon_sym_continue] = ACTIONS(3975),
    [anon_sym_do] = ACTIONS(3975),
    [anon_sym_while] = ACTIONS(3975),
    [anon_sym_for] = ACTIONS(3975),
    [anon_sym_lock] = ACTIONS(3975),
    [anon_sym_yield] = ACTIONS(3975),
    [anon_sym_switch] = ACTIONS(3975),
    [anon_sym_default] = ACTIONS(3975),
    [anon_sym_throw] = ACTIONS(3975),
    [anon_sym_try] = ACTIONS(3975),
    [anon_sym_when] = ACTIONS(3975),
    [anon_sym_await] = ACTIONS(3975),
    [anon_sym_foreach] = ACTIONS(3975),
    [anon_sym_goto] = ACTIONS(3975),
    [anon_sym_if] = ACTIONS(3975),
    [anon_sym_DOT_DOT] = ACTIONS(3977),
    [anon_sym_from] = ACTIONS(3975),
    [anon_sym_into] = ACTIONS(3975),
    [anon_sym_join] = ACTIONS(3975),
    [anon_sym_on] = ACTIONS(3975),
    [anon_sym_equals] = ACTIONS(3975),
    [anon_sym_let] = ACTIONS(3975),
    [anon_sym_orderby] = ACTIONS(3975),
    [anon_sym_ascending] = ACTIONS(3975),
    [anon_sym_descending] = ACTIONS(3975),
    [anon_sym_group] = ACTIONS(3975),
    [anon_sym_by] = ACTIONS(3975),
    [anon_sym_select] = ACTIONS(3975),
    [anon_sym_stackalloc] = ACTIONS(3975),
    [anon_sym_sizeof] = ACTIONS(3975),
    [anon_sym_typeof] = ACTIONS(3975),
    [anon_sym___makeref] = ACTIONS(3975),
    [anon_sym___reftype] = ACTIONS(3975),
    [anon_sym___refvalue] = ACTIONS(3975),
    [sym_null_literal] = ACTIONS(3975),
    [anon_sym_SQUOTE] = ACTIONS(3977),
    [sym_integer_literal] = ACTIONS(3975),
    [sym_real_literal] = ACTIONS(3977),
    [anon_sym_DQUOTE] = ACTIONS(3977),
    [sym_verbatim_string_literal] = ACTIONS(3977),
    [aux_sym_preproc_if_token1] = ACTIONS(3977),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3977),
    [sym_interpolation_verbatim_start] = ACTIONS(3977),
    [sym_interpolation_raw_start] = ACTIONS(3977),
    [sym_raw_string_start] = ACTIONS(3977),
  },
  [2534] = {
    [sym_preproc_region] = STATE(2534),
    [sym_preproc_endregion] = STATE(2534),
    [sym_preproc_line] = STATE(2534),
    [sym_preproc_pragma] = STATE(2534),
    [sym_preproc_nullable] = STATE(2534),
    [sym_preproc_error] = STATE(2534),
    [sym_preproc_warning] = STATE(2534),
    [sym_preproc_define] = STATE(2534),
    [sym_preproc_undef] = STATE(2534),
    [ts_builtin_sym_end] = ACTIONS(3981),
    [sym__identifier_token] = ACTIONS(3979),
    [anon_sym_extern] = ACTIONS(3979),
    [anon_sym_alias] = ACTIONS(3979),
    [anon_sym_SEMI] = ACTIONS(3981),
    [anon_sym_global] = ACTIONS(3979),
    [anon_sym_using] = ACTIONS(3979),
    [anon_sym_unsafe] = ACTIONS(3979),
    [anon_sym_static] = ACTIONS(3979),
    [anon_sym_LBRACK] = ACTIONS(3981),
    [anon_sym_LPAREN] = ACTIONS(3981),
    [anon_sym_return] = ACTIONS(3979),
    [anon_sym_namespace] = ACTIONS(3979),
    [anon_sym_class] = ACTIONS(3979),
    [anon_sym_ref] = ACTIONS(3979),
    [anon_sym_struct] = ACTIONS(3979),
    [anon_sym_enum] = ACTIONS(3979),
    [anon_sym_LBRACE] = ACTIONS(3981),
    [anon_sym_interface] = ACTIONS(3979),
    [anon_sym_delegate] = ACTIONS(3979),
    [anon_sym_record] = ACTIONS(3979),
    [anon_sym_abstract] = ACTIONS(3979),
    [anon_sym_async] = ACTIONS(3979),
    [anon_sym_const] = ACTIONS(3979),
    [anon_sym_file] = ACTIONS(3979),
    [anon_sym_fixed] = ACTIONS(3979),
    [anon_sym_internal] = ACTIONS(3979),
    [anon_sym_new] = ACTIONS(3979),
    [anon_sym_override] = ACTIONS(3979),
    [anon_sym_partial] = ACTIONS(3979),
    [anon_sym_private] = ACTIONS(3979),
    [anon_sym_protected] = ACTIONS(3979),
    [anon_sym_public] = ACTIONS(3979),
    [anon_sym_readonly] = ACTIONS(3979),
    [anon_sym_required] = ACTIONS(3979),
    [anon_sym_sealed] = ACTIONS(3979),
    [anon_sym_virtual] = ACTIONS(3979),
    [anon_sym_volatile] = ACTIONS(3979),
    [anon_sym_where] = ACTIONS(3979),
    [anon_sym_notnull] = ACTIONS(3979),
    [anon_sym_unmanaged] = ACTIONS(3979),
    [anon_sym_checked] = ACTIONS(3979),
    [anon_sym_BANG] = ACTIONS(3981),
    [anon_sym_TILDE] = ACTIONS(3981),
    [anon_sym_PLUS_PLUS] = ACTIONS(3981),
    [anon_sym_DASH_DASH] = ACTIONS(3981),
    [anon_sym_true] = ACTIONS(3979),
    [anon_sym_false] = ACTIONS(3979),
    [anon_sym_PLUS] = ACTIONS(3979),
    [anon_sym_DASH] = ACTIONS(3979),
    [anon_sym_STAR] = ACTIONS(3981),
    [anon_sym_CARET] = ACTIONS(3981),
    [anon_sym_AMP] = ACTIONS(3981),
    [anon_sym_this] = ACTIONS(3979),
    [anon_sym_scoped] = ACTIONS(3979),
    [anon_sym_base] = ACTIONS(3979),
    [anon_sym_var] = ACTIONS(3979),
    [sym_predefined_type] = ACTIONS(3979),
    [anon_sym_break] = ACTIONS(3979),
    [anon_sym_unchecked] = ACTIONS(3979),
    [anon_sym_continue] = ACTIONS(3979),
    [anon_sym_do] = ACTIONS(3979),
    [anon_sym_while] = ACTIONS(3979),
    [anon_sym_for] = ACTIONS(3979),
    [anon_sym_lock] = ACTIONS(3979),
    [anon_sym_yield] = ACTIONS(3979),
    [anon_sym_switch] = ACTIONS(3979),
    [anon_sym_default] = ACTIONS(3979),
    [anon_sym_throw] = ACTIONS(3979),
    [anon_sym_try] = ACTIONS(3979),
    [anon_sym_when] = ACTIONS(3979),
    [anon_sym_await] = ACTIONS(3979),
    [anon_sym_foreach] = ACTIONS(3979),
    [anon_sym_goto] = ACTIONS(3979),
    [anon_sym_if] = ACTIONS(3979),
    [anon_sym_DOT_DOT] = ACTIONS(3981),
    [anon_sym_from] = ACTIONS(3979),
    [anon_sym_into] = ACTIONS(3979),
    [anon_sym_join] = ACTIONS(3979),
    [anon_sym_on] = ACTIONS(3979),
    [anon_sym_equals] = ACTIONS(3979),
    [anon_sym_let] = ACTIONS(3979),
    [anon_sym_orderby] = ACTIONS(3979),
    [anon_sym_ascending] = ACTIONS(3979),
    [anon_sym_descending] = ACTIONS(3979),
    [anon_sym_group] = ACTIONS(3979),
    [anon_sym_by] = ACTIONS(3979),
    [anon_sym_select] = ACTIONS(3979),
    [anon_sym_stackalloc] = ACTIONS(3979),
    [anon_sym_sizeof] = ACTIONS(3979),
    [anon_sym_typeof] = ACTIONS(3979),
    [anon_sym___makeref] = ACTIONS(3979),
    [anon_sym___reftype] = ACTIONS(3979),
    [anon_sym___refvalue] = ACTIONS(3979),
    [sym_null_literal] = ACTIONS(3979),
    [anon_sym_SQUOTE] = ACTIONS(3981),
    [sym_integer_literal] = ACTIONS(3979),
    [sym_real_literal] = ACTIONS(3981),
    [anon_sym_DQUOTE] = ACTIONS(3981),
    [sym_verbatim_string_literal] = ACTIONS(3981),
    [aux_sym_preproc_if_token1] = ACTIONS(3981),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3981),
    [sym_interpolation_verbatim_start] = ACTIONS(3981),
    [sym_interpolation_raw_start] = ACTIONS(3981),
    [sym_raw_string_start] = ACTIONS(3981),
  },
  [2535] = {
    [sym_preproc_region] = STATE(2535),
    [sym_preproc_endregion] = STATE(2535),
    [sym_preproc_line] = STATE(2535),
    [sym_preproc_pragma] = STATE(2535),
    [sym_preproc_nullable] = STATE(2535),
    [sym_preproc_error] = STATE(2535),
    [sym_preproc_warning] = STATE(2535),
    [sym_preproc_define] = STATE(2535),
    [sym_preproc_undef] = STATE(2535),
    [ts_builtin_sym_end] = ACTIONS(3771),
    [sym__identifier_token] = ACTIONS(3769),
    [anon_sym_extern] = ACTIONS(3769),
    [anon_sym_alias] = ACTIONS(3769),
    [anon_sym_SEMI] = ACTIONS(3771),
    [anon_sym_global] = ACTIONS(3769),
    [anon_sym_using] = ACTIONS(3769),
    [anon_sym_unsafe] = ACTIONS(3769),
    [anon_sym_static] = ACTIONS(3769),
    [anon_sym_LBRACK] = ACTIONS(3771),
    [anon_sym_LPAREN] = ACTIONS(3771),
    [anon_sym_return] = ACTIONS(3769),
    [anon_sym_namespace] = ACTIONS(3769),
    [anon_sym_class] = ACTIONS(3769),
    [anon_sym_ref] = ACTIONS(3769),
    [anon_sym_struct] = ACTIONS(3769),
    [anon_sym_enum] = ACTIONS(3769),
    [anon_sym_LBRACE] = ACTIONS(3771),
    [anon_sym_interface] = ACTIONS(3769),
    [anon_sym_delegate] = ACTIONS(3769),
    [anon_sym_record] = ACTIONS(3769),
    [anon_sym_abstract] = ACTIONS(3769),
    [anon_sym_async] = ACTIONS(3769),
    [anon_sym_const] = ACTIONS(3769),
    [anon_sym_file] = ACTIONS(3769),
    [anon_sym_fixed] = ACTIONS(3769),
    [anon_sym_internal] = ACTIONS(3769),
    [anon_sym_new] = ACTIONS(3769),
    [anon_sym_override] = ACTIONS(3769),
    [anon_sym_partial] = ACTIONS(3769),
    [anon_sym_private] = ACTIONS(3769),
    [anon_sym_protected] = ACTIONS(3769),
    [anon_sym_public] = ACTIONS(3769),
    [anon_sym_readonly] = ACTIONS(3769),
    [anon_sym_required] = ACTIONS(3769),
    [anon_sym_sealed] = ACTIONS(3769),
    [anon_sym_virtual] = ACTIONS(3769),
    [anon_sym_volatile] = ACTIONS(3769),
    [anon_sym_where] = ACTIONS(3769),
    [anon_sym_notnull] = ACTIONS(3769),
    [anon_sym_unmanaged] = ACTIONS(3769),
    [anon_sym_checked] = ACTIONS(3769),
    [anon_sym_BANG] = ACTIONS(3771),
    [anon_sym_TILDE] = ACTIONS(3771),
    [anon_sym_PLUS_PLUS] = ACTIONS(3771),
    [anon_sym_DASH_DASH] = ACTIONS(3771),
    [anon_sym_true] = ACTIONS(3769),
    [anon_sym_false] = ACTIONS(3769),
    [anon_sym_PLUS] = ACTIONS(3769),
    [anon_sym_DASH] = ACTIONS(3769),
    [anon_sym_STAR] = ACTIONS(3771),
    [anon_sym_CARET] = ACTIONS(3771),
    [anon_sym_AMP] = ACTIONS(3771),
    [anon_sym_this] = ACTIONS(3769),
    [anon_sym_scoped] = ACTIONS(3769),
    [anon_sym_base] = ACTIONS(3769),
    [anon_sym_var] = ACTIONS(3769),
    [sym_predefined_type] = ACTIONS(3769),
    [anon_sym_break] = ACTIONS(3769),
    [anon_sym_unchecked] = ACTIONS(3769),
    [anon_sym_continue] = ACTIONS(3769),
    [anon_sym_do] = ACTIONS(3769),
    [anon_sym_while] = ACTIONS(3769),
    [anon_sym_for] = ACTIONS(3769),
    [anon_sym_lock] = ACTIONS(3769),
    [anon_sym_yield] = ACTIONS(3769),
    [anon_sym_switch] = ACTIONS(3769),
    [anon_sym_default] = ACTIONS(3769),
    [anon_sym_throw] = ACTIONS(3769),
    [anon_sym_try] = ACTIONS(3769),
    [anon_sym_when] = ACTIONS(3769),
    [anon_sym_await] = ACTIONS(3769),
    [anon_sym_foreach] = ACTIONS(3769),
    [anon_sym_goto] = ACTIONS(3769),
    [anon_sym_if] = ACTIONS(3769),
    [anon_sym_DOT_DOT] = ACTIONS(3771),
    [anon_sym_from] = ACTIONS(3769),
    [anon_sym_into] = ACTIONS(3769),
    [anon_sym_join] = ACTIONS(3769),
    [anon_sym_on] = ACTIONS(3769),
    [anon_sym_equals] = ACTIONS(3769),
    [anon_sym_let] = ACTIONS(3769),
    [anon_sym_orderby] = ACTIONS(3769),
    [anon_sym_ascending] = ACTIONS(3769),
    [anon_sym_descending] = ACTIONS(3769),
    [anon_sym_group] = ACTIONS(3769),
    [anon_sym_by] = ACTIONS(3769),
    [anon_sym_select] = ACTIONS(3769),
    [anon_sym_stackalloc] = ACTIONS(3769),
    [anon_sym_sizeof] = ACTIONS(3769),
    [anon_sym_typeof] = ACTIONS(3769),
    [anon_sym___makeref] = ACTIONS(3769),
    [anon_sym___reftype] = ACTIONS(3769),
    [anon_sym___refvalue] = ACTIONS(3769),
    [sym_null_literal] = ACTIONS(3769),
    [anon_sym_SQUOTE] = ACTIONS(3771),
    [sym_integer_literal] = ACTIONS(3769),
    [sym_real_literal] = ACTIONS(3771),
    [anon_sym_DQUOTE] = ACTIONS(3771),
    [sym_verbatim_string_literal] = ACTIONS(3771),
    [aux_sym_preproc_if_token1] = ACTIONS(3771),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3771),
    [sym_interpolation_verbatim_start] = ACTIONS(3771),
    [sym_interpolation_raw_start] = ACTIONS(3771),
    [sym_raw_string_start] = ACTIONS(3771),
  },
  [2536] = {
    [sym_preproc_region] = STATE(2536),
    [sym_preproc_endregion] = STATE(2536),
    [sym_preproc_line] = STATE(2536),
    [sym_preproc_pragma] = STATE(2536),
    [sym_preproc_nullable] = STATE(2536),
    [sym_preproc_error] = STATE(2536),
    [sym_preproc_warning] = STATE(2536),
    [sym_preproc_define] = STATE(2536),
    [sym_preproc_undef] = STATE(2536),
    [ts_builtin_sym_end] = ACTIONS(3775),
    [sym__identifier_token] = ACTIONS(3773),
    [anon_sym_extern] = ACTIONS(3773),
    [anon_sym_alias] = ACTIONS(3773),
    [anon_sym_SEMI] = ACTIONS(3775),
    [anon_sym_global] = ACTIONS(3773),
    [anon_sym_using] = ACTIONS(3773),
    [anon_sym_unsafe] = ACTIONS(3773),
    [anon_sym_static] = ACTIONS(3773),
    [anon_sym_LBRACK] = ACTIONS(3775),
    [anon_sym_LPAREN] = ACTIONS(3775),
    [anon_sym_return] = ACTIONS(3773),
    [anon_sym_namespace] = ACTIONS(3773),
    [anon_sym_class] = ACTIONS(3773),
    [anon_sym_ref] = ACTIONS(3773),
    [anon_sym_struct] = ACTIONS(3773),
    [anon_sym_enum] = ACTIONS(3773),
    [anon_sym_LBRACE] = ACTIONS(3775),
    [anon_sym_interface] = ACTIONS(3773),
    [anon_sym_delegate] = ACTIONS(3773),
    [anon_sym_record] = ACTIONS(3773),
    [anon_sym_abstract] = ACTIONS(3773),
    [anon_sym_async] = ACTIONS(3773),
    [anon_sym_const] = ACTIONS(3773),
    [anon_sym_file] = ACTIONS(3773),
    [anon_sym_fixed] = ACTIONS(3773),
    [anon_sym_internal] = ACTIONS(3773),
    [anon_sym_new] = ACTIONS(3773),
    [anon_sym_override] = ACTIONS(3773),
    [anon_sym_partial] = ACTIONS(3773),
    [anon_sym_private] = ACTIONS(3773),
    [anon_sym_protected] = ACTIONS(3773),
    [anon_sym_public] = ACTIONS(3773),
    [anon_sym_readonly] = ACTIONS(3773),
    [anon_sym_required] = ACTIONS(3773),
    [anon_sym_sealed] = ACTIONS(3773),
    [anon_sym_virtual] = ACTIONS(3773),
    [anon_sym_volatile] = ACTIONS(3773),
    [anon_sym_where] = ACTIONS(3773),
    [anon_sym_notnull] = ACTIONS(3773),
    [anon_sym_unmanaged] = ACTIONS(3773),
    [anon_sym_checked] = ACTIONS(3773),
    [anon_sym_BANG] = ACTIONS(3775),
    [anon_sym_TILDE] = ACTIONS(3775),
    [anon_sym_PLUS_PLUS] = ACTIONS(3775),
    [anon_sym_DASH_DASH] = ACTIONS(3775),
    [anon_sym_true] = ACTIONS(3773),
    [anon_sym_false] = ACTIONS(3773),
    [anon_sym_PLUS] = ACTIONS(3773),
    [anon_sym_DASH] = ACTIONS(3773),
    [anon_sym_STAR] = ACTIONS(3775),
    [anon_sym_CARET] = ACTIONS(3775),
    [anon_sym_AMP] = ACTIONS(3775),
    [anon_sym_this] = ACTIONS(3773),
    [anon_sym_scoped] = ACTIONS(3773),
    [anon_sym_base] = ACTIONS(3773),
    [anon_sym_var] = ACTIONS(3773),
    [sym_predefined_type] = ACTIONS(3773),
    [anon_sym_break] = ACTIONS(3773),
    [anon_sym_unchecked] = ACTIONS(3773),
    [anon_sym_continue] = ACTIONS(3773),
    [anon_sym_do] = ACTIONS(3773),
    [anon_sym_while] = ACTIONS(3773),
    [anon_sym_for] = ACTIONS(3773),
    [anon_sym_lock] = ACTIONS(3773),
    [anon_sym_yield] = ACTIONS(3773),
    [anon_sym_switch] = ACTIONS(3773),
    [anon_sym_default] = ACTIONS(3773),
    [anon_sym_throw] = ACTIONS(3773),
    [anon_sym_try] = ACTIONS(3773),
    [anon_sym_when] = ACTIONS(3773),
    [anon_sym_await] = ACTIONS(3773),
    [anon_sym_foreach] = ACTIONS(3773),
    [anon_sym_goto] = ACTIONS(3773),
    [anon_sym_if] = ACTIONS(3773),
    [anon_sym_DOT_DOT] = ACTIONS(3775),
    [anon_sym_from] = ACTIONS(3773),
    [anon_sym_into] = ACTIONS(3773),
    [anon_sym_join] = ACTIONS(3773),
    [anon_sym_on] = ACTIONS(3773),
    [anon_sym_equals] = ACTIONS(3773),
    [anon_sym_let] = ACTIONS(3773),
    [anon_sym_orderby] = ACTIONS(3773),
    [anon_sym_ascending] = ACTIONS(3773),
    [anon_sym_descending] = ACTIONS(3773),
    [anon_sym_group] = ACTIONS(3773),
    [anon_sym_by] = ACTIONS(3773),
    [anon_sym_select] = ACTIONS(3773),
    [anon_sym_stackalloc] = ACTIONS(3773),
    [anon_sym_sizeof] = ACTIONS(3773),
    [anon_sym_typeof] = ACTIONS(3773),
    [anon_sym___makeref] = ACTIONS(3773),
    [anon_sym___reftype] = ACTIONS(3773),
    [anon_sym___refvalue] = ACTIONS(3773),
    [sym_null_literal] = ACTIONS(3773),
    [anon_sym_SQUOTE] = ACTIONS(3775),
    [sym_integer_literal] = ACTIONS(3773),
    [sym_real_literal] = ACTIONS(3775),
    [anon_sym_DQUOTE] = ACTIONS(3775),
    [sym_verbatim_string_literal] = ACTIONS(3775),
    [aux_sym_preproc_if_token1] = ACTIONS(3775),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3775),
    [sym_interpolation_verbatim_start] = ACTIONS(3775),
    [sym_interpolation_raw_start] = ACTIONS(3775),
    [sym_raw_string_start] = ACTIONS(3775),
  },
  [2537] = {
    [sym_preproc_region] = STATE(2537),
    [sym_preproc_endregion] = STATE(2537),
    [sym_preproc_line] = STATE(2537),
    [sym_preproc_pragma] = STATE(2537),
    [sym_preproc_nullable] = STATE(2537),
    [sym_preproc_error] = STATE(2537),
    [sym_preproc_warning] = STATE(2537),
    [sym_preproc_define] = STATE(2537),
    [sym_preproc_undef] = STATE(2537),
    [ts_builtin_sym_end] = ACTIONS(3779),
    [sym__identifier_token] = ACTIONS(3777),
    [anon_sym_extern] = ACTIONS(3777),
    [anon_sym_alias] = ACTIONS(3777),
    [anon_sym_SEMI] = ACTIONS(3779),
    [anon_sym_global] = ACTIONS(3777),
    [anon_sym_using] = ACTIONS(3777),
    [anon_sym_unsafe] = ACTIONS(3777),
    [anon_sym_static] = ACTIONS(3777),
    [anon_sym_LBRACK] = ACTIONS(3779),
    [anon_sym_LPAREN] = ACTIONS(3779),
    [anon_sym_return] = ACTIONS(3777),
    [anon_sym_namespace] = ACTIONS(3777),
    [anon_sym_class] = ACTIONS(3777),
    [anon_sym_ref] = ACTIONS(3777),
    [anon_sym_struct] = ACTIONS(3777),
    [anon_sym_enum] = ACTIONS(3777),
    [anon_sym_LBRACE] = ACTIONS(3779),
    [anon_sym_interface] = ACTIONS(3777),
    [anon_sym_delegate] = ACTIONS(3777),
    [anon_sym_record] = ACTIONS(3777),
    [anon_sym_abstract] = ACTIONS(3777),
    [anon_sym_async] = ACTIONS(3777),
    [anon_sym_const] = ACTIONS(3777),
    [anon_sym_file] = ACTIONS(3777),
    [anon_sym_fixed] = ACTIONS(3777),
    [anon_sym_internal] = ACTIONS(3777),
    [anon_sym_new] = ACTIONS(3777),
    [anon_sym_override] = ACTIONS(3777),
    [anon_sym_partial] = ACTIONS(3777),
    [anon_sym_private] = ACTIONS(3777),
    [anon_sym_protected] = ACTIONS(3777),
    [anon_sym_public] = ACTIONS(3777),
    [anon_sym_readonly] = ACTIONS(3777),
    [anon_sym_required] = ACTIONS(3777),
    [anon_sym_sealed] = ACTIONS(3777),
    [anon_sym_virtual] = ACTIONS(3777),
    [anon_sym_volatile] = ACTIONS(3777),
    [anon_sym_where] = ACTIONS(3777),
    [anon_sym_notnull] = ACTIONS(3777),
    [anon_sym_unmanaged] = ACTIONS(3777),
    [anon_sym_checked] = ACTIONS(3777),
    [anon_sym_BANG] = ACTIONS(3779),
    [anon_sym_TILDE] = ACTIONS(3779),
    [anon_sym_PLUS_PLUS] = ACTIONS(3779),
    [anon_sym_DASH_DASH] = ACTIONS(3779),
    [anon_sym_true] = ACTIONS(3777),
    [anon_sym_false] = ACTIONS(3777),
    [anon_sym_PLUS] = ACTIONS(3777),
    [anon_sym_DASH] = ACTIONS(3777),
    [anon_sym_STAR] = ACTIONS(3779),
    [anon_sym_CARET] = ACTIONS(3779),
    [anon_sym_AMP] = ACTIONS(3779),
    [anon_sym_this] = ACTIONS(3777),
    [anon_sym_scoped] = ACTIONS(3777),
    [anon_sym_base] = ACTIONS(3777),
    [anon_sym_var] = ACTIONS(3777),
    [sym_predefined_type] = ACTIONS(3777),
    [anon_sym_break] = ACTIONS(3777),
    [anon_sym_unchecked] = ACTIONS(3777),
    [anon_sym_continue] = ACTIONS(3777),
    [anon_sym_do] = ACTIONS(3777),
    [anon_sym_while] = ACTIONS(3777),
    [anon_sym_for] = ACTIONS(3777),
    [anon_sym_lock] = ACTIONS(3777),
    [anon_sym_yield] = ACTIONS(3777),
    [anon_sym_switch] = ACTIONS(3777),
    [anon_sym_default] = ACTIONS(3777),
    [anon_sym_throw] = ACTIONS(3777),
    [anon_sym_try] = ACTIONS(3777),
    [anon_sym_when] = ACTIONS(3777),
    [anon_sym_await] = ACTIONS(3777),
    [anon_sym_foreach] = ACTIONS(3777),
    [anon_sym_goto] = ACTIONS(3777),
    [anon_sym_if] = ACTIONS(3777),
    [anon_sym_DOT_DOT] = ACTIONS(3779),
    [anon_sym_from] = ACTIONS(3777),
    [anon_sym_into] = ACTIONS(3777),
    [anon_sym_join] = ACTIONS(3777),
    [anon_sym_on] = ACTIONS(3777),
    [anon_sym_equals] = ACTIONS(3777),
    [anon_sym_let] = ACTIONS(3777),
    [anon_sym_orderby] = ACTIONS(3777),
    [anon_sym_ascending] = ACTIONS(3777),
    [anon_sym_descending] = ACTIONS(3777),
    [anon_sym_group] = ACTIONS(3777),
    [anon_sym_by] = ACTIONS(3777),
    [anon_sym_select] = ACTIONS(3777),
    [anon_sym_stackalloc] = ACTIONS(3777),
    [anon_sym_sizeof] = ACTIONS(3777),
    [anon_sym_typeof] = ACTIONS(3777),
    [anon_sym___makeref] = ACTIONS(3777),
    [anon_sym___reftype] = ACTIONS(3777),
    [anon_sym___refvalue] = ACTIONS(3777),
    [sym_null_literal] = ACTIONS(3777),
    [anon_sym_SQUOTE] = ACTIONS(3779),
    [sym_integer_literal] = ACTIONS(3777),
    [sym_real_literal] = ACTIONS(3779),
    [anon_sym_DQUOTE] = ACTIONS(3779),
    [sym_verbatim_string_literal] = ACTIONS(3779),
    [aux_sym_preproc_if_token1] = ACTIONS(3779),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3779),
    [sym_interpolation_verbatim_start] = ACTIONS(3779),
    [sym_interpolation_raw_start] = ACTIONS(3779),
    [sym_raw_string_start] = ACTIONS(3779),
  },
  [2538] = {
    [sym_preproc_region] = STATE(2538),
    [sym_preproc_endregion] = STATE(2538),
    [sym_preproc_line] = STATE(2538),
    [sym_preproc_pragma] = STATE(2538),
    [sym_preproc_nullable] = STATE(2538),
    [sym_preproc_error] = STATE(2538),
    [sym_preproc_warning] = STATE(2538),
    [sym_preproc_define] = STATE(2538),
    [sym_preproc_undef] = STATE(2538),
    [ts_builtin_sym_end] = ACTIONS(3511),
    [sym__identifier_token] = ACTIONS(3509),
    [anon_sym_extern] = ACTIONS(3509),
    [anon_sym_alias] = ACTIONS(3509),
    [anon_sym_SEMI] = ACTIONS(3511),
    [anon_sym_global] = ACTIONS(3509),
    [anon_sym_using] = ACTIONS(3509),
    [anon_sym_unsafe] = ACTIONS(3509),
    [anon_sym_static] = ACTIONS(3509),
    [anon_sym_LBRACK] = ACTIONS(3511),
    [anon_sym_LPAREN] = ACTIONS(3511),
    [anon_sym_return] = ACTIONS(3509),
    [anon_sym_namespace] = ACTIONS(3509),
    [anon_sym_class] = ACTIONS(3509),
    [anon_sym_ref] = ACTIONS(3509),
    [anon_sym_struct] = ACTIONS(3509),
    [anon_sym_enum] = ACTIONS(3509),
    [anon_sym_LBRACE] = ACTIONS(3511),
    [anon_sym_interface] = ACTIONS(3509),
    [anon_sym_delegate] = ACTIONS(3509),
    [anon_sym_record] = ACTIONS(3509),
    [anon_sym_abstract] = ACTIONS(3509),
    [anon_sym_async] = ACTIONS(3509),
    [anon_sym_const] = ACTIONS(3509),
    [anon_sym_file] = ACTIONS(3509),
    [anon_sym_fixed] = ACTIONS(3509),
    [anon_sym_internal] = ACTIONS(3509),
    [anon_sym_new] = ACTIONS(3509),
    [anon_sym_override] = ACTIONS(3509),
    [anon_sym_partial] = ACTIONS(3509),
    [anon_sym_private] = ACTIONS(3509),
    [anon_sym_protected] = ACTIONS(3509),
    [anon_sym_public] = ACTIONS(3509),
    [anon_sym_readonly] = ACTIONS(3509),
    [anon_sym_required] = ACTIONS(3509),
    [anon_sym_sealed] = ACTIONS(3509),
    [anon_sym_virtual] = ACTIONS(3509),
    [anon_sym_volatile] = ACTIONS(3509),
    [anon_sym_where] = ACTIONS(3509),
    [anon_sym_notnull] = ACTIONS(3509),
    [anon_sym_unmanaged] = ACTIONS(3509),
    [anon_sym_checked] = ACTIONS(3509),
    [anon_sym_BANG] = ACTIONS(3511),
    [anon_sym_TILDE] = ACTIONS(3511),
    [anon_sym_PLUS_PLUS] = ACTIONS(3511),
    [anon_sym_DASH_DASH] = ACTIONS(3511),
    [anon_sym_true] = ACTIONS(3509),
    [anon_sym_false] = ACTIONS(3509),
    [anon_sym_PLUS] = ACTIONS(3509),
    [anon_sym_DASH] = ACTIONS(3509),
    [anon_sym_STAR] = ACTIONS(3511),
    [anon_sym_CARET] = ACTIONS(3511),
    [anon_sym_AMP] = ACTIONS(3511),
    [anon_sym_this] = ACTIONS(3509),
    [anon_sym_scoped] = ACTIONS(3509),
    [anon_sym_base] = ACTIONS(3509),
    [anon_sym_var] = ACTIONS(3509),
    [sym_predefined_type] = ACTIONS(3509),
    [anon_sym_break] = ACTIONS(3509),
    [anon_sym_unchecked] = ACTIONS(3509),
    [anon_sym_continue] = ACTIONS(3509),
    [anon_sym_do] = ACTIONS(3509),
    [anon_sym_while] = ACTIONS(3509),
    [anon_sym_for] = ACTIONS(3509),
    [anon_sym_lock] = ACTIONS(3509),
    [anon_sym_yield] = ACTIONS(3509),
    [anon_sym_switch] = ACTIONS(3509),
    [anon_sym_default] = ACTIONS(3509),
    [anon_sym_throw] = ACTIONS(3509),
    [anon_sym_try] = ACTIONS(3509),
    [anon_sym_when] = ACTIONS(3509),
    [anon_sym_await] = ACTIONS(3509),
    [anon_sym_foreach] = ACTIONS(3509),
    [anon_sym_goto] = ACTIONS(3509),
    [anon_sym_if] = ACTIONS(3509),
    [anon_sym_DOT_DOT] = ACTIONS(3511),
    [anon_sym_from] = ACTIONS(3509),
    [anon_sym_into] = ACTIONS(3509),
    [anon_sym_join] = ACTIONS(3509),
    [anon_sym_on] = ACTIONS(3509),
    [anon_sym_equals] = ACTIONS(3509),
    [anon_sym_let] = ACTIONS(3509),
    [anon_sym_orderby] = ACTIONS(3509),
    [anon_sym_ascending] = ACTIONS(3509),
    [anon_sym_descending] = ACTIONS(3509),
    [anon_sym_group] = ACTIONS(3509),
    [anon_sym_by] = ACTIONS(3509),
    [anon_sym_select] = ACTIONS(3509),
    [anon_sym_stackalloc] = ACTIONS(3509),
    [anon_sym_sizeof] = ACTIONS(3509),
    [anon_sym_typeof] = ACTIONS(3509),
    [anon_sym___makeref] = ACTIONS(3509),
    [anon_sym___reftype] = ACTIONS(3509),
    [anon_sym___refvalue] = ACTIONS(3509),
    [sym_null_literal] = ACTIONS(3509),
    [anon_sym_SQUOTE] = ACTIONS(3511),
    [sym_integer_literal] = ACTIONS(3509),
    [sym_real_literal] = ACTIONS(3511),
    [anon_sym_DQUOTE] = ACTIONS(3511),
    [sym_verbatim_string_literal] = ACTIONS(3511),
    [aux_sym_preproc_if_token1] = ACTIONS(3511),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3511),
    [sym_interpolation_verbatim_start] = ACTIONS(3511),
    [sym_interpolation_raw_start] = ACTIONS(3511),
    [sym_raw_string_start] = ACTIONS(3511),
  },
  [2539] = {
    [sym_preproc_region] = STATE(2539),
    [sym_preproc_endregion] = STATE(2539),
    [sym_preproc_line] = STATE(2539),
    [sym_preproc_pragma] = STATE(2539),
    [sym_preproc_nullable] = STATE(2539),
    [sym_preproc_error] = STATE(2539),
    [sym_preproc_warning] = STATE(2539),
    [sym_preproc_define] = STATE(2539),
    [sym_preproc_undef] = STATE(2539),
    [ts_builtin_sym_end] = ACTIONS(3583),
    [sym__identifier_token] = ACTIONS(3581),
    [anon_sym_extern] = ACTIONS(3581),
    [anon_sym_alias] = ACTIONS(3581),
    [anon_sym_SEMI] = ACTIONS(3583),
    [anon_sym_global] = ACTIONS(3581),
    [anon_sym_using] = ACTIONS(3581),
    [anon_sym_unsafe] = ACTIONS(3581),
    [anon_sym_static] = ACTIONS(3581),
    [anon_sym_LBRACK] = ACTIONS(3583),
    [anon_sym_LPAREN] = ACTIONS(3583),
    [anon_sym_return] = ACTIONS(3581),
    [anon_sym_namespace] = ACTIONS(3581),
    [anon_sym_class] = ACTIONS(3581),
    [anon_sym_ref] = ACTIONS(3581),
    [anon_sym_struct] = ACTIONS(3581),
    [anon_sym_enum] = ACTIONS(3581),
    [anon_sym_LBRACE] = ACTIONS(3583),
    [anon_sym_interface] = ACTIONS(3581),
    [anon_sym_delegate] = ACTIONS(3581),
    [anon_sym_record] = ACTIONS(3581),
    [anon_sym_abstract] = ACTIONS(3581),
    [anon_sym_async] = ACTIONS(3581),
    [anon_sym_const] = ACTIONS(3581),
    [anon_sym_file] = ACTIONS(3581),
    [anon_sym_fixed] = ACTIONS(3581),
    [anon_sym_internal] = ACTIONS(3581),
    [anon_sym_new] = ACTIONS(3581),
    [anon_sym_override] = ACTIONS(3581),
    [anon_sym_partial] = ACTIONS(3581),
    [anon_sym_private] = ACTIONS(3581),
    [anon_sym_protected] = ACTIONS(3581),
    [anon_sym_public] = ACTIONS(3581),
    [anon_sym_readonly] = ACTIONS(3581),
    [anon_sym_required] = ACTIONS(3581),
    [anon_sym_sealed] = ACTIONS(3581),
    [anon_sym_virtual] = ACTIONS(3581),
    [anon_sym_volatile] = ACTIONS(3581),
    [anon_sym_where] = ACTIONS(3581),
    [anon_sym_notnull] = ACTIONS(3581),
    [anon_sym_unmanaged] = ACTIONS(3581),
    [anon_sym_checked] = ACTIONS(3581),
    [anon_sym_BANG] = ACTIONS(3583),
    [anon_sym_TILDE] = ACTIONS(3583),
    [anon_sym_PLUS_PLUS] = ACTIONS(3583),
    [anon_sym_DASH_DASH] = ACTIONS(3583),
    [anon_sym_true] = ACTIONS(3581),
    [anon_sym_false] = ACTIONS(3581),
    [anon_sym_PLUS] = ACTIONS(3581),
    [anon_sym_DASH] = ACTIONS(3581),
    [anon_sym_STAR] = ACTIONS(3583),
    [anon_sym_CARET] = ACTIONS(3583),
    [anon_sym_AMP] = ACTIONS(3583),
    [anon_sym_this] = ACTIONS(3581),
    [anon_sym_scoped] = ACTIONS(3581),
    [anon_sym_base] = ACTIONS(3581),
    [anon_sym_var] = ACTIONS(3581),
    [sym_predefined_type] = ACTIONS(3581),
    [anon_sym_break] = ACTIONS(3581),
    [anon_sym_unchecked] = ACTIONS(3581),
    [anon_sym_continue] = ACTIONS(3581),
    [anon_sym_do] = ACTIONS(3581),
    [anon_sym_while] = ACTIONS(3581),
    [anon_sym_for] = ACTIONS(3581),
    [anon_sym_lock] = ACTIONS(3581),
    [anon_sym_yield] = ACTIONS(3581),
    [anon_sym_switch] = ACTIONS(3581),
    [anon_sym_default] = ACTIONS(3581),
    [anon_sym_throw] = ACTIONS(3581),
    [anon_sym_try] = ACTIONS(3581),
    [anon_sym_when] = ACTIONS(3581),
    [anon_sym_await] = ACTIONS(3581),
    [anon_sym_foreach] = ACTIONS(3581),
    [anon_sym_goto] = ACTIONS(3581),
    [anon_sym_if] = ACTIONS(3581),
    [anon_sym_DOT_DOT] = ACTIONS(3583),
    [anon_sym_from] = ACTIONS(3581),
    [anon_sym_into] = ACTIONS(3581),
    [anon_sym_join] = ACTIONS(3581),
    [anon_sym_on] = ACTIONS(3581),
    [anon_sym_equals] = ACTIONS(3581),
    [anon_sym_let] = ACTIONS(3581),
    [anon_sym_orderby] = ACTIONS(3581),
    [anon_sym_ascending] = ACTIONS(3581),
    [anon_sym_descending] = ACTIONS(3581),
    [anon_sym_group] = ACTIONS(3581),
    [anon_sym_by] = ACTIONS(3581),
    [anon_sym_select] = ACTIONS(3581),
    [anon_sym_stackalloc] = ACTIONS(3581),
    [anon_sym_sizeof] = ACTIONS(3581),
    [anon_sym_typeof] = ACTIONS(3581),
    [anon_sym___makeref] = ACTIONS(3581),
    [anon_sym___reftype] = ACTIONS(3581),
    [anon_sym___refvalue] = ACTIONS(3581),
    [sym_null_literal] = ACTIONS(3581),
    [anon_sym_SQUOTE] = ACTIONS(3583),
    [sym_integer_literal] = ACTIONS(3581),
    [sym_real_literal] = ACTIONS(3583),
    [anon_sym_DQUOTE] = ACTIONS(3583),
    [sym_verbatim_string_literal] = ACTIONS(3583),
    [aux_sym_preproc_if_token1] = ACTIONS(3583),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3583),
    [sym_interpolation_verbatim_start] = ACTIONS(3583),
    [sym_interpolation_raw_start] = ACTIONS(3583),
    [sym_raw_string_start] = ACTIONS(3583),
  },
  [2540] = {
    [sym_preproc_region] = STATE(2540),
    [sym_preproc_endregion] = STATE(2540),
    [sym_preproc_line] = STATE(2540),
    [sym_preproc_pragma] = STATE(2540),
    [sym_preproc_nullable] = STATE(2540),
    [sym_preproc_error] = STATE(2540),
    [sym_preproc_warning] = STATE(2540),
    [sym_preproc_define] = STATE(2540),
    [sym_preproc_undef] = STATE(2540),
    [ts_builtin_sym_end] = ACTIONS(3945),
    [sym__identifier_token] = ACTIONS(3943),
    [anon_sym_extern] = ACTIONS(3943),
    [anon_sym_alias] = ACTIONS(3943),
    [anon_sym_SEMI] = ACTIONS(3945),
    [anon_sym_global] = ACTIONS(3943),
    [anon_sym_using] = ACTIONS(3943),
    [anon_sym_unsafe] = ACTIONS(3943),
    [anon_sym_static] = ACTIONS(3943),
    [anon_sym_LBRACK] = ACTIONS(3945),
    [anon_sym_LPAREN] = ACTIONS(3945),
    [anon_sym_return] = ACTIONS(3943),
    [anon_sym_namespace] = ACTIONS(3943),
    [anon_sym_class] = ACTIONS(3943),
    [anon_sym_ref] = ACTIONS(3943),
    [anon_sym_struct] = ACTIONS(3943),
    [anon_sym_enum] = ACTIONS(3943),
    [anon_sym_LBRACE] = ACTIONS(3945),
    [anon_sym_interface] = ACTIONS(3943),
    [anon_sym_delegate] = ACTIONS(3943),
    [anon_sym_record] = ACTIONS(3943),
    [anon_sym_abstract] = ACTIONS(3943),
    [anon_sym_async] = ACTIONS(3943),
    [anon_sym_const] = ACTIONS(3943),
    [anon_sym_file] = ACTIONS(3943),
    [anon_sym_fixed] = ACTIONS(3943),
    [anon_sym_internal] = ACTIONS(3943),
    [anon_sym_new] = ACTIONS(3943),
    [anon_sym_override] = ACTIONS(3943),
    [anon_sym_partial] = ACTIONS(3943),
    [anon_sym_private] = ACTIONS(3943),
    [anon_sym_protected] = ACTIONS(3943),
    [anon_sym_public] = ACTIONS(3943),
    [anon_sym_readonly] = ACTIONS(3943),
    [anon_sym_required] = ACTIONS(3943),
    [anon_sym_sealed] = ACTIONS(3943),
    [anon_sym_virtual] = ACTIONS(3943),
    [anon_sym_volatile] = ACTIONS(3943),
    [anon_sym_where] = ACTIONS(3943),
    [anon_sym_notnull] = ACTIONS(3943),
    [anon_sym_unmanaged] = ACTIONS(3943),
    [anon_sym_checked] = ACTIONS(3943),
    [anon_sym_BANG] = ACTIONS(3945),
    [anon_sym_TILDE] = ACTIONS(3945),
    [anon_sym_PLUS_PLUS] = ACTIONS(3945),
    [anon_sym_DASH_DASH] = ACTIONS(3945),
    [anon_sym_true] = ACTIONS(3943),
    [anon_sym_false] = ACTIONS(3943),
    [anon_sym_PLUS] = ACTIONS(3943),
    [anon_sym_DASH] = ACTIONS(3943),
    [anon_sym_STAR] = ACTIONS(3945),
    [anon_sym_CARET] = ACTIONS(3945),
    [anon_sym_AMP] = ACTIONS(3945),
    [anon_sym_this] = ACTIONS(3943),
    [anon_sym_scoped] = ACTIONS(3943),
    [anon_sym_base] = ACTIONS(3943),
    [anon_sym_var] = ACTIONS(3943),
    [sym_predefined_type] = ACTIONS(3943),
    [anon_sym_break] = ACTIONS(3943),
    [anon_sym_unchecked] = ACTIONS(3943),
    [anon_sym_continue] = ACTIONS(3943),
    [anon_sym_do] = ACTIONS(3943),
    [anon_sym_while] = ACTIONS(3943),
    [anon_sym_for] = ACTIONS(3943),
    [anon_sym_lock] = ACTIONS(3943),
    [anon_sym_yield] = ACTIONS(3943),
    [anon_sym_switch] = ACTIONS(3943),
    [anon_sym_default] = ACTIONS(3943),
    [anon_sym_throw] = ACTIONS(3943),
    [anon_sym_try] = ACTIONS(3943),
    [anon_sym_when] = ACTIONS(3943),
    [anon_sym_await] = ACTIONS(3943),
    [anon_sym_foreach] = ACTIONS(3943),
    [anon_sym_goto] = ACTIONS(3943),
    [anon_sym_if] = ACTIONS(3943),
    [anon_sym_DOT_DOT] = ACTIONS(3945),
    [anon_sym_from] = ACTIONS(3943),
    [anon_sym_into] = ACTIONS(3943),
    [anon_sym_join] = ACTIONS(3943),
    [anon_sym_on] = ACTIONS(3943),
    [anon_sym_equals] = ACTIONS(3943),
    [anon_sym_let] = ACTIONS(3943),
    [anon_sym_orderby] = ACTIONS(3943),
    [anon_sym_ascending] = ACTIONS(3943),
    [anon_sym_descending] = ACTIONS(3943),
    [anon_sym_group] = ACTIONS(3943),
    [anon_sym_by] = ACTIONS(3943),
    [anon_sym_select] = ACTIONS(3943),
    [anon_sym_stackalloc] = ACTIONS(3943),
    [anon_sym_sizeof] = ACTIONS(3943),
    [anon_sym_typeof] = ACTIONS(3943),
    [anon_sym___makeref] = ACTIONS(3943),
    [anon_sym___reftype] = ACTIONS(3943),
    [anon_sym___refvalue] = ACTIONS(3943),
    [sym_null_literal] = ACTIONS(3943),
    [anon_sym_SQUOTE] = ACTIONS(3945),
    [sym_integer_literal] = ACTIONS(3943),
    [sym_real_literal] = ACTIONS(3945),
    [anon_sym_DQUOTE] = ACTIONS(3945),
    [sym_verbatim_string_literal] = ACTIONS(3945),
    [aux_sym_preproc_if_token1] = ACTIONS(3945),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3945),
    [sym_interpolation_verbatim_start] = ACTIONS(3945),
    [sym_interpolation_raw_start] = ACTIONS(3945),
    [sym_raw_string_start] = ACTIONS(3945),
  },
  [2541] = {
    [sym_preproc_region] = STATE(2541),
    [sym_preproc_endregion] = STATE(2541),
    [sym_preproc_line] = STATE(2541),
    [sym_preproc_pragma] = STATE(2541),
    [sym_preproc_nullable] = STATE(2541),
    [sym_preproc_error] = STATE(2541),
    [sym_preproc_warning] = STATE(2541),
    [sym_preproc_define] = STATE(2541),
    [sym_preproc_undef] = STATE(2541),
    [ts_builtin_sym_end] = ACTIONS(3783),
    [sym__identifier_token] = ACTIONS(3781),
    [anon_sym_extern] = ACTIONS(3781),
    [anon_sym_alias] = ACTIONS(3781),
    [anon_sym_SEMI] = ACTIONS(3783),
    [anon_sym_global] = ACTIONS(3781),
    [anon_sym_using] = ACTIONS(3781),
    [anon_sym_unsafe] = ACTIONS(3781),
    [anon_sym_static] = ACTIONS(3781),
    [anon_sym_LBRACK] = ACTIONS(3783),
    [anon_sym_LPAREN] = ACTIONS(3783),
    [anon_sym_return] = ACTIONS(3781),
    [anon_sym_namespace] = ACTIONS(3781),
    [anon_sym_class] = ACTIONS(3781),
    [anon_sym_ref] = ACTIONS(3781),
    [anon_sym_struct] = ACTIONS(3781),
    [anon_sym_enum] = ACTIONS(3781),
    [anon_sym_LBRACE] = ACTIONS(3783),
    [anon_sym_interface] = ACTIONS(3781),
    [anon_sym_delegate] = ACTIONS(3781),
    [anon_sym_record] = ACTIONS(3781),
    [anon_sym_abstract] = ACTIONS(3781),
    [anon_sym_async] = ACTIONS(3781),
    [anon_sym_const] = ACTIONS(3781),
    [anon_sym_file] = ACTIONS(3781),
    [anon_sym_fixed] = ACTIONS(3781),
    [anon_sym_internal] = ACTIONS(3781),
    [anon_sym_new] = ACTIONS(3781),
    [anon_sym_override] = ACTIONS(3781),
    [anon_sym_partial] = ACTIONS(3781),
    [anon_sym_private] = ACTIONS(3781),
    [anon_sym_protected] = ACTIONS(3781),
    [anon_sym_public] = ACTIONS(3781),
    [anon_sym_readonly] = ACTIONS(3781),
    [anon_sym_required] = ACTIONS(3781),
    [anon_sym_sealed] = ACTIONS(3781),
    [anon_sym_virtual] = ACTIONS(3781),
    [anon_sym_volatile] = ACTIONS(3781),
    [anon_sym_where] = ACTIONS(3781),
    [anon_sym_notnull] = ACTIONS(3781),
    [anon_sym_unmanaged] = ACTIONS(3781),
    [anon_sym_checked] = ACTIONS(3781),
    [anon_sym_BANG] = ACTIONS(3783),
    [anon_sym_TILDE] = ACTIONS(3783),
    [anon_sym_PLUS_PLUS] = ACTIONS(3783),
    [anon_sym_DASH_DASH] = ACTIONS(3783),
    [anon_sym_true] = ACTIONS(3781),
    [anon_sym_false] = ACTIONS(3781),
    [anon_sym_PLUS] = ACTIONS(3781),
    [anon_sym_DASH] = ACTIONS(3781),
    [anon_sym_STAR] = ACTIONS(3783),
    [anon_sym_CARET] = ACTIONS(3783),
    [anon_sym_AMP] = ACTIONS(3783),
    [anon_sym_this] = ACTIONS(3781),
    [anon_sym_scoped] = ACTIONS(3781),
    [anon_sym_base] = ACTIONS(3781),
    [anon_sym_var] = ACTIONS(3781),
    [sym_predefined_type] = ACTIONS(3781),
    [anon_sym_break] = ACTIONS(3781),
    [anon_sym_unchecked] = ACTIONS(3781),
    [anon_sym_continue] = ACTIONS(3781),
    [anon_sym_do] = ACTIONS(3781),
    [anon_sym_while] = ACTIONS(3781),
    [anon_sym_for] = ACTIONS(3781),
    [anon_sym_lock] = ACTIONS(3781),
    [anon_sym_yield] = ACTIONS(3781),
    [anon_sym_switch] = ACTIONS(3781),
    [anon_sym_default] = ACTIONS(3781),
    [anon_sym_throw] = ACTIONS(3781),
    [anon_sym_try] = ACTIONS(3781),
    [anon_sym_when] = ACTIONS(3781),
    [anon_sym_await] = ACTIONS(3781),
    [anon_sym_foreach] = ACTIONS(3781),
    [anon_sym_goto] = ACTIONS(3781),
    [anon_sym_if] = ACTIONS(3781),
    [anon_sym_DOT_DOT] = ACTIONS(3783),
    [anon_sym_from] = ACTIONS(3781),
    [anon_sym_into] = ACTIONS(3781),
    [anon_sym_join] = ACTIONS(3781),
    [anon_sym_on] = ACTIONS(3781),
    [anon_sym_equals] = ACTIONS(3781),
    [anon_sym_let] = ACTIONS(3781),
    [anon_sym_orderby] = ACTIONS(3781),
    [anon_sym_ascending] = ACTIONS(3781),
    [anon_sym_descending] = ACTIONS(3781),
    [anon_sym_group] = ACTIONS(3781),
    [anon_sym_by] = ACTIONS(3781),
    [anon_sym_select] = ACTIONS(3781),
    [anon_sym_stackalloc] = ACTIONS(3781),
    [anon_sym_sizeof] = ACTIONS(3781),
    [anon_sym_typeof] = ACTIONS(3781),
    [anon_sym___makeref] = ACTIONS(3781),
    [anon_sym___reftype] = ACTIONS(3781),
    [anon_sym___refvalue] = ACTIONS(3781),
    [sym_null_literal] = ACTIONS(3781),
    [anon_sym_SQUOTE] = ACTIONS(3783),
    [sym_integer_literal] = ACTIONS(3781),
    [sym_real_literal] = ACTIONS(3783),
    [anon_sym_DQUOTE] = ACTIONS(3783),
    [sym_verbatim_string_literal] = ACTIONS(3783),
    [aux_sym_preproc_if_token1] = ACTIONS(3783),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3783),
    [sym_interpolation_verbatim_start] = ACTIONS(3783),
    [sym_interpolation_raw_start] = ACTIONS(3783),
    [sym_raw_string_start] = ACTIONS(3783),
  },
  [2542] = {
    [sym_preproc_region] = STATE(2542),
    [sym_preproc_endregion] = STATE(2542),
    [sym_preproc_line] = STATE(2542),
    [sym_preproc_pragma] = STATE(2542),
    [sym_preproc_nullable] = STATE(2542),
    [sym_preproc_error] = STATE(2542),
    [sym_preproc_warning] = STATE(2542),
    [sym_preproc_define] = STATE(2542),
    [sym_preproc_undef] = STATE(2542),
    [ts_builtin_sym_end] = ACTIONS(3787),
    [sym__identifier_token] = ACTIONS(3785),
    [anon_sym_extern] = ACTIONS(3785),
    [anon_sym_alias] = ACTIONS(3785),
    [anon_sym_SEMI] = ACTIONS(3787),
    [anon_sym_global] = ACTIONS(3785),
    [anon_sym_using] = ACTIONS(3785),
    [anon_sym_unsafe] = ACTIONS(3785),
    [anon_sym_static] = ACTIONS(3785),
    [anon_sym_LBRACK] = ACTIONS(3787),
    [anon_sym_LPAREN] = ACTIONS(3787),
    [anon_sym_return] = ACTIONS(3785),
    [anon_sym_namespace] = ACTIONS(3785),
    [anon_sym_class] = ACTIONS(3785),
    [anon_sym_ref] = ACTIONS(3785),
    [anon_sym_struct] = ACTIONS(3785),
    [anon_sym_enum] = ACTIONS(3785),
    [anon_sym_LBRACE] = ACTIONS(3787),
    [anon_sym_interface] = ACTIONS(3785),
    [anon_sym_delegate] = ACTIONS(3785),
    [anon_sym_record] = ACTIONS(3785),
    [anon_sym_abstract] = ACTIONS(3785),
    [anon_sym_async] = ACTIONS(3785),
    [anon_sym_const] = ACTIONS(3785),
    [anon_sym_file] = ACTIONS(3785),
    [anon_sym_fixed] = ACTIONS(3785),
    [anon_sym_internal] = ACTIONS(3785),
    [anon_sym_new] = ACTIONS(3785),
    [anon_sym_override] = ACTIONS(3785),
    [anon_sym_partial] = ACTIONS(3785),
    [anon_sym_private] = ACTIONS(3785),
    [anon_sym_protected] = ACTIONS(3785),
    [anon_sym_public] = ACTIONS(3785),
    [anon_sym_readonly] = ACTIONS(3785),
    [anon_sym_required] = ACTIONS(3785),
    [anon_sym_sealed] = ACTIONS(3785),
    [anon_sym_virtual] = ACTIONS(3785),
    [anon_sym_volatile] = ACTIONS(3785),
    [anon_sym_where] = ACTIONS(3785),
    [anon_sym_notnull] = ACTIONS(3785),
    [anon_sym_unmanaged] = ACTIONS(3785),
    [anon_sym_checked] = ACTIONS(3785),
    [anon_sym_BANG] = ACTIONS(3787),
    [anon_sym_TILDE] = ACTIONS(3787),
    [anon_sym_PLUS_PLUS] = ACTIONS(3787),
    [anon_sym_DASH_DASH] = ACTIONS(3787),
    [anon_sym_true] = ACTIONS(3785),
    [anon_sym_false] = ACTIONS(3785),
    [anon_sym_PLUS] = ACTIONS(3785),
    [anon_sym_DASH] = ACTIONS(3785),
    [anon_sym_STAR] = ACTIONS(3787),
    [anon_sym_CARET] = ACTIONS(3787),
    [anon_sym_AMP] = ACTIONS(3787),
    [anon_sym_this] = ACTIONS(3785),
    [anon_sym_scoped] = ACTIONS(3785),
    [anon_sym_base] = ACTIONS(3785),
    [anon_sym_var] = ACTIONS(3785),
    [sym_predefined_type] = ACTIONS(3785),
    [anon_sym_break] = ACTIONS(3785),
    [anon_sym_unchecked] = ACTIONS(3785),
    [anon_sym_continue] = ACTIONS(3785),
    [anon_sym_do] = ACTIONS(3785),
    [anon_sym_while] = ACTIONS(3785),
    [anon_sym_for] = ACTIONS(3785),
    [anon_sym_lock] = ACTIONS(3785),
    [anon_sym_yield] = ACTIONS(3785),
    [anon_sym_switch] = ACTIONS(3785),
    [anon_sym_default] = ACTIONS(3785),
    [anon_sym_throw] = ACTIONS(3785),
    [anon_sym_try] = ACTIONS(3785),
    [anon_sym_when] = ACTIONS(3785),
    [anon_sym_await] = ACTIONS(3785),
    [anon_sym_foreach] = ACTIONS(3785),
    [anon_sym_goto] = ACTIONS(3785),
    [anon_sym_if] = ACTIONS(3785),
    [anon_sym_DOT_DOT] = ACTIONS(3787),
    [anon_sym_from] = ACTIONS(3785),
    [anon_sym_into] = ACTIONS(3785),
    [anon_sym_join] = ACTIONS(3785),
    [anon_sym_on] = ACTIONS(3785),
    [anon_sym_equals] = ACTIONS(3785),
    [anon_sym_let] = ACTIONS(3785),
    [anon_sym_orderby] = ACTIONS(3785),
    [anon_sym_ascending] = ACTIONS(3785),
    [anon_sym_descending] = ACTIONS(3785),
    [anon_sym_group] = ACTIONS(3785),
    [anon_sym_by] = ACTIONS(3785),
    [anon_sym_select] = ACTIONS(3785),
    [anon_sym_stackalloc] = ACTIONS(3785),
    [anon_sym_sizeof] = ACTIONS(3785),
    [anon_sym_typeof] = ACTIONS(3785),
    [anon_sym___makeref] = ACTIONS(3785),
    [anon_sym___reftype] = ACTIONS(3785),
    [anon_sym___refvalue] = ACTIONS(3785),
    [sym_null_literal] = ACTIONS(3785),
    [anon_sym_SQUOTE] = ACTIONS(3787),
    [sym_integer_literal] = ACTIONS(3785),
    [sym_real_literal] = ACTIONS(3787),
    [anon_sym_DQUOTE] = ACTIONS(3787),
    [sym_verbatim_string_literal] = ACTIONS(3787),
    [aux_sym_preproc_if_token1] = ACTIONS(3787),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3787),
    [sym_interpolation_verbatim_start] = ACTIONS(3787),
    [sym_interpolation_raw_start] = ACTIONS(3787),
    [sym_raw_string_start] = ACTIONS(3787),
  },
  [2543] = {
    [sym_preproc_region] = STATE(2543),
    [sym_preproc_endregion] = STATE(2543),
    [sym_preproc_line] = STATE(2543),
    [sym_preproc_pragma] = STATE(2543),
    [sym_preproc_nullable] = STATE(2543),
    [sym_preproc_error] = STATE(2543),
    [sym_preproc_warning] = STATE(2543),
    [sym_preproc_define] = STATE(2543),
    [sym_preproc_undef] = STATE(2543),
    [ts_builtin_sym_end] = ACTIONS(3791),
    [sym__identifier_token] = ACTIONS(3789),
    [anon_sym_extern] = ACTIONS(3789),
    [anon_sym_alias] = ACTIONS(3789),
    [anon_sym_SEMI] = ACTIONS(3791),
    [anon_sym_global] = ACTIONS(3789),
    [anon_sym_using] = ACTIONS(3789),
    [anon_sym_unsafe] = ACTIONS(3789),
    [anon_sym_static] = ACTIONS(3789),
    [anon_sym_LBRACK] = ACTIONS(3791),
    [anon_sym_LPAREN] = ACTIONS(3791),
    [anon_sym_return] = ACTIONS(3789),
    [anon_sym_namespace] = ACTIONS(3789),
    [anon_sym_class] = ACTIONS(3789),
    [anon_sym_ref] = ACTIONS(3789),
    [anon_sym_struct] = ACTIONS(3789),
    [anon_sym_enum] = ACTIONS(3789),
    [anon_sym_LBRACE] = ACTIONS(3791),
    [anon_sym_interface] = ACTIONS(3789),
    [anon_sym_delegate] = ACTIONS(3789),
    [anon_sym_record] = ACTIONS(3789),
    [anon_sym_abstract] = ACTIONS(3789),
    [anon_sym_async] = ACTIONS(3789),
    [anon_sym_const] = ACTIONS(3789),
    [anon_sym_file] = ACTIONS(3789),
    [anon_sym_fixed] = ACTIONS(3789),
    [anon_sym_internal] = ACTIONS(3789),
    [anon_sym_new] = ACTIONS(3789),
    [anon_sym_override] = ACTIONS(3789),
    [anon_sym_partial] = ACTIONS(3789),
    [anon_sym_private] = ACTIONS(3789),
    [anon_sym_protected] = ACTIONS(3789),
    [anon_sym_public] = ACTIONS(3789),
    [anon_sym_readonly] = ACTIONS(3789),
    [anon_sym_required] = ACTIONS(3789),
    [anon_sym_sealed] = ACTIONS(3789),
    [anon_sym_virtual] = ACTIONS(3789),
    [anon_sym_volatile] = ACTIONS(3789),
    [anon_sym_where] = ACTIONS(3789),
    [anon_sym_notnull] = ACTIONS(3789),
    [anon_sym_unmanaged] = ACTIONS(3789),
    [anon_sym_checked] = ACTIONS(3789),
    [anon_sym_BANG] = ACTIONS(3791),
    [anon_sym_TILDE] = ACTIONS(3791),
    [anon_sym_PLUS_PLUS] = ACTIONS(3791),
    [anon_sym_DASH_DASH] = ACTIONS(3791),
    [anon_sym_true] = ACTIONS(3789),
    [anon_sym_false] = ACTIONS(3789),
    [anon_sym_PLUS] = ACTIONS(3789),
    [anon_sym_DASH] = ACTIONS(3789),
    [anon_sym_STAR] = ACTIONS(3791),
    [anon_sym_CARET] = ACTIONS(3791),
    [anon_sym_AMP] = ACTIONS(3791),
    [anon_sym_this] = ACTIONS(3789),
    [anon_sym_scoped] = ACTIONS(3789),
    [anon_sym_base] = ACTIONS(3789),
    [anon_sym_var] = ACTIONS(3789),
    [sym_predefined_type] = ACTIONS(3789),
    [anon_sym_break] = ACTIONS(3789),
    [anon_sym_unchecked] = ACTIONS(3789),
    [anon_sym_continue] = ACTIONS(3789),
    [anon_sym_do] = ACTIONS(3789),
    [anon_sym_while] = ACTIONS(3789),
    [anon_sym_for] = ACTIONS(3789),
    [anon_sym_lock] = ACTIONS(3789),
    [anon_sym_yield] = ACTIONS(3789),
    [anon_sym_switch] = ACTIONS(3789),
    [anon_sym_default] = ACTIONS(3789),
    [anon_sym_throw] = ACTIONS(3789),
    [anon_sym_try] = ACTIONS(3789),
    [anon_sym_when] = ACTIONS(3789),
    [anon_sym_await] = ACTIONS(3789),
    [anon_sym_foreach] = ACTIONS(3789),
    [anon_sym_goto] = ACTIONS(3789),
    [anon_sym_if] = ACTIONS(3789),
    [anon_sym_DOT_DOT] = ACTIONS(3791),
    [anon_sym_from] = ACTIONS(3789),
    [anon_sym_into] = ACTIONS(3789),
    [anon_sym_join] = ACTIONS(3789),
    [anon_sym_on] = ACTIONS(3789),
    [anon_sym_equals] = ACTIONS(3789),
    [anon_sym_let] = ACTIONS(3789),
    [anon_sym_orderby] = ACTIONS(3789),
    [anon_sym_ascending] = ACTIONS(3789),
    [anon_sym_descending] = ACTIONS(3789),
    [anon_sym_group] = ACTIONS(3789),
    [anon_sym_by] = ACTIONS(3789),
    [anon_sym_select] = ACTIONS(3789),
    [anon_sym_stackalloc] = ACTIONS(3789),
    [anon_sym_sizeof] = ACTIONS(3789),
    [anon_sym_typeof] = ACTIONS(3789),
    [anon_sym___makeref] = ACTIONS(3789),
    [anon_sym___reftype] = ACTIONS(3789),
    [anon_sym___refvalue] = ACTIONS(3789),
    [sym_null_literal] = ACTIONS(3789),
    [anon_sym_SQUOTE] = ACTIONS(3791),
    [sym_integer_literal] = ACTIONS(3789),
    [sym_real_literal] = ACTIONS(3791),
    [anon_sym_DQUOTE] = ACTIONS(3791),
    [sym_verbatim_string_literal] = ACTIONS(3791),
    [aux_sym_preproc_if_token1] = ACTIONS(3791),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3791),
    [sym_interpolation_verbatim_start] = ACTIONS(3791),
    [sym_interpolation_raw_start] = ACTIONS(3791),
    [sym_raw_string_start] = ACTIONS(3791),
  },
  [2544] = {
    [sym_preproc_region] = STATE(2544),
    [sym_preproc_endregion] = STATE(2544),
    [sym_preproc_line] = STATE(2544),
    [sym_preproc_pragma] = STATE(2544),
    [sym_preproc_nullable] = STATE(2544),
    [sym_preproc_error] = STATE(2544),
    [sym_preproc_warning] = STATE(2544),
    [sym_preproc_define] = STATE(2544),
    [sym_preproc_undef] = STATE(2544),
    [ts_builtin_sym_end] = ACTIONS(3795),
    [sym__identifier_token] = ACTIONS(3793),
    [anon_sym_extern] = ACTIONS(3793),
    [anon_sym_alias] = ACTIONS(3793),
    [anon_sym_SEMI] = ACTIONS(3795),
    [anon_sym_global] = ACTIONS(3793),
    [anon_sym_using] = ACTIONS(3793),
    [anon_sym_unsafe] = ACTIONS(3793),
    [anon_sym_static] = ACTIONS(3793),
    [anon_sym_LBRACK] = ACTIONS(3795),
    [anon_sym_LPAREN] = ACTIONS(3795),
    [anon_sym_return] = ACTIONS(3793),
    [anon_sym_namespace] = ACTIONS(3793),
    [anon_sym_class] = ACTIONS(3793),
    [anon_sym_ref] = ACTIONS(3793),
    [anon_sym_struct] = ACTIONS(3793),
    [anon_sym_enum] = ACTIONS(3793),
    [anon_sym_LBRACE] = ACTIONS(3795),
    [anon_sym_interface] = ACTIONS(3793),
    [anon_sym_delegate] = ACTIONS(3793),
    [anon_sym_record] = ACTIONS(3793),
    [anon_sym_abstract] = ACTIONS(3793),
    [anon_sym_async] = ACTIONS(3793),
    [anon_sym_const] = ACTIONS(3793),
    [anon_sym_file] = ACTIONS(3793),
    [anon_sym_fixed] = ACTIONS(3793),
    [anon_sym_internal] = ACTIONS(3793),
    [anon_sym_new] = ACTIONS(3793),
    [anon_sym_override] = ACTIONS(3793),
    [anon_sym_partial] = ACTIONS(3793),
    [anon_sym_private] = ACTIONS(3793),
    [anon_sym_protected] = ACTIONS(3793),
    [anon_sym_public] = ACTIONS(3793),
    [anon_sym_readonly] = ACTIONS(3793),
    [anon_sym_required] = ACTIONS(3793),
    [anon_sym_sealed] = ACTIONS(3793),
    [anon_sym_virtual] = ACTIONS(3793),
    [anon_sym_volatile] = ACTIONS(3793),
    [anon_sym_where] = ACTIONS(3793),
    [anon_sym_notnull] = ACTIONS(3793),
    [anon_sym_unmanaged] = ACTIONS(3793),
    [anon_sym_checked] = ACTIONS(3793),
    [anon_sym_BANG] = ACTIONS(3795),
    [anon_sym_TILDE] = ACTIONS(3795),
    [anon_sym_PLUS_PLUS] = ACTIONS(3795),
    [anon_sym_DASH_DASH] = ACTIONS(3795),
    [anon_sym_true] = ACTIONS(3793),
    [anon_sym_false] = ACTIONS(3793),
    [anon_sym_PLUS] = ACTIONS(3793),
    [anon_sym_DASH] = ACTIONS(3793),
    [anon_sym_STAR] = ACTIONS(3795),
    [anon_sym_CARET] = ACTIONS(3795),
    [anon_sym_AMP] = ACTIONS(3795),
    [anon_sym_this] = ACTIONS(3793),
    [anon_sym_scoped] = ACTIONS(3793),
    [anon_sym_base] = ACTIONS(3793),
    [anon_sym_var] = ACTIONS(3793),
    [sym_predefined_type] = ACTIONS(3793),
    [anon_sym_break] = ACTIONS(3793),
    [anon_sym_unchecked] = ACTIONS(3793),
    [anon_sym_continue] = ACTIONS(3793),
    [anon_sym_do] = ACTIONS(3793),
    [anon_sym_while] = ACTIONS(3793),
    [anon_sym_for] = ACTIONS(3793),
    [anon_sym_lock] = ACTIONS(3793),
    [anon_sym_yield] = ACTIONS(3793),
    [anon_sym_switch] = ACTIONS(3793),
    [anon_sym_default] = ACTIONS(3793),
    [anon_sym_throw] = ACTIONS(3793),
    [anon_sym_try] = ACTIONS(3793),
    [anon_sym_when] = ACTIONS(3793),
    [anon_sym_await] = ACTIONS(3793),
    [anon_sym_foreach] = ACTIONS(3793),
    [anon_sym_goto] = ACTIONS(3793),
    [anon_sym_if] = ACTIONS(3793),
    [anon_sym_DOT_DOT] = ACTIONS(3795),
    [anon_sym_from] = ACTIONS(3793),
    [anon_sym_into] = ACTIONS(3793),
    [anon_sym_join] = ACTIONS(3793),
    [anon_sym_on] = ACTIONS(3793),
    [anon_sym_equals] = ACTIONS(3793),
    [anon_sym_let] = ACTIONS(3793),
    [anon_sym_orderby] = ACTIONS(3793),
    [anon_sym_ascending] = ACTIONS(3793),
    [anon_sym_descending] = ACTIONS(3793),
    [anon_sym_group] = ACTIONS(3793),
    [anon_sym_by] = ACTIONS(3793),
    [anon_sym_select] = ACTIONS(3793),
    [anon_sym_stackalloc] = ACTIONS(3793),
    [anon_sym_sizeof] = ACTIONS(3793),
    [anon_sym_typeof] = ACTIONS(3793),
    [anon_sym___makeref] = ACTIONS(3793),
    [anon_sym___reftype] = ACTIONS(3793),
    [anon_sym___refvalue] = ACTIONS(3793),
    [sym_null_literal] = ACTIONS(3793),
    [anon_sym_SQUOTE] = ACTIONS(3795),
    [sym_integer_literal] = ACTIONS(3793),
    [sym_real_literal] = ACTIONS(3795),
    [anon_sym_DQUOTE] = ACTIONS(3795),
    [sym_verbatim_string_literal] = ACTIONS(3795),
    [aux_sym_preproc_if_token1] = ACTIONS(3795),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3795),
    [sym_interpolation_verbatim_start] = ACTIONS(3795),
    [sym_interpolation_raw_start] = ACTIONS(3795),
    [sym_raw_string_start] = ACTIONS(3795),
  },
  [2545] = {
    [sym_preproc_region] = STATE(2545),
    [sym_preproc_endregion] = STATE(2545),
    [sym_preproc_line] = STATE(2545),
    [sym_preproc_pragma] = STATE(2545),
    [sym_preproc_nullable] = STATE(2545),
    [sym_preproc_error] = STATE(2545),
    [sym_preproc_warning] = STATE(2545),
    [sym_preproc_define] = STATE(2545),
    [sym_preproc_undef] = STATE(2545),
    [ts_builtin_sym_end] = ACTIONS(3799),
    [sym__identifier_token] = ACTIONS(3797),
    [anon_sym_extern] = ACTIONS(3797),
    [anon_sym_alias] = ACTIONS(3797),
    [anon_sym_SEMI] = ACTIONS(3799),
    [anon_sym_global] = ACTIONS(3797),
    [anon_sym_using] = ACTIONS(3797),
    [anon_sym_unsafe] = ACTIONS(3797),
    [anon_sym_static] = ACTIONS(3797),
    [anon_sym_LBRACK] = ACTIONS(3799),
    [anon_sym_LPAREN] = ACTIONS(3799),
    [anon_sym_return] = ACTIONS(3797),
    [anon_sym_namespace] = ACTIONS(3797),
    [anon_sym_class] = ACTIONS(3797),
    [anon_sym_ref] = ACTIONS(3797),
    [anon_sym_struct] = ACTIONS(3797),
    [anon_sym_enum] = ACTIONS(3797),
    [anon_sym_LBRACE] = ACTIONS(3799),
    [anon_sym_interface] = ACTIONS(3797),
    [anon_sym_delegate] = ACTIONS(3797),
    [anon_sym_record] = ACTIONS(3797),
    [anon_sym_abstract] = ACTIONS(3797),
    [anon_sym_async] = ACTIONS(3797),
    [anon_sym_const] = ACTIONS(3797),
    [anon_sym_file] = ACTIONS(3797),
    [anon_sym_fixed] = ACTIONS(3797),
    [anon_sym_internal] = ACTIONS(3797),
    [anon_sym_new] = ACTIONS(3797),
    [anon_sym_override] = ACTIONS(3797),
    [anon_sym_partial] = ACTIONS(3797),
    [anon_sym_private] = ACTIONS(3797),
    [anon_sym_protected] = ACTIONS(3797),
    [anon_sym_public] = ACTIONS(3797),
    [anon_sym_readonly] = ACTIONS(3797),
    [anon_sym_required] = ACTIONS(3797),
    [anon_sym_sealed] = ACTIONS(3797),
    [anon_sym_virtual] = ACTIONS(3797),
    [anon_sym_volatile] = ACTIONS(3797),
    [anon_sym_where] = ACTIONS(3797),
    [anon_sym_notnull] = ACTIONS(3797),
    [anon_sym_unmanaged] = ACTIONS(3797),
    [anon_sym_checked] = ACTIONS(3797),
    [anon_sym_BANG] = ACTIONS(3799),
    [anon_sym_TILDE] = ACTIONS(3799),
    [anon_sym_PLUS_PLUS] = ACTIONS(3799),
    [anon_sym_DASH_DASH] = ACTIONS(3799),
    [anon_sym_true] = ACTIONS(3797),
    [anon_sym_false] = ACTIONS(3797),
    [anon_sym_PLUS] = ACTIONS(3797),
    [anon_sym_DASH] = ACTIONS(3797),
    [anon_sym_STAR] = ACTIONS(3799),
    [anon_sym_CARET] = ACTIONS(3799),
    [anon_sym_AMP] = ACTIONS(3799),
    [anon_sym_this] = ACTIONS(3797),
    [anon_sym_scoped] = ACTIONS(3797),
    [anon_sym_base] = ACTIONS(3797),
    [anon_sym_var] = ACTIONS(3797),
    [sym_predefined_type] = ACTIONS(3797),
    [anon_sym_break] = ACTIONS(3797),
    [anon_sym_unchecked] = ACTIONS(3797),
    [anon_sym_continue] = ACTIONS(3797),
    [anon_sym_do] = ACTIONS(3797),
    [anon_sym_while] = ACTIONS(3797),
    [anon_sym_for] = ACTIONS(3797),
    [anon_sym_lock] = ACTIONS(3797),
    [anon_sym_yield] = ACTIONS(3797),
    [anon_sym_switch] = ACTIONS(3797),
    [anon_sym_default] = ACTIONS(3797),
    [anon_sym_throw] = ACTIONS(3797),
    [anon_sym_try] = ACTIONS(3797),
    [anon_sym_when] = ACTIONS(3797),
    [anon_sym_await] = ACTIONS(3797),
    [anon_sym_foreach] = ACTIONS(3797),
    [anon_sym_goto] = ACTIONS(3797),
    [anon_sym_if] = ACTIONS(3797),
    [anon_sym_DOT_DOT] = ACTIONS(3799),
    [anon_sym_from] = ACTIONS(3797),
    [anon_sym_into] = ACTIONS(3797),
    [anon_sym_join] = ACTIONS(3797),
    [anon_sym_on] = ACTIONS(3797),
    [anon_sym_equals] = ACTIONS(3797),
    [anon_sym_let] = ACTIONS(3797),
    [anon_sym_orderby] = ACTIONS(3797),
    [anon_sym_ascending] = ACTIONS(3797),
    [anon_sym_descending] = ACTIONS(3797),
    [anon_sym_group] = ACTIONS(3797),
    [anon_sym_by] = ACTIONS(3797),
    [anon_sym_select] = ACTIONS(3797),
    [anon_sym_stackalloc] = ACTIONS(3797),
    [anon_sym_sizeof] = ACTIONS(3797),
    [anon_sym_typeof] = ACTIONS(3797),
    [anon_sym___makeref] = ACTIONS(3797),
    [anon_sym___reftype] = ACTIONS(3797),
    [anon_sym___refvalue] = ACTIONS(3797),
    [sym_null_literal] = ACTIONS(3797),
    [anon_sym_SQUOTE] = ACTIONS(3799),
    [sym_integer_literal] = ACTIONS(3797),
    [sym_real_literal] = ACTIONS(3799),
    [anon_sym_DQUOTE] = ACTIONS(3799),
    [sym_verbatim_string_literal] = ACTIONS(3799),
    [aux_sym_preproc_if_token1] = ACTIONS(3799),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3799),
    [sym_interpolation_verbatim_start] = ACTIONS(3799),
    [sym_interpolation_raw_start] = ACTIONS(3799),
    [sym_raw_string_start] = ACTIONS(3799),
  },
  [2546] = {
    [sym_preproc_region] = STATE(2546),
    [sym_preproc_endregion] = STATE(2546),
    [sym_preproc_line] = STATE(2546),
    [sym_preproc_pragma] = STATE(2546),
    [sym_preproc_nullable] = STATE(2546),
    [sym_preproc_error] = STATE(2546),
    [sym_preproc_warning] = STATE(2546),
    [sym_preproc_define] = STATE(2546),
    [sym_preproc_undef] = STATE(2546),
    [ts_builtin_sym_end] = ACTIONS(3803),
    [sym__identifier_token] = ACTIONS(3801),
    [anon_sym_extern] = ACTIONS(3801),
    [anon_sym_alias] = ACTIONS(3801),
    [anon_sym_SEMI] = ACTIONS(3803),
    [anon_sym_global] = ACTIONS(3801),
    [anon_sym_using] = ACTIONS(3801),
    [anon_sym_unsafe] = ACTIONS(3801),
    [anon_sym_static] = ACTIONS(3801),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [anon_sym_LPAREN] = ACTIONS(3803),
    [anon_sym_return] = ACTIONS(3801),
    [anon_sym_namespace] = ACTIONS(3801),
    [anon_sym_class] = ACTIONS(3801),
    [anon_sym_ref] = ACTIONS(3801),
    [anon_sym_struct] = ACTIONS(3801),
    [anon_sym_enum] = ACTIONS(3801),
    [anon_sym_LBRACE] = ACTIONS(3803),
    [anon_sym_interface] = ACTIONS(3801),
    [anon_sym_delegate] = ACTIONS(3801),
    [anon_sym_record] = ACTIONS(3801),
    [anon_sym_abstract] = ACTIONS(3801),
    [anon_sym_async] = ACTIONS(3801),
    [anon_sym_const] = ACTIONS(3801),
    [anon_sym_file] = ACTIONS(3801),
    [anon_sym_fixed] = ACTIONS(3801),
    [anon_sym_internal] = ACTIONS(3801),
    [anon_sym_new] = ACTIONS(3801),
    [anon_sym_override] = ACTIONS(3801),
    [anon_sym_partial] = ACTIONS(3801),
    [anon_sym_private] = ACTIONS(3801),
    [anon_sym_protected] = ACTIONS(3801),
    [anon_sym_public] = ACTIONS(3801),
    [anon_sym_readonly] = ACTIONS(3801),
    [anon_sym_required] = ACTIONS(3801),
    [anon_sym_sealed] = ACTIONS(3801),
    [anon_sym_virtual] = ACTIONS(3801),
    [anon_sym_volatile] = ACTIONS(3801),
    [anon_sym_where] = ACTIONS(3801),
    [anon_sym_notnull] = ACTIONS(3801),
    [anon_sym_unmanaged] = ACTIONS(3801),
    [anon_sym_checked] = ACTIONS(3801),
    [anon_sym_BANG] = ACTIONS(3803),
    [anon_sym_TILDE] = ACTIONS(3803),
    [anon_sym_PLUS_PLUS] = ACTIONS(3803),
    [anon_sym_DASH_DASH] = ACTIONS(3803),
    [anon_sym_true] = ACTIONS(3801),
    [anon_sym_false] = ACTIONS(3801),
    [anon_sym_PLUS] = ACTIONS(3801),
    [anon_sym_DASH] = ACTIONS(3801),
    [anon_sym_STAR] = ACTIONS(3803),
    [anon_sym_CARET] = ACTIONS(3803),
    [anon_sym_AMP] = ACTIONS(3803),
    [anon_sym_this] = ACTIONS(3801),
    [anon_sym_scoped] = ACTIONS(3801),
    [anon_sym_base] = ACTIONS(3801),
    [anon_sym_var] = ACTIONS(3801),
    [sym_predefined_type] = ACTIONS(3801),
    [anon_sym_break] = ACTIONS(3801),
    [anon_sym_unchecked] = ACTIONS(3801),
    [anon_sym_continue] = ACTIONS(3801),
    [anon_sym_do] = ACTIONS(3801),
    [anon_sym_while] = ACTIONS(3801),
    [anon_sym_for] = ACTIONS(3801),
    [anon_sym_lock] = ACTIONS(3801),
    [anon_sym_yield] = ACTIONS(3801),
    [anon_sym_switch] = ACTIONS(3801),
    [anon_sym_default] = ACTIONS(3801),
    [anon_sym_throw] = ACTIONS(3801),
    [anon_sym_try] = ACTIONS(3801),
    [anon_sym_when] = ACTIONS(3801),
    [anon_sym_await] = ACTIONS(3801),
    [anon_sym_foreach] = ACTIONS(3801),
    [anon_sym_goto] = ACTIONS(3801),
    [anon_sym_if] = ACTIONS(3801),
    [anon_sym_DOT_DOT] = ACTIONS(3803),
    [anon_sym_from] = ACTIONS(3801),
    [anon_sym_into] = ACTIONS(3801),
    [anon_sym_join] = ACTIONS(3801),
    [anon_sym_on] = ACTIONS(3801),
    [anon_sym_equals] = ACTIONS(3801),
    [anon_sym_let] = ACTIONS(3801),
    [anon_sym_orderby] = ACTIONS(3801),
    [anon_sym_ascending] = ACTIONS(3801),
    [anon_sym_descending] = ACTIONS(3801),
    [anon_sym_group] = ACTIONS(3801),
    [anon_sym_by] = ACTIONS(3801),
    [anon_sym_select] = ACTIONS(3801),
    [anon_sym_stackalloc] = ACTIONS(3801),
    [anon_sym_sizeof] = ACTIONS(3801),
    [anon_sym_typeof] = ACTIONS(3801),
    [anon_sym___makeref] = ACTIONS(3801),
    [anon_sym___reftype] = ACTIONS(3801),
    [anon_sym___refvalue] = ACTIONS(3801),
    [sym_null_literal] = ACTIONS(3801),
    [anon_sym_SQUOTE] = ACTIONS(3803),
    [sym_integer_literal] = ACTIONS(3801),
    [sym_real_literal] = ACTIONS(3803),
    [anon_sym_DQUOTE] = ACTIONS(3803),
    [sym_verbatim_string_literal] = ACTIONS(3803),
    [aux_sym_preproc_if_token1] = ACTIONS(3803),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3803),
    [sym_interpolation_verbatim_start] = ACTIONS(3803),
    [sym_interpolation_raw_start] = ACTIONS(3803),
    [sym_raw_string_start] = ACTIONS(3803),
  },
  [2547] = {
    [sym_preproc_region] = STATE(2547),
    [sym_preproc_endregion] = STATE(2547),
    [sym_preproc_line] = STATE(2547),
    [sym_preproc_pragma] = STATE(2547),
    [sym_preproc_nullable] = STATE(2547),
    [sym_preproc_error] = STATE(2547),
    [sym_preproc_warning] = STATE(2547),
    [sym_preproc_define] = STATE(2547),
    [sym_preproc_undef] = STATE(2547),
    [ts_builtin_sym_end] = ACTIONS(3807),
    [sym__identifier_token] = ACTIONS(3805),
    [anon_sym_extern] = ACTIONS(3805),
    [anon_sym_alias] = ACTIONS(3805),
    [anon_sym_SEMI] = ACTIONS(3807),
    [anon_sym_global] = ACTIONS(3805),
    [anon_sym_using] = ACTIONS(3805),
    [anon_sym_unsafe] = ACTIONS(3805),
    [anon_sym_static] = ACTIONS(3805),
    [anon_sym_LBRACK] = ACTIONS(3807),
    [anon_sym_LPAREN] = ACTIONS(3807),
    [anon_sym_return] = ACTIONS(3805),
    [anon_sym_namespace] = ACTIONS(3805),
    [anon_sym_class] = ACTIONS(3805),
    [anon_sym_ref] = ACTIONS(3805),
    [anon_sym_struct] = ACTIONS(3805),
    [anon_sym_enum] = ACTIONS(3805),
    [anon_sym_LBRACE] = ACTIONS(3807),
    [anon_sym_interface] = ACTIONS(3805),
    [anon_sym_delegate] = ACTIONS(3805),
    [anon_sym_record] = ACTIONS(3805),
    [anon_sym_abstract] = ACTIONS(3805),
    [anon_sym_async] = ACTIONS(3805),
    [anon_sym_const] = ACTIONS(3805),
    [anon_sym_file] = ACTIONS(3805),
    [anon_sym_fixed] = ACTIONS(3805),
    [anon_sym_internal] = ACTIONS(3805),
    [anon_sym_new] = ACTIONS(3805),
    [anon_sym_override] = ACTIONS(3805),
    [anon_sym_partial] = ACTIONS(3805),
    [anon_sym_private] = ACTIONS(3805),
    [anon_sym_protected] = ACTIONS(3805),
    [anon_sym_public] = ACTIONS(3805),
    [anon_sym_readonly] = ACTIONS(3805),
    [anon_sym_required] = ACTIONS(3805),
    [anon_sym_sealed] = ACTIONS(3805),
    [anon_sym_virtual] = ACTIONS(3805),
    [anon_sym_volatile] = ACTIONS(3805),
    [anon_sym_where] = ACTIONS(3805),
    [anon_sym_notnull] = ACTIONS(3805),
    [anon_sym_unmanaged] = ACTIONS(3805),
    [anon_sym_checked] = ACTIONS(3805),
    [anon_sym_BANG] = ACTIONS(3807),
    [anon_sym_TILDE] = ACTIONS(3807),
    [anon_sym_PLUS_PLUS] = ACTIONS(3807),
    [anon_sym_DASH_DASH] = ACTIONS(3807),
    [anon_sym_true] = ACTIONS(3805),
    [anon_sym_false] = ACTIONS(3805),
    [anon_sym_PLUS] = ACTIONS(3805),
    [anon_sym_DASH] = ACTIONS(3805),
    [anon_sym_STAR] = ACTIONS(3807),
    [anon_sym_CARET] = ACTIONS(3807),
    [anon_sym_AMP] = ACTIONS(3807),
    [anon_sym_this] = ACTIONS(3805),
    [anon_sym_scoped] = ACTIONS(3805),
    [anon_sym_base] = ACTIONS(3805),
    [anon_sym_var] = ACTIONS(3805),
    [sym_predefined_type] = ACTIONS(3805),
    [anon_sym_break] = ACTIONS(3805),
    [anon_sym_unchecked] = ACTIONS(3805),
    [anon_sym_continue] = ACTIONS(3805),
    [anon_sym_do] = ACTIONS(3805),
    [anon_sym_while] = ACTIONS(3805),
    [anon_sym_for] = ACTIONS(3805),
    [anon_sym_lock] = ACTIONS(3805),
    [anon_sym_yield] = ACTIONS(3805),
    [anon_sym_switch] = ACTIONS(3805),
    [anon_sym_default] = ACTIONS(3805),
    [anon_sym_throw] = ACTIONS(3805),
    [anon_sym_try] = ACTIONS(3805),
    [anon_sym_when] = ACTIONS(3805),
    [anon_sym_await] = ACTIONS(3805),
    [anon_sym_foreach] = ACTIONS(3805),
    [anon_sym_goto] = ACTIONS(3805),
    [anon_sym_if] = ACTIONS(3805),
    [anon_sym_DOT_DOT] = ACTIONS(3807),
    [anon_sym_from] = ACTIONS(3805),
    [anon_sym_into] = ACTIONS(3805),
    [anon_sym_join] = ACTIONS(3805),
    [anon_sym_on] = ACTIONS(3805),
    [anon_sym_equals] = ACTIONS(3805),
    [anon_sym_let] = ACTIONS(3805),
    [anon_sym_orderby] = ACTIONS(3805),
    [anon_sym_ascending] = ACTIONS(3805),
    [anon_sym_descending] = ACTIONS(3805),
    [anon_sym_group] = ACTIONS(3805),
    [anon_sym_by] = ACTIONS(3805),
    [anon_sym_select] = ACTIONS(3805),
    [anon_sym_stackalloc] = ACTIONS(3805),
    [anon_sym_sizeof] = ACTIONS(3805),
    [anon_sym_typeof] = ACTIONS(3805),
    [anon_sym___makeref] = ACTIONS(3805),
    [anon_sym___reftype] = ACTIONS(3805),
    [anon_sym___refvalue] = ACTIONS(3805),
    [sym_null_literal] = ACTIONS(3805),
    [anon_sym_SQUOTE] = ACTIONS(3807),
    [sym_integer_literal] = ACTIONS(3805),
    [sym_real_literal] = ACTIONS(3807),
    [anon_sym_DQUOTE] = ACTIONS(3807),
    [sym_verbatim_string_literal] = ACTIONS(3807),
    [aux_sym_preproc_if_token1] = ACTIONS(3807),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3807),
    [sym_interpolation_verbatim_start] = ACTIONS(3807),
    [sym_interpolation_raw_start] = ACTIONS(3807),
    [sym_raw_string_start] = ACTIONS(3807),
  },
  [2548] = {
    [sym_preproc_region] = STATE(2548),
    [sym_preproc_endregion] = STATE(2548),
    [sym_preproc_line] = STATE(2548),
    [sym_preproc_pragma] = STATE(2548),
    [sym_preproc_nullable] = STATE(2548),
    [sym_preproc_error] = STATE(2548),
    [sym_preproc_warning] = STATE(2548),
    [sym_preproc_define] = STATE(2548),
    [sym_preproc_undef] = STATE(2548),
    [ts_builtin_sym_end] = ACTIONS(3811),
    [sym__identifier_token] = ACTIONS(3809),
    [anon_sym_extern] = ACTIONS(3809),
    [anon_sym_alias] = ACTIONS(3809),
    [anon_sym_SEMI] = ACTIONS(3811),
    [anon_sym_global] = ACTIONS(3809),
    [anon_sym_using] = ACTIONS(3809),
    [anon_sym_unsafe] = ACTIONS(3809),
    [anon_sym_static] = ACTIONS(3809),
    [anon_sym_LBRACK] = ACTIONS(3811),
    [anon_sym_LPAREN] = ACTIONS(3811),
    [anon_sym_return] = ACTIONS(3809),
    [anon_sym_namespace] = ACTIONS(3809),
    [anon_sym_class] = ACTIONS(3809),
    [anon_sym_ref] = ACTIONS(3809),
    [anon_sym_struct] = ACTIONS(3809),
    [anon_sym_enum] = ACTIONS(3809),
    [anon_sym_LBRACE] = ACTIONS(3811),
    [anon_sym_interface] = ACTIONS(3809),
    [anon_sym_delegate] = ACTIONS(3809),
    [anon_sym_record] = ACTIONS(3809),
    [anon_sym_abstract] = ACTIONS(3809),
    [anon_sym_async] = ACTIONS(3809),
    [anon_sym_const] = ACTIONS(3809),
    [anon_sym_file] = ACTIONS(3809),
    [anon_sym_fixed] = ACTIONS(3809),
    [anon_sym_internal] = ACTIONS(3809),
    [anon_sym_new] = ACTIONS(3809),
    [anon_sym_override] = ACTIONS(3809),
    [anon_sym_partial] = ACTIONS(3809),
    [anon_sym_private] = ACTIONS(3809),
    [anon_sym_protected] = ACTIONS(3809),
    [anon_sym_public] = ACTIONS(3809),
    [anon_sym_readonly] = ACTIONS(3809),
    [anon_sym_required] = ACTIONS(3809),
    [anon_sym_sealed] = ACTIONS(3809),
    [anon_sym_virtual] = ACTIONS(3809),
    [anon_sym_volatile] = ACTIONS(3809),
    [anon_sym_where] = ACTIONS(3809),
    [anon_sym_notnull] = ACTIONS(3809),
    [anon_sym_unmanaged] = ACTIONS(3809),
    [anon_sym_checked] = ACTIONS(3809),
    [anon_sym_BANG] = ACTIONS(3811),
    [anon_sym_TILDE] = ACTIONS(3811),
    [anon_sym_PLUS_PLUS] = ACTIONS(3811),
    [anon_sym_DASH_DASH] = ACTIONS(3811),
    [anon_sym_true] = ACTIONS(3809),
    [anon_sym_false] = ACTIONS(3809),
    [anon_sym_PLUS] = ACTIONS(3809),
    [anon_sym_DASH] = ACTIONS(3809),
    [anon_sym_STAR] = ACTIONS(3811),
    [anon_sym_CARET] = ACTIONS(3811),
    [anon_sym_AMP] = ACTIONS(3811),
    [anon_sym_this] = ACTIONS(3809),
    [anon_sym_scoped] = ACTIONS(3809),
    [anon_sym_base] = ACTIONS(3809),
    [anon_sym_var] = ACTIONS(3809),
    [sym_predefined_type] = ACTIONS(3809),
    [anon_sym_break] = ACTIONS(3809),
    [anon_sym_unchecked] = ACTIONS(3809),
    [anon_sym_continue] = ACTIONS(3809),
    [anon_sym_do] = ACTIONS(3809),
    [anon_sym_while] = ACTIONS(3809),
    [anon_sym_for] = ACTIONS(3809),
    [anon_sym_lock] = ACTIONS(3809),
    [anon_sym_yield] = ACTIONS(3809),
    [anon_sym_switch] = ACTIONS(3809),
    [anon_sym_default] = ACTIONS(3809),
    [anon_sym_throw] = ACTIONS(3809),
    [anon_sym_try] = ACTIONS(3809),
    [anon_sym_when] = ACTIONS(3809),
    [anon_sym_await] = ACTIONS(3809),
    [anon_sym_foreach] = ACTIONS(3809),
    [anon_sym_goto] = ACTIONS(3809),
    [anon_sym_if] = ACTIONS(3809),
    [anon_sym_DOT_DOT] = ACTIONS(3811),
    [anon_sym_from] = ACTIONS(3809),
    [anon_sym_into] = ACTIONS(3809),
    [anon_sym_join] = ACTIONS(3809),
    [anon_sym_on] = ACTIONS(3809),
    [anon_sym_equals] = ACTIONS(3809),
    [anon_sym_let] = ACTIONS(3809),
    [anon_sym_orderby] = ACTIONS(3809),
    [anon_sym_ascending] = ACTIONS(3809),
    [anon_sym_descending] = ACTIONS(3809),
    [anon_sym_group] = ACTIONS(3809),
    [anon_sym_by] = ACTIONS(3809),
    [anon_sym_select] = ACTIONS(3809),
    [anon_sym_stackalloc] = ACTIONS(3809),
    [anon_sym_sizeof] = ACTIONS(3809),
    [anon_sym_typeof] = ACTIONS(3809),
    [anon_sym___makeref] = ACTIONS(3809),
    [anon_sym___reftype] = ACTIONS(3809),
    [anon_sym___refvalue] = ACTIONS(3809),
    [sym_null_literal] = ACTIONS(3809),
    [anon_sym_SQUOTE] = ACTIONS(3811),
    [sym_integer_literal] = ACTIONS(3809),
    [sym_real_literal] = ACTIONS(3811),
    [anon_sym_DQUOTE] = ACTIONS(3811),
    [sym_verbatim_string_literal] = ACTIONS(3811),
    [aux_sym_preproc_if_token1] = ACTIONS(3811),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3811),
    [sym_interpolation_verbatim_start] = ACTIONS(3811),
    [sym_interpolation_raw_start] = ACTIONS(3811),
    [sym_raw_string_start] = ACTIONS(3811),
  },
  [2549] = {
    [sym_preproc_region] = STATE(2549),
    [sym_preproc_endregion] = STATE(2549),
    [sym_preproc_line] = STATE(2549),
    [sym_preproc_pragma] = STATE(2549),
    [sym_preproc_nullable] = STATE(2549),
    [sym_preproc_error] = STATE(2549),
    [sym_preproc_warning] = STATE(2549),
    [sym_preproc_define] = STATE(2549),
    [sym_preproc_undef] = STATE(2549),
    [ts_builtin_sym_end] = ACTIONS(3815),
    [sym__identifier_token] = ACTIONS(3813),
    [anon_sym_extern] = ACTIONS(3813),
    [anon_sym_alias] = ACTIONS(3813),
    [anon_sym_SEMI] = ACTIONS(3815),
    [anon_sym_global] = ACTIONS(3813),
    [anon_sym_using] = ACTIONS(3813),
    [anon_sym_unsafe] = ACTIONS(3813),
    [anon_sym_static] = ACTIONS(3813),
    [anon_sym_LBRACK] = ACTIONS(3815),
    [anon_sym_LPAREN] = ACTIONS(3815),
    [anon_sym_return] = ACTIONS(3813),
    [anon_sym_namespace] = ACTIONS(3813),
    [anon_sym_class] = ACTIONS(3813),
    [anon_sym_ref] = ACTIONS(3813),
    [anon_sym_struct] = ACTIONS(3813),
    [anon_sym_enum] = ACTIONS(3813),
    [anon_sym_LBRACE] = ACTIONS(3815),
    [anon_sym_interface] = ACTIONS(3813),
    [anon_sym_delegate] = ACTIONS(3813),
    [anon_sym_record] = ACTIONS(3813),
    [anon_sym_abstract] = ACTIONS(3813),
    [anon_sym_async] = ACTIONS(3813),
    [anon_sym_const] = ACTIONS(3813),
    [anon_sym_file] = ACTIONS(3813),
    [anon_sym_fixed] = ACTIONS(3813),
    [anon_sym_internal] = ACTIONS(3813),
    [anon_sym_new] = ACTIONS(3813),
    [anon_sym_override] = ACTIONS(3813),
    [anon_sym_partial] = ACTIONS(3813),
    [anon_sym_private] = ACTIONS(3813),
    [anon_sym_protected] = ACTIONS(3813),
    [anon_sym_public] = ACTIONS(3813),
    [anon_sym_readonly] = ACTIONS(3813),
    [anon_sym_required] = ACTIONS(3813),
    [anon_sym_sealed] = ACTIONS(3813),
    [anon_sym_virtual] = ACTIONS(3813),
    [anon_sym_volatile] = ACTIONS(3813),
    [anon_sym_where] = ACTIONS(3813),
    [anon_sym_notnull] = ACTIONS(3813),
    [anon_sym_unmanaged] = ACTIONS(3813),
    [anon_sym_checked] = ACTIONS(3813),
    [anon_sym_BANG] = ACTIONS(3815),
    [anon_sym_TILDE] = ACTIONS(3815),
    [anon_sym_PLUS_PLUS] = ACTIONS(3815),
    [anon_sym_DASH_DASH] = ACTIONS(3815),
    [anon_sym_true] = ACTIONS(3813),
    [anon_sym_false] = ACTIONS(3813),
    [anon_sym_PLUS] = ACTIONS(3813),
    [anon_sym_DASH] = ACTIONS(3813),
    [anon_sym_STAR] = ACTIONS(3815),
    [anon_sym_CARET] = ACTIONS(3815),
    [anon_sym_AMP] = ACTIONS(3815),
    [anon_sym_this] = ACTIONS(3813),
    [anon_sym_scoped] = ACTIONS(3813),
    [anon_sym_base] = ACTIONS(3813),
    [anon_sym_var] = ACTIONS(3813),
    [sym_predefined_type] = ACTIONS(3813),
    [anon_sym_break] = ACTIONS(3813),
    [anon_sym_unchecked] = ACTIONS(3813),
    [anon_sym_continue] = ACTIONS(3813),
    [anon_sym_do] = ACTIONS(3813),
    [anon_sym_while] = ACTIONS(3813),
    [anon_sym_for] = ACTIONS(3813),
    [anon_sym_lock] = ACTIONS(3813),
    [anon_sym_yield] = ACTIONS(3813),
    [anon_sym_switch] = ACTIONS(3813),
    [anon_sym_default] = ACTIONS(3813),
    [anon_sym_throw] = ACTIONS(3813),
    [anon_sym_try] = ACTIONS(3813),
    [anon_sym_when] = ACTIONS(3813),
    [anon_sym_await] = ACTIONS(3813),
    [anon_sym_foreach] = ACTIONS(3813),
    [anon_sym_goto] = ACTIONS(3813),
    [anon_sym_if] = ACTIONS(3813),
    [anon_sym_DOT_DOT] = ACTIONS(3815),
    [anon_sym_from] = ACTIONS(3813),
    [anon_sym_into] = ACTIONS(3813),
    [anon_sym_join] = ACTIONS(3813),
    [anon_sym_on] = ACTIONS(3813),
    [anon_sym_equals] = ACTIONS(3813),
    [anon_sym_let] = ACTIONS(3813),
    [anon_sym_orderby] = ACTIONS(3813),
    [anon_sym_ascending] = ACTIONS(3813),
    [anon_sym_descending] = ACTIONS(3813),
    [anon_sym_group] = ACTIONS(3813),
    [anon_sym_by] = ACTIONS(3813),
    [anon_sym_select] = ACTIONS(3813),
    [anon_sym_stackalloc] = ACTIONS(3813),
    [anon_sym_sizeof] = ACTIONS(3813),
    [anon_sym_typeof] = ACTIONS(3813),
    [anon_sym___makeref] = ACTIONS(3813),
    [anon_sym___reftype] = ACTIONS(3813),
    [anon_sym___refvalue] = ACTIONS(3813),
    [sym_null_literal] = ACTIONS(3813),
    [anon_sym_SQUOTE] = ACTIONS(3815),
    [sym_integer_literal] = ACTIONS(3813),
    [sym_real_literal] = ACTIONS(3815),
    [anon_sym_DQUOTE] = ACTIONS(3815),
    [sym_verbatim_string_literal] = ACTIONS(3815),
    [aux_sym_preproc_if_token1] = ACTIONS(3815),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3815),
    [sym_interpolation_verbatim_start] = ACTIONS(3815),
    [sym_interpolation_raw_start] = ACTIONS(3815),
    [sym_raw_string_start] = ACTIONS(3815),
  },
  [2550] = {
    [sym_preproc_region] = STATE(2550),
    [sym_preproc_endregion] = STATE(2550),
    [sym_preproc_line] = STATE(2550),
    [sym_preproc_pragma] = STATE(2550),
    [sym_preproc_nullable] = STATE(2550),
    [sym_preproc_error] = STATE(2550),
    [sym_preproc_warning] = STATE(2550),
    [sym_preproc_define] = STATE(2550),
    [sym_preproc_undef] = STATE(2550),
    [ts_builtin_sym_end] = ACTIONS(3819),
    [sym__identifier_token] = ACTIONS(3817),
    [anon_sym_extern] = ACTIONS(3817),
    [anon_sym_alias] = ACTIONS(3817),
    [anon_sym_SEMI] = ACTIONS(3819),
    [anon_sym_global] = ACTIONS(3817),
    [anon_sym_using] = ACTIONS(3817),
    [anon_sym_unsafe] = ACTIONS(3817),
    [anon_sym_static] = ACTIONS(3817),
    [anon_sym_LBRACK] = ACTIONS(3819),
    [anon_sym_LPAREN] = ACTIONS(3819),
    [anon_sym_return] = ACTIONS(3817),
    [anon_sym_namespace] = ACTIONS(3817),
    [anon_sym_class] = ACTIONS(3817),
    [anon_sym_ref] = ACTIONS(3817),
    [anon_sym_struct] = ACTIONS(3817),
    [anon_sym_enum] = ACTIONS(3817),
    [anon_sym_LBRACE] = ACTIONS(3819),
    [anon_sym_interface] = ACTIONS(3817),
    [anon_sym_delegate] = ACTIONS(3817),
    [anon_sym_record] = ACTIONS(3817),
    [anon_sym_abstract] = ACTIONS(3817),
    [anon_sym_async] = ACTIONS(3817),
    [anon_sym_const] = ACTIONS(3817),
    [anon_sym_file] = ACTIONS(3817),
    [anon_sym_fixed] = ACTIONS(3817),
    [anon_sym_internal] = ACTIONS(3817),
    [anon_sym_new] = ACTIONS(3817),
    [anon_sym_override] = ACTIONS(3817),
    [anon_sym_partial] = ACTIONS(3817),
    [anon_sym_private] = ACTIONS(3817),
    [anon_sym_protected] = ACTIONS(3817),
    [anon_sym_public] = ACTIONS(3817),
    [anon_sym_readonly] = ACTIONS(3817),
    [anon_sym_required] = ACTIONS(3817),
    [anon_sym_sealed] = ACTIONS(3817),
    [anon_sym_virtual] = ACTIONS(3817),
    [anon_sym_volatile] = ACTIONS(3817),
    [anon_sym_where] = ACTIONS(3817),
    [anon_sym_notnull] = ACTIONS(3817),
    [anon_sym_unmanaged] = ACTIONS(3817),
    [anon_sym_checked] = ACTIONS(3817),
    [anon_sym_BANG] = ACTIONS(3819),
    [anon_sym_TILDE] = ACTIONS(3819),
    [anon_sym_PLUS_PLUS] = ACTIONS(3819),
    [anon_sym_DASH_DASH] = ACTIONS(3819),
    [anon_sym_true] = ACTIONS(3817),
    [anon_sym_false] = ACTIONS(3817),
    [anon_sym_PLUS] = ACTIONS(3817),
    [anon_sym_DASH] = ACTIONS(3817),
    [anon_sym_STAR] = ACTIONS(3819),
    [anon_sym_CARET] = ACTIONS(3819),
    [anon_sym_AMP] = ACTIONS(3819),
    [anon_sym_this] = ACTIONS(3817),
    [anon_sym_scoped] = ACTIONS(3817),
    [anon_sym_base] = ACTIONS(3817),
    [anon_sym_var] = ACTIONS(3817),
    [sym_predefined_type] = ACTIONS(3817),
    [anon_sym_break] = ACTIONS(3817),
    [anon_sym_unchecked] = ACTIONS(3817),
    [anon_sym_continue] = ACTIONS(3817),
    [anon_sym_do] = ACTIONS(3817),
    [anon_sym_while] = ACTIONS(3817),
    [anon_sym_for] = ACTIONS(3817),
    [anon_sym_lock] = ACTIONS(3817),
    [anon_sym_yield] = ACTIONS(3817),
    [anon_sym_switch] = ACTIONS(3817),
    [anon_sym_default] = ACTIONS(3817),
    [anon_sym_throw] = ACTIONS(3817),
    [anon_sym_try] = ACTIONS(3817),
    [anon_sym_when] = ACTIONS(3817),
    [anon_sym_await] = ACTIONS(3817),
    [anon_sym_foreach] = ACTIONS(3817),
    [anon_sym_goto] = ACTIONS(3817),
    [anon_sym_if] = ACTIONS(3817),
    [anon_sym_DOT_DOT] = ACTIONS(3819),
    [anon_sym_from] = ACTIONS(3817),
    [anon_sym_into] = ACTIONS(3817),
    [anon_sym_join] = ACTIONS(3817),
    [anon_sym_on] = ACTIONS(3817),
    [anon_sym_equals] = ACTIONS(3817),
    [anon_sym_let] = ACTIONS(3817),
    [anon_sym_orderby] = ACTIONS(3817),
    [anon_sym_ascending] = ACTIONS(3817),
    [anon_sym_descending] = ACTIONS(3817),
    [anon_sym_group] = ACTIONS(3817),
    [anon_sym_by] = ACTIONS(3817),
    [anon_sym_select] = ACTIONS(3817),
    [anon_sym_stackalloc] = ACTIONS(3817),
    [anon_sym_sizeof] = ACTIONS(3817),
    [anon_sym_typeof] = ACTIONS(3817),
    [anon_sym___makeref] = ACTIONS(3817),
    [anon_sym___reftype] = ACTIONS(3817),
    [anon_sym___refvalue] = ACTIONS(3817),
    [sym_null_literal] = ACTIONS(3817),
    [anon_sym_SQUOTE] = ACTIONS(3819),
    [sym_integer_literal] = ACTIONS(3817),
    [sym_real_literal] = ACTIONS(3819),
    [anon_sym_DQUOTE] = ACTIONS(3819),
    [sym_verbatim_string_literal] = ACTIONS(3819),
    [aux_sym_preproc_if_token1] = ACTIONS(3819),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3819),
    [sym_interpolation_verbatim_start] = ACTIONS(3819),
    [sym_interpolation_raw_start] = ACTIONS(3819),
    [sym_raw_string_start] = ACTIONS(3819),
  },
  [2551] = {
    [sym_preproc_region] = STATE(2551),
    [sym_preproc_endregion] = STATE(2551),
    [sym_preproc_line] = STATE(2551),
    [sym_preproc_pragma] = STATE(2551),
    [sym_preproc_nullable] = STATE(2551),
    [sym_preproc_error] = STATE(2551),
    [sym_preproc_warning] = STATE(2551),
    [sym_preproc_define] = STATE(2551),
    [sym_preproc_undef] = STATE(2551),
    [ts_builtin_sym_end] = ACTIONS(3823),
    [sym__identifier_token] = ACTIONS(3821),
    [anon_sym_extern] = ACTIONS(3821),
    [anon_sym_alias] = ACTIONS(3821),
    [anon_sym_SEMI] = ACTIONS(3823),
    [anon_sym_global] = ACTIONS(3821),
    [anon_sym_using] = ACTIONS(3821),
    [anon_sym_unsafe] = ACTIONS(3821),
    [anon_sym_static] = ACTIONS(3821),
    [anon_sym_LBRACK] = ACTIONS(3823),
    [anon_sym_LPAREN] = ACTIONS(3823),
    [anon_sym_return] = ACTIONS(3821),
    [anon_sym_namespace] = ACTIONS(3821),
    [anon_sym_class] = ACTIONS(3821),
    [anon_sym_ref] = ACTIONS(3821),
    [anon_sym_struct] = ACTIONS(3821),
    [anon_sym_enum] = ACTIONS(3821),
    [anon_sym_LBRACE] = ACTIONS(3823),
    [anon_sym_interface] = ACTIONS(3821),
    [anon_sym_delegate] = ACTIONS(3821),
    [anon_sym_record] = ACTIONS(3821),
    [anon_sym_abstract] = ACTIONS(3821),
    [anon_sym_async] = ACTIONS(3821),
    [anon_sym_const] = ACTIONS(3821),
    [anon_sym_file] = ACTIONS(3821),
    [anon_sym_fixed] = ACTIONS(3821),
    [anon_sym_internal] = ACTIONS(3821),
    [anon_sym_new] = ACTIONS(3821),
    [anon_sym_override] = ACTIONS(3821),
    [anon_sym_partial] = ACTIONS(3821),
    [anon_sym_private] = ACTIONS(3821),
    [anon_sym_protected] = ACTIONS(3821),
    [anon_sym_public] = ACTIONS(3821),
    [anon_sym_readonly] = ACTIONS(3821),
    [anon_sym_required] = ACTIONS(3821),
    [anon_sym_sealed] = ACTIONS(3821),
    [anon_sym_virtual] = ACTIONS(3821),
    [anon_sym_volatile] = ACTIONS(3821),
    [anon_sym_where] = ACTIONS(3821),
    [anon_sym_notnull] = ACTIONS(3821),
    [anon_sym_unmanaged] = ACTIONS(3821),
    [anon_sym_checked] = ACTIONS(3821),
    [anon_sym_BANG] = ACTIONS(3823),
    [anon_sym_TILDE] = ACTIONS(3823),
    [anon_sym_PLUS_PLUS] = ACTIONS(3823),
    [anon_sym_DASH_DASH] = ACTIONS(3823),
    [anon_sym_true] = ACTIONS(3821),
    [anon_sym_false] = ACTIONS(3821),
    [anon_sym_PLUS] = ACTIONS(3821),
    [anon_sym_DASH] = ACTIONS(3821),
    [anon_sym_STAR] = ACTIONS(3823),
    [anon_sym_CARET] = ACTIONS(3823),
    [anon_sym_AMP] = ACTIONS(3823),
    [anon_sym_this] = ACTIONS(3821),
    [anon_sym_scoped] = ACTIONS(3821),
    [anon_sym_base] = ACTIONS(3821),
    [anon_sym_var] = ACTIONS(3821),
    [sym_predefined_type] = ACTIONS(3821),
    [anon_sym_break] = ACTIONS(3821),
    [anon_sym_unchecked] = ACTIONS(3821),
    [anon_sym_continue] = ACTIONS(3821),
    [anon_sym_do] = ACTIONS(3821),
    [anon_sym_while] = ACTIONS(3821),
    [anon_sym_for] = ACTIONS(3821),
    [anon_sym_lock] = ACTIONS(3821),
    [anon_sym_yield] = ACTIONS(3821),
    [anon_sym_switch] = ACTIONS(3821),
    [anon_sym_default] = ACTIONS(3821),
    [anon_sym_throw] = ACTIONS(3821),
    [anon_sym_try] = ACTIONS(3821),
    [anon_sym_when] = ACTIONS(3821),
    [anon_sym_await] = ACTIONS(3821),
    [anon_sym_foreach] = ACTIONS(3821),
    [anon_sym_goto] = ACTIONS(3821),
    [anon_sym_if] = ACTIONS(3821),
    [anon_sym_DOT_DOT] = ACTIONS(3823),
    [anon_sym_from] = ACTIONS(3821),
    [anon_sym_into] = ACTIONS(3821),
    [anon_sym_join] = ACTIONS(3821),
    [anon_sym_on] = ACTIONS(3821),
    [anon_sym_equals] = ACTIONS(3821),
    [anon_sym_let] = ACTIONS(3821),
    [anon_sym_orderby] = ACTIONS(3821),
    [anon_sym_ascending] = ACTIONS(3821),
    [anon_sym_descending] = ACTIONS(3821),
    [anon_sym_group] = ACTIONS(3821),
    [anon_sym_by] = ACTIONS(3821),
    [anon_sym_select] = ACTIONS(3821),
    [anon_sym_stackalloc] = ACTIONS(3821),
    [anon_sym_sizeof] = ACTIONS(3821),
    [anon_sym_typeof] = ACTIONS(3821),
    [anon_sym___makeref] = ACTIONS(3821),
    [anon_sym___reftype] = ACTIONS(3821),
    [anon_sym___refvalue] = ACTIONS(3821),
    [sym_null_literal] = ACTIONS(3821),
    [anon_sym_SQUOTE] = ACTIONS(3823),
    [sym_integer_literal] = ACTIONS(3821),
    [sym_real_literal] = ACTIONS(3823),
    [anon_sym_DQUOTE] = ACTIONS(3823),
    [sym_verbatim_string_literal] = ACTIONS(3823),
    [aux_sym_preproc_if_token1] = ACTIONS(3823),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3823),
    [sym_interpolation_verbatim_start] = ACTIONS(3823),
    [sym_interpolation_raw_start] = ACTIONS(3823),
    [sym_raw_string_start] = ACTIONS(3823),
  },
  [2552] = {
    [sym_preproc_region] = STATE(2552),
    [sym_preproc_endregion] = STATE(2552),
    [sym_preproc_line] = STATE(2552),
    [sym_preproc_pragma] = STATE(2552),
    [sym_preproc_nullable] = STATE(2552),
    [sym_preproc_error] = STATE(2552),
    [sym_preproc_warning] = STATE(2552),
    [sym_preproc_define] = STATE(2552),
    [sym_preproc_undef] = STATE(2552),
    [ts_builtin_sym_end] = ACTIONS(3827),
    [sym__identifier_token] = ACTIONS(3825),
    [anon_sym_extern] = ACTIONS(3825),
    [anon_sym_alias] = ACTIONS(3825),
    [anon_sym_SEMI] = ACTIONS(3827),
    [anon_sym_global] = ACTIONS(3825),
    [anon_sym_using] = ACTIONS(3825),
    [anon_sym_unsafe] = ACTIONS(3825),
    [anon_sym_static] = ACTIONS(3825),
    [anon_sym_LBRACK] = ACTIONS(3827),
    [anon_sym_LPAREN] = ACTIONS(3827),
    [anon_sym_return] = ACTIONS(3825),
    [anon_sym_namespace] = ACTIONS(3825),
    [anon_sym_class] = ACTIONS(3825),
    [anon_sym_ref] = ACTIONS(3825),
    [anon_sym_struct] = ACTIONS(3825),
    [anon_sym_enum] = ACTIONS(3825),
    [anon_sym_LBRACE] = ACTIONS(3827),
    [anon_sym_interface] = ACTIONS(3825),
    [anon_sym_delegate] = ACTIONS(3825),
    [anon_sym_record] = ACTIONS(3825),
    [anon_sym_abstract] = ACTIONS(3825),
    [anon_sym_async] = ACTIONS(3825),
    [anon_sym_const] = ACTIONS(3825),
    [anon_sym_file] = ACTIONS(3825),
    [anon_sym_fixed] = ACTIONS(3825),
    [anon_sym_internal] = ACTIONS(3825),
    [anon_sym_new] = ACTIONS(3825),
    [anon_sym_override] = ACTIONS(3825),
    [anon_sym_partial] = ACTIONS(3825),
    [anon_sym_private] = ACTIONS(3825),
    [anon_sym_protected] = ACTIONS(3825),
    [anon_sym_public] = ACTIONS(3825),
    [anon_sym_readonly] = ACTIONS(3825),
    [anon_sym_required] = ACTIONS(3825),
    [anon_sym_sealed] = ACTIONS(3825),
    [anon_sym_virtual] = ACTIONS(3825),
    [anon_sym_volatile] = ACTIONS(3825),
    [anon_sym_where] = ACTIONS(3825),
    [anon_sym_notnull] = ACTIONS(3825),
    [anon_sym_unmanaged] = ACTIONS(3825),
    [anon_sym_checked] = ACTIONS(3825),
    [anon_sym_BANG] = ACTIONS(3827),
    [anon_sym_TILDE] = ACTIONS(3827),
    [anon_sym_PLUS_PLUS] = ACTIONS(3827),
    [anon_sym_DASH_DASH] = ACTIONS(3827),
    [anon_sym_true] = ACTIONS(3825),
    [anon_sym_false] = ACTIONS(3825),
    [anon_sym_PLUS] = ACTIONS(3825),
    [anon_sym_DASH] = ACTIONS(3825),
    [anon_sym_STAR] = ACTIONS(3827),
    [anon_sym_CARET] = ACTIONS(3827),
    [anon_sym_AMP] = ACTIONS(3827),
    [anon_sym_this] = ACTIONS(3825),
    [anon_sym_scoped] = ACTIONS(3825),
    [anon_sym_base] = ACTIONS(3825),
    [anon_sym_var] = ACTIONS(3825),
    [sym_predefined_type] = ACTIONS(3825),
    [anon_sym_break] = ACTIONS(3825),
    [anon_sym_unchecked] = ACTIONS(3825),
    [anon_sym_continue] = ACTIONS(3825),
    [anon_sym_do] = ACTIONS(3825),
    [anon_sym_while] = ACTIONS(3825),
    [anon_sym_for] = ACTIONS(3825),
    [anon_sym_lock] = ACTIONS(3825),
    [anon_sym_yield] = ACTIONS(3825),
    [anon_sym_switch] = ACTIONS(3825),
    [anon_sym_default] = ACTIONS(3825),
    [anon_sym_throw] = ACTIONS(3825),
    [anon_sym_try] = ACTIONS(3825),
    [anon_sym_when] = ACTIONS(3825),
    [anon_sym_await] = ACTIONS(3825),
    [anon_sym_foreach] = ACTIONS(3825),
    [anon_sym_goto] = ACTIONS(3825),
    [anon_sym_if] = ACTIONS(3825),
    [anon_sym_DOT_DOT] = ACTIONS(3827),
    [anon_sym_from] = ACTIONS(3825),
    [anon_sym_into] = ACTIONS(3825),
    [anon_sym_join] = ACTIONS(3825),
    [anon_sym_on] = ACTIONS(3825),
    [anon_sym_equals] = ACTIONS(3825),
    [anon_sym_let] = ACTIONS(3825),
    [anon_sym_orderby] = ACTIONS(3825),
    [anon_sym_ascending] = ACTIONS(3825),
    [anon_sym_descending] = ACTIONS(3825),
    [anon_sym_group] = ACTIONS(3825),
    [anon_sym_by] = ACTIONS(3825),
    [anon_sym_select] = ACTIONS(3825),
    [anon_sym_stackalloc] = ACTIONS(3825),
    [anon_sym_sizeof] = ACTIONS(3825),
    [anon_sym_typeof] = ACTIONS(3825),
    [anon_sym___makeref] = ACTIONS(3825),
    [anon_sym___reftype] = ACTIONS(3825),
    [anon_sym___refvalue] = ACTIONS(3825),
    [sym_null_literal] = ACTIONS(3825),
    [anon_sym_SQUOTE] = ACTIONS(3827),
    [sym_integer_literal] = ACTIONS(3825),
    [sym_real_literal] = ACTIONS(3827),
    [anon_sym_DQUOTE] = ACTIONS(3827),
    [sym_verbatim_string_literal] = ACTIONS(3827),
    [aux_sym_preproc_if_token1] = ACTIONS(3827),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3827),
    [sym_interpolation_verbatim_start] = ACTIONS(3827),
    [sym_interpolation_raw_start] = ACTIONS(3827),
    [sym_raw_string_start] = ACTIONS(3827),
  },
  [2553] = {
    [sym_preproc_region] = STATE(2553),
    [sym_preproc_endregion] = STATE(2553),
    [sym_preproc_line] = STATE(2553),
    [sym_preproc_pragma] = STATE(2553),
    [sym_preproc_nullable] = STATE(2553),
    [sym_preproc_error] = STATE(2553),
    [sym_preproc_warning] = STATE(2553),
    [sym_preproc_define] = STATE(2553),
    [sym_preproc_undef] = STATE(2553),
    [ts_builtin_sym_end] = ACTIONS(3831),
    [sym__identifier_token] = ACTIONS(3829),
    [anon_sym_extern] = ACTIONS(3829),
    [anon_sym_alias] = ACTIONS(3829),
    [anon_sym_SEMI] = ACTIONS(3831),
    [anon_sym_global] = ACTIONS(3829),
    [anon_sym_using] = ACTIONS(3829),
    [anon_sym_unsafe] = ACTIONS(3829),
    [anon_sym_static] = ACTIONS(3829),
    [anon_sym_LBRACK] = ACTIONS(3831),
    [anon_sym_LPAREN] = ACTIONS(3831),
    [anon_sym_return] = ACTIONS(3829),
    [anon_sym_namespace] = ACTIONS(3829),
    [anon_sym_class] = ACTIONS(3829),
    [anon_sym_ref] = ACTIONS(3829),
    [anon_sym_struct] = ACTIONS(3829),
    [anon_sym_enum] = ACTIONS(3829),
    [anon_sym_LBRACE] = ACTIONS(3831),
    [anon_sym_interface] = ACTIONS(3829),
    [anon_sym_delegate] = ACTIONS(3829),
    [anon_sym_record] = ACTIONS(3829),
    [anon_sym_abstract] = ACTIONS(3829),
    [anon_sym_async] = ACTIONS(3829),
    [anon_sym_const] = ACTIONS(3829),
    [anon_sym_file] = ACTIONS(3829),
    [anon_sym_fixed] = ACTIONS(3829),
    [anon_sym_internal] = ACTIONS(3829),
    [anon_sym_new] = ACTIONS(3829),
    [anon_sym_override] = ACTIONS(3829),
    [anon_sym_partial] = ACTIONS(3829),
    [anon_sym_private] = ACTIONS(3829),
    [anon_sym_protected] = ACTIONS(3829),
    [anon_sym_public] = ACTIONS(3829),
    [anon_sym_readonly] = ACTIONS(3829),
    [anon_sym_required] = ACTIONS(3829),
    [anon_sym_sealed] = ACTIONS(3829),
    [anon_sym_virtual] = ACTIONS(3829),
    [anon_sym_volatile] = ACTIONS(3829),
    [anon_sym_where] = ACTIONS(3829),
    [anon_sym_notnull] = ACTIONS(3829),
    [anon_sym_unmanaged] = ACTIONS(3829),
    [anon_sym_checked] = ACTIONS(3829),
    [anon_sym_BANG] = ACTIONS(3831),
    [anon_sym_TILDE] = ACTIONS(3831),
    [anon_sym_PLUS_PLUS] = ACTIONS(3831),
    [anon_sym_DASH_DASH] = ACTIONS(3831),
    [anon_sym_true] = ACTIONS(3829),
    [anon_sym_false] = ACTIONS(3829),
    [anon_sym_PLUS] = ACTIONS(3829),
    [anon_sym_DASH] = ACTIONS(3829),
    [anon_sym_STAR] = ACTIONS(3831),
    [anon_sym_CARET] = ACTIONS(3831),
    [anon_sym_AMP] = ACTIONS(3831),
    [anon_sym_this] = ACTIONS(3829),
    [anon_sym_scoped] = ACTIONS(3829),
    [anon_sym_base] = ACTIONS(3829),
    [anon_sym_var] = ACTIONS(3829),
    [sym_predefined_type] = ACTIONS(3829),
    [anon_sym_break] = ACTIONS(3829),
    [anon_sym_unchecked] = ACTIONS(3829),
    [anon_sym_continue] = ACTIONS(3829),
    [anon_sym_do] = ACTIONS(3829),
    [anon_sym_while] = ACTIONS(3829),
    [anon_sym_for] = ACTIONS(3829),
    [anon_sym_lock] = ACTIONS(3829),
    [anon_sym_yield] = ACTIONS(3829),
    [anon_sym_switch] = ACTIONS(3829),
    [anon_sym_default] = ACTIONS(3829),
    [anon_sym_throw] = ACTIONS(3829),
    [anon_sym_try] = ACTIONS(3829),
    [anon_sym_when] = ACTIONS(3829),
    [anon_sym_await] = ACTIONS(3829),
    [anon_sym_foreach] = ACTIONS(3829),
    [anon_sym_goto] = ACTIONS(3829),
    [anon_sym_if] = ACTIONS(3829),
    [anon_sym_DOT_DOT] = ACTIONS(3831),
    [anon_sym_from] = ACTIONS(3829),
    [anon_sym_into] = ACTIONS(3829),
    [anon_sym_join] = ACTIONS(3829),
    [anon_sym_on] = ACTIONS(3829),
    [anon_sym_equals] = ACTIONS(3829),
    [anon_sym_let] = ACTIONS(3829),
    [anon_sym_orderby] = ACTIONS(3829),
    [anon_sym_ascending] = ACTIONS(3829),
    [anon_sym_descending] = ACTIONS(3829),
    [anon_sym_group] = ACTIONS(3829),
    [anon_sym_by] = ACTIONS(3829),
    [anon_sym_select] = ACTIONS(3829),
    [anon_sym_stackalloc] = ACTIONS(3829),
    [anon_sym_sizeof] = ACTIONS(3829),
    [anon_sym_typeof] = ACTIONS(3829),
    [anon_sym___makeref] = ACTIONS(3829),
    [anon_sym___reftype] = ACTIONS(3829),
    [anon_sym___refvalue] = ACTIONS(3829),
    [sym_null_literal] = ACTIONS(3829),
    [anon_sym_SQUOTE] = ACTIONS(3831),
    [sym_integer_literal] = ACTIONS(3829),
    [sym_real_literal] = ACTIONS(3831),
    [anon_sym_DQUOTE] = ACTIONS(3831),
    [sym_verbatim_string_literal] = ACTIONS(3831),
    [aux_sym_preproc_if_token1] = ACTIONS(3831),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3831),
    [sym_interpolation_verbatim_start] = ACTIONS(3831),
    [sym_interpolation_raw_start] = ACTIONS(3831),
    [sym_raw_string_start] = ACTIONS(3831),
  },
  [2554] = {
    [sym_preproc_region] = STATE(2554),
    [sym_preproc_endregion] = STATE(2554),
    [sym_preproc_line] = STATE(2554),
    [sym_preproc_pragma] = STATE(2554),
    [sym_preproc_nullable] = STATE(2554),
    [sym_preproc_error] = STATE(2554),
    [sym_preproc_warning] = STATE(2554),
    [sym_preproc_define] = STATE(2554),
    [sym_preproc_undef] = STATE(2554),
    [ts_builtin_sym_end] = ACTIONS(3835),
    [sym__identifier_token] = ACTIONS(3833),
    [anon_sym_extern] = ACTIONS(3833),
    [anon_sym_alias] = ACTIONS(3833),
    [anon_sym_SEMI] = ACTIONS(3835),
    [anon_sym_global] = ACTIONS(3833),
    [anon_sym_using] = ACTIONS(3833),
    [anon_sym_unsafe] = ACTIONS(3833),
    [anon_sym_static] = ACTIONS(3833),
    [anon_sym_LBRACK] = ACTIONS(3835),
    [anon_sym_LPAREN] = ACTIONS(3835),
    [anon_sym_return] = ACTIONS(3833),
    [anon_sym_namespace] = ACTIONS(3833),
    [anon_sym_class] = ACTIONS(3833),
    [anon_sym_ref] = ACTIONS(3833),
    [anon_sym_struct] = ACTIONS(3833),
    [anon_sym_enum] = ACTIONS(3833),
    [anon_sym_LBRACE] = ACTIONS(3835),
    [anon_sym_interface] = ACTIONS(3833),
    [anon_sym_delegate] = ACTIONS(3833),
    [anon_sym_record] = ACTIONS(3833),
    [anon_sym_abstract] = ACTIONS(3833),
    [anon_sym_async] = ACTIONS(3833),
    [anon_sym_const] = ACTIONS(3833),
    [anon_sym_file] = ACTIONS(3833),
    [anon_sym_fixed] = ACTIONS(3833),
    [anon_sym_internal] = ACTIONS(3833),
    [anon_sym_new] = ACTIONS(3833),
    [anon_sym_override] = ACTIONS(3833),
    [anon_sym_partial] = ACTIONS(3833),
    [anon_sym_private] = ACTIONS(3833),
    [anon_sym_protected] = ACTIONS(3833),
    [anon_sym_public] = ACTIONS(3833),
    [anon_sym_readonly] = ACTIONS(3833),
    [anon_sym_required] = ACTIONS(3833),
    [anon_sym_sealed] = ACTIONS(3833),
    [anon_sym_virtual] = ACTIONS(3833),
    [anon_sym_volatile] = ACTIONS(3833),
    [anon_sym_where] = ACTIONS(3833),
    [anon_sym_notnull] = ACTIONS(3833),
    [anon_sym_unmanaged] = ACTIONS(3833),
    [anon_sym_checked] = ACTIONS(3833),
    [anon_sym_BANG] = ACTIONS(3835),
    [anon_sym_TILDE] = ACTIONS(3835),
    [anon_sym_PLUS_PLUS] = ACTIONS(3835),
    [anon_sym_DASH_DASH] = ACTIONS(3835),
    [anon_sym_true] = ACTIONS(3833),
    [anon_sym_false] = ACTIONS(3833),
    [anon_sym_PLUS] = ACTIONS(3833),
    [anon_sym_DASH] = ACTIONS(3833),
    [anon_sym_STAR] = ACTIONS(3835),
    [anon_sym_CARET] = ACTIONS(3835),
    [anon_sym_AMP] = ACTIONS(3835),
    [anon_sym_this] = ACTIONS(3833),
    [anon_sym_scoped] = ACTIONS(3833),
    [anon_sym_base] = ACTIONS(3833),
    [anon_sym_var] = ACTIONS(3833),
    [sym_predefined_type] = ACTIONS(3833),
    [anon_sym_break] = ACTIONS(3833),
    [anon_sym_unchecked] = ACTIONS(3833),
    [anon_sym_continue] = ACTIONS(3833),
    [anon_sym_do] = ACTIONS(3833),
    [anon_sym_while] = ACTIONS(3833),
    [anon_sym_for] = ACTIONS(3833),
    [anon_sym_lock] = ACTIONS(3833),
    [anon_sym_yield] = ACTIONS(3833),
    [anon_sym_switch] = ACTIONS(3833),
    [anon_sym_default] = ACTIONS(3833),
    [anon_sym_throw] = ACTIONS(3833),
    [anon_sym_try] = ACTIONS(3833),
    [anon_sym_when] = ACTIONS(3833),
    [anon_sym_await] = ACTIONS(3833),
    [anon_sym_foreach] = ACTIONS(3833),
    [anon_sym_goto] = ACTIONS(3833),
    [anon_sym_if] = ACTIONS(3833),
    [anon_sym_DOT_DOT] = ACTIONS(3835),
    [anon_sym_from] = ACTIONS(3833),
    [anon_sym_into] = ACTIONS(3833),
    [anon_sym_join] = ACTIONS(3833),
    [anon_sym_on] = ACTIONS(3833),
    [anon_sym_equals] = ACTIONS(3833),
    [anon_sym_let] = ACTIONS(3833),
    [anon_sym_orderby] = ACTIONS(3833),
    [anon_sym_ascending] = ACTIONS(3833),
    [anon_sym_descending] = ACTIONS(3833),
    [anon_sym_group] = ACTIONS(3833),
    [anon_sym_by] = ACTIONS(3833),
    [anon_sym_select] = ACTIONS(3833),
    [anon_sym_stackalloc] = ACTIONS(3833),
    [anon_sym_sizeof] = ACTIONS(3833),
    [anon_sym_typeof] = ACTIONS(3833),
    [anon_sym___makeref] = ACTIONS(3833),
    [anon_sym___reftype] = ACTIONS(3833),
    [anon_sym___refvalue] = ACTIONS(3833),
    [sym_null_literal] = ACTIONS(3833),
    [anon_sym_SQUOTE] = ACTIONS(3835),
    [sym_integer_literal] = ACTIONS(3833),
    [sym_real_literal] = ACTIONS(3835),
    [anon_sym_DQUOTE] = ACTIONS(3835),
    [sym_verbatim_string_literal] = ACTIONS(3835),
    [aux_sym_preproc_if_token1] = ACTIONS(3835),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3835),
    [sym_interpolation_verbatim_start] = ACTIONS(3835),
    [sym_interpolation_raw_start] = ACTIONS(3835),
    [sym_raw_string_start] = ACTIONS(3835),
  },
  [2555] = {
    [sym_preproc_region] = STATE(2555),
    [sym_preproc_endregion] = STATE(2555),
    [sym_preproc_line] = STATE(2555),
    [sym_preproc_pragma] = STATE(2555),
    [sym_preproc_nullable] = STATE(2555),
    [sym_preproc_error] = STATE(2555),
    [sym_preproc_warning] = STATE(2555),
    [sym_preproc_define] = STATE(2555),
    [sym_preproc_undef] = STATE(2555),
    [ts_builtin_sym_end] = ACTIONS(3839),
    [sym__identifier_token] = ACTIONS(3837),
    [anon_sym_extern] = ACTIONS(3837),
    [anon_sym_alias] = ACTIONS(3837),
    [anon_sym_SEMI] = ACTIONS(3839),
    [anon_sym_global] = ACTIONS(3837),
    [anon_sym_using] = ACTIONS(3837),
    [anon_sym_unsafe] = ACTIONS(3837),
    [anon_sym_static] = ACTIONS(3837),
    [anon_sym_LBRACK] = ACTIONS(3839),
    [anon_sym_LPAREN] = ACTIONS(3839),
    [anon_sym_return] = ACTIONS(3837),
    [anon_sym_namespace] = ACTIONS(3837),
    [anon_sym_class] = ACTIONS(3837),
    [anon_sym_ref] = ACTIONS(3837),
    [anon_sym_struct] = ACTIONS(3837),
    [anon_sym_enum] = ACTIONS(3837),
    [anon_sym_LBRACE] = ACTIONS(3839),
    [anon_sym_interface] = ACTIONS(3837),
    [anon_sym_delegate] = ACTIONS(3837),
    [anon_sym_record] = ACTIONS(3837),
    [anon_sym_abstract] = ACTIONS(3837),
    [anon_sym_async] = ACTIONS(3837),
    [anon_sym_const] = ACTIONS(3837),
    [anon_sym_file] = ACTIONS(3837),
    [anon_sym_fixed] = ACTIONS(3837),
    [anon_sym_internal] = ACTIONS(3837),
    [anon_sym_new] = ACTIONS(3837),
    [anon_sym_override] = ACTIONS(3837),
    [anon_sym_partial] = ACTIONS(3837),
    [anon_sym_private] = ACTIONS(3837),
    [anon_sym_protected] = ACTIONS(3837),
    [anon_sym_public] = ACTIONS(3837),
    [anon_sym_readonly] = ACTIONS(3837),
    [anon_sym_required] = ACTIONS(3837),
    [anon_sym_sealed] = ACTIONS(3837),
    [anon_sym_virtual] = ACTIONS(3837),
    [anon_sym_volatile] = ACTIONS(3837),
    [anon_sym_where] = ACTIONS(3837),
    [anon_sym_notnull] = ACTIONS(3837),
    [anon_sym_unmanaged] = ACTIONS(3837),
    [anon_sym_checked] = ACTIONS(3837),
    [anon_sym_BANG] = ACTIONS(3839),
    [anon_sym_TILDE] = ACTIONS(3839),
    [anon_sym_PLUS_PLUS] = ACTIONS(3839),
    [anon_sym_DASH_DASH] = ACTIONS(3839),
    [anon_sym_true] = ACTIONS(3837),
    [anon_sym_false] = ACTIONS(3837),
    [anon_sym_PLUS] = ACTIONS(3837),
    [anon_sym_DASH] = ACTIONS(3837),
    [anon_sym_STAR] = ACTIONS(3839),
    [anon_sym_CARET] = ACTIONS(3839),
    [anon_sym_AMP] = ACTIONS(3839),
    [anon_sym_this] = ACTIONS(3837),
    [anon_sym_scoped] = ACTIONS(3837),
    [anon_sym_base] = ACTIONS(3837),
    [anon_sym_var] = ACTIONS(3837),
    [sym_predefined_type] = ACTIONS(3837),
    [anon_sym_break] = ACTIONS(3837),
    [anon_sym_unchecked] = ACTIONS(3837),
    [anon_sym_continue] = ACTIONS(3837),
    [anon_sym_do] = ACTIONS(3837),
    [anon_sym_while] = ACTIONS(3837),
    [anon_sym_for] = ACTIONS(3837),
    [anon_sym_lock] = ACTIONS(3837),
    [anon_sym_yield] = ACTIONS(3837),
    [anon_sym_switch] = ACTIONS(3837),
    [anon_sym_default] = ACTIONS(3837),
    [anon_sym_throw] = ACTIONS(3837),
    [anon_sym_try] = ACTIONS(3837),
    [anon_sym_when] = ACTIONS(3837),
    [anon_sym_await] = ACTIONS(3837),
    [anon_sym_foreach] = ACTIONS(3837),
    [anon_sym_goto] = ACTIONS(3837),
    [anon_sym_if] = ACTIONS(3837),
    [anon_sym_DOT_DOT] = ACTIONS(3839),
    [anon_sym_from] = ACTIONS(3837),
    [anon_sym_into] = ACTIONS(3837),
    [anon_sym_join] = ACTIONS(3837),
    [anon_sym_on] = ACTIONS(3837),
    [anon_sym_equals] = ACTIONS(3837),
    [anon_sym_let] = ACTIONS(3837),
    [anon_sym_orderby] = ACTIONS(3837),
    [anon_sym_ascending] = ACTIONS(3837),
    [anon_sym_descending] = ACTIONS(3837),
    [anon_sym_group] = ACTIONS(3837),
    [anon_sym_by] = ACTIONS(3837),
    [anon_sym_select] = ACTIONS(3837),
    [anon_sym_stackalloc] = ACTIONS(3837),
    [anon_sym_sizeof] = ACTIONS(3837),
    [anon_sym_typeof] = ACTIONS(3837),
    [anon_sym___makeref] = ACTIONS(3837),
    [anon_sym___reftype] = ACTIONS(3837),
    [anon_sym___refvalue] = ACTIONS(3837),
    [sym_null_literal] = ACTIONS(3837),
    [anon_sym_SQUOTE] = ACTIONS(3839),
    [sym_integer_literal] = ACTIONS(3837),
    [sym_real_literal] = ACTIONS(3839),
    [anon_sym_DQUOTE] = ACTIONS(3839),
    [sym_verbatim_string_literal] = ACTIONS(3839),
    [aux_sym_preproc_if_token1] = ACTIONS(3839),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3839),
    [sym_interpolation_verbatim_start] = ACTIONS(3839),
    [sym_interpolation_raw_start] = ACTIONS(3839),
    [sym_raw_string_start] = ACTIONS(3839),
  },
  [2556] = {
    [sym_preproc_region] = STATE(2556),
    [sym_preproc_endregion] = STATE(2556),
    [sym_preproc_line] = STATE(2556),
    [sym_preproc_pragma] = STATE(2556),
    [sym_preproc_nullable] = STATE(2556),
    [sym_preproc_error] = STATE(2556),
    [sym_preproc_warning] = STATE(2556),
    [sym_preproc_define] = STATE(2556),
    [sym_preproc_undef] = STATE(2556),
    [ts_builtin_sym_end] = ACTIONS(3843),
    [sym__identifier_token] = ACTIONS(3841),
    [anon_sym_extern] = ACTIONS(3841),
    [anon_sym_alias] = ACTIONS(3841),
    [anon_sym_SEMI] = ACTIONS(3843),
    [anon_sym_global] = ACTIONS(3841),
    [anon_sym_using] = ACTIONS(3841),
    [anon_sym_unsafe] = ACTIONS(3841),
    [anon_sym_static] = ACTIONS(3841),
    [anon_sym_LBRACK] = ACTIONS(3843),
    [anon_sym_LPAREN] = ACTIONS(3843),
    [anon_sym_return] = ACTIONS(3841),
    [anon_sym_namespace] = ACTIONS(3841),
    [anon_sym_class] = ACTIONS(3841),
    [anon_sym_ref] = ACTIONS(3841),
    [anon_sym_struct] = ACTIONS(3841),
    [anon_sym_enum] = ACTIONS(3841),
    [anon_sym_LBRACE] = ACTIONS(3843),
    [anon_sym_interface] = ACTIONS(3841),
    [anon_sym_delegate] = ACTIONS(3841),
    [anon_sym_record] = ACTIONS(3841),
    [anon_sym_abstract] = ACTIONS(3841),
    [anon_sym_async] = ACTIONS(3841),
    [anon_sym_const] = ACTIONS(3841),
    [anon_sym_file] = ACTIONS(3841),
    [anon_sym_fixed] = ACTIONS(3841),
    [anon_sym_internal] = ACTIONS(3841),
    [anon_sym_new] = ACTIONS(3841),
    [anon_sym_override] = ACTIONS(3841),
    [anon_sym_partial] = ACTIONS(3841),
    [anon_sym_private] = ACTIONS(3841),
    [anon_sym_protected] = ACTIONS(3841),
    [anon_sym_public] = ACTIONS(3841),
    [anon_sym_readonly] = ACTIONS(3841),
    [anon_sym_required] = ACTIONS(3841),
    [anon_sym_sealed] = ACTIONS(3841),
    [anon_sym_virtual] = ACTIONS(3841),
    [anon_sym_volatile] = ACTIONS(3841),
    [anon_sym_where] = ACTIONS(3841),
    [anon_sym_notnull] = ACTIONS(3841),
    [anon_sym_unmanaged] = ACTIONS(3841),
    [anon_sym_checked] = ACTIONS(3841),
    [anon_sym_BANG] = ACTIONS(3843),
    [anon_sym_TILDE] = ACTIONS(3843),
    [anon_sym_PLUS_PLUS] = ACTIONS(3843),
    [anon_sym_DASH_DASH] = ACTIONS(3843),
    [anon_sym_true] = ACTIONS(3841),
    [anon_sym_false] = ACTIONS(3841),
    [anon_sym_PLUS] = ACTIONS(3841),
    [anon_sym_DASH] = ACTIONS(3841),
    [anon_sym_STAR] = ACTIONS(3843),
    [anon_sym_CARET] = ACTIONS(3843),
    [anon_sym_AMP] = ACTIONS(3843),
    [anon_sym_this] = ACTIONS(3841),
    [anon_sym_scoped] = ACTIONS(3841),
    [anon_sym_base] = ACTIONS(3841),
    [anon_sym_var] = ACTIONS(3841),
    [sym_predefined_type] = ACTIONS(3841),
    [anon_sym_break] = ACTIONS(3841),
    [anon_sym_unchecked] = ACTIONS(3841),
    [anon_sym_continue] = ACTIONS(3841),
    [anon_sym_do] = ACTIONS(3841),
    [anon_sym_while] = ACTIONS(3841),
    [anon_sym_for] = ACTIONS(3841),
    [anon_sym_lock] = ACTIONS(3841),
    [anon_sym_yield] = ACTIONS(3841),
    [anon_sym_switch] = ACTIONS(3841),
    [anon_sym_default] = ACTIONS(3841),
    [anon_sym_throw] = ACTIONS(3841),
    [anon_sym_try] = ACTIONS(3841),
    [anon_sym_when] = ACTIONS(3841),
    [anon_sym_await] = ACTIONS(3841),
    [anon_sym_foreach] = ACTIONS(3841),
    [anon_sym_goto] = ACTIONS(3841),
    [anon_sym_if] = ACTIONS(3841),
    [anon_sym_DOT_DOT] = ACTIONS(3843),
    [anon_sym_from] = ACTIONS(3841),
    [anon_sym_into] = ACTIONS(3841),
    [anon_sym_join] = ACTIONS(3841),
    [anon_sym_on] = ACTIONS(3841),
    [anon_sym_equals] = ACTIONS(3841),
    [anon_sym_let] = ACTIONS(3841),
    [anon_sym_orderby] = ACTIONS(3841),
    [anon_sym_ascending] = ACTIONS(3841),
    [anon_sym_descending] = ACTIONS(3841),
    [anon_sym_group] = ACTIONS(3841),
    [anon_sym_by] = ACTIONS(3841),
    [anon_sym_select] = ACTIONS(3841),
    [anon_sym_stackalloc] = ACTIONS(3841),
    [anon_sym_sizeof] = ACTIONS(3841),
    [anon_sym_typeof] = ACTIONS(3841),
    [anon_sym___makeref] = ACTIONS(3841),
    [anon_sym___reftype] = ACTIONS(3841),
    [anon_sym___refvalue] = ACTIONS(3841),
    [sym_null_literal] = ACTIONS(3841),
    [anon_sym_SQUOTE] = ACTIONS(3843),
    [sym_integer_literal] = ACTIONS(3841),
    [sym_real_literal] = ACTIONS(3843),
    [anon_sym_DQUOTE] = ACTIONS(3843),
    [sym_verbatim_string_literal] = ACTIONS(3843),
    [aux_sym_preproc_if_token1] = ACTIONS(3843),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3843),
    [sym_interpolation_verbatim_start] = ACTIONS(3843),
    [sym_interpolation_raw_start] = ACTIONS(3843),
    [sym_raw_string_start] = ACTIONS(3843),
  },
  [2557] = {
    [sym_preproc_region] = STATE(2557),
    [sym_preproc_endregion] = STATE(2557),
    [sym_preproc_line] = STATE(2557),
    [sym_preproc_pragma] = STATE(2557),
    [sym_preproc_nullable] = STATE(2557),
    [sym_preproc_error] = STATE(2557),
    [sym_preproc_warning] = STATE(2557),
    [sym_preproc_define] = STATE(2557),
    [sym_preproc_undef] = STATE(2557),
    [ts_builtin_sym_end] = ACTIONS(3851),
    [sym__identifier_token] = ACTIONS(3849),
    [anon_sym_extern] = ACTIONS(3849),
    [anon_sym_alias] = ACTIONS(3849),
    [anon_sym_SEMI] = ACTIONS(3851),
    [anon_sym_global] = ACTIONS(3849),
    [anon_sym_using] = ACTIONS(3849),
    [anon_sym_unsafe] = ACTIONS(3849),
    [anon_sym_static] = ACTIONS(3849),
    [anon_sym_LBRACK] = ACTIONS(3851),
    [anon_sym_LPAREN] = ACTIONS(3851),
    [anon_sym_return] = ACTIONS(3849),
    [anon_sym_namespace] = ACTIONS(3849),
    [anon_sym_class] = ACTIONS(3849),
    [anon_sym_ref] = ACTIONS(3849),
    [anon_sym_struct] = ACTIONS(3849),
    [anon_sym_enum] = ACTIONS(3849),
    [anon_sym_LBRACE] = ACTIONS(3851),
    [anon_sym_interface] = ACTIONS(3849),
    [anon_sym_delegate] = ACTIONS(3849),
    [anon_sym_record] = ACTIONS(3849),
    [anon_sym_abstract] = ACTIONS(3849),
    [anon_sym_async] = ACTIONS(3849),
    [anon_sym_const] = ACTIONS(3849),
    [anon_sym_file] = ACTIONS(3849),
    [anon_sym_fixed] = ACTIONS(3849),
    [anon_sym_internal] = ACTIONS(3849),
    [anon_sym_new] = ACTIONS(3849),
    [anon_sym_override] = ACTIONS(3849),
    [anon_sym_partial] = ACTIONS(3849),
    [anon_sym_private] = ACTIONS(3849),
    [anon_sym_protected] = ACTIONS(3849),
    [anon_sym_public] = ACTIONS(3849),
    [anon_sym_readonly] = ACTIONS(3849),
    [anon_sym_required] = ACTIONS(3849),
    [anon_sym_sealed] = ACTIONS(3849),
    [anon_sym_virtual] = ACTIONS(3849),
    [anon_sym_volatile] = ACTIONS(3849),
    [anon_sym_where] = ACTIONS(3849),
    [anon_sym_notnull] = ACTIONS(3849),
    [anon_sym_unmanaged] = ACTIONS(3849),
    [anon_sym_checked] = ACTIONS(3849),
    [anon_sym_BANG] = ACTIONS(3851),
    [anon_sym_TILDE] = ACTIONS(3851),
    [anon_sym_PLUS_PLUS] = ACTIONS(3851),
    [anon_sym_DASH_DASH] = ACTIONS(3851),
    [anon_sym_true] = ACTIONS(3849),
    [anon_sym_false] = ACTIONS(3849),
    [anon_sym_PLUS] = ACTIONS(3849),
    [anon_sym_DASH] = ACTIONS(3849),
    [anon_sym_STAR] = ACTIONS(3851),
    [anon_sym_CARET] = ACTIONS(3851),
    [anon_sym_AMP] = ACTIONS(3851),
    [anon_sym_this] = ACTIONS(3849),
    [anon_sym_scoped] = ACTIONS(3849),
    [anon_sym_base] = ACTIONS(3849),
    [anon_sym_var] = ACTIONS(3849),
    [sym_predefined_type] = ACTIONS(3849),
    [anon_sym_break] = ACTIONS(3849),
    [anon_sym_unchecked] = ACTIONS(3849),
    [anon_sym_continue] = ACTIONS(3849),
    [anon_sym_do] = ACTIONS(3849),
    [anon_sym_while] = ACTIONS(3849),
    [anon_sym_for] = ACTIONS(3849),
    [anon_sym_lock] = ACTIONS(3849),
    [anon_sym_yield] = ACTIONS(3849),
    [anon_sym_switch] = ACTIONS(3849),
    [anon_sym_default] = ACTIONS(3849),
    [anon_sym_throw] = ACTIONS(3849),
    [anon_sym_try] = ACTIONS(3849),
    [anon_sym_when] = ACTIONS(3849),
    [anon_sym_await] = ACTIONS(3849),
    [anon_sym_foreach] = ACTIONS(3849),
    [anon_sym_goto] = ACTIONS(3849),
    [anon_sym_if] = ACTIONS(3849),
    [anon_sym_DOT_DOT] = ACTIONS(3851),
    [anon_sym_from] = ACTIONS(3849),
    [anon_sym_into] = ACTIONS(3849),
    [anon_sym_join] = ACTIONS(3849),
    [anon_sym_on] = ACTIONS(3849),
    [anon_sym_equals] = ACTIONS(3849),
    [anon_sym_let] = ACTIONS(3849),
    [anon_sym_orderby] = ACTIONS(3849),
    [anon_sym_ascending] = ACTIONS(3849),
    [anon_sym_descending] = ACTIONS(3849),
    [anon_sym_group] = ACTIONS(3849),
    [anon_sym_by] = ACTIONS(3849),
    [anon_sym_select] = ACTIONS(3849),
    [anon_sym_stackalloc] = ACTIONS(3849),
    [anon_sym_sizeof] = ACTIONS(3849),
    [anon_sym_typeof] = ACTIONS(3849),
    [anon_sym___makeref] = ACTIONS(3849),
    [anon_sym___reftype] = ACTIONS(3849),
    [anon_sym___refvalue] = ACTIONS(3849),
    [sym_null_literal] = ACTIONS(3849),
    [anon_sym_SQUOTE] = ACTIONS(3851),
    [sym_integer_literal] = ACTIONS(3849),
    [sym_real_literal] = ACTIONS(3851),
    [anon_sym_DQUOTE] = ACTIONS(3851),
    [sym_verbatim_string_literal] = ACTIONS(3851),
    [aux_sym_preproc_if_token1] = ACTIONS(3851),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3851),
    [sym_interpolation_verbatim_start] = ACTIONS(3851),
    [sym_interpolation_raw_start] = ACTIONS(3851),
    [sym_raw_string_start] = ACTIONS(3851),
  },
  [2558] = {
    [sym_preproc_region] = STATE(2558),
    [sym_preproc_endregion] = STATE(2558),
    [sym_preproc_line] = STATE(2558),
    [sym_preproc_pragma] = STATE(2558),
    [sym_preproc_nullable] = STATE(2558),
    [sym_preproc_error] = STATE(2558),
    [sym_preproc_warning] = STATE(2558),
    [sym_preproc_define] = STATE(2558),
    [sym_preproc_undef] = STATE(2558),
    [ts_builtin_sym_end] = ACTIONS(3855),
    [sym__identifier_token] = ACTIONS(3853),
    [anon_sym_extern] = ACTIONS(3853),
    [anon_sym_alias] = ACTIONS(3853),
    [anon_sym_SEMI] = ACTIONS(3855),
    [anon_sym_global] = ACTIONS(3853),
    [anon_sym_using] = ACTIONS(3853),
    [anon_sym_unsafe] = ACTIONS(3853),
    [anon_sym_static] = ACTIONS(3853),
    [anon_sym_LBRACK] = ACTIONS(3855),
    [anon_sym_LPAREN] = ACTIONS(3855),
    [anon_sym_return] = ACTIONS(3853),
    [anon_sym_namespace] = ACTIONS(3853),
    [anon_sym_class] = ACTIONS(3853),
    [anon_sym_ref] = ACTIONS(3853),
    [anon_sym_struct] = ACTIONS(3853),
    [anon_sym_enum] = ACTIONS(3853),
    [anon_sym_LBRACE] = ACTIONS(3855),
    [anon_sym_interface] = ACTIONS(3853),
    [anon_sym_delegate] = ACTIONS(3853),
    [anon_sym_record] = ACTIONS(3853),
    [anon_sym_abstract] = ACTIONS(3853),
    [anon_sym_async] = ACTIONS(3853),
    [anon_sym_const] = ACTIONS(3853),
    [anon_sym_file] = ACTIONS(3853),
    [anon_sym_fixed] = ACTIONS(3853),
    [anon_sym_internal] = ACTIONS(3853),
    [anon_sym_new] = ACTIONS(3853),
    [anon_sym_override] = ACTIONS(3853),
    [anon_sym_partial] = ACTIONS(3853),
    [anon_sym_private] = ACTIONS(3853),
    [anon_sym_protected] = ACTIONS(3853),
    [anon_sym_public] = ACTIONS(3853),
    [anon_sym_readonly] = ACTIONS(3853),
    [anon_sym_required] = ACTIONS(3853),
    [anon_sym_sealed] = ACTIONS(3853),
    [anon_sym_virtual] = ACTIONS(3853),
    [anon_sym_volatile] = ACTIONS(3853),
    [anon_sym_where] = ACTIONS(3853),
    [anon_sym_notnull] = ACTIONS(3853),
    [anon_sym_unmanaged] = ACTIONS(3853),
    [anon_sym_checked] = ACTIONS(3853),
    [anon_sym_BANG] = ACTIONS(3855),
    [anon_sym_TILDE] = ACTIONS(3855),
    [anon_sym_PLUS_PLUS] = ACTIONS(3855),
    [anon_sym_DASH_DASH] = ACTIONS(3855),
    [anon_sym_true] = ACTIONS(3853),
    [anon_sym_false] = ACTIONS(3853),
    [anon_sym_PLUS] = ACTIONS(3853),
    [anon_sym_DASH] = ACTIONS(3853),
    [anon_sym_STAR] = ACTIONS(3855),
    [anon_sym_CARET] = ACTIONS(3855),
    [anon_sym_AMP] = ACTIONS(3855),
    [anon_sym_this] = ACTIONS(3853),
    [anon_sym_scoped] = ACTIONS(3853),
    [anon_sym_base] = ACTIONS(3853),
    [anon_sym_var] = ACTIONS(3853),
    [sym_predefined_type] = ACTIONS(3853),
    [anon_sym_break] = ACTIONS(3853),
    [anon_sym_unchecked] = ACTIONS(3853),
    [anon_sym_continue] = ACTIONS(3853),
    [anon_sym_do] = ACTIONS(3853),
    [anon_sym_while] = ACTIONS(3853),
    [anon_sym_for] = ACTIONS(3853),
    [anon_sym_lock] = ACTIONS(3853),
    [anon_sym_yield] = ACTIONS(3853),
    [anon_sym_switch] = ACTIONS(3853),
    [anon_sym_default] = ACTIONS(3853),
    [anon_sym_throw] = ACTIONS(3853),
    [anon_sym_try] = ACTIONS(3853),
    [anon_sym_when] = ACTIONS(3853),
    [anon_sym_await] = ACTIONS(3853),
    [anon_sym_foreach] = ACTIONS(3853),
    [anon_sym_goto] = ACTIONS(3853),
    [anon_sym_if] = ACTIONS(3853),
    [anon_sym_DOT_DOT] = ACTIONS(3855),
    [anon_sym_from] = ACTIONS(3853),
    [anon_sym_into] = ACTIONS(3853),
    [anon_sym_join] = ACTIONS(3853),
    [anon_sym_on] = ACTIONS(3853),
    [anon_sym_equals] = ACTIONS(3853),
    [anon_sym_let] = ACTIONS(3853),
    [anon_sym_orderby] = ACTIONS(3853),
    [anon_sym_ascending] = ACTIONS(3853),
    [anon_sym_descending] = ACTIONS(3853),
    [anon_sym_group] = ACTIONS(3853),
    [anon_sym_by] = ACTIONS(3853),
    [anon_sym_select] = ACTIONS(3853),
    [anon_sym_stackalloc] = ACTIONS(3853),
    [anon_sym_sizeof] = ACTIONS(3853),
    [anon_sym_typeof] = ACTIONS(3853),
    [anon_sym___makeref] = ACTIONS(3853),
    [anon_sym___reftype] = ACTIONS(3853),
    [anon_sym___refvalue] = ACTIONS(3853),
    [sym_null_literal] = ACTIONS(3853),
    [anon_sym_SQUOTE] = ACTIONS(3855),
    [sym_integer_literal] = ACTIONS(3853),
    [sym_real_literal] = ACTIONS(3855),
    [anon_sym_DQUOTE] = ACTIONS(3855),
    [sym_verbatim_string_literal] = ACTIONS(3855),
    [aux_sym_preproc_if_token1] = ACTIONS(3855),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3855),
    [sym_interpolation_verbatim_start] = ACTIONS(3855),
    [sym_interpolation_raw_start] = ACTIONS(3855),
    [sym_raw_string_start] = ACTIONS(3855),
  },
  [2559] = {
    [sym_preproc_region] = STATE(2559),
    [sym_preproc_endregion] = STATE(2559),
    [sym_preproc_line] = STATE(2559),
    [sym_preproc_pragma] = STATE(2559),
    [sym_preproc_nullable] = STATE(2559),
    [sym_preproc_error] = STATE(2559),
    [sym_preproc_warning] = STATE(2559),
    [sym_preproc_define] = STATE(2559),
    [sym_preproc_undef] = STATE(2559),
    [ts_builtin_sym_end] = ACTIONS(3859),
    [sym__identifier_token] = ACTIONS(3857),
    [anon_sym_extern] = ACTIONS(3857),
    [anon_sym_alias] = ACTIONS(3857),
    [anon_sym_SEMI] = ACTIONS(3859),
    [anon_sym_global] = ACTIONS(3857),
    [anon_sym_using] = ACTIONS(3857),
    [anon_sym_unsafe] = ACTIONS(3857),
    [anon_sym_static] = ACTIONS(3857),
    [anon_sym_LBRACK] = ACTIONS(3859),
    [anon_sym_LPAREN] = ACTIONS(3859),
    [anon_sym_return] = ACTIONS(3857),
    [anon_sym_namespace] = ACTIONS(3857),
    [anon_sym_class] = ACTIONS(3857),
    [anon_sym_ref] = ACTIONS(3857),
    [anon_sym_struct] = ACTIONS(3857),
    [anon_sym_enum] = ACTIONS(3857),
    [anon_sym_LBRACE] = ACTIONS(3859),
    [anon_sym_interface] = ACTIONS(3857),
    [anon_sym_delegate] = ACTIONS(3857),
    [anon_sym_record] = ACTIONS(3857),
    [anon_sym_abstract] = ACTIONS(3857),
    [anon_sym_async] = ACTIONS(3857),
    [anon_sym_const] = ACTIONS(3857),
    [anon_sym_file] = ACTIONS(3857),
    [anon_sym_fixed] = ACTIONS(3857),
    [anon_sym_internal] = ACTIONS(3857),
    [anon_sym_new] = ACTIONS(3857),
    [anon_sym_override] = ACTIONS(3857),
    [anon_sym_partial] = ACTIONS(3857),
    [anon_sym_private] = ACTIONS(3857),
    [anon_sym_protected] = ACTIONS(3857),
    [anon_sym_public] = ACTIONS(3857),
    [anon_sym_readonly] = ACTIONS(3857),
    [anon_sym_required] = ACTIONS(3857),
    [anon_sym_sealed] = ACTIONS(3857),
    [anon_sym_virtual] = ACTIONS(3857),
    [anon_sym_volatile] = ACTIONS(3857),
    [anon_sym_where] = ACTIONS(3857),
    [anon_sym_notnull] = ACTIONS(3857),
    [anon_sym_unmanaged] = ACTIONS(3857),
    [anon_sym_checked] = ACTIONS(3857),
    [anon_sym_BANG] = ACTIONS(3859),
    [anon_sym_TILDE] = ACTIONS(3859),
    [anon_sym_PLUS_PLUS] = ACTIONS(3859),
    [anon_sym_DASH_DASH] = ACTIONS(3859),
    [anon_sym_true] = ACTIONS(3857),
    [anon_sym_false] = ACTIONS(3857),
    [anon_sym_PLUS] = ACTIONS(3857),
    [anon_sym_DASH] = ACTIONS(3857),
    [anon_sym_STAR] = ACTIONS(3859),
    [anon_sym_CARET] = ACTIONS(3859),
    [anon_sym_AMP] = ACTIONS(3859),
    [anon_sym_this] = ACTIONS(3857),
    [anon_sym_scoped] = ACTIONS(3857),
    [anon_sym_base] = ACTIONS(3857),
    [anon_sym_var] = ACTIONS(3857),
    [sym_predefined_type] = ACTIONS(3857),
    [anon_sym_break] = ACTIONS(3857),
    [anon_sym_unchecked] = ACTIONS(3857),
    [anon_sym_continue] = ACTIONS(3857),
    [anon_sym_do] = ACTIONS(3857),
    [anon_sym_while] = ACTIONS(3857),
    [anon_sym_for] = ACTIONS(3857),
    [anon_sym_lock] = ACTIONS(3857),
    [anon_sym_yield] = ACTIONS(3857),
    [anon_sym_switch] = ACTIONS(3857),
    [anon_sym_default] = ACTIONS(3857),
    [anon_sym_throw] = ACTIONS(3857),
    [anon_sym_try] = ACTIONS(3857),
    [anon_sym_when] = ACTIONS(3857),
    [anon_sym_await] = ACTIONS(3857),
    [anon_sym_foreach] = ACTIONS(3857),
    [anon_sym_goto] = ACTIONS(3857),
    [anon_sym_if] = ACTIONS(3857),
    [anon_sym_DOT_DOT] = ACTIONS(3859),
    [anon_sym_from] = ACTIONS(3857),
    [anon_sym_into] = ACTIONS(3857),
    [anon_sym_join] = ACTIONS(3857),
    [anon_sym_on] = ACTIONS(3857),
    [anon_sym_equals] = ACTIONS(3857),
    [anon_sym_let] = ACTIONS(3857),
    [anon_sym_orderby] = ACTIONS(3857),
    [anon_sym_ascending] = ACTIONS(3857),
    [anon_sym_descending] = ACTIONS(3857),
    [anon_sym_group] = ACTIONS(3857),
    [anon_sym_by] = ACTIONS(3857),
    [anon_sym_select] = ACTIONS(3857),
    [anon_sym_stackalloc] = ACTIONS(3857),
    [anon_sym_sizeof] = ACTIONS(3857),
    [anon_sym_typeof] = ACTIONS(3857),
    [anon_sym___makeref] = ACTIONS(3857),
    [anon_sym___reftype] = ACTIONS(3857),
    [anon_sym___refvalue] = ACTIONS(3857),
    [sym_null_literal] = ACTIONS(3857),
    [anon_sym_SQUOTE] = ACTIONS(3859),
    [sym_integer_literal] = ACTIONS(3857),
    [sym_real_literal] = ACTIONS(3859),
    [anon_sym_DQUOTE] = ACTIONS(3859),
    [sym_verbatim_string_literal] = ACTIONS(3859),
    [aux_sym_preproc_if_token1] = ACTIONS(3859),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3859),
    [sym_interpolation_verbatim_start] = ACTIONS(3859),
    [sym_interpolation_raw_start] = ACTIONS(3859),
    [sym_raw_string_start] = ACTIONS(3859),
  },
  [2560] = {
    [sym_preproc_region] = STATE(2560),
    [sym_preproc_endregion] = STATE(2560),
    [sym_preproc_line] = STATE(2560),
    [sym_preproc_pragma] = STATE(2560),
    [sym_preproc_nullable] = STATE(2560),
    [sym_preproc_error] = STATE(2560),
    [sym_preproc_warning] = STATE(2560),
    [sym_preproc_define] = STATE(2560),
    [sym_preproc_undef] = STATE(2560),
    [ts_builtin_sym_end] = ACTIONS(3863),
    [sym__identifier_token] = ACTIONS(3861),
    [anon_sym_extern] = ACTIONS(3861),
    [anon_sym_alias] = ACTIONS(3861),
    [anon_sym_SEMI] = ACTIONS(3863),
    [anon_sym_global] = ACTIONS(3861),
    [anon_sym_using] = ACTIONS(3861),
    [anon_sym_unsafe] = ACTIONS(3861),
    [anon_sym_static] = ACTIONS(3861),
    [anon_sym_LBRACK] = ACTIONS(3863),
    [anon_sym_LPAREN] = ACTIONS(3863),
    [anon_sym_return] = ACTIONS(3861),
    [anon_sym_namespace] = ACTIONS(3861),
    [anon_sym_class] = ACTIONS(3861),
    [anon_sym_ref] = ACTIONS(3861),
    [anon_sym_struct] = ACTIONS(3861),
    [anon_sym_enum] = ACTIONS(3861),
    [anon_sym_LBRACE] = ACTIONS(3863),
    [anon_sym_interface] = ACTIONS(3861),
    [anon_sym_delegate] = ACTIONS(3861),
    [anon_sym_record] = ACTIONS(3861),
    [anon_sym_abstract] = ACTIONS(3861),
    [anon_sym_async] = ACTIONS(3861),
    [anon_sym_const] = ACTIONS(3861),
    [anon_sym_file] = ACTIONS(3861),
    [anon_sym_fixed] = ACTIONS(3861),
    [anon_sym_internal] = ACTIONS(3861),
    [anon_sym_new] = ACTIONS(3861),
    [anon_sym_override] = ACTIONS(3861),
    [anon_sym_partial] = ACTIONS(3861),
    [anon_sym_private] = ACTIONS(3861),
    [anon_sym_protected] = ACTIONS(3861),
    [anon_sym_public] = ACTIONS(3861),
    [anon_sym_readonly] = ACTIONS(3861),
    [anon_sym_required] = ACTIONS(3861),
    [anon_sym_sealed] = ACTIONS(3861),
    [anon_sym_virtual] = ACTIONS(3861),
    [anon_sym_volatile] = ACTIONS(3861),
    [anon_sym_where] = ACTIONS(3861),
    [anon_sym_notnull] = ACTIONS(3861),
    [anon_sym_unmanaged] = ACTIONS(3861),
    [anon_sym_checked] = ACTIONS(3861),
    [anon_sym_BANG] = ACTIONS(3863),
    [anon_sym_TILDE] = ACTIONS(3863),
    [anon_sym_PLUS_PLUS] = ACTIONS(3863),
    [anon_sym_DASH_DASH] = ACTIONS(3863),
    [anon_sym_true] = ACTIONS(3861),
    [anon_sym_false] = ACTIONS(3861),
    [anon_sym_PLUS] = ACTIONS(3861),
    [anon_sym_DASH] = ACTIONS(3861),
    [anon_sym_STAR] = ACTIONS(3863),
    [anon_sym_CARET] = ACTIONS(3863),
    [anon_sym_AMP] = ACTIONS(3863),
    [anon_sym_this] = ACTIONS(3861),
    [anon_sym_scoped] = ACTIONS(3861),
    [anon_sym_base] = ACTIONS(3861),
    [anon_sym_var] = ACTIONS(3861),
    [sym_predefined_type] = ACTIONS(3861),
    [anon_sym_break] = ACTIONS(3861),
    [anon_sym_unchecked] = ACTIONS(3861),
    [anon_sym_continue] = ACTIONS(3861),
    [anon_sym_do] = ACTIONS(3861),
    [anon_sym_while] = ACTIONS(3861),
    [anon_sym_for] = ACTIONS(3861),
    [anon_sym_lock] = ACTIONS(3861),
    [anon_sym_yield] = ACTIONS(3861),
    [anon_sym_switch] = ACTIONS(3861),
    [anon_sym_default] = ACTIONS(3861),
    [anon_sym_throw] = ACTIONS(3861),
    [anon_sym_try] = ACTIONS(3861),
    [anon_sym_when] = ACTIONS(3861),
    [anon_sym_await] = ACTIONS(3861),
    [anon_sym_foreach] = ACTIONS(3861),
    [anon_sym_goto] = ACTIONS(3861),
    [anon_sym_if] = ACTIONS(3861),
    [anon_sym_DOT_DOT] = ACTIONS(3863),
    [anon_sym_from] = ACTIONS(3861),
    [anon_sym_into] = ACTIONS(3861),
    [anon_sym_join] = ACTIONS(3861),
    [anon_sym_on] = ACTIONS(3861),
    [anon_sym_equals] = ACTIONS(3861),
    [anon_sym_let] = ACTIONS(3861),
    [anon_sym_orderby] = ACTIONS(3861),
    [anon_sym_ascending] = ACTIONS(3861),
    [anon_sym_descending] = ACTIONS(3861),
    [anon_sym_group] = ACTIONS(3861),
    [anon_sym_by] = ACTIONS(3861),
    [anon_sym_select] = ACTIONS(3861),
    [anon_sym_stackalloc] = ACTIONS(3861),
    [anon_sym_sizeof] = ACTIONS(3861),
    [anon_sym_typeof] = ACTIONS(3861),
    [anon_sym___makeref] = ACTIONS(3861),
    [anon_sym___reftype] = ACTIONS(3861),
    [anon_sym___refvalue] = ACTIONS(3861),
    [sym_null_literal] = ACTIONS(3861),
    [anon_sym_SQUOTE] = ACTIONS(3863),
    [sym_integer_literal] = ACTIONS(3861),
    [sym_real_literal] = ACTIONS(3863),
    [anon_sym_DQUOTE] = ACTIONS(3863),
    [sym_verbatim_string_literal] = ACTIONS(3863),
    [aux_sym_preproc_if_token1] = ACTIONS(3863),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3863),
    [sym_interpolation_verbatim_start] = ACTIONS(3863),
    [sym_interpolation_raw_start] = ACTIONS(3863),
    [sym_raw_string_start] = ACTIONS(3863),
  },
  [2561] = {
    [sym_preproc_region] = STATE(2561),
    [sym_preproc_endregion] = STATE(2561),
    [sym_preproc_line] = STATE(2561),
    [sym_preproc_pragma] = STATE(2561),
    [sym_preproc_nullable] = STATE(2561),
    [sym_preproc_error] = STATE(2561),
    [sym_preproc_warning] = STATE(2561),
    [sym_preproc_define] = STATE(2561),
    [sym_preproc_undef] = STATE(2561),
    [ts_builtin_sym_end] = ACTIONS(3539),
    [sym__identifier_token] = ACTIONS(3537),
    [anon_sym_extern] = ACTIONS(3537),
    [anon_sym_alias] = ACTIONS(3537),
    [anon_sym_SEMI] = ACTIONS(3539),
    [anon_sym_global] = ACTIONS(3537),
    [anon_sym_using] = ACTIONS(3537),
    [anon_sym_unsafe] = ACTIONS(3537),
    [anon_sym_static] = ACTIONS(3537),
    [anon_sym_LBRACK] = ACTIONS(3539),
    [anon_sym_LPAREN] = ACTIONS(3539),
    [anon_sym_return] = ACTIONS(3537),
    [anon_sym_namespace] = ACTIONS(3537),
    [anon_sym_class] = ACTIONS(3537),
    [anon_sym_ref] = ACTIONS(3537),
    [anon_sym_struct] = ACTIONS(3537),
    [anon_sym_enum] = ACTIONS(3537),
    [anon_sym_LBRACE] = ACTIONS(3539),
    [anon_sym_interface] = ACTIONS(3537),
    [anon_sym_delegate] = ACTIONS(3537),
    [anon_sym_record] = ACTIONS(3537),
    [anon_sym_abstract] = ACTIONS(3537),
    [anon_sym_async] = ACTIONS(3537),
    [anon_sym_const] = ACTIONS(3537),
    [anon_sym_file] = ACTIONS(3537),
    [anon_sym_fixed] = ACTIONS(3537),
    [anon_sym_internal] = ACTIONS(3537),
    [anon_sym_new] = ACTIONS(3537),
    [anon_sym_override] = ACTIONS(3537),
    [anon_sym_partial] = ACTIONS(3537),
    [anon_sym_private] = ACTIONS(3537),
    [anon_sym_protected] = ACTIONS(3537),
    [anon_sym_public] = ACTIONS(3537),
    [anon_sym_readonly] = ACTIONS(3537),
    [anon_sym_required] = ACTIONS(3537),
    [anon_sym_sealed] = ACTIONS(3537),
    [anon_sym_virtual] = ACTIONS(3537),
    [anon_sym_volatile] = ACTIONS(3537),
    [anon_sym_where] = ACTIONS(3537),
    [anon_sym_notnull] = ACTIONS(3537),
    [anon_sym_unmanaged] = ACTIONS(3537),
    [anon_sym_checked] = ACTIONS(3537),
    [anon_sym_BANG] = ACTIONS(3539),
    [anon_sym_TILDE] = ACTIONS(3539),
    [anon_sym_PLUS_PLUS] = ACTIONS(3539),
    [anon_sym_DASH_DASH] = ACTIONS(3539),
    [anon_sym_true] = ACTIONS(3537),
    [anon_sym_false] = ACTIONS(3537),
    [anon_sym_PLUS] = ACTIONS(3537),
    [anon_sym_DASH] = ACTIONS(3537),
    [anon_sym_STAR] = ACTIONS(3539),
    [anon_sym_CARET] = ACTIONS(3539),
    [anon_sym_AMP] = ACTIONS(3539),
    [anon_sym_this] = ACTIONS(3537),
    [anon_sym_scoped] = ACTIONS(3537),
    [anon_sym_base] = ACTIONS(3537),
    [anon_sym_var] = ACTIONS(3537),
    [sym_predefined_type] = ACTIONS(3537),
    [anon_sym_break] = ACTIONS(3537),
    [anon_sym_unchecked] = ACTIONS(3537),
    [anon_sym_continue] = ACTIONS(3537),
    [anon_sym_do] = ACTIONS(3537),
    [anon_sym_while] = ACTIONS(3537),
    [anon_sym_for] = ACTIONS(3537),
    [anon_sym_lock] = ACTIONS(3537),
    [anon_sym_yield] = ACTIONS(3537),
    [anon_sym_switch] = ACTIONS(3537),
    [anon_sym_default] = ACTIONS(3537),
    [anon_sym_throw] = ACTIONS(3537),
    [anon_sym_try] = ACTIONS(3537),
    [anon_sym_when] = ACTIONS(3537),
    [anon_sym_await] = ACTIONS(3537),
    [anon_sym_foreach] = ACTIONS(3537),
    [anon_sym_goto] = ACTIONS(3537),
    [anon_sym_if] = ACTIONS(3537),
    [anon_sym_DOT_DOT] = ACTIONS(3539),
    [anon_sym_from] = ACTIONS(3537),
    [anon_sym_into] = ACTIONS(3537),
    [anon_sym_join] = ACTIONS(3537),
    [anon_sym_on] = ACTIONS(3537),
    [anon_sym_equals] = ACTIONS(3537),
    [anon_sym_let] = ACTIONS(3537),
    [anon_sym_orderby] = ACTIONS(3537),
    [anon_sym_ascending] = ACTIONS(3537),
    [anon_sym_descending] = ACTIONS(3537),
    [anon_sym_group] = ACTIONS(3537),
    [anon_sym_by] = ACTIONS(3537),
    [anon_sym_select] = ACTIONS(3537),
    [anon_sym_stackalloc] = ACTIONS(3537),
    [anon_sym_sizeof] = ACTIONS(3537),
    [anon_sym_typeof] = ACTIONS(3537),
    [anon_sym___makeref] = ACTIONS(3537),
    [anon_sym___reftype] = ACTIONS(3537),
    [anon_sym___refvalue] = ACTIONS(3537),
    [sym_null_literal] = ACTIONS(3537),
    [anon_sym_SQUOTE] = ACTIONS(3539),
    [sym_integer_literal] = ACTIONS(3537),
    [sym_real_literal] = ACTIONS(3539),
    [anon_sym_DQUOTE] = ACTIONS(3539),
    [sym_verbatim_string_literal] = ACTIONS(3539),
    [aux_sym_preproc_if_token1] = ACTIONS(3539),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3539),
    [sym_interpolation_verbatim_start] = ACTIONS(3539),
    [sym_interpolation_raw_start] = ACTIONS(3539),
    [sym_raw_string_start] = ACTIONS(3539),
  },
  [2562] = {
    [sym_preproc_region] = STATE(2562),
    [sym_preproc_endregion] = STATE(2562),
    [sym_preproc_line] = STATE(2562),
    [sym_preproc_pragma] = STATE(2562),
    [sym_preproc_nullable] = STATE(2562),
    [sym_preproc_error] = STATE(2562),
    [sym_preproc_warning] = STATE(2562),
    [sym_preproc_define] = STATE(2562),
    [sym_preproc_undef] = STATE(2562),
    [ts_builtin_sym_end] = ACTIONS(3543),
    [sym__identifier_token] = ACTIONS(3541),
    [anon_sym_extern] = ACTIONS(3541),
    [anon_sym_alias] = ACTIONS(3541),
    [anon_sym_SEMI] = ACTIONS(3543),
    [anon_sym_global] = ACTIONS(3541),
    [anon_sym_using] = ACTIONS(3541),
    [anon_sym_unsafe] = ACTIONS(3541),
    [anon_sym_static] = ACTIONS(3541),
    [anon_sym_LBRACK] = ACTIONS(3543),
    [anon_sym_LPAREN] = ACTIONS(3543),
    [anon_sym_return] = ACTIONS(3541),
    [anon_sym_namespace] = ACTIONS(3541),
    [anon_sym_class] = ACTIONS(3541),
    [anon_sym_ref] = ACTIONS(3541),
    [anon_sym_struct] = ACTIONS(3541),
    [anon_sym_enum] = ACTIONS(3541),
    [anon_sym_LBRACE] = ACTIONS(3543),
    [anon_sym_interface] = ACTIONS(3541),
    [anon_sym_delegate] = ACTIONS(3541),
    [anon_sym_record] = ACTIONS(3541),
    [anon_sym_abstract] = ACTIONS(3541),
    [anon_sym_async] = ACTIONS(3541),
    [anon_sym_const] = ACTIONS(3541),
    [anon_sym_file] = ACTIONS(3541),
    [anon_sym_fixed] = ACTIONS(3541),
    [anon_sym_internal] = ACTIONS(3541),
    [anon_sym_new] = ACTIONS(3541),
    [anon_sym_override] = ACTIONS(3541),
    [anon_sym_partial] = ACTIONS(3541),
    [anon_sym_private] = ACTIONS(3541),
    [anon_sym_protected] = ACTIONS(3541),
    [anon_sym_public] = ACTIONS(3541),
    [anon_sym_readonly] = ACTIONS(3541),
    [anon_sym_required] = ACTIONS(3541),
    [anon_sym_sealed] = ACTIONS(3541),
    [anon_sym_virtual] = ACTIONS(3541),
    [anon_sym_volatile] = ACTIONS(3541),
    [anon_sym_where] = ACTIONS(3541),
    [anon_sym_notnull] = ACTIONS(3541),
    [anon_sym_unmanaged] = ACTIONS(3541),
    [anon_sym_checked] = ACTIONS(3541),
    [anon_sym_BANG] = ACTIONS(3543),
    [anon_sym_TILDE] = ACTIONS(3543),
    [anon_sym_PLUS_PLUS] = ACTIONS(3543),
    [anon_sym_DASH_DASH] = ACTIONS(3543),
    [anon_sym_true] = ACTIONS(3541),
    [anon_sym_false] = ACTIONS(3541),
    [anon_sym_PLUS] = ACTIONS(3541),
    [anon_sym_DASH] = ACTIONS(3541),
    [anon_sym_STAR] = ACTIONS(3543),
    [anon_sym_CARET] = ACTIONS(3543),
    [anon_sym_AMP] = ACTIONS(3543),
    [anon_sym_this] = ACTIONS(3541),
    [anon_sym_scoped] = ACTIONS(3541),
    [anon_sym_base] = ACTIONS(3541),
    [anon_sym_var] = ACTIONS(3541),
    [sym_predefined_type] = ACTIONS(3541),
    [anon_sym_break] = ACTIONS(3541),
    [anon_sym_unchecked] = ACTIONS(3541),
    [anon_sym_continue] = ACTIONS(3541),
    [anon_sym_do] = ACTIONS(3541),
    [anon_sym_while] = ACTIONS(3541),
    [anon_sym_for] = ACTIONS(3541),
    [anon_sym_lock] = ACTIONS(3541),
    [anon_sym_yield] = ACTIONS(3541),
    [anon_sym_switch] = ACTIONS(3541),
    [anon_sym_default] = ACTIONS(3541),
    [anon_sym_throw] = ACTIONS(3541),
    [anon_sym_try] = ACTIONS(3541),
    [anon_sym_when] = ACTIONS(3541),
    [anon_sym_await] = ACTIONS(3541),
    [anon_sym_foreach] = ACTIONS(3541),
    [anon_sym_goto] = ACTIONS(3541),
    [anon_sym_if] = ACTIONS(3541),
    [anon_sym_DOT_DOT] = ACTIONS(3543),
    [anon_sym_from] = ACTIONS(3541),
    [anon_sym_into] = ACTIONS(3541),
    [anon_sym_join] = ACTIONS(3541),
    [anon_sym_on] = ACTIONS(3541),
    [anon_sym_equals] = ACTIONS(3541),
    [anon_sym_let] = ACTIONS(3541),
    [anon_sym_orderby] = ACTIONS(3541),
    [anon_sym_ascending] = ACTIONS(3541),
    [anon_sym_descending] = ACTIONS(3541),
    [anon_sym_group] = ACTIONS(3541),
    [anon_sym_by] = ACTIONS(3541),
    [anon_sym_select] = ACTIONS(3541),
    [anon_sym_stackalloc] = ACTIONS(3541),
    [anon_sym_sizeof] = ACTIONS(3541),
    [anon_sym_typeof] = ACTIONS(3541),
    [anon_sym___makeref] = ACTIONS(3541),
    [anon_sym___reftype] = ACTIONS(3541),
    [anon_sym___refvalue] = ACTIONS(3541),
    [sym_null_literal] = ACTIONS(3541),
    [anon_sym_SQUOTE] = ACTIONS(3543),
    [sym_integer_literal] = ACTIONS(3541),
    [sym_real_literal] = ACTIONS(3543),
    [anon_sym_DQUOTE] = ACTIONS(3543),
    [sym_verbatim_string_literal] = ACTIONS(3543),
    [aux_sym_preproc_if_token1] = ACTIONS(3543),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3543),
    [sym_interpolation_verbatim_start] = ACTIONS(3543),
    [sym_interpolation_raw_start] = ACTIONS(3543),
    [sym_raw_string_start] = ACTIONS(3543),
  },
  [2563] = {
    [sym_preproc_region] = STATE(2563),
    [sym_preproc_endregion] = STATE(2563),
    [sym_preproc_line] = STATE(2563),
    [sym_preproc_pragma] = STATE(2563),
    [sym_preproc_nullable] = STATE(2563),
    [sym_preproc_error] = STATE(2563),
    [sym_preproc_warning] = STATE(2563),
    [sym_preproc_define] = STATE(2563),
    [sym_preproc_undef] = STATE(2563),
    [ts_builtin_sym_end] = ACTIONS(3547),
    [sym__identifier_token] = ACTIONS(3545),
    [anon_sym_extern] = ACTIONS(3545),
    [anon_sym_alias] = ACTIONS(3545),
    [anon_sym_SEMI] = ACTIONS(3547),
    [anon_sym_global] = ACTIONS(3545),
    [anon_sym_using] = ACTIONS(3545),
    [anon_sym_unsafe] = ACTIONS(3545),
    [anon_sym_static] = ACTIONS(3545),
    [anon_sym_LBRACK] = ACTIONS(3547),
    [anon_sym_LPAREN] = ACTIONS(3547),
    [anon_sym_return] = ACTIONS(3545),
    [anon_sym_namespace] = ACTIONS(3545),
    [anon_sym_class] = ACTIONS(3545),
    [anon_sym_ref] = ACTIONS(3545),
    [anon_sym_struct] = ACTIONS(3545),
    [anon_sym_enum] = ACTIONS(3545),
    [anon_sym_LBRACE] = ACTIONS(3547),
    [anon_sym_interface] = ACTIONS(3545),
    [anon_sym_delegate] = ACTIONS(3545),
    [anon_sym_record] = ACTIONS(3545),
    [anon_sym_abstract] = ACTIONS(3545),
    [anon_sym_async] = ACTIONS(3545),
    [anon_sym_const] = ACTIONS(3545),
    [anon_sym_file] = ACTIONS(3545),
    [anon_sym_fixed] = ACTIONS(3545),
    [anon_sym_internal] = ACTIONS(3545),
    [anon_sym_new] = ACTIONS(3545),
    [anon_sym_override] = ACTIONS(3545),
    [anon_sym_partial] = ACTIONS(3545),
    [anon_sym_private] = ACTIONS(3545),
    [anon_sym_protected] = ACTIONS(3545),
    [anon_sym_public] = ACTIONS(3545),
    [anon_sym_readonly] = ACTIONS(3545),
    [anon_sym_required] = ACTIONS(3545),
    [anon_sym_sealed] = ACTIONS(3545),
    [anon_sym_virtual] = ACTIONS(3545),
    [anon_sym_volatile] = ACTIONS(3545),
    [anon_sym_where] = ACTIONS(3545),
    [anon_sym_notnull] = ACTIONS(3545),
    [anon_sym_unmanaged] = ACTIONS(3545),
    [anon_sym_checked] = ACTIONS(3545),
    [anon_sym_BANG] = ACTIONS(3547),
    [anon_sym_TILDE] = ACTIONS(3547),
    [anon_sym_PLUS_PLUS] = ACTIONS(3547),
    [anon_sym_DASH_DASH] = ACTIONS(3547),
    [anon_sym_true] = ACTIONS(3545),
    [anon_sym_false] = ACTIONS(3545),
    [anon_sym_PLUS] = ACTIONS(3545),
    [anon_sym_DASH] = ACTIONS(3545),
    [anon_sym_STAR] = ACTIONS(3547),
    [anon_sym_CARET] = ACTIONS(3547),
    [anon_sym_AMP] = ACTIONS(3547),
    [anon_sym_this] = ACTIONS(3545),
    [anon_sym_scoped] = ACTIONS(3545),
    [anon_sym_base] = ACTIONS(3545),
    [anon_sym_var] = ACTIONS(3545),
    [sym_predefined_type] = ACTIONS(3545),
    [anon_sym_break] = ACTIONS(3545),
    [anon_sym_unchecked] = ACTIONS(3545),
    [anon_sym_continue] = ACTIONS(3545),
    [anon_sym_do] = ACTIONS(3545),
    [anon_sym_while] = ACTIONS(3545),
    [anon_sym_for] = ACTIONS(3545),
    [anon_sym_lock] = ACTIONS(3545),
    [anon_sym_yield] = ACTIONS(3545),
    [anon_sym_switch] = ACTIONS(3545),
    [anon_sym_default] = ACTIONS(3545),
    [anon_sym_throw] = ACTIONS(3545),
    [anon_sym_try] = ACTIONS(3545),
    [anon_sym_when] = ACTIONS(3545),
    [anon_sym_await] = ACTIONS(3545),
    [anon_sym_foreach] = ACTIONS(3545),
    [anon_sym_goto] = ACTIONS(3545),
    [anon_sym_if] = ACTIONS(3545),
    [anon_sym_DOT_DOT] = ACTIONS(3547),
    [anon_sym_from] = ACTIONS(3545),
    [anon_sym_into] = ACTIONS(3545),
    [anon_sym_join] = ACTIONS(3545),
    [anon_sym_on] = ACTIONS(3545),
    [anon_sym_equals] = ACTIONS(3545),
    [anon_sym_let] = ACTIONS(3545),
    [anon_sym_orderby] = ACTIONS(3545),
    [anon_sym_ascending] = ACTIONS(3545),
    [anon_sym_descending] = ACTIONS(3545),
    [anon_sym_group] = ACTIONS(3545),
    [anon_sym_by] = ACTIONS(3545),
    [anon_sym_select] = ACTIONS(3545),
    [anon_sym_stackalloc] = ACTIONS(3545),
    [anon_sym_sizeof] = ACTIONS(3545),
    [anon_sym_typeof] = ACTIONS(3545),
    [anon_sym___makeref] = ACTIONS(3545),
    [anon_sym___reftype] = ACTIONS(3545),
    [anon_sym___refvalue] = ACTIONS(3545),
    [sym_null_literal] = ACTIONS(3545),
    [anon_sym_SQUOTE] = ACTIONS(3547),
    [sym_integer_literal] = ACTIONS(3545),
    [sym_real_literal] = ACTIONS(3547),
    [anon_sym_DQUOTE] = ACTIONS(3547),
    [sym_verbatim_string_literal] = ACTIONS(3547),
    [aux_sym_preproc_if_token1] = ACTIONS(3547),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3547),
    [sym_interpolation_verbatim_start] = ACTIONS(3547),
    [sym_interpolation_raw_start] = ACTIONS(3547),
    [sym_raw_string_start] = ACTIONS(3547),
  },
  [2564] = {
    [sym_preproc_region] = STATE(2564),
    [sym_preproc_endregion] = STATE(2564),
    [sym_preproc_line] = STATE(2564),
    [sym_preproc_pragma] = STATE(2564),
    [sym_preproc_nullable] = STATE(2564),
    [sym_preproc_error] = STATE(2564),
    [sym_preproc_warning] = STATE(2564),
    [sym_preproc_define] = STATE(2564),
    [sym_preproc_undef] = STATE(2564),
    [ts_builtin_sym_end] = ACTIONS(3663),
    [sym__identifier_token] = ACTIONS(3661),
    [anon_sym_extern] = ACTIONS(3661),
    [anon_sym_alias] = ACTIONS(3661),
    [anon_sym_SEMI] = ACTIONS(3663),
    [anon_sym_global] = ACTIONS(3661),
    [anon_sym_using] = ACTIONS(3661),
    [anon_sym_unsafe] = ACTIONS(3661),
    [anon_sym_static] = ACTIONS(3661),
    [anon_sym_LBRACK] = ACTIONS(3663),
    [anon_sym_LPAREN] = ACTIONS(3663),
    [anon_sym_return] = ACTIONS(3661),
    [anon_sym_namespace] = ACTIONS(3661),
    [anon_sym_class] = ACTIONS(3661),
    [anon_sym_ref] = ACTIONS(3661),
    [anon_sym_struct] = ACTIONS(3661),
    [anon_sym_enum] = ACTIONS(3661),
    [anon_sym_LBRACE] = ACTIONS(3663),
    [anon_sym_interface] = ACTIONS(3661),
    [anon_sym_delegate] = ACTIONS(3661),
    [anon_sym_record] = ACTIONS(3661),
    [anon_sym_abstract] = ACTIONS(3661),
    [anon_sym_async] = ACTIONS(3661),
    [anon_sym_const] = ACTIONS(3661),
    [anon_sym_file] = ACTIONS(3661),
    [anon_sym_fixed] = ACTIONS(3661),
    [anon_sym_internal] = ACTIONS(3661),
    [anon_sym_new] = ACTIONS(3661),
    [anon_sym_override] = ACTIONS(3661),
    [anon_sym_partial] = ACTIONS(3661),
    [anon_sym_private] = ACTIONS(3661),
    [anon_sym_protected] = ACTIONS(3661),
    [anon_sym_public] = ACTIONS(3661),
    [anon_sym_readonly] = ACTIONS(3661),
    [anon_sym_required] = ACTIONS(3661),
    [anon_sym_sealed] = ACTIONS(3661),
    [anon_sym_virtual] = ACTIONS(3661),
    [anon_sym_volatile] = ACTIONS(3661),
    [anon_sym_where] = ACTIONS(3661),
    [anon_sym_notnull] = ACTIONS(3661),
    [anon_sym_unmanaged] = ACTIONS(3661),
    [anon_sym_checked] = ACTIONS(3661),
    [anon_sym_BANG] = ACTIONS(3663),
    [anon_sym_TILDE] = ACTIONS(3663),
    [anon_sym_PLUS_PLUS] = ACTIONS(3663),
    [anon_sym_DASH_DASH] = ACTIONS(3663),
    [anon_sym_true] = ACTIONS(3661),
    [anon_sym_false] = ACTIONS(3661),
    [anon_sym_PLUS] = ACTIONS(3661),
    [anon_sym_DASH] = ACTIONS(3661),
    [anon_sym_STAR] = ACTIONS(3663),
    [anon_sym_CARET] = ACTIONS(3663),
    [anon_sym_AMP] = ACTIONS(3663),
    [anon_sym_this] = ACTIONS(3661),
    [anon_sym_scoped] = ACTIONS(3661),
    [anon_sym_base] = ACTIONS(3661),
    [anon_sym_var] = ACTIONS(3661),
    [sym_predefined_type] = ACTIONS(3661),
    [anon_sym_break] = ACTIONS(3661),
    [anon_sym_unchecked] = ACTIONS(3661),
    [anon_sym_continue] = ACTIONS(3661),
    [anon_sym_do] = ACTIONS(3661),
    [anon_sym_while] = ACTIONS(3661),
    [anon_sym_for] = ACTIONS(3661),
    [anon_sym_lock] = ACTIONS(3661),
    [anon_sym_yield] = ACTIONS(3661),
    [anon_sym_switch] = ACTIONS(3661),
    [anon_sym_default] = ACTIONS(3661),
    [anon_sym_throw] = ACTIONS(3661),
    [anon_sym_try] = ACTIONS(3661),
    [anon_sym_when] = ACTIONS(3661),
    [anon_sym_await] = ACTIONS(3661),
    [anon_sym_foreach] = ACTIONS(3661),
    [anon_sym_goto] = ACTIONS(3661),
    [anon_sym_if] = ACTIONS(3661),
    [anon_sym_DOT_DOT] = ACTIONS(3663),
    [anon_sym_from] = ACTIONS(3661),
    [anon_sym_into] = ACTIONS(3661),
    [anon_sym_join] = ACTIONS(3661),
    [anon_sym_on] = ACTIONS(3661),
    [anon_sym_equals] = ACTIONS(3661),
    [anon_sym_let] = ACTIONS(3661),
    [anon_sym_orderby] = ACTIONS(3661),
    [anon_sym_ascending] = ACTIONS(3661),
    [anon_sym_descending] = ACTIONS(3661),
    [anon_sym_group] = ACTIONS(3661),
    [anon_sym_by] = ACTIONS(3661),
    [anon_sym_select] = ACTIONS(3661),
    [anon_sym_stackalloc] = ACTIONS(3661),
    [anon_sym_sizeof] = ACTIONS(3661),
    [anon_sym_typeof] = ACTIONS(3661),
    [anon_sym___makeref] = ACTIONS(3661),
    [anon_sym___reftype] = ACTIONS(3661),
    [anon_sym___refvalue] = ACTIONS(3661),
    [sym_null_literal] = ACTIONS(3661),
    [anon_sym_SQUOTE] = ACTIONS(3663),
    [sym_integer_literal] = ACTIONS(3661),
    [sym_real_literal] = ACTIONS(3663),
    [anon_sym_DQUOTE] = ACTIONS(3663),
    [sym_verbatim_string_literal] = ACTIONS(3663),
    [aux_sym_preproc_if_token1] = ACTIONS(3663),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3663),
    [sym_interpolation_verbatim_start] = ACTIONS(3663),
    [sym_interpolation_raw_start] = ACTIONS(3663),
    [sym_raw_string_start] = ACTIONS(3663),
  },
  [2565] = {
    [sym_preproc_region] = STATE(2565),
    [sym_preproc_endregion] = STATE(2565),
    [sym_preproc_line] = STATE(2565),
    [sym_preproc_pragma] = STATE(2565),
    [sym_preproc_nullable] = STATE(2565),
    [sym_preproc_error] = STATE(2565),
    [sym_preproc_warning] = STATE(2565),
    [sym_preproc_define] = STATE(2565),
    [sym_preproc_undef] = STATE(2565),
    [ts_builtin_sym_end] = ACTIONS(3411),
    [sym__identifier_token] = ACTIONS(3409),
    [anon_sym_extern] = ACTIONS(3409),
    [anon_sym_alias] = ACTIONS(3409),
    [anon_sym_SEMI] = ACTIONS(3411),
    [anon_sym_global] = ACTIONS(3409),
    [anon_sym_using] = ACTIONS(3409),
    [anon_sym_unsafe] = ACTIONS(3409),
    [anon_sym_static] = ACTIONS(3409),
    [anon_sym_LBRACK] = ACTIONS(3411),
    [anon_sym_LPAREN] = ACTIONS(3411),
    [anon_sym_return] = ACTIONS(3409),
    [anon_sym_namespace] = ACTIONS(3409),
    [anon_sym_class] = ACTIONS(3409),
    [anon_sym_ref] = ACTIONS(3409),
    [anon_sym_struct] = ACTIONS(3409),
    [anon_sym_enum] = ACTIONS(3409),
    [anon_sym_LBRACE] = ACTIONS(3411),
    [anon_sym_interface] = ACTIONS(3409),
    [anon_sym_delegate] = ACTIONS(3409),
    [anon_sym_record] = ACTIONS(3409),
    [anon_sym_abstract] = ACTIONS(3409),
    [anon_sym_async] = ACTIONS(3409),
    [anon_sym_const] = ACTIONS(3409),
    [anon_sym_file] = ACTIONS(3409),
    [anon_sym_fixed] = ACTIONS(3409),
    [anon_sym_internal] = ACTIONS(3409),
    [anon_sym_new] = ACTIONS(3409),
    [anon_sym_override] = ACTIONS(3409),
    [anon_sym_partial] = ACTIONS(3409),
    [anon_sym_private] = ACTIONS(3409),
    [anon_sym_protected] = ACTIONS(3409),
    [anon_sym_public] = ACTIONS(3409),
    [anon_sym_readonly] = ACTIONS(3409),
    [anon_sym_required] = ACTIONS(3409),
    [anon_sym_sealed] = ACTIONS(3409),
    [anon_sym_virtual] = ACTIONS(3409),
    [anon_sym_volatile] = ACTIONS(3409),
    [anon_sym_where] = ACTIONS(3409),
    [anon_sym_notnull] = ACTIONS(3409),
    [anon_sym_unmanaged] = ACTIONS(3409),
    [anon_sym_checked] = ACTIONS(3409),
    [anon_sym_BANG] = ACTIONS(3411),
    [anon_sym_TILDE] = ACTIONS(3411),
    [anon_sym_PLUS_PLUS] = ACTIONS(3411),
    [anon_sym_DASH_DASH] = ACTIONS(3411),
    [anon_sym_true] = ACTIONS(3409),
    [anon_sym_false] = ACTIONS(3409),
    [anon_sym_PLUS] = ACTIONS(3409),
    [anon_sym_DASH] = ACTIONS(3409),
    [anon_sym_STAR] = ACTIONS(3411),
    [anon_sym_CARET] = ACTIONS(3411),
    [anon_sym_AMP] = ACTIONS(3411),
    [anon_sym_this] = ACTIONS(3409),
    [anon_sym_scoped] = ACTIONS(3409),
    [anon_sym_base] = ACTIONS(3409),
    [anon_sym_var] = ACTIONS(3409),
    [sym_predefined_type] = ACTIONS(3409),
    [anon_sym_break] = ACTIONS(3409),
    [anon_sym_unchecked] = ACTIONS(3409),
    [anon_sym_continue] = ACTIONS(3409),
    [anon_sym_do] = ACTIONS(3409),
    [anon_sym_while] = ACTIONS(3409),
    [anon_sym_for] = ACTIONS(3409),
    [anon_sym_lock] = ACTIONS(3409),
    [anon_sym_yield] = ACTIONS(3409),
    [anon_sym_switch] = ACTIONS(3409),
    [anon_sym_default] = ACTIONS(3409),
    [anon_sym_throw] = ACTIONS(3409),
    [anon_sym_try] = ACTIONS(3409),
    [anon_sym_when] = ACTIONS(3409),
    [anon_sym_await] = ACTIONS(3409),
    [anon_sym_foreach] = ACTIONS(3409),
    [anon_sym_goto] = ACTIONS(3409),
    [anon_sym_if] = ACTIONS(3409),
    [anon_sym_DOT_DOT] = ACTIONS(3411),
    [anon_sym_from] = ACTIONS(3409),
    [anon_sym_into] = ACTIONS(3409),
    [anon_sym_join] = ACTIONS(3409),
    [anon_sym_on] = ACTIONS(3409),
    [anon_sym_equals] = ACTIONS(3409),
    [anon_sym_let] = ACTIONS(3409),
    [anon_sym_orderby] = ACTIONS(3409),
    [anon_sym_ascending] = ACTIONS(3409),
    [anon_sym_descending] = ACTIONS(3409),
    [anon_sym_group] = ACTIONS(3409),
    [anon_sym_by] = ACTIONS(3409),
    [anon_sym_select] = ACTIONS(3409),
    [anon_sym_stackalloc] = ACTIONS(3409),
    [anon_sym_sizeof] = ACTIONS(3409),
    [anon_sym_typeof] = ACTIONS(3409),
    [anon_sym___makeref] = ACTIONS(3409),
    [anon_sym___reftype] = ACTIONS(3409),
    [anon_sym___refvalue] = ACTIONS(3409),
    [sym_null_literal] = ACTIONS(3409),
    [anon_sym_SQUOTE] = ACTIONS(3411),
    [sym_integer_literal] = ACTIONS(3409),
    [sym_real_literal] = ACTIONS(3411),
    [anon_sym_DQUOTE] = ACTIONS(3411),
    [sym_verbatim_string_literal] = ACTIONS(3411),
    [aux_sym_preproc_if_token1] = ACTIONS(3411),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3411),
    [sym_interpolation_verbatim_start] = ACTIONS(3411),
    [sym_interpolation_raw_start] = ACTIONS(3411),
    [sym_raw_string_start] = ACTIONS(3411),
  },
  [2566] = {
    [sym_preproc_region] = STATE(2566),
    [sym_preproc_endregion] = STATE(2566),
    [sym_preproc_line] = STATE(2566),
    [sym_preproc_pragma] = STATE(2566),
    [sym_preproc_nullable] = STATE(2566),
    [sym_preproc_error] = STATE(2566),
    [sym_preproc_warning] = STATE(2566),
    [sym_preproc_define] = STATE(2566),
    [sym_preproc_undef] = STATE(2566),
    [ts_builtin_sym_end] = ACTIONS(3495),
    [sym__identifier_token] = ACTIONS(3493),
    [anon_sym_extern] = ACTIONS(3493),
    [anon_sym_alias] = ACTIONS(3493),
    [anon_sym_SEMI] = ACTIONS(3495),
    [anon_sym_global] = ACTIONS(3493),
    [anon_sym_using] = ACTIONS(3493),
    [anon_sym_unsafe] = ACTIONS(3493),
    [anon_sym_static] = ACTIONS(3493),
    [anon_sym_LBRACK] = ACTIONS(3495),
    [anon_sym_LPAREN] = ACTIONS(3495),
    [anon_sym_return] = ACTIONS(3493),
    [anon_sym_namespace] = ACTIONS(3493),
    [anon_sym_class] = ACTIONS(3493),
    [anon_sym_ref] = ACTIONS(3493),
    [anon_sym_struct] = ACTIONS(3493),
    [anon_sym_enum] = ACTIONS(3493),
    [anon_sym_LBRACE] = ACTIONS(3495),
    [anon_sym_interface] = ACTIONS(3493),
    [anon_sym_delegate] = ACTIONS(3493),
    [anon_sym_record] = ACTIONS(3493),
    [anon_sym_abstract] = ACTIONS(3493),
    [anon_sym_async] = ACTIONS(3493),
    [anon_sym_const] = ACTIONS(3493),
    [anon_sym_file] = ACTIONS(3493),
    [anon_sym_fixed] = ACTIONS(3493),
    [anon_sym_internal] = ACTIONS(3493),
    [anon_sym_new] = ACTIONS(3493),
    [anon_sym_override] = ACTIONS(3493),
    [anon_sym_partial] = ACTIONS(3493),
    [anon_sym_private] = ACTIONS(3493),
    [anon_sym_protected] = ACTIONS(3493),
    [anon_sym_public] = ACTIONS(3493),
    [anon_sym_readonly] = ACTIONS(3493),
    [anon_sym_required] = ACTIONS(3493),
    [anon_sym_sealed] = ACTIONS(3493),
    [anon_sym_virtual] = ACTIONS(3493),
    [anon_sym_volatile] = ACTIONS(3493),
    [anon_sym_where] = ACTIONS(3493),
    [anon_sym_notnull] = ACTIONS(3493),
    [anon_sym_unmanaged] = ACTIONS(3493),
    [anon_sym_checked] = ACTIONS(3493),
    [anon_sym_BANG] = ACTIONS(3495),
    [anon_sym_TILDE] = ACTIONS(3495),
    [anon_sym_PLUS_PLUS] = ACTIONS(3495),
    [anon_sym_DASH_DASH] = ACTIONS(3495),
    [anon_sym_true] = ACTIONS(3493),
    [anon_sym_false] = ACTIONS(3493),
    [anon_sym_PLUS] = ACTIONS(3493),
    [anon_sym_DASH] = ACTIONS(3493),
    [anon_sym_STAR] = ACTIONS(3495),
    [anon_sym_CARET] = ACTIONS(3495),
    [anon_sym_AMP] = ACTIONS(3495),
    [anon_sym_this] = ACTIONS(3493),
    [anon_sym_scoped] = ACTIONS(3493),
    [anon_sym_base] = ACTIONS(3493),
    [anon_sym_var] = ACTIONS(3493),
    [sym_predefined_type] = ACTIONS(3493),
    [anon_sym_break] = ACTIONS(3493),
    [anon_sym_unchecked] = ACTIONS(3493),
    [anon_sym_continue] = ACTIONS(3493),
    [anon_sym_do] = ACTIONS(3493),
    [anon_sym_while] = ACTIONS(3493),
    [anon_sym_for] = ACTIONS(3493),
    [anon_sym_lock] = ACTIONS(3493),
    [anon_sym_yield] = ACTIONS(3493),
    [anon_sym_switch] = ACTIONS(3493),
    [anon_sym_default] = ACTIONS(3493),
    [anon_sym_throw] = ACTIONS(3493),
    [anon_sym_try] = ACTIONS(3493),
    [anon_sym_when] = ACTIONS(3493),
    [anon_sym_await] = ACTIONS(3493),
    [anon_sym_foreach] = ACTIONS(3493),
    [anon_sym_goto] = ACTIONS(3493),
    [anon_sym_if] = ACTIONS(3493),
    [anon_sym_DOT_DOT] = ACTIONS(3495),
    [anon_sym_from] = ACTIONS(3493),
    [anon_sym_into] = ACTIONS(3493),
    [anon_sym_join] = ACTIONS(3493),
    [anon_sym_on] = ACTIONS(3493),
    [anon_sym_equals] = ACTIONS(3493),
    [anon_sym_let] = ACTIONS(3493),
    [anon_sym_orderby] = ACTIONS(3493),
    [anon_sym_ascending] = ACTIONS(3493),
    [anon_sym_descending] = ACTIONS(3493),
    [anon_sym_group] = ACTIONS(3493),
    [anon_sym_by] = ACTIONS(3493),
    [anon_sym_select] = ACTIONS(3493),
    [anon_sym_stackalloc] = ACTIONS(3493),
    [anon_sym_sizeof] = ACTIONS(3493),
    [anon_sym_typeof] = ACTIONS(3493),
    [anon_sym___makeref] = ACTIONS(3493),
    [anon_sym___reftype] = ACTIONS(3493),
    [anon_sym___refvalue] = ACTIONS(3493),
    [sym_null_literal] = ACTIONS(3493),
    [anon_sym_SQUOTE] = ACTIONS(3495),
    [sym_integer_literal] = ACTIONS(3493),
    [sym_real_literal] = ACTIONS(3495),
    [anon_sym_DQUOTE] = ACTIONS(3495),
    [sym_verbatim_string_literal] = ACTIONS(3495),
    [aux_sym_preproc_if_token1] = ACTIONS(3495),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3495),
    [sym_interpolation_verbatim_start] = ACTIONS(3495),
    [sym_interpolation_raw_start] = ACTIONS(3495),
    [sym_raw_string_start] = ACTIONS(3495),
  },
  [2567] = {
    [sym_preproc_region] = STATE(2567),
    [sym_preproc_endregion] = STATE(2567),
    [sym_preproc_line] = STATE(2567),
    [sym_preproc_pragma] = STATE(2567),
    [sym_preproc_nullable] = STATE(2567),
    [sym_preproc_error] = STATE(2567),
    [sym_preproc_warning] = STATE(2567),
    [sym_preproc_define] = STATE(2567),
    [sym_preproc_undef] = STATE(2567),
    [ts_builtin_sym_end] = ACTIONS(3587),
    [sym__identifier_token] = ACTIONS(3585),
    [anon_sym_extern] = ACTIONS(3585),
    [anon_sym_alias] = ACTIONS(3585),
    [anon_sym_SEMI] = ACTIONS(3587),
    [anon_sym_global] = ACTIONS(3585),
    [anon_sym_using] = ACTIONS(3585),
    [anon_sym_unsafe] = ACTIONS(3585),
    [anon_sym_static] = ACTIONS(3585),
    [anon_sym_LBRACK] = ACTIONS(3587),
    [anon_sym_LPAREN] = ACTIONS(3587),
    [anon_sym_return] = ACTIONS(3585),
    [anon_sym_namespace] = ACTIONS(3585),
    [anon_sym_class] = ACTIONS(3585),
    [anon_sym_ref] = ACTIONS(3585),
    [anon_sym_struct] = ACTIONS(3585),
    [anon_sym_enum] = ACTIONS(3585),
    [anon_sym_LBRACE] = ACTIONS(3587),
    [anon_sym_interface] = ACTIONS(3585),
    [anon_sym_delegate] = ACTIONS(3585),
    [anon_sym_record] = ACTIONS(3585),
    [anon_sym_abstract] = ACTIONS(3585),
    [anon_sym_async] = ACTIONS(3585),
    [anon_sym_const] = ACTIONS(3585),
    [anon_sym_file] = ACTIONS(3585),
    [anon_sym_fixed] = ACTIONS(3585),
    [anon_sym_internal] = ACTIONS(3585),
    [anon_sym_new] = ACTIONS(3585),
    [anon_sym_override] = ACTIONS(3585),
    [anon_sym_partial] = ACTIONS(3585),
    [anon_sym_private] = ACTIONS(3585),
    [anon_sym_protected] = ACTIONS(3585),
    [anon_sym_public] = ACTIONS(3585),
    [anon_sym_readonly] = ACTIONS(3585),
    [anon_sym_required] = ACTIONS(3585),
    [anon_sym_sealed] = ACTIONS(3585),
    [anon_sym_virtual] = ACTIONS(3585),
    [anon_sym_volatile] = ACTIONS(3585),
    [anon_sym_where] = ACTIONS(3585),
    [anon_sym_notnull] = ACTIONS(3585),
    [anon_sym_unmanaged] = ACTIONS(3585),
    [anon_sym_checked] = ACTIONS(3585),
    [anon_sym_BANG] = ACTIONS(3587),
    [anon_sym_TILDE] = ACTIONS(3587),
    [anon_sym_PLUS_PLUS] = ACTIONS(3587),
    [anon_sym_DASH_DASH] = ACTIONS(3587),
    [anon_sym_true] = ACTIONS(3585),
    [anon_sym_false] = ACTIONS(3585),
    [anon_sym_PLUS] = ACTIONS(3585),
    [anon_sym_DASH] = ACTIONS(3585),
    [anon_sym_STAR] = ACTIONS(3587),
    [anon_sym_CARET] = ACTIONS(3587),
    [anon_sym_AMP] = ACTIONS(3587),
    [anon_sym_this] = ACTIONS(3585),
    [anon_sym_scoped] = ACTIONS(3585),
    [anon_sym_base] = ACTIONS(3585),
    [anon_sym_var] = ACTIONS(3585),
    [sym_predefined_type] = ACTIONS(3585),
    [anon_sym_break] = ACTIONS(3585),
    [anon_sym_unchecked] = ACTIONS(3585),
    [anon_sym_continue] = ACTIONS(3585),
    [anon_sym_do] = ACTIONS(3585),
    [anon_sym_while] = ACTIONS(3585),
    [anon_sym_for] = ACTIONS(3585),
    [anon_sym_lock] = ACTIONS(3585),
    [anon_sym_yield] = ACTIONS(3585),
    [anon_sym_switch] = ACTIONS(3585),
    [anon_sym_default] = ACTIONS(3585),
    [anon_sym_throw] = ACTIONS(3585),
    [anon_sym_try] = ACTIONS(3585),
    [anon_sym_when] = ACTIONS(3585),
    [anon_sym_await] = ACTIONS(3585),
    [anon_sym_foreach] = ACTIONS(3585),
    [anon_sym_goto] = ACTIONS(3585),
    [anon_sym_if] = ACTIONS(3585),
    [anon_sym_DOT_DOT] = ACTIONS(3587),
    [anon_sym_from] = ACTIONS(3585),
    [anon_sym_into] = ACTIONS(3585),
    [anon_sym_join] = ACTIONS(3585),
    [anon_sym_on] = ACTIONS(3585),
    [anon_sym_equals] = ACTIONS(3585),
    [anon_sym_let] = ACTIONS(3585),
    [anon_sym_orderby] = ACTIONS(3585),
    [anon_sym_ascending] = ACTIONS(3585),
    [anon_sym_descending] = ACTIONS(3585),
    [anon_sym_group] = ACTIONS(3585),
    [anon_sym_by] = ACTIONS(3585),
    [anon_sym_select] = ACTIONS(3585),
    [anon_sym_stackalloc] = ACTIONS(3585),
    [anon_sym_sizeof] = ACTIONS(3585),
    [anon_sym_typeof] = ACTIONS(3585),
    [anon_sym___makeref] = ACTIONS(3585),
    [anon_sym___reftype] = ACTIONS(3585),
    [anon_sym___refvalue] = ACTIONS(3585),
    [sym_null_literal] = ACTIONS(3585),
    [anon_sym_SQUOTE] = ACTIONS(3587),
    [sym_integer_literal] = ACTIONS(3585),
    [sym_real_literal] = ACTIONS(3587),
    [anon_sym_DQUOTE] = ACTIONS(3587),
    [sym_verbatim_string_literal] = ACTIONS(3587),
    [aux_sym_preproc_if_token1] = ACTIONS(3587),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3587),
    [sym_interpolation_verbatim_start] = ACTIONS(3587),
    [sym_interpolation_raw_start] = ACTIONS(3587),
    [sym_raw_string_start] = ACTIONS(3587),
  },
  [2568] = {
    [sym_preproc_region] = STATE(2568),
    [sym_preproc_endregion] = STATE(2568),
    [sym_preproc_line] = STATE(2568),
    [sym_preproc_pragma] = STATE(2568),
    [sym_preproc_nullable] = STATE(2568),
    [sym_preproc_error] = STATE(2568),
    [sym_preproc_warning] = STATE(2568),
    [sym_preproc_define] = STATE(2568),
    [sym_preproc_undef] = STATE(2568),
    [ts_builtin_sym_end] = ACTIONS(3591),
    [sym__identifier_token] = ACTIONS(3589),
    [anon_sym_extern] = ACTIONS(3589),
    [anon_sym_alias] = ACTIONS(3589),
    [anon_sym_SEMI] = ACTIONS(3591),
    [anon_sym_global] = ACTIONS(3589),
    [anon_sym_using] = ACTIONS(3589),
    [anon_sym_unsafe] = ACTIONS(3589),
    [anon_sym_static] = ACTIONS(3589),
    [anon_sym_LBRACK] = ACTIONS(3591),
    [anon_sym_LPAREN] = ACTIONS(3591),
    [anon_sym_return] = ACTIONS(3589),
    [anon_sym_namespace] = ACTIONS(3589),
    [anon_sym_class] = ACTIONS(3589),
    [anon_sym_ref] = ACTIONS(3589),
    [anon_sym_struct] = ACTIONS(3589),
    [anon_sym_enum] = ACTIONS(3589),
    [anon_sym_LBRACE] = ACTIONS(3591),
    [anon_sym_interface] = ACTIONS(3589),
    [anon_sym_delegate] = ACTIONS(3589),
    [anon_sym_record] = ACTIONS(3589),
    [anon_sym_abstract] = ACTIONS(3589),
    [anon_sym_async] = ACTIONS(3589),
    [anon_sym_const] = ACTIONS(3589),
    [anon_sym_file] = ACTIONS(3589),
    [anon_sym_fixed] = ACTIONS(3589),
    [anon_sym_internal] = ACTIONS(3589),
    [anon_sym_new] = ACTIONS(3589),
    [anon_sym_override] = ACTIONS(3589),
    [anon_sym_partial] = ACTIONS(3589),
    [anon_sym_private] = ACTIONS(3589),
    [anon_sym_protected] = ACTIONS(3589),
    [anon_sym_public] = ACTIONS(3589),
    [anon_sym_readonly] = ACTIONS(3589),
    [anon_sym_required] = ACTIONS(3589),
    [anon_sym_sealed] = ACTIONS(3589),
    [anon_sym_virtual] = ACTIONS(3589),
    [anon_sym_volatile] = ACTIONS(3589),
    [anon_sym_where] = ACTIONS(3589),
    [anon_sym_notnull] = ACTIONS(3589),
    [anon_sym_unmanaged] = ACTIONS(3589),
    [anon_sym_checked] = ACTIONS(3589),
    [anon_sym_BANG] = ACTIONS(3591),
    [anon_sym_TILDE] = ACTIONS(3591),
    [anon_sym_PLUS_PLUS] = ACTIONS(3591),
    [anon_sym_DASH_DASH] = ACTIONS(3591),
    [anon_sym_true] = ACTIONS(3589),
    [anon_sym_false] = ACTIONS(3589),
    [anon_sym_PLUS] = ACTIONS(3589),
    [anon_sym_DASH] = ACTIONS(3589),
    [anon_sym_STAR] = ACTIONS(3591),
    [anon_sym_CARET] = ACTIONS(3591),
    [anon_sym_AMP] = ACTIONS(3591),
    [anon_sym_this] = ACTIONS(3589),
    [anon_sym_scoped] = ACTIONS(3589),
    [anon_sym_base] = ACTIONS(3589),
    [anon_sym_var] = ACTIONS(3589),
    [sym_predefined_type] = ACTIONS(3589),
    [anon_sym_break] = ACTIONS(3589),
    [anon_sym_unchecked] = ACTIONS(3589),
    [anon_sym_continue] = ACTIONS(3589),
    [anon_sym_do] = ACTIONS(3589),
    [anon_sym_while] = ACTIONS(3589),
    [anon_sym_for] = ACTIONS(3589),
    [anon_sym_lock] = ACTIONS(3589),
    [anon_sym_yield] = ACTIONS(3589),
    [anon_sym_switch] = ACTIONS(3589),
    [anon_sym_default] = ACTIONS(3589),
    [anon_sym_throw] = ACTIONS(3589),
    [anon_sym_try] = ACTIONS(3589),
    [anon_sym_when] = ACTIONS(3589),
    [anon_sym_await] = ACTIONS(3589),
    [anon_sym_foreach] = ACTIONS(3589),
    [anon_sym_goto] = ACTIONS(3589),
    [anon_sym_if] = ACTIONS(3589),
    [anon_sym_DOT_DOT] = ACTIONS(3591),
    [anon_sym_from] = ACTIONS(3589),
    [anon_sym_into] = ACTIONS(3589),
    [anon_sym_join] = ACTIONS(3589),
    [anon_sym_on] = ACTIONS(3589),
    [anon_sym_equals] = ACTIONS(3589),
    [anon_sym_let] = ACTIONS(3589),
    [anon_sym_orderby] = ACTIONS(3589),
    [anon_sym_ascending] = ACTIONS(3589),
    [anon_sym_descending] = ACTIONS(3589),
    [anon_sym_group] = ACTIONS(3589),
    [anon_sym_by] = ACTIONS(3589),
    [anon_sym_select] = ACTIONS(3589),
    [anon_sym_stackalloc] = ACTIONS(3589),
    [anon_sym_sizeof] = ACTIONS(3589),
    [anon_sym_typeof] = ACTIONS(3589),
    [anon_sym___makeref] = ACTIONS(3589),
    [anon_sym___reftype] = ACTIONS(3589),
    [anon_sym___refvalue] = ACTIONS(3589),
    [sym_null_literal] = ACTIONS(3589),
    [anon_sym_SQUOTE] = ACTIONS(3591),
    [sym_integer_literal] = ACTIONS(3589),
    [sym_real_literal] = ACTIONS(3591),
    [anon_sym_DQUOTE] = ACTIONS(3591),
    [sym_verbatim_string_literal] = ACTIONS(3591),
    [aux_sym_preproc_if_token1] = ACTIONS(3591),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3591),
    [sym_interpolation_verbatim_start] = ACTIONS(3591),
    [sym_interpolation_raw_start] = ACTIONS(3591),
    [sym_raw_string_start] = ACTIONS(3591),
  },
  [2569] = {
    [sym_preproc_region] = STATE(2569),
    [sym_preproc_endregion] = STATE(2569),
    [sym_preproc_line] = STATE(2569),
    [sym_preproc_pragma] = STATE(2569),
    [sym_preproc_nullable] = STATE(2569),
    [sym_preproc_error] = STATE(2569),
    [sym_preproc_warning] = STATE(2569),
    [sym_preproc_define] = STATE(2569),
    [sym_preproc_undef] = STATE(2569),
    [ts_builtin_sym_end] = ACTIONS(3595),
    [sym__identifier_token] = ACTIONS(3593),
    [anon_sym_extern] = ACTIONS(3593),
    [anon_sym_alias] = ACTIONS(3593),
    [anon_sym_SEMI] = ACTIONS(3595),
    [anon_sym_global] = ACTIONS(3593),
    [anon_sym_using] = ACTIONS(3593),
    [anon_sym_unsafe] = ACTIONS(3593),
    [anon_sym_static] = ACTIONS(3593),
    [anon_sym_LBRACK] = ACTIONS(3595),
    [anon_sym_LPAREN] = ACTIONS(3595),
    [anon_sym_return] = ACTIONS(3593),
    [anon_sym_namespace] = ACTIONS(3593),
    [anon_sym_class] = ACTIONS(3593),
    [anon_sym_ref] = ACTIONS(3593),
    [anon_sym_struct] = ACTIONS(3593),
    [anon_sym_enum] = ACTIONS(3593),
    [anon_sym_LBRACE] = ACTIONS(3595),
    [anon_sym_interface] = ACTIONS(3593),
    [anon_sym_delegate] = ACTIONS(3593),
    [anon_sym_record] = ACTIONS(3593),
    [anon_sym_abstract] = ACTIONS(3593),
    [anon_sym_async] = ACTIONS(3593),
    [anon_sym_const] = ACTIONS(3593),
    [anon_sym_file] = ACTIONS(3593),
    [anon_sym_fixed] = ACTIONS(3593),
    [anon_sym_internal] = ACTIONS(3593),
    [anon_sym_new] = ACTIONS(3593),
    [anon_sym_override] = ACTIONS(3593),
    [anon_sym_partial] = ACTIONS(3593),
    [anon_sym_private] = ACTIONS(3593),
    [anon_sym_protected] = ACTIONS(3593),
    [anon_sym_public] = ACTIONS(3593),
    [anon_sym_readonly] = ACTIONS(3593),
    [anon_sym_required] = ACTIONS(3593),
    [anon_sym_sealed] = ACTIONS(3593),
    [anon_sym_virtual] = ACTIONS(3593),
    [anon_sym_volatile] = ACTIONS(3593),
    [anon_sym_where] = ACTIONS(3593),
    [anon_sym_notnull] = ACTIONS(3593),
    [anon_sym_unmanaged] = ACTIONS(3593),
    [anon_sym_checked] = ACTIONS(3593),
    [anon_sym_BANG] = ACTIONS(3595),
    [anon_sym_TILDE] = ACTIONS(3595),
    [anon_sym_PLUS_PLUS] = ACTIONS(3595),
    [anon_sym_DASH_DASH] = ACTIONS(3595),
    [anon_sym_true] = ACTIONS(3593),
    [anon_sym_false] = ACTIONS(3593),
    [anon_sym_PLUS] = ACTIONS(3593),
    [anon_sym_DASH] = ACTIONS(3593),
    [anon_sym_STAR] = ACTIONS(3595),
    [anon_sym_CARET] = ACTIONS(3595),
    [anon_sym_AMP] = ACTIONS(3595),
    [anon_sym_this] = ACTIONS(3593),
    [anon_sym_scoped] = ACTIONS(3593),
    [anon_sym_base] = ACTIONS(3593),
    [anon_sym_var] = ACTIONS(3593),
    [sym_predefined_type] = ACTIONS(3593),
    [anon_sym_break] = ACTIONS(3593),
    [anon_sym_unchecked] = ACTIONS(3593),
    [anon_sym_continue] = ACTIONS(3593),
    [anon_sym_do] = ACTIONS(3593),
    [anon_sym_while] = ACTIONS(3593),
    [anon_sym_for] = ACTIONS(3593),
    [anon_sym_lock] = ACTIONS(3593),
    [anon_sym_yield] = ACTIONS(3593),
    [anon_sym_switch] = ACTIONS(3593),
    [anon_sym_default] = ACTIONS(3593),
    [anon_sym_throw] = ACTIONS(3593),
    [anon_sym_try] = ACTIONS(3593),
    [anon_sym_when] = ACTIONS(3593),
    [anon_sym_await] = ACTIONS(3593),
    [anon_sym_foreach] = ACTIONS(3593),
    [anon_sym_goto] = ACTIONS(3593),
    [anon_sym_if] = ACTIONS(3593),
    [anon_sym_DOT_DOT] = ACTIONS(3595),
    [anon_sym_from] = ACTIONS(3593),
    [anon_sym_into] = ACTIONS(3593),
    [anon_sym_join] = ACTIONS(3593),
    [anon_sym_on] = ACTIONS(3593),
    [anon_sym_equals] = ACTIONS(3593),
    [anon_sym_let] = ACTIONS(3593),
    [anon_sym_orderby] = ACTIONS(3593),
    [anon_sym_ascending] = ACTIONS(3593),
    [anon_sym_descending] = ACTIONS(3593),
    [anon_sym_group] = ACTIONS(3593),
    [anon_sym_by] = ACTIONS(3593),
    [anon_sym_select] = ACTIONS(3593),
    [anon_sym_stackalloc] = ACTIONS(3593),
    [anon_sym_sizeof] = ACTIONS(3593),
    [anon_sym_typeof] = ACTIONS(3593),
    [anon_sym___makeref] = ACTIONS(3593),
    [anon_sym___reftype] = ACTIONS(3593),
    [anon_sym___refvalue] = ACTIONS(3593),
    [sym_null_literal] = ACTIONS(3593),
    [anon_sym_SQUOTE] = ACTIONS(3595),
    [sym_integer_literal] = ACTIONS(3593),
    [sym_real_literal] = ACTIONS(3595),
    [anon_sym_DQUOTE] = ACTIONS(3595),
    [sym_verbatim_string_literal] = ACTIONS(3595),
    [aux_sym_preproc_if_token1] = ACTIONS(3595),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3595),
    [sym_interpolation_verbatim_start] = ACTIONS(3595),
    [sym_interpolation_raw_start] = ACTIONS(3595),
    [sym_raw_string_start] = ACTIONS(3595),
  },
  [2570] = {
    [sym_preproc_region] = STATE(2570),
    [sym_preproc_endregion] = STATE(2570),
    [sym_preproc_line] = STATE(2570),
    [sym_preproc_pragma] = STATE(2570),
    [sym_preproc_nullable] = STATE(2570),
    [sym_preproc_error] = STATE(2570),
    [sym_preproc_warning] = STATE(2570),
    [sym_preproc_define] = STATE(2570),
    [sym_preproc_undef] = STATE(2570),
    [ts_builtin_sym_end] = ACTIONS(3599),
    [sym__identifier_token] = ACTIONS(3597),
    [anon_sym_extern] = ACTIONS(3597),
    [anon_sym_alias] = ACTIONS(3597),
    [anon_sym_SEMI] = ACTIONS(3599),
    [anon_sym_global] = ACTIONS(3597),
    [anon_sym_using] = ACTIONS(3597),
    [anon_sym_unsafe] = ACTIONS(3597),
    [anon_sym_static] = ACTIONS(3597),
    [anon_sym_LBRACK] = ACTIONS(3599),
    [anon_sym_LPAREN] = ACTIONS(3599),
    [anon_sym_return] = ACTIONS(3597),
    [anon_sym_namespace] = ACTIONS(3597),
    [anon_sym_class] = ACTIONS(3597),
    [anon_sym_ref] = ACTIONS(3597),
    [anon_sym_struct] = ACTIONS(3597),
    [anon_sym_enum] = ACTIONS(3597),
    [anon_sym_LBRACE] = ACTIONS(3599),
    [anon_sym_interface] = ACTIONS(3597),
    [anon_sym_delegate] = ACTIONS(3597),
    [anon_sym_record] = ACTIONS(3597),
    [anon_sym_abstract] = ACTIONS(3597),
    [anon_sym_async] = ACTIONS(3597),
    [anon_sym_const] = ACTIONS(3597),
    [anon_sym_file] = ACTIONS(3597),
    [anon_sym_fixed] = ACTIONS(3597),
    [anon_sym_internal] = ACTIONS(3597),
    [anon_sym_new] = ACTIONS(3597),
    [anon_sym_override] = ACTIONS(3597),
    [anon_sym_partial] = ACTIONS(3597),
    [anon_sym_private] = ACTIONS(3597),
    [anon_sym_protected] = ACTIONS(3597),
    [anon_sym_public] = ACTIONS(3597),
    [anon_sym_readonly] = ACTIONS(3597),
    [anon_sym_required] = ACTIONS(3597),
    [anon_sym_sealed] = ACTIONS(3597),
    [anon_sym_virtual] = ACTIONS(3597),
    [anon_sym_volatile] = ACTIONS(3597),
    [anon_sym_where] = ACTIONS(3597),
    [anon_sym_notnull] = ACTIONS(3597),
    [anon_sym_unmanaged] = ACTIONS(3597),
    [anon_sym_checked] = ACTIONS(3597),
    [anon_sym_BANG] = ACTIONS(3599),
    [anon_sym_TILDE] = ACTIONS(3599),
    [anon_sym_PLUS_PLUS] = ACTIONS(3599),
    [anon_sym_DASH_DASH] = ACTIONS(3599),
    [anon_sym_true] = ACTIONS(3597),
    [anon_sym_false] = ACTIONS(3597),
    [anon_sym_PLUS] = ACTIONS(3597),
    [anon_sym_DASH] = ACTIONS(3597),
    [anon_sym_STAR] = ACTIONS(3599),
    [anon_sym_CARET] = ACTIONS(3599),
    [anon_sym_AMP] = ACTIONS(3599),
    [anon_sym_this] = ACTIONS(3597),
    [anon_sym_scoped] = ACTIONS(3597),
    [anon_sym_base] = ACTIONS(3597),
    [anon_sym_var] = ACTIONS(3597),
    [sym_predefined_type] = ACTIONS(3597),
    [anon_sym_break] = ACTIONS(3597),
    [anon_sym_unchecked] = ACTIONS(3597),
    [anon_sym_continue] = ACTIONS(3597),
    [anon_sym_do] = ACTIONS(3597),
    [anon_sym_while] = ACTIONS(3597),
    [anon_sym_for] = ACTIONS(3597),
    [anon_sym_lock] = ACTIONS(3597),
    [anon_sym_yield] = ACTIONS(3597),
    [anon_sym_switch] = ACTIONS(3597),
    [anon_sym_default] = ACTIONS(3597),
    [anon_sym_throw] = ACTIONS(3597),
    [anon_sym_try] = ACTIONS(3597),
    [anon_sym_when] = ACTIONS(3597),
    [anon_sym_await] = ACTIONS(3597),
    [anon_sym_foreach] = ACTIONS(3597),
    [anon_sym_goto] = ACTIONS(3597),
    [anon_sym_if] = ACTIONS(3597),
    [anon_sym_DOT_DOT] = ACTIONS(3599),
    [anon_sym_from] = ACTIONS(3597),
    [anon_sym_into] = ACTIONS(3597),
    [anon_sym_join] = ACTIONS(3597),
    [anon_sym_on] = ACTIONS(3597),
    [anon_sym_equals] = ACTIONS(3597),
    [anon_sym_let] = ACTIONS(3597),
    [anon_sym_orderby] = ACTIONS(3597),
    [anon_sym_ascending] = ACTIONS(3597),
    [anon_sym_descending] = ACTIONS(3597),
    [anon_sym_group] = ACTIONS(3597),
    [anon_sym_by] = ACTIONS(3597),
    [anon_sym_select] = ACTIONS(3597),
    [anon_sym_stackalloc] = ACTIONS(3597),
    [anon_sym_sizeof] = ACTIONS(3597),
    [anon_sym_typeof] = ACTIONS(3597),
    [anon_sym___makeref] = ACTIONS(3597),
    [anon_sym___reftype] = ACTIONS(3597),
    [anon_sym___refvalue] = ACTIONS(3597),
    [sym_null_literal] = ACTIONS(3597),
    [anon_sym_SQUOTE] = ACTIONS(3599),
    [sym_integer_literal] = ACTIONS(3597),
    [sym_real_literal] = ACTIONS(3599),
    [anon_sym_DQUOTE] = ACTIONS(3599),
    [sym_verbatim_string_literal] = ACTIONS(3599),
    [aux_sym_preproc_if_token1] = ACTIONS(3599),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3599),
    [sym_interpolation_verbatim_start] = ACTIONS(3599),
    [sym_interpolation_raw_start] = ACTIONS(3599),
    [sym_raw_string_start] = ACTIONS(3599),
  },
  [2571] = {
    [sym_preproc_region] = STATE(2571),
    [sym_preproc_endregion] = STATE(2571),
    [sym_preproc_line] = STATE(2571),
    [sym_preproc_pragma] = STATE(2571),
    [sym_preproc_nullable] = STATE(2571),
    [sym_preproc_error] = STATE(2571),
    [sym_preproc_warning] = STATE(2571),
    [sym_preproc_define] = STATE(2571),
    [sym_preproc_undef] = STATE(2571),
    [ts_builtin_sym_end] = ACTIONS(3603),
    [sym__identifier_token] = ACTIONS(3601),
    [anon_sym_extern] = ACTIONS(3601),
    [anon_sym_alias] = ACTIONS(3601),
    [anon_sym_SEMI] = ACTIONS(3603),
    [anon_sym_global] = ACTIONS(3601),
    [anon_sym_using] = ACTIONS(3601),
    [anon_sym_unsafe] = ACTIONS(3601),
    [anon_sym_static] = ACTIONS(3601),
    [anon_sym_LBRACK] = ACTIONS(3603),
    [anon_sym_LPAREN] = ACTIONS(3603),
    [anon_sym_return] = ACTIONS(3601),
    [anon_sym_namespace] = ACTIONS(3601),
    [anon_sym_class] = ACTIONS(3601),
    [anon_sym_ref] = ACTIONS(3601),
    [anon_sym_struct] = ACTIONS(3601),
    [anon_sym_enum] = ACTIONS(3601),
    [anon_sym_LBRACE] = ACTIONS(3603),
    [anon_sym_interface] = ACTIONS(3601),
    [anon_sym_delegate] = ACTIONS(3601),
    [anon_sym_record] = ACTIONS(3601),
    [anon_sym_abstract] = ACTIONS(3601),
    [anon_sym_async] = ACTIONS(3601),
    [anon_sym_const] = ACTIONS(3601),
    [anon_sym_file] = ACTIONS(3601),
    [anon_sym_fixed] = ACTIONS(3601),
    [anon_sym_internal] = ACTIONS(3601),
    [anon_sym_new] = ACTIONS(3601),
    [anon_sym_override] = ACTIONS(3601),
    [anon_sym_partial] = ACTIONS(3601),
    [anon_sym_private] = ACTIONS(3601),
    [anon_sym_protected] = ACTIONS(3601),
    [anon_sym_public] = ACTIONS(3601),
    [anon_sym_readonly] = ACTIONS(3601),
    [anon_sym_required] = ACTIONS(3601),
    [anon_sym_sealed] = ACTIONS(3601),
    [anon_sym_virtual] = ACTIONS(3601),
    [anon_sym_volatile] = ACTIONS(3601),
    [anon_sym_where] = ACTIONS(3601),
    [anon_sym_notnull] = ACTIONS(3601),
    [anon_sym_unmanaged] = ACTIONS(3601),
    [anon_sym_checked] = ACTIONS(3601),
    [anon_sym_BANG] = ACTIONS(3603),
    [anon_sym_TILDE] = ACTIONS(3603),
    [anon_sym_PLUS_PLUS] = ACTIONS(3603),
    [anon_sym_DASH_DASH] = ACTIONS(3603),
    [anon_sym_true] = ACTIONS(3601),
    [anon_sym_false] = ACTIONS(3601),
    [anon_sym_PLUS] = ACTIONS(3601),
    [anon_sym_DASH] = ACTIONS(3601),
    [anon_sym_STAR] = ACTIONS(3603),
    [anon_sym_CARET] = ACTIONS(3603),
    [anon_sym_AMP] = ACTIONS(3603),
    [anon_sym_this] = ACTIONS(3601),
    [anon_sym_scoped] = ACTIONS(3601),
    [anon_sym_base] = ACTIONS(3601),
    [anon_sym_var] = ACTIONS(3601),
    [sym_predefined_type] = ACTIONS(3601),
    [anon_sym_break] = ACTIONS(3601),
    [anon_sym_unchecked] = ACTIONS(3601),
    [anon_sym_continue] = ACTIONS(3601),
    [anon_sym_do] = ACTIONS(3601),
    [anon_sym_while] = ACTIONS(3601),
    [anon_sym_for] = ACTIONS(3601),
    [anon_sym_lock] = ACTIONS(3601),
    [anon_sym_yield] = ACTIONS(3601),
    [anon_sym_switch] = ACTIONS(3601),
    [anon_sym_default] = ACTIONS(3601),
    [anon_sym_throw] = ACTIONS(3601),
    [anon_sym_try] = ACTIONS(3601),
    [anon_sym_when] = ACTIONS(3601),
    [anon_sym_await] = ACTIONS(3601),
    [anon_sym_foreach] = ACTIONS(3601),
    [anon_sym_goto] = ACTIONS(3601),
    [anon_sym_if] = ACTIONS(3601),
    [anon_sym_DOT_DOT] = ACTIONS(3603),
    [anon_sym_from] = ACTIONS(3601),
    [anon_sym_into] = ACTIONS(3601),
    [anon_sym_join] = ACTIONS(3601),
    [anon_sym_on] = ACTIONS(3601),
    [anon_sym_equals] = ACTIONS(3601),
    [anon_sym_let] = ACTIONS(3601),
    [anon_sym_orderby] = ACTIONS(3601),
    [anon_sym_ascending] = ACTIONS(3601),
    [anon_sym_descending] = ACTIONS(3601),
    [anon_sym_group] = ACTIONS(3601),
    [anon_sym_by] = ACTIONS(3601),
    [anon_sym_select] = ACTIONS(3601),
    [anon_sym_stackalloc] = ACTIONS(3601),
    [anon_sym_sizeof] = ACTIONS(3601),
    [anon_sym_typeof] = ACTIONS(3601),
    [anon_sym___makeref] = ACTIONS(3601),
    [anon_sym___reftype] = ACTIONS(3601),
    [anon_sym___refvalue] = ACTIONS(3601),
    [sym_null_literal] = ACTIONS(3601),
    [anon_sym_SQUOTE] = ACTIONS(3603),
    [sym_integer_literal] = ACTIONS(3601),
    [sym_real_literal] = ACTIONS(3603),
    [anon_sym_DQUOTE] = ACTIONS(3603),
    [sym_verbatim_string_literal] = ACTIONS(3603),
    [aux_sym_preproc_if_token1] = ACTIONS(3603),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3603),
    [sym_interpolation_verbatim_start] = ACTIONS(3603),
    [sym_interpolation_raw_start] = ACTIONS(3603),
    [sym_raw_string_start] = ACTIONS(3603),
  },
  [2572] = {
    [sym_preproc_region] = STATE(2572),
    [sym_preproc_endregion] = STATE(2572),
    [sym_preproc_line] = STATE(2572),
    [sym_preproc_pragma] = STATE(2572),
    [sym_preproc_nullable] = STATE(2572),
    [sym_preproc_error] = STATE(2572),
    [sym_preproc_warning] = STATE(2572),
    [sym_preproc_define] = STATE(2572),
    [sym_preproc_undef] = STATE(2572),
    [ts_builtin_sym_end] = ACTIONS(3607),
    [sym__identifier_token] = ACTIONS(3605),
    [anon_sym_extern] = ACTIONS(3605),
    [anon_sym_alias] = ACTIONS(3605),
    [anon_sym_SEMI] = ACTIONS(3607),
    [anon_sym_global] = ACTIONS(3605),
    [anon_sym_using] = ACTIONS(3605),
    [anon_sym_unsafe] = ACTIONS(3605),
    [anon_sym_static] = ACTIONS(3605),
    [anon_sym_LBRACK] = ACTIONS(3607),
    [anon_sym_LPAREN] = ACTIONS(3607),
    [anon_sym_return] = ACTIONS(3605),
    [anon_sym_namespace] = ACTIONS(3605),
    [anon_sym_class] = ACTIONS(3605),
    [anon_sym_ref] = ACTIONS(3605),
    [anon_sym_struct] = ACTIONS(3605),
    [anon_sym_enum] = ACTIONS(3605),
    [anon_sym_LBRACE] = ACTIONS(3607),
    [anon_sym_interface] = ACTIONS(3605),
    [anon_sym_delegate] = ACTIONS(3605),
    [anon_sym_record] = ACTIONS(3605),
    [anon_sym_abstract] = ACTIONS(3605),
    [anon_sym_async] = ACTIONS(3605),
    [anon_sym_const] = ACTIONS(3605),
    [anon_sym_file] = ACTIONS(3605),
    [anon_sym_fixed] = ACTIONS(3605),
    [anon_sym_internal] = ACTIONS(3605),
    [anon_sym_new] = ACTIONS(3605),
    [anon_sym_override] = ACTIONS(3605),
    [anon_sym_partial] = ACTIONS(3605),
    [anon_sym_private] = ACTIONS(3605),
    [anon_sym_protected] = ACTIONS(3605),
    [anon_sym_public] = ACTIONS(3605),
    [anon_sym_readonly] = ACTIONS(3605),
    [anon_sym_required] = ACTIONS(3605),
    [anon_sym_sealed] = ACTIONS(3605),
    [anon_sym_virtual] = ACTIONS(3605),
    [anon_sym_volatile] = ACTIONS(3605),
    [anon_sym_where] = ACTIONS(3605),
    [anon_sym_notnull] = ACTIONS(3605),
    [anon_sym_unmanaged] = ACTIONS(3605),
    [anon_sym_checked] = ACTIONS(3605),
    [anon_sym_BANG] = ACTIONS(3607),
    [anon_sym_TILDE] = ACTIONS(3607),
    [anon_sym_PLUS_PLUS] = ACTIONS(3607),
    [anon_sym_DASH_DASH] = ACTIONS(3607),
    [anon_sym_true] = ACTIONS(3605),
    [anon_sym_false] = ACTIONS(3605),
    [anon_sym_PLUS] = ACTIONS(3605),
    [anon_sym_DASH] = ACTIONS(3605),
    [anon_sym_STAR] = ACTIONS(3607),
    [anon_sym_CARET] = ACTIONS(3607),
    [anon_sym_AMP] = ACTIONS(3607),
    [anon_sym_this] = ACTIONS(3605),
    [anon_sym_scoped] = ACTIONS(3605),
    [anon_sym_base] = ACTIONS(3605),
    [anon_sym_var] = ACTIONS(3605),
    [sym_predefined_type] = ACTIONS(3605),
    [anon_sym_break] = ACTIONS(3605),
    [anon_sym_unchecked] = ACTIONS(3605),
    [anon_sym_continue] = ACTIONS(3605),
    [anon_sym_do] = ACTIONS(3605),
    [anon_sym_while] = ACTIONS(3605),
    [anon_sym_for] = ACTIONS(3605),
    [anon_sym_lock] = ACTIONS(3605),
    [anon_sym_yield] = ACTIONS(3605),
    [anon_sym_switch] = ACTIONS(3605),
    [anon_sym_default] = ACTIONS(3605),
    [anon_sym_throw] = ACTIONS(3605),
    [anon_sym_try] = ACTIONS(3605),
    [anon_sym_when] = ACTIONS(3605),
    [anon_sym_await] = ACTIONS(3605),
    [anon_sym_foreach] = ACTIONS(3605),
    [anon_sym_goto] = ACTIONS(3605),
    [anon_sym_if] = ACTIONS(3605),
    [anon_sym_DOT_DOT] = ACTIONS(3607),
    [anon_sym_from] = ACTIONS(3605),
    [anon_sym_into] = ACTIONS(3605),
    [anon_sym_join] = ACTIONS(3605),
    [anon_sym_on] = ACTIONS(3605),
    [anon_sym_equals] = ACTIONS(3605),
    [anon_sym_let] = ACTIONS(3605),
    [anon_sym_orderby] = ACTIONS(3605),
    [anon_sym_ascending] = ACTIONS(3605),
    [anon_sym_descending] = ACTIONS(3605),
    [anon_sym_group] = ACTIONS(3605),
    [anon_sym_by] = ACTIONS(3605),
    [anon_sym_select] = ACTIONS(3605),
    [anon_sym_stackalloc] = ACTIONS(3605),
    [anon_sym_sizeof] = ACTIONS(3605),
    [anon_sym_typeof] = ACTIONS(3605),
    [anon_sym___makeref] = ACTIONS(3605),
    [anon_sym___reftype] = ACTIONS(3605),
    [anon_sym___refvalue] = ACTIONS(3605),
    [sym_null_literal] = ACTIONS(3605),
    [anon_sym_SQUOTE] = ACTIONS(3607),
    [sym_integer_literal] = ACTIONS(3605),
    [sym_real_literal] = ACTIONS(3607),
    [anon_sym_DQUOTE] = ACTIONS(3607),
    [sym_verbatim_string_literal] = ACTIONS(3607),
    [aux_sym_preproc_if_token1] = ACTIONS(3607),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3607),
    [sym_interpolation_verbatim_start] = ACTIONS(3607),
    [sym_interpolation_raw_start] = ACTIONS(3607),
    [sym_raw_string_start] = ACTIONS(3607),
  },
  [2573] = {
    [sym_preproc_region] = STATE(2573),
    [sym_preproc_endregion] = STATE(2573),
    [sym_preproc_line] = STATE(2573),
    [sym_preproc_pragma] = STATE(2573),
    [sym_preproc_nullable] = STATE(2573),
    [sym_preproc_error] = STATE(2573),
    [sym_preproc_warning] = STATE(2573),
    [sym_preproc_define] = STATE(2573),
    [sym_preproc_undef] = STATE(2573),
    [ts_builtin_sym_end] = ACTIONS(3515),
    [sym__identifier_token] = ACTIONS(3513),
    [anon_sym_extern] = ACTIONS(3513),
    [anon_sym_alias] = ACTIONS(3513),
    [anon_sym_SEMI] = ACTIONS(3515),
    [anon_sym_global] = ACTIONS(3513),
    [anon_sym_using] = ACTIONS(3513),
    [anon_sym_unsafe] = ACTIONS(3513),
    [anon_sym_static] = ACTIONS(3513),
    [anon_sym_LBRACK] = ACTIONS(3515),
    [anon_sym_LPAREN] = ACTIONS(3515),
    [anon_sym_return] = ACTIONS(3513),
    [anon_sym_namespace] = ACTIONS(3513),
    [anon_sym_class] = ACTIONS(3513),
    [anon_sym_ref] = ACTIONS(3513),
    [anon_sym_struct] = ACTIONS(3513),
    [anon_sym_enum] = ACTIONS(3513),
    [anon_sym_LBRACE] = ACTIONS(3515),
    [anon_sym_interface] = ACTIONS(3513),
    [anon_sym_delegate] = ACTIONS(3513),
    [anon_sym_record] = ACTIONS(3513),
    [anon_sym_abstract] = ACTIONS(3513),
    [anon_sym_async] = ACTIONS(3513),
    [anon_sym_const] = ACTIONS(3513),
    [anon_sym_file] = ACTIONS(3513),
    [anon_sym_fixed] = ACTIONS(3513),
    [anon_sym_internal] = ACTIONS(3513),
    [anon_sym_new] = ACTIONS(3513),
    [anon_sym_override] = ACTIONS(3513),
    [anon_sym_partial] = ACTIONS(3513),
    [anon_sym_private] = ACTIONS(3513),
    [anon_sym_protected] = ACTIONS(3513),
    [anon_sym_public] = ACTIONS(3513),
    [anon_sym_readonly] = ACTIONS(3513),
    [anon_sym_required] = ACTIONS(3513),
    [anon_sym_sealed] = ACTIONS(3513),
    [anon_sym_virtual] = ACTIONS(3513),
    [anon_sym_volatile] = ACTIONS(3513),
    [anon_sym_where] = ACTIONS(3513),
    [anon_sym_notnull] = ACTIONS(3513),
    [anon_sym_unmanaged] = ACTIONS(3513),
    [anon_sym_checked] = ACTIONS(3513),
    [anon_sym_BANG] = ACTIONS(3515),
    [anon_sym_TILDE] = ACTIONS(3515),
    [anon_sym_PLUS_PLUS] = ACTIONS(3515),
    [anon_sym_DASH_DASH] = ACTIONS(3515),
    [anon_sym_true] = ACTIONS(3513),
    [anon_sym_false] = ACTIONS(3513),
    [anon_sym_PLUS] = ACTIONS(3513),
    [anon_sym_DASH] = ACTIONS(3513),
    [anon_sym_STAR] = ACTIONS(3515),
    [anon_sym_CARET] = ACTIONS(3515),
    [anon_sym_AMP] = ACTIONS(3515),
    [anon_sym_this] = ACTIONS(3513),
    [anon_sym_scoped] = ACTIONS(3513),
    [anon_sym_base] = ACTIONS(3513),
    [anon_sym_var] = ACTIONS(3513),
    [sym_predefined_type] = ACTIONS(3513),
    [anon_sym_break] = ACTIONS(3513),
    [anon_sym_unchecked] = ACTIONS(3513),
    [anon_sym_continue] = ACTIONS(3513),
    [anon_sym_do] = ACTIONS(3513),
    [anon_sym_while] = ACTIONS(3513),
    [anon_sym_for] = ACTIONS(3513),
    [anon_sym_lock] = ACTIONS(3513),
    [anon_sym_yield] = ACTIONS(3513),
    [anon_sym_switch] = ACTIONS(3513),
    [anon_sym_default] = ACTIONS(3513),
    [anon_sym_throw] = ACTIONS(3513),
    [anon_sym_try] = ACTIONS(3513),
    [anon_sym_when] = ACTIONS(3513),
    [anon_sym_await] = ACTIONS(3513),
    [anon_sym_foreach] = ACTIONS(3513),
    [anon_sym_goto] = ACTIONS(3513),
    [anon_sym_if] = ACTIONS(3513),
    [anon_sym_DOT_DOT] = ACTIONS(3515),
    [anon_sym_from] = ACTIONS(3513),
    [anon_sym_into] = ACTIONS(3513),
    [anon_sym_join] = ACTIONS(3513),
    [anon_sym_on] = ACTIONS(3513),
    [anon_sym_equals] = ACTIONS(3513),
    [anon_sym_let] = ACTIONS(3513),
    [anon_sym_orderby] = ACTIONS(3513),
    [anon_sym_ascending] = ACTIONS(3513),
    [anon_sym_descending] = ACTIONS(3513),
    [anon_sym_group] = ACTIONS(3513),
    [anon_sym_by] = ACTIONS(3513),
    [anon_sym_select] = ACTIONS(3513),
    [anon_sym_stackalloc] = ACTIONS(3513),
    [anon_sym_sizeof] = ACTIONS(3513),
    [anon_sym_typeof] = ACTIONS(3513),
    [anon_sym___makeref] = ACTIONS(3513),
    [anon_sym___reftype] = ACTIONS(3513),
    [anon_sym___refvalue] = ACTIONS(3513),
    [sym_null_literal] = ACTIONS(3513),
    [anon_sym_SQUOTE] = ACTIONS(3515),
    [sym_integer_literal] = ACTIONS(3513),
    [sym_real_literal] = ACTIONS(3515),
    [anon_sym_DQUOTE] = ACTIONS(3515),
    [sym_verbatim_string_literal] = ACTIONS(3515),
    [aux_sym_preproc_if_token1] = ACTIONS(3515),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3515),
    [sym_interpolation_verbatim_start] = ACTIONS(3515),
    [sym_interpolation_raw_start] = ACTIONS(3515),
    [sym_raw_string_start] = ACTIONS(3515),
  },
  [2574] = {
    [sym_preproc_region] = STATE(2574),
    [sym_preproc_endregion] = STATE(2574),
    [sym_preproc_line] = STATE(2574),
    [sym_preproc_pragma] = STATE(2574),
    [sym_preproc_nullable] = STATE(2574),
    [sym_preproc_error] = STATE(2574),
    [sym_preproc_warning] = STATE(2574),
    [sym_preproc_define] = STATE(2574),
    [sym_preproc_undef] = STATE(2574),
    [ts_builtin_sym_end] = ACTIONS(3611),
    [sym__identifier_token] = ACTIONS(3609),
    [anon_sym_extern] = ACTIONS(3609),
    [anon_sym_alias] = ACTIONS(3609),
    [anon_sym_SEMI] = ACTIONS(3611),
    [anon_sym_global] = ACTIONS(3609),
    [anon_sym_using] = ACTIONS(3609),
    [anon_sym_unsafe] = ACTIONS(3609),
    [anon_sym_static] = ACTIONS(3609),
    [anon_sym_LBRACK] = ACTIONS(3611),
    [anon_sym_LPAREN] = ACTIONS(3611),
    [anon_sym_return] = ACTIONS(3609),
    [anon_sym_namespace] = ACTIONS(3609),
    [anon_sym_class] = ACTIONS(3609),
    [anon_sym_ref] = ACTIONS(3609),
    [anon_sym_struct] = ACTIONS(3609),
    [anon_sym_enum] = ACTIONS(3609),
    [anon_sym_LBRACE] = ACTIONS(3611),
    [anon_sym_interface] = ACTIONS(3609),
    [anon_sym_delegate] = ACTIONS(3609),
    [anon_sym_record] = ACTIONS(3609),
    [anon_sym_abstract] = ACTIONS(3609),
    [anon_sym_async] = ACTIONS(3609),
    [anon_sym_const] = ACTIONS(3609),
    [anon_sym_file] = ACTIONS(3609),
    [anon_sym_fixed] = ACTIONS(3609),
    [anon_sym_internal] = ACTIONS(3609),
    [anon_sym_new] = ACTIONS(3609),
    [anon_sym_override] = ACTIONS(3609),
    [anon_sym_partial] = ACTIONS(3609),
    [anon_sym_private] = ACTIONS(3609),
    [anon_sym_protected] = ACTIONS(3609),
    [anon_sym_public] = ACTIONS(3609),
    [anon_sym_readonly] = ACTIONS(3609),
    [anon_sym_required] = ACTIONS(3609),
    [anon_sym_sealed] = ACTIONS(3609),
    [anon_sym_virtual] = ACTIONS(3609),
    [anon_sym_volatile] = ACTIONS(3609),
    [anon_sym_where] = ACTIONS(3609),
    [anon_sym_notnull] = ACTIONS(3609),
    [anon_sym_unmanaged] = ACTIONS(3609),
    [anon_sym_checked] = ACTIONS(3609),
    [anon_sym_BANG] = ACTIONS(3611),
    [anon_sym_TILDE] = ACTIONS(3611),
    [anon_sym_PLUS_PLUS] = ACTIONS(3611),
    [anon_sym_DASH_DASH] = ACTIONS(3611),
    [anon_sym_true] = ACTIONS(3609),
    [anon_sym_false] = ACTIONS(3609),
    [anon_sym_PLUS] = ACTIONS(3609),
    [anon_sym_DASH] = ACTIONS(3609),
    [anon_sym_STAR] = ACTIONS(3611),
    [anon_sym_CARET] = ACTIONS(3611),
    [anon_sym_AMP] = ACTIONS(3611),
    [anon_sym_this] = ACTIONS(3609),
    [anon_sym_scoped] = ACTIONS(3609),
    [anon_sym_base] = ACTIONS(3609),
    [anon_sym_var] = ACTIONS(3609),
    [sym_predefined_type] = ACTIONS(3609),
    [anon_sym_break] = ACTIONS(3609),
    [anon_sym_unchecked] = ACTIONS(3609),
    [anon_sym_continue] = ACTIONS(3609),
    [anon_sym_do] = ACTIONS(3609),
    [anon_sym_while] = ACTIONS(3609),
    [anon_sym_for] = ACTIONS(3609),
    [anon_sym_lock] = ACTIONS(3609),
    [anon_sym_yield] = ACTIONS(3609),
    [anon_sym_switch] = ACTIONS(3609),
    [anon_sym_default] = ACTIONS(3609),
    [anon_sym_throw] = ACTIONS(3609),
    [anon_sym_try] = ACTIONS(3609),
    [anon_sym_when] = ACTIONS(3609),
    [anon_sym_await] = ACTIONS(3609),
    [anon_sym_foreach] = ACTIONS(3609),
    [anon_sym_goto] = ACTIONS(3609),
    [anon_sym_if] = ACTIONS(3609),
    [anon_sym_DOT_DOT] = ACTIONS(3611),
    [anon_sym_from] = ACTIONS(3609),
    [anon_sym_into] = ACTIONS(3609),
    [anon_sym_join] = ACTIONS(3609),
    [anon_sym_on] = ACTIONS(3609),
    [anon_sym_equals] = ACTIONS(3609),
    [anon_sym_let] = ACTIONS(3609),
    [anon_sym_orderby] = ACTIONS(3609),
    [anon_sym_ascending] = ACTIONS(3609),
    [anon_sym_descending] = ACTIONS(3609),
    [anon_sym_group] = ACTIONS(3609),
    [anon_sym_by] = ACTIONS(3609),
    [anon_sym_select] = ACTIONS(3609),
    [anon_sym_stackalloc] = ACTIONS(3609),
    [anon_sym_sizeof] = ACTIONS(3609),
    [anon_sym_typeof] = ACTIONS(3609),
    [anon_sym___makeref] = ACTIONS(3609),
    [anon_sym___reftype] = ACTIONS(3609),
    [anon_sym___refvalue] = ACTIONS(3609),
    [sym_null_literal] = ACTIONS(3609),
    [anon_sym_SQUOTE] = ACTIONS(3611),
    [sym_integer_literal] = ACTIONS(3609),
    [sym_real_literal] = ACTIONS(3611),
    [anon_sym_DQUOTE] = ACTIONS(3611),
    [sym_verbatim_string_literal] = ACTIONS(3611),
    [aux_sym_preproc_if_token1] = ACTIONS(3611),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3611),
    [sym_interpolation_verbatim_start] = ACTIONS(3611),
    [sym_interpolation_raw_start] = ACTIONS(3611),
    [sym_raw_string_start] = ACTIONS(3611),
  },
  [2575] = {
    [sym_preproc_region] = STATE(2575),
    [sym_preproc_endregion] = STATE(2575),
    [sym_preproc_line] = STATE(2575),
    [sym_preproc_pragma] = STATE(2575),
    [sym_preproc_nullable] = STATE(2575),
    [sym_preproc_error] = STATE(2575),
    [sym_preproc_warning] = STATE(2575),
    [sym_preproc_define] = STATE(2575),
    [sym_preproc_undef] = STATE(2575),
    [ts_builtin_sym_end] = ACTIONS(3615),
    [sym__identifier_token] = ACTIONS(3613),
    [anon_sym_extern] = ACTIONS(3613),
    [anon_sym_alias] = ACTIONS(3613),
    [anon_sym_SEMI] = ACTIONS(3615),
    [anon_sym_global] = ACTIONS(3613),
    [anon_sym_using] = ACTIONS(3613),
    [anon_sym_unsafe] = ACTIONS(3613),
    [anon_sym_static] = ACTIONS(3613),
    [anon_sym_LBRACK] = ACTIONS(3615),
    [anon_sym_LPAREN] = ACTIONS(3615),
    [anon_sym_return] = ACTIONS(3613),
    [anon_sym_namespace] = ACTIONS(3613),
    [anon_sym_class] = ACTIONS(3613),
    [anon_sym_ref] = ACTIONS(3613),
    [anon_sym_struct] = ACTIONS(3613),
    [anon_sym_enum] = ACTIONS(3613),
    [anon_sym_LBRACE] = ACTIONS(3615),
    [anon_sym_interface] = ACTIONS(3613),
    [anon_sym_delegate] = ACTIONS(3613),
    [anon_sym_record] = ACTIONS(3613),
    [anon_sym_abstract] = ACTIONS(3613),
    [anon_sym_async] = ACTIONS(3613),
    [anon_sym_const] = ACTIONS(3613),
    [anon_sym_file] = ACTIONS(3613),
    [anon_sym_fixed] = ACTIONS(3613),
    [anon_sym_internal] = ACTIONS(3613),
    [anon_sym_new] = ACTIONS(3613),
    [anon_sym_override] = ACTIONS(3613),
    [anon_sym_partial] = ACTIONS(3613),
    [anon_sym_private] = ACTIONS(3613),
    [anon_sym_protected] = ACTIONS(3613),
    [anon_sym_public] = ACTIONS(3613),
    [anon_sym_readonly] = ACTIONS(3613),
    [anon_sym_required] = ACTIONS(3613),
    [anon_sym_sealed] = ACTIONS(3613),
    [anon_sym_virtual] = ACTIONS(3613),
    [anon_sym_volatile] = ACTIONS(3613),
    [anon_sym_where] = ACTIONS(3613),
    [anon_sym_notnull] = ACTIONS(3613),
    [anon_sym_unmanaged] = ACTIONS(3613),
    [anon_sym_checked] = ACTIONS(3613),
    [anon_sym_BANG] = ACTIONS(3615),
    [anon_sym_TILDE] = ACTIONS(3615),
    [anon_sym_PLUS_PLUS] = ACTIONS(3615),
    [anon_sym_DASH_DASH] = ACTIONS(3615),
    [anon_sym_true] = ACTIONS(3613),
    [anon_sym_false] = ACTIONS(3613),
    [anon_sym_PLUS] = ACTIONS(3613),
    [anon_sym_DASH] = ACTIONS(3613),
    [anon_sym_STAR] = ACTIONS(3615),
    [anon_sym_CARET] = ACTIONS(3615),
    [anon_sym_AMP] = ACTIONS(3615),
    [anon_sym_this] = ACTIONS(3613),
    [anon_sym_scoped] = ACTIONS(3613),
    [anon_sym_base] = ACTIONS(3613),
    [anon_sym_var] = ACTIONS(3613),
    [sym_predefined_type] = ACTIONS(3613),
    [anon_sym_break] = ACTIONS(3613),
    [anon_sym_unchecked] = ACTIONS(3613),
    [anon_sym_continue] = ACTIONS(3613),
    [anon_sym_do] = ACTIONS(3613),
    [anon_sym_while] = ACTIONS(3613),
    [anon_sym_for] = ACTIONS(3613),
    [anon_sym_lock] = ACTIONS(3613),
    [anon_sym_yield] = ACTIONS(3613),
    [anon_sym_switch] = ACTIONS(3613),
    [anon_sym_default] = ACTIONS(3613),
    [anon_sym_throw] = ACTIONS(3613),
    [anon_sym_try] = ACTIONS(3613),
    [anon_sym_when] = ACTIONS(3613),
    [anon_sym_await] = ACTIONS(3613),
    [anon_sym_foreach] = ACTIONS(3613),
    [anon_sym_goto] = ACTIONS(3613),
    [anon_sym_if] = ACTIONS(3613),
    [anon_sym_DOT_DOT] = ACTIONS(3615),
    [anon_sym_from] = ACTIONS(3613),
    [anon_sym_into] = ACTIONS(3613),
    [anon_sym_join] = ACTIONS(3613),
    [anon_sym_on] = ACTIONS(3613),
    [anon_sym_equals] = ACTIONS(3613),
    [anon_sym_let] = ACTIONS(3613),
    [anon_sym_orderby] = ACTIONS(3613),
    [anon_sym_ascending] = ACTIONS(3613),
    [anon_sym_descending] = ACTIONS(3613),
    [anon_sym_group] = ACTIONS(3613),
    [anon_sym_by] = ACTIONS(3613),
    [anon_sym_select] = ACTIONS(3613),
    [anon_sym_stackalloc] = ACTIONS(3613),
    [anon_sym_sizeof] = ACTIONS(3613),
    [anon_sym_typeof] = ACTIONS(3613),
    [anon_sym___makeref] = ACTIONS(3613),
    [anon_sym___reftype] = ACTIONS(3613),
    [anon_sym___refvalue] = ACTIONS(3613),
    [sym_null_literal] = ACTIONS(3613),
    [anon_sym_SQUOTE] = ACTIONS(3615),
    [sym_integer_literal] = ACTIONS(3613),
    [sym_real_literal] = ACTIONS(3615),
    [anon_sym_DQUOTE] = ACTIONS(3615),
    [sym_verbatim_string_literal] = ACTIONS(3615),
    [aux_sym_preproc_if_token1] = ACTIONS(3615),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3615),
    [sym_interpolation_verbatim_start] = ACTIONS(3615),
    [sym_interpolation_raw_start] = ACTIONS(3615),
    [sym_raw_string_start] = ACTIONS(3615),
  },
  [2576] = {
    [sym_preproc_region] = STATE(2576),
    [sym_preproc_endregion] = STATE(2576),
    [sym_preproc_line] = STATE(2576),
    [sym_preproc_pragma] = STATE(2576),
    [sym_preproc_nullable] = STATE(2576),
    [sym_preproc_error] = STATE(2576),
    [sym_preproc_warning] = STATE(2576),
    [sym_preproc_define] = STATE(2576),
    [sym_preproc_undef] = STATE(2576),
    [ts_builtin_sym_end] = ACTIONS(3619),
    [sym__identifier_token] = ACTIONS(3617),
    [anon_sym_extern] = ACTIONS(3617),
    [anon_sym_alias] = ACTIONS(3617),
    [anon_sym_SEMI] = ACTIONS(3619),
    [anon_sym_global] = ACTIONS(3617),
    [anon_sym_using] = ACTIONS(3617),
    [anon_sym_unsafe] = ACTIONS(3617),
    [anon_sym_static] = ACTIONS(3617),
    [anon_sym_LBRACK] = ACTIONS(3619),
    [anon_sym_LPAREN] = ACTIONS(3619),
    [anon_sym_return] = ACTIONS(3617),
    [anon_sym_namespace] = ACTIONS(3617),
    [anon_sym_class] = ACTIONS(3617),
    [anon_sym_ref] = ACTIONS(3617),
    [anon_sym_struct] = ACTIONS(3617),
    [anon_sym_enum] = ACTIONS(3617),
    [anon_sym_LBRACE] = ACTIONS(3619),
    [anon_sym_interface] = ACTIONS(3617),
    [anon_sym_delegate] = ACTIONS(3617),
    [anon_sym_record] = ACTIONS(3617),
    [anon_sym_abstract] = ACTIONS(3617),
    [anon_sym_async] = ACTIONS(3617),
    [anon_sym_const] = ACTIONS(3617),
    [anon_sym_file] = ACTIONS(3617),
    [anon_sym_fixed] = ACTIONS(3617),
    [anon_sym_internal] = ACTIONS(3617),
    [anon_sym_new] = ACTIONS(3617),
    [anon_sym_override] = ACTIONS(3617),
    [anon_sym_partial] = ACTIONS(3617),
    [anon_sym_private] = ACTIONS(3617),
    [anon_sym_protected] = ACTIONS(3617),
    [anon_sym_public] = ACTIONS(3617),
    [anon_sym_readonly] = ACTIONS(3617),
    [anon_sym_required] = ACTIONS(3617),
    [anon_sym_sealed] = ACTIONS(3617),
    [anon_sym_virtual] = ACTIONS(3617),
    [anon_sym_volatile] = ACTIONS(3617),
    [anon_sym_where] = ACTIONS(3617),
    [anon_sym_notnull] = ACTIONS(3617),
    [anon_sym_unmanaged] = ACTIONS(3617),
    [anon_sym_checked] = ACTIONS(3617),
    [anon_sym_BANG] = ACTIONS(3619),
    [anon_sym_TILDE] = ACTIONS(3619),
    [anon_sym_PLUS_PLUS] = ACTIONS(3619),
    [anon_sym_DASH_DASH] = ACTIONS(3619),
    [anon_sym_true] = ACTIONS(3617),
    [anon_sym_false] = ACTIONS(3617),
    [anon_sym_PLUS] = ACTIONS(3617),
    [anon_sym_DASH] = ACTIONS(3617),
    [anon_sym_STAR] = ACTIONS(3619),
    [anon_sym_CARET] = ACTIONS(3619),
    [anon_sym_AMP] = ACTIONS(3619),
    [anon_sym_this] = ACTIONS(3617),
    [anon_sym_scoped] = ACTIONS(3617),
    [anon_sym_base] = ACTIONS(3617),
    [anon_sym_var] = ACTIONS(3617),
    [sym_predefined_type] = ACTIONS(3617),
    [anon_sym_break] = ACTIONS(3617),
    [anon_sym_unchecked] = ACTIONS(3617),
    [anon_sym_continue] = ACTIONS(3617),
    [anon_sym_do] = ACTIONS(3617),
    [anon_sym_while] = ACTIONS(3617),
    [anon_sym_for] = ACTIONS(3617),
    [anon_sym_lock] = ACTIONS(3617),
    [anon_sym_yield] = ACTIONS(3617),
    [anon_sym_switch] = ACTIONS(3617),
    [anon_sym_default] = ACTIONS(3617),
    [anon_sym_throw] = ACTIONS(3617),
    [anon_sym_try] = ACTIONS(3617),
    [anon_sym_when] = ACTIONS(3617),
    [anon_sym_await] = ACTIONS(3617),
    [anon_sym_foreach] = ACTIONS(3617),
    [anon_sym_goto] = ACTIONS(3617),
    [anon_sym_if] = ACTIONS(3617),
    [anon_sym_DOT_DOT] = ACTIONS(3619),
    [anon_sym_from] = ACTIONS(3617),
    [anon_sym_into] = ACTIONS(3617),
    [anon_sym_join] = ACTIONS(3617),
    [anon_sym_on] = ACTIONS(3617),
    [anon_sym_equals] = ACTIONS(3617),
    [anon_sym_let] = ACTIONS(3617),
    [anon_sym_orderby] = ACTIONS(3617),
    [anon_sym_ascending] = ACTIONS(3617),
    [anon_sym_descending] = ACTIONS(3617),
    [anon_sym_group] = ACTIONS(3617),
    [anon_sym_by] = ACTIONS(3617),
    [anon_sym_select] = ACTIONS(3617),
    [anon_sym_stackalloc] = ACTIONS(3617),
    [anon_sym_sizeof] = ACTIONS(3617),
    [anon_sym_typeof] = ACTIONS(3617),
    [anon_sym___makeref] = ACTIONS(3617),
    [anon_sym___reftype] = ACTIONS(3617),
    [anon_sym___refvalue] = ACTIONS(3617),
    [sym_null_literal] = ACTIONS(3617),
    [anon_sym_SQUOTE] = ACTIONS(3619),
    [sym_integer_literal] = ACTIONS(3617),
    [sym_real_literal] = ACTIONS(3619),
    [anon_sym_DQUOTE] = ACTIONS(3619),
    [sym_verbatim_string_literal] = ACTIONS(3619),
    [aux_sym_preproc_if_token1] = ACTIONS(3619),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3619),
    [sym_interpolation_verbatim_start] = ACTIONS(3619),
    [sym_interpolation_raw_start] = ACTIONS(3619),
    [sym_raw_string_start] = ACTIONS(3619),
  },
  [2577] = {
    [sym_preproc_region] = STATE(2577),
    [sym_preproc_endregion] = STATE(2577),
    [sym_preproc_line] = STATE(2577),
    [sym_preproc_pragma] = STATE(2577),
    [sym_preproc_nullable] = STATE(2577),
    [sym_preproc_error] = STATE(2577),
    [sym_preproc_warning] = STATE(2577),
    [sym_preproc_define] = STATE(2577),
    [sym_preproc_undef] = STATE(2577),
    [ts_builtin_sym_end] = ACTIONS(3519),
    [sym__identifier_token] = ACTIONS(3517),
    [anon_sym_extern] = ACTIONS(3517),
    [anon_sym_alias] = ACTIONS(3517),
    [anon_sym_SEMI] = ACTIONS(3519),
    [anon_sym_global] = ACTIONS(3517),
    [anon_sym_using] = ACTIONS(3517),
    [anon_sym_unsafe] = ACTIONS(3517),
    [anon_sym_static] = ACTIONS(3517),
    [anon_sym_LBRACK] = ACTIONS(3519),
    [anon_sym_LPAREN] = ACTIONS(3519),
    [anon_sym_return] = ACTIONS(3517),
    [anon_sym_namespace] = ACTIONS(3517),
    [anon_sym_class] = ACTIONS(3517),
    [anon_sym_ref] = ACTIONS(3517),
    [anon_sym_struct] = ACTIONS(3517),
    [anon_sym_enum] = ACTIONS(3517),
    [anon_sym_LBRACE] = ACTIONS(3519),
    [anon_sym_interface] = ACTIONS(3517),
    [anon_sym_delegate] = ACTIONS(3517),
    [anon_sym_record] = ACTIONS(3517),
    [anon_sym_abstract] = ACTIONS(3517),
    [anon_sym_async] = ACTIONS(3517),
    [anon_sym_const] = ACTIONS(3517),
    [anon_sym_file] = ACTIONS(3517),
    [anon_sym_fixed] = ACTIONS(3517),
    [anon_sym_internal] = ACTIONS(3517),
    [anon_sym_new] = ACTIONS(3517),
    [anon_sym_override] = ACTIONS(3517),
    [anon_sym_partial] = ACTIONS(3517),
    [anon_sym_private] = ACTIONS(3517),
    [anon_sym_protected] = ACTIONS(3517),
    [anon_sym_public] = ACTIONS(3517),
    [anon_sym_readonly] = ACTIONS(3517),
    [anon_sym_required] = ACTIONS(3517),
    [anon_sym_sealed] = ACTIONS(3517),
    [anon_sym_virtual] = ACTIONS(3517),
    [anon_sym_volatile] = ACTIONS(3517),
    [anon_sym_where] = ACTIONS(3517),
    [anon_sym_notnull] = ACTIONS(3517),
    [anon_sym_unmanaged] = ACTIONS(3517),
    [anon_sym_checked] = ACTIONS(3517),
    [anon_sym_BANG] = ACTIONS(3519),
    [anon_sym_TILDE] = ACTIONS(3519),
    [anon_sym_PLUS_PLUS] = ACTIONS(3519),
    [anon_sym_DASH_DASH] = ACTIONS(3519),
    [anon_sym_true] = ACTIONS(3517),
    [anon_sym_false] = ACTIONS(3517),
    [anon_sym_PLUS] = ACTIONS(3517),
    [anon_sym_DASH] = ACTIONS(3517),
    [anon_sym_STAR] = ACTIONS(3519),
    [anon_sym_CARET] = ACTIONS(3519),
    [anon_sym_AMP] = ACTIONS(3519),
    [anon_sym_this] = ACTIONS(3517),
    [anon_sym_scoped] = ACTIONS(3517),
    [anon_sym_base] = ACTIONS(3517),
    [anon_sym_var] = ACTIONS(3517),
    [sym_predefined_type] = ACTIONS(3517),
    [anon_sym_break] = ACTIONS(3517),
    [anon_sym_unchecked] = ACTIONS(3517),
    [anon_sym_continue] = ACTIONS(3517),
    [anon_sym_do] = ACTIONS(3517),
    [anon_sym_while] = ACTIONS(3517),
    [anon_sym_for] = ACTIONS(3517),
    [anon_sym_lock] = ACTIONS(3517),
    [anon_sym_yield] = ACTIONS(3517),
    [anon_sym_switch] = ACTIONS(3517),
    [anon_sym_default] = ACTIONS(3517),
    [anon_sym_throw] = ACTIONS(3517),
    [anon_sym_try] = ACTIONS(3517),
    [anon_sym_when] = ACTIONS(3517),
    [anon_sym_await] = ACTIONS(3517),
    [anon_sym_foreach] = ACTIONS(3517),
    [anon_sym_goto] = ACTIONS(3517),
    [anon_sym_if] = ACTIONS(3517),
    [anon_sym_DOT_DOT] = ACTIONS(3519),
    [anon_sym_from] = ACTIONS(3517),
    [anon_sym_into] = ACTIONS(3517),
    [anon_sym_join] = ACTIONS(3517),
    [anon_sym_on] = ACTIONS(3517),
    [anon_sym_equals] = ACTIONS(3517),
    [anon_sym_let] = ACTIONS(3517),
    [anon_sym_orderby] = ACTIONS(3517),
    [anon_sym_ascending] = ACTIONS(3517),
    [anon_sym_descending] = ACTIONS(3517),
    [anon_sym_group] = ACTIONS(3517),
    [anon_sym_by] = ACTIONS(3517),
    [anon_sym_select] = ACTIONS(3517),
    [anon_sym_stackalloc] = ACTIONS(3517),
    [anon_sym_sizeof] = ACTIONS(3517),
    [anon_sym_typeof] = ACTIONS(3517),
    [anon_sym___makeref] = ACTIONS(3517),
    [anon_sym___reftype] = ACTIONS(3517),
    [anon_sym___refvalue] = ACTIONS(3517),
    [sym_null_literal] = ACTIONS(3517),
    [anon_sym_SQUOTE] = ACTIONS(3519),
    [sym_integer_literal] = ACTIONS(3517),
    [sym_real_literal] = ACTIONS(3519),
    [anon_sym_DQUOTE] = ACTIONS(3519),
    [sym_verbatim_string_literal] = ACTIONS(3519),
    [aux_sym_preproc_if_token1] = ACTIONS(3519),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3519),
    [sym_interpolation_verbatim_start] = ACTIONS(3519),
    [sym_interpolation_raw_start] = ACTIONS(3519),
    [sym_raw_string_start] = ACTIONS(3519),
  },
  [2578] = {
    [sym_preproc_region] = STATE(2578),
    [sym_preproc_endregion] = STATE(2578),
    [sym_preproc_line] = STATE(2578),
    [sym_preproc_pragma] = STATE(2578),
    [sym_preproc_nullable] = STATE(2578),
    [sym_preproc_error] = STATE(2578),
    [sym_preproc_warning] = STATE(2578),
    [sym_preproc_define] = STATE(2578),
    [sym_preproc_undef] = STATE(2578),
    [ts_builtin_sym_end] = ACTIONS(3523),
    [sym__identifier_token] = ACTIONS(3521),
    [anon_sym_extern] = ACTIONS(3521),
    [anon_sym_alias] = ACTIONS(3521),
    [anon_sym_SEMI] = ACTIONS(3523),
    [anon_sym_global] = ACTIONS(3521),
    [anon_sym_using] = ACTIONS(3521),
    [anon_sym_unsafe] = ACTIONS(3521),
    [anon_sym_static] = ACTIONS(3521),
    [anon_sym_LBRACK] = ACTIONS(3523),
    [anon_sym_LPAREN] = ACTIONS(3523),
    [anon_sym_return] = ACTIONS(3521),
    [anon_sym_namespace] = ACTIONS(3521),
    [anon_sym_class] = ACTIONS(3521),
    [anon_sym_ref] = ACTIONS(3521),
    [anon_sym_struct] = ACTIONS(3521),
    [anon_sym_enum] = ACTIONS(3521),
    [anon_sym_LBRACE] = ACTIONS(3523),
    [anon_sym_interface] = ACTIONS(3521),
    [anon_sym_delegate] = ACTIONS(3521),
    [anon_sym_record] = ACTIONS(3521),
    [anon_sym_abstract] = ACTIONS(3521),
    [anon_sym_async] = ACTIONS(3521),
    [anon_sym_const] = ACTIONS(3521),
    [anon_sym_file] = ACTIONS(3521),
    [anon_sym_fixed] = ACTIONS(3521),
    [anon_sym_internal] = ACTIONS(3521),
    [anon_sym_new] = ACTIONS(3521),
    [anon_sym_override] = ACTIONS(3521),
    [anon_sym_partial] = ACTIONS(3521),
    [anon_sym_private] = ACTIONS(3521),
    [anon_sym_protected] = ACTIONS(3521),
    [anon_sym_public] = ACTIONS(3521),
    [anon_sym_readonly] = ACTIONS(3521),
    [anon_sym_required] = ACTIONS(3521),
    [anon_sym_sealed] = ACTIONS(3521),
    [anon_sym_virtual] = ACTIONS(3521),
    [anon_sym_volatile] = ACTIONS(3521),
    [anon_sym_where] = ACTIONS(3521),
    [anon_sym_notnull] = ACTIONS(3521),
    [anon_sym_unmanaged] = ACTIONS(3521),
    [anon_sym_checked] = ACTIONS(3521),
    [anon_sym_BANG] = ACTIONS(3523),
    [anon_sym_TILDE] = ACTIONS(3523),
    [anon_sym_PLUS_PLUS] = ACTIONS(3523),
    [anon_sym_DASH_DASH] = ACTIONS(3523),
    [anon_sym_true] = ACTIONS(3521),
    [anon_sym_false] = ACTIONS(3521),
    [anon_sym_PLUS] = ACTIONS(3521),
    [anon_sym_DASH] = ACTIONS(3521),
    [anon_sym_STAR] = ACTIONS(3523),
    [anon_sym_CARET] = ACTIONS(3523),
    [anon_sym_AMP] = ACTIONS(3523),
    [anon_sym_this] = ACTIONS(3521),
    [anon_sym_scoped] = ACTIONS(3521),
    [anon_sym_base] = ACTIONS(3521),
    [anon_sym_var] = ACTIONS(3521),
    [sym_predefined_type] = ACTIONS(3521),
    [anon_sym_break] = ACTIONS(3521),
    [anon_sym_unchecked] = ACTIONS(3521),
    [anon_sym_continue] = ACTIONS(3521),
    [anon_sym_do] = ACTIONS(3521),
    [anon_sym_while] = ACTIONS(3521),
    [anon_sym_for] = ACTIONS(3521),
    [anon_sym_lock] = ACTIONS(3521),
    [anon_sym_yield] = ACTIONS(3521),
    [anon_sym_switch] = ACTIONS(3521),
    [anon_sym_default] = ACTIONS(3521),
    [anon_sym_throw] = ACTIONS(3521),
    [anon_sym_try] = ACTIONS(3521),
    [anon_sym_when] = ACTIONS(3521),
    [anon_sym_await] = ACTIONS(3521),
    [anon_sym_foreach] = ACTIONS(3521),
    [anon_sym_goto] = ACTIONS(3521),
    [anon_sym_if] = ACTIONS(3521),
    [anon_sym_DOT_DOT] = ACTIONS(3523),
    [anon_sym_from] = ACTIONS(3521),
    [anon_sym_into] = ACTIONS(3521),
    [anon_sym_join] = ACTIONS(3521),
    [anon_sym_on] = ACTIONS(3521),
    [anon_sym_equals] = ACTIONS(3521),
    [anon_sym_let] = ACTIONS(3521),
    [anon_sym_orderby] = ACTIONS(3521),
    [anon_sym_ascending] = ACTIONS(3521),
    [anon_sym_descending] = ACTIONS(3521),
    [anon_sym_group] = ACTIONS(3521),
    [anon_sym_by] = ACTIONS(3521),
    [anon_sym_select] = ACTIONS(3521),
    [anon_sym_stackalloc] = ACTIONS(3521),
    [anon_sym_sizeof] = ACTIONS(3521),
    [anon_sym_typeof] = ACTIONS(3521),
    [anon_sym___makeref] = ACTIONS(3521),
    [anon_sym___reftype] = ACTIONS(3521),
    [anon_sym___refvalue] = ACTIONS(3521),
    [sym_null_literal] = ACTIONS(3521),
    [anon_sym_SQUOTE] = ACTIONS(3523),
    [sym_integer_literal] = ACTIONS(3521),
    [sym_real_literal] = ACTIONS(3523),
    [anon_sym_DQUOTE] = ACTIONS(3523),
    [sym_verbatim_string_literal] = ACTIONS(3523),
    [aux_sym_preproc_if_token1] = ACTIONS(3523),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3523),
    [sym_interpolation_verbatim_start] = ACTIONS(3523),
    [sym_interpolation_raw_start] = ACTIONS(3523),
    [sym_raw_string_start] = ACTIONS(3523),
  },
  [2579] = {
    [sym_preproc_region] = STATE(2579),
    [sym_preproc_endregion] = STATE(2579),
    [sym_preproc_line] = STATE(2579),
    [sym_preproc_pragma] = STATE(2579),
    [sym_preproc_nullable] = STATE(2579),
    [sym_preproc_error] = STATE(2579),
    [sym_preproc_warning] = STATE(2579),
    [sym_preproc_define] = STATE(2579),
    [sym_preproc_undef] = STATE(2579),
    [ts_builtin_sym_end] = ACTIONS(3527),
    [sym__identifier_token] = ACTIONS(3525),
    [anon_sym_extern] = ACTIONS(3525),
    [anon_sym_alias] = ACTIONS(3525),
    [anon_sym_SEMI] = ACTIONS(3527),
    [anon_sym_global] = ACTIONS(3525),
    [anon_sym_using] = ACTIONS(3525),
    [anon_sym_unsafe] = ACTIONS(3525),
    [anon_sym_static] = ACTIONS(3525),
    [anon_sym_LBRACK] = ACTIONS(3527),
    [anon_sym_LPAREN] = ACTIONS(3527),
    [anon_sym_return] = ACTIONS(3525),
    [anon_sym_namespace] = ACTIONS(3525),
    [anon_sym_class] = ACTIONS(3525),
    [anon_sym_ref] = ACTIONS(3525),
    [anon_sym_struct] = ACTIONS(3525),
    [anon_sym_enum] = ACTIONS(3525),
    [anon_sym_LBRACE] = ACTIONS(3527),
    [anon_sym_interface] = ACTIONS(3525),
    [anon_sym_delegate] = ACTIONS(3525),
    [anon_sym_record] = ACTIONS(3525),
    [anon_sym_abstract] = ACTIONS(3525),
    [anon_sym_async] = ACTIONS(3525),
    [anon_sym_const] = ACTIONS(3525),
    [anon_sym_file] = ACTIONS(3525),
    [anon_sym_fixed] = ACTIONS(3525),
    [anon_sym_internal] = ACTIONS(3525),
    [anon_sym_new] = ACTIONS(3525),
    [anon_sym_override] = ACTIONS(3525),
    [anon_sym_partial] = ACTIONS(3525),
    [anon_sym_private] = ACTIONS(3525),
    [anon_sym_protected] = ACTIONS(3525),
    [anon_sym_public] = ACTIONS(3525),
    [anon_sym_readonly] = ACTIONS(3525),
    [anon_sym_required] = ACTIONS(3525),
    [anon_sym_sealed] = ACTIONS(3525),
    [anon_sym_virtual] = ACTIONS(3525),
    [anon_sym_volatile] = ACTIONS(3525),
    [anon_sym_where] = ACTIONS(3525),
    [anon_sym_notnull] = ACTIONS(3525),
    [anon_sym_unmanaged] = ACTIONS(3525),
    [anon_sym_checked] = ACTIONS(3525),
    [anon_sym_BANG] = ACTIONS(3527),
    [anon_sym_TILDE] = ACTIONS(3527),
    [anon_sym_PLUS_PLUS] = ACTIONS(3527),
    [anon_sym_DASH_DASH] = ACTIONS(3527),
    [anon_sym_true] = ACTIONS(3525),
    [anon_sym_false] = ACTIONS(3525),
    [anon_sym_PLUS] = ACTIONS(3525),
    [anon_sym_DASH] = ACTIONS(3525),
    [anon_sym_STAR] = ACTIONS(3527),
    [anon_sym_CARET] = ACTIONS(3527),
    [anon_sym_AMP] = ACTIONS(3527),
    [anon_sym_this] = ACTIONS(3525),
    [anon_sym_scoped] = ACTIONS(3525),
    [anon_sym_base] = ACTIONS(3525),
    [anon_sym_var] = ACTIONS(3525),
    [sym_predefined_type] = ACTIONS(3525),
    [anon_sym_break] = ACTIONS(3525),
    [anon_sym_unchecked] = ACTIONS(3525),
    [anon_sym_continue] = ACTIONS(3525),
    [anon_sym_do] = ACTIONS(3525),
    [anon_sym_while] = ACTIONS(3525),
    [anon_sym_for] = ACTIONS(3525),
    [anon_sym_lock] = ACTIONS(3525),
    [anon_sym_yield] = ACTIONS(3525),
    [anon_sym_switch] = ACTIONS(3525),
    [anon_sym_default] = ACTIONS(3525),
    [anon_sym_throw] = ACTIONS(3525),
    [anon_sym_try] = ACTIONS(3525),
    [anon_sym_when] = ACTIONS(3525),
    [anon_sym_await] = ACTIONS(3525),
    [anon_sym_foreach] = ACTIONS(3525),
    [anon_sym_goto] = ACTIONS(3525),
    [anon_sym_if] = ACTIONS(3525),
    [anon_sym_DOT_DOT] = ACTIONS(3527),
    [anon_sym_from] = ACTIONS(3525),
    [anon_sym_into] = ACTIONS(3525),
    [anon_sym_join] = ACTIONS(3525),
    [anon_sym_on] = ACTIONS(3525),
    [anon_sym_equals] = ACTIONS(3525),
    [anon_sym_let] = ACTIONS(3525),
    [anon_sym_orderby] = ACTIONS(3525),
    [anon_sym_ascending] = ACTIONS(3525),
    [anon_sym_descending] = ACTIONS(3525),
    [anon_sym_group] = ACTIONS(3525),
    [anon_sym_by] = ACTIONS(3525),
    [anon_sym_select] = ACTIONS(3525),
    [anon_sym_stackalloc] = ACTIONS(3525),
    [anon_sym_sizeof] = ACTIONS(3525),
    [anon_sym_typeof] = ACTIONS(3525),
    [anon_sym___makeref] = ACTIONS(3525),
    [anon_sym___reftype] = ACTIONS(3525),
    [anon_sym___refvalue] = ACTIONS(3525),
    [sym_null_literal] = ACTIONS(3525),
    [anon_sym_SQUOTE] = ACTIONS(3527),
    [sym_integer_literal] = ACTIONS(3525),
    [sym_real_literal] = ACTIONS(3527),
    [anon_sym_DQUOTE] = ACTIONS(3527),
    [sym_verbatim_string_literal] = ACTIONS(3527),
    [aux_sym_preproc_if_token1] = ACTIONS(3527),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3527),
    [sym_interpolation_verbatim_start] = ACTIONS(3527),
    [sym_interpolation_raw_start] = ACTIONS(3527),
    [sym_raw_string_start] = ACTIONS(3527),
  },
  [2580] = {
    [sym_preproc_region] = STATE(2580),
    [sym_preproc_endregion] = STATE(2580),
    [sym_preproc_line] = STATE(2580),
    [sym_preproc_pragma] = STATE(2580),
    [sym_preproc_nullable] = STATE(2580),
    [sym_preproc_error] = STATE(2580),
    [sym_preproc_warning] = STATE(2580),
    [sym_preproc_define] = STATE(2580),
    [sym_preproc_undef] = STATE(2580),
    [ts_builtin_sym_end] = ACTIONS(3847),
    [sym__identifier_token] = ACTIONS(3845),
    [anon_sym_extern] = ACTIONS(3845),
    [anon_sym_alias] = ACTIONS(3845),
    [anon_sym_SEMI] = ACTIONS(3847),
    [anon_sym_global] = ACTIONS(3845),
    [anon_sym_using] = ACTIONS(3845),
    [anon_sym_unsafe] = ACTIONS(3845),
    [anon_sym_static] = ACTIONS(3845),
    [anon_sym_LBRACK] = ACTIONS(3847),
    [anon_sym_LPAREN] = ACTIONS(3847),
    [anon_sym_return] = ACTIONS(3845),
    [anon_sym_namespace] = ACTIONS(3845),
    [anon_sym_class] = ACTIONS(3845),
    [anon_sym_ref] = ACTIONS(3845),
    [anon_sym_struct] = ACTIONS(3845),
    [anon_sym_enum] = ACTIONS(3845),
    [anon_sym_LBRACE] = ACTIONS(3847),
    [anon_sym_interface] = ACTIONS(3845),
    [anon_sym_delegate] = ACTIONS(3845),
    [anon_sym_record] = ACTIONS(3845),
    [anon_sym_abstract] = ACTIONS(3845),
    [anon_sym_async] = ACTIONS(3845),
    [anon_sym_const] = ACTIONS(3845),
    [anon_sym_file] = ACTIONS(3845),
    [anon_sym_fixed] = ACTIONS(3845),
    [anon_sym_internal] = ACTIONS(3845),
    [anon_sym_new] = ACTIONS(3845),
    [anon_sym_override] = ACTIONS(3845),
    [anon_sym_partial] = ACTIONS(3845),
    [anon_sym_private] = ACTIONS(3845),
    [anon_sym_protected] = ACTIONS(3845),
    [anon_sym_public] = ACTIONS(3845),
    [anon_sym_readonly] = ACTIONS(3845),
    [anon_sym_required] = ACTIONS(3845),
    [anon_sym_sealed] = ACTIONS(3845),
    [anon_sym_virtual] = ACTIONS(3845),
    [anon_sym_volatile] = ACTIONS(3845),
    [anon_sym_where] = ACTIONS(3845),
    [anon_sym_notnull] = ACTIONS(3845),
    [anon_sym_unmanaged] = ACTIONS(3845),
    [anon_sym_checked] = ACTIONS(3845),
    [anon_sym_BANG] = ACTIONS(3847),
    [anon_sym_TILDE] = ACTIONS(3847),
    [anon_sym_PLUS_PLUS] = ACTIONS(3847),
    [anon_sym_DASH_DASH] = ACTIONS(3847),
    [anon_sym_true] = ACTIONS(3845),
    [anon_sym_false] = ACTIONS(3845),
    [anon_sym_PLUS] = ACTIONS(3845),
    [anon_sym_DASH] = ACTIONS(3845),
    [anon_sym_STAR] = ACTIONS(3847),
    [anon_sym_CARET] = ACTIONS(3847),
    [anon_sym_AMP] = ACTIONS(3847),
    [anon_sym_this] = ACTIONS(3845),
    [anon_sym_scoped] = ACTIONS(3845),
    [anon_sym_base] = ACTIONS(3845),
    [anon_sym_var] = ACTIONS(3845),
    [sym_predefined_type] = ACTIONS(3845),
    [anon_sym_break] = ACTIONS(3845),
    [anon_sym_unchecked] = ACTIONS(3845),
    [anon_sym_continue] = ACTIONS(3845),
    [anon_sym_do] = ACTIONS(3845),
    [anon_sym_while] = ACTIONS(3845),
    [anon_sym_for] = ACTIONS(3845),
    [anon_sym_lock] = ACTIONS(3845),
    [anon_sym_yield] = ACTIONS(3845),
    [anon_sym_switch] = ACTIONS(3845),
    [anon_sym_default] = ACTIONS(3845),
    [anon_sym_throw] = ACTIONS(3845),
    [anon_sym_try] = ACTIONS(3845),
    [anon_sym_when] = ACTIONS(3845),
    [anon_sym_await] = ACTIONS(3845),
    [anon_sym_foreach] = ACTIONS(3845),
    [anon_sym_goto] = ACTIONS(3845),
    [anon_sym_if] = ACTIONS(3845),
    [anon_sym_DOT_DOT] = ACTIONS(3847),
    [anon_sym_from] = ACTIONS(3845),
    [anon_sym_into] = ACTIONS(3845),
    [anon_sym_join] = ACTIONS(3845),
    [anon_sym_on] = ACTIONS(3845),
    [anon_sym_equals] = ACTIONS(3845),
    [anon_sym_let] = ACTIONS(3845),
    [anon_sym_orderby] = ACTIONS(3845),
    [anon_sym_ascending] = ACTIONS(3845),
    [anon_sym_descending] = ACTIONS(3845),
    [anon_sym_group] = ACTIONS(3845),
    [anon_sym_by] = ACTIONS(3845),
    [anon_sym_select] = ACTIONS(3845),
    [anon_sym_stackalloc] = ACTIONS(3845),
    [anon_sym_sizeof] = ACTIONS(3845),
    [anon_sym_typeof] = ACTIONS(3845),
    [anon_sym___makeref] = ACTIONS(3845),
    [anon_sym___reftype] = ACTIONS(3845),
    [anon_sym___refvalue] = ACTIONS(3845),
    [sym_null_literal] = ACTIONS(3845),
    [anon_sym_SQUOTE] = ACTIONS(3847),
    [sym_integer_literal] = ACTIONS(3845),
    [sym_real_literal] = ACTIONS(3847),
    [anon_sym_DQUOTE] = ACTIONS(3847),
    [sym_verbatim_string_literal] = ACTIONS(3847),
    [aux_sym_preproc_if_token1] = ACTIONS(3847),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3847),
    [sym_interpolation_verbatim_start] = ACTIONS(3847),
    [sym_interpolation_raw_start] = ACTIONS(3847),
    [sym_raw_string_start] = ACTIONS(3847),
  },
  [2581] = {
    [sym_preproc_region] = STATE(2581),
    [sym_preproc_endregion] = STATE(2581),
    [sym_preproc_line] = STATE(2581),
    [sym_preproc_pragma] = STATE(2581),
    [sym_preproc_nullable] = STATE(2581),
    [sym_preproc_error] = STATE(2581),
    [sym_preproc_warning] = STATE(2581),
    [sym_preproc_define] = STATE(2581),
    [sym_preproc_undef] = STATE(2581),
    [ts_builtin_sym_end] = ACTIONS(4016),
    [sym__identifier_token] = ACTIONS(4018),
    [anon_sym_extern] = ACTIONS(4018),
    [anon_sym_alias] = ACTIONS(4018),
    [anon_sym_SEMI] = ACTIONS(4016),
    [anon_sym_global] = ACTIONS(4018),
    [anon_sym_using] = ACTIONS(4018),
    [anon_sym_unsafe] = ACTIONS(4018),
    [anon_sym_static] = ACTIONS(4018),
    [anon_sym_LBRACK] = ACTIONS(4016),
    [anon_sym_LPAREN] = ACTIONS(4016),
    [anon_sym_return] = ACTIONS(4018),
    [anon_sym_namespace] = ACTIONS(4018),
    [anon_sym_class] = ACTIONS(4018),
    [anon_sym_ref] = ACTIONS(4018),
    [anon_sym_struct] = ACTIONS(4018),
    [anon_sym_enum] = ACTIONS(4018),
    [anon_sym_LBRACE] = ACTIONS(4016),
    [anon_sym_interface] = ACTIONS(4018),
    [anon_sym_delegate] = ACTIONS(4018),
    [anon_sym_record] = ACTIONS(4018),
    [anon_sym_abstract] = ACTIONS(4018),
    [anon_sym_async] = ACTIONS(4018),
    [anon_sym_const] = ACTIONS(4018),
    [anon_sym_file] = ACTIONS(4018),
    [anon_sym_fixed] = ACTIONS(4018),
    [anon_sym_internal] = ACTIONS(4018),
    [anon_sym_new] = ACTIONS(4018),
    [anon_sym_override] = ACTIONS(4018),
    [anon_sym_partial] = ACTIONS(4018),
    [anon_sym_private] = ACTIONS(4018),
    [anon_sym_protected] = ACTIONS(4018),
    [anon_sym_public] = ACTIONS(4018),
    [anon_sym_readonly] = ACTIONS(4018),
    [anon_sym_required] = ACTIONS(4018),
    [anon_sym_sealed] = ACTIONS(4018),
    [anon_sym_virtual] = ACTIONS(4018),
    [anon_sym_volatile] = ACTIONS(4018),
    [anon_sym_where] = ACTIONS(4018),
    [anon_sym_notnull] = ACTIONS(4018),
    [anon_sym_unmanaged] = ACTIONS(4018),
    [anon_sym_checked] = ACTIONS(4018),
    [anon_sym_BANG] = ACTIONS(4016),
    [anon_sym_TILDE] = ACTIONS(4016),
    [anon_sym_PLUS_PLUS] = ACTIONS(4016),
    [anon_sym_DASH_DASH] = ACTIONS(4016),
    [anon_sym_true] = ACTIONS(4018),
    [anon_sym_false] = ACTIONS(4018),
    [anon_sym_PLUS] = ACTIONS(4018),
    [anon_sym_DASH] = ACTIONS(4018),
    [anon_sym_STAR] = ACTIONS(4016),
    [anon_sym_CARET] = ACTIONS(4016),
    [anon_sym_AMP] = ACTIONS(4016),
    [anon_sym_this] = ACTIONS(4018),
    [anon_sym_scoped] = ACTIONS(4018),
    [anon_sym_base] = ACTIONS(4018),
    [anon_sym_var] = ACTIONS(4018),
    [sym_predefined_type] = ACTIONS(4018),
    [anon_sym_break] = ACTIONS(4018),
    [anon_sym_unchecked] = ACTIONS(4018),
    [anon_sym_continue] = ACTIONS(4018),
    [anon_sym_do] = ACTIONS(4018),
    [anon_sym_while] = ACTIONS(4018),
    [anon_sym_for] = ACTIONS(4018),
    [anon_sym_lock] = ACTIONS(4018),
    [anon_sym_yield] = ACTIONS(4018),
    [anon_sym_switch] = ACTIONS(4018),
    [anon_sym_default] = ACTIONS(4018),
    [anon_sym_throw] = ACTIONS(4018),
    [anon_sym_try] = ACTIONS(4018),
    [anon_sym_when] = ACTIONS(4018),
    [anon_sym_await] = ACTIONS(4018),
    [anon_sym_foreach] = ACTIONS(4018),
    [anon_sym_goto] = ACTIONS(4018),
    [anon_sym_if] = ACTIONS(4018),
    [anon_sym_DOT_DOT] = ACTIONS(4016),
    [anon_sym_from] = ACTIONS(4018),
    [anon_sym_into] = ACTIONS(4018),
    [anon_sym_join] = ACTIONS(4018),
    [anon_sym_on] = ACTIONS(4018),
    [anon_sym_equals] = ACTIONS(4018),
    [anon_sym_let] = ACTIONS(4018),
    [anon_sym_orderby] = ACTIONS(4018),
    [anon_sym_ascending] = ACTIONS(4018),
    [anon_sym_descending] = ACTIONS(4018),
    [anon_sym_group] = ACTIONS(4018),
    [anon_sym_by] = ACTIONS(4018),
    [anon_sym_select] = ACTIONS(4018),
    [anon_sym_stackalloc] = ACTIONS(4018),
    [anon_sym_sizeof] = ACTIONS(4018),
    [anon_sym_typeof] = ACTIONS(4018),
    [anon_sym___makeref] = ACTIONS(4018),
    [anon_sym___reftype] = ACTIONS(4018),
    [anon_sym___refvalue] = ACTIONS(4018),
    [sym_null_literal] = ACTIONS(4018),
    [anon_sym_SQUOTE] = ACTIONS(4016),
    [sym_integer_literal] = ACTIONS(4018),
    [sym_real_literal] = ACTIONS(4016),
    [anon_sym_DQUOTE] = ACTIONS(4016),
    [sym_verbatim_string_literal] = ACTIONS(4016),
    [aux_sym_preproc_if_token1] = ACTIONS(4016),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(4016),
    [sym_interpolation_verbatim_start] = ACTIONS(4016),
    [sym_interpolation_raw_start] = ACTIONS(4016),
    [sym_raw_string_start] = ACTIONS(4016),
  },
  [2582] = {
    [sym_preproc_region] = STATE(2582),
    [sym_preproc_endregion] = STATE(2582),
    [sym_preproc_line] = STATE(2582),
    [sym_preproc_pragma] = STATE(2582),
    [sym_preproc_nullable] = STATE(2582),
    [sym_preproc_error] = STATE(2582),
    [sym_preproc_warning] = STATE(2582),
    [sym_preproc_define] = STATE(2582),
    [sym_preproc_undef] = STATE(2582),
    [ts_builtin_sym_end] = ACTIONS(3551),
    [sym__identifier_token] = ACTIONS(3549),
    [anon_sym_extern] = ACTIONS(3549),
    [anon_sym_alias] = ACTIONS(3549),
    [anon_sym_SEMI] = ACTIONS(3551),
    [anon_sym_global] = ACTIONS(3549),
    [anon_sym_using] = ACTIONS(3549),
    [anon_sym_unsafe] = ACTIONS(3549),
    [anon_sym_static] = ACTIONS(3549),
    [anon_sym_LBRACK] = ACTIONS(3551),
    [anon_sym_LPAREN] = ACTIONS(3551),
    [anon_sym_return] = ACTIONS(3549),
    [anon_sym_namespace] = ACTIONS(3549),
    [anon_sym_class] = ACTIONS(3549),
    [anon_sym_ref] = ACTIONS(3549),
    [anon_sym_struct] = ACTIONS(3549),
    [anon_sym_enum] = ACTIONS(3549),
    [anon_sym_LBRACE] = ACTIONS(3551),
    [anon_sym_interface] = ACTIONS(3549),
    [anon_sym_delegate] = ACTIONS(3549),
    [anon_sym_record] = ACTIONS(3549),
    [anon_sym_abstract] = ACTIONS(3549),
    [anon_sym_async] = ACTIONS(3549),
    [anon_sym_const] = ACTIONS(3549),
    [anon_sym_file] = ACTIONS(3549),
    [anon_sym_fixed] = ACTIONS(3549),
    [anon_sym_internal] = ACTIONS(3549),
    [anon_sym_new] = ACTIONS(3549),
    [anon_sym_override] = ACTIONS(3549),
    [anon_sym_partial] = ACTIONS(3549),
    [anon_sym_private] = ACTIONS(3549),
    [anon_sym_protected] = ACTIONS(3549),
    [anon_sym_public] = ACTIONS(3549),
    [anon_sym_readonly] = ACTIONS(3549),
    [anon_sym_required] = ACTIONS(3549),
    [anon_sym_sealed] = ACTIONS(3549),
    [anon_sym_virtual] = ACTIONS(3549),
    [anon_sym_volatile] = ACTIONS(3549),
    [anon_sym_where] = ACTIONS(3549),
    [anon_sym_notnull] = ACTIONS(3549),
    [anon_sym_unmanaged] = ACTIONS(3549),
    [anon_sym_checked] = ACTIONS(3549),
    [anon_sym_BANG] = ACTIONS(3551),
    [anon_sym_TILDE] = ACTIONS(3551),
    [anon_sym_PLUS_PLUS] = ACTIONS(3551),
    [anon_sym_DASH_DASH] = ACTIONS(3551),
    [anon_sym_true] = ACTIONS(3549),
    [anon_sym_false] = ACTIONS(3549),
    [anon_sym_PLUS] = ACTIONS(3549),
    [anon_sym_DASH] = ACTIONS(3549),
    [anon_sym_STAR] = ACTIONS(3551),
    [anon_sym_CARET] = ACTIONS(3551),
    [anon_sym_AMP] = ACTIONS(3551),
    [anon_sym_this] = ACTIONS(3549),
    [anon_sym_scoped] = ACTIONS(3549),
    [anon_sym_base] = ACTIONS(3549),
    [anon_sym_var] = ACTIONS(3549),
    [sym_predefined_type] = ACTIONS(3549),
    [anon_sym_break] = ACTIONS(3549),
    [anon_sym_unchecked] = ACTIONS(3549),
    [anon_sym_continue] = ACTIONS(3549),
    [anon_sym_do] = ACTIONS(3549),
    [anon_sym_while] = ACTIONS(3549),
    [anon_sym_for] = ACTIONS(3549),
    [anon_sym_lock] = ACTIONS(3549),
    [anon_sym_yield] = ACTIONS(3549),
    [anon_sym_switch] = ACTIONS(3549),
    [anon_sym_default] = ACTIONS(3549),
    [anon_sym_throw] = ACTIONS(3549),
    [anon_sym_try] = ACTIONS(3549),
    [anon_sym_when] = ACTIONS(3549),
    [anon_sym_await] = ACTIONS(3549),
    [anon_sym_foreach] = ACTIONS(3549),
    [anon_sym_goto] = ACTIONS(3549),
    [anon_sym_if] = ACTIONS(3549),
    [anon_sym_DOT_DOT] = ACTIONS(3551),
    [anon_sym_from] = ACTIONS(3549),
    [anon_sym_into] = ACTIONS(3549),
    [anon_sym_join] = ACTIONS(3549),
    [anon_sym_on] = ACTIONS(3549),
    [anon_sym_equals] = ACTIONS(3549),
    [anon_sym_let] = ACTIONS(3549),
    [anon_sym_orderby] = ACTIONS(3549),
    [anon_sym_ascending] = ACTIONS(3549),
    [anon_sym_descending] = ACTIONS(3549),
    [anon_sym_group] = ACTIONS(3549),
    [anon_sym_by] = ACTIONS(3549),
    [anon_sym_select] = ACTIONS(3549),
    [anon_sym_stackalloc] = ACTIONS(3549),
    [anon_sym_sizeof] = ACTIONS(3549),
    [anon_sym_typeof] = ACTIONS(3549),
    [anon_sym___makeref] = ACTIONS(3549),
    [anon_sym___reftype] = ACTIONS(3549),
    [anon_sym___refvalue] = ACTIONS(3549),
    [sym_null_literal] = ACTIONS(3549),
    [anon_sym_SQUOTE] = ACTIONS(3551),
    [sym_integer_literal] = ACTIONS(3549),
    [sym_real_literal] = ACTIONS(3551),
    [anon_sym_DQUOTE] = ACTIONS(3551),
    [sym_verbatim_string_literal] = ACTIONS(3551),
    [aux_sym_preproc_if_token1] = ACTIONS(3551),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3551),
    [sym_interpolation_verbatim_start] = ACTIONS(3551),
    [sym_interpolation_raw_start] = ACTIONS(3551),
    [sym_raw_string_start] = ACTIONS(3551),
  },
  [2583] = {
    [sym_preproc_region] = STATE(2583),
    [sym_preproc_endregion] = STATE(2583),
    [sym_preproc_line] = STATE(2583),
    [sym_preproc_pragma] = STATE(2583),
    [sym_preproc_nullable] = STATE(2583),
    [sym_preproc_error] = STATE(2583),
    [sym_preproc_warning] = STATE(2583),
    [sym_preproc_define] = STATE(2583),
    [sym_preproc_undef] = STATE(2583),
    [ts_builtin_sym_end] = ACTIONS(3555),
    [sym__identifier_token] = ACTIONS(3553),
    [anon_sym_extern] = ACTIONS(3553),
    [anon_sym_alias] = ACTIONS(3553),
    [anon_sym_SEMI] = ACTIONS(3555),
    [anon_sym_global] = ACTIONS(3553),
    [anon_sym_using] = ACTIONS(3553),
    [anon_sym_unsafe] = ACTIONS(3553),
    [anon_sym_static] = ACTIONS(3553),
    [anon_sym_LBRACK] = ACTIONS(3555),
    [anon_sym_LPAREN] = ACTIONS(3555),
    [anon_sym_return] = ACTIONS(3553),
    [anon_sym_namespace] = ACTIONS(3553),
    [anon_sym_class] = ACTIONS(3553),
    [anon_sym_ref] = ACTIONS(3553),
    [anon_sym_struct] = ACTIONS(3553),
    [anon_sym_enum] = ACTIONS(3553),
    [anon_sym_LBRACE] = ACTIONS(3555),
    [anon_sym_interface] = ACTIONS(3553),
    [anon_sym_delegate] = ACTIONS(3553),
    [anon_sym_record] = ACTIONS(3553),
    [anon_sym_abstract] = ACTIONS(3553),
    [anon_sym_async] = ACTIONS(3553),
    [anon_sym_const] = ACTIONS(3553),
    [anon_sym_file] = ACTIONS(3553),
    [anon_sym_fixed] = ACTIONS(3553),
    [anon_sym_internal] = ACTIONS(3553),
    [anon_sym_new] = ACTIONS(3553),
    [anon_sym_override] = ACTIONS(3553),
    [anon_sym_partial] = ACTIONS(3553),
    [anon_sym_private] = ACTIONS(3553),
    [anon_sym_protected] = ACTIONS(3553),
    [anon_sym_public] = ACTIONS(3553),
    [anon_sym_readonly] = ACTIONS(3553),
    [anon_sym_required] = ACTIONS(3553),
    [anon_sym_sealed] = ACTIONS(3553),
    [anon_sym_virtual] = ACTIONS(3553),
    [anon_sym_volatile] = ACTIONS(3553),
    [anon_sym_where] = ACTIONS(3553),
    [anon_sym_notnull] = ACTIONS(3553),
    [anon_sym_unmanaged] = ACTIONS(3553),
    [anon_sym_checked] = ACTIONS(3553),
    [anon_sym_BANG] = ACTIONS(3555),
    [anon_sym_TILDE] = ACTIONS(3555),
    [anon_sym_PLUS_PLUS] = ACTIONS(3555),
    [anon_sym_DASH_DASH] = ACTIONS(3555),
    [anon_sym_true] = ACTIONS(3553),
    [anon_sym_false] = ACTIONS(3553),
    [anon_sym_PLUS] = ACTIONS(3553),
    [anon_sym_DASH] = ACTIONS(3553),
    [anon_sym_STAR] = ACTIONS(3555),
    [anon_sym_CARET] = ACTIONS(3555),
    [anon_sym_AMP] = ACTIONS(3555),
    [anon_sym_this] = ACTIONS(3553),
    [anon_sym_scoped] = ACTIONS(3553),
    [anon_sym_base] = ACTIONS(3553),
    [anon_sym_var] = ACTIONS(3553),
    [sym_predefined_type] = ACTIONS(3553),
    [anon_sym_break] = ACTIONS(3553),
    [anon_sym_unchecked] = ACTIONS(3553),
    [anon_sym_continue] = ACTIONS(3553),
    [anon_sym_do] = ACTIONS(3553),
    [anon_sym_while] = ACTIONS(3553),
    [anon_sym_for] = ACTIONS(3553),
    [anon_sym_lock] = ACTIONS(3553),
    [anon_sym_yield] = ACTIONS(3553),
    [anon_sym_switch] = ACTIONS(3553),
    [anon_sym_default] = ACTIONS(3553),
    [anon_sym_throw] = ACTIONS(3553),
    [anon_sym_try] = ACTIONS(3553),
    [anon_sym_when] = ACTIONS(3553),
    [anon_sym_await] = ACTIONS(3553),
    [anon_sym_foreach] = ACTIONS(3553),
    [anon_sym_goto] = ACTIONS(3553),
    [anon_sym_if] = ACTIONS(3553),
    [anon_sym_DOT_DOT] = ACTIONS(3555),
    [anon_sym_from] = ACTIONS(3553),
    [anon_sym_into] = ACTIONS(3553),
    [anon_sym_join] = ACTIONS(3553),
    [anon_sym_on] = ACTIONS(3553),
    [anon_sym_equals] = ACTIONS(3553),
    [anon_sym_let] = ACTIONS(3553),
    [anon_sym_orderby] = ACTIONS(3553),
    [anon_sym_ascending] = ACTIONS(3553),
    [anon_sym_descending] = ACTIONS(3553),
    [anon_sym_group] = ACTIONS(3553),
    [anon_sym_by] = ACTIONS(3553),
    [anon_sym_select] = ACTIONS(3553),
    [anon_sym_stackalloc] = ACTIONS(3553),
    [anon_sym_sizeof] = ACTIONS(3553),
    [anon_sym_typeof] = ACTIONS(3553),
    [anon_sym___makeref] = ACTIONS(3553),
    [anon_sym___reftype] = ACTIONS(3553),
    [anon_sym___refvalue] = ACTIONS(3553),
    [sym_null_literal] = ACTIONS(3553),
    [anon_sym_SQUOTE] = ACTIONS(3555),
    [sym_integer_literal] = ACTIONS(3553),
    [sym_real_literal] = ACTIONS(3555),
    [anon_sym_DQUOTE] = ACTIONS(3555),
    [sym_verbatim_string_literal] = ACTIONS(3555),
    [aux_sym_preproc_if_token1] = ACTIONS(3555),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3555),
    [sym_interpolation_verbatim_start] = ACTIONS(3555),
    [sym_interpolation_raw_start] = ACTIONS(3555),
    [sym_raw_string_start] = ACTIONS(3555),
  },
  [2584] = {
    [sym_preproc_region] = STATE(2584),
    [sym_preproc_endregion] = STATE(2584),
    [sym_preproc_line] = STATE(2584),
    [sym_preproc_pragma] = STATE(2584),
    [sym_preproc_nullable] = STATE(2584),
    [sym_preproc_error] = STATE(2584),
    [sym_preproc_warning] = STATE(2584),
    [sym_preproc_define] = STATE(2584),
    [sym_preproc_undef] = STATE(2584),
    [ts_builtin_sym_end] = ACTIONS(3623),
    [sym__identifier_token] = ACTIONS(3621),
    [anon_sym_extern] = ACTIONS(3621),
    [anon_sym_alias] = ACTIONS(3621),
    [anon_sym_SEMI] = ACTIONS(3623),
    [anon_sym_global] = ACTIONS(3621),
    [anon_sym_using] = ACTIONS(3621),
    [anon_sym_unsafe] = ACTIONS(3621),
    [anon_sym_static] = ACTIONS(3621),
    [anon_sym_LBRACK] = ACTIONS(3623),
    [anon_sym_LPAREN] = ACTIONS(3623),
    [anon_sym_return] = ACTIONS(3621),
    [anon_sym_namespace] = ACTIONS(3621),
    [anon_sym_class] = ACTIONS(3621),
    [anon_sym_ref] = ACTIONS(3621),
    [anon_sym_struct] = ACTIONS(3621),
    [anon_sym_enum] = ACTIONS(3621),
    [anon_sym_LBRACE] = ACTIONS(3623),
    [anon_sym_interface] = ACTIONS(3621),
    [anon_sym_delegate] = ACTIONS(3621),
    [anon_sym_record] = ACTIONS(3621),
    [anon_sym_abstract] = ACTIONS(3621),
    [anon_sym_async] = ACTIONS(3621),
    [anon_sym_const] = ACTIONS(3621),
    [anon_sym_file] = ACTIONS(3621),
    [anon_sym_fixed] = ACTIONS(3621),
    [anon_sym_internal] = ACTIONS(3621),
    [anon_sym_new] = ACTIONS(3621),
    [anon_sym_override] = ACTIONS(3621),
    [anon_sym_partial] = ACTIONS(3621),
    [anon_sym_private] = ACTIONS(3621),
    [anon_sym_protected] = ACTIONS(3621),
    [anon_sym_public] = ACTIONS(3621),
    [anon_sym_readonly] = ACTIONS(3621),
    [anon_sym_required] = ACTIONS(3621),
    [anon_sym_sealed] = ACTIONS(3621),
    [anon_sym_virtual] = ACTIONS(3621),
    [anon_sym_volatile] = ACTIONS(3621),
    [anon_sym_where] = ACTIONS(3621),
    [anon_sym_notnull] = ACTIONS(3621),
    [anon_sym_unmanaged] = ACTIONS(3621),
    [anon_sym_checked] = ACTIONS(3621),
    [anon_sym_BANG] = ACTIONS(3623),
    [anon_sym_TILDE] = ACTIONS(3623),
    [anon_sym_PLUS_PLUS] = ACTIONS(3623),
    [anon_sym_DASH_DASH] = ACTIONS(3623),
    [anon_sym_true] = ACTIONS(3621),
    [anon_sym_false] = ACTIONS(3621),
    [anon_sym_PLUS] = ACTIONS(3621),
    [anon_sym_DASH] = ACTIONS(3621),
    [anon_sym_STAR] = ACTIONS(3623),
    [anon_sym_CARET] = ACTIONS(3623),
    [anon_sym_AMP] = ACTIONS(3623),
    [anon_sym_this] = ACTIONS(3621),
    [anon_sym_scoped] = ACTIONS(3621),
    [anon_sym_base] = ACTIONS(3621),
    [anon_sym_var] = ACTIONS(3621),
    [sym_predefined_type] = ACTIONS(3621),
    [anon_sym_break] = ACTIONS(3621),
    [anon_sym_unchecked] = ACTIONS(3621),
    [anon_sym_continue] = ACTIONS(3621),
    [anon_sym_do] = ACTIONS(3621),
    [anon_sym_while] = ACTIONS(3621),
    [anon_sym_for] = ACTIONS(3621),
    [anon_sym_lock] = ACTIONS(3621),
    [anon_sym_yield] = ACTIONS(3621),
    [anon_sym_switch] = ACTIONS(3621),
    [anon_sym_default] = ACTIONS(3621),
    [anon_sym_throw] = ACTIONS(3621),
    [anon_sym_try] = ACTIONS(3621),
    [anon_sym_when] = ACTIONS(3621),
    [anon_sym_await] = ACTIONS(3621),
    [anon_sym_foreach] = ACTIONS(3621),
    [anon_sym_goto] = ACTIONS(3621),
    [anon_sym_if] = ACTIONS(3621),
    [anon_sym_DOT_DOT] = ACTIONS(3623),
    [anon_sym_from] = ACTIONS(3621),
    [anon_sym_into] = ACTIONS(3621),
    [anon_sym_join] = ACTIONS(3621),
    [anon_sym_on] = ACTIONS(3621),
    [anon_sym_equals] = ACTIONS(3621),
    [anon_sym_let] = ACTIONS(3621),
    [anon_sym_orderby] = ACTIONS(3621),
    [anon_sym_ascending] = ACTIONS(3621),
    [anon_sym_descending] = ACTIONS(3621),
    [anon_sym_group] = ACTIONS(3621),
    [anon_sym_by] = ACTIONS(3621),
    [anon_sym_select] = ACTIONS(3621),
    [anon_sym_stackalloc] = ACTIONS(3621),
    [anon_sym_sizeof] = ACTIONS(3621),
    [anon_sym_typeof] = ACTIONS(3621),
    [anon_sym___makeref] = ACTIONS(3621),
    [anon_sym___reftype] = ACTIONS(3621),
    [anon_sym___refvalue] = ACTIONS(3621),
    [sym_null_literal] = ACTIONS(3621),
    [anon_sym_SQUOTE] = ACTIONS(3623),
    [sym_integer_literal] = ACTIONS(3621),
    [sym_real_literal] = ACTIONS(3623),
    [anon_sym_DQUOTE] = ACTIONS(3623),
    [sym_verbatim_string_literal] = ACTIONS(3623),
    [aux_sym_preproc_if_token1] = ACTIONS(3623),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3623),
    [sym_interpolation_verbatim_start] = ACTIONS(3623),
    [sym_interpolation_raw_start] = ACTIONS(3623),
    [sym_raw_string_start] = ACTIONS(3623),
  },
  [2585] = {
    [sym_preproc_region] = STATE(2585),
    [sym_preproc_endregion] = STATE(2585),
    [sym_preproc_line] = STATE(2585),
    [sym_preproc_pragma] = STATE(2585),
    [sym_preproc_nullable] = STATE(2585),
    [sym_preproc_error] = STATE(2585),
    [sym_preproc_warning] = STATE(2585),
    [sym_preproc_define] = STATE(2585),
    [sym_preproc_undef] = STATE(2585),
    [ts_builtin_sym_end] = ACTIONS(4020),
    [sym__identifier_token] = ACTIONS(4022),
    [anon_sym_extern] = ACTIONS(4022),
    [anon_sym_alias] = ACTIONS(4022),
    [anon_sym_SEMI] = ACTIONS(4020),
    [anon_sym_global] = ACTIONS(4022),
    [anon_sym_using] = ACTIONS(4022),
    [anon_sym_unsafe] = ACTIONS(4022),
    [anon_sym_static] = ACTIONS(4022),
    [anon_sym_LBRACK] = ACTIONS(4020),
    [anon_sym_LPAREN] = ACTIONS(4020),
    [anon_sym_return] = ACTIONS(4022),
    [anon_sym_namespace] = ACTIONS(4022),
    [anon_sym_class] = ACTIONS(4022),
    [anon_sym_ref] = ACTIONS(4022),
    [anon_sym_struct] = ACTIONS(4022),
    [anon_sym_enum] = ACTIONS(4022),
    [anon_sym_LBRACE] = ACTIONS(4020),
    [anon_sym_interface] = ACTIONS(4022),
    [anon_sym_delegate] = ACTIONS(4022),
    [anon_sym_record] = ACTIONS(4022),
    [anon_sym_abstract] = ACTIONS(4022),
    [anon_sym_async] = ACTIONS(4022),
    [anon_sym_const] = ACTIONS(4022),
    [anon_sym_file] = ACTIONS(4022),
    [anon_sym_fixed] = ACTIONS(4022),
    [anon_sym_internal] = ACTIONS(4022),
    [anon_sym_new] = ACTIONS(4022),
    [anon_sym_override] = ACTIONS(4022),
    [anon_sym_partial] = ACTIONS(4022),
    [anon_sym_private] = ACTIONS(4022),
    [anon_sym_protected] = ACTIONS(4022),
    [anon_sym_public] = ACTIONS(4022),
    [anon_sym_readonly] = ACTIONS(4022),
    [anon_sym_required] = ACTIONS(4022),
    [anon_sym_sealed] = ACTIONS(4022),
    [anon_sym_virtual] = ACTIONS(4022),
    [anon_sym_volatile] = ACTIONS(4022),
    [anon_sym_where] = ACTIONS(4022),
    [anon_sym_notnull] = ACTIONS(4022),
    [anon_sym_unmanaged] = ACTIONS(4022),
    [anon_sym_checked] = ACTIONS(4022),
    [anon_sym_BANG] = ACTIONS(4020),
    [anon_sym_TILDE] = ACTIONS(4020),
    [anon_sym_PLUS_PLUS] = ACTIONS(4020),
    [anon_sym_DASH_DASH] = ACTIONS(4020),
    [anon_sym_true] = ACTIONS(4022),
    [anon_sym_false] = ACTIONS(4022),
    [anon_sym_PLUS] = ACTIONS(4022),
    [anon_sym_DASH] = ACTIONS(4022),
    [anon_sym_STAR] = ACTIONS(4020),
    [anon_sym_CARET] = ACTIONS(4020),
    [anon_sym_AMP] = ACTIONS(4020),
    [anon_sym_this] = ACTIONS(4022),
    [anon_sym_scoped] = ACTIONS(4022),
    [anon_sym_base] = ACTIONS(4022),
    [anon_sym_var] = ACTIONS(4022),
    [sym_predefined_type] = ACTIONS(4022),
    [anon_sym_break] = ACTIONS(4022),
    [anon_sym_unchecked] = ACTIONS(4022),
    [anon_sym_continue] = ACTIONS(4022),
    [anon_sym_do] = ACTIONS(4022),
    [anon_sym_while] = ACTIONS(4022),
    [anon_sym_for] = ACTIONS(4022),
    [anon_sym_lock] = ACTIONS(4022),
    [anon_sym_yield] = ACTIONS(4022),
    [anon_sym_switch] = ACTIONS(4022),
    [anon_sym_default] = ACTIONS(4022),
    [anon_sym_throw] = ACTIONS(4022),
    [anon_sym_try] = ACTIONS(4022),
    [anon_sym_when] = ACTIONS(4022),
    [anon_sym_await] = ACTIONS(4022),
    [anon_sym_foreach] = ACTIONS(4022),
    [anon_sym_goto] = ACTIONS(4022),
    [anon_sym_if] = ACTIONS(4022),
    [anon_sym_DOT_DOT] = ACTIONS(4020),
    [anon_sym_from] = ACTIONS(4022),
    [anon_sym_into] = ACTIONS(4022),
    [anon_sym_join] = ACTIONS(4022),
    [anon_sym_on] = ACTIONS(4022),
    [anon_sym_equals] = ACTIONS(4022),
    [anon_sym_let] = ACTIONS(4022),
    [anon_sym_orderby] = ACTIONS(4022),
    [anon_sym_ascending] = ACTIONS(4022),
    [anon_sym_descending] = ACTIONS(4022),
    [anon_sym_group] = ACTIONS(4022),
    [anon_sym_by] = ACTIONS(4022),
    [anon_sym_select] = ACTIONS(4022),
    [anon_sym_stackalloc] = ACTIONS(4022),
    [anon_sym_sizeof] = ACTIONS(4022),
    [anon_sym_typeof] = ACTIONS(4022),
    [anon_sym___makeref] = ACTIONS(4022),
    [anon_sym___reftype] = ACTIONS(4022),
    [anon_sym___refvalue] = ACTIONS(4022),
    [sym_null_literal] = ACTIONS(4022),
    [anon_sym_SQUOTE] = ACTIONS(4020),
    [sym_integer_literal] = ACTIONS(4022),
    [sym_real_literal] = ACTIONS(4020),
    [anon_sym_DQUOTE] = ACTIONS(4020),
    [sym_verbatim_string_literal] = ACTIONS(4020),
    [aux_sym_preproc_if_token1] = ACTIONS(4020),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(4020),
    [sym_interpolation_verbatim_start] = ACTIONS(4020),
    [sym_interpolation_raw_start] = ACTIONS(4020),
    [sym_raw_string_start] = ACTIONS(4020),
  },
  [2586] = {
    [sym_preproc_region] = STATE(2586),
    [sym_preproc_endregion] = STATE(2586),
    [sym_preproc_line] = STATE(2586),
    [sym_preproc_pragma] = STATE(2586),
    [sym_preproc_nullable] = STATE(2586),
    [sym_preproc_error] = STATE(2586),
    [sym_preproc_warning] = STATE(2586),
    [sym_preproc_define] = STATE(2586),
    [sym_preproc_undef] = STATE(2586),
    [ts_builtin_sym_end] = ACTIONS(3631),
    [sym__identifier_token] = ACTIONS(3629),
    [anon_sym_extern] = ACTIONS(3629),
    [anon_sym_alias] = ACTIONS(3629),
    [anon_sym_SEMI] = ACTIONS(3631),
    [anon_sym_global] = ACTIONS(3629),
    [anon_sym_using] = ACTIONS(3629),
    [anon_sym_unsafe] = ACTIONS(3629),
    [anon_sym_static] = ACTIONS(3629),
    [anon_sym_LBRACK] = ACTIONS(3631),
    [anon_sym_LPAREN] = ACTIONS(3631),
    [anon_sym_return] = ACTIONS(3629),
    [anon_sym_namespace] = ACTIONS(3629),
    [anon_sym_class] = ACTIONS(3629),
    [anon_sym_ref] = ACTIONS(3629),
    [anon_sym_struct] = ACTIONS(3629),
    [anon_sym_enum] = ACTIONS(3629),
    [anon_sym_LBRACE] = ACTIONS(3631),
    [anon_sym_interface] = ACTIONS(3629),
    [anon_sym_delegate] = ACTIONS(3629),
    [anon_sym_record] = ACTIONS(3629),
    [anon_sym_abstract] = ACTIONS(3629),
    [anon_sym_async] = ACTIONS(3629),
    [anon_sym_const] = ACTIONS(3629),
    [anon_sym_file] = ACTIONS(3629),
    [anon_sym_fixed] = ACTIONS(3629),
    [anon_sym_internal] = ACTIONS(3629),
    [anon_sym_new] = ACTIONS(3629),
    [anon_sym_override] = ACTIONS(3629),
    [anon_sym_partial] = ACTIONS(3629),
    [anon_sym_private] = ACTIONS(3629),
    [anon_sym_protected] = ACTIONS(3629),
    [anon_sym_public] = ACTIONS(3629),
    [anon_sym_readonly] = ACTIONS(3629),
    [anon_sym_required] = ACTIONS(3629),
    [anon_sym_sealed] = ACTIONS(3629),
    [anon_sym_virtual] = ACTIONS(3629),
    [anon_sym_volatile] = ACTIONS(3629),
    [anon_sym_where] = ACTIONS(3629),
    [anon_sym_notnull] = ACTIONS(3629),
    [anon_sym_unmanaged] = ACTIONS(3629),
    [anon_sym_checked] = ACTIONS(3629),
    [anon_sym_BANG] = ACTIONS(3631),
    [anon_sym_TILDE] = ACTIONS(3631),
    [anon_sym_PLUS_PLUS] = ACTIONS(3631),
    [anon_sym_DASH_DASH] = ACTIONS(3631),
    [anon_sym_true] = ACTIONS(3629),
    [anon_sym_false] = ACTIONS(3629),
    [anon_sym_PLUS] = ACTIONS(3629),
    [anon_sym_DASH] = ACTIONS(3629),
    [anon_sym_STAR] = ACTIONS(3631),
    [anon_sym_CARET] = ACTIONS(3631),
    [anon_sym_AMP] = ACTIONS(3631),
    [anon_sym_this] = ACTIONS(3629),
    [anon_sym_scoped] = ACTIONS(3629),
    [anon_sym_base] = ACTIONS(3629),
    [anon_sym_var] = ACTIONS(3629),
    [sym_predefined_type] = ACTIONS(3629),
    [anon_sym_break] = ACTIONS(3629),
    [anon_sym_unchecked] = ACTIONS(3629),
    [anon_sym_continue] = ACTIONS(3629),
    [anon_sym_do] = ACTIONS(3629),
    [anon_sym_while] = ACTIONS(3629),
    [anon_sym_for] = ACTIONS(3629),
    [anon_sym_lock] = ACTIONS(3629),
    [anon_sym_yield] = ACTIONS(3629),
    [anon_sym_switch] = ACTIONS(3629),
    [anon_sym_default] = ACTIONS(3629),
    [anon_sym_throw] = ACTIONS(3629),
    [anon_sym_try] = ACTIONS(3629),
    [anon_sym_when] = ACTIONS(3629),
    [anon_sym_await] = ACTIONS(3629),
    [anon_sym_foreach] = ACTIONS(3629),
    [anon_sym_goto] = ACTIONS(3629),
    [anon_sym_if] = ACTIONS(3629),
    [anon_sym_DOT_DOT] = ACTIONS(3631),
    [anon_sym_from] = ACTIONS(3629),
    [anon_sym_into] = ACTIONS(3629),
    [anon_sym_join] = ACTIONS(3629),
    [anon_sym_on] = ACTIONS(3629),
    [anon_sym_equals] = ACTIONS(3629),
    [anon_sym_let] = ACTIONS(3629),
    [anon_sym_orderby] = ACTIONS(3629),
    [anon_sym_ascending] = ACTIONS(3629),
    [anon_sym_descending] = ACTIONS(3629),
    [anon_sym_group] = ACTIONS(3629),
    [anon_sym_by] = ACTIONS(3629),
    [anon_sym_select] = ACTIONS(3629),
    [anon_sym_stackalloc] = ACTIONS(3629),
    [anon_sym_sizeof] = ACTIONS(3629),
    [anon_sym_typeof] = ACTIONS(3629),
    [anon_sym___makeref] = ACTIONS(3629),
    [anon_sym___reftype] = ACTIONS(3629),
    [anon_sym___refvalue] = ACTIONS(3629),
    [sym_null_literal] = ACTIONS(3629),
    [anon_sym_SQUOTE] = ACTIONS(3631),
    [sym_integer_literal] = ACTIONS(3629),
    [sym_real_literal] = ACTIONS(3631),
    [anon_sym_DQUOTE] = ACTIONS(3631),
    [sym_verbatim_string_literal] = ACTIONS(3631),
    [aux_sym_preproc_if_token1] = ACTIONS(3631),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3631),
    [sym_interpolation_verbatim_start] = ACTIONS(3631),
    [sym_interpolation_raw_start] = ACTIONS(3631),
    [sym_raw_string_start] = ACTIONS(3631),
  },
  [2587] = {
    [sym_preproc_region] = STATE(2587),
    [sym_preproc_endregion] = STATE(2587),
    [sym_preproc_line] = STATE(2587),
    [sym_preproc_pragma] = STATE(2587),
    [sym_preproc_nullable] = STATE(2587),
    [sym_preproc_error] = STATE(2587),
    [sym_preproc_warning] = STATE(2587),
    [sym_preproc_define] = STATE(2587),
    [sym_preproc_undef] = STATE(2587),
    [ts_builtin_sym_end] = ACTIONS(3635),
    [sym__identifier_token] = ACTIONS(3633),
    [anon_sym_extern] = ACTIONS(3633),
    [anon_sym_alias] = ACTIONS(3633),
    [anon_sym_SEMI] = ACTIONS(3635),
    [anon_sym_global] = ACTIONS(3633),
    [anon_sym_using] = ACTIONS(3633),
    [anon_sym_unsafe] = ACTIONS(3633),
    [anon_sym_static] = ACTIONS(3633),
    [anon_sym_LBRACK] = ACTIONS(3635),
    [anon_sym_LPAREN] = ACTIONS(3635),
    [anon_sym_return] = ACTIONS(3633),
    [anon_sym_namespace] = ACTIONS(3633),
    [anon_sym_class] = ACTIONS(3633),
    [anon_sym_ref] = ACTIONS(3633),
    [anon_sym_struct] = ACTIONS(3633),
    [anon_sym_enum] = ACTIONS(3633),
    [anon_sym_LBRACE] = ACTIONS(3635),
    [anon_sym_interface] = ACTIONS(3633),
    [anon_sym_delegate] = ACTIONS(3633),
    [anon_sym_record] = ACTIONS(3633),
    [anon_sym_abstract] = ACTIONS(3633),
    [anon_sym_async] = ACTIONS(3633),
    [anon_sym_const] = ACTIONS(3633),
    [anon_sym_file] = ACTIONS(3633),
    [anon_sym_fixed] = ACTIONS(3633),
    [anon_sym_internal] = ACTIONS(3633),
    [anon_sym_new] = ACTIONS(3633),
    [anon_sym_override] = ACTIONS(3633),
    [anon_sym_partial] = ACTIONS(3633),
    [anon_sym_private] = ACTIONS(3633),
    [anon_sym_protected] = ACTIONS(3633),
    [anon_sym_public] = ACTIONS(3633),
    [anon_sym_readonly] = ACTIONS(3633),
    [anon_sym_required] = ACTIONS(3633),
    [anon_sym_sealed] = ACTIONS(3633),
    [anon_sym_virtual] = ACTIONS(3633),
    [anon_sym_volatile] = ACTIONS(3633),
    [anon_sym_where] = ACTIONS(3633),
    [anon_sym_notnull] = ACTIONS(3633),
    [anon_sym_unmanaged] = ACTIONS(3633),
    [anon_sym_checked] = ACTIONS(3633),
    [anon_sym_BANG] = ACTIONS(3635),
    [anon_sym_TILDE] = ACTIONS(3635),
    [anon_sym_PLUS_PLUS] = ACTIONS(3635),
    [anon_sym_DASH_DASH] = ACTIONS(3635),
    [anon_sym_true] = ACTIONS(3633),
    [anon_sym_false] = ACTIONS(3633),
    [anon_sym_PLUS] = ACTIONS(3633),
    [anon_sym_DASH] = ACTIONS(3633),
    [anon_sym_STAR] = ACTIONS(3635),
    [anon_sym_CARET] = ACTIONS(3635),
    [anon_sym_AMP] = ACTIONS(3635),
    [anon_sym_this] = ACTIONS(3633),
    [anon_sym_scoped] = ACTIONS(3633),
    [anon_sym_base] = ACTIONS(3633),
    [anon_sym_var] = ACTIONS(3633),
    [sym_predefined_type] = ACTIONS(3633),
    [anon_sym_break] = ACTIONS(3633),
    [anon_sym_unchecked] = ACTIONS(3633),
    [anon_sym_continue] = ACTIONS(3633),
    [anon_sym_do] = ACTIONS(3633),
    [anon_sym_while] = ACTIONS(3633),
    [anon_sym_for] = ACTIONS(3633),
    [anon_sym_lock] = ACTIONS(3633),
    [anon_sym_yield] = ACTIONS(3633),
    [anon_sym_switch] = ACTIONS(3633),
    [anon_sym_default] = ACTIONS(3633),
    [anon_sym_throw] = ACTIONS(3633),
    [anon_sym_try] = ACTIONS(3633),
    [anon_sym_when] = ACTIONS(3633),
    [anon_sym_await] = ACTIONS(3633),
    [anon_sym_foreach] = ACTIONS(3633),
    [anon_sym_goto] = ACTIONS(3633),
    [anon_sym_if] = ACTIONS(3633),
    [anon_sym_DOT_DOT] = ACTIONS(3635),
    [anon_sym_from] = ACTIONS(3633),
    [anon_sym_into] = ACTIONS(3633),
    [anon_sym_join] = ACTIONS(3633),
    [anon_sym_on] = ACTIONS(3633),
    [anon_sym_equals] = ACTIONS(3633),
    [anon_sym_let] = ACTIONS(3633),
    [anon_sym_orderby] = ACTIONS(3633),
    [anon_sym_ascending] = ACTIONS(3633),
    [anon_sym_descending] = ACTIONS(3633),
    [anon_sym_group] = ACTIONS(3633),
    [anon_sym_by] = ACTIONS(3633),
    [anon_sym_select] = ACTIONS(3633),
    [anon_sym_stackalloc] = ACTIONS(3633),
    [anon_sym_sizeof] = ACTIONS(3633),
    [anon_sym_typeof] = ACTIONS(3633),
    [anon_sym___makeref] = ACTIONS(3633),
    [anon_sym___reftype] = ACTIONS(3633),
    [anon_sym___refvalue] = ACTIONS(3633),
    [sym_null_literal] = ACTIONS(3633),
    [anon_sym_SQUOTE] = ACTIONS(3635),
    [sym_integer_literal] = ACTIONS(3633),
    [sym_real_literal] = ACTIONS(3635),
    [anon_sym_DQUOTE] = ACTIONS(3635),
    [sym_verbatim_string_literal] = ACTIONS(3635),
    [aux_sym_preproc_if_token1] = ACTIONS(3635),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3635),
    [sym_interpolation_verbatim_start] = ACTIONS(3635),
    [sym_interpolation_raw_start] = ACTIONS(3635),
    [sym_raw_string_start] = ACTIONS(3635),
  },
  [2588] = {
    [sym_preproc_region] = STATE(2588),
    [sym_preproc_endregion] = STATE(2588),
    [sym_preproc_line] = STATE(2588),
    [sym_preproc_pragma] = STATE(2588),
    [sym_preproc_nullable] = STATE(2588),
    [sym_preproc_error] = STATE(2588),
    [sym_preproc_warning] = STATE(2588),
    [sym_preproc_define] = STATE(2588),
    [sym_preproc_undef] = STATE(2588),
    [ts_builtin_sym_end] = ACTIONS(3639),
    [sym__identifier_token] = ACTIONS(3637),
    [anon_sym_extern] = ACTIONS(3637),
    [anon_sym_alias] = ACTIONS(3637),
    [anon_sym_SEMI] = ACTIONS(3639),
    [anon_sym_global] = ACTIONS(3637),
    [anon_sym_using] = ACTIONS(3637),
    [anon_sym_unsafe] = ACTIONS(3637),
    [anon_sym_static] = ACTIONS(3637),
    [anon_sym_LBRACK] = ACTIONS(3639),
    [anon_sym_LPAREN] = ACTIONS(3639),
    [anon_sym_return] = ACTIONS(3637),
    [anon_sym_namespace] = ACTIONS(3637),
    [anon_sym_class] = ACTIONS(3637),
    [anon_sym_ref] = ACTIONS(3637),
    [anon_sym_struct] = ACTIONS(3637),
    [anon_sym_enum] = ACTIONS(3637),
    [anon_sym_LBRACE] = ACTIONS(3639),
    [anon_sym_interface] = ACTIONS(3637),
    [anon_sym_delegate] = ACTIONS(3637),
    [anon_sym_record] = ACTIONS(3637),
    [anon_sym_abstract] = ACTIONS(3637),
    [anon_sym_async] = ACTIONS(3637),
    [anon_sym_const] = ACTIONS(3637),
    [anon_sym_file] = ACTIONS(3637),
    [anon_sym_fixed] = ACTIONS(3637),
    [anon_sym_internal] = ACTIONS(3637),
    [anon_sym_new] = ACTIONS(3637),
    [anon_sym_override] = ACTIONS(3637),
    [anon_sym_partial] = ACTIONS(3637),
    [anon_sym_private] = ACTIONS(3637),
    [anon_sym_protected] = ACTIONS(3637),
    [anon_sym_public] = ACTIONS(3637),
    [anon_sym_readonly] = ACTIONS(3637),
    [anon_sym_required] = ACTIONS(3637),
    [anon_sym_sealed] = ACTIONS(3637),
    [anon_sym_virtual] = ACTIONS(3637),
    [anon_sym_volatile] = ACTIONS(3637),
    [anon_sym_where] = ACTIONS(3637),
    [anon_sym_notnull] = ACTIONS(3637),
    [anon_sym_unmanaged] = ACTIONS(3637),
    [anon_sym_checked] = ACTIONS(3637),
    [anon_sym_BANG] = ACTIONS(3639),
    [anon_sym_TILDE] = ACTIONS(3639),
    [anon_sym_PLUS_PLUS] = ACTIONS(3639),
    [anon_sym_DASH_DASH] = ACTIONS(3639),
    [anon_sym_true] = ACTIONS(3637),
    [anon_sym_false] = ACTIONS(3637),
    [anon_sym_PLUS] = ACTIONS(3637),
    [anon_sym_DASH] = ACTIONS(3637),
    [anon_sym_STAR] = ACTIONS(3639),
    [anon_sym_CARET] = ACTIONS(3639),
    [anon_sym_AMP] = ACTIONS(3639),
    [anon_sym_this] = ACTIONS(3637),
    [anon_sym_scoped] = ACTIONS(3637),
    [anon_sym_base] = ACTIONS(3637),
    [anon_sym_var] = ACTIONS(3637),
    [sym_predefined_type] = ACTIONS(3637),
    [anon_sym_break] = ACTIONS(3637),
    [anon_sym_unchecked] = ACTIONS(3637),
    [anon_sym_continue] = ACTIONS(3637),
    [anon_sym_do] = ACTIONS(3637),
    [anon_sym_while] = ACTIONS(3637),
    [anon_sym_for] = ACTIONS(3637),
    [anon_sym_lock] = ACTIONS(3637),
    [anon_sym_yield] = ACTIONS(3637),
    [anon_sym_switch] = ACTIONS(3637),
    [anon_sym_default] = ACTIONS(3637),
    [anon_sym_throw] = ACTIONS(3637),
    [anon_sym_try] = ACTIONS(3637),
    [anon_sym_when] = ACTIONS(3637),
    [anon_sym_await] = ACTIONS(3637),
    [anon_sym_foreach] = ACTIONS(3637),
    [anon_sym_goto] = ACTIONS(3637),
    [anon_sym_if] = ACTIONS(3637),
    [anon_sym_DOT_DOT] = ACTIONS(3639),
    [anon_sym_from] = ACTIONS(3637),
    [anon_sym_into] = ACTIONS(3637),
    [anon_sym_join] = ACTIONS(3637),
    [anon_sym_on] = ACTIONS(3637),
    [anon_sym_equals] = ACTIONS(3637),
    [anon_sym_let] = ACTIONS(3637),
    [anon_sym_orderby] = ACTIONS(3637),
    [anon_sym_ascending] = ACTIONS(3637),
    [anon_sym_descending] = ACTIONS(3637),
    [anon_sym_group] = ACTIONS(3637),
    [anon_sym_by] = ACTIONS(3637),
    [anon_sym_select] = ACTIONS(3637),
    [anon_sym_stackalloc] = ACTIONS(3637),
    [anon_sym_sizeof] = ACTIONS(3637),
    [anon_sym_typeof] = ACTIONS(3637),
    [anon_sym___makeref] = ACTIONS(3637),
    [anon_sym___reftype] = ACTIONS(3637),
    [anon_sym___refvalue] = ACTIONS(3637),
    [sym_null_literal] = ACTIONS(3637),
    [anon_sym_SQUOTE] = ACTIONS(3639),
    [sym_integer_literal] = ACTIONS(3637),
    [sym_real_literal] = ACTIONS(3639),
    [anon_sym_DQUOTE] = ACTIONS(3639),
    [sym_verbatim_string_literal] = ACTIONS(3639),
    [aux_sym_preproc_if_token1] = ACTIONS(3639),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3639),
    [sym_interpolation_verbatim_start] = ACTIONS(3639),
    [sym_interpolation_raw_start] = ACTIONS(3639),
    [sym_raw_string_start] = ACTIONS(3639),
  },
  [2589] = {
    [sym_preproc_region] = STATE(2589),
    [sym_preproc_endregion] = STATE(2589),
    [sym_preproc_line] = STATE(2589),
    [sym_preproc_pragma] = STATE(2589),
    [sym_preproc_nullable] = STATE(2589),
    [sym_preproc_error] = STATE(2589),
    [sym_preproc_warning] = STATE(2589),
    [sym_preproc_define] = STATE(2589),
    [sym_preproc_undef] = STATE(2589),
    [ts_builtin_sym_end] = ACTIONS(3643),
    [sym__identifier_token] = ACTIONS(3641),
    [anon_sym_extern] = ACTIONS(3641),
    [anon_sym_alias] = ACTIONS(3641),
    [anon_sym_SEMI] = ACTIONS(3643),
    [anon_sym_global] = ACTIONS(3641),
    [anon_sym_using] = ACTIONS(3641),
    [anon_sym_unsafe] = ACTIONS(3641),
    [anon_sym_static] = ACTIONS(3641),
    [anon_sym_LBRACK] = ACTIONS(3643),
    [anon_sym_LPAREN] = ACTIONS(3643),
    [anon_sym_return] = ACTIONS(3641),
    [anon_sym_namespace] = ACTIONS(3641),
    [anon_sym_class] = ACTIONS(3641),
    [anon_sym_ref] = ACTIONS(3641),
    [anon_sym_struct] = ACTIONS(3641),
    [anon_sym_enum] = ACTIONS(3641),
    [anon_sym_LBRACE] = ACTIONS(3643),
    [anon_sym_interface] = ACTIONS(3641),
    [anon_sym_delegate] = ACTIONS(3641),
    [anon_sym_record] = ACTIONS(3641),
    [anon_sym_abstract] = ACTIONS(3641),
    [anon_sym_async] = ACTIONS(3641),
    [anon_sym_const] = ACTIONS(3641),
    [anon_sym_file] = ACTIONS(3641),
    [anon_sym_fixed] = ACTIONS(3641),
    [anon_sym_internal] = ACTIONS(3641),
    [anon_sym_new] = ACTIONS(3641),
    [anon_sym_override] = ACTIONS(3641),
    [anon_sym_partial] = ACTIONS(3641),
    [anon_sym_private] = ACTIONS(3641),
    [anon_sym_protected] = ACTIONS(3641),
    [anon_sym_public] = ACTIONS(3641),
    [anon_sym_readonly] = ACTIONS(3641),
    [anon_sym_required] = ACTIONS(3641),
    [anon_sym_sealed] = ACTIONS(3641),
    [anon_sym_virtual] = ACTIONS(3641),
    [anon_sym_volatile] = ACTIONS(3641),
    [anon_sym_where] = ACTIONS(3641),
    [anon_sym_notnull] = ACTIONS(3641),
    [anon_sym_unmanaged] = ACTIONS(3641),
    [anon_sym_checked] = ACTIONS(3641),
    [anon_sym_BANG] = ACTIONS(3643),
    [anon_sym_TILDE] = ACTIONS(3643),
    [anon_sym_PLUS_PLUS] = ACTIONS(3643),
    [anon_sym_DASH_DASH] = ACTIONS(3643),
    [anon_sym_true] = ACTIONS(3641),
    [anon_sym_false] = ACTIONS(3641),
    [anon_sym_PLUS] = ACTIONS(3641),
    [anon_sym_DASH] = ACTIONS(3641),
    [anon_sym_STAR] = ACTIONS(3643),
    [anon_sym_CARET] = ACTIONS(3643),
    [anon_sym_AMP] = ACTIONS(3643),
    [anon_sym_this] = ACTIONS(3641),
    [anon_sym_scoped] = ACTIONS(3641),
    [anon_sym_base] = ACTIONS(3641),
    [anon_sym_var] = ACTIONS(3641),
    [sym_predefined_type] = ACTIONS(3641),
    [anon_sym_break] = ACTIONS(3641),
    [anon_sym_unchecked] = ACTIONS(3641),
    [anon_sym_continue] = ACTIONS(3641),
    [anon_sym_do] = ACTIONS(3641),
    [anon_sym_while] = ACTIONS(3641),
    [anon_sym_for] = ACTIONS(3641),
    [anon_sym_lock] = ACTIONS(3641),
    [anon_sym_yield] = ACTIONS(3641),
    [anon_sym_switch] = ACTIONS(3641),
    [anon_sym_default] = ACTIONS(3641),
    [anon_sym_throw] = ACTIONS(3641),
    [anon_sym_try] = ACTIONS(3641),
    [anon_sym_when] = ACTIONS(3641),
    [anon_sym_await] = ACTIONS(3641),
    [anon_sym_foreach] = ACTIONS(3641),
    [anon_sym_goto] = ACTIONS(3641),
    [anon_sym_if] = ACTIONS(3641),
    [anon_sym_DOT_DOT] = ACTIONS(3643),
    [anon_sym_from] = ACTIONS(3641),
    [anon_sym_into] = ACTIONS(3641),
    [anon_sym_join] = ACTIONS(3641),
    [anon_sym_on] = ACTIONS(3641),
    [anon_sym_equals] = ACTIONS(3641),
    [anon_sym_let] = ACTIONS(3641),
    [anon_sym_orderby] = ACTIONS(3641),
    [anon_sym_ascending] = ACTIONS(3641),
    [anon_sym_descending] = ACTIONS(3641),
    [anon_sym_group] = ACTIONS(3641),
    [anon_sym_by] = ACTIONS(3641),
    [anon_sym_select] = ACTIONS(3641),
    [anon_sym_stackalloc] = ACTIONS(3641),
    [anon_sym_sizeof] = ACTIONS(3641),
    [anon_sym_typeof] = ACTIONS(3641),
    [anon_sym___makeref] = ACTIONS(3641),
    [anon_sym___reftype] = ACTIONS(3641),
    [anon_sym___refvalue] = ACTIONS(3641),
    [sym_null_literal] = ACTIONS(3641),
    [anon_sym_SQUOTE] = ACTIONS(3643),
    [sym_integer_literal] = ACTIONS(3641),
    [sym_real_literal] = ACTIONS(3643),
    [anon_sym_DQUOTE] = ACTIONS(3643),
    [sym_verbatim_string_literal] = ACTIONS(3643),
    [aux_sym_preproc_if_token1] = ACTIONS(3643),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3643),
    [sym_interpolation_verbatim_start] = ACTIONS(3643),
    [sym_interpolation_raw_start] = ACTIONS(3643),
    [sym_raw_string_start] = ACTIONS(3643),
  },
  [2590] = {
    [sym_preproc_region] = STATE(2590),
    [sym_preproc_endregion] = STATE(2590),
    [sym_preproc_line] = STATE(2590),
    [sym_preproc_pragma] = STATE(2590),
    [sym_preproc_nullable] = STATE(2590),
    [sym_preproc_error] = STATE(2590),
    [sym_preproc_warning] = STATE(2590),
    [sym_preproc_define] = STATE(2590),
    [sym_preproc_undef] = STATE(2590),
    [ts_builtin_sym_end] = ACTIONS(3419),
    [sym__identifier_token] = ACTIONS(3417),
    [anon_sym_extern] = ACTIONS(3417),
    [anon_sym_alias] = ACTIONS(3417),
    [anon_sym_SEMI] = ACTIONS(3419),
    [anon_sym_global] = ACTIONS(3417),
    [anon_sym_using] = ACTIONS(3417),
    [anon_sym_unsafe] = ACTIONS(3417),
    [anon_sym_static] = ACTIONS(3417),
    [anon_sym_LBRACK] = ACTIONS(3419),
    [anon_sym_LPAREN] = ACTIONS(3419),
    [anon_sym_return] = ACTIONS(3417),
    [anon_sym_namespace] = ACTIONS(3417),
    [anon_sym_class] = ACTIONS(3417),
    [anon_sym_ref] = ACTIONS(3417),
    [anon_sym_struct] = ACTIONS(3417),
    [anon_sym_enum] = ACTIONS(3417),
    [anon_sym_LBRACE] = ACTIONS(3419),
    [anon_sym_interface] = ACTIONS(3417),
    [anon_sym_delegate] = ACTIONS(3417),
    [anon_sym_record] = ACTIONS(3417),
    [anon_sym_abstract] = ACTIONS(3417),
    [anon_sym_async] = ACTIONS(3417),
    [anon_sym_const] = ACTIONS(3417),
    [anon_sym_file] = ACTIONS(3417),
    [anon_sym_fixed] = ACTIONS(3417),
    [anon_sym_internal] = ACTIONS(3417),
    [anon_sym_new] = ACTIONS(3417),
    [anon_sym_override] = ACTIONS(3417),
    [anon_sym_partial] = ACTIONS(3417),
    [anon_sym_private] = ACTIONS(3417),
    [anon_sym_protected] = ACTIONS(3417),
    [anon_sym_public] = ACTIONS(3417),
    [anon_sym_readonly] = ACTIONS(3417),
    [anon_sym_required] = ACTIONS(3417),
    [anon_sym_sealed] = ACTIONS(3417),
    [anon_sym_virtual] = ACTIONS(3417),
    [anon_sym_volatile] = ACTIONS(3417),
    [anon_sym_where] = ACTIONS(3417),
    [anon_sym_notnull] = ACTIONS(3417),
    [anon_sym_unmanaged] = ACTIONS(3417),
    [anon_sym_checked] = ACTIONS(3417),
    [anon_sym_BANG] = ACTIONS(3419),
    [anon_sym_TILDE] = ACTIONS(3419),
    [anon_sym_PLUS_PLUS] = ACTIONS(3419),
    [anon_sym_DASH_DASH] = ACTIONS(3419),
    [anon_sym_true] = ACTIONS(3417),
    [anon_sym_false] = ACTIONS(3417),
    [anon_sym_PLUS] = ACTIONS(3417),
    [anon_sym_DASH] = ACTIONS(3417),
    [anon_sym_STAR] = ACTIONS(3419),
    [anon_sym_CARET] = ACTIONS(3419),
    [anon_sym_AMP] = ACTIONS(3419),
    [anon_sym_this] = ACTIONS(3417),
    [anon_sym_scoped] = ACTIONS(3417),
    [anon_sym_base] = ACTIONS(3417),
    [anon_sym_var] = ACTIONS(3417),
    [sym_predefined_type] = ACTIONS(3417),
    [anon_sym_break] = ACTIONS(3417),
    [anon_sym_unchecked] = ACTIONS(3417),
    [anon_sym_continue] = ACTIONS(3417),
    [anon_sym_do] = ACTIONS(3417),
    [anon_sym_while] = ACTIONS(3417),
    [anon_sym_for] = ACTIONS(3417),
    [anon_sym_lock] = ACTIONS(3417),
    [anon_sym_yield] = ACTIONS(3417),
    [anon_sym_switch] = ACTIONS(3417),
    [anon_sym_default] = ACTIONS(3417),
    [anon_sym_throw] = ACTIONS(3417),
    [anon_sym_try] = ACTIONS(3417),
    [anon_sym_when] = ACTIONS(3417),
    [anon_sym_await] = ACTIONS(3417),
    [anon_sym_foreach] = ACTIONS(3417),
    [anon_sym_goto] = ACTIONS(3417),
    [anon_sym_if] = ACTIONS(3417),
    [anon_sym_DOT_DOT] = ACTIONS(3419),
    [anon_sym_from] = ACTIONS(3417),
    [anon_sym_into] = ACTIONS(3417),
    [anon_sym_join] = ACTIONS(3417),
    [anon_sym_on] = ACTIONS(3417),
    [anon_sym_equals] = ACTIONS(3417),
    [anon_sym_let] = ACTIONS(3417),
    [anon_sym_orderby] = ACTIONS(3417),
    [anon_sym_ascending] = ACTIONS(3417),
    [anon_sym_descending] = ACTIONS(3417),
    [anon_sym_group] = ACTIONS(3417),
    [anon_sym_by] = ACTIONS(3417),
    [anon_sym_select] = ACTIONS(3417),
    [anon_sym_stackalloc] = ACTIONS(3417),
    [anon_sym_sizeof] = ACTIONS(3417),
    [anon_sym_typeof] = ACTIONS(3417),
    [anon_sym___makeref] = ACTIONS(3417),
    [anon_sym___reftype] = ACTIONS(3417),
    [anon_sym___refvalue] = ACTIONS(3417),
    [sym_null_literal] = ACTIONS(3417),
    [anon_sym_SQUOTE] = ACTIONS(3419),
    [sym_integer_literal] = ACTIONS(3417),
    [sym_real_literal] = ACTIONS(3419),
    [anon_sym_DQUOTE] = ACTIONS(3419),
    [sym_verbatim_string_literal] = ACTIONS(3419),
    [aux_sym_preproc_if_token1] = ACTIONS(3419),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3419),
    [sym_interpolation_verbatim_start] = ACTIONS(3419),
    [sym_interpolation_raw_start] = ACTIONS(3419),
    [sym_raw_string_start] = ACTIONS(3419),
  },
  [2591] = {
    [sym_preproc_region] = STATE(2591),
    [sym_preproc_endregion] = STATE(2591),
    [sym_preproc_line] = STATE(2591),
    [sym_preproc_pragma] = STATE(2591),
    [sym_preproc_nullable] = STATE(2591),
    [sym_preproc_error] = STATE(2591),
    [sym_preproc_warning] = STATE(2591),
    [sym_preproc_define] = STATE(2591),
    [sym_preproc_undef] = STATE(2591),
    [ts_builtin_sym_end] = ACTIONS(3647),
    [sym__identifier_token] = ACTIONS(3645),
    [anon_sym_extern] = ACTIONS(3645),
    [anon_sym_alias] = ACTIONS(3645),
    [anon_sym_SEMI] = ACTIONS(3647),
    [anon_sym_global] = ACTIONS(3645),
    [anon_sym_using] = ACTIONS(3645),
    [anon_sym_unsafe] = ACTIONS(3645),
    [anon_sym_static] = ACTIONS(3645),
    [anon_sym_LBRACK] = ACTIONS(3647),
    [anon_sym_LPAREN] = ACTIONS(3647),
    [anon_sym_return] = ACTIONS(3645),
    [anon_sym_namespace] = ACTIONS(3645),
    [anon_sym_class] = ACTIONS(3645),
    [anon_sym_ref] = ACTIONS(3645),
    [anon_sym_struct] = ACTIONS(3645),
    [anon_sym_enum] = ACTIONS(3645),
    [anon_sym_LBRACE] = ACTIONS(3647),
    [anon_sym_interface] = ACTIONS(3645),
    [anon_sym_delegate] = ACTIONS(3645),
    [anon_sym_record] = ACTIONS(3645),
    [anon_sym_abstract] = ACTIONS(3645),
    [anon_sym_async] = ACTIONS(3645),
    [anon_sym_const] = ACTIONS(3645),
    [anon_sym_file] = ACTIONS(3645),
    [anon_sym_fixed] = ACTIONS(3645),
    [anon_sym_internal] = ACTIONS(3645),
    [anon_sym_new] = ACTIONS(3645),
    [anon_sym_override] = ACTIONS(3645),
    [anon_sym_partial] = ACTIONS(3645),
    [anon_sym_private] = ACTIONS(3645),
    [anon_sym_protected] = ACTIONS(3645),
    [anon_sym_public] = ACTIONS(3645),
    [anon_sym_readonly] = ACTIONS(3645),
    [anon_sym_required] = ACTIONS(3645),
    [anon_sym_sealed] = ACTIONS(3645),
    [anon_sym_virtual] = ACTIONS(3645),
    [anon_sym_volatile] = ACTIONS(3645),
    [anon_sym_where] = ACTIONS(3645),
    [anon_sym_notnull] = ACTIONS(3645),
    [anon_sym_unmanaged] = ACTIONS(3645),
    [anon_sym_checked] = ACTIONS(3645),
    [anon_sym_BANG] = ACTIONS(3647),
    [anon_sym_TILDE] = ACTIONS(3647),
    [anon_sym_PLUS_PLUS] = ACTIONS(3647),
    [anon_sym_DASH_DASH] = ACTIONS(3647),
    [anon_sym_true] = ACTIONS(3645),
    [anon_sym_false] = ACTIONS(3645),
    [anon_sym_PLUS] = ACTIONS(3645),
    [anon_sym_DASH] = ACTIONS(3645),
    [anon_sym_STAR] = ACTIONS(3647),
    [anon_sym_CARET] = ACTIONS(3647),
    [anon_sym_AMP] = ACTIONS(3647),
    [anon_sym_this] = ACTIONS(3645),
    [anon_sym_scoped] = ACTIONS(3645),
    [anon_sym_base] = ACTIONS(3645),
    [anon_sym_var] = ACTIONS(3645),
    [sym_predefined_type] = ACTIONS(3645),
    [anon_sym_break] = ACTIONS(3645),
    [anon_sym_unchecked] = ACTIONS(3645),
    [anon_sym_continue] = ACTIONS(3645),
    [anon_sym_do] = ACTIONS(3645),
    [anon_sym_while] = ACTIONS(3645),
    [anon_sym_for] = ACTIONS(3645),
    [anon_sym_lock] = ACTIONS(3645),
    [anon_sym_yield] = ACTIONS(3645),
    [anon_sym_switch] = ACTIONS(3645),
    [anon_sym_default] = ACTIONS(3645),
    [anon_sym_throw] = ACTIONS(3645),
    [anon_sym_try] = ACTIONS(3645),
    [anon_sym_when] = ACTIONS(3645),
    [anon_sym_await] = ACTIONS(3645),
    [anon_sym_foreach] = ACTIONS(3645),
    [anon_sym_goto] = ACTIONS(3645),
    [anon_sym_if] = ACTIONS(3645),
    [anon_sym_DOT_DOT] = ACTIONS(3647),
    [anon_sym_from] = ACTIONS(3645),
    [anon_sym_into] = ACTIONS(3645),
    [anon_sym_join] = ACTIONS(3645),
    [anon_sym_on] = ACTIONS(3645),
    [anon_sym_equals] = ACTIONS(3645),
    [anon_sym_let] = ACTIONS(3645),
    [anon_sym_orderby] = ACTIONS(3645),
    [anon_sym_ascending] = ACTIONS(3645),
    [anon_sym_descending] = ACTIONS(3645),
    [anon_sym_group] = ACTIONS(3645),
    [anon_sym_by] = ACTIONS(3645),
    [anon_sym_select] = ACTIONS(3645),
    [anon_sym_stackalloc] = ACTIONS(3645),
    [anon_sym_sizeof] = ACTIONS(3645),
    [anon_sym_typeof] = ACTIONS(3645),
    [anon_sym___makeref] = ACTIONS(3645),
    [anon_sym___reftype] = ACTIONS(3645),
    [anon_sym___refvalue] = ACTIONS(3645),
    [sym_null_literal] = ACTIONS(3645),
    [anon_sym_SQUOTE] = ACTIONS(3647),
    [sym_integer_literal] = ACTIONS(3645),
    [sym_real_literal] = ACTIONS(3647),
    [anon_sym_DQUOTE] = ACTIONS(3647),
    [sym_verbatim_string_literal] = ACTIONS(3647),
    [aux_sym_preproc_if_token1] = ACTIONS(3647),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3647),
    [sym_interpolation_verbatim_start] = ACTIONS(3647),
    [sym_interpolation_raw_start] = ACTIONS(3647),
    [sym_raw_string_start] = ACTIONS(3647),
  },
  [2592] = {
    [sym_preproc_region] = STATE(2592),
    [sym_preproc_endregion] = STATE(2592),
    [sym_preproc_line] = STATE(2592),
    [sym_preproc_pragma] = STATE(2592),
    [sym_preproc_nullable] = STATE(2592),
    [sym_preproc_error] = STATE(2592),
    [sym_preproc_warning] = STATE(2592),
    [sym_preproc_define] = STATE(2592),
    [sym_preproc_undef] = STATE(2592),
    [ts_builtin_sym_end] = ACTIONS(3531),
    [sym__identifier_token] = ACTIONS(3529),
    [anon_sym_extern] = ACTIONS(3529),
    [anon_sym_alias] = ACTIONS(3529),
    [anon_sym_SEMI] = ACTIONS(3531),
    [anon_sym_global] = ACTIONS(3529),
    [anon_sym_using] = ACTIONS(3529),
    [anon_sym_unsafe] = ACTIONS(3529),
    [anon_sym_static] = ACTIONS(3529),
    [anon_sym_LBRACK] = ACTIONS(3531),
    [anon_sym_LPAREN] = ACTIONS(3531),
    [anon_sym_return] = ACTIONS(3529),
    [anon_sym_namespace] = ACTIONS(3529),
    [anon_sym_class] = ACTIONS(3529),
    [anon_sym_ref] = ACTIONS(3529),
    [anon_sym_struct] = ACTIONS(3529),
    [anon_sym_enum] = ACTIONS(3529),
    [anon_sym_LBRACE] = ACTIONS(3531),
    [anon_sym_interface] = ACTIONS(3529),
    [anon_sym_delegate] = ACTIONS(3529),
    [anon_sym_record] = ACTIONS(3529),
    [anon_sym_abstract] = ACTIONS(3529),
    [anon_sym_async] = ACTIONS(3529),
    [anon_sym_const] = ACTIONS(3529),
    [anon_sym_file] = ACTIONS(3529),
    [anon_sym_fixed] = ACTIONS(3529),
    [anon_sym_internal] = ACTIONS(3529),
    [anon_sym_new] = ACTIONS(3529),
    [anon_sym_override] = ACTIONS(3529),
    [anon_sym_partial] = ACTIONS(3529),
    [anon_sym_private] = ACTIONS(3529),
    [anon_sym_protected] = ACTIONS(3529),
    [anon_sym_public] = ACTIONS(3529),
    [anon_sym_readonly] = ACTIONS(3529),
    [anon_sym_required] = ACTIONS(3529),
    [anon_sym_sealed] = ACTIONS(3529),
    [anon_sym_virtual] = ACTIONS(3529),
    [anon_sym_volatile] = ACTIONS(3529),
    [anon_sym_where] = ACTIONS(3529),
    [anon_sym_notnull] = ACTIONS(3529),
    [anon_sym_unmanaged] = ACTIONS(3529),
    [anon_sym_checked] = ACTIONS(3529),
    [anon_sym_BANG] = ACTIONS(3531),
    [anon_sym_TILDE] = ACTIONS(3531),
    [anon_sym_PLUS_PLUS] = ACTIONS(3531),
    [anon_sym_DASH_DASH] = ACTIONS(3531),
    [anon_sym_true] = ACTIONS(3529),
    [anon_sym_false] = ACTIONS(3529),
    [anon_sym_PLUS] = ACTIONS(3529),
    [anon_sym_DASH] = ACTIONS(3529),
    [anon_sym_STAR] = ACTIONS(3531),
    [anon_sym_CARET] = ACTIONS(3531),
    [anon_sym_AMP] = ACTIONS(3531),
    [anon_sym_this] = ACTIONS(3529),
    [anon_sym_scoped] = ACTIONS(3529),
    [anon_sym_base] = ACTIONS(3529),
    [anon_sym_var] = ACTIONS(3529),
    [sym_predefined_type] = ACTIONS(3529),
    [anon_sym_break] = ACTIONS(3529),
    [anon_sym_unchecked] = ACTIONS(3529),
    [anon_sym_continue] = ACTIONS(3529),
    [anon_sym_do] = ACTIONS(3529),
    [anon_sym_while] = ACTIONS(3529),
    [anon_sym_for] = ACTIONS(3529),
    [anon_sym_lock] = ACTIONS(3529),
    [anon_sym_yield] = ACTIONS(3529),
    [anon_sym_switch] = ACTIONS(3529),
    [anon_sym_default] = ACTIONS(3529),
    [anon_sym_throw] = ACTIONS(3529),
    [anon_sym_try] = ACTIONS(3529),
    [anon_sym_when] = ACTIONS(3529),
    [anon_sym_await] = ACTIONS(3529),
    [anon_sym_foreach] = ACTIONS(3529),
    [anon_sym_goto] = ACTIONS(3529),
    [anon_sym_if] = ACTIONS(3529),
    [anon_sym_DOT_DOT] = ACTIONS(3531),
    [anon_sym_from] = ACTIONS(3529),
    [anon_sym_into] = ACTIONS(3529),
    [anon_sym_join] = ACTIONS(3529),
    [anon_sym_on] = ACTIONS(3529),
    [anon_sym_equals] = ACTIONS(3529),
    [anon_sym_let] = ACTIONS(3529),
    [anon_sym_orderby] = ACTIONS(3529),
    [anon_sym_ascending] = ACTIONS(3529),
    [anon_sym_descending] = ACTIONS(3529),
    [anon_sym_group] = ACTIONS(3529),
    [anon_sym_by] = ACTIONS(3529),
    [anon_sym_select] = ACTIONS(3529),
    [anon_sym_stackalloc] = ACTIONS(3529),
    [anon_sym_sizeof] = ACTIONS(3529),
    [anon_sym_typeof] = ACTIONS(3529),
    [anon_sym___makeref] = ACTIONS(3529),
    [anon_sym___reftype] = ACTIONS(3529),
    [anon_sym___refvalue] = ACTIONS(3529),
    [sym_null_literal] = ACTIONS(3529),
    [anon_sym_SQUOTE] = ACTIONS(3531),
    [sym_integer_literal] = ACTIONS(3529),
    [sym_real_literal] = ACTIONS(3531),
    [anon_sym_DQUOTE] = ACTIONS(3531),
    [sym_verbatim_string_literal] = ACTIONS(3531),
    [aux_sym_preproc_if_token1] = ACTIONS(3531),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3531),
    [sym_interpolation_verbatim_start] = ACTIONS(3531),
    [sym_interpolation_raw_start] = ACTIONS(3531),
    [sym_raw_string_start] = ACTIONS(3531),
  },
  [2593] = {
    [sym_preproc_region] = STATE(2593),
    [sym_preproc_endregion] = STATE(2593),
    [sym_preproc_line] = STATE(2593),
    [sym_preproc_pragma] = STATE(2593),
    [sym_preproc_nullable] = STATE(2593),
    [sym_preproc_error] = STATE(2593),
    [sym_preproc_warning] = STATE(2593),
    [sym_preproc_define] = STATE(2593),
    [sym_preproc_undef] = STATE(2593),
    [ts_builtin_sym_end] = ACTIONS(3953),
    [sym__identifier_token] = ACTIONS(3951),
    [anon_sym_extern] = ACTIONS(3951),
    [anon_sym_alias] = ACTIONS(3951),
    [anon_sym_SEMI] = ACTIONS(3953),
    [anon_sym_global] = ACTIONS(3951),
    [anon_sym_using] = ACTIONS(3951),
    [anon_sym_unsafe] = ACTIONS(3951),
    [anon_sym_static] = ACTIONS(3951),
    [anon_sym_LBRACK] = ACTIONS(3953),
    [anon_sym_LPAREN] = ACTIONS(3953),
    [anon_sym_return] = ACTIONS(3951),
    [anon_sym_namespace] = ACTIONS(3951),
    [anon_sym_class] = ACTIONS(3951),
    [anon_sym_ref] = ACTIONS(3951),
    [anon_sym_struct] = ACTIONS(3951),
    [anon_sym_enum] = ACTIONS(3951),
    [anon_sym_LBRACE] = ACTIONS(3953),
    [anon_sym_interface] = ACTIONS(3951),
    [anon_sym_delegate] = ACTIONS(3951),
    [anon_sym_record] = ACTIONS(3951),
    [anon_sym_abstract] = ACTIONS(3951),
    [anon_sym_async] = ACTIONS(3951),
    [anon_sym_const] = ACTIONS(3951),
    [anon_sym_file] = ACTIONS(3951),
    [anon_sym_fixed] = ACTIONS(3951),
    [anon_sym_internal] = ACTIONS(3951),
    [anon_sym_new] = ACTIONS(3951),
    [anon_sym_override] = ACTIONS(3951),
    [anon_sym_partial] = ACTIONS(3951),
    [anon_sym_private] = ACTIONS(3951),
    [anon_sym_protected] = ACTIONS(3951),
    [anon_sym_public] = ACTIONS(3951),
    [anon_sym_readonly] = ACTIONS(3951),
    [anon_sym_required] = ACTIONS(3951),
    [anon_sym_sealed] = ACTIONS(3951),
    [anon_sym_virtual] = ACTIONS(3951),
    [anon_sym_volatile] = ACTIONS(3951),
    [anon_sym_where] = ACTIONS(3951),
    [anon_sym_notnull] = ACTIONS(3951),
    [anon_sym_unmanaged] = ACTIONS(3951),
    [anon_sym_checked] = ACTIONS(3951),
    [anon_sym_BANG] = ACTIONS(3953),
    [anon_sym_TILDE] = ACTIONS(3953),
    [anon_sym_PLUS_PLUS] = ACTIONS(3953),
    [anon_sym_DASH_DASH] = ACTIONS(3953),
    [anon_sym_true] = ACTIONS(3951),
    [anon_sym_false] = ACTIONS(3951),
    [anon_sym_PLUS] = ACTIONS(3951),
    [anon_sym_DASH] = ACTIONS(3951),
    [anon_sym_STAR] = ACTIONS(3953),
    [anon_sym_CARET] = ACTIONS(3953),
    [anon_sym_AMP] = ACTIONS(3953),
    [anon_sym_this] = ACTIONS(3951),
    [anon_sym_scoped] = ACTIONS(3951),
    [anon_sym_base] = ACTIONS(3951),
    [anon_sym_var] = ACTIONS(3951),
    [sym_predefined_type] = ACTIONS(3951),
    [anon_sym_break] = ACTIONS(3951),
    [anon_sym_unchecked] = ACTIONS(3951),
    [anon_sym_continue] = ACTIONS(3951),
    [anon_sym_do] = ACTIONS(3951),
    [anon_sym_while] = ACTIONS(3951),
    [anon_sym_for] = ACTIONS(3951),
    [anon_sym_lock] = ACTIONS(3951),
    [anon_sym_yield] = ACTIONS(3951),
    [anon_sym_switch] = ACTIONS(3951),
    [anon_sym_default] = ACTIONS(3951),
    [anon_sym_throw] = ACTIONS(3951),
    [anon_sym_try] = ACTIONS(3951),
    [anon_sym_when] = ACTIONS(3951),
    [anon_sym_await] = ACTIONS(3951),
    [anon_sym_foreach] = ACTIONS(3951),
    [anon_sym_goto] = ACTIONS(3951),
    [anon_sym_if] = ACTIONS(3951),
    [anon_sym_DOT_DOT] = ACTIONS(3953),
    [anon_sym_from] = ACTIONS(3951),
    [anon_sym_into] = ACTIONS(3951),
    [anon_sym_join] = ACTIONS(3951),
    [anon_sym_on] = ACTIONS(3951),
    [anon_sym_equals] = ACTIONS(3951),
    [anon_sym_let] = ACTIONS(3951),
    [anon_sym_orderby] = ACTIONS(3951),
    [anon_sym_ascending] = ACTIONS(3951),
    [anon_sym_descending] = ACTIONS(3951),
    [anon_sym_group] = ACTIONS(3951),
    [anon_sym_by] = ACTIONS(3951),
    [anon_sym_select] = ACTIONS(3951),
    [anon_sym_stackalloc] = ACTIONS(3951),
    [anon_sym_sizeof] = ACTIONS(3951),
    [anon_sym_typeof] = ACTIONS(3951),
    [anon_sym___makeref] = ACTIONS(3951),
    [anon_sym___reftype] = ACTIONS(3951),
    [anon_sym___refvalue] = ACTIONS(3951),
    [sym_null_literal] = ACTIONS(3951),
    [anon_sym_SQUOTE] = ACTIONS(3953),
    [sym_integer_literal] = ACTIONS(3951),
    [sym_real_literal] = ACTIONS(3953),
    [anon_sym_DQUOTE] = ACTIONS(3953),
    [sym_verbatim_string_literal] = ACTIONS(3953),
    [aux_sym_preproc_if_token1] = ACTIONS(3953),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3953),
    [sym_interpolation_verbatim_start] = ACTIONS(3953),
    [sym_interpolation_raw_start] = ACTIONS(3953),
    [sym_raw_string_start] = ACTIONS(3953),
  },
  [2594] = {
    [sym_preproc_region] = STATE(2594),
    [sym_preproc_endregion] = STATE(2594),
    [sym_preproc_line] = STATE(2594),
    [sym_preproc_pragma] = STATE(2594),
    [sym_preproc_nullable] = STATE(2594),
    [sym_preproc_error] = STATE(2594),
    [sym_preproc_warning] = STATE(2594),
    [sym_preproc_define] = STATE(2594),
    [sym_preproc_undef] = STATE(2594),
    [ts_builtin_sym_end] = ACTIONS(3651),
    [sym__identifier_token] = ACTIONS(3649),
    [anon_sym_extern] = ACTIONS(3649),
    [anon_sym_alias] = ACTIONS(3649),
    [anon_sym_SEMI] = ACTIONS(3651),
    [anon_sym_global] = ACTIONS(3649),
    [anon_sym_using] = ACTIONS(3649),
    [anon_sym_unsafe] = ACTIONS(3649),
    [anon_sym_static] = ACTIONS(3649),
    [anon_sym_LBRACK] = ACTIONS(3651),
    [anon_sym_LPAREN] = ACTIONS(3651),
    [anon_sym_return] = ACTIONS(3649),
    [anon_sym_namespace] = ACTIONS(3649),
    [anon_sym_class] = ACTIONS(3649),
    [anon_sym_ref] = ACTIONS(3649),
    [anon_sym_struct] = ACTIONS(3649),
    [anon_sym_enum] = ACTIONS(3649),
    [anon_sym_LBRACE] = ACTIONS(3651),
    [anon_sym_interface] = ACTIONS(3649),
    [anon_sym_delegate] = ACTIONS(3649),
    [anon_sym_record] = ACTIONS(3649),
    [anon_sym_abstract] = ACTIONS(3649),
    [anon_sym_async] = ACTIONS(3649),
    [anon_sym_const] = ACTIONS(3649),
    [anon_sym_file] = ACTIONS(3649),
    [anon_sym_fixed] = ACTIONS(3649),
    [anon_sym_internal] = ACTIONS(3649),
    [anon_sym_new] = ACTIONS(3649),
    [anon_sym_override] = ACTIONS(3649),
    [anon_sym_partial] = ACTIONS(3649),
    [anon_sym_private] = ACTIONS(3649),
    [anon_sym_protected] = ACTIONS(3649),
    [anon_sym_public] = ACTIONS(3649),
    [anon_sym_readonly] = ACTIONS(3649),
    [anon_sym_required] = ACTIONS(3649),
    [anon_sym_sealed] = ACTIONS(3649),
    [anon_sym_virtual] = ACTIONS(3649),
    [anon_sym_volatile] = ACTIONS(3649),
    [anon_sym_where] = ACTIONS(3649),
    [anon_sym_notnull] = ACTIONS(3649),
    [anon_sym_unmanaged] = ACTIONS(3649),
    [anon_sym_checked] = ACTIONS(3649),
    [anon_sym_BANG] = ACTIONS(3651),
    [anon_sym_TILDE] = ACTIONS(3651),
    [anon_sym_PLUS_PLUS] = ACTIONS(3651),
    [anon_sym_DASH_DASH] = ACTIONS(3651),
    [anon_sym_true] = ACTIONS(3649),
    [anon_sym_false] = ACTIONS(3649),
    [anon_sym_PLUS] = ACTIONS(3649),
    [anon_sym_DASH] = ACTIONS(3649),
    [anon_sym_STAR] = ACTIONS(3651),
    [anon_sym_CARET] = ACTIONS(3651),
    [anon_sym_AMP] = ACTIONS(3651),
    [anon_sym_this] = ACTIONS(3649),
    [anon_sym_scoped] = ACTIONS(3649),
    [anon_sym_base] = ACTIONS(3649),
    [anon_sym_var] = ACTIONS(3649),
    [sym_predefined_type] = ACTIONS(3649),
    [anon_sym_break] = ACTIONS(3649),
    [anon_sym_unchecked] = ACTIONS(3649),
    [anon_sym_continue] = ACTIONS(3649),
    [anon_sym_do] = ACTIONS(3649),
    [anon_sym_while] = ACTIONS(3649),
    [anon_sym_for] = ACTIONS(3649),
    [anon_sym_lock] = ACTIONS(3649),
    [anon_sym_yield] = ACTIONS(3649),
    [anon_sym_switch] = ACTIONS(3649),
    [anon_sym_default] = ACTIONS(3649),
    [anon_sym_throw] = ACTIONS(3649),
    [anon_sym_try] = ACTIONS(3649),
    [anon_sym_when] = ACTIONS(3649),
    [anon_sym_await] = ACTIONS(3649),
    [anon_sym_foreach] = ACTIONS(3649),
    [anon_sym_goto] = ACTIONS(3649),
    [anon_sym_if] = ACTIONS(3649),
    [anon_sym_DOT_DOT] = ACTIONS(3651),
    [anon_sym_from] = ACTIONS(3649),
    [anon_sym_into] = ACTIONS(3649),
    [anon_sym_join] = ACTIONS(3649),
    [anon_sym_on] = ACTIONS(3649),
    [anon_sym_equals] = ACTIONS(3649),
    [anon_sym_let] = ACTIONS(3649),
    [anon_sym_orderby] = ACTIONS(3649),
    [anon_sym_ascending] = ACTIONS(3649),
    [anon_sym_descending] = ACTIONS(3649),
    [anon_sym_group] = ACTIONS(3649),
    [anon_sym_by] = ACTIONS(3649),
    [anon_sym_select] = ACTIONS(3649),
    [anon_sym_stackalloc] = ACTIONS(3649),
    [anon_sym_sizeof] = ACTIONS(3649),
    [anon_sym_typeof] = ACTIONS(3649),
    [anon_sym___makeref] = ACTIONS(3649),
    [anon_sym___reftype] = ACTIONS(3649),
    [anon_sym___refvalue] = ACTIONS(3649),
    [sym_null_literal] = ACTIONS(3649),
    [anon_sym_SQUOTE] = ACTIONS(3651),
    [sym_integer_literal] = ACTIONS(3649),
    [sym_real_literal] = ACTIONS(3651),
    [anon_sym_DQUOTE] = ACTIONS(3651),
    [sym_verbatim_string_literal] = ACTIONS(3651),
    [aux_sym_preproc_if_token1] = ACTIONS(3651),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3651),
    [sym_interpolation_verbatim_start] = ACTIONS(3651),
    [sym_interpolation_raw_start] = ACTIONS(3651),
    [sym_raw_string_start] = ACTIONS(3651),
  },
  [2595] = {
    [sym_preproc_region] = STATE(2595),
    [sym_preproc_endregion] = STATE(2595),
    [sym_preproc_line] = STATE(2595),
    [sym_preproc_pragma] = STATE(2595),
    [sym_preproc_nullable] = STATE(2595),
    [sym_preproc_error] = STATE(2595),
    [sym_preproc_warning] = STATE(2595),
    [sym_preproc_define] = STATE(2595),
    [sym_preproc_undef] = STATE(2595),
    [ts_builtin_sym_end] = ACTIONS(3535),
    [sym__identifier_token] = ACTIONS(3533),
    [anon_sym_extern] = ACTIONS(3533),
    [anon_sym_alias] = ACTIONS(3533),
    [anon_sym_SEMI] = ACTIONS(3535),
    [anon_sym_global] = ACTIONS(3533),
    [anon_sym_using] = ACTIONS(3533),
    [anon_sym_unsafe] = ACTIONS(3533),
    [anon_sym_static] = ACTIONS(3533),
    [anon_sym_LBRACK] = ACTIONS(3535),
    [anon_sym_LPAREN] = ACTIONS(3535),
    [anon_sym_return] = ACTIONS(3533),
    [anon_sym_namespace] = ACTIONS(3533),
    [anon_sym_class] = ACTIONS(3533),
    [anon_sym_ref] = ACTIONS(3533),
    [anon_sym_struct] = ACTIONS(3533),
    [anon_sym_enum] = ACTIONS(3533),
    [anon_sym_LBRACE] = ACTIONS(3535),
    [anon_sym_interface] = ACTIONS(3533),
    [anon_sym_delegate] = ACTIONS(3533),
    [anon_sym_record] = ACTIONS(3533),
    [anon_sym_abstract] = ACTIONS(3533),
    [anon_sym_async] = ACTIONS(3533),
    [anon_sym_const] = ACTIONS(3533),
    [anon_sym_file] = ACTIONS(3533),
    [anon_sym_fixed] = ACTIONS(3533),
    [anon_sym_internal] = ACTIONS(3533),
    [anon_sym_new] = ACTIONS(3533),
    [anon_sym_override] = ACTIONS(3533),
    [anon_sym_partial] = ACTIONS(3533),
    [anon_sym_private] = ACTIONS(3533),
    [anon_sym_protected] = ACTIONS(3533),
    [anon_sym_public] = ACTIONS(3533),
    [anon_sym_readonly] = ACTIONS(3533),
    [anon_sym_required] = ACTIONS(3533),
    [anon_sym_sealed] = ACTIONS(3533),
    [anon_sym_virtual] = ACTIONS(3533),
    [anon_sym_volatile] = ACTIONS(3533),
    [anon_sym_where] = ACTIONS(3533),
    [anon_sym_notnull] = ACTIONS(3533),
    [anon_sym_unmanaged] = ACTIONS(3533),
    [anon_sym_checked] = ACTIONS(3533),
    [anon_sym_BANG] = ACTIONS(3535),
    [anon_sym_TILDE] = ACTIONS(3535),
    [anon_sym_PLUS_PLUS] = ACTIONS(3535),
    [anon_sym_DASH_DASH] = ACTIONS(3535),
    [anon_sym_true] = ACTIONS(3533),
    [anon_sym_false] = ACTIONS(3533),
    [anon_sym_PLUS] = ACTIONS(3533),
    [anon_sym_DASH] = ACTIONS(3533),
    [anon_sym_STAR] = ACTIONS(3535),
    [anon_sym_CARET] = ACTIONS(3535),
    [anon_sym_AMP] = ACTIONS(3535),
    [anon_sym_this] = ACTIONS(3533),
    [anon_sym_scoped] = ACTIONS(3533),
    [anon_sym_base] = ACTIONS(3533),
    [anon_sym_var] = ACTIONS(3533),
    [sym_predefined_type] = ACTIONS(3533),
    [anon_sym_break] = ACTIONS(3533),
    [anon_sym_unchecked] = ACTIONS(3533),
    [anon_sym_continue] = ACTIONS(3533),
    [anon_sym_do] = ACTIONS(3533),
    [anon_sym_while] = ACTIONS(3533),
    [anon_sym_for] = ACTIONS(3533),
    [anon_sym_lock] = ACTIONS(3533),
    [anon_sym_yield] = ACTIONS(3533),
    [anon_sym_switch] = ACTIONS(3533),
    [anon_sym_default] = ACTIONS(3533),
    [anon_sym_throw] = ACTIONS(3533),
    [anon_sym_try] = ACTIONS(3533),
    [anon_sym_when] = ACTIONS(3533),
    [anon_sym_await] = ACTIONS(3533),
    [anon_sym_foreach] = ACTIONS(3533),
    [anon_sym_goto] = ACTIONS(3533),
    [anon_sym_if] = ACTIONS(3533),
    [anon_sym_DOT_DOT] = ACTIONS(3535),
    [anon_sym_from] = ACTIONS(3533),
    [anon_sym_into] = ACTIONS(3533),
    [anon_sym_join] = ACTIONS(3533),
    [anon_sym_on] = ACTIONS(3533),
    [anon_sym_equals] = ACTIONS(3533),
    [anon_sym_let] = ACTIONS(3533),
    [anon_sym_orderby] = ACTIONS(3533),
    [anon_sym_ascending] = ACTIONS(3533),
    [anon_sym_descending] = ACTIONS(3533),
    [anon_sym_group] = ACTIONS(3533),
    [anon_sym_by] = ACTIONS(3533),
    [anon_sym_select] = ACTIONS(3533),
    [anon_sym_stackalloc] = ACTIONS(3533),
    [anon_sym_sizeof] = ACTIONS(3533),
    [anon_sym_typeof] = ACTIONS(3533),
    [anon_sym___makeref] = ACTIONS(3533),
    [anon_sym___reftype] = ACTIONS(3533),
    [anon_sym___refvalue] = ACTIONS(3533),
    [sym_null_literal] = ACTIONS(3533),
    [anon_sym_SQUOTE] = ACTIONS(3535),
    [sym_integer_literal] = ACTIONS(3533),
    [sym_real_literal] = ACTIONS(3535),
    [anon_sym_DQUOTE] = ACTIONS(3535),
    [sym_verbatim_string_literal] = ACTIONS(3535),
    [aux_sym_preproc_if_token1] = ACTIONS(3535),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3535),
    [sym_interpolation_verbatim_start] = ACTIONS(3535),
    [sym_interpolation_raw_start] = ACTIONS(3535),
    [sym_raw_string_start] = ACTIONS(3535),
  },
  [2596] = {
    [sym_preproc_region] = STATE(2596),
    [sym_preproc_endregion] = STATE(2596),
    [sym_preproc_line] = STATE(2596),
    [sym_preproc_pragma] = STATE(2596),
    [sym_preproc_nullable] = STATE(2596),
    [sym_preproc_error] = STATE(2596),
    [sym_preproc_warning] = STATE(2596),
    [sym_preproc_define] = STATE(2596),
    [sym_preproc_undef] = STATE(2596),
    [ts_builtin_sym_end] = ACTIONS(3655),
    [sym__identifier_token] = ACTIONS(3653),
    [anon_sym_extern] = ACTIONS(3653),
    [anon_sym_alias] = ACTIONS(3653),
    [anon_sym_SEMI] = ACTIONS(3655),
    [anon_sym_global] = ACTIONS(3653),
    [anon_sym_using] = ACTIONS(3653),
    [anon_sym_unsafe] = ACTIONS(3653),
    [anon_sym_static] = ACTIONS(3653),
    [anon_sym_LBRACK] = ACTIONS(3655),
    [anon_sym_LPAREN] = ACTIONS(3655),
    [anon_sym_return] = ACTIONS(3653),
    [anon_sym_namespace] = ACTIONS(3653),
    [anon_sym_class] = ACTIONS(3653),
    [anon_sym_ref] = ACTIONS(3653),
    [anon_sym_struct] = ACTIONS(3653),
    [anon_sym_enum] = ACTIONS(3653),
    [anon_sym_LBRACE] = ACTIONS(3655),
    [anon_sym_interface] = ACTIONS(3653),
    [anon_sym_delegate] = ACTIONS(3653),
    [anon_sym_record] = ACTIONS(3653),
    [anon_sym_abstract] = ACTIONS(3653),
    [anon_sym_async] = ACTIONS(3653),
    [anon_sym_const] = ACTIONS(3653),
    [anon_sym_file] = ACTIONS(3653),
    [anon_sym_fixed] = ACTIONS(3653),
    [anon_sym_internal] = ACTIONS(3653),
    [anon_sym_new] = ACTIONS(3653),
    [anon_sym_override] = ACTIONS(3653),
    [anon_sym_partial] = ACTIONS(3653),
    [anon_sym_private] = ACTIONS(3653),
    [anon_sym_protected] = ACTIONS(3653),
    [anon_sym_public] = ACTIONS(3653),
    [anon_sym_readonly] = ACTIONS(3653),
    [anon_sym_required] = ACTIONS(3653),
    [anon_sym_sealed] = ACTIONS(3653),
    [anon_sym_virtual] = ACTIONS(3653),
    [anon_sym_volatile] = ACTIONS(3653),
    [anon_sym_where] = ACTIONS(3653),
    [anon_sym_notnull] = ACTIONS(3653),
    [anon_sym_unmanaged] = ACTIONS(3653),
    [anon_sym_checked] = ACTIONS(3653),
    [anon_sym_BANG] = ACTIONS(3655),
    [anon_sym_TILDE] = ACTIONS(3655),
    [anon_sym_PLUS_PLUS] = ACTIONS(3655),
    [anon_sym_DASH_DASH] = ACTIONS(3655),
    [anon_sym_true] = ACTIONS(3653),
    [anon_sym_false] = ACTIONS(3653),
    [anon_sym_PLUS] = ACTIONS(3653),
    [anon_sym_DASH] = ACTIONS(3653),
    [anon_sym_STAR] = ACTIONS(3655),
    [anon_sym_CARET] = ACTIONS(3655),
    [anon_sym_AMP] = ACTIONS(3655),
    [anon_sym_this] = ACTIONS(3653),
    [anon_sym_scoped] = ACTIONS(3653),
    [anon_sym_base] = ACTIONS(3653),
    [anon_sym_var] = ACTIONS(3653),
    [sym_predefined_type] = ACTIONS(3653),
    [anon_sym_break] = ACTIONS(3653),
    [anon_sym_unchecked] = ACTIONS(3653),
    [anon_sym_continue] = ACTIONS(3653),
    [anon_sym_do] = ACTIONS(3653),
    [anon_sym_while] = ACTIONS(3653),
    [anon_sym_for] = ACTIONS(3653),
    [anon_sym_lock] = ACTIONS(3653),
    [anon_sym_yield] = ACTIONS(3653),
    [anon_sym_switch] = ACTIONS(3653),
    [anon_sym_default] = ACTIONS(3653),
    [anon_sym_throw] = ACTIONS(3653),
    [anon_sym_try] = ACTIONS(3653),
    [anon_sym_when] = ACTIONS(3653),
    [anon_sym_await] = ACTIONS(3653),
    [anon_sym_foreach] = ACTIONS(3653),
    [anon_sym_goto] = ACTIONS(3653),
    [anon_sym_if] = ACTIONS(3653),
    [anon_sym_DOT_DOT] = ACTIONS(3655),
    [anon_sym_from] = ACTIONS(3653),
    [anon_sym_into] = ACTIONS(3653),
    [anon_sym_join] = ACTIONS(3653),
    [anon_sym_on] = ACTIONS(3653),
    [anon_sym_equals] = ACTIONS(3653),
    [anon_sym_let] = ACTIONS(3653),
    [anon_sym_orderby] = ACTIONS(3653),
    [anon_sym_ascending] = ACTIONS(3653),
    [anon_sym_descending] = ACTIONS(3653),
    [anon_sym_group] = ACTIONS(3653),
    [anon_sym_by] = ACTIONS(3653),
    [anon_sym_select] = ACTIONS(3653),
    [anon_sym_stackalloc] = ACTIONS(3653),
    [anon_sym_sizeof] = ACTIONS(3653),
    [anon_sym_typeof] = ACTIONS(3653),
    [anon_sym___makeref] = ACTIONS(3653),
    [anon_sym___reftype] = ACTIONS(3653),
    [anon_sym___refvalue] = ACTIONS(3653),
    [sym_null_literal] = ACTIONS(3653),
    [anon_sym_SQUOTE] = ACTIONS(3655),
    [sym_integer_literal] = ACTIONS(3653),
    [sym_real_literal] = ACTIONS(3655),
    [anon_sym_DQUOTE] = ACTIONS(3655),
    [sym_verbatim_string_literal] = ACTIONS(3655),
    [aux_sym_preproc_if_token1] = ACTIONS(3655),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3655),
    [sym_interpolation_verbatim_start] = ACTIONS(3655),
    [sym_interpolation_raw_start] = ACTIONS(3655),
    [sym_raw_string_start] = ACTIONS(3655),
  },
  [2597] = {
    [sym_preproc_region] = STATE(2597),
    [sym_preproc_endregion] = STATE(2597),
    [sym_preproc_line] = STATE(2597),
    [sym_preproc_pragma] = STATE(2597),
    [sym_preproc_nullable] = STATE(2597),
    [sym_preproc_error] = STATE(2597),
    [sym_preproc_warning] = STATE(2597),
    [sym_preproc_define] = STATE(2597),
    [sym_preproc_undef] = STATE(2597),
    [ts_builtin_sym_end] = ACTIONS(3659),
    [sym__identifier_token] = ACTIONS(3657),
    [anon_sym_extern] = ACTIONS(3657),
    [anon_sym_alias] = ACTIONS(3657),
    [anon_sym_SEMI] = ACTIONS(3659),
    [anon_sym_global] = ACTIONS(3657),
    [anon_sym_using] = ACTIONS(3657),
    [anon_sym_unsafe] = ACTIONS(3657),
    [anon_sym_static] = ACTIONS(3657),
    [anon_sym_LBRACK] = ACTIONS(3659),
    [anon_sym_LPAREN] = ACTIONS(3659),
    [anon_sym_return] = ACTIONS(3657),
    [anon_sym_namespace] = ACTIONS(3657),
    [anon_sym_class] = ACTIONS(3657),
    [anon_sym_ref] = ACTIONS(3657),
    [anon_sym_struct] = ACTIONS(3657),
    [anon_sym_enum] = ACTIONS(3657),
    [anon_sym_LBRACE] = ACTIONS(3659),
    [anon_sym_interface] = ACTIONS(3657),
    [anon_sym_delegate] = ACTIONS(3657),
    [anon_sym_record] = ACTIONS(3657),
    [anon_sym_abstract] = ACTIONS(3657),
    [anon_sym_async] = ACTIONS(3657),
    [anon_sym_const] = ACTIONS(3657),
    [anon_sym_file] = ACTIONS(3657),
    [anon_sym_fixed] = ACTIONS(3657),
    [anon_sym_internal] = ACTIONS(3657),
    [anon_sym_new] = ACTIONS(3657),
    [anon_sym_override] = ACTIONS(3657),
    [anon_sym_partial] = ACTIONS(3657),
    [anon_sym_private] = ACTIONS(3657),
    [anon_sym_protected] = ACTIONS(3657),
    [anon_sym_public] = ACTIONS(3657),
    [anon_sym_readonly] = ACTIONS(3657),
    [anon_sym_required] = ACTIONS(3657),
    [anon_sym_sealed] = ACTIONS(3657),
    [anon_sym_virtual] = ACTIONS(3657),
    [anon_sym_volatile] = ACTIONS(3657),
    [anon_sym_where] = ACTIONS(3657),
    [anon_sym_notnull] = ACTIONS(3657),
    [anon_sym_unmanaged] = ACTIONS(3657),
    [anon_sym_checked] = ACTIONS(3657),
    [anon_sym_BANG] = ACTIONS(3659),
    [anon_sym_TILDE] = ACTIONS(3659),
    [anon_sym_PLUS_PLUS] = ACTIONS(3659),
    [anon_sym_DASH_DASH] = ACTIONS(3659),
    [anon_sym_true] = ACTIONS(3657),
    [anon_sym_false] = ACTIONS(3657),
    [anon_sym_PLUS] = ACTIONS(3657),
    [anon_sym_DASH] = ACTIONS(3657),
    [anon_sym_STAR] = ACTIONS(3659),
    [anon_sym_CARET] = ACTIONS(3659),
    [anon_sym_AMP] = ACTIONS(3659),
    [anon_sym_this] = ACTIONS(3657),
    [anon_sym_scoped] = ACTIONS(3657),
    [anon_sym_base] = ACTIONS(3657),
    [anon_sym_var] = ACTIONS(3657),
    [sym_predefined_type] = ACTIONS(3657),
    [anon_sym_break] = ACTIONS(3657),
    [anon_sym_unchecked] = ACTIONS(3657),
    [anon_sym_continue] = ACTIONS(3657),
    [anon_sym_do] = ACTIONS(3657),
    [anon_sym_while] = ACTIONS(3657),
    [anon_sym_for] = ACTIONS(3657),
    [anon_sym_lock] = ACTIONS(3657),
    [anon_sym_yield] = ACTIONS(3657),
    [anon_sym_switch] = ACTIONS(3657),
    [anon_sym_default] = ACTIONS(3657),
    [anon_sym_throw] = ACTIONS(3657),
    [anon_sym_try] = ACTIONS(3657),
    [anon_sym_when] = ACTIONS(3657),
    [anon_sym_await] = ACTIONS(3657),
    [anon_sym_foreach] = ACTIONS(3657),
    [anon_sym_goto] = ACTIONS(3657),
    [anon_sym_if] = ACTIONS(3657),
    [anon_sym_DOT_DOT] = ACTIONS(3659),
    [anon_sym_from] = ACTIONS(3657),
    [anon_sym_into] = ACTIONS(3657),
    [anon_sym_join] = ACTIONS(3657),
    [anon_sym_on] = ACTIONS(3657),
    [anon_sym_equals] = ACTIONS(3657),
    [anon_sym_let] = ACTIONS(3657),
    [anon_sym_orderby] = ACTIONS(3657),
    [anon_sym_ascending] = ACTIONS(3657),
    [anon_sym_descending] = ACTIONS(3657),
    [anon_sym_group] = ACTIONS(3657),
    [anon_sym_by] = ACTIONS(3657),
    [anon_sym_select] = ACTIONS(3657),
    [anon_sym_stackalloc] = ACTIONS(3657),
    [anon_sym_sizeof] = ACTIONS(3657),
    [anon_sym_typeof] = ACTIONS(3657),
    [anon_sym___makeref] = ACTIONS(3657),
    [anon_sym___reftype] = ACTIONS(3657),
    [anon_sym___refvalue] = ACTIONS(3657),
    [sym_null_literal] = ACTIONS(3657),
    [anon_sym_SQUOTE] = ACTIONS(3659),
    [sym_integer_literal] = ACTIONS(3657),
    [sym_real_literal] = ACTIONS(3659),
    [anon_sym_DQUOTE] = ACTIONS(3659),
    [sym_verbatim_string_literal] = ACTIONS(3659),
    [aux_sym_preproc_if_token1] = ACTIONS(3659),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3659),
    [sym_interpolation_verbatim_start] = ACTIONS(3659),
    [sym_interpolation_raw_start] = ACTIONS(3659),
    [sym_raw_string_start] = ACTIONS(3659),
  },
  [2598] = {
    [sym_preproc_region] = STATE(2598),
    [sym_preproc_endregion] = STATE(2598),
    [sym_preproc_line] = STATE(2598),
    [sym_preproc_pragma] = STATE(2598),
    [sym_preproc_nullable] = STATE(2598),
    [sym_preproc_error] = STATE(2598),
    [sym_preproc_warning] = STATE(2598),
    [sym_preproc_define] = STATE(2598),
    [sym_preproc_undef] = STATE(2598),
    [ts_builtin_sym_end] = ACTIONS(3985),
    [sym__identifier_token] = ACTIONS(3983),
    [anon_sym_extern] = ACTIONS(3983),
    [anon_sym_alias] = ACTIONS(3983),
    [anon_sym_SEMI] = ACTIONS(3985),
    [anon_sym_global] = ACTIONS(3983),
    [anon_sym_using] = ACTIONS(3983),
    [anon_sym_unsafe] = ACTIONS(3983),
    [anon_sym_static] = ACTIONS(3983),
    [anon_sym_LBRACK] = ACTIONS(3985),
    [anon_sym_LPAREN] = ACTIONS(3985),
    [anon_sym_return] = ACTIONS(3983),
    [anon_sym_namespace] = ACTIONS(3983),
    [anon_sym_class] = ACTIONS(3983),
    [anon_sym_ref] = ACTIONS(3983),
    [anon_sym_struct] = ACTIONS(3983),
    [anon_sym_enum] = ACTIONS(3983),
    [anon_sym_LBRACE] = ACTIONS(3985),
    [anon_sym_interface] = ACTIONS(3983),
    [anon_sym_delegate] = ACTIONS(3983),
    [anon_sym_record] = ACTIONS(3983),
    [anon_sym_abstract] = ACTIONS(3983),
    [anon_sym_async] = ACTIONS(3983),
    [anon_sym_const] = ACTIONS(3983),
    [anon_sym_file] = ACTIONS(3983),
    [anon_sym_fixed] = ACTIONS(3983),
    [anon_sym_internal] = ACTIONS(3983),
    [anon_sym_new] = ACTIONS(3983),
    [anon_sym_override] = ACTIONS(3983),
    [anon_sym_partial] = ACTIONS(3983),
    [anon_sym_private] = ACTIONS(3983),
    [anon_sym_protected] = ACTIONS(3983),
    [anon_sym_public] = ACTIONS(3983),
    [anon_sym_readonly] = ACTIONS(3983),
    [anon_sym_required] = ACTIONS(3983),
    [anon_sym_sealed] = ACTIONS(3983),
    [anon_sym_virtual] = ACTIONS(3983),
    [anon_sym_volatile] = ACTIONS(3983),
    [anon_sym_where] = ACTIONS(3983),
    [anon_sym_notnull] = ACTIONS(3983),
    [anon_sym_unmanaged] = ACTIONS(3983),
    [anon_sym_checked] = ACTIONS(3983),
    [anon_sym_BANG] = ACTIONS(3985),
    [anon_sym_TILDE] = ACTIONS(3985),
    [anon_sym_PLUS_PLUS] = ACTIONS(3985),
    [anon_sym_DASH_DASH] = ACTIONS(3985),
    [anon_sym_true] = ACTIONS(3983),
    [anon_sym_false] = ACTIONS(3983),
    [anon_sym_PLUS] = ACTIONS(3983),
    [anon_sym_DASH] = ACTIONS(3983),
    [anon_sym_STAR] = ACTIONS(3985),
    [anon_sym_CARET] = ACTIONS(3985),
    [anon_sym_AMP] = ACTIONS(3985),
    [anon_sym_this] = ACTIONS(3983),
    [anon_sym_scoped] = ACTIONS(3983),
    [anon_sym_base] = ACTIONS(3983),
    [anon_sym_var] = ACTIONS(3983),
    [sym_predefined_type] = ACTIONS(3983),
    [anon_sym_break] = ACTIONS(3983),
    [anon_sym_unchecked] = ACTIONS(3983),
    [anon_sym_continue] = ACTIONS(3983),
    [anon_sym_do] = ACTIONS(3983),
    [anon_sym_while] = ACTIONS(3983),
    [anon_sym_for] = ACTIONS(3983),
    [anon_sym_lock] = ACTIONS(3983),
    [anon_sym_yield] = ACTIONS(3983),
    [anon_sym_switch] = ACTIONS(3983),
    [anon_sym_default] = ACTIONS(3983),
    [anon_sym_throw] = ACTIONS(3983),
    [anon_sym_try] = ACTIONS(3983),
    [anon_sym_when] = ACTIONS(3983),
    [anon_sym_await] = ACTIONS(3983),
    [anon_sym_foreach] = ACTIONS(3983),
    [anon_sym_goto] = ACTIONS(3983),
    [anon_sym_if] = ACTIONS(3983),
    [anon_sym_DOT_DOT] = ACTIONS(3985),
    [anon_sym_from] = ACTIONS(3983),
    [anon_sym_into] = ACTIONS(3983),
    [anon_sym_join] = ACTIONS(3983),
    [anon_sym_on] = ACTIONS(3983),
    [anon_sym_equals] = ACTIONS(3983),
    [anon_sym_let] = ACTIONS(3983),
    [anon_sym_orderby] = ACTIONS(3983),
    [anon_sym_ascending] = ACTIONS(3983),
    [anon_sym_descending] = ACTIONS(3983),
    [anon_sym_group] = ACTIONS(3983),
    [anon_sym_by] = ACTIONS(3983),
    [anon_sym_select] = ACTIONS(3983),
    [anon_sym_stackalloc] = ACTIONS(3983),
    [anon_sym_sizeof] = ACTIONS(3983),
    [anon_sym_typeof] = ACTIONS(3983),
    [anon_sym___makeref] = ACTIONS(3983),
    [anon_sym___reftype] = ACTIONS(3983),
    [anon_sym___refvalue] = ACTIONS(3983),
    [sym_null_literal] = ACTIONS(3983),
    [anon_sym_SQUOTE] = ACTIONS(3985),
    [sym_integer_literal] = ACTIONS(3983),
    [sym_real_literal] = ACTIONS(3985),
    [anon_sym_DQUOTE] = ACTIONS(3985),
    [sym_verbatim_string_literal] = ACTIONS(3985),
    [aux_sym_preproc_if_token1] = ACTIONS(3985),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3985),
    [sym_interpolation_verbatim_start] = ACTIONS(3985),
    [sym_interpolation_raw_start] = ACTIONS(3985),
    [sym_raw_string_start] = ACTIONS(3985),
  },
  [2599] = {
    [sym_preproc_region] = STATE(2599),
    [sym_preproc_endregion] = STATE(2599),
    [sym_preproc_line] = STATE(2599),
    [sym_preproc_pragma] = STATE(2599),
    [sym_preproc_nullable] = STATE(2599),
    [sym_preproc_error] = STATE(2599),
    [sym_preproc_warning] = STATE(2599),
    [sym_preproc_define] = STATE(2599),
    [sym_preproc_undef] = STATE(2599),
    [ts_builtin_sym_end] = ACTIONS(3667),
    [sym__identifier_token] = ACTIONS(3665),
    [anon_sym_extern] = ACTIONS(3665),
    [anon_sym_alias] = ACTIONS(3665),
    [anon_sym_SEMI] = ACTIONS(3667),
    [anon_sym_global] = ACTIONS(3665),
    [anon_sym_using] = ACTIONS(3665),
    [anon_sym_unsafe] = ACTIONS(3665),
    [anon_sym_static] = ACTIONS(3665),
    [anon_sym_LBRACK] = ACTIONS(3667),
    [anon_sym_LPAREN] = ACTIONS(3667),
    [anon_sym_return] = ACTIONS(3665),
    [anon_sym_namespace] = ACTIONS(3665),
    [anon_sym_class] = ACTIONS(3665),
    [anon_sym_ref] = ACTIONS(3665),
    [anon_sym_struct] = ACTIONS(3665),
    [anon_sym_enum] = ACTIONS(3665),
    [anon_sym_LBRACE] = ACTIONS(3667),
    [anon_sym_interface] = ACTIONS(3665),
    [anon_sym_delegate] = ACTIONS(3665),
    [anon_sym_record] = ACTIONS(3665),
    [anon_sym_abstract] = ACTIONS(3665),
    [anon_sym_async] = ACTIONS(3665),
    [anon_sym_const] = ACTIONS(3665),
    [anon_sym_file] = ACTIONS(3665),
    [anon_sym_fixed] = ACTIONS(3665),
    [anon_sym_internal] = ACTIONS(3665),
    [anon_sym_new] = ACTIONS(3665),
    [anon_sym_override] = ACTIONS(3665),
    [anon_sym_partial] = ACTIONS(3665),
    [anon_sym_private] = ACTIONS(3665),
    [anon_sym_protected] = ACTIONS(3665),
    [anon_sym_public] = ACTIONS(3665),
    [anon_sym_readonly] = ACTIONS(3665),
    [anon_sym_required] = ACTIONS(3665),
    [anon_sym_sealed] = ACTIONS(3665),
    [anon_sym_virtual] = ACTIONS(3665),
    [anon_sym_volatile] = ACTIONS(3665),
    [anon_sym_where] = ACTIONS(3665),
    [anon_sym_notnull] = ACTIONS(3665),
    [anon_sym_unmanaged] = ACTIONS(3665),
    [anon_sym_checked] = ACTIONS(3665),
    [anon_sym_BANG] = ACTIONS(3667),
    [anon_sym_TILDE] = ACTIONS(3667),
    [anon_sym_PLUS_PLUS] = ACTIONS(3667),
    [anon_sym_DASH_DASH] = ACTIONS(3667),
    [anon_sym_true] = ACTIONS(3665),
    [anon_sym_false] = ACTIONS(3665),
    [anon_sym_PLUS] = ACTIONS(3665),
    [anon_sym_DASH] = ACTIONS(3665),
    [anon_sym_STAR] = ACTIONS(3667),
    [anon_sym_CARET] = ACTIONS(3667),
    [anon_sym_AMP] = ACTIONS(3667),
    [anon_sym_this] = ACTIONS(3665),
    [anon_sym_scoped] = ACTIONS(3665),
    [anon_sym_base] = ACTIONS(3665),
    [anon_sym_var] = ACTIONS(3665),
    [sym_predefined_type] = ACTIONS(3665),
    [anon_sym_break] = ACTIONS(3665),
    [anon_sym_unchecked] = ACTIONS(3665),
    [anon_sym_continue] = ACTIONS(3665),
    [anon_sym_do] = ACTIONS(3665),
    [anon_sym_while] = ACTIONS(3665),
    [anon_sym_for] = ACTIONS(3665),
    [anon_sym_lock] = ACTIONS(3665),
    [anon_sym_yield] = ACTIONS(3665),
    [anon_sym_switch] = ACTIONS(3665),
    [anon_sym_default] = ACTIONS(3665),
    [anon_sym_throw] = ACTIONS(3665),
    [anon_sym_try] = ACTIONS(3665),
    [anon_sym_when] = ACTIONS(3665),
    [anon_sym_await] = ACTIONS(3665),
    [anon_sym_foreach] = ACTIONS(3665),
    [anon_sym_goto] = ACTIONS(3665),
    [anon_sym_if] = ACTIONS(3665),
    [anon_sym_DOT_DOT] = ACTIONS(3667),
    [anon_sym_from] = ACTIONS(3665),
    [anon_sym_into] = ACTIONS(3665),
    [anon_sym_join] = ACTIONS(3665),
    [anon_sym_on] = ACTIONS(3665),
    [anon_sym_equals] = ACTIONS(3665),
    [anon_sym_let] = ACTIONS(3665),
    [anon_sym_orderby] = ACTIONS(3665),
    [anon_sym_ascending] = ACTIONS(3665),
    [anon_sym_descending] = ACTIONS(3665),
    [anon_sym_group] = ACTIONS(3665),
    [anon_sym_by] = ACTIONS(3665),
    [anon_sym_select] = ACTIONS(3665),
    [anon_sym_stackalloc] = ACTIONS(3665),
    [anon_sym_sizeof] = ACTIONS(3665),
    [anon_sym_typeof] = ACTIONS(3665),
    [anon_sym___makeref] = ACTIONS(3665),
    [anon_sym___reftype] = ACTIONS(3665),
    [anon_sym___refvalue] = ACTIONS(3665),
    [sym_null_literal] = ACTIONS(3665),
    [anon_sym_SQUOTE] = ACTIONS(3667),
    [sym_integer_literal] = ACTIONS(3665),
    [sym_real_literal] = ACTIONS(3667),
    [anon_sym_DQUOTE] = ACTIONS(3667),
    [sym_verbatim_string_literal] = ACTIONS(3667),
    [aux_sym_preproc_if_token1] = ACTIONS(3667),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3667),
    [sym_interpolation_verbatim_start] = ACTIONS(3667),
    [sym_interpolation_raw_start] = ACTIONS(3667),
    [sym_raw_string_start] = ACTIONS(3667),
  },
  [2600] = {
    [sym_preproc_region] = STATE(2600),
    [sym_preproc_endregion] = STATE(2600),
    [sym_preproc_line] = STATE(2600),
    [sym_preproc_pragma] = STATE(2600),
    [sym_preproc_nullable] = STATE(2600),
    [sym_preproc_error] = STATE(2600),
    [sym_preproc_warning] = STATE(2600),
    [sym_preproc_define] = STATE(2600),
    [sym_preproc_undef] = STATE(2600),
    [ts_builtin_sym_end] = ACTIONS(3671),
    [sym__identifier_token] = ACTIONS(3669),
    [anon_sym_extern] = ACTIONS(3669),
    [anon_sym_alias] = ACTIONS(3669),
    [anon_sym_SEMI] = ACTIONS(3671),
    [anon_sym_global] = ACTIONS(3669),
    [anon_sym_using] = ACTIONS(3669),
    [anon_sym_unsafe] = ACTIONS(3669),
    [anon_sym_static] = ACTIONS(3669),
    [anon_sym_LBRACK] = ACTIONS(3671),
    [anon_sym_LPAREN] = ACTIONS(3671),
    [anon_sym_return] = ACTIONS(3669),
    [anon_sym_namespace] = ACTIONS(3669),
    [anon_sym_class] = ACTIONS(3669),
    [anon_sym_ref] = ACTIONS(3669),
    [anon_sym_struct] = ACTIONS(3669),
    [anon_sym_enum] = ACTIONS(3669),
    [anon_sym_LBRACE] = ACTIONS(3671),
    [anon_sym_interface] = ACTIONS(3669),
    [anon_sym_delegate] = ACTIONS(3669),
    [anon_sym_record] = ACTIONS(3669),
    [anon_sym_abstract] = ACTIONS(3669),
    [anon_sym_async] = ACTIONS(3669),
    [anon_sym_const] = ACTIONS(3669),
    [anon_sym_file] = ACTIONS(3669),
    [anon_sym_fixed] = ACTIONS(3669),
    [anon_sym_internal] = ACTIONS(3669),
    [anon_sym_new] = ACTIONS(3669),
    [anon_sym_override] = ACTIONS(3669),
    [anon_sym_partial] = ACTIONS(3669),
    [anon_sym_private] = ACTIONS(3669),
    [anon_sym_protected] = ACTIONS(3669),
    [anon_sym_public] = ACTIONS(3669),
    [anon_sym_readonly] = ACTIONS(3669),
    [anon_sym_required] = ACTIONS(3669),
    [anon_sym_sealed] = ACTIONS(3669),
    [anon_sym_virtual] = ACTIONS(3669),
    [anon_sym_volatile] = ACTIONS(3669),
    [anon_sym_where] = ACTIONS(3669),
    [anon_sym_notnull] = ACTIONS(3669),
    [anon_sym_unmanaged] = ACTIONS(3669),
    [anon_sym_checked] = ACTIONS(3669),
    [anon_sym_BANG] = ACTIONS(3671),
    [anon_sym_TILDE] = ACTIONS(3671),
    [anon_sym_PLUS_PLUS] = ACTIONS(3671),
    [anon_sym_DASH_DASH] = ACTIONS(3671),
    [anon_sym_true] = ACTIONS(3669),
    [anon_sym_false] = ACTIONS(3669),
    [anon_sym_PLUS] = ACTIONS(3669),
    [anon_sym_DASH] = ACTIONS(3669),
    [anon_sym_STAR] = ACTIONS(3671),
    [anon_sym_CARET] = ACTIONS(3671),
    [anon_sym_AMP] = ACTIONS(3671),
    [anon_sym_this] = ACTIONS(3669),
    [anon_sym_scoped] = ACTIONS(3669),
    [anon_sym_base] = ACTIONS(3669),
    [anon_sym_var] = ACTIONS(3669),
    [sym_predefined_type] = ACTIONS(3669),
    [anon_sym_break] = ACTIONS(3669),
    [anon_sym_unchecked] = ACTIONS(3669),
    [anon_sym_continue] = ACTIONS(3669),
    [anon_sym_do] = ACTIONS(3669),
    [anon_sym_while] = ACTIONS(3669),
    [anon_sym_for] = ACTIONS(3669),
    [anon_sym_lock] = ACTIONS(3669),
    [anon_sym_yield] = ACTIONS(3669),
    [anon_sym_switch] = ACTIONS(3669),
    [anon_sym_default] = ACTIONS(3669),
    [anon_sym_throw] = ACTIONS(3669),
    [anon_sym_try] = ACTIONS(3669),
    [anon_sym_when] = ACTIONS(3669),
    [anon_sym_await] = ACTIONS(3669),
    [anon_sym_foreach] = ACTIONS(3669),
    [anon_sym_goto] = ACTIONS(3669),
    [anon_sym_if] = ACTIONS(3669),
    [anon_sym_DOT_DOT] = ACTIONS(3671),
    [anon_sym_from] = ACTIONS(3669),
    [anon_sym_into] = ACTIONS(3669),
    [anon_sym_join] = ACTIONS(3669),
    [anon_sym_on] = ACTIONS(3669),
    [anon_sym_equals] = ACTIONS(3669),
    [anon_sym_let] = ACTIONS(3669),
    [anon_sym_orderby] = ACTIONS(3669),
    [anon_sym_ascending] = ACTIONS(3669),
    [anon_sym_descending] = ACTIONS(3669),
    [anon_sym_group] = ACTIONS(3669),
    [anon_sym_by] = ACTIONS(3669),
    [anon_sym_select] = ACTIONS(3669),
    [anon_sym_stackalloc] = ACTIONS(3669),
    [anon_sym_sizeof] = ACTIONS(3669),
    [anon_sym_typeof] = ACTIONS(3669),
    [anon_sym___makeref] = ACTIONS(3669),
    [anon_sym___reftype] = ACTIONS(3669),
    [anon_sym___refvalue] = ACTIONS(3669),
    [sym_null_literal] = ACTIONS(3669),
    [anon_sym_SQUOTE] = ACTIONS(3671),
    [sym_integer_literal] = ACTIONS(3669),
    [sym_real_literal] = ACTIONS(3671),
    [anon_sym_DQUOTE] = ACTIONS(3671),
    [sym_verbatim_string_literal] = ACTIONS(3671),
    [aux_sym_preproc_if_token1] = ACTIONS(3671),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3671),
    [sym_interpolation_verbatim_start] = ACTIONS(3671),
    [sym_interpolation_raw_start] = ACTIONS(3671),
    [sym_raw_string_start] = ACTIONS(3671),
  },
  [2601] = {
    [sym_preproc_region] = STATE(2601),
    [sym_preproc_endregion] = STATE(2601),
    [sym_preproc_line] = STATE(2601),
    [sym_preproc_pragma] = STATE(2601),
    [sym_preproc_nullable] = STATE(2601),
    [sym_preproc_error] = STATE(2601),
    [sym_preproc_warning] = STATE(2601),
    [sym_preproc_define] = STATE(2601),
    [sym_preproc_undef] = STATE(2601),
    [ts_builtin_sym_end] = ACTIONS(3675),
    [sym__identifier_token] = ACTIONS(3673),
    [anon_sym_extern] = ACTIONS(3673),
    [anon_sym_alias] = ACTIONS(3673),
    [anon_sym_SEMI] = ACTIONS(3675),
    [anon_sym_global] = ACTIONS(3673),
    [anon_sym_using] = ACTIONS(3673),
    [anon_sym_unsafe] = ACTIONS(3673),
    [anon_sym_static] = ACTIONS(3673),
    [anon_sym_LBRACK] = ACTIONS(3675),
    [anon_sym_LPAREN] = ACTIONS(3675),
    [anon_sym_return] = ACTIONS(3673),
    [anon_sym_namespace] = ACTIONS(3673),
    [anon_sym_class] = ACTIONS(3673),
    [anon_sym_ref] = ACTIONS(3673),
    [anon_sym_struct] = ACTIONS(3673),
    [anon_sym_enum] = ACTIONS(3673),
    [anon_sym_LBRACE] = ACTIONS(3675),
    [anon_sym_interface] = ACTIONS(3673),
    [anon_sym_delegate] = ACTIONS(3673),
    [anon_sym_record] = ACTIONS(3673),
    [anon_sym_abstract] = ACTIONS(3673),
    [anon_sym_async] = ACTIONS(3673),
    [anon_sym_const] = ACTIONS(3673),
    [anon_sym_file] = ACTIONS(3673),
    [anon_sym_fixed] = ACTIONS(3673),
    [anon_sym_internal] = ACTIONS(3673),
    [anon_sym_new] = ACTIONS(3673),
    [anon_sym_override] = ACTIONS(3673),
    [anon_sym_partial] = ACTIONS(3673),
    [anon_sym_private] = ACTIONS(3673),
    [anon_sym_protected] = ACTIONS(3673),
    [anon_sym_public] = ACTIONS(3673),
    [anon_sym_readonly] = ACTIONS(3673),
    [anon_sym_required] = ACTIONS(3673),
    [anon_sym_sealed] = ACTIONS(3673),
    [anon_sym_virtual] = ACTIONS(3673),
    [anon_sym_volatile] = ACTIONS(3673),
    [anon_sym_where] = ACTIONS(3673),
    [anon_sym_notnull] = ACTIONS(3673),
    [anon_sym_unmanaged] = ACTIONS(3673),
    [anon_sym_checked] = ACTIONS(3673),
    [anon_sym_BANG] = ACTIONS(3675),
    [anon_sym_TILDE] = ACTIONS(3675),
    [anon_sym_PLUS_PLUS] = ACTIONS(3675),
    [anon_sym_DASH_DASH] = ACTIONS(3675),
    [anon_sym_true] = ACTIONS(3673),
    [anon_sym_false] = ACTIONS(3673),
    [anon_sym_PLUS] = ACTIONS(3673),
    [anon_sym_DASH] = ACTIONS(3673),
    [anon_sym_STAR] = ACTIONS(3675),
    [anon_sym_CARET] = ACTIONS(3675),
    [anon_sym_AMP] = ACTIONS(3675),
    [anon_sym_this] = ACTIONS(3673),
    [anon_sym_scoped] = ACTIONS(3673),
    [anon_sym_base] = ACTIONS(3673),
    [anon_sym_var] = ACTIONS(3673),
    [sym_predefined_type] = ACTIONS(3673),
    [anon_sym_break] = ACTIONS(3673),
    [anon_sym_unchecked] = ACTIONS(3673),
    [anon_sym_continue] = ACTIONS(3673),
    [anon_sym_do] = ACTIONS(3673),
    [anon_sym_while] = ACTIONS(3673),
    [anon_sym_for] = ACTIONS(3673),
    [anon_sym_lock] = ACTIONS(3673),
    [anon_sym_yield] = ACTIONS(3673),
    [anon_sym_switch] = ACTIONS(3673),
    [anon_sym_default] = ACTIONS(3673),
    [anon_sym_throw] = ACTIONS(3673),
    [anon_sym_try] = ACTIONS(3673),
    [anon_sym_when] = ACTIONS(3673),
    [anon_sym_await] = ACTIONS(3673),
    [anon_sym_foreach] = ACTIONS(3673),
    [anon_sym_goto] = ACTIONS(3673),
    [anon_sym_if] = ACTIONS(3673),
    [anon_sym_DOT_DOT] = ACTIONS(3675),
    [anon_sym_from] = ACTIONS(3673),
    [anon_sym_into] = ACTIONS(3673),
    [anon_sym_join] = ACTIONS(3673),
    [anon_sym_on] = ACTIONS(3673),
    [anon_sym_equals] = ACTIONS(3673),
    [anon_sym_let] = ACTIONS(3673),
    [anon_sym_orderby] = ACTIONS(3673),
    [anon_sym_ascending] = ACTIONS(3673),
    [anon_sym_descending] = ACTIONS(3673),
    [anon_sym_group] = ACTIONS(3673),
    [anon_sym_by] = ACTIONS(3673),
    [anon_sym_select] = ACTIONS(3673),
    [anon_sym_stackalloc] = ACTIONS(3673),
    [anon_sym_sizeof] = ACTIONS(3673),
    [anon_sym_typeof] = ACTIONS(3673),
    [anon_sym___makeref] = ACTIONS(3673),
    [anon_sym___reftype] = ACTIONS(3673),
    [anon_sym___refvalue] = ACTIONS(3673),
    [sym_null_literal] = ACTIONS(3673),
    [anon_sym_SQUOTE] = ACTIONS(3675),
    [sym_integer_literal] = ACTIONS(3673),
    [sym_real_literal] = ACTIONS(3675),
    [anon_sym_DQUOTE] = ACTIONS(3675),
    [sym_verbatim_string_literal] = ACTIONS(3675),
    [aux_sym_preproc_if_token1] = ACTIONS(3675),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3675),
    [sym_interpolation_verbatim_start] = ACTIONS(3675),
    [sym_interpolation_raw_start] = ACTIONS(3675),
    [sym_raw_string_start] = ACTIONS(3675),
  },
  [2602] = {
    [sym_preproc_region] = STATE(2602),
    [sym_preproc_endregion] = STATE(2602),
    [sym_preproc_line] = STATE(2602),
    [sym_preproc_pragma] = STATE(2602),
    [sym_preproc_nullable] = STATE(2602),
    [sym_preproc_error] = STATE(2602),
    [sym_preproc_warning] = STATE(2602),
    [sym_preproc_define] = STATE(2602),
    [sym_preproc_undef] = STATE(2602),
    [ts_builtin_sym_end] = ACTIONS(3679),
    [sym__identifier_token] = ACTIONS(3677),
    [anon_sym_extern] = ACTIONS(3677),
    [anon_sym_alias] = ACTIONS(3677),
    [anon_sym_SEMI] = ACTIONS(3679),
    [anon_sym_global] = ACTIONS(3677),
    [anon_sym_using] = ACTIONS(3677),
    [anon_sym_unsafe] = ACTIONS(3677),
    [anon_sym_static] = ACTIONS(3677),
    [anon_sym_LBRACK] = ACTIONS(3679),
    [anon_sym_LPAREN] = ACTIONS(3679),
    [anon_sym_return] = ACTIONS(3677),
    [anon_sym_namespace] = ACTIONS(3677),
    [anon_sym_class] = ACTIONS(3677),
    [anon_sym_ref] = ACTIONS(3677),
    [anon_sym_struct] = ACTIONS(3677),
    [anon_sym_enum] = ACTIONS(3677),
    [anon_sym_LBRACE] = ACTIONS(3679),
    [anon_sym_interface] = ACTIONS(3677),
    [anon_sym_delegate] = ACTIONS(3677),
    [anon_sym_record] = ACTIONS(3677),
    [anon_sym_abstract] = ACTIONS(3677),
    [anon_sym_async] = ACTIONS(3677),
    [anon_sym_const] = ACTIONS(3677),
    [anon_sym_file] = ACTIONS(3677),
    [anon_sym_fixed] = ACTIONS(3677),
    [anon_sym_internal] = ACTIONS(3677),
    [anon_sym_new] = ACTIONS(3677),
    [anon_sym_override] = ACTIONS(3677),
    [anon_sym_partial] = ACTIONS(3677),
    [anon_sym_private] = ACTIONS(3677),
    [anon_sym_protected] = ACTIONS(3677),
    [anon_sym_public] = ACTIONS(3677),
    [anon_sym_readonly] = ACTIONS(3677),
    [anon_sym_required] = ACTIONS(3677),
    [anon_sym_sealed] = ACTIONS(3677),
    [anon_sym_virtual] = ACTIONS(3677),
    [anon_sym_volatile] = ACTIONS(3677),
    [anon_sym_where] = ACTIONS(3677),
    [anon_sym_notnull] = ACTIONS(3677),
    [anon_sym_unmanaged] = ACTIONS(3677),
    [anon_sym_checked] = ACTIONS(3677),
    [anon_sym_BANG] = ACTIONS(3679),
    [anon_sym_TILDE] = ACTIONS(3679),
    [anon_sym_PLUS_PLUS] = ACTIONS(3679),
    [anon_sym_DASH_DASH] = ACTIONS(3679),
    [anon_sym_true] = ACTIONS(3677),
    [anon_sym_false] = ACTIONS(3677),
    [anon_sym_PLUS] = ACTIONS(3677),
    [anon_sym_DASH] = ACTIONS(3677),
    [anon_sym_STAR] = ACTIONS(3679),
    [anon_sym_CARET] = ACTIONS(3679),
    [anon_sym_AMP] = ACTIONS(3679),
    [anon_sym_this] = ACTIONS(3677),
    [anon_sym_scoped] = ACTIONS(3677),
    [anon_sym_base] = ACTIONS(3677),
    [anon_sym_var] = ACTIONS(3677),
    [sym_predefined_type] = ACTIONS(3677),
    [anon_sym_break] = ACTIONS(3677),
    [anon_sym_unchecked] = ACTIONS(3677),
    [anon_sym_continue] = ACTIONS(3677),
    [anon_sym_do] = ACTIONS(3677),
    [anon_sym_while] = ACTIONS(3677),
    [anon_sym_for] = ACTIONS(3677),
    [anon_sym_lock] = ACTIONS(3677),
    [anon_sym_yield] = ACTIONS(3677),
    [anon_sym_switch] = ACTIONS(3677),
    [anon_sym_default] = ACTIONS(3677),
    [anon_sym_throw] = ACTIONS(3677),
    [anon_sym_try] = ACTIONS(3677),
    [anon_sym_when] = ACTIONS(3677),
    [anon_sym_await] = ACTIONS(3677),
    [anon_sym_foreach] = ACTIONS(3677),
    [anon_sym_goto] = ACTIONS(3677),
    [anon_sym_if] = ACTIONS(3677),
    [anon_sym_DOT_DOT] = ACTIONS(3679),
    [anon_sym_from] = ACTIONS(3677),
    [anon_sym_into] = ACTIONS(3677),
    [anon_sym_join] = ACTIONS(3677),
    [anon_sym_on] = ACTIONS(3677),
    [anon_sym_equals] = ACTIONS(3677),
    [anon_sym_let] = ACTIONS(3677),
    [anon_sym_orderby] = ACTIONS(3677),
    [anon_sym_ascending] = ACTIONS(3677),
    [anon_sym_descending] = ACTIONS(3677),
    [anon_sym_group] = ACTIONS(3677),
    [anon_sym_by] = ACTIONS(3677),
    [anon_sym_select] = ACTIONS(3677),
    [anon_sym_stackalloc] = ACTIONS(3677),
    [anon_sym_sizeof] = ACTIONS(3677),
    [anon_sym_typeof] = ACTIONS(3677),
    [anon_sym___makeref] = ACTIONS(3677),
    [anon_sym___reftype] = ACTIONS(3677),
    [anon_sym___refvalue] = ACTIONS(3677),
    [sym_null_literal] = ACTIONS(3677),
    [anon_sym_SQUOTE] = ACTIONS(3679),
    [sym_integer_literal] = ACTIONS(3677),
    [sym_real_literal] = ACTIONS(3679),
    [anon_sym_DQUOTE] = ACTIONS(3679),
    [sym_verbatim_string_literal] = ACTIONS(3679),
    [aux_sym_preproc_if_token1] = ACTIONS(3679),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3679),
    [sym_interpolation_verbatim_start] = ACTIONS(3679),
    [sym_interpolation_raw_start] = ACTIONS(3679),
    [sym_raw_string_start] = ACTIONS(3679),
  },
  [2603] = {
    [sym_preproc_region] = STATE(2603),
    [sym_preproc_endregion] = STATE(2603),
    [sym_preproc_line] = STATE(2603),
    [sym_preproc_pragma] = STATE(2603),
    [sym_preproc_nullable] = STATE(2603),
    [sym_preproc_error] = STATE(2603),
    [sym_preproc_warning] = STATE(2603),
    [sym_preproc_define] = STATE(2603),
    [sym_preproc_undef] = STATE(2603),
    [ts_builtin_sym_end] = ACTIONS(3423),
    [sym__identifier_token] = ACTIONS(3421),
    [anon_sym_extern] = ACTIONS(3421),
    [anon_sym_alias] = ACTIONS(3421),
    [anon_sym_SEMI] = ACTIONS(3423),
    [anon_sym_global] = ACTIONS(3421),
    [anon_sym_using] = ACTIONS(3421),
    [anon_sym_unsafe] = ACTIONS(3421),
    [anon_sym_static] = ACTIONS(3421),
    [anon_sym_LBRACK] = ACTIONS(3423),
    [anon_sym_LPAREN] = ACTIONS(3423),
    [anon_sym_return] = ACTIONS(3421),
    [anon_sym_namespace] = ACTIONS(3421),
    [anon_sym_class] = ACTIONS(3421),
    [anon_sym_ref] = ACTIONS(3421),
    [anon_sym_struct] = ACTIONS(3421),
    [anon_sym_enum] = ACTIONS(3421),
    [anon_sym_LBRACE] = ACTIONS(3423),
    [anon_sym_interface] = ACTIONS(3421),
    [anon_sym_delegate] = ACTIONS(3421),
    [anon_sym_record] = ACTIONS(3421),
    [anon_sym_abstract] = ACTIONS(3421),
    [anon_sym_async] = ACTIONS(3421),
    [anon_sym_const] = ACTIONS(3421),
    [anon_sym_file] = ACTIONS(3421),
    [anon_sym_fixed] = ACTIONS(3421),
    [anon_sym_internal] = ACTIONS(3421),
    [anon_sym_new] = ACTIONS(3421),
    [anon_sym_override] = ACTIONS(3421),
    [anon_sym_partial] = ACTIONS(3421),
    [anon_sym_private] = ACTIONS(3421),
    [anon_sym_protected] = ACTIONS(3421),
    [anon_sym_public] = ACTIONS(3421),
    [anon_sym_readonly] = ACTIONS(3421),
    [anon_sym_required] = ACTIONS(3421),
    [anon_sym_sealed] = ACTIONS(3421),
    [anon_sym_virtual] = ACTIONS(3421),
    [anon_sym_volatile] = ACTIONS(3421),
    [anon_sym_where] = ACTIONS(3421),
    [anon_sym_notnull] = ACTIONS(3421),
    [anon_sym_unmanaged] = ACTIONS(3421),
    [anon_sym_checked] = ACTIONS(3421),
    [anon_sym_BANG] = ACTIONS(3423),
    [anon_sym_TILDE] = ACTIONS(3423),
    [anon_sym_PLUS_PLUS] = ACTIONS(3423),
    [anon_sym_DASH_DASH] = ACTIONS(3423),
    [anon_sym_true] = ACTIONS(3421),
    [anon_sym_false] = ACTIONS(3421),
    [anon_sym_PLUS] = ACTIONS(3421),
    [anon_sym_DASH] = ACTIONS(3421),
    [anon_sym_STAR] = ACTIONS(3423),
    [anon_sym_CARET] = ACTIONS(3423),
    [anon_sym_AMP] = ACTIONS(3423),
    [anon_sym_this] = ACTIONS(3421),
    [anon_sym_scoped] = ACTIONS(3421),
    [anon_sym_base] = ACTIONS(3421),
    [anon_sym_var] = ACTIONS(3421),
    [sym_predefined_type] = ACTIONS(3421),
    [anon_sym_break] = ACTIONS(3421),
    [anon_sym_unchecked] = ACTIONS(3421),
    [anon_sym_continue] = ACTIONS(3421),
    [anon_sym_do] = ACTIONS(3421),
    [anon_sym_while] = ACTIONS(3421),
    [anon_sym_for] = ACTIONS(3421),
    [anon_sym_lock] = ACTIONS(3421),
    [anon_sym_yield] = ACTIONS(3421),
    [anon_sym_switch] = ACTIONS(3421),
    [anon_sym_default] = ACTIONS(3421),
    [anon_sym_throw] = ACTIONS(3421),
    [anon_sym_try] = ACTIONS(3421),
    [anon_sym_when] = ACTIONS(3421),
    [anon_sym_await] = ACTIONS(3421),
    [anon_sym_foreach] = ACTIONS(3421),
    [anon_sym_goto] = ACTIONS(3421),
    [anon_sym_if] = ACTIONS(3421),
    [anon_sym_DOT_DOT] = ACTIONS(3423),
    [anon_sym_from] = ACTIONS(3421),
    [anon_sym_into] = ACTIONS(3421),
    [anon_sym_join] = ACTIONS(3421),
    [anon_sym_on] = ACTIONS(3421),
    [anon_sym_equals] = ACTIONS(3421),
    [anon_sym_let] = ACTIONS(3421),
    [anon_sym_orderby] = ACTIONS(3421),
    [anon_sym_ascending] = ACTIONS(3421),
    [anon_sym_descending] = ACTIONS(3421),
    [anon_sym_group] = ACTIONS(3421),
    [anon_sym_by] = ACTIONS(3421),
    [anon_sym_select] = ACTIONS(3421),
    [anon_sym_stackalloc] = ACTIONS(3421),
    [anon_sym_sizeof] = ACTIONS(3421),
    [anon_sym_typeof] = ACTIONS(3421),
    [anon_sym___makeref] = ACTIONS(3421),
    [anon_sym___reftype] = ACTIONS(3421),
    [anon_sym___refvalue] = ACTIONS(3421),
    [sym_null_literal] = ACTIONS(3421),
    [anon_sym_SQUOTE] = ACTIONS(3423),
    [sym_integer_literal] = ACTIONS(3421),
    [sym_real_literal] = ACTIONS(3423),
    [anon_sym_DQUOTE] = ACTIONS(3423),
    [sym_verbatim_string_literal] = ACTIONS(3423),
    [aux_sym_preproc_if_token1] = ACTIONS(3423),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3423),
    [sym_interpolation_verbatim_start] = ACTIONS(3423),
    [sym_interpolation_raw_start] = ACTIONS(3423),
    [sym_raw_string_start] = ACTIONS(3423),
  },
  [2604] = {
    [sym_preproc_region] = STATE(2604),
    [sym_preproc_endregion] = STATE(2604),
    [sym_preproc_line] = STATE(2604),
    [sym_preproc_pragma] = STATE(2604),
    [sym_preproc_nullable] = STATE(2604),
    [sym_preproc_error] = STATE(2604),
    [sym_preproc_warning] = STATE(2604),
    [sym_preproc_define] = STATE(2604),
    [sym_preproc_undef] = STATE(2604),
    [ts_builtin_sym_end] = ACTIONS(3957),
    [sym__identifier_token] = ACTIONS(3955),
    [anon_sym_extern] = ACTIONS(3955),
    [anon_sym_alias] = ACTIONS(3955),
    [anon_sym_SEMI] = ACTIONS(3957),
    [anon_sym_global] = ACTIONS(3955),
    [anon_sym_using] = ACTIONS(3955),
    [anon_sym_unsafe] = ACTIONS(3955),
    [anon_sym_static] = ACTIONS(3955),
    [anon_sym_LBRACK] = ACTIONS(3957),
    [anon_sym_LPAREN] = ACTIONS(3957),
    [anon_sym_return] = ACTIONS(3955),
    [anon_sym_namespace] = ACTIONS(3955),
    [anon_sym_class] = ACTIONS(3955),
    [anon_sym_ref] = ACTIONS(3955),
    [anon_sym_struct] = ACTIONS(3955),
    [anon_sym_enum] = ACTIONS(3955),
    [anon_sym_LBRACE] = ACTIONS(3957),
    [anon_sym_interface] = ACTIONS(3955),
    [anon_sym_delegate] = ACTIONS(3955),
    [anon_sym_record] = ACTIONS(3955),
    [anon_sym_abstract] = ACTIONS(3955),
    [anon_sym_async] = ACTIONS(3955),
    [anon_sym_const] = ACTIONS(3955),
    [anon_sym_file] = ACTIONS(3955),
    [anon_sym_fixed] = ACTIONS(3955),
    [anon_sym_internal] = ACTIONS(3955),
    [anon_sym_new] = ACTIONS(3955),
    [anon_sym_override] = ACTIONS(3955),
    [anon_sym_partial] = ACTIONS(3955),
    [anon_sym_private] = ACTIONS(3955),
    [anon_sym_protected] = ACTIONS(3955),
    [anon_sym_public] = ACTIONS(3955),
    [anon_sym_readonly] = ACTIONS(3955),
    [anon_sym_required] = ACTIONS(3955),
    [anon_sym_sealed] = ACTIONS(3955),
    [anon_sym_virtual] = ACTIONS(3955),
    [anon_sym_volatile] = ACTIONS(3955),
    [anon_sym_where] = ACTIONS(3955),
    [anon_sym_notnull] = ACTIONS(3955),
    [anon_sym_unmanaged] = ACTIONS(3955),
    [anon_sym_checked] = ACTIONS(3955),
    [anon_sym_BANG] = ACTIONS(3957),
    [anon_sym_TILDE] = ACTIONS(3957),
    [anon_sym_PLUS_PLUS] = ACTIONS(3957),
    [anon_sym_DASH_DASH] = ACTIONS(3957),
    [anon_sym_true] = ACTIONS(3955),
    [anon_sym_false] = ACTIONS(3955),
    [anon_sym_PLUS] = ACTIONS(3955),
    [anon_sym_DASH] = ACTIONS(3955),
    [anon_sym_STAR] = ACTIONS(3957),
    [anon_sym_CARET] = ACTIONS(3957),
    [anon_sym_AMP] = ACTIONS(3957),
    [anon_sym_this] = ACTIONS(3955),
    [anon_sym_scoped] = ACTIONS(3955),
    [anon_sym_base] = ACTIONS(3955),
    [anon_sym_var] = ACTIONS(3955),
    [sym_predefined_type] = ACTIONS(3955),
    [anon_sym_break] = ACTIONS(3955),
    [anon_sym_unchecked] = ACTIONS(3955),
    [anon_sym_continue] = ACTIONS(3955),
    [anon_sym_do] = ACTIONS(3955),
    [anon_sym_while] = ACTIONS(3955),
    [anon_sym_for] = ACTIONS(3955),
    [anon_sym_lock] = ACTIONS(3955),
    [anon_sym_yield] = ACTIONS(3955),
    [anon_sym_switch] = ACTIONS(3955),
    [anon_sym_default] = ACTIONS(3955),
    [anon_sym_throw] = ACTIONS(3955),
    [anon_sym_try] = ACTIONS(3955),
    [anon_sym_when] = ACTIONS(3955),
    [anon_sym_await] = ACTIONS(3955),
    [anon_sym_foreach] = ACTIONS(3955),
    [anon_sym_goto] = ACTIONS(3955),
    [anon_sym_if] = ACTIONS(3955),
    [anon_sym_DOT_DOT] = ACTIONS(3957),
    [anon_sym_from] = ACTIONS(3955),
    [anon_sym_into] = ACTIONS(3955),
    [anon_sym_join] = ACTIONS(3955),
    [anon_sym_on] = ACTIONS(3955),
    [anon_sym_equals] = ACTIONS(3955),
    [anon_sym_let] = ACTIONS(3955),
    [anon_sym_orderby] = ACTIONS(3955),
    [anon_sym_ascending] = ACTIONS(3955),
    [anon_sym_descending] = ACTIONS(3955),
    [anon_sym_group] = ACTIONS(3955),
    [anon_sym_by] = ACTIONS(3955),
    [anon_sym_select] = ACTIONS(3955),
    [anon_sym_stackalloc] = ACTIONS(3955),
    [anon_sym_sizeof] = ACTIONS(3955),
    [anon_sym_typeof] = ACTIONS(3955),
    [anon_sym___makeref] = ACTIONS(3955),
    [anon_sym___reftype] = ACTIONS(3955),
    [anon_sym___refvalue] = ACTIONS(3955),
    [sym_null_literal] = ACTIONS(3955),
    [anon_sym_SQUOTE] = ACTIONS(3957),
    [sym_integer_literal] = ACTIONS(3955),
    [sym_real_literal] = ACTIONS(3957),
    [anon_sym_DQUOTE] = ACTIONS(3957),
    [sym_verbatim_string_literal] = ACTIONS(3957),
    [aux_sym_preproc_if_token1] = ACTIONS(3957),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3957),
    [sym_interpolation_verbatim_start] = ACTIONS(3957),
    [sym_interpolation_raw_start] = ACTIONS(3957),
    [sym_raw_string_start] = ACTIONS(3957),
  },
  [2605] = {
    [sym_preproc_region] = STATE(2605),
    [sym_preproc_endregion] = STATE(2605),
    [sym_preproc_line] = STATE(2605),
    [sym_preproc_pragma] = STATE(2605),
    [sym_preproc_nullable] = STATE(2605),
    [sym_preproc_error] = STATE(2605),
    [sym_preproc_warning] = STATE(2605),
    [sym_preproc_define] = STATE(2605),
    [sym_preproc_undef] = STATE(2605),
    [ts_builtin_sym_end] = ACTIONS(3563),
    [sym__identifier_token] = ACTIONS(3561),
    [anon_sym_extern] = ACTIONS(3561),
    [anon_sym_alias] = ACTIONS(3561),
    [anon_sym_SEMI] = ACTIONS(3563),
    [anon_sym_global] = ACTIONS(3561),
    [anon_sym_using] = ACTIONS(3561),
    [anon_sym_unsafe] = ACTIONS(3561),
    [anon_sym_static] = ACTIONS(3561),
    [anon_sym_LBRACK] = ACTIONS(3563),
    [anon_sym_LPAREN] = ACTIONS(3563),
    [anon_sym_return] = ACTIONS(3561),
    [anon_sym_namespace] = ACTIONS(3561),
    [anon_sym_class] = ACTIONS(3561),
    [anon_sym_ref] = ACTIONS(3561),
    [anon_sym_struct] = ACTIONS(3561),
    [anon_sym_enum] = ACTIONS(3561),
    [anon_sym_LBRACE] = ACTIONS(3563),
    [anon_sym_interface] = ACTIONS(3561),
    [anon_sym_delegate] = ACTIONS(3561),
    [anon_sym_record] = ACTIONS(3561),
    [anon_sym_abstract] = ACTIONS(3561),
    [anon_sym_async] = ACTIONS(3561),
    [anon_sym_const] = ACTIONS(3561),
    [anon_sym_file] = ACTIONS(3561),
    [anon_sym_fixed] = ACTIONS(3561),
    [anon_sym_internal] = ACTIONS(3561),
    [anon_sym_new] = ACTIONS(3561),
    [anon_sym_override] = ACTIONS(3561),
    [anon_sym_partial] = ACTIONS(3561),
    [anon_sym_private] = ACTIONS(3561),
    [anon_sym_protected] = ACTIONS(3561),
    [anon_sym_public] = ACTIONS(3561),
    [anon_sym_readonly] = ACTIONS(3561),
    [anon_sym_required] = ACTIONS(3561),
    [anon_sym_sealed] = ACTIONS(3561),
    [anon_sym_virtual] = ACTIONS(3561),
    [anon_sym_volatile] = ACTIONS(3561),
    [anon_sym_where] = ACTIONS(3561),
    [anon_sym_notnull] = ACTIONS(3561),
    [anon_sym_unmanaged] = ACTIONS(3561),
    [anon_sym_checked] = ACTIONS(3561),
    [anon_sym_BANG] = ACTIONS(3563),
    [anon_sym_TILDE] = ACTIONS(3563),
    [anon_sym_PLUS_PLUS] = ACTIONS(3563),
    [anon_sym_DASH_DASH] = ACTIONS(3563),
    [anon_sym_true] = ACTIONS(3561),
    [anon_sym_false] = ACTIONS(3561),
    [anon_sym_PLUS] = ACTIONS(3561),
    [anon_sym_DASH] = ACTIONS(3561),
    [anon_sym_STAR] = ACTIONS(3563),
    [anon_sym_CARET] = ACTIONS(3563),
    [anon_sym_AMP] = ACTIONS(3563),
    [anon_sym_this] = ACTIONS(3561),
    [anon_sym_scoped] = ACTIONS(3561),
    [anon_sym_base] = ACTIONS(3561),
    [anon_sym_var] = ACTIONS(3561),
    [sym_predefined_type] = ACTIONS(3561),
    [anon_sym_break] = ACTIONS(3561),
    [anon_sym_unchecked] = ACTIONS(3561),
    [anon_sym_continue] = ACTIONS(3561),
    [anon_sym_do] = ACTIONS(3561),
    [anon_sym_while] = ACTIONS(3561),
    [anon_sym_for] = ACTIONS(3561),
    [anon_sym_lock] = ACTIONS(3561),
    [anon_sym_yield] = ACTIONS(3561),
    [anon_sym_switch] = ACTIONS(3561),
    [anon_sym_default] = ACTIONS(3561),
    [anon_sym_throw] = ACTIONS(3561),
    [anon_sym_try] = ACTIONS(3561),
    [anon_sym_when] = ACTIONS(3561),
    [anon_sym_await] = ACTIONS(3561),
    [anon_sym_foreach] = ACTIONS(3561),
    [anon_sym_goto] = ACTIONS(3561),
    [anon_sym_if] = ACTIONS(3561),
    [anon_sym_DOT_DOT] = ACTIONS(3563),
    [anon_sym_from] = ACTIONS(3561),
    [anon_sym_into] = ACTIONS(3561),
    [anon_sym_join] = ACTIONS(3561),
    [anon_sym_on] = ACTIONS(3561),
    [anon_sym_equals] = ACTIONS(3561),
    [anon_sym_let] = ACTIONS(3561),
    [anon_sym_orderby] = ACTIONS(3561),
    [anon_sym_ascending] = ACTIONS(3561),
    [anon_sym_descending] = ACTIONS(3561),
    [anon_sym_group] = ACTIONS(3561),
    [anon_sym_by] = ACTIONS(3561),
    [anon_sym_select] = ACTIONS(3561),
    [anon_sym_stackalloc] = ACTIONS(3561),
    [anon_sym_sizeof] = ACTIONS(3561),
    [anon_sym_typeof] = ACTIONS(3561),
    [anon_sym___makeref] = ACTIONS(3561),
    [anon_sym___reftype] = ACTIONS(3561),
    [anon_sym___refvalue] = ACTIONS(3561),
    [sym_null_literal] = ACTIONS(3561),
    [anon_sym_SQUOTE] = ACTIONS(3563),
    [sym_integer_literal] = ACTIONS(3561),
    [sym_real_literal] = ACTIONS(3563),
    [anon_sym_DQUOTE] = ACTIONS(3563),
    [sym_verbatim_string_literal] = ACTIONS(3563),
    [aux_sym_preproc_if_token1] = ACTIONS(3563),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3563),
    [sym_interpolation_verbatim_start] = ACTIONS(3563),
    [sym_interpolation_raw_start] = ACTIONS(3563),
    [sym_raw_string_start] = ACTIONS(3563),
  },
  [2606] = {
    [sym_preproc_region] = STATE(2606),
    [sym_preproc_endregion] = STATE(2606),
    [sym_preproc_line] = STATE(2606),
    [sym_preproc_pragma] = STATE(2606),
    [sym_preproc_nullable] = STATE(2606),
    [sym_preproc_error] = STATE(2606),
    [sym_preproc_warning] = STATE(2606),
    [sym_preproc_define] = STATE(2606),
    [sym_preproc_undef] = STATE(2606),
    [ts_builtin_sym_end] = ACTIONS(3567),
    [sym__identifier_token] = ACTIONS(3565),
    [anon_sym_extern] = ACTIONS(3565),
    [anon_sym_alias] = ACTIONS(3565),
    [anon_sym_SEMI] = ACTIONS(3567),
    [anon_sym_global] = ACTIONS(3565),
    [anon_sym_using] = ACTIONS(3565),
    [anon_sym_unsafe] = ACTIONS(3565),
    [anon_sym_static] = ACTIONS(3565),
    [anon_sym_LBRACK] = ACTIONS(3567),
    [anon_sym_LPAREN] = ACTIONS(3567),
    [anon_sym_return] = ACTIONS(3565),
    [anon_sym_namespace] = ACTIONS(3565),
    [anon_sym_class] = ACTIONS(3565),
    [anon_sym_ref] = ACTIONS(3565),
    [anon_sym_struct] = ACTIONS(3565),
    [anon_sym_enum] = ACTIONS(3565),
    [anon_sym_LBRACE] = ACTIONS(3567),
    [anon_sym_interface] = ACTIONS(3565),
    [anon_sym_delegate] = ACTIONS(3565),
    [anon_sym_record] = ACTIONS(3565),
    [anon_sym_abstract] = ACTIONS(3565),
    [anon_sym_async] = ACTIONS(3565),
    [anon_sym_const] = ACTIONS(3565),
    [anon_sym_file] = ACTIONS(3565),
    [anon_sym_fixed] = ACTIONS(3565),
    [anon_sym_internal] = ACTIONS(3565),
    [anon_sym_new] = ACTIONS(3565),
    [anon_sym_override] = ACTIONS(3565),
    [anon_sym_partial] = ACTIONS(3565),
    [anon_sym_private] = ACTIONS(3565),
    [anon_sym_protected] = ACTIONS(3565),
    [anon_sym_public] = ACTIONS(3565),
    [anon_sym_readonly] = ACTIONS(3565),
    [anon_sym_required] = ACTIONS(3565),
    [anon_sym_sealed] = ACTIONS(3565),
    [anon_sym_virtual] = ACTIONS(3565),
    [anon_sym_volatile] = ACTIONS(3565),
    [anon_sym_where] = ACTIONS(3565),
    [anon_sym_notnull] = ACTIONS(3565),
    [anon_sym_unmanaged] = ACTIONS(3565),
    [anon_sym_checked] = ACTIONS(3565),
    [anon_sym_BANG] = ACTIONS(3567),
    [anon_sym_TILDE] = ACTIONS(3567),
    [anon_sym_PLUS_PLUS] = ACTIONS(3567),
    [anon_sym_DASH_DASH] = ACTIONS(3567),
    [anon_sym_true] = ACTIONS(3565),
    [anon_sym_false] = ACTIONS(3565),
    [anon_sym_PLUS] = ACTIONS(3565),
    [anon_sym_DASH] = ACTIONS(3565),
    [anon_sym_STAR] = ACTIONS(3567),
    [anon_sym_CARET] = ACTIONS(3567),
    [anon_sym_AMP] = ACTIONS(3567),
    [anon_sym_this] = ACTIONS(3565),
    [anon_sym_scoped] = ACTIONS(3565),
    [anon_sym_base] = ACTIONS(3565),
    [anon_sym_var] = ACTIONS(3565),
    [sym_predefined_type] = ACTIONS(3565),
    [anon_sym_break] = ACTIONS(3565),
    [anon_sym_unchecked] = ACTIONS(3565),
    [anon_sym_continue] = ACTIONS(3565),
    [anon_sym_do] = ACTIONS(3565),
    [anon_sym_while] = ACTIONS(3565),
    [anon_sym_for] = ACTIONS(3565),
    [anon_sym_lock] = ACTIONS(3565),
    [anon_sym_yield] = ACTIONS(3565),
    [anon_sym_switch] = ACTIONS(3565),
    [anon_sym_default] = ACTIONS(3565),
    [anon_sym_throw] = ACTIONS(3565),
    [anon_sym_try] = ACTIONS(3565),
    [anon_sym_when] = ACTIONS(3565),
    [anon_sym_await] = ACTIONS(3565),
    [anon_sym_foreach] = ACTIONS(3565),
    [anon_sym_goto] = ACTIONS(3565),
    [anon_sym_if] = ACTIONS(3565),
    [anon_sym_DOT_DOT] = ACTIONS(3567),
    [anon_sym_from] = ACTIONS(3565),
    [anon_sym_into] = ACTIONS(3565),
    [anon_sym_join] = ACTIONS(3565),
    [anon_sym_on] = ACTIONS(3565),
    [anon_sym_equals] = ACTIONS(3565),
    [anon_sym_let] = ACTIONS(3565),
    [anon_sym_orderby] = ACTIONS(3565),
    [anon_sym_ascending] = ACTIONS(3565),
    [anon_sym_descending] = ACTIONS(3565),
    [anon_sym_group] = ACTIONS(3565),
    [anon_sym_by] = ACTIONS(3565),
    [anon_sym_select] = ACTIONS(3565),
    [anon_sym_stackalloc] = ACTIONS(3565),
    [anon_sym_sizeof] = ACTIONS(3565),
    [anon_sym_typeof] = ACTIONS(3565),
    [anon_sym___makeref] = ACTIONS(3565),
    [anon_sym___reftype] = ACTIONS(3565),
    [anon_sym___refvalue] = ACTIONS(3565),
    [sym_null_literal] = ACTIONS(3565),
    [anon_sym_SQUOTE] = ACTIONS(3567),
    [sym_integer_literal] = ACTIONS(3565),
    [sym_real_literal] = ACTIONS(3567),
    [anon_sym_DQUOTE] = ACTIONS(3567),
    [sym_verbatim_string_literal] = ACTIONS(3567),
    [aux_sym_preproc_if_token1] = ACTIONS(3567),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3567),
    [sym_interpolation_verbatim_start] = ACTIONS(3567),
    [sym_interpolation_raw_start] = ACTIONS(3567),
    [sym_raw_string_start] = ACTIONS(3567),
  },
  [2607] = {
    [sym_preproc_region] = STATE(2607),
    [sym_preproc_endregion] = STATE(2607),
    [sym_preproc_line] = STATE(2607),
    [sym_preproc_pragma] = STATE(2607),
    [sym_preproc_nullable] = STATE(2607),
    [sym_preproc_error] = STATE(2607),
    [sym_preproc_warning] = STATE(2607),
    [sym_preproc_define] = STATE(2607),
    [sym_preproc_undef] = STATE(2607),
    [ts_builtin_sym_end] = ACTIONS(3683),
    [sym__identifier_token] = ACTIONS(3681),
    [anon_sym_extern] = ACTIONS(3681),
    [anon_sym_alias] = ACTIONS(3681),
    [anon_sym_SEMI] = ACTIONS(3683),
    [anon_sym_global] = ACTIONS(3681),
    [anon_sym_using] = ACTIONS(3681),
    [anon_sym_unsafe] = ACTIONS(3681),
    [anon_sym_static] = ACTIONS(3681),
    [anon_sym_LBRACK] = ACTIONS(3683),
    [anon_sym_LPAREN] = ACTIONS(3683),
    [anon_sym_return] = ACTIONS(3681),
    [anon_sym_namespace] = ACTIONS(3681),
    [anon_sym_class] = ACTIONS(3681),
    [anon_sym_ref] = ACTIONS(3681),
    [anon_sym_struct] = ACTIONS(3681),
    [anon_sym_enum] = ACTIONS(3681),
    [anon_sym_LBRACE] = ACTIONS(3683),
    [anon_sym_interface] = ACTIONS(3681),
    [anon_sym_delegate] = ACTIONS(3681),
    [anon_sym_record] = ACTIONS(3681),
    [anon_sym_abstract] = ACTIONS(3681),
    [anon_sym_async] = ACTIONS(3681),
    [anon_sym_const] = ACTIONS(3681),
    [anon_sym_file] = ACTIONS(3681),
    [anon_sym_fixed] = ACTIONS(3681),
    [anon_sym_internal] = ACTIONS(3681),
    [anon_sym_new] = ACTIONS(3681),
    [anon_sym_override] = ACTIONS(3681),
    [anon_sym_partial] = ACTIONS(3681),
    [anon_sym_private] = ACTIONS(3681),
    [anon_sym_protected] = ACTIONS(3681),
    [anon_sym_public] = ACTIONS(3681),
    [anon_sym_readonly] = ACTIONS(3681),
    [anon_sym_required] = ACTIONS(3681),
    [anon_sym_sealed] = ACTIONS(3681),
    [anon_sym_virtual] = ACTIONS(3681),
    [anon_sym_volatile] = ACTIONS(3681),
    [anon_sym_where] = ACTIONS(3681),
    [anon_sym_notnull] = ACTIONS(3681),
    [anon_sym_unmanaged] = ACTIONS(3681),
    [anon_sym_checked] = ACTIONS(3681),
    [anon_sym_BANG] = ACTIONS(3683),
    [anon_sym_TILDE] = ACTIONS(3683),
    [anon_sym_PLUS_PLUS] = ACTIONS(3683),
    [anon_sym_DASH_DASH] = ACTIONS(3683),
    [anon_sym_true] = ACTIONS(3681),
    [anon_sym_false] = ACTIONS(3681),
    [anon_sym_PLUS] = ACTIONS(3681),
    [anon_sym_DASH] = ACTIONS(3681),
    [anon_sym_STAR] = ACTIONS(3683),
    [anon_sym_CARET] = ACTIONS(3683),
    [anon_sym_AMP] = ACTIONS(3683),
    [anon_sym_this] = ACTIONS(3681),
    [anon_sym_scoped] = ACTIONS(3681),
    [anon_sym_base] = ACTIONS(3681),
    [anon_sym_var] = ACTIONS(3681),
    [sym_predefined_type] = ACTIONS(3681),
    [anon_sym_break] = ACTIONS(3681),
    [anon_sym_unchecked] = ACTIONS(3681),
    [anon_sym_continue] = ACTIONS(3681),
    [anon_sym_do] = ACTIONS(3681),
    [anon_sym_while] = ACTIONS(3681),
    [anon_sym_for] = ACTIONS(3681),
    [anon_sym_lock] = ACTIONS(3681),
    [anon_sym_yield] = ACTIONS(3681),
    [anon_sym_switch] = ACTIONS(3681),
    [anon_sym_default] = ACTIONS(3681),
    [anon_sym_throw] = ACTIONS(3681),
    [anon_sym_try] = ACTIONS(3681),
    [anon_sym_when] = ACTIONS(3681),
    [anon_sym_await] = ACTIONS(3681),
    [anon_sym_foreach] = ACTIONS(3681),
    [anon_sym_goto] = ACTIONS(3681),
    [anon_sym_if] = ACTIONS(3681),
    [anon_sym_DOT_DOT] = ACTIONS(3683),
    [anon_sym_from] = ACTIONS(3681),
    [anon_sym_into] = ACTIONS(3681),
    [anon_sym_join] = ACTIONS(3681),
    [anon_sym_on] = ACTIONS(3681),
    [anon_sym_equals] = ACTIONS(3681),
    [anon_sym_let] = ACTIONS(3681),
    [anon_sym_orderby] = ACTIONS(3681),
    [anon_sym_ascending] = ACTIONS(3681),
    [anon_sym_descending] = ACTIONS(3681),
    [anon_sym_group] = ACTIONS(3681),
    [anon_sym_by] = ACTIONS(3681),
    [anon_sym_select] = ACTIONS(3681),
    [anon_sym_stackalloc] = ACTIONS(3681),
    [anon_sym_sizeof] = ACTIONS(3681),
    [anon_sym_typeof] = ACTIONS(3681),
    [anon_sym___makeref] = ACTIONS(3681),
    [anon_sym___reftype] = ACTIONS(3681),
    [anon_sym___refvalue] = ACTIONS(3681),
    [sym_null_literal] = ACTIONS(3681),
    [anon_sym_SQUOTE] = ACTIONS(3683),
    [sym_integer_literal] = ACTIONS(3681),
    [sym_real_literal] = ACTIONS(3683),
    [anon_sym_DQUOTE] = ACTIONS(3683),
    [sym_verbatim_string_literal] = ACTIONS(3683),
    [aux_sym_preproc_if_token1] = ACTIONS(3683),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3683),
    [sym_interpolation_verbatim_start] = ACTIONS(3683),
    [sym_interpolation_raw_start] = ACTIONS(3683),
    [sym_raw_string_start] = ACTIONS(3683),
  },
  [2608] = {
    [sym_preproc_region] = STATE(2608),
    [sym_preproc_endregion] = STATE(2608),
    [sym_preproc_line] = STATE(2608),
    [sym_preproc_pragma] = STATE(2608),
    [sym_preproc_nullable] = STATE(2608),
    [sym_preproc_error] = STATE(2608),
    [sym_preproc_warning] = STATE(2608),
    [sym_preproc_define] = STATE(2608),
    [sym_preproc_undef] = STATE(2608),
    [ts_builtin_sym_end] = ACTIONS(3949),
    [sym__identifier_token] = ACTIONS(3947),
    [anon_sym_extern] = ACTIONS(3947),
    [anon_sym_alias] = ACTIONS(3947),
    [anon_sym_SEMI] = ACTIONS(3949),
    [anon_sym_global] = ACTIONS(3947),
    [anon_sym_using] = ACTIONS(3947),
    [anon_sym_unsafe] = ACTIONS(3947),
    [anon_sym_static] = ACTIONS(3947),
    [anon_sym_LBRACK] = ACTIONS(3949),
    [anon_sym_LPAREN] = ACTIONS(3949),
    [anon_sym_return] = ACTIONS(3947),
    [anon_sym_namespace] = ACTIONS(3947),
    [anon_sym_class] = ACTIONS(3947),
    [anon_sym_ref] = ACTIONS(3947),
    [anon_sym_struct] = ACTIONS(3947),
    [anon_sym_enum] = ACTIONS(3947),
    [anon_sym_LBRACE] = ACTIONS(3949),
    [anon_sym_interface] = ACTIONS(3947),
    [anon_sym_delegate] = ACTIONS(3947),
    [anon_sym_record] = ACTIONS(3947),
    [anon_sym_abstract] = ACTIONS(3947),
    [anon_sym_async] = ACTIONS(3947),
    [anon_sym_const] = ACTIONS(3947),
    [anon_sym_file] = ACTIONS(3947),
    [anon_sym_fixed] = ACTIONS(3947),
    [anon_sym_internal] = ACTIONS(3947),
    [anon_sym_new] = ACTIONS(3947),
    [anon_sym_override] = ACTIONS(3947),
    [anon_sym_partial] = ACTIONS(3947),
    [anon_sym_private] = ACTIONS(3947),
    [anon_sym_protected] = ACTIONS(3947),
    [anon_sym_public] = ACTIONS(3947),
    [anon_sym_readonly] = ACTIONS(3947),
    [anon_sym_required] = ACTIONS(3947),
    [anon_sym_sealed] = ACTIONS(3947),
    [anon_sym_virtual] = ACTIONS(3947),
    [anon_sym_volatile] = ACTIONS(3947),
    [anon_sym_where] = ACTIONS(3947),
    [anon_sym_notnull] = ACTIONS(3947),
    [anon_sym_unmanaged] = ACTIONS(3947),
    [anon_sym_checked] = ACTIONS(3947),
    [anon_sym_BANG] = ACTIONS(3949),
    [anon_sym_TILDE] = ACTIONS(3949),
    [anon_sym_PLUS_PLUS] = ACTIONS(3949),
    [anon_sym_DASH_DASH] = ACTIONS(3949),
    [anon_sym_true] = ACTIONS(3947),
    [anon_sym_false] = ACTIONS(3947),
    [anon_sym_PLUS] = ACTIONS(3947),
    [anon_sym_DASH] = ACTIONS(3947),
    [anon_sym_STAR] = ACTIONS(3949),
    [anon_sym_CARET] = ACTIONS(3949),
    [anon_sym_AMP] = ACTIONS(3949),
    [anon_sym_this] = ACTIONS(3947),
    [anon_sym_scoped] = ACTIONS(3947),
    [anon_sym_base] = ACTIONS(3947),
    [anon_sym_var] = ACTIONS(3947),
    [sym_predefined_type] = ACTIONS(3947),
    [anon_sym_break] = ACTIONS(3947),
    [anon_sym_unchecked] = ACTIONS(3947),
    [anon_sym_continue] = ACTIONS(3947),
    [anon_sym_do] = ACTIONS(3947),
    [anon_sym_while] = ACTIONS(3947),
    [anon_sym_for] = ACTIONS(3947),
    [anon_sym_lock] = ACTIONS(3947),
    [anon_sym_yield] = ACTIONS(3947),
    [anon_sym_switch] = ACTIONS(3947),
    [anon_sym_default] = ACTIONS(3947),
    [anon_sym_throw] = ACTIONS(3947),
    [anon_sym_try] = ACTIONS(3947),
    [anon_sym_when] = ACTIONS(3947),
    [anon_sym_await] = ACTIONS(3947),
    [anon_sym_foreach] = ACTIONS(3947),
    [anon_sym_goto] = ACTIONS(3947),
    [anon_sym_if] = ACTIONS(3947),
    [anon_sym_DOT_DOT] = ACTIONS(3949),
    [anon_sym_from] = ACTIONS(3947),
    [anon_sym_into] = ACTIONS(3947),
    [anon_sym_join] = ACTIONS(3947),
    [anon_sym_on] = ACTIONS(3947),
    [anon_sym_equals] = ACTIONS(3947),
    [anon_sym_let] = ACTIONS(3947),
    [anon_sym_orderby] = ACTIONS(3947),
    [anon_sym_ascending] = ACTIONS(3947),
    [anon_sym_descending] = ACTIONS(3947),
    [anon_sym_group] = ACTIONS(3947),
    [anon_sym_by] = ACTIONS(3947),
    [anon_sym_select] = ACTIONS(3947),
    [anon_sym_stackalloc] = ACTIONS(3947),
    [anon_sym_sizeof] = ACTIONS(3947),
    [anon_sym_typeof] = ACTIONS(3947),
    [anon_sym___makeref] = ACTIONS(3947),
    [anon_sym___reftype] = ACTIONS(3947),
    [anon_sym___refvalue] = ACTIONS(3947),
    [sym_null_literal] = ACTIONS(3947),
    [anon_sym_SQUOTE] = ACTIONS(3949),
    [sym_integer_literal] = ACTIONS(3947),
    [sym_real_literal] = ACTIONS(3949),
    [anon_sym_DQUOTE] = ACTIONS(3949),
    [sym_verbatim_string_literal] = ACTIONS(3949),
    [aux_sym_preproc_if_token1] = ACTIONS(3949),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3949),
    [sym_interpolation_verbatim_start] = ACTIONS(3949),
    [sym_interpolation_raw_start] = ACTIONS(3949),
    [sym_raw_string_start] = ACTIONS(3949),
  },
  [2609] = {
    [sym_preproc_region] = STATE(2609),
    [sym_preproc_endregion] = STATE(2609),
    [sym_preproc_line] = STATE(2609),
    [sym_preproc_pragma] = STATE(2609),
    [sym_preproc_nullable] = STATE(2609),
    [sym_preproc_error] = STATE(2609),
    [sym_preproc_warning] = STATE(2609),
    [sym_preproc_define] = STATE(2609),
    [sym_preproc_undef] = STATE(2609),
    [ts_builtin_sym_end] = ACTIONS(3961),
    [sym__identifier_token] = ACTIONS(3959),
    [anon_sym_extern] = ACTIONS(3959),
    [anon_sym_alias] = ACTIONS(3959),
    [anon_sym_SEMI] = ACTIONS(3961),
    [anon_sym_global] = ACTIONS(3959),
    [anon_sym_using] = ACTIONS(3959),
    [anon_sym_unsafe] = ACTIONS(3959),
    [anon_sym_static] = ACTIONS(3959),
    [anon_sym_LBRACK] = ACTIONS(3961),
    [anon_sym_LPAREN] = ACTIONS(3961),
    [anon_sym_return] = ACTIONS(3959),
    [anon_sym_namespace] = ACTIONS(3959),
    [anon_sym_class] = ACTIONS(3959),
    [anon_sym_ref] = ACTIONS(3959),
    [anon_sym_struct] = ACTIONS(3959),
    [anon_sym_enum] = ACTIONS(3959),
    [anon_sym_LBRACE] = ACTIONS(3961),
    [anon_sym_interface] = ACTIONS(3959),
    [anon_sym_delegate] = ACTIONS(3959),
    [anon_sym_record] = ACTIONS(3959),
    [anon_sym_abstract] = ACTIONS(3959),
    [anon_sym_async] = ACTIONS(3959),
    [anon_sym_const] = ACTIONS(3959),
    [anon_sym_file] = ACTIONS(3959),
    [anon_sym_fixed] = ACTIONS(3959),
    [anon_sym_internal] = ACTIONS(3959),
    [anon_sym_new] = ACTIONS(3959),
    [anon_sym_override] = ACTIONS(3959),
    [anon_sym_partial] = ACTIONS(3959),
    [anon_sym_private] = ACTIONS(3959),
    [anon_sym_protected] = ACTIONS(3959),
    [anon_sym_public] = ACTIONS(3959),
    [anon_sym_readonly] = ACTIONS(3959),
    [anon_sym_required] = ACTIONS(3959),
    [anon_sym_sealed] = ACTIONS(3959),
    [anon_sym_virtual] = ACTIONS(3959),
    [anon_sym_volatile] = ACTIONS(3959),
    [anon_sym_where] = ACTIONS(3959),
    [anon_sym_notnull] = ACTIONS(3959),
    [anon_sym_unmanaged] = ACTIONS(3959),
    [anon_sym_checked] = ACTIONS(3959),
    [anon_sym_BANG] = ACTIONS(3961),
    [anon_sym_TILDE] = ACTIONS(3961),
    [anon_sym_PLUS_PLUS] = ACTIONS(3961),
    [anon_sym_DASH_DASH] = ACTIONS(3961),
    [anon_sym_true] = ACTIONS(3959),
    [anon_sym_false] = ACTIONS(3959),
    [anon_sym_PLUS] = ACTIONS(3959),
    [anon_sym_DASH] = ACTIONS(3959),
    [anon_sym_STAR] = ACTIONS(3961),
    [anon_sym_CARET] = ACTIONS(3961),
    [anon_sym_AMP] = ACTIONS(3961),
    [anon_sym_this] = ACTIONS(3959),
    [anon_sym_scoped] = ACTIONS(3959),
    [anon_sym_base] = ACTIONS(3959),
    [anon_sym_var] = ACTIONS(3959),
    [sym_predefined_type] = ACTIONS(3959),
    [anon_sym_break] = ACTIONS(3959),
    [anon_sym_unchecked] = ACTIONS(3959),
    [anon_sym_continue] = ACTIONS(3959),
    [anon_sym_do] = ACTIONS(3959),
    [anon_sym_while] = ACTIONS(3959),
    [anon_sym_for] = ACTIONS(3959),
    [anon_sym_lock] = ACTIONS(3959),
    [anon_sym_yield] = ACTIONS(3959),
    [anon_sym_switch] = ACTIONS(3959),
    [anon_sym_default] = ACTIONS(3959),
    [anon_sym_throw] = ACTIONS(3959),
    [anon_sym_try] = ACTIONS(3959),
    [anon_sym_when] = ACTIONS(3959),
    [anon_sym_await] = ACTIONS(3959),
    [anon_sym_foreach] = ACTIONS(3959),
    [anon_sym_goto] = ACTIONS(3959),
    [anon_sym_if] = ACTIONS(3959),
    [anon_sym_DOT_DOT] = ACTIONS(3961),
    [anon_sym_from] = ACTIONS(3959),
    [anon_sym_into] = ACTIONS(3959),
    [anon_sym_join] = ACTIONS(3959),
    [anon_sym_on] = ACTIONS(3959),
    [anon_sym_equals] = ACTIONS(3959),
    [anon_sym_let] = ACTIONS(3959),
    [anon_sym_orderby] = ACTIONS(3959),
    [anon_sym_ascending] = ACTIONS(3959),
    [anon_sym_descending] = ACTIONS(3959),
    [anon_sym_group] = ACTIONS(3959),
    [anon_sym_by] = ACTIONS(3959),
    [anon_sym_select] = ACTIONS(3959),
    [anon_sym_stackalloc] = ACTIONS(3959),
    [anon_sym_sizeof] = ACTIONS(3959),
    [anon_sym_typeof] = ACTIONS(3959),
    [anon_sym___makeref] = ACTIONS(3959),
    [anon_sym___reftype] = ACTIONS(3959),
    [anon_sym___refvalue] = ACTIONS(3959),
    [sym_null_literal] = ACTIONS(3959),
    [anon_sym_SQUOTE] = ACTIONS(3961),
    [sym_integer_literal] = ACTIONS(3959),
    [sym_real_literal] = ACTIONS(3961),
    [anon_sym_DQUOTE] = ACTIONS(3961),
    [sym_verbatim_string_literal] = ACTIONS(3961),
    [aux_sym_preproc_if_token1] = ACTIONS(3961),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3961),
    [sym_interpolation_verbatim_start] = ACTIONS(3961),
    [sym_interpolation_raw_start] = ACTIONS(3961),
    [sym_raw_string_start] = ACTIONS(3961),
  },
  [2610] = {
    [sym_preproc_region] = STATE(2610),
    [sym_preproc_endregion] = STATE(2610),
    [sym_preproc_line] = STATE(2610),
    [sym_preproc_pragma] = STATE(2610),
    [sym_preproc_nullable] = STATE(2610),
    [sym_preproc_error] = STATE(2610),
    [sym_preproc_warning] = STATE(2610),
    [sym_preproc_define] = STATE(2610),
    [sym_preproc_undef] = STATE(2610),
    [ts_builtin_sym_end] = ACTIONS(3427),
    [sym__identifier_token] = ACTIONS(3425),
    [anon_sym_extern] = ACTIONS(3425),
    [anon_sym_alias] = ACTIONS(3425),
    [anon_sym_SEMI] = ACTIONS(3427),
    [anon_sym_global] = ACTIONS(3425),
    [anon_sym_using] = ACTIONS(3425),
    [anon_sym_unsafe] = ACTIONS(3425),
    [anon_sym_static] = ACTIONS(3425),
    [anon_sym_LBRACK] = ACTIONS(3427),
    [anon_sym_LPAREN] = ACTIONS(3427),
    [anon_sym_return] = ACTIONS(3425),
    [anon_sym_namespace] = ACTIONS(3425),
    [anon_sym_class] = ACTIONS(3425),
    [anon_sym_ref] = ACTIONS(3425),
    [anon_sym_struct] = ACTIONS(3425),
    [anon_sym_enum] = ACTIONS(3425),
    [anon_sym_LBRACE] = ACTIONS(3427),
    [anon_sym_interface] = ACTIONS(3425),
    [anon_sym_delegate] = ACTIONS(3425),
    [anon_sym_record] = ACTIONS(3425),
    [anon_sym_abstract] = ACTIONS(3425),
    [anon_sym_async] = ACTIONS(3425),
    [anon_sym_const] = ACTIONS(3425),
    [anon_sym_file] = ACTIONS(3425),
    [anon_sym_fixed] = ACTIONS(3425),
    [anon_sym_internal] = ACTIONS(3425),
    [anon_sym_new] = ACTIONS(3425),
    [anon_sym_override] = ACTIONS(3425),
    [anon_sym_partial] = ACTIONS(3425),
    [anon_sym_private] = ACTIONS(3425),
    [anon_sym_protected] = ACTIONS(3425),
    [anon_sym_public] = ACTIONS(3425),
    [anon_sym_readonly] = ACTIONS(3425),
    [anon_sym_required] = ACTIONS(3425),
    [anon_sym_sealed] = ACTIONS(3425),
    [anon_sym_virtual] = ACTIONS(3425),
    [anon_sym_volatile] = ACTIONS(3425),
    [anon_sym_where] = ACTIONS(3425),
    [anon_sym_notnull] = ACTIONS(3425),
    [anon_sym_unmanaged] = ACTIONS(3425),
    [anon_sym_checked] = ACTIONS(3425),
    [anon_sym_BANG] = ACTIONS(3427),
    [anon_sym_TILDE] = ACTIONS(3427),
    [anon_sym_PLUS_PLUS] = ACTIONS(3427),
    [anon_sym_DASH_DASH] = ACTIONS(3427),
    [anon_sym_true] = ACTIONS(3425),
    [anon_sym_false] = ACTIONS(3425),
    [anon_sym_PLUS] = ACTIONS(3425),
    [anon_sym_DASH] = ACTIONS(3425),
    [anon_sym_STAR] = ACTIONS(3427),
    [anon_sym_CARET] = ACTIONS(3427),
    [anon_sym_AMP] = ACTIONS(3427),
    [anon_sym_this] = ACTIONS(3425),
    [anon_sym_scoped] = ACTIONS(3425),
    [anon_sym_base] = ACTIONS(3425),
    [anon_sym_var] = ACTIONS(3425),
    [sym_predefined_type] = ACTIONS(3425),
    [anon_sym_break] = ACTIONS(3425),
    [anon_sym_unchecked] = ACTIONS(3425),
    [anon_sym_continue] = ACTIONS(3425),
    [anon_sym_do] = ACTIONS(3425),
    [anon_sym_while] = ACTIONS(3425),
    [anon_sym_for] = ACTIONS(3425),
    [anon_sym_lock] = ACTIONS(3425),
    [anon_sym_yield] = ACTIONS(3425),
    [anon_sym_switch] = ACTIONS(3425),
    [anon_sym_default] = ACTIONS(3425),
    [anon_sym_throw] = ACTIONS(3425),
    [anon_sym_try] = ACTIONS(3425),
    [anon_sym_when] = ACTIONS(3425),
    [anon_sym_await] = ACTIONS(3425),
    [anon_sym_foreach] = ACTIONS(3425),
    [anon_sym_goto] = ACTIONS(3425),
    [anon_sym_if] = ACTIONS(3425),
    [anon_sym_DOT_DOT] = ACTIONS(3427),
    [anon_sym_from] = ACTIONS(3425),
    [anon_sym_into] = ACTIONS(3425),
    [anon_sym_join] = ACTIONS(3425),
    [anon_sym_on] = ACTIONS(3425),
    [anon_sym_equals] = ACTIONS(3425),
    [anon_sym_let] = ACTIONS(3425),
    [anon_sym_orderby] = ACTIONS(3425),
    [anon_sym_ascending] = ACTIONS(3425),
    [anon_sym_descending] = ACTIONS(3425),
    [anon_sym_group] = ACTIONS(3425),
    [anon_sym_by] = ACTIONS(3425),
    [anon_sym_select] = ACTIONS(3425),
    [anon_sym_stackalloc] = ACTIONS(3425),
    [anon_sym_sizeof] = ACTIONS(3425),
    [anon_sym_typeof] = ACTIONS(3425),
    [anon_sym___makeref] = ACTIONS(3425),
    [anon_sym___reftype] = ACTIONS(3425),
    [anon_sym___refvalue] = ACTIONS(3425),
    [sym_null_literal] = ACTIONS(3425),
    [anon_sym_SQUOTE] = ACTIONS(3427),
    [sym_integer_literal] = ACTIONS(3425),
    [sym_real_literal] = ACTIONS(3427),
    [anon_sym_DQUOTE] = ACTIONS(3427),
    [sym_verbatim_string_literal] = ACTIONS(3427),
    [aux_sym_preproc_if_token1] = ACTIONS(3427),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3427),
    [sym_interpolation_verbatim_start] = ACTIONS(3427),
    [sym_interpolation_raw_start] = ACTIONS(3427),
    [sym_raw_string_start] = ACTIONS(3427),
  },
  [2611] = {
    [sym_preproc_region] = STATE(2611),
    [sym_preproc_endregion] = STATE(2611),
    [sym_preproc_line] = STATE(2611),
    [sym_preproc_pragma] = STATE(2611),
    [sym_preproc_nullable] = STATE(2611),
    [sym_preproc_error] = STATE(2611),
    [sym_preproc_warning] = STATE(2611),
    [sym_preproc_define] = STATE(2611),
    [sym_preproc_undef] = STATE(2611),
    [ts_builtin_sym_end] = ACTIONS(3431),
    [sym__identifier_token] = ACTIONS(3429),
    [anon_sym_extern] = ACTIONS(3429),
    [anon_sym_alias] = ACTIONS(3429),
    [anon_sym_SEMI] = ACTIONS(3431),
    [anon_sym_global] = ACTIONS(3429),
    [anon_sym_using] = ACTIONS(3429),
    [anon_sym_unsafe] = ACTIONS(3429),
    [anon_sym_static] = ACTIONS(3429),
    [anon_sym_LBRACK] = ACTIONS(3431),
    [anon_sym_LPAREN] = ACTIONS(3431),
    [anon_sym_return] = ACTIONS(3429),
    [anon_sym_namespace] = ACTIONS(3429),
    [anon_sym_class] = ACTIONS(3429),
    [anon_sym_ref] = ACTIONS(3429),
    [anon_sym_struct] = ACTIONS(3429),
    [anon_sym_enum] = ACTIONS(3429),
    [anon_sym_LBRACE] = ACTIONS(3431),
    [anon_sym_interface] = ACTIONS(3429),
    [anon_sym_delegate] = ACTIONS(3429),
    [anon_sym_record] = ACTIONS(3429),
    [anon_sym_abstract] = ACTIONS(3429),
    [anon_sym_async] = ACTIONS(3429),
    [anon_sym_const] = ACTIONS(3429),
    [anon_sym_file] = ACTIONS(3429),
    [anon_sym_fixed] = ACTIONS(3429),
    [anon_sym_internal] = ACTIONS(3429),
    [anon_sym_new] = ACTIONS(3429),
    [anon_sym_override] = ACTIONS(3429),
    [anon_sym_partial] = ACTIONS(3429),
    [anon_sym_private] = ACTIONS(3429),
    [anon_sym_protected] = ACTIONS(3429),
    [anon_sym_public] = ACTIONS(3429),
    [anon_sym_readonly] = ACTIONS(3429),
    [anon_sym_required] = ACTIONS(3429),
    [anon_sym_sealed] = ACTIONS(3429),
    [anon_sym_virtual] = ACTIONS(3429),
    [anon_sym_volatile] = ACTIONS(3429),
    [anon_sym_where] = ACTIONS(3429),
    [anon_sym_notnull] = ACTIONS(3429),
    [anon_sym_unmanaged] = ACTIONS(3429),
    [anon_sym_checked] = ACTIONS(3429),
    [anon_sym_BANG] = ACTIONS(3431),
    [anon_sym_TILDE] = ACTIONS(3431),
    [anon_sym_PLUS_PLUS] = ACTIONS(3431),
    [anon_sym_DASH_DASH] = ACTIONS(3431),
    [anon_sym_true] = ACTIONS(3429),
    [anon_sym_false] = ACTIONS(3429),
    [anon_sym_PLUS] = ACTIONS(3429),
    [anon_sym_DASH] = ACTIONS(3429),
    [anon_sym_STAR] = ACTIONS(3431),
    [anon_sym_CARET] = ACTIONS(3431),
    [anon_sym_AMP] = ACTIONS(3431),
    [anon_sym_this] = ACTIONS(3429),
    [anon_sym_scoped] = ACTIONS(3429),
    [anon_sym_base] = ACTIONS(3429),
    [anon_sym_var] = ACTIONS(3429),
    [sym_predefined_type] = ACTIONS(3429),
    [anon_sym_break] = ACTIONS(3429),
    [anon_sym_unchecked] = ACTIONS(3429),
    [anon_sym_continue] = ACTIONS(3429),
    [anon_sym_do] = ACTIONS(3429),
    [anon_sym_while] = ACTIONS(3429),
    [anon_sym_for] = ACTIONS(3429),
    [anon_sym_lock] = ACTIONS(3429),
    [anon_sym_yield] = ACTIONS(3429),
    [anon_sym_switch] = ACTIONS(3429),
    [anon_sym_default] = ACTIONS(3429),
    [anon_sym_throw] = ACTIONS(3429),
    [anon_sym_try] = ACTIONS(3429),
    [anon_sym_when] = ACTIONS(3429),
    [anon_sym_await] = ACTIONS(3429),
    [anon_sym_foreach] = ACTIONS(3429),
    [anon_sym_goto] = ACTIONS(3429),
    [anon_sym_if] = ACTIONS(3429),
    [anon_sym_DOT_DOT] = ACTIONS(3431),
    [anon_sym_from] = ACTIONS(3429),
    [anon_sym_into] = ACTIONS(3429),
    [anon_sym_join] = ACTIONS(3429),
    [anon_sym_on] = ACTIONS(3429),
    [anon_sym_equals] = ACTIONS(3429),
    [anon_sym_let] = ACTIONS(3429),
    [anon_sym_orderby] = ACTIONS(3429),
    [anon_sym_ascending] = ACTIONS(3429),
    [anon_sym_descending] = ACTIONS(3429),
    [anon_sym_group] = ACTIONS(3429),
    [anon_sym_by] = ACTIONS(3429),
    [anon_sym_select] = ACTIONS(3429),
    [anon_sym_stackalloc] = ACTIONS(3429),
    [anon_sym_sizeof] = ACTIONS(3429),
    [anon_sym_typeof] = ACTIONS(3429),
    [anon_sym___makeref] = ACTIONS(3429),
    [anon_sym___reftype] = ACTIONS(3429),
    [anon_sym___refvalue] = ACTIONS(3429),
    [sym_null_literal] = ACTIONS(3429),
    [anon_sym_SQUOTE] = ACTIONS(3431),
    [sym_integer_literal] = ACTIONS(3429),
    [sym_real_literal] = ACTIONS(3431),
    [anon_sym_DQUOTE] = ACTIONS(3431),
    [sym_verbatim_string_literal] = ACTIONS(3431),
    [aux_sym_preproc_if_token1] = ACTIONS(3431),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3431),
    [sym_interpolation_verbatim_start] = ACTIONS(3431),
    [sym_interpolation_raw_start] = ACTIONS(3431),
    [sym_raw_string_start] = ACTIONS(3431),
  },
  [2612] = {
    [sym_preproc_region] = STATE(2612),
    [sym_preproc_endregion] = STATE(2612),
    [sym_preproc_line] = STATE(2612),
    [sym_preproc_pragma] = STATE(2612),
    [sym_preproc_nullable] = STATE(2612),
    [sym_preproc_error] = STATE(2612),
    [sym_preproc_warning] = STATE(2612),
    [sym_preproc_define] = STATE(2612),
    [sym_preproc_undef] = STATE(2612),
    [ts_builtin_sym_end] = ACTIONS(3435),
    [sym__identifier_token] = ACTIONS(3433),
    [anon_sym_extern] = ACTIONS(3433),
    [anon_sym_alias] = ACTIONS(3433),
    [anon_sym_SEMI] = ACTIONS(3435),
    [anon_sym_global] = ACTIONS(3433),
    [anon_sym_using] = ACTIONS(3433),
    [anon_sym_unsafe] = ACTIONS(3433),
    [anon_sym_static] = ACTIONS(3433),
    [anon_sym_LBRACK] = ACTIONS(3435),
    [anon_sym_LPAREN] = ACTIONS(3435),
    [anon_sym_return] = ACTIONS(3433),
    [anon_sym_namespace] = ACTIONS(3433),
    [anon_sym_class] = ACTIONS(3433),
    [anon_sym_ref] = ACTIONS(3433),
    [anon_sym_struct] = ACTIONS(3433),
    [anon_sym_enum] = ACTIONS(3433),
    [anon_sym_LBRACE] = ACTIONS(3435),
    [anon_sym_interface] = ACTIONS(3433),
    [anon_sym_delegate] = ACTIONS(3433),
    [anon_sym_record] = ACTIONS(3433),
    [anon_sym_abstract] = ACTIONS(3433),
    [anon_sym_async] = ACTIONS(3433),
    [anon_sym_const] = ACTIONS(3433),
    [anon_sym_file] = ACTIONS(3433),
    [anon_sym_fixed] = ACTIONS(3433),
    [anon_sym_internal] = ACTIONS(3433),
    [anon_sym_new] = ACTIONS(3433),
    [anon_sym_override] = ACTIONS(3433),
    [anon_sym_partial] = ACTIONS(3433),
    [anon_sym_private] = ACTIONS(3433),
    [anon_sym_protected] = ACTIONS(3433),
    [anon_sym_public] = ACTIONS(3433),
    [anon_sym_readonly] = ACTIONS(3433),
    [anon_sym_required] = ACTIONS(3433),
    [anon_sym_sealed] = ACTIONS(3433),
    [anon_sym_virtual] = ACTIONS(3433),
    [anon_sym_volatile] = ACTIONS(3433),
    [anon_sym_where] = ACTIONS(3433),
    [anon_sym_notnull] = ACTIONS(3433),
    [anon_sym_unmanaged] = ACTIONS(3433),
    [anon_sym_checked] = ACTIONS(3433),
    [anon_sym_BANG] = ACTIONS(3435),
    [anon_sym_TILDE] = ACTIONS(3435),
    [anon_sym_PLUS_PLUS] = ACTIONS(3435),
    [anon_sym_DASH_DASH] = ACTIONS(3435),
    [anon_sym_true] = ACTIONS(3433),
    [anon_sym_false] = ACTIONS(3433),
    [anon_sym_PLUS] = ACTIONS(3433),
    [anon_sym_DASH] = ACTIONS(3433),
    [anon_sym_STAR] = ACTIONS(3435),
    [anon_sym_CARET] = ACTIONS(3435),
    [anon_sym_AMP] = ACTIONS(3435),
    [anon_sym_this] = ACTIONS(3433),
    [anon_sym_scoped] = ACTIONS(3433),
    [anon_sym_base] = ACTIONS(3433),
    [anon_sym_var] = ACTIONS(3433),
    [sym_predefined_type] = ACTIONS(3433),
    [anon_sym_break] = ACTIONS(3433),
    [anon_sym_unchecked] = ACTIONS(3433),
    [anon_sym_continue] = ACTIONS(3433),
    [anon_sym_do] = ACTIONS(3433),
    [anon_sym_while] = ACTIONS(3433),
    [anon_sym_for] = ACTIONS(3433),
    [anon_sym_lock] = ACTIONS(3433),
    [anon_sym_yield] = ACTIONS(3433),
    [anon_sym_switch] = ACTIONS(3433),
    [anon_sym_default] = ACTIONS(3433),
    [anon_sym_throw] = ACTIONS(3433),
    [anon_sym_try] = ACTIONS(3433),
    [anon_sym_when] = ACTIONS(3433),
    [anon_sym_await] = ACTIONS(3433),
    [anon_sym_foreach] = ACTIONS(3433),
    [anon_sym_goto] = ACTIONS(3433),
    [anon_sym_if] = ACTIONS(3433),
    [anon_sym_DOT_DOT] = ACTIONS(3435),
    [anon_sym_from] = ACTIONS(3433),
    [anon_sym_into] = ACTIONS(3433),
    [anon_sym_join] = ACTIONS(3433),
    [anon_sym_on] = ACTIONS(3433),
    [anon_sym_equals] = ACTIONS(3433),
    [anon_sym_let] = ACTIONS(3433),
    [anon_sym_orderby] = ACTIONS(3433),
    [anon_sym_ascending] = ACTIONS(3433),
    [anon_sym_descending] = ACTIONS(3433),
    [anon_sym_group] = ACTIONS(3433),
    [anon_sym_by] = ACTIONS(3433),
    [anon_sym_select] = ACTIONS(3433),
    [anon_sym_stackalloc] = ACTIONS(3433),
    [anon_sym_sizeof] = ACTIONS(3433),
    [anon_sym_typeof] = ACTIONS(3433),
    [anon_sym___makeref] = ACTIONS(3433),
    [anon_sym___reftype] = ACTIONS(3433),
    [anon_sym___refvalue] = ACTIONS(3433),
    [sym_null_literal] = ACTIONS(3433),
    [anon_sym_SQUOTE] = ACTIONS(3435),
    [sym_integer_literal] = ACTIONS(3433),
    [sym_real_literal] = ACTIONS(3435),
    [anon_sym_DQUOTE] = ACTIONS(3435),
    [sym_verbatim_string_literal] = ACTIONS(3435),
    [aux_sym_preproc_if_token1] = ACTIONS(3435),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3435),
    [sym_interpolation_verbatim_start] = ACTIONS(3435),
    [sym_interpolation_raw_start] = ACTIONS(3435),
    [sym_raw_string_start] = ACTIONS(3435),
  },
  [2613] = {
    [sym_preproc_region] = STATE(2613),
    [sym_preproc_endregion] = STATE(2613),
    [sym_preproc_line] = STATE(2613),
    [sym_preproc_pragma] = STATE(2613),
    [sym_preproc_nullable] = STATE(2613),
    [sym_preproc_error] = STATE(2613),
    [sym_preproc_warning] = STATE(2613),
    [sym_preproc_define] = STATE(2613),
    [sym_preproc_undef] = STATE(2613),
    [ts_builtin_sym_end] = ACTIONS(3439),
    [sym__identifier_token] = ACTIONS(3437),
    [anon_sym_extern] = ACTIONS(3437),
    [anon_sym_alias] = ACTIONS(3437),
    [anon_sym_SEMI] = ACTIONS(3439),
    [anon_sym_global] = ACTIONS(3437),
    [anon_sym_using] = ACTIONS(3437),
    [anon_sym_unsafe] = ACTIONS(3437),
    [anon_sym_static] = ACTIONS(3437),
    [anon_sym_LBRACK] = ACTIONS(3439),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_return] = ACTIONS(3437),
    [anon_sym_namespace] = ACTIONS(3437),
    [anon_sym_class] = ACTIONS(3437),
    [anon_sym_ref] = ACTIONS(3437),
    [anon_sym_struct] = ACTIONS(3437),
    [anon_sym_enum] = ACTIONS(3437),
    [anon_sym_LBRACE] = ACTIONS(3439),
    [anon_sym_interface] = ACTIONS(3437),
    [anon_sym_delegate] = ACTIONS(3437),
    [anon_sym_record] = ACTIONS(3437),
    [anon_sym_abstract] = ACTIONS(3437),
    [anon_sym_async] = ACTIONS(3437),
    [anon_sym_const] = ACTIONS(3437),
    [anon_sym_file] = ACTIONS(3437),
    [anon_sym_fixed] = ACTIONS(3437),
    [anon_sym_internal] = ACTIONS(3437),
    [anon_sym_new] = ACTIONS(3437),
    [anon_sym_override] = ACTIONS(3437),
    [anon_sym_partial] = ACTIONS(3437),
    [anon_sym_private] = ACTIONS(3437),
    [anon_sym_protected] = ACTIONS(3437),
    [anon_sym_public] = ACTIONS(3437),
    [anon_sym_readonly] = ACTIONS(3437),
    [anon_sym_required] = ACTIONS(3437),
    [anon_sym_sealed] = ACTIONS(3437),
    [anon_sym_virtual] = ACTIONS(3437),
    [anon_sym_volatile] = ACTIONS(3437),
    [anon_sym_where] = ACTIONS(3437),
    [anon_sym_notnull] = ACTIONS(3437),
    [anon_sym_unmanaged] = ACTIONS(3437),
    [anon_sym_checked] = ACTIONS(3437),
    [anon_sym_BANG] = ACTIONS(3439),
    [anon_sym_TILDE] = ACTIONS(3439),
    [anon_sym_PLUS_PLUS] = ACTIONS(3439),
    [anon_sym_DASH_DASH] = ACTIONS(3439),
    [anon_sym_true] = ACTIONS(3437),
    [anon_sym_false] = ACTIONS(3437),
    [anon_sym_PLUS] = ACTIONS(3437),
    [anon_sym_DASH] = ACTIONS(3437),
    [anon_sym_STAR] = ACTIONS(3439),
    [anon_sym_CARET] = ACTIONS(3439),
    [anon_sym_AMP] = ACTIONS(3439),
    [anon_sym_this] = ACTIONS(3437),
    [anon_sym_scoped] = ACTIONS(3437),
    [anon_sym_base] = ACTIONS(3437),
    [anon_sym_var] = ACTIONS(3437),
    [sym_predefined_type] = ACTIONS(3437),
    [anon_sym_break] = ACTIONS(3437),
    [anon_sym_unchecked] = ACTIONS(3437),
    [anon_sym_continue] = ACTIONS(3437),
    [anon_sym_do] = ACTIONS(3437),
    [anon_sym_while] = ACTIONS(3437),
    [anon_sym_for] = ACTIONS(3437),
    [anon_sym_lock] = ACTIONS(3437),
    [anon_sym_yield] = ACTIONS(3437),
    [anon_sym_switch] = ACTIONS(3437),
    [anon_sym_default] = ACTIONS(3437),
    [anon_sym_throw] = ACTIONS(3437),
    [anon_sym_try] = ACTIONS(3437),
    [anon_sym_when] = ACTIONS(3437),
    [anon_sym_await] = ACTIONS(3437),
    [anon_sym_foreach] = ACTIONS(3437),
    [anon_sym_goto] = ACTIONS(3437),
    [anon_sym_if] = ACTIONS(3437),
    [anon_sym_DOT_DOT] = ACTIONS(3439),
    [anon_sym_from] = ACTIONS(3437),
    [anon_sym_into] = ACTIONS(3437),
    [anon_sym_join] = ACTIONS(3437),
    [anon_sym_on] = ACTIONS(3437),
    [anon_sym_equals] = ACTIONS(3437),
    [anon_sym_let] = ACTIONS(3437),
    [anon_sym_orderby] = ACTIONS(3437),
    [anon_sym_ascending] = ACTIONS(3437),
    [anon_sym_descending] = ACTIONS(3437),
    [anon_sym_group] = ACTIONS(3437),
    [anon_sym_by] = ACTIONS(3437),
    [anon_sym_select] = ACTIONS(3437),
    [anon_sym_stackalloc] = ACTIONS(3437),
    [anon_sym_sizeof] = ACTIONS(3437),
    [anon_sym_typeof] = ACTIONS(3437),
    [anon_sym___makeref] = ACTIONS(3437),
    [anon_sym___reftype] = ACTIONS(3437),
    [anon_sym___refvalue] = ACTIONS(3437),
    [sym_null_literal] = ACTIONS(3437),
    [anon_sym_SQUOTE] = ACTIONS(3439),
    [sym_integer_literal] = ACTIONS(3437),
    [sym_real_literal] = ACTIONS(3439),
    [anon_sym_DQUOTE] = ACTIONS(3439),
    [sym_verbatim_string_literal] = ACTIONS(3439),
    [aux_sym_preproc_if_token1] = ACTIONS(3439),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3439),
    [sym_interpolation_verbatim_start] = ACTIONS(3439),
    [sym_interpolation_raw_start] = ACTIONS(3439),
    [sym_raw_string_start] = ACTIONS(3439),
  },
  [2614] = {
    [sym_preproc_region] = STATE(2614),
    [sym_preproc_endregion] = STATE(2614),
    [sym_preproc_line] = STATE(2614),
    [sym_preproc_pragma] = STATE(2614),
    [sym_preproc_nullable] = STATE(2614),
    [sym_preproc_error] = STATE(2614),
    [sym_preproc_warning] = STATE(2614),
    [sym_preproc_define] = STATE(2614),
    [sym_preproc_undef] = STATE(2614),
    [ts_builtin_sym_end] = ACTIONS(3443),
    [sym__identifier_token] = ACTIONS(3441),
    [anon_sym_extern] = ACTIONS(3441),
    [anon_sym_alias] = ACTIONS(3441),
    [anon_sym_SEMI] = ACTIONS(3443),
    [anon_sym_global] = ACTIONS(3441),
    [anon_sym_using] = ACTIONS(3441),
    [anon_sym_unsafe] = ACTIONS(3441),
    [anon_sym_static] = ACTIONS(3441),
    [anon_sym_LBRACK] = ACTIONS(3443),
    [anon_sym_LPAREN] = ACTIONS(3443),
    [anon_sym_return] = ACTIONS(3441),
    [anon_sym_namespace] = ACTIONS(3441),
    [anon_sym_class] = ACTIONS(3441),
    [anon_sym_ref] = ACTIONS(3441),
    [anon_sym_struct] = ACTIONS(3441),
    [anon_sym_enum] = ACTIONS(3441),
    [anon_sym_LBRACE] = ACTIONS(3443),
    [anon_sym_interface] = ACTIONS(3441),
    [anon_sym_delegate] = ACTIONS(3441),
    [anon_sym_record] = ACTIONS(3441),
    [anon_sym_abstract] = ACTIONS(3441),
    [anon_sym_async] = ACTIONS(3441),
    [anon_sym_const] = ACTIONS(3441),
    [anon_sym_file] = ACTIONS(3441),
    [anon_sym_fixed] = ACTIONS(3441),
    [anon_sym_internal] = ACTIONS(3441),
    [anon_sym_new] = ACTIONS(3441),
    [anon_sym_override] = ACTIONS(3441),
    [anon_sym_partial] = ACTIONS(3441),
    [anon_sym_private] = ACTIONS(3441),
    [anon_sym_protected] = ACTIONS(3441),
    [anon_sym_public] = ACTIONS(3441),
    [anon_sym_readonly] = ACTIONS(3441),
    [anon_sym_required] = ACTIONS(3441),
    [anon_sym_sealed] = ACTIONS(3441),
    [anon_sym_virtual] = ACTIONS(3441),
    [anon_sym_volatile] = ACTIONS(3441),
    [anon_sym_where] = ACTIONS(3441),
    [anon_sym_notnull] = ACTIONS(3441),
    [anon_sym_unmanaged] = ACTIONS(3441),
    [anon_sym_checked] = ACTIONS(3441),
    [anon_sym_BANG] = ACTIONS(3443),
    [anon_sym_TILDE] = ACTIONS(3443),
    [anon_sym_PLUS_PLUS] = ACTIONS(3443),
    [anon_sym_DASH_DASH] = ACTIONS(3443),
    [anon_sym_true] = ACTIONS(3441),
    [anon_sym_false] = ACTIONS(3441),
    [anon_sym_PLUS] = ACTIONS(3441),
    [anon_sym_DASH] = ACTIONS(3441),
    [anon_sym_STAR] = ACTIONS(3443),
    [anon_sym_CARET] = ACTIONS(3443),
    [anon_sym_AMP] = ACTIONS(3443),
    [anon_sym_this] = ACTIONS(3441),
    [anon_sym_scoped] = ACTIONS(3441),
    [anon_sym_base] = ACTIONS(3441),
    [anon_sym_var] = ACTIONS(3441),
    [sym_predefined_type] = ACTIONS(3441),
    [anon_sym_break] = ACTIONS(3441),
    [anon_sym_unchecked] = ACTIONS(3441),
    [anon_sym_continue] = ACTIONS(3441),
    [anon_sym_do] = ACTIONS(3441),
    [anon_sym_while] = ACTIONS(3441),
    [anon_sym_for] = ACTIONS(3441),
    [anon_sym_lock] = ACTIONS(3441),
    [anon_sym_yield] = ACTIONS(3441),
    [anon_sym_switch] = ACTIONS(3441),
    [anon_sym_default] = ACTIONS(3441),
    [anon_sym_throw] = ACTIONS(3441),
    [anon_sym_try] = ACTIONS(3441),
    [anon_sym_when] = ACTIONS(3441),
    [anon_sym_await] = ACTIONS(3441),
    [anon_sym_foreach] = ACTIONS(3441),
    [anon_sym_goto] = ACTIONS(3441),
    [anon_sym_if] = ACTIONS(3441),
    [anon_sym_DOT_DOT] = ACTIONS(3443),
    [anon_sym_from] = ACTIONS(3441),
    [anon_sym_into] = ACTIONS(3441),
    [anon_sym_join] = ACTIONS(3441),
    [anon_sym_on] = ACTIONS(3441),
    [anon_sym_equals] = ACTIONS(3441),
    [anon_sym_let] = ACTIONS(3441),
    [anon_sym_orderby] = ACTIONS(3441),
    [anon_sym_ascending] = ACTIONS(3441),
    [anon_sym_descending] = ACTIONS(3441),
    [anon_sym_group] = ACTIONS(3441),
    [anon_sym_by] = ACTIONS(3441),
    [anon_sym_select] = ACTIONS(3441),
    [anon_sym_stackalloc] = ACTIONS(3441),
    [anon_sym_sizeof] = ACTIONS(3441),
    [anon_sym_typeof] = ACTIONS(3441),
    [anon_sym___makeref] = ACTIONS(3441),
    [anon_sym___reftype] = ACTIONS(3441),
    [anon_sym___refvalue] = ACTIONS(3441),
    [sym_null_literal] = ACTIONS(3441),
    [anon_sym_SQUOTE] = ACTIONS(3443),
    [sym_integer_literal] = ACTIONS(3441),
    [sym_real_literal] = ACTIONS(3443),
    [anon_sym_DQUOTE] = ACTIONS(3443),
    [sym_verbatim_string_literal] = ACTIONS(3443),
    [aux_sym_preproc_if_token1] = ACTIONS(3443),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3443),
    [sym_interpolation_verbatim_start] = ACTIONS(3443),
    [sym_interpolation_raw_start] = ACTIONS(3443),
    [sym_raw_string_start] = ACTIONS(3443),
  },
  [2615] = {
    [sym_preproc_region] = STATE(2615),
    [sym_preproc_endregion] = STATE(2615),
    [sym_preproc_line] = STATE(2615),
    [sym_preproc_pragma] = STATE(2615),
    [sym_preproc_nullable] = STATE(2615),
    [sym_preproc_error] = STATE(2615),
    [sym_preproc_warning] = STATE(2615),
    [sym_preproc_define] = STATE(2615),
    [sym_preproc_undef] = STATE(2615),
    [ts_builtin_sym_end] = ACTIONS(3447),
    [sym__identifier_token] = ACTIONS(3445),
    [anon_sym_extern] = ACTIONS(3445),
    [anon_sym_alias] = ACTIONS(3445),
    [anon_sym_SEMI] = ACTIONS(3447),
    [anon_sym_global] = ACTIONS(3445),
    [anon_sym_using] = ACTIONS(3445),
    [anon_sym_unsafe] = ACTIONS(3445),
    [anon_sym_static] = ACTIONS(3445),
    [anon_sym_LBRACK] = ACTIONS(3447),
    [anon_sym_LPAREN] = ACTIONS(3447),
    [anon_sym_return] = ACTIONS(3445),
    [anon_sym_namespace] = ACTIONS(3445),
    [anon_sym_class] = ACTIONS(3445),
    [anon_sym_ref] = ACTIONS(3445),
    [anon_sym_struct] = ACTIONS(3445),
    [anon_sym_enum] = ACTIONS(3445),
    [anon_sym_LBRACE] = ACTIONS(3447),
    [anon_sym_interface] = ACTIONS(3445),
    [anon_sym_delegate] = ACTIONS(3445),
    [anon_sym_record] = ACTIONS(3445),
    [anon_sym_abstract] = ACTIONS(3445),
    [anon_sym_async] = ACTIONS(3445),
    [anon_sym_const] = ACTIONS(3445),
    [anon_sym_file] = ACTIONS(3445),
    [anon_sym_fixed] = ACTIONS(3445),
    [anon_sym_internal] = ACTIONS(3445),
    [anon_sym_new] = ACTIONS(3445),
    [anon_sym_override] = ACTIONS(3445),
    [anon_sym_partial] = ACTIONS(3445),
    [anon_sym_private] = ACTIONS(3445),
    [anon_sym_protected] = ACTIONS(3445),
    [anon_sym_public] = ACTIONS(3445),
    [anon_sym_readonly] = ACTIONS(3445),
    [anon_sym_required] = ACTIONS(3445),
    [anon_sym_sealed] = ACTIONS(3445),
    [anon_sym_virtual] = ACTIONS(3445),
    [anon_sym_volatile] = ACTIONS(3445),
    [anon_sym_where] = ACTIONS(3445),
    [anon_sym_notnull] = ACTIONS(3445),
    [anon_sym_unmanaged] = ACTIONS(3445),
    [anon_sym_checked] = ACTIONS(3445),
    [anon_sym_BANG] = ACTIONS(3447),
    [anon_sym_TILDE] = ACTIONS(3447),
    [anon_sym_PLUS_PLUS] = ACTIONS(3447),
    [anon_sym_DASH_DASH] = ACTIONS(3447),
    [anon_sym_true] = ACTIONS(3445),
    [anon_sym_false] = ACTIONS(3445),
    [anon_sym_PLUS] = ACTIONS(3445),
    [anon_sym_DASH] = ACTIONS(3445),
    [anon_sym_STAR] = ACTIONS(3447),
    [anon_sym_CARET] = ACTIONS(3447),
    [anon_sym_AMP] = ACTIONS(3447),
    [anon_sym_this] = ACTIONS(3445),
    [anon_sym_scoped] = ACTIONS(3445),
    [anon_sym_base] = ACTIONS(3445),
    [anon_sym_var] = ACTIONS(3445),
    [sym_predefined_type] = ACTIONS(3445),
    [anon_sym_break] = ACTIONS(3445),
    [anon_sym_unchecked] = ACTIONS(3445),
    [anon_sym_continue] = ACTIONS(3445),
    [anon_sym_do] = ACTIONS(3445),
    [anon_sym_while] = ACTIONS(3445),
    [anon_sym_for] = ACTIONS(3445),
    [anon_sym_lock] = ACTIONS(3445),
    [anon_sym_yield] = ACTIONS(3445),
    [anon_sym_switch] = ACTIONS(3445),
    [anon_sym_default] = ACTIONS(3445),
    [anon_sym_throw] = ACTIONS(3445),
    [anon_sym_try] = ACTIONS(3445),
    [anon_sym_when] = ACTIONS(3445),
    [anon_sym_await] = ACTIONS(3445),
    [anon_sym_foreach] = ACTIONS(3445),
    [anon_sym_goto] = ACTIONS(3445),
    [anon_sym_if] = ACTIONS(3445),
    [anon_sym_DOT_DOT] = ACTIONS(3447),
    [anon_sym_from] = ACTIONS(3445),
    [anon_sym_into] = ACTIONS(3445),
    [anon_sym_join] = ACTIONS(3445),
    [anon_sym_on] = ACTIONS(3445),
    [anon_sym_equals] = ACTIONS(3445),
    [anon_sym_let] = ACTIONS(3445),
    [anon_sym_orderby] = ACTIONS(3445),
    [anon_sym_ascending] = ACTIONS(3445),
    [anon_sym_descending] = ACTIONS(3445),
    [anon_sym_group] = ACTIONS(3445),
    [anon_sym_by] = ACTIONS(3445),
    [anon_sym_select] = ACTIONS(3445),
    [anon_sym_stackalloc] = ACTIONS(3445),
    [anon_sym_sizeof] = ACTIONS(3445),
    [anon_sym_typeof] = ACTIONS(3445),
    [anon_sym___makeref] = ACTIONS(3445),
    [anon_sym___reftype] = ACTIONS(3445),
    [anon_sym___refvalue] = ACTIONS(3445),
    [sym_null_literal] = ACTIONS(3445),
    [anon_sym_SQUOTE] = ACTIONS(3447),
    [sym_integer_literal] = ACTIONS(3445),
    [sym_real_literal] = ACTIONS(3447),
    [anon_sym_DQUOTE] = ACTIONS(3447),
    [sym_verbatim_string_literal] = ACTIONS(3447),
    [aux_sym_preproc_if_token1] = ACTIONS(3447),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3447),
    [sym_interpolation_verbatim_start] = ACTIONS(3447),
    [sym_interpolation_raw_start] = ACTIONS(3447),
    [sym_raw_string_start] = ACTIONS(3447),
  },
  [2616] = {
    [sym_preproc_region] = STATE(2616),
    [sym_preproc_endregion] = STATE(2616),
    [sym_preproc_line] = STATE(2616),
    [sym_preproc_pragma] = STATE(2616),
    [sym_preproc_nullable] = STATE(2616),
    [sym_preproc_error] = STATE(2616),
    [sym_preproc_warning] = STATE(2616),
    [sym_preproc_define] = STATE(2616),
    [sym_preproc_undef] = STATE(2616),
    [ts_builtin_sym_end] = ACTIONS(3451),
    [sym__identifier_token] = ACTIONS(3449),
    [anon_sym_extern] = ACTIONS(3449),
    [anon_sym_alias] = ACTIONS(3449),
    [anon_sym_SEMI] = ACTIONS(3451),
    [anon_sym_global] = ACTIONS(3449),
    [anon_sym_using] = ACTIONS(3449),
    [anon_sym_unsafe] = ACTIONS(3449),
    [anon_sym_static] = ACTIONS(3449),
    [anon_sym_LBRACK] = ACTIONS(3451),
    [anon_sym_LPAREN] = ACTIONS(3451),
    [anon_sym_return] = ACTIONS(3449),
    [anon_sym_namespace] = ACTIONS(3449),
    [anon_sym_class] = ACTIONS(3449),
    [anon_sym_ref] = ACTIONS(3449),
    [anon_sym_struct] = ACTIONS(3449),
    [anon_sym_enum] = ACTIONS(3449),
    [anon_sym_LBRACE] = ACTIONS(3451),
    [anon_sym_interface] = ACTIONS(3449),
    [anon_sym_delegate] = ACTIONS(3449),
    [anon_sym_record] = ACTIONS(3449),
    [anon_sym_abstract] = ACTIONS(3449),
    [anon_sym_async] = ACTIONS(3449),
    [anon_sym_const] = ACTIONS(3449),
    [anon_sym_file] = ACTIONS(3449),
    [anon_sym_fixed] = ACTIONS(3449),
    [anon_sym_internal] = ACTIONS(3449),
    [anon_sym_new] = ACTIONS(3449),
    [anon_sym_override] = ACTIONS(3449),
    [anon_sym_partial] = ACTIONS(3449),
    [anon_sym_private] = ACTIONS(3449),
    [anon_sym_protected] = ACTIONS(3449),
    [anon_sym_public] = ACTIONS(3449),
    [anon_sym_readonly] = ACTIONS(3449),
    [anon_sym_required] = ACTIONS(3449),
    [anon_sym_sealed] = ACTIONS(3449),
    [anon_sym_virtual] = ACTIONS(3449),
    [anon_sym_volatile] = ACTIONS(3449),
    [anon_sym_where] = ACTIONS(3449),
    [anon_sym_notnull] = ACTIONS(3449),
    [anon_sym_unmanaged] = ACTIONS(3449),
    [anon_sym_checked] = ACTIONS(3449),
    [anon_sym_BANG] = ACTIONS(3451),
    [anon_sym_TILDE] = ACTIONS(3451),
    [anon_sym_PLUS_PLUS] = ACTIONS(3451),
    [anon_sym_DASH_DASH] = ACTIONS(3451),
    [anon_sym_true] = ACTIONS(3449),
    [anon_sym_false] = ACTIONS(3449),
    [anon_sym_PLUS] = ACTIONS(3449),
    [anon_sym_DASH] = ACTIONS(3449),
    [anon_sym_STAR] = ACTIONS(3451),
    [anon_sym_CARET] = ACTIONS(3451),
    [anon_sym_AMP] = ACTIONS(3451),
    [anon_sym_this] = ACTIONS(3449),
    [anon_sym_scoped] = ACTIONS(3449),
    [anon_sym_base] = ACTIONS(3449),
    [anon_sym_var] = ACTIONS(3449),
    [sym_predefined_type] = ACTIONS(3449),
    [anon_sym_break] = ACTIONS(3449),
    [anon_sym_unchecked] = ACTIONS(3449),
    [anon_sym_continue] = ACTIONS(3449),
    [anon_sym_do] = ACTIONS(3449),
    [anon_sym_while] = ACTIONS(3449),
    [anon_sym_for] = ACTIONS(3449),
    [anon_sym_lock] = ACTIONS(3449),
    [anon_sym_yield] = ACTIONS(3449),
    [anon_sym_switch] = ACTIONS(3449),
    [anon_sym_default] = ACTIONS(3449),
    [anon_sym_throw] = ACTIONS(3449),
    [anon_sym_try] = ACTIONS(3449),
    [anon_sym_when] = ACTIONS(3449),
    [anon_sym_await] = ACTIONS(3449),
    [anon_sym_foreach] = ACTIONS(3449),
    [anon_sym_goto] = ACTIONS(3449),
    [anon_sym_if] = ACTIONS(3449),
    [anon_sym_DOT_DOT] = ACTIONS(3451),
    [anon_sym_from] = ACTIONS(3449),
    [anon_sym_into] = ACTIONS(3449),
    [anon_sym_join] = ACTIONS(3449),
    [anon_sym_on] = ACTIONS(3449),
    [anon_sym_equals] = ACTIONS(3449),
    [anon_sym_let] = ACTIONS(3449),
    [anon_sym_orderby] = ACTIONS(3449),
    [anon_sym_ascending] = ACTIONS(3449),
    [anon_sym_descending] = ACTIONS(3449),
    [anon_sym_group] = ACTIONS(3449),
    [anon_sym_by] = ACTIONS(3449),
    [anon_sym_select] = ACTIONS(3449),
    [anon_sym_stackalloc] = ACTIONS(3449),
    [anon_sym_sizeof] = ACTIONS(3449),
    [anon_sym_typeof] = ACTIONS(3449),
    [anon_sym___makeref] = ACTIONS(3449),
    [anon_sym___reftype] = ACTIONS(3449),
    [anon_sym___refvalue] = ACTIONS(3449),
    [sym_null_literal] = ACTIONS(3449),
    [anon_sym_SQUOTE] = ACTIONS(3451),
    [sym_integer_literal] = ACTIONS(3449),
    [sym_real_literal] = ACTIONS(3451),
    [anon_sym_DQUOTE] = ACTIONS(3451),
    [sym_verbatim_string_literal] = ACTIONS(3451),
    [aux_sym_preproc_if_token1] = ACTIONS(3451),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3451),
    [sym_interpolation_verbatim_start] = ACTIONS(3451),
    [sym_interpolation_raw_start] = ACTIONS(3451),
    [sym_raw_string_start] = ACTIONS(3451),
  },
  [2617] = {
    [sym_preproc_region] = STATE(2617),
    [sym_preproc_endregion] = STATE(2617),
    [sym_preproc_line] = STATE(2617),
    [sym_preproc_pragma] = STATE(2617),
    [sym_preproc_nullable] = STATE(2617),
    [sym_preproc_error] = STATE(2617),
    [sym_preproc_warning] = STATE(2617),
    [sym_preproc_define] = STATE(2617),
    [sym_preproc_undef] = STATE(2617),
    [ts_builtin_sym_end] = ACTIONS(3455),
    [sym__identifier_token] = ACTIONS(3453),
    [anon_sym_extern] = ACTIONS(3453),
    [anon_sym_alias] = ACTIONS(3453),
    [anon_sym_SEMI] = ACTIONS(3455),
    [anon_sym_global] = ACTIONS(3453),
    [anon_sym_using] = ACTIONS(3453),
    [anon_sym_unsafe] = ACTIONS(3453),
    [anon_sym_static] = ACTIONS(3453),
    [anon_sym_LBRACK] = ACTIONS(3455),
    [anon_sym_LPAREN] = ACTIONS(3455),
    [anon_sym_return] = ACTIONS(3453),
    [anon_sym_namespace] = ACTIONS(3453),
    [anon_sym_class] = ACTIONS(3453),
    [anon_sym_ref] = ACTIONS(3453),
    [anon_sym_struct] = ACTIONS(3453),
    [anon_sym_enum] = ACTIONS(3453),
    [anon_sym_LBRACE] = ACTIONS(3455),
    [anon_sym_interface] = ACTIONS(3453),
    [anon_sym_delegate] = ACTIONS(3453),
    [anon_sym_record] = ACTIONS(3453),
    [anon_sym_abstract] = ACTIONS(3453),
    [anon_sym_async] = ACTIONS(3453),
    [anon_sym_const] = ACTIONS(3453),
    [anon_sym_file] = ACTIONS(3453),
    [anon_sym_fixed] = ACTIONS(3453),
    [anon_sym_internal] = ACTIONS(3453),
    [anon_sym_new] = ACTIONS(3453),
    [anon_sym_override] = ACTIONS(3453),
    [anon_sym_partial] = ACTIONS(3453),
    [anon_sym_private] = ACTIONS(3453),
    [anon_sym_protected] = ACTIONS(3453),
    [anon_sym_public] = ACTIONS(3453),
    [anon_sym_readonly] = ACTIONS(3453),
    [anon_sym_required] = ACTIONS(3453),
    [anon_sym_sealed] = ACTIONS(3453),
    [anon_sym_virtual] = ACTIONS(3453),
    [anon_sym_volatile] = ACTIONS(3453),
    [anon_sym_where] = ACTIONS(3453),
    [anon_sym_notnull] = ACTIONS(3453),
    [anon_sym_unmanaged] = ACTIONS(3453),
    [anon_sym_checked] = ACTIONS(3453),
    [anon_sym_BANG] = ACTIONS(3455),
    [anon_sym_TILDE] = ACTIONS(3455),
    [anon_sym_PLUS_PLUS] = ACTIONS(3455),
    [anon_sym_DASH_DASH] = ACTIONS(3455),
    [anon_sym_true] = ACTIONS(3453),
    [anon_sym_false] = ACTIONS(3453),
    [anon_sym_PLUS] = ACTIONS(3453),
    [anon_sym_DASH] = ACTIONS(3453),
    [anon_sym_STAR] = ACTIONS(3455),
    [anon_sym_CARET] = ACTIONS(3455),
    [anon_sym_AMP] = ACTIONS(3455),
    [anon_sym_this] = ACTIONS(3453),
    [anon_sym_scoped] = ACTIONS(3453),
    [anon_sym_base] = ACTIONS(3453),
    [anon_sym_var] = ACTIONS(3453),
    [sym_predefined_type] = ACTIONS(3453),
    [anon_sym_break] = ACTIONS(3453),
    [anon_sym_unchecked] = ACTIONS(3453),
    [anon_sym_continue] = ACTIONS(3453),
    [anon_sym_do] = ACTIONS(3453),
    [anon_sym_while] = ACTIONS(3453),
    [anon_sym_for] = ACTIONS(3453),
    [anon_sym_lock] = ACTIONS(3453),
    [anon_sym_yield] = ACTIONS(3453),
    [anon_sym_switch] = ACTIONS(3453),
    [anon_sym_default] = ACTIONS(3453),
    [anon_sym_throw] = ACTIONS(3453),
    [anon_sym_try] = ACTIONS(3453),
    [anon_sym_when] = ACTIONS(3453),
    [anon_sym_await] = ACTIONS(3453),
    [anon_sym_foreach] = ACTIONS(3453),
    [anon_sym_goto] = ACTIONS(3453),
    [anon_sym_if] = ACTIONS(3453),
    [anon_sym_DOT_DOT] = ACTIONS(3455),
    [anon_sym_from] = ACTIONS(3453),
    [anon_sym_into] = ACTIONS(3453),
    [anon_sym_join] = ACTIONS(3453),
    [anon_sym_on] = ACTIONS(3453),
    [anon_sym_equals] = ACTIONS(3453),
    [anon_sym_let] = ACTIONS(3453),
    [anon_sym_orderby] = ACTIONS(3453),
    [anon_sym_ascending] = ACTIONS(3453),
    [anon_sym_descending] = ACTIONS(3453),
    [anon_sym_group] = ACTIONS(3453),
    [anon_sym_by] = ACTIONS(3453),
    [anon_sym_select] = ACTIONS(3453),
    [anon_sym_stackalloc] = ACTIONS(3453),
    [anon_sym_sizeof] = ACTIONS(3453),
    [anon_sym_typeof] = ACTIONS(3453),
    [anon_sym___makeref] = ACTIONS(3453),
    [anon_sym___reftype] = ACTIONS(3453),
    [anon_sym___refvalue] = ACTIONS(3453),
    [sym_null_literal] = ACTIONS(3453),
    [anon_sym_SQUOTE] = ACTIONS(3455),
    [sym_integer_literal] = ACTIONS(3453),
    [sym_real_literal] = ACTIONS(3455),
    [anon_sym_DQUOTE] = ACTIONS(3455),
    [sym_verbatim_string_literal] = ACTIONS(3455),
    [aux_sym_preproc_if_token1] = ACTIONS(3455),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3455),
    [sym_interpolation_verbatim_start] = ACTIONS(3455),
    [sym_interpolation_raw_start] = ACTIONS(3455),
    [sym_raw_string_start] = ACTIONS(3455),
  },
  [2618] = {
    [sym_preproc_region] = STATE(2618),
    [sym_preproc_endregion] = STATE(2618),
    [sym_preproc_line] = STATE(2618),
    [sym_preproc_pragma] = STATE(2618),
    [sym_preproc_nullable] = STATE(2618),
    [sym_preproc_error] = STATE(2618),
    [sym_preproc_warning] = STATE(2618),
    [sym_preproc_define] = STATE(2618),
    [sym_preproc_undef] = STATE(2618),
    [ts_builtin_sym_end] = ACTIONS(3459),
    [sym__identifier_token] = ACTIONS(3457),
    [anon_sym_extern] = ACTIONS(3457),
    [anon_sym_alias] = ACTIONS(3457),
    [anon_sym_SEMI] = ACTIONS(3459),
    [anon_sym_global] = ACTIONS(3457),
    [anon_sym_using] = ACTIONS(3457),
    [anon_sym_unsafe] = ACTIONS(3457),
    [anon_sym_static] = ACTIONS(3457),
    [anon_sym_LBRACK] = ACTIONS(3459),
    [anon_sym_LPAREN] = ACTIONS(3459),
    [anon_sym_return] = ACTIONS(3457),
    [anon_sym_namespace] = ACTIONS(3457),
    [anon_sym_class] = ACTIONS(3457),
    [anon_sym_ref] = ACTIONS(3457),
    [anon_sym_struct] = ACTIONS(3457),
    [anon_sym_enum] = ACTIONS(3457),
    [anon_sym_LBRACE] = ACTIONS(3459),
    [anon_sym_interface] = ACTIONS(3457),
    [anon_sym_delegate] = ACTIONS(3457),
    [anon_sym_record] = ACTIONS(3457),
    [anon_sym_abstract] = ACTIONS(3457),
    [anon_sym_async] = ACTIONS(3457),
    [anon_sym_const] = ACTIONS(3457),
    [anon_sym_file] = ACTIONS(3457),
    [anon_sym_fixed] = ACTIONS(3457),
    [anon_sym_internal] = ACTIONS(3457),
    [anon_sym_new] = ACTIONS(3457),
    [anon_sym_override] = ACTIONS(3457),
    [anon_sym_partial] = ACTIONS(3457),
    [anon_sym_private] = ACTIONS(3457),
    [anon_sym_protected] = ACTIONS(3457),
    [anon_sym_public] = ACTIONS(3457),
    [anon_sym_readonly] = ACTIONS(3457),
    [anon_sym_required] = ACTIONS(3457),
    [anon_sym_sealed] = ACTIONS(3457),
    [anon_sym_virtual] = ACTIONS(3457),
    [anon_sym_volatile] = ACTIONS(3457),
    [anon_sym_where] = ACTIONS(3457),
    [anon_sym_notnull] = ACTIONS(3457),
    [anon_sym_unmanaged] = ACTIONS(3457),
    [anon_sym_checked] = ACTIONS(3457),
    [anon_sym_BANG] = ACTIONS(3459),
    [anon_sym_TILDE] = ACTIONS(3459),
    [anon_sym_PLUS_PLUS] = ACTIONS(3459),
    [anon_sym_DASH_DASH] = ACTIONS(3459),
    [anon_sym_true] = ACTIONS(3457),
    [anon_sym_false] = ACTIONS(3457),
    [anon_sym_PLUS] = ACTIONS(3457),
    [anon_sym_DASH] = ACTIONS(3457),
    [anon_sym_STAR] = ACTIONS(3459),
    [anon_sym_CARET] = ACTIONS(3459),
    [anon_sym_AMP] = ACTIONS(3459),
    [anon_sym_this] = ACTIONS(3457),
    [anon_sym_scoped] = ACTIONS(3457),
    [anon_sym_base] = ACTIONS(3457),
    [anon_sym_var] = ACTIONS(3457),
    [sym_predefined_type] = ACTIONS(3457),
    [anon_sym_break] = ACTIONS(3457),
    [anon_sym_unchecked] = ACTIONS(3457),
    [anon_sym_continue] = ACTIONS(3457),
    [anon_sym_do] = ACTIONS(3457),
    [anon_sym_while] = ACTIONS(3457),
    [anon_sym_for] = ACTIONS(3457),
    [anon_sym_lock] = ACTIONS(3457),
    [anon_sym_yield] = ACTIONS(3457),
    [anon_sym_switch] = ACTIONS(3457),
    [anon_sym_default] = ACTIONS(3457),
    [anon_sym_throw] = ACTIONS(3457),
    [anon_sym_try] = ACTIONS(3457),
    [anon_sym_when] = ACTIONS(3457),
    [anon_sym_await] = ACTIONS(3457),
    [anon_sym_foreach] = ACTIONS(3457),
    [anon_sym_goto] = ACTIONS(3457),
    [anon_sym_if] = ACTIONS(3457),
    [anon_sym_DOT_DOT] = ACTIONS(3459),
    [anon_sym_from] = ACTIONS(3457),
    [anon_sym_into] = ACTIONS(3457),
    [anon_sym_join] = ACTIONS(3457),
    [anon_sym_on] = ACTIONS(3457),
    [anon_sym_equals] = ACTIONS(3457),
    [anon_sym_let] = ACTIONS(3457),
    [anon_sym_orderby] = ACTIONS(3457),
    [anon_sym_ascending] = ACTIONS(3457),
    [anon_sym_descending] = ACTIONS(3457),
    [anon_sym_group] = ACTIONS(3457),
    [anon_sym_by] = ACTIONS(3457),
    [anon_sym_select] = ACTIONS(3457),
    [anon_sym_stackalloc] = ACTIONS(3457),
    [anon_sym_sizeof] = ACTIONS(3457),
    [anon_sym_typeof] = ACTIONS(3457),
    [anon_sym___makeref] = ACTIONS(3457),
    [anon_sym___reftype] = ACTIONS(3457),
    [anon_sym___refvalue] = ACTIONS(3457),
    [sym_null_literal] = ACTIONS(3457),
    [anon_sym_SQUOTE] = ACTIONS(3459),
    [sym_integer_literal] = ACTIONS(3457),
    [sym_real_literal] = ACTIONS(3459),
    [anon_sym_DQUOTE] = ACTIONS(3459),
    [sym_verbatim_string_literal] = ACTIONS(3459),
    [aux_sym_preproc_if_token1] = ACTIONS(3459),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3459),
    [sym_interpolation_verbatim_start] = ACTIONS(3459),
    [sym_interpolation_raw_start] = ACTIONS(3459),
    [sym_raw_string_start] = ACTIONS(3459),
  },
  [2619] = {
    [sym_preproc_region] = STATE(2619),
    [sym_preproc_endregion] = STATE(2619),
    [sym_preproc_line] = STATE(2619),
    [sym_preproc_pragma] = STATE(2619),
    [sym_preproc_nullable] = STATE(2619),
    [sym_preproc_error] = STATE(2619),
    [sym_preproc_warning] = STATE(2619),
    [sym_preproc_define] = STATE(2619),
    [sym_preproc_undef] = STATE(2619),
    [ts_builtin_sym_end] = ACTIONS(3463),
    [sym__identifier_token] = ACTIONS(3461),
    [anon_sym_extern] = ACTIONS(3461),
    [anon_sym_alias] = ACTIONS(3461),
    [anon_sym_SEMI] = ACTIONS(3463),
    [anon_sym_global] = ACTIONS(3461),
    [anon_sym_using] = ACTIONS(3461),
    [anon_sym_unsafe] = ACTIONS(3461),
    [anon_sym_static] = ACTIONS(3461),
    [anon_sym_LBRACK] = ACTIONS(3463),
    [anon_sym_LPAREN] = ACTIONS(3463),
    [anon_sym_return] = ACTIONS(3461),
    [anon_sym_namespace] = ACTIONS(3461),
    [anon_sym_class] = ACTIONS(3461),
    [anon_sym_ref] = ACTIONS(3461),
    [anon_sym_struct] = ACTIONS(3461),
    [anon_sym_enum] = ACTIONS(3461),
    [anon_sym_LBRACE] = ACTIONS(3463),
    [anon_sym_interface] = ACTIONS(3461),
    [anon_sym_delegate] = ACTIONS(3461),
    [anon_sym_record] = ACTIONS(3461),
    [anon_sym_abstract] = ACTIONS(3461),
    [anon_sym_async] = ACTIONS(3461),
    [anon_sym_const] = ACTIONS(3461),
    [anon_sym_file] = ACTIONS(3461),
    [anon_sym_fixed] = ACTIONS(3461),
    [anon_sym_internal] = ACTIONS(3461),
    [anon_sym_new] = ACTIONS(3461),
    [anon_sym_override] = ACTIONS(3461),
    [anon_sym_partial] = ACTIONS(3461),
    [anon_sym_private] = ACTIONS(3461),
    [anon_sym_protected] = ACTIONS(3461),
    [anon_sym_public] = ACTIONS(3461),
    [anon_sym_readonly] = ACTIONS(3461),
    [anon_sym_required] = ACTIONS(3461),
    [anon_sym_sealed] = ACTIONS(3461),
    [anon_sym_virtual] = ACTIONS(3461),
    [anon_sym_volatile] = ACTIONS(3461),
    [anon_sym_where] = ACTIONS(3461),
    [anon_sym_notnull] = ACTIONS(3461),
    [anon_sym_unmanaged] = ACTIONS(3461),
    [anon_sym_checked] = ACTIONS(3461),
    [anon_sym_BANG] = ACTIONS(3463),
    [anon_sym_TILDE] = ACTIONS(3463),
    [anon_sym_PLUS_PLUS] = ACTIONS(3463),
    [anon_sym_DASH_DASH] = ACTIONS(3463),
    [anon_sym_true] = ACTIONS(3461),
    [anon_sym_false] = ACTIONS(3461),
    [anon_sym_PLUS] = ACTIONS(3461),
    [anon_sym_DASH] = ACTIONS(3461),
    [anon_sym_STAR] = ACTIONS(3463),
    [anon_sym_CARET] = ACTIONS(3463),
    [anon_sym_AMP] = ACTIONS(3463),
    [anon_sym_this] = ACTIONS(3461),
    [anon_sym_scoped] = ACTIONS(3461),
    [anon_sym_base] = ACTIONS(3461),
    [anon_sym_var] = ACTIONS(3461),
    [sym_predefined_type] = ACTIONS(3461),
    [anon_sym_break] = ACTIONS(3461),
    [anon_sym_unchecked] = ACTIONS(3461),
    [anon_sym_continue] = ACTIONS(3461),
    [anon_sym_do] = ACTIONS(3461),
    [anon_sym_while] = ACTIONS(3461),
    [anon_sym_for] = ACTIONS(3461),
    [anon_sym_lock] = ACTIONS(3461),
    [anon_sym_yield] = ACTIONS(3461),
    [anon_sym_switch] = ACTIONS(3461),
    [anon_sym_default] = ACTIONS(3461),
    [anon_sym_throw] = ACTIONS(3461),
    [anon_sym_try] = ACTIONS(3461),
    [anon_sym_when] = ACTIONS(3461),
    [anon_sym_await] = ACTIONS(3461),
    [anon_sym_foreach] = ACTIONS(3461),
    [anon_sym_goto] = ACTIONS(3461),
    [anon_sym_if] = ACTIONS(3461),
    [anon_sym_DOT_DOT] = ACTIONS(3463),
    [anon_sym_from] = ACTIONS(3461),
    [anon_sym_into] = ACTIONS(3461),
    [anon_sym_join] = ACTIONS(3461),
    [anon_sym_on] = ACTIONS(3461),
    [anon_sym_equals] = ACTIONS(3461),
    [anon_sym_let] = ACTIONS(3461),
    [anon_sym_orderby] = ACTIONS(3461),
    [anon_sym_ascending] = ACTIONS(3461),
    [anon_sym_descending] = ACTIONS(3461),
    [anon_sym_group] = ACTIONS(3461),
    [anon_sym_by] = ACTIONS(3461),
    [anon_sym_select] = ACTIONS(3461),
    [anon_sym_stackalloc] = ACTIONS(3461),
    [anon_sym_sizeof] = ACTIONS(3461),
    [anon_sym_typeof] = ACTIONS(3461),
    [anon_sym___makeref] = ACTIONS(3461),
    [anon_sym___reftype] = ACTIONS(3461),
    [anon_sym___refvalue] = ACTIONS(3461),
    [sym_null_literal] = ACTIONS(3461),
    [anon_sym_SQUOTE] = ACTIONS(3463),
    [sym_integer_literal] = ACTIONS(3461),
    [sym_real_literal] = ACTIONS(3463),
    [anon_sym_DQUOTE] = ACTIONS(3463),
    [sym_verbatim_string_literal] = ACTIONS(3463),
    [aux_sym_preproc_if_token1] = ACTIONS(3463),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3463),
    [sym_interpolation_verbatim_start] = ACTIONS(3463),
    [sym_interpolation_raw_start] = ACTIONS(3463),
    [sym_raw_string_start] = ACTIONS(3463),
  },
  [2620] = {
    [sym_preproc_region] = STATE(2620),
    [sym_preproc_endregion] = STATE(2620),
    [sym_preproc_line] = STATE(2620),
    [sym_preproc_pragma] = STATE(2620),
    [sym_preproc_nullable] = STATE(2620),
    [sym_preproc_error] = STATE(2620),
    [sym_preproc_warning] = STATE(2620),
    [sym_preproc_define] = STATE(2620),
    [sym_preproc_undef] = STATE(2620),
    [ts_builtin_sym_end] = ACTIONS(3467),
    [sym__identifier_token] = ACTIONS(3465),
    [anon_sym_extern] = ACTIONS(3465),
    [anon_sym_alias] = ACTIONS(3465),
    [anon_sym_SEMI] = ACTIONS(3467),
    [anon_sym_global] = ACTIONS(3465),
    [anon_sym_using] = ACTIONS(3465),
    [anon_sym_unsafe] = ACTIONS(3465),
    [anon_sym_static] = ACTIONS(3465),
    [anon_sym_LBRACK] = ACTIONS(3467),
    [anon_sym_LPAREN] = ACTIONS(3467),
    [anon_sym_return] = ACTIONS(3465),
    [anon_sym_namespace] = ACTIONS(3465),
    [anon_sym_class] = ACTIONS(3465),
    [anon_sym_ref] = ACTIONS(3465),
    [anon_sym_struct] = ACTIONS(3465),
    [anon_sym_enum] = ACTIONS(3465),
    [anon_sym_LBRACE] = ACTIONS(3467),
    [anon_sym_interface] = ACTIONS(3465),
    [anon_sym_delegate] = ACTIONS(3465),
    [anon_sym_record] = ACTIONS(3465),
    [anon_sym_abstract] = ACTIONS(3465),
    [anon_sym_async] = ACTIONS(3465),
    [anon_sym_const] = ACTIONS(3465),
    [anon_sym_file] = ACTIONS(3465),
    [anon_sym_fixed] = ACTIONS(3465),
    [anon_sym_internal] = ACTIONS(3465),
    [anon_sym_new] = ACTIONS(3465),
    [anon_sym_override] = ACTIONS(3465),
    [anon_sym_partial] = ACTIONS(3465),
    [anon_sym_private] = ACTIONS(3465),
    [anon_sym_protected] = ACTIONS(3465),
    [anon_sym_public] = ACTIONS(3465),
    [anon_sym_readonly] = ACTIONS(3465),
    [anon_sym_required] = ACTIONS(3465),
    [anon_sym_sealed] = ACTIONS(3465),
    [anon_sym_virtual] = ACTIONS(3465),
    [anon_sym_volatile] = ACTIONS(3465),
    [anon_sym_where] = ACTIONS(3465),
    [anon_sym_notnull] = ACTIONS(3465),
    [anon_sym_unmanaged] = ACTIONS(3465),
    [anon_sym_checked] = ACTIONS(3465),
    [anon_sym_BANG] = ACTIONS(3467),
    [anon_sym_TILDE] = ACTIONS(3467),
    [anon_sym_PLUS_PLUS] = ACTIONS(3467),
    [anon_sym_DASH_DASH] = ACTIONS(3467),
    [anon_sym_true] = ACTIONS(3465),
    [anon_sym_false] = ACTIONS(3465),
    [anon_sym_PLUS] = ACTIONS(3465),
    [anon_sym_DASH] = ACTIONS(3465),
    [anon_sym_STAR] = ACTIONS(3467),
    [anon_sym_CARET] = ACTIONS(3467),
    [anon_sym_AMP] = ACTIONS(3467),
    [anon_sym_this] = ACTIONS(3465),
    [anon_sym_scoped] = ACTIONS(3465),
    [anon_sym_base] = ACTIONS(3465),
    [anon_sym_var] = ACTIONS(3465),
    [sym_predefined_type] = ACTIONS(3465),
    [anon_sym_break] = ACTIONS(3465),
    [anon_sym_unchecked] = ACTIONS(3465),
    [anon_sym_continue] = ACTIONS(3465),
    [anon_sym_do] = ACTIONS(3465),
    [anon_sym_while] = ACTIONS(3465),
    [anon_sym_for] = ACTIONS(3465),
    [anon_sym_lock] = ACTIONS(3465),
    [anon_sym_yield] = ACTIONS(3465),
    [anon_sym_switch] = ACTIONS(3465),
    [anon_sym_default] = ACTIONS(3465),
    [anon_sym_throw] = ACTIONS(3465),
    [anon_sym_try] = ACTIONS(3465),
    [anon_sym_when] = ACTIONS(3465),
    [anon_sym_await] = ACTIONS(3465),
    [anon_sym_foreach] = ACTIONS(3465),
    [anon_sym_goto] = ACTIONS(3465),
    [anon_sym_if] = ACTIONS(3465),
    [anon_sym_DOT_DOT] = ACTIONS(3467),
    [anon_sym_from] = ACTIONS(3465),
    [anon_sym_into] = ACTIONS(3465),
    [anon_sym_join] = ACTIONS(3465),
    [anon_sym_on] = ACTIONS(3465),
    [anon_sym_equals] = ACTIONS(3465),
    [anon_sym_let] = ACTIONS(3465),
    [anon_sym_orderby] = ACTIONS(3465),
    [anon_sym_ascending] = ACTIONS(3465),
    [anon_sym_descending] = ACTIONS(3465),
    [anon_sym_group] = ACTIONS(3465),
    [anon_sym_by] = ACTIONS(3465),
    [anon_sym_select] = ACTIONS(3465),
    [anon_sym_stackalloc] = ACTIONS(3465),
    [anon_sym_sizeof] = ACTIONS(3465),
    [anon_sym_typeof] = ACTIONS(3465),
    [anon_sym___makeref] = ACTIONS(3465),
    [anon_sym___reftype] = ACTIONS(3465),
    [anon_sym___refvalue] = ACTIONS(3465),
    [sym_null_literal] = ACTIONS(3465),
    [anon_sym_SQUOTE] = ACTIONS(3467),
    [sym_integer_literal] = ACTIONS(3465),
    [sym_real_literal] = ACTIONS(3467),
    [anon_sym_DQUOTE] = ACTIONS(3467),
    [sym_verbatim_string_literal] = ACTIONS(3467),
    [aux_sym_preproc_if_token1] = ACTIONS(3467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3467),
    [sym_interpolation_verbatim_start] = ACTIONS(3467),
    [sym_interpolation_raw_start] = ACTIONS(3467),
    [sym_raw_string_start] = ACTIONS(3467),
  },
  [2621] = {
    [sym_preproc_region] = STATE(2621),
    [sym_preproc_endregion] = STATE(2621),
    [sym_preproc_line] = STATE(2621),
    [sym_preproc_pragma] = STATE(2621),
    [sym_preproc_nullable] = STATE(2621),
    [sym_preproc_error] = STATE(2621),
    [sym_preproc_warning] = STATE(2621),
    [sym_preproc_define] = STATE(2621),
    [sym_preproc_undef] = STATE(2621),
    [ts_builtin_sym_end] = ACTIONS(4016),
    [sym__identifier_token] = ACTIONS(4018),
    [anon_sym_extern] = ACTIONS(4018),
    [anon_sym_alias] = ACTIONS(4018),
    [anon_sym_SEMI] = ACTIONS(4016),
    [anon_sym_global] = ACTIONS(4018),
    [anon_sym_using] = ACTIONS(4018),
    [anon_sym_unsafe] = ACTIONS(4018),
    [anon_sym_static] = ACTIONS(4018),
    [anon_sym_LBRACK] = ACTIONS(4016),
    [anon_sym_LPAREN] = ACTIONS(4016),
    [anon_sym_return] = ACTIONS(4018),
    [anon_sym_namespace] = ACTIONS(4018),
    [anon_sym_class] = ACTIONS(4018),
    [anon_sym_ref] = ACTIONS(4018),
    [anon_sym_struct] = ACTIONS(4018),
    [anon_sym_enum] = ACTIONS(4018),
    [anon_sym_LBRACE] = ACTIONS(4016),
    [anon_sym_interface] = ACTIONS(4018),
    [anon_sym_delegate] = ACTIONS(4018),
    [anon_sym_record] = ACTIONS(4018),
    [anon_sym_abstract] = ACTIONS(4018),
    [anon_sym_async] = ACTIONS(4018),
    [anon_sym_const] = ACTIONS(4018),
    [anon_sym_file] = ACTIONS(4018),
    [anon_sym_fixed] = ACTIONS(4018),
    [anon_sym_internal] = ACTIONS(4018),
    [anon_sym_new] = ACTIONS(4018),
    [anon_sym_override] = ACTIONS(4018),
    [anon_sym_partial] = ACTIONS(4018),
    [anon_sym_private] = ACTIONS(4018),
    [anon_sym_protected] = ACTIONS(4018),
    [anon_sym_public] = ACTIONS(4018),
    [anon_sym_readonly] = ACTIONS(4018),
    [anon_sym_required] = ACTIONS(4018),
    [anon_sym_sealed] = ACTIONS(4018),
    [anon_sym_virtual] = ACTIONS(4018),
    [anon_sym_volatile] = ACTIONS(4018),
    [anon_sym_where] = ACTIONS(4018),
    [anon_sym_notnull] = ACTIONS(4018),
    [anon_sym_unmanaged] = ACTIONS(4018),
    [anon_sym_checked] = ACTIONS(4018),
    [anon_sym_BANG] = ACTIONS(4016),
    [anon_sym_TILDE] = ACTIONS(4016),
    [anon_sym_PLUS_PLUS] = ACTIONS(4016),
    [anon_sym_DASH_DASH] = ACTIONS(4016),
    [anon_sym_true] = ACTIONS(4018),
    [anon_sym_false] = ACTIONS(4018),
    [anon_sym_PLUS] = ACTIONS(4018),
    [anon_sym_DASH] = ACTIONS(4018),
    [anon_sym_STAR] = ACTIONS(4016),
    [anon_sym_CARET] = ACTIONS(4016),
    [anon_sym_AMP] = ACTIONS(4016),
    [anon_sym_this] = ACTIONS(4018),
    [anon_sym_scoped] = ACTIONS(4018),
    [anon_sym_base] = ACTIONS(4018),
    [anon_sym_var] = ACTIONS(4018),
    [sym_predefined_type] = ACTIONS(4018),
    [anon_sym_break] = ACTIONS(4018),
    [anon_sym_unchecked] = ACTIONS(4018),
    [anon_sym_continue] = ACTIONS(4018),
    [anon_sym_do] = ACTIONS(4018),
    [anon_sym_while] = ACTIONS(4018),
    [anon_sym_for] = ACTIONS(4018),
    [anon_sym_lock] = ACTIONS(4018),
    [anon_sym_yield] = ACTIONS(4018),
    [anon_sym_switch] = ACTIONS(4018),
    [anon_sym_default] = ACTIONS(4018),
    [anon_sym_throw] = ACTIONS(4018),
    [anon_sym_try] = ACTIONS(4018),
    [anon_sym_when] = ACTIONS(4018),
    [anon_sym_await] = ACTIONS(4018),
    [anon_sym_foreach] = ACTIONS(4018),
    [anon_sym_goto] = ACTIONS(4018),
    [anon_sym_if] = ACTIONS(4018),
    [anon_sym_DOT_DOT] = ACTIONS(4016),
    [anon_sym_from] = ACTIONS(4018),
    [anon_sym_into] = ACTIONS(4018),
    [anon_sym_join] = ACTIONS(4018),
    [anon_sym_on] = ACTIONS(4018),
    [anon_sym_equals] = ACTIONS(4018),
    [anon_sym_let] = ACTIONS(4018),
    [anon_sym_orderby] = ACTIONS(4018),
    [anon_sym_ascending] = ACTIONS(4018),
    [anon_sym_descending] = ACTIONS(4018),
    [anon_sym_group] = ACTIONS(4018),
    [anon_sym_by] = ACTIONS(4018),
    [anon_sym_select] = ACTIONS(4018),
    [anon_sym_stackalloc] = ACTIONS(4018),
    [anon_sym_sizeof] = ACTIONS(4018),
    [anon_sym_typeof] = ACTIONS(4018),
    [anon_sym___makeref] = ACTIONS(4018),
    [anon_sym___reftype] = ACTIONS(4018),
    [anon_sym___refvalue] = ACTIONS(4018),
    [sym_null_literal] = ACTIONS(4018),
    [anon_sym_SQUOTE] = ACTIONS(4016),
    [sym_integer_literal] = ACTIONS(4018),
    [sym_real_literal] = ACTIONS(4016),
    [anon_sym_DQUOTE] = ACTIONS(4016),
    [sym_verbatim_string_literal] = ACTIONS(4016),
    [aux_sym_preproc_if_token1] = ACTIONS(4016),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(4016),
    [sym_interpolation_verbatim_start] = ACTIONS(4016),
    [sym_interpolation_raw_start] = ACTIONS(4016),
    [sym_raw_string_start] = ACTIONS(4016),
  },
  [2622] = {
    [sym_preproc_region] = STATE(2622),
    [sym_preproc_endregion] = STATE(2622),
    [sym_preproc_line] = STATE(2622),
    [sym_preproc_pragma] = STATE(2622),
    [sym_preproc_nullable] = STATE(2622),
    [sym_preproc_error] = STATE(2622),
    [sym_preproc_warning] = STATE(2622),
    [sym_preproc_define] = STATE(2622),
    [sym_preproc_undef] = STATE(2622),
    [ts_builtin_sym_end] = ACTIONS(3415),
    [sym__identifier_token] = ACTIONS(3413),
    [anon_sym_extern] = ACTIONS(3413),
    [anon_sym_alias] = ACTIONS(3413),
    [anon_sym_SEMI] = ACTIONS(3415),
    [anon_sym_global] = ACTIONS(3413),
    [anon_sym_using] = ACTIONS(3413),
    [anon_sym_unsafe] = ACTIONS(3413),
    [anon_sym_static] = ACTIONS(3413),
    [anon_sym_LBRACK] = ACTIONS(3415),
    [anon_sym_LPAREN] = ACTIONS(3415),
    [anon_sym_return] = ACTIONS(3413),
    [anon_sym_namespace] = ACTIONS(3413),
    [anon_sym_class] = ACTIONS(3413),
    [anon_sym_ref] = ACTIONS(3413),
    [anon_sym_struct] = ACTIONS(3413),
    [anon_sym_enum] = ACTIONS(3413),
    [anon_sym_LBRACE] = ACTIONS(3415),
    [anon_sym_interface] = ACTIONS(3413),
    [anon_sym_delegate] = ACTIONS(3413),
    [anon_sym_record] = ACTIONS(3413),
    [anon_sym_abstract] = ACTIONS(3413),
    [anon_sym_async] = ACTIONS(3413),
    [anon_sym_const] = ACTIONS(3413),
    [anon_sym_file] = ACTIONS(3413),
    [anon_sym_fixed] = ACTIONS(3413),
    [anon_sym_internal] = ACTIONS(3413),
    [anon_sym_new] = ACTIONS(3413),
    [anon_sym_override] = ACTIONS(3413),
    [anon_sym_partial] = ACTIONS(3413),
    [anon_sym_private] = ACTIONS(3413),
    [anon_sym_protected] = ACTIONS(3413),
    [anon_sym_public] = ACTIONS(3413),
    [anon_sym_readonly] = ACTIONS(3413),
    [anon_sym_required] = ACTIONS(3413),
    [anon_sym_sealed] = ACTIONS(3413),
    [anon_sym_virtual] = ACTIONS(3413),
    [anon_sym_volatile] = ACTIONS(3413),
    [anon_sym_where] = ACTIONS(3413),
    [anon_sym_notnull] = ACTIONS(3413),
    [anon_sym_unmanaged] = ACTIONS(3413),
    [anon_sym_checked] = ACTIONS(3413),
    [anon_sym_BANG] = ACTIONS(3415),
    [anon_sym_TILDE] = ACTIONS(3415),
    [anon_sym_PLUS_PLUS] = ACTIONS(3415),
    [anon_sym_DASH_DASH] = ACTIONS(3415),
    [anon_sym_true] = ACTIONS(3413),
    [anon_sym_false] = ACTIONS(3413),
    [anon_sym_PLUS] = ACTIONS(3413),
    [anon_sym_DASH] = ACTIONS(3413),
    [anon_sym_STAR] = ACTIONS(3415),
    [anon_sym_CARET] = ACTIONS(3415),
    [anon_sym_AMP] = ACTIONS(3415),
    [anon_sym_this] = ACTIONS(3413),
    [anon_sym_scoped] = ACTIONS(3413),
    [anon_sym_base] = ACTIONS(3413),
    [anon_sym_var] = ACTIONS(3413),
    [sym_predefined_type] = ACTIONS(3413),
    [anon_sym_break] = ACTIONS(3413),
    [anon_sym_unchecked] = ACTIONS(3413),
    [anon_sym_continue] = ACTIONS(3413),
    [anon_sym_do] = ACTIONS(3413),
    [anon_sym_while] = ACTIONS(3413),
    [anon_sym_for] = ACTIONS(3413),
    [anon_sym_lock] = ACTIONS(3413),
    [anon_sym_yield] = ACTIONS(3413),
    [anon_sym_switch] = ACTIONS(3413),
    [anon_sym_default] = ACTIONS(3413),
    [anon_sym_throw] = ACTIONS(3413),
    [anon_sym_try] = ACTIONS(3413),
    [anon_sym_when] = ACTIONS(3413),
    [anon_sym_await] = ACTIONS(3413),
    [anon_sym_foreach] = ACTIONS(3413),
    [anon_sym_goto] = ACTIONS(3413),
    [anon_sym_if] = ACTIONS(3413),
    [anon_sym_DOT_DOT] = ACTIONS(3415),
    [anon_sym_from] = ACTIONS(3413),
    [anon_sym_into] = ACTIONS(3413),
    [anon_sym_join] = ACTIONS(3413),
    [anon_sym_on] = ACTIONS(3413),
    [anon_sym_equals] = ACTIONS(3413),
    [anon_sym_let] = ACTIONS(3413),
    [anon_sym_orderby] = ACTIONS(3413),
    [anon_sym_ascending] = ACTIONS(3413),
    [anon_sym_descending] = ACTIONS(3413),
    [anon_sym_group] = ACTIONS(3413),
    [anon_sym_by] = ACTIONS(3413),
    [anon_sym_select] = ACTIONS(3413),
    [anon_sym_stackalloc] = ACTIONS(3413),
    [anon_sym_sizeof] = ACTIONS(3413),
    [anon_sym_typeof] = ACTIONS(3413),
    [anon_sym___makeref] = ACTIONS(3413),
    [anon_sym___reftype] = ACTIONS(3413),
    [anon_sym___refvalue] = ACTIONS(3413),
    [sym_null_literal] = ACTIONS(3413),
    [anon_sym_SQUOTE] = ACTIONS(3415),
    [sym_integer_literal] = ACTIONS(3413),
    [sym_real_literal] = ACTIONS(3415),
    [anon_sym_DQUOTE] = ACTIONS(3415),
    [sym_verbatim_string_literal] = ACTIONS(3415),
    [aux_sym_preproc_if_token1] = ACTIONS(3415),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3415),
    [sym_interpolation_verbatim_start] = ACTIONS(3415),
    [sym_interpolation_raw_start] = ACTIONS(3415),
    [sym_raw_string_start] = ACTIONS(3415),
  },
  [2623] = {
    [sym_preproc_region] = STATE(2623),
    [sym_preproc_endregion] = STATE(2623),
    [sym_preproc_line] = STATE(2623),
    [sym_preproc_pragma] = STATE(2623),
    [sym_preproc_nullable] = STATE(2623),
    [sym_preproc_error] = STATE(2623),
    [sym_preproc_warning] = STATE(2623),
    [sym_preproc_define] = STATE(2623),
    [sym_preproc_undef] = STATE(2623),
    [ts_builtin_sym_end] = ACTIONS(3687),
    [sym__identifier_token] = ACTIONS(3685),
    [anon_sym_extern] = ACTIONS(3685),
    [anon_sym_alias] = ACTIONS(3685),
    [anon_sym_SEMI] = ACTIONS(3687),
    [anon_sym_global] = ACTIONS(3685),
    [anon_sym_using] = ACTIONS(3685),
    [anon_sym_unsafe] = ACTIONS(3685),
    [anon_sym_static] = ACTIONS(3685),
    [anon_sym_LBRACK] = ACTIONS(3687),
    [anon_sym_LPAREN] = ACTIONS(3687),
    [anon_sym_return] = ACTIONS(3685),
    [anon_sym_namespace] = ACTIONS(3685),
    [anon_sym_class] = ACTIONS(3685),
    [anon_sym_ref] = ACTIONS(3685),
    [anon_sym_struct] = ACTIONS(3685),
    [anon_sym_enum] = ACTIONS(3685),
    [anon_sym_LBRACE] = ACTIONS(3687),
    [anon_sym_interface] = ACTIONS(3685),
    [anon_sym_delegate] = ACTIONS(3685),
    [anon_sym_record] = ACTIONS(3685),
    [anon_sym_abstract] = ACTIONS(3685),
    [anon_sym_async] = ACTIONS(3685),
    [anon_sym_const] = ACTIONS(3685),
    [anon_sym_file] = ACTIONS(3685),
    [anon_sym_fixed] = ACTIONS(3685),
    [anon_sym_internal] = ACTIONS(3685),
    [anon_sym_new] = ACTIONS(3685),
    [anon_sym_override] = ACTIONS(3685),
    [anon_sym_partial] = ACTIONS(3685),
    [anon_sym_private] = ACTIONS(3685),
    [anon_sym_protected] = ACTIONS(3685),
    [anon_sym_public] = ACTIONS(3685),
    [anon_sym_readonly] = ACTIONS(3685),
    [anon_sym_required] = ACTIONS(3685),
    [anon_sym_sealed] = ACTIONS(3685),
    [anon_sym_virtual] = ACTIONS(3685),
    [anon_sym_volatile] = ACTIONS(3685),
    [anon_sym_where] = ACTIONS(3685),
    [anon_sym_notnull] = ACTIONS(3685),
    [anon_sym_unmanaged] = ACTIONS(3685),
    [anon_sym_checked] = ACTIONS(3685),
    [anon_sym_BANG] = ACTIONS(3687),
    [anon_sym_TILDE] = ACTIONS(3687),
    [anon_sym_PLUS_PLUS] = ACTIONS(3687),
    [anon_sym_DASH_DASH] = ACTIONS(3687),
    [anon_sym_true] = ACTIONS(3685),
    [anon_sym_false] = ACTIONS(3685),
    [anon_sym_PLUS] = ACTIONS(3685),
    [anon_sym_DASH] = ACTIONS(3685),
    [anon_sym_STAR] = ACTIONS(3687),
    [anon_sym_CARET] = ACTIONS(3687),
    [anon_sym_AMP] = ACTIONS(3687),
    [anon_sym_this] = ACTIONS(3685),
    [anon_sym_scoped] = ACTIONS(3685),
    [anon_sym_base] = ACTIONS(3685),
    [anon_sym_var] = ACTIONS(3685),
    [sym_predefined_type] = ACTIONS(3685),
    [anon_sym_break] = ACTIONS(3685),
    [anon_sym_unchecked] = ACTIONS(3685),
    [anon_sym_continue] = ACTIONS(3685),
    [anon_sym_do] = ACTIONS(3685),
    [anon_sym_while] = ACTIONS(3685),
    [anon_sym_for] = ACTIONS(3685),
    [anon_sym_lock] = ACTIONS(3685),
    [anon_sym_yield] = ACTIONS(3685),
    [anon_sym_switch] = ACTIONS(3685),
    [anon_sym_default] = ACTIONS(3685),
    [anon_sym_throw] = ACTIONS(3685),
    [anon_sym_try] = ACTIONS(3685),
    [anon_sym_when] = ACTIONS(3685),
    [anon_sym_await] = ACTIONS(3685),
    [anon_sym_foreach] = ACTIONS(3685),
    [anon_sym_goto] = ACTIONS(3685),
    [anon_sym_if] = ACTIONS(3685),
    [anon_sym_DOT_DOT] = ACTIONS(3687),
    [anon_sym_from] = ACTIONS(3685),
    [anon_sym_into] = ACTIONS(3685),
    [anon_sym_join] = ACTIONS(3685),
    [anon_sym_on] = ACTIONS(3685),
    [anon_sym_equals] = ACTIONS(3685),
    [anon_sym_let] = ACTIONS(3685),
    [anon_sym_orderby] = ACTIONS(3685),
    [anon_sym_ascending] = ACTIONS(3685),
    [anon_sym_descending] = ACTIONS(3685),
    [anon_sym_group] = ACTIONS(3685),
    [anon_sym_by] = ACTIONS(3685),
    [anon_sym_select] = ACTIONS(3685),
    [anon_sym_stackalloc] = ACTIONS(3685),
    [anon_sym_sizeof] = ACTIONS(3685),
    [anon_sym_typeof] = ACTIONS(3685),
    [anon_sym___makeref] = ACTIONS(3685),
    [anon_sym___reftype] = ACTIONS(3685),
    [anon_sym___refvalue] = ACTIONS(3685),
    [sym_null_literal] = ACTIONS(3685),
    [anon_sym_SQUOTE] = ACTIONS(3687),
    [sym_integer_literal] = ACTIONS(3685),
    [sym_real_literal] = ACTIONS(3687),
    [anon_sym_DQUOTE] = ACTIONS(3687),
    [sym_verbatim_string_literal] = ACTIONS(3687),
    [aux_sym_preproc_if_token1] = ACTIONS(3687),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3687),
    [sym_interpolation_verbatim_start] = ACTIONS(3687),
    [sym_interpolation_raw_start] = ACTIONS(3687),
    [sym_raw_string_start] = ACTIONS(3687),
  },
  [2624] = {
    [sym_preproc_region] = STATE(2624),
    [sym_preproc_endregion] = STATE(2624),
    [sym_preproc_line] = STATE(2624),
    [sym_preproc_pragma] = STATE(2624),
    [sym_preproc_nullable] = STATE(2624),
    [sym_preproc_error] = STATE(2624),
    [sym_preproc_warning] = STATE(2624),
    [sym_preproc_define] = STATE(2624),
    [sym_preproc_undef] = STATE(2624),
    [ts_builtin_sym_end] = ACTIONS(3691),
    [sym__identifier_token] = ACTIONS(3689),
    [anon_sym_extern] = ACTIONS(3689),
    [anon_sym_alias] = ACTIONS(3689),
    [anon_sym_SEMI] = ACTIONS(3691),
    [anon_sym_global] = ACTIONS(3689),
    [anon_sym_using] = ACTIONS(3689),
    [anon_sym_unsafe] = ACTIONS(3689),
    [anon_sym_static] = ACTIONS(3689),
    [anon_sym_LBRACK] = ACTIONS(3691),
    [anon_sym_LPAREN] = ACTIONS(3691),
    [anon_sym_return] = ACTIONS(3689),
    [anon_sym_namespace] = ACTIONS(3689),
    [anon_sym_class] = ACTIONS(3689),
    [anon_sym_ref] = ACTIONS(3689),
    [anon_sym_struct] = ACTIONS(3689),
    [anon_sym_enum] = ACTIONS(3689),
    [anon_sym_LBRACE] = ACTIONS(3691),
    [anon_sym_interface] = ACTIONS(3689),
    [anon_sym_delegate] = ACTIONS(3689),
    [anon_sym_record] = ACTIONS(3689),
    [anon_sym_abstract] = ACTIONS(3689),
    [anon_sym_async] = ACTIONS(3689),
    [anon_sym_const] = ACTIONS(3689),
    [anon_sym_file] = ACTIONS(3689),
    [anon_sym_fixed] = ACTIONS(3689),
    [anon_sym_internal] = ACTIONS(3689),
    [anon_sym_new] = ACTIONS(3689),
    [anon_sym_override] = ACTIONS(3689),
    [anon_sym_partial] = ACTIONS(3689),
    [anon_sym_private] = ACTIONS(3689),
    [anon_sym_protected] = ACTIONS(3689),
    [anon_sym_public] = ACTIONS(3689),
    [anon_sym_readonly] = ACTIONS(3689),
    [anon_sym_required] = ACTIONS(3689),
    [anon_sym_sealed] = ACTIONS(3689),
    [anon_sym_virtual] = ACTIONS(3689),
    [anon_sym_volatile] = ACTIONS(3689),
    [anon_sym_where] = ACTIONS(3689),
    [anon_sym_notnull] = ACTIONS(3689),
    [anon_sym_unmanaged] = ACTIONS(3689),
    [anon_sym_checked] = ACTIONS(3689),
    [anon_sym_BANG] = ACTIONS(3691),
    [anon_sym_TILDE] = ACTIONS(3691),
    [anon_sym_PLUS_PLUS] = ACTIONS(3691),
    [anon_sym_DASH_DASH] = ACTIONS(3691),
    [anon_sym_true] = ACTIONS(3689),
    [anon_sym_false] = ACTIONS(3689),
    [anon_sym_PLUS] = ACTIONS(3689),
    [anon_sym_DASH] = ACTIONS(3689),
    [anon_sym_STAR] = ACTIONS(3691),
    [anon_sym_CARET] = ACTIONS(3691),
    [anon_sym_AMP] = ACTIONS(3691),
    [anon_sym_this] = ACTIONS(3689),
    [anon_sym_scoped] = ACTIONS(3689),
    [anon_sym_base] = ACTIONS(3689),
    [anon_sym_var] = ACTIONS(3689),
    [sym_predefined_type] = ACTIONS(3689),
    [anon_sym_break] = ACTIONS(3689),
    [anon_sym_unchecked] = ACTIONS(3689),
    [anon_sym_continue] = ACTIONS(3689),
    [anon_sym_do] = ACTIONS(3689),
    [anon_sym_while] = ACTIONS(3689),
    [anon_sym_for] = ACTIONS(3689),
    [anon_sym_lock] = ACTIONS(3689),
    [anon_sym_yield] = ACTIONS(3689),
    [anon_sym_switch] = ACTIONS(3689),
    [anon_sym_default] = ACTIONS(3689),
    [anon_sym_throw] = ACTIONS(3689),
    [anon_sym_try] = ACTIONS(3689),
    [anon_sym_when] = ACTIONS(3689),
    [anon_sym_await] = ACTIONS(3689),
    [anon_sym_foreach] = ACTIONS(3689),
    [anon_sym_goto] = ACTIONS(3689),
    [anon_sym_if] = ACTIONS(3689),
    [anon_sym_DOT_DOT] = ACTIONS(3691),
    [anon_sym_from] = ACTIONS(3689),
    [anon_sym_into] = ACTIONS(3689),
    [anon_sym_join] = ACTIONS(3689),
    [anon_sym_on] = ACTIONS(3689),
    [anon_sym_equals] = ACTIONS(3689),
    [anon_sym_let] = ACTIONS(3689),
    [anon_sym_orderby] = ACTIONS(3689),
    [anon_sym_ascending] = ACTIONS(3689),
    [anon_sym_descending] = ACTIONS(3689),
    [anon_sym_group] = ACTIONS(3689),
    [anon_sym_by] = ACTIONS(3689),
    [anon_sym_select] = ACTIONS(3689),
    [anon_sym_stackalloc] = ACTIONS(3689),
    [anon_sym_sizeof] = ACTIONS(3689),
    [anon_sym_typeof] = ACTIONS(3689),
    [anon_sym___makeref] = ACTIONS(3689),
    [anon_sym___reftype] = ACTIONS(3689),
    [anon_sym___refvalue] = ACTIONS(3689),
    [sym_null_literal] = ACTIONS(3689),
    [anon_sym_SQUOTE] = ACTIONS(3691),
    [sym_integer_literal] = ACTIONS(3689),
    [sym_real_literal] = ACTIONS(3691),
    [anon_sym_DQUOTE] = ACTIONS(3691),
    [sym_verbatim_string_literal] = ACTIONS(3691),
    [aux_sym_preproc_if_token1] = ACTIONS(3691),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3691),
    [sym_interpolation_verbatim_start] = ACTIONS(3691),
    [sym_interpolation_raw_start] = ACTIONS(3691),
    [sym_raw_string_start] = ACTIONS(3691),
  },
  [2625] = {
    [sym_preproc_region] = STATE(2625),
    [sym_preproc_endregion] = STATE(2625),
    [sym_preproc_line] = STATE(2625),
    [sym_preproc_pragma] = STATE(2625),
    [sym_preproc_nullable] = STATE(2625),
    [sym_preproc_error] = STATE(2625),
    [sym_preproc_warning] = STATE(2625),
    [sym_preproc_define] = STATE(2625),
    [sym_preproc_undef] = STATE(2625),
    [ts_builtin_sym_end] = ACTIONS(3695),
    [sym__identifier_token] = ACTIONS(3693),
    [anon_sym_extern] = ACTIONS(3693),
    [anon_sym_alias] = ACTIONS(3693),
    [anon_sym_SEMI] = ACTIONS(3695),
    [anon_sym_global] = ACTIONS(3693),
    [anon_sym_using] = ACTIONS(3693),
    [anon_sym_unsafe] = ACTIONS(3693),
    [anon_sym_static] = ACTIONS(3693),
    [anon_sym_LBRACK] = ACTIONS(3695),
    [anon_sym_LPAREN] = ACTIONS(3695),
    [anon_sym_return] = ACTIONS(3693),
    [anon_sym_namespace] = ACTIONS(3693),
    [anon_sym_class] = ACTIONS(3693),
    [anon_sym_ref] = ACTIONS(3693),
    [anon_sym_struct] = ACTIONS(3693),
    [anon_sym_enum] = ACTIONS(3693),
    [anon_sym_LBRACE] = ACTIONS(3695),
    [anon_sym_interface] = ACTIONS(3693),
    [anon_sym_delegate] = ACTIONS(3693),
    [anon_sym_record] = ACTIONS(3693),
    [anon_sym_abstract] = ACTIONS(3693),
    [anon_sym_async] = ACTIONS(3693),
    [anon_sym_const] = ACTIONS(3693),
    [anon_sym_file] = ACTIONS(3693),
    [anon_sym_fixed] = ACTIONS(3693),
    [anon_sym_internal] = ACTIONS(3693),
    [anon_sym_new] = ACTIONS(3693),
    [anon_sym_override] = ACTIONS(3693),
    [anon_sym_partial] = ACTIONS(3693),
    [anon_sym_private] = ACTIONS(3693),
    [anon_sym_protected] = ACTIONS(3693),
    [anon_sym_public] = ACTIONS(3693),
    [anon_sym_readonly] = ACTIONS(3693),
    [anon_sym_required] = ACTIONS(3693),
    [anon_sym_sealed] = ACTIONS(3693),
    [anon_sym_virtual] = ACTIONS(3693),
    [anon_sym_volatile] = ACTIONS(3693),
    [anon_sym_where] = ACTIONS(3693),
    [anon_sym_notnull] = ACTIONS(3693),
    [anon_sym_unmanaged] = ACTIONS(3693),
    [anon_sym_checked] = ACTIONS(3693),
    [anon_sym_BANG] = ACTIONS(3695),
    [anon_sym_TILDE] = ACTIONS(3695),
    [anon_sym_PLUS_PLUS] = ACTIONS(3695),
    [anon_sym_DASH_DASH] = ACTIONS(3695),
    [anon_sym_true] = ACTIONS(3693),
    [anon_sym_false] = ACTIONS(3693),
    [anon_sym_PLUS] = ACTIONS(3693),
    [anon_sym_DASH] = ACTIONS(3693),
    [anon_sym_STAR] = ACTIONS(3695),
    [anon_sym_CARET] = ACTIONS(3695),
    [anon_sym_AMP] = ACTIONS(3695),
    [anon_sym_this] = ACTIONS(3693),
    [anon_sym_scoped] = ACTIONS(3693),
    [anon_sym_base] = ACTIONS(3693),
    [anon_sym_var] = ACTIONS(3693),
    [sym_predefined_type] = ACTIONS(3693),
    [anon_sym_break] = ACTIONS(3693),
    [anon_sym_unchecked] = ACTIONS(3693),
    [anon_sym_continue] = ACTIONS(3693),
    [anon_sym_do] = ACTIONS(3693),
    [anon_sym_while] = ACTIONS(3693),
    [anon_sym_for] = ACTIONS(3693),
    [anon_sym_lock] = ACTIONS(3693),
    [anon_sym_yield] = ACTIONS(3693),
    [anon_sym_switch] = ACTIONS(3693),
    [anon_sym_default] = ACTIONS(3693),
    [anon_sym_throw] = ACTIONS(3693),
    [anon_sym_try] = ACTIONS(3693),
    [anon_sym_when] = ACTIONS(3693),
    [anon_sym_await] = ACTIONS(3693),
    [anon_sym_foreach] = ACTIONS(3693),
    [anon_sym_goto] = ACTIONS(3693),
    [anon_sym_if] = ACTIONS(3693),
    [anon_sym_DOT_DOT] = ACTIONS(3695),
    [anon_sym_from] = ACTIONS(3693),
    [anon_sym_into] = ACTIONS(3693),
    [anon_sym_join] = ACTIONS(3693),
    [anon_sym_on] = ACTIONS(3693),
    [anon_sym_equals] = ACTIONS(3693),
    [anon_sym_let] = ACTIONS(3693),
    [anon_sym_orderby] = ACTIONS(3693),
    [anon_sym_ascending] = ACTIONS(3693),
    [anon_sym_descending] = ACTIONS(3693),
    [anon_sym_group] = ACTIONS(3693),
    [anon_sym_by] = ACTIONS(3693),
    [anon_sym_select] = ACTIONS(3693),
    [anon_sym_stackalloc] = ACTIONS(3693),
    [anon_sym_sizeof] = ACTIONS(3693),
    [anon_sym_typeof] = ACTIONS(3693),
    [anon_sym___makeref] = ACTIONS(3693),
    [anon_sym___reftype] = ACTIONS(3693),
    [anon_sym___refvalue] = ACTIONS(3693),
    [sym_null_literal] = ACTIONS(3693),
    [anon_sym_SQUOTE] = ACTIONS(3695),
    [sym_integer_literal] = ACTIONS(3693),
    [sym_real_literal] = ACTIONS(3695),
    [anon_sym_DQUOTE] = ACTIONS(3695),
    [sym_verbatim_string_literal] = ACTIONS(3695),
    [aux_sym_preproc_if_token1] = ACTIONS(3695),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3695),
    [sym_interpolation_verbatim_start] = ACTIONS(3695),
    [sym_interpolation_raw_start] = ACTIONS(3695),
    [sym_raw_string_start] = ACTIONS(3695),
  },
  [2626] = {
    [sym_catch_clause] = STATE(2648),
    [sym_preproc_region] = STATE(2626),
    [sym_preproc_endregion] = STATE(2626),
    [sym_preproc_line] = STATE(2626),
    [sym_preproc_pragma] = STATE(2626),
    [sym_preproc_nullable] = STATE(2626),
    [sym_preproc_error] = STATE(2626),
    [sym_preproc_warning] = STATE(2626),
    [sym_preproc_define] = STATE(2626),
    [sym_preproc_undef] = STATE(2626),
    [aux_sym_try_statement_repeat1] = STATE(2626),
    [sym__identifier_token] = ACTIONS(3015),
    [anon_sym_extern] = ACTIONS(3015),
    [anon_sym_alias] = ACTIONS(3015),
    [anon_sym_SEMI] = ACTIONS(3017),
    [anon_sym_global] = ACTIONS(3015),
    [anon_sym_using] = ACTIONS(3015),
    [anon_sym_unsafe] = ACTIONS(3015),
    [anon_sym_static] = ACTIONS(3015),
    [anon_sym_LBRACK] = ACTIONS(3017),
    [anon_sym_LPAREN] = ACTIONS(3017),
    [anon_sym_return] = ACTIONS(3015),
    [anon_sym_ref] = ACTIONS(3015),
    [anon_sym_LBRACE] = ACTIONS(3017),
    [anon_sym_RBRACE] = ACTIONS(3017),
    [anon_sym_delegate] = ACTIONS(3015),
    [anon_sym_abstract] = ACTIONS(3015),
    [anon_sym_async] = ACTIONS(3015),
    [anon_sym_const] = ACTIONS(3015),
    [anon_sym_file] = ACTIONS(3015),
    [anon_sym_fixed] = ACTIONS(3015),
    [anon_sym_internal] = ACTIONS(3015),
    [anon_sym_new] = ACTIONS(3015),
    [anon_sym_override] = ACTIONS(3015),
    [anon_sym_partial] = ACTIONS(3015),
    [anon_sym_private] = ACTIONS(3015),
    [anon_sym_protected] = ACTIONS(3015),
    [anon_sym_public] = ACTIONS(3015),
    [anon_sym_readonly] = ACTIONS(3015),
    [anon_sym_required] = ACTIONS(3015),
    [anon_sym_sealed] = ACTIONS(3015),
    [anon_sym_virtual] = ACTIONS(3015),
    [anon_sym_volatile] = ACTIONS(3015),
    [anon_sym_where] = ACTIONS(3015),
    [anon_sym_notnull] = ACTIONS(3015),
    [anon_sym_unmanaged] = ACTIONS(3015),
    [anon_sym_checked] = ACTIONS(3015),
    [anon_sym_BANG] = ACTIONS(3017),
    [anon_sym_TILDE] = ACTIONS(3017),
    [anon_sym_PLUS_PLUS] = ACTIONS(3017),
    [anon_sym_DASH_DASH] = ACTIONS(3017),
    [anon_sym_true] = ACTIONS(3015),
    [anon_sym_false] = ACTIONS(3015),
    [anon_sym_PLUS] = ACTIONS(3015),
    [anon_sym_DASH] = ACTIONS(3015),
    [anon_sym_STAR] = ACTIONS(3017),
    [anon_sym_CARET] = ACTIONS(3017),
    [anon_sym_AMP] = ACTIONS(3017),
    [anon_sym_this] = ACTIONS(3015),
    [anon_sym_scoped] = ACTIONS(3015),
    [anon_sym_base] = ACTIONS(3015),
    [anon_sym_var] = ACTIONS(3015),
    [sym_predefined_type] = ACTIONS(3015),
    [anon_sym_break] = ACTIONS(3015),
    [anon_sym_unchecked] = ACTIONS(3015),
    [anon_sym_continue] = ACTIONS(3015),
    [anon_sym_do] = ACTIONS(3015),
    [anon_sym_while] = ACTIONS(3015),
    [anon_sym_for] = ACTIONS(3015),
    [anon_sym_lock] = ACTIONS(3015),
    [anon_sym_yield] = ACTIONS(3015),
    [anon_sym_switch] = ACTIONS(3015),
    [anon_sym_case] = ACTIONS(3015),
    [anon_sym_default] = ACTIONS(3015),
    [anon_sym_throw] = ACTIONS(3015),
    [anon_sym_try] = ACTIONS(3015),
    [anon_sym_catch] = ACTIONS(4024),
    [anon_sym_when] = ACTIONS(3015),
    [anon_sym_finally] = ACTIONS(3015),
    [anon_sym_await] = ACTIONS(3015),
    [anon_sym_foreach] = ACTIONS(3015),
    [anon_sym_goto] = ACTIONS(3015),
    [anon_sym_if] = ACTIONS(3015),
    [anon_sym_else] = ACTIONS(3015),
    [anon_sym_DOT_DOT] = ACTIONS(3017),
    [anon_sym_from] = ACTIONS(3015),
    [anon_sym_into] = ACTIONS(3015),
    [anon_sym_join] = ACTIONS(3015),
    [anon_sym_on] = ACTIONS(3015),
    [anon_sym_equals] = ACTIONS(3015),
    [anon_sym_let] = ACTIONS(3015),
    [anon_sym_orderby] = ACTIONS(3015),
    [anon_sym_ascending] = ACTIONS(3015),
    [anon_sym_descending] = ACTIONS(3015),
    [anon_sym_group] = ACTIONS(3015),
    [anon_sym_by] = ACTIONS(3015),
    [anon_sym_select] = ACTIONS(3015),
    [anon_sym_stackalloc] = ACTIONS(3015),
    [anon_sym_sizeof] = ACTIONS(3015),
    [anon_sym_typeof] = ACTIONS(3015),
    [anon_sym___makeref] = ACTIONS(3015),
    [anon_sym___reftype] = ACTIONS(3015),
    [anon_sym___refvalue] = ACTIONS(3015),
    [sym_null_literal] = ACTIONS(3015),
    [anon_sym_SQUOTE] = ACTIONS(3017),
    [sym_integer_literal] = ACTIONS(3015),
    [sym_real_literal] = ACTIONS(3017),
    [anon_sym_DQUOTE] = ACTIONS(3017),
    [sym_verbatim_string_literal] = ACTIONS(3017),
    [aux_sym_preproc_if_token1] = ACTIONS(3017),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3017),
    [sym_interpolation_verbatim_start] = ACTIONS(3017),
    [sym_interpolation_raw_start] = ACTIONS(3017),
    [sym_raw_string_start] = ACTIONS(3017),
  },
  [2627] = {
    [sym_preproc_region] = STATE(2627),
    [sym_preproc_endregion] = STATE(2627),
    [sym_preproc_line] = STATE(2627),
    [sym_preproc_pragma] = STATE(2627),
    [sym_preproc_nullable] = STATE(2627),
    [sym_preproc_error] = STATE(2627),
    [sym_preproc_warning] = STATE(2627),
    [sym_preproc_define] = STATE(2627),
    [sym_preproc_undef] = STATE(2627),
    [ts_builtin_sym_end] = ACTIONS(3699),
    [sym__identifier_token] = ACTIONS(3697),
    [anon_sym_extern] = ACTIONS(3697),
    [anon_sym_alias] = ACTIONS(3697),
    [anon_sym_SEMI] = ACTIONS(3699),
    [anon_sym_global] = ACTIONS(3697),
    [anon_sym_using] = ACTIONS(3697),
    [anon_sym_unsafe] = ACTIONS(3697),
    [anon_sym_static] = ACTIONS(3697),
    [anon_sym_LBRACK] = ACTIONS(3699),
    [anon_sym_LPAREN] = ACTIONS(3699),
    [anon_sym_return] = ACTIONS(3697),
    [anon_sym_namespace] = ACTIONS(3697),
    [anon_sym_class] = ACTIONS(3697),
    [anon_sym_ref] = ACTIONS(3697),
    [anon_sym_struct] = ACTIONS(3697),
    [anon_sym_enum] = ACTIONS(3697),
    [anon_sym_LBRACE] = ACTIONS(3699),
    [anon_sym_interface] = ACTIONS(3697),
    [anon_sym_delegate] = ACTIONS(3697),
    [anon_sym_record] = ACTIONS(3697),
    [anon_sym_abstract] = ACTIONS(3697),
    [anon_sym_async] = ACTIONS(3697),
    [anon_sym_const] = ACTIONS(3697),
    [anon_sym_file] = ACTIONS(3697),
    [anon_sym_fixed] = ACTIONS(3697),
    [anon_sym_internal] = ACTIONS(3697),
    [anon_sym_new] = ACTIONS(3697),
    [anon_sym_override] = ACTIONS(3697),
    [anon_sym_partial] = ACTIONS(3697),
    [anon_sym_private] = ACTIONS(3697),
    [anon_sym_protected] = ACTIONS(3697),
    [anon_sym_public] = ACTIONS(3697),
    [anon_sym_readonly] = ACTIONS(3697),
    [anon_sym_required] = ACTIONS(3697),
    [anon_sym_sealed] = ACTIONS(3697),
    [anon_sym_virtual] = ACTIONS(3697),
    [anon_sym_volatile] = ACTIONS(3697),
    [anon_sym_where] = ACTIONS(3697),
    [anon_sym_notnull] = ACTIONS(3697),
    [anon_sym_unmanaged] = ACTIONS(3697),
    [anon_sym_checked] = ACTIONS(3697),
    [anon_sym_BANG] = ACTIONS(3699),
    [anon_sym_TILDE] = ACTIONS(3699),
    [anon_sym_PLUS_PLUS] = ACTIONS(3699),
    [anon_sym_DASH_DASH] = ACTIONS(3699),
    [anon_sym_true] = ACTIONS(3697),
    [anon_sym_false] = ACTIONS(3697),
    [anon_sym_PLUS] = ACTIONS(3697),
    [anon_sym_DASH] = ACTIONS(3697),
    [anon_sym_STAR] = ACTIONS(3699),
    [anon_sym_CARET] = ACTIONS(3699),
    [anon_sym_AMP] = ACTIONS(3699),
    [anon_sym_this] = ACTIONS(3697),
    [anon_sym_scoped] = ACTIONS(3697),
    [anon_sym_base] = ACTIONS(3697),
    [anon_sym_var] = ACTIONS(3697),
    [sym_predefined_type] = ACTIONS(3697),
    [anon_sym_break] = ACTIONS(3697),
    [anon_sym_unchecked] = ACTIONS(3697),
    [anon_sym_continue] = ACTIONS(3697),
    [anon_sym_do] = ACTIONS(3697),
    [anon_sym_while] = ACTIONS(3697),
    [anon_sym_for] = ACTIONS(3697),
    [anon_sym_lock] = ACTIONS(3697),
    [anon_sym_yield] = ACTIONS(3697),
    [anon_sym_switch] = ACTIONS(3697),
    [anon_sym_default] = ACTIONS(3697),
    [anon_sym_throw] = ACTIONS(3697),
    [anon_sym_try] = ACTIONS(3697),
    [anon_sym_when] = ACTIONS(3697),
    [anon_sym_await] = ACTIONS(3697),
    [anon_sym_foreach] = ACTIONS(3697),
    [anon_sym_goto] = ACTIONS(3697),
    [anon_sym_if] = ACTIONS(3697),
    [anon_sym_DOT_DOT] = ACTIONS(3699),
    [anon_sym_from] = ACTIONS(3697),
    [anon_sym_into] = ACTIONS(3697),
    [anon_sym_join] = ACTIONS(3697),
    [anon_sym_on] = ACTIONS(3697),
    [anon_sym_equals] = ACTIONS(3697),
    [anon_sym_let] = ACTIONS(3697),
    [anon_sym_orderby] = ACTIONS(3697),
    [anon_sym_ascending] = ACTIONS(3697),
    [anon_sym_descending] = ACTIONS(3697),
    [anon_sym_group] = ACTIONS(3697),
    [anon_sym_by] = ACTIONS(3697),
    [anon_sym_select] = ACTIONS(3697),
    [anon_sym_stackalloc] = ACTIONS(3697),
    [anon_sym_sizeof] = ACTIONS(3697),
    [anon_sym_typeof] = ACTIONS(3697),
    [anon_sym___makeref] = ACTIONS(3697),
    [anon_sym___reftype] = ACTIONS(3697),
    [anon_sym___refvalue] = ACTIONS(3697),
    [sym_null_literal] = ACTIONS(3697),
    [anon_sym_SQUOTE] = ACTIONS(3699),
    [sym_integer_literal] = ACTIONS(3697),
    [sym_real_literal] = ACTIONS(3699),
    [anon_sym_DQUOTE] = ACTIONS(3699),
    [sym_verbatim_string_literal] = ACTIONS(3699),
    [aux_sym_preproc_if_token1] = ACTIONS(3699),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3699),
    [sym_interpolation_verbatim_start] = ACTIONS(3699),
    [sym_interpolation_raw_start] = ACTIONS(3699),
    [sym_raw_string_start] = ACTIONS(3699),
  },
  [2628] = {
    [sym_preproc_region] = STATE(2628),
    [sym_preproc_endregion] = STATE(2628),
    [sym_preproc_line] = STATE(2628),
    [sym_preproc_pragma] = STATE(2628),
    [sym_preproc_nullable] = STATE(2628),
    [sym_preproc_error] = STATE(2628),
    [sym_preproc_warning] = STATE(2628),
    [sym_preproc_define] = STATE(2628),
    [sym_preproc_undef] = STATE(2628),
    [ts_builtin_sym_end] = ACTIONS(3703),
    [sym__identifier_token] = ACTIONS(3701),
    [anon_sym_extern] = ACTIONS(3701),
    [anon_sym_alias] = ACTIONS(3701),
    [anon_sym_SEMI] = ACTIONS(3703),
    [anon_sym_global] = ACTIONS(3701),
    [anon_sym_using] = ACTIONS(3701),
    [anon_sym_unsafe] = ACTIONS(3701),
    [anon_sym_static] = ACTIONS(3701),
    [anon_sym_LBRACK] = ACTIONS(3703),
    [anon_sym_LPAREN] = ACTIONS(3703),
    [anon_sym_return] = ACTIONS(3701),
    [anon_sym_namespace] = ACTIONS(3701),
    [anon_sym_class] = ACTIONS(3701),
    [anon_sym_ref] = ACTIONS(3701),
    [anon_sym_struct] = ACTIONS(3701),
    [anon_sym_enum] = ACTIONS(3701),
    [anon_sym_LBRACE] = ACTIONS(3703),
    [anon_sym_interface] = ACTIONS(3701),
    [anon_sym_delegate] = ACTIONS(3701),
    [anon_sym_record] = ACTIONS(3701),
    [anon_sym_abstract] = ACTIONS(3701),
    [anon_sym_async] = ACTIONS(3701),
    [anon_sym_const] = ACTIONS(3701),
    [anon_sym_file] = ACTIONS(3701),
    [anon_sym_fixed] = ACTIONS(3701),
    [anon_sym_internal] = ACTIONS(3701),
    [anon_sym_new] = ACTIONS(3701),
    [anon_sym_override] = ACTIONS(3701),
    [anon_sym_partial] = ACTIONS(3701),
    [anon_sym_private] = ACTIONS(3701),
    [anon_sym_protected] = ACTIONS(3701),
    [anon_sym_public] = ACTIONS(3701),
    [anon_sym_readonly] = ACTIONS(3701),
    [anon_sym_required] = ACTIONS(3701),
    [anon_sym_sealed] = ACTIONS(3701),
    [anon_sym_virtual] = ACTIONS(3701),
    [anon_sym_volatile] = ACTIONS(3701),
    [anon_sym_where] = ACTIONS(3701),
    [anon_sym_notnull] = ACTIONS(3701),
    [anon_sym_unmanaged] = ACTIONS(3701),
    [anon_sym_checked] = ACTIONS(3701),
    [anon_sym_BANG] = ACTIONS(3703),
    [anon_sym_TILDE] = ACTIONS(3703),
    [anon_sym_PLUS_PLUS] = ACTIONS(3703),
    [anon_sym_DASH_DASH] = ACTIONS(3703),
    [anon_sym_true] = ACTIONS(3701),
    [anon_sym_false] = ACTIONS(3701),
    [anon_sym_PLUS] = ACTIONS(3701),
    [anon_sym_DASH] = ACTIONS(3701),
    [anon_sym_STAR] = ACTIONS(3703),
    [anon_sym_CARET] = ACTIONS(3703),
    [anon_sym_AMP] = ACTIONS(3703),
    [anon_sym_this] = ACTIONS(3701),
    [anon_sym_scoped] = ACTIONS(3701),
    [anon_sym_base] = ACTIONS(3701),
    [anon_sym_var] = ACTIONS(3701),
    [sym_predefined_type] = ACTIONS(3701),
    [anon_sym_break] = ACTIONS(3701),
    [anon_sym_unchecked] = ACTIONS(3701),
    [anon_sym_continue] = ACTIONS(3701),
    [anon_sym_do] = ACTIONS(3701),
    [anon_sym_while] = ACTIONS(3701),
    [anon_sym_for] = ACTIONS(3701),
    [anon_sym_lock] = ACTIONS(3701),
    [anon_sym_yield] = ACTIONS(3701),
    [anon_sym_switch] = ACTIONS(3701),
    [anon_sym_default] = ACTIONS(3701),
    [anon_sym_throw] = ACTIONS(3701),
    [anon_sym_try] = ACTIONS(3701),
    [anon_sym_when] = ACTIONS(3701),
    [anon_sym_await] = ACTIONS(3701),
    [anon_sym_foreach] = ACTIONS(3701),
    [anon_sym_goto] = ACTIONS(3701),
    [anon_sym_if] = ACTIONS(3701),
    [anon_sym_DOT_DOT] = ACTIONS(3703),
    [anon_sym_from] = ACTIONS(3701),
    [anon_sym_into] = ACTIONS(3701),
    [anon_sym_join] = ACTIONS(3701),
    [anon_sym_on] = ACTIONS(3701),
    [anon_sym_equals] = ACTIONS(3701),
    [anon_sym_let] = ACTIONS(3701),
    [anon_sym_orderby] = ACTIONS(3701),
    [anon_sym_ascending] = ACTIONS(3701),
    [anon_sym_descending] = ACTIONS(3701),
    [anon_sym_group] = ACTIONS(3701),
    [anon_sym_by] = ACTIONS(3701),
    [anon_sym_select] = ACTIONS(3701),
    [anon_sym_stackalloc] = ACTIONS(3701),
    [anon_sym_sizeof] = ACTIONS(3701),
    [anon_sym_typeof] = ACTIONS(3701),
    [anon_sym___makeref] = ACTIONS(3701),
    [anon_sym___reftype] = ACTIONS(3701),
    [anon_sym___refvalue] = ACTIONS(3701),
    [sym_null_literal] = ACTIONS(3701),
    [anon_sym_SQUOTE] = ACTIONS(3703),
    [sym_integer_literal] = ACTIONS(3701),
    [sym_real_literal] = ACTIONS(3703),
    [anon_sym_DQUOTE] = ACTIONS(3703),
    [sym_verbatim_string_literal] = ACTIONS(3703),
    [aux_sym_preproc_if_token1] = ACTIONS(3703),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3703),
    [sym_interpolation_verbatim_start] = ACTIONS(3703),
    [sym_interpolation_raw_start] = ACTIONS(3703),
    [sym_raw_string_start] = ACTIONS(3703),
  },
  [2629] = {
    [sym_preproc_region] = STATE(2629),
    [sym_preproc_endregion] = STATE(2629),
    [sym_preproc_line] = STATE(2629),
    [sym_preproc_pragma] = STATE(2629),
    [sym_preproc_nullable] = STATE(2629),
    [sym_preproc_error] = STATE(2629),
    [sym_preproc_warning] = STATE(2629),
    [sym_preproc_define] = STATE(2629),
    [sym_preproc_undef] = STATE(2629),
    [ts_builtin_sym_end] = ACTIONS(3707),
    [sym__identifier_token] = ACTIONS(3705),
    [anon_sym_extern] = ACTIONS(3705),
    [anon_sym_alias] = ACTIONS(3705),
    [anon_sym_SEMI] = ACTIONS(3707),
    [anon_sym_global] = ACTIONS(3705),
    [anon_sym_using] = ACTIONS(3705),
    [anon_sym_unsafe] = ACTIONS(3705),
    [anon_sym_static] = ACTIONS(3705),
    [anon_sym_LBRACK] = ACTIONS(3707),
    [anon_sym_LPAREN] = ACTIONS(3707),
    [anon_sym_return] = ACTIONS(3705),
    [anon_sym_namespace] = ACTIONS(3705),
    [anon_sym_class] = ACTIONS(3705),
    [anon_sym_ref] = ACTIONS(3705),
    [anon_sym_struct] = ACTIONS(3705),
    [anon_sym_enum] = ACTIONS(3705),
    [anon_sym_LBRACE] = ACTIONS(3707),
    [anon_sym_interface] = ACTIONS(3705),
    [anon_sym_delegate] = ACTIONS(3705),
    [anon_sym_record] = ACTIONS(3705),
    [anon_sym_abstract] = ACTIONS(3705),
    [anon_sym_async] = ACTIONS(3705),
    [anon_sym_const] = ACTIONS(3705),
    [anon_sym_file] = ACTIONS(3705),
    [anon_sym_fixed] = ACTIONS(3705),
    [anon_sym_internal] = ACTIONS(3705),
    [anon_sym_new] = ACTIONS(3705),
    [anon_sym_override] = ACTIONS(3705),
    [anon_sym_partial] = ACTIONS(3705),
    [anon_sym_private] = ACTIONS(3705),
    [anon_sym_protected] = ACTIONS(3705),
    [anon_sym_public] = ACTIONS(3705),
    [anon_sym_readonly] = ACTIONS(3705),
    [anon_sym_required] = ACTIONS(3705),
    [anon_sym_sealed] = ACTIONS(3705),
    [anon_sym_virtual] = ACTIONS(3705),
    [anon_sym_volatile] = ACTIONS(3705),
    [anon_sym_where] = ACTIONS(3705),
    [anon_sym_notnull] = ACTIONS(3705),
    [anon_sym_unmanaged] = ACTIONS(3705),
    [anon_sym_checked] = ACTIONS(3705),
    [anon_sym_BANG] = ACTIONS(3707),
    [anon_sym_TILDE] = ACTIONS(3707),
    [anon_sym_PLUS_PLUS] = ACTIONS(3707),
    [anon_sym_DASH_DASH] = ACTIONS(3707),
    [anon_sym_true] = ACTIONS(3705),
    [anon_sym_false] = ACTIONS(3705),
    [anon_sym_PLUS] = ACTIONS(3705),
    [anon_sym_DASH] = ACTIONS(3705),
    [anon_sym_STAR] = ACTIONS(3707),
    [anon_sym_CARET] = ACTIONS(3707),
    [anon_sym_AMP] = ACTIONS(3707),
    [anon_sym_this] = ACTIONS(3705),
    [anon_sym_scoped] = ACTIONS(3705),
    [anon_sym_base] = ACTIONS(3705),
    [anon_sym_var] = ACTIONS(3705),
    [sym_predefined_type] = ACTIONS(3705),
    [anon_sym_break] = ACTIONS(3705),
    [anon_sym_unchecked] = ACTIONS(3705),
    [anon_sym_continue] = ACTIONS(3705),
    [anon_sym_do] = ACTIONS(3705),
    [anon_sym_while] = ACTIONS(3705),
    [anon_sym_for] = ACTIONS(3705),
    [anon_sym_lock] = ACTIONS(3705),
    [anon_sym_yield] = ACTIONS(3705),
    [anon_sym_switch] = ACTIONS(3705),
    [anon_sym_default] = ACTIONS(3705),
    [anon_sym_throw] = ACTIONS(3705),
    [anon_sym_try] = ACTIONS(3705),
    [anon_sym_when] = ACTIONS(3705),
    [anon_sym_await] = ACTIONS(3705),
    [anon_sym_foreach] = ACTIONS(3705),
    [anon_sym_goto] = ACTIONS(3705),
    [anon_sym_if] = ACTIONS(3705),
    [anon_sym_DOT_DOT] = ACTIONS(3707),
    [anon_sym_from] = ACTIONS(3705),
    [anon_sym_into] = ACTIONS(3705),
    [anon_sym_join] = ACTIONS(3705),
    [anon_sym_on] = ACTIONS(3705),
    [anon_sym_equals] = ACTIONS(3705),
    [anon_sym_let] = ACTIONS(3705),
    [anon_sym_orderby] = ACTIONS(3705),
    [anon_sym_ascending] = ACTIONS(3705),
    [anon_sym_descending] = ACTIONS(3705),
    [anon_sym_group] = ACTIONS(3705),
    [anon_sym_by] = ACTIONS(3705),
    [anon_sym_select] = ACTIONS(3705),
    [anon_sym_stackalloc] = ACTIONS(3705),
    [anon_sym_sizeof] = ACTIONS(3705),
    [anon_sym_typeof] = ACTIONS(3705),
    [anon_sym___makeref] = ACTIONS(3705),
    [anon_sym___reftype] = ACTIONS(3705),
    [anon_sym___refvalue] = ACTIONS(3705),
    [sym_null_literal] = ACTIONS(3705),
    [anon_sym_SQUOTE] = ACTIONS(3707),
    [sym_integer_literal] = ACTIONS(3705),
    [sym_real_literal] = ACTIONS(3707),
    [anon_sym_DQUOTE] = ACTIONS(3707),
    [sym_verbatim_string_literal] = ACTIONS(3707),
    [aux_sym_preproc_if_token1] = ACTIONS(3707),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3707),
    [sym_interpolation_verbatim_start] = ACTIONS(3707),
    [sym_interpolation_raw_start] = ACTIONS(3707),
    [sym_raw_string_start] = ACTIONS(3707),
  },
  [2630] = {
    [sym_preproc_region] = STATE(2630),
    [sym_preproc_endregion] = STATE(2630),
    [sym_preproc_line] = STATE(2630),
    [sym_preproc_pragma] = STATE(2630),
    [sym_preproc_nullable] = STATE(2630),
    [sym_preproc_error] = STATE(2630),
    [sym_preproc_warning] = STATE(2630),
    [sym_preproc_define] = STATE(2630),
    [sym_preproc_undef] = STATE(2630),
    [ts_builtin_sym_end] = ACTIONS(3711),
    [sym__identifier_token] = ACTIONS(3709),
    [anon_sym_extern] = ACTIONS(3709),
    [anon_sym_alias] = ACTIONS(3709),
    [anon_sym_SEMI] = ACTIONS(3711),
    [anon_sym_global] = ACTIONS(3709),
    [anon_sym_using] = ACTIONS(3709),
    [anon_sym_unsafe] = ACTIONS(3709),
    [anon_sym_static] = ACTIONS(3709),
    [anon_sym_LBRACK] = ACTIONS(3711),
    [anon_sym_LPAREN] = ACTIONS(3711),
    [anon_sym_return] = ACTIONS(3709),
    [anon_sym_namespace] = ACTIONS(3709),
    [anon_sym_class] = ACTIONS(3709),
    [anon_sym_ref] = ACTIONS(3709),
    [anon_sym_struct] = ACTIONS(3709),
    [anon_sym_enum] = ACTIONS(3709),
    [anon_sym_LBRACE] = ACTIONS(3711),
    [anon_sym_interface] = ACTIONS(3709),
    [anon_sym_delegate] = ACTIONS(3709),
    [anon_sym_record] = ACTIONS(3709),
    [anon_sym_abstract] = ACTIONS(3709),
    [anon_sym_async] = ACTIONS(3709),
    [anon_sym_const] = ACTIONS(3709),
    [anon_sym_file] = ACTIONS(3709),
    [anon_sym_fixed] = ACTIONS(3709),
    [anon_sym_internal] = ACTIONS(3709),
    [anon_sym_new] = ACTIONS(3709),
    [anon_sym_override] = ACTIONS(3709),
    [anon_sym_partial] = ACTIONS(3709),
    [anon_sym_private] = ACTIONS(3709),
    [anon_sym_protected] = ACTIONS(3709),
    [anon_sym_public] = ACTIONS(3709),
    [anon_sym_readonly] = ACTIONS(3709),
    [anon_sym_required] = ACTIONS(3709),
    [anon_sym_sealed] = ACTIONS(3709),
    [anon_sym_virtual] = ACTIONS(3709),
    [anon_sym_volatile] = ACTIONS(3709),
    [anon_sym_where] = ACTIONS(3709),
    [anon_sym_notnull] = ACTIONS(3709),
    [anon_sym_unmanaged] = ACTIONS(3709),
    [anon_sym_checked] = ACTIONS(3709),
    [anon_sym_BANG] = ACTIONS(3711),
    [anon_sym_TILDE] = ACTIONS(3711),
    [anon_sym_PLUS_PLUS] = ACTIONS(3711),
    [anon_sym_DASH_DASH] = ACTIONS(3711),
    [anon_sym_true] = ACTIONS(3709),
    [anon_sym_false] = ACTIONS(3709),
    [anon_sym_PLUS] = ACTIONS(3709),
    [anon_sym_DASH] = ACTIONS(3709),
    [anon_sym_STAR] = ACTIONS(3711),
    [anon_sym_CARET] = ACTIONS(3711),
    [anon_sym_AMP] = ACTIONS(3711),
    [anon_sym_this] = ACTIONS(3709),
    [anon_sym_scoped] = ACTIONS(3709),
    [anon_sym_base] = ACTIONS(3709),
    [anon_sym_var] = ACTIONS(3709),
    [sym_predefined_type] = ACTIONS(3709),
    [anon_sym_break] = ACTIONS(3709),
    [anon_sym_unchecked] = ACTIONS(3709),
    [anon_sym_continue] = ACTIONS(3709),
    [anon_sym_do] = ACTIONS(3709),
    [anon_sym_while] = ACTIONS(3709),
    [anon_sym_for] = ACTIONS(3709),
    [anon_sym_lock] = ACTIONS(3709),
    [anon_sym_yield] = ACTIONS(3709),
    [anon_sym_switch] = ACTIONS(3709),
    [anon_sym_default] = ACTIONS(3709),
    [anon_sym_throw] = ACTIONS(3709),
    [anon_sym_try] = ACTIONS(3709),
    [anon_sym_when] = ACTIONS(3709),
    [anon_sym_await] = ACTIONS(3709),
    [anon_sym_foreach] = ACTIONS(3709),
    [anon_sym_goto] = ACTIONS(3709),
    [anon_sym_if] = ACTIONS(3709),
    [anon_sym_DOT_DOT] = ACTIONS(3711),
    [anon_sym_from] = ACTIONS(3709),
    [anon_sym_into] = ACTIONS(3709),
    [anon_sym_join] = ACTIONS(3709),
    [anon_sym_on] = ACTIONS(3709),
    [anon_sym_equals] = ACTIONS(3709),
    [anon_sym_let] = ACTIONS(3709),
    [anon_sym_orderby] = ACTIONS(3709),
    [anon_sym_ascending] = ACTIONS(3709),
    [anon_sym_descending] = ACTIONS(3709),
    [anon_sym_group] = ACTIONS(3709),
    [anon_sym_by] = ACTIONS(3709),
    [anon_sym_select] = ACTIONS(3709),
    [anon_sym_stackalloc] = ACTIONS(3709),
    [anon_sym_sizeof] = ACTIONS(3709),
    [anon_sym_typeof] = ACTIONS(3709),
    [anon_sym___makeref] = ACTIONS(3709),
    [anon_sym___reftype] = ACTIONS(3709),
    [anon_sym___refvalue] = ACTIONS(3709),
    [sym_null_literal] = ACTIONS(3709),
    [anon_sym_SQUOTE] = ACTIONS(3711),
    [sym_integer_literal] = ACTIONS(3709),
    [sym_real_literal] = ACTIONS(3711),
    [anon_sym_DQUOTE] = ACTIONS(3711),
    [sym_verbatim_string_literal] = ACTIONS(3711),
    [aux_sym_preproc_if_token1] = ACTIONS(3711),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3711),
    [sym_interpolation_verbatim_start] = ACTIONS(3711),
    [sym_interpolation_raw_start] = ACTIONS(3711),
    [sym_raw_string_start] = ACTIONS(3711),
  },
  [2631] = {
    [sym_preproc_region] = STATE(2631),
    [sym_preproc_endregion] = STATE(2631),
    [sym_preproc_line] = STATE(2631),
    [sym_preproc_pragma] = STATE(2631),
    [sym_preproc_nullable] = STATE(2631),
    [sym_preproc_error] = STATE(2631),
    [sym_preproc_warning] = STATE(2631),
    [sym_preproc_define] = STATE(2631),
    [sym_preproc_undef] = STATE(2631),
    [ts_builtin_sym_end] = ACTIONS(3571),
    [sym__identifier_token] = ACTIONS(3569),
    [anon_sym_extern] = ACTIONS(3569),
    [anon_sym_alias] = ACTIONS(3569),
    [anon_sym_SEMI] = ACTIONS(3571),
    [anon_sym_global] = ACTIONS(3569),
    [anon_sym_using] = ACTIONS(3569),
    [anon_sym_unsafe] = ACTIONS(3569),
    [anon_sym_static] = ACTIONS(3569),
    [anon_sym_LBRACK] = ACTIONS(3571),
    [anon_sym_LPAREN] = ACTIONS(3571),
    [anon_sym_return] = ACTIONS(3569),
    [anon_sym_namespace] = ACTIONS(3569),
    [anon_sym_class] = ACTIONS(3569),
    [anon_sym_ref] = ACTIONS(3569),
    [anon_sym_struct] = ACTIONS(3569),
    [anon_sym_enum] = ACTIONS(3569),
    [anon_sym_LBRACE] = ACTIONS(3571),
    [anon_sym_interface] = ACTIONS(3569),
    [anon_sym_delegate] = ACTIONS(3569),
    [anon_sym_record] = ACTIONS(3569),
    [anon_sym_abstract] = ACTIONS(3569),
    [anon_sym_async] = ACTIONS(3569),
    [anon_sym_const] = ACTIONS(3569),
    [anon_sym_file] = ACTIONS(3569),
    [anon_sym_fixed] = ACTIONS(3569),
    [anon_sym_internal] = ACTIONS(3569),
    [anon_sym_new] = ACTIONS(3569),
    [anon_sym_override] = ACTIONS(3569),
    [anon_sym_partial] = ACTIONS(3569),
    [anon_sym_private] = ACTIONS(3569),
    [anon_sym_protected] = ACTIONS(3569),
    [anon_sym_public] = ACTIONS(3569),
    [anon_sym_readonly] = ACTIONS(3569),
    [anon_sym_required] = ACTIONS(3569),
    [anon_sym_sealed] = ACTIONS(3569),
    [anon_sym_virtual] = ACTIONS(3569),
    [anon_sym_volatile] = ACTIONS(3569),
    [anon_sym_where] = ACTIONS(3569),
    [anon_sym_notnull] = ACTIONS(3569),
    [anon_sym_unmanaged] = ACTIONS(3569),
    [anon_sym_checked] = ACTIONS(3569),
    [anon_sym_BANG] = ACTIONS(3571),
    [anon_sym_TILDE] = ACTIONS(3571),
    [anon_sym_PLUS_PLUS] = ACTIONS(3571),
    [anon_sym_DASH_DASH] = ACTIONS(3571),
    [anon_sym_true] = ACTIONS(3569),
    [anon_sym_false] = ACTIONS(3569),
    [anon_sym_PLUS] = ACTIONS(3569),
    [anon_sym_DASH] = ACTIONS(3569),
    [anon_sym_STAR] = ACTIONS(3571),
    [anon_sym_CARET] = ACTIONS(3571),
    [anon_sym_AMP] = ACTIONS(3571),
    [anon_sym_this] = ACTIONS(3569),
    [anon_sym_scoped] = ACTIONS(3569),
    [anon_sym_base] = ACTIONS(3569),
    [anon_sym_var] = ACTIONS(3569),
    [sym_predefined_type] = ACTIONS(3569),
    [anon_sym_break] = ACTIONS(3569),
    [anon_sym_unchecked] = ACTIONS(3569),
    [anon_sym_continue] = ACTIONS(3569),
    [anon_sym_do] = ACTIONS(3569),
    [anon_sym_while] = ACTIONS(3569),
    [anon_sym_for] = ACTIONS(3569),
    [anon_sym_lock] = ACTIONS(3569),
    [anon_sym_yield] = ACTIONS(3569),
    [anon_sym_switch] = ACTIONS(3569),
    [anon_sym_default] = ACTIONS(3569),
    [anon_sym_throw] = ACTIONS(3569),
    [anon_sym_try] = ACTIONS(3569),
    [anon_sym_when] = ACTIONS(3569),
    [anon_sym_await] = ACTIONS(3569),
    [anon_sym_foreach] = ACTIONS(3569),
    [anon_sym_goto] = ACTIONS(3569),
    [anon_sym_if] = ACTIONS(3569),
    [anon_sym_DOT_DOT] = ACTIONS(3571),
    [anon_sym_from] = ACTIONS(3569),
    [anon_sym_into] = ACTIONS(3569),
    [anon_sym_join] = ACTIONS(3569),
    [anon_sym_on] = ACTIONS(3569),
    [anon_sym_equals] = ACTIONS(3569),
    [anon_sym_let] = ACTIONS(3569),
    [anon_sym_orderby] = ACTIONS(3569),
    [anon_sym_ascending] = ACTIONS(3569),
    [anon_sym_descending] = ACTIONS(3569),
    [anon_sym_group] = ACTIONS(3569),
    [anon_sym_by] = ACTIONS(3569),
    [anon_sym_select] = ACTIONS(3569),
    [anon_sym_stackalloc] = ACTIONS(3569),
    [anon_sym_sizeof] = ACTIONS(3569),
    [anon_sym_typeof] = ACTIONS(3569),
    [anon_sym___makeref] = ACTIONS(3569),
    [anon_sym___reftype] = ACTIONS(3569),
    [anon_sym___refvalue] = ACTIONS(3569),
    [sym_null_literal] = ACTIONS(3569),
    [anon_sym_SQUOTE] = ACTIONS(3571),
    [sym_integer_literal] = ACTIONS(3569),
    [sym_real_literal] = ACTIONS(3571),
    [anon_sym_DQUOTE] = ACTIONS(3571),
    [sym_verbatim_string_literal] = ACTIONS(3571),
    [aux_sym_preproc_if_token1] = ACTIONS(3571),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3571),
    [sym_interpolation_verbatim_start] = ACTIONS(3571),
    [sym_interpolation_raw_start] = ACTIONS(3571),
    [sym_raw_string_start] = ACTIONS(3571),
  },
  [2632] = {
    [sym_preproc_region] = STATE(2632),
    [sym_preproc_endregion] = STATE(2632),
    [sym_preproc_line] = STATE(2632),
    [sym_preproc_pragma] = STATE(2632),
    [sym_preproc_nullable] = STATE(2632),
    [sym_preproc_error] = STATE(2632),
    [sym_preproc_warning] = STATE(2632),
    [sym_preproc_define] = STATE(2632),
    [sym_preproc_undef] = STATE(2632),
    [ts_builtin_sym_end] = ACTIONS(3499),
    [sym__identifier_token] = ACTIONS(3497),
    [anon_sym_extern] = ACTIONS(3497),
    [anon_sym_alias] = ACTIONS(3497),
    [anon_sym_SEMI] = ACTIONS(3499),
    [anon_sym_global] = ACTIONS(3497),
    [anon_sym_using] = ACTIONS(3497),
    [anon_sym_unsafe] = ACTIONS(3497),
    [anon_sym_static] = ACTIONS(3497),
    [anon_sym_LBRACK] = ACTIONS(3499),
    [anon_sym_LPAREN] = ACTIONS(3499),
    [anon_sym_return] = ACTIONS(3497),
    [anon_sym_namespace] = ACTIONS(3497),
    [anon_sym_class] = ACTIONS(3497),
    [anon_sym_ref] = ACTIONS(3497),
    [anon_sym_struct] = ACTIONS(3497),
    [anon_sym_enum] = ACTIONS(3497),
    [anon_sym_LBRACE] = ACTIONS(3499),
    [anon_sym_interface] = ACTIONS(3497),
    [anon_sym_delegate] = ACTIONS(3497),
    [anon_sym_record] = ACTIONS(3497),
    [anon_sym_abstract] = ACTIONS(3497),
    [anon_sym_async] = ACTIONS(3497),
    [anon_sym_const] = ACTIONS(3497),
    [anon_sym_file] = ACTIONS(3497),
    [anon_sym_fixed] = ACTIONS(3497),
    [anon_sym_internal] = ACTIONS(3497),
    [anon_sym_new] = ACTIONS(3497),
    [anon_sym_override] = ACTIONS(3497),
    [anon_sym_partial] = ACTIONS(3497),
    [anon_sym_private] = ACTIONS(3497),
    [anon_sym_protected] = ACTIONS(3497),
    [anon_sym_public] = ACTIONS(3497),
    [anon_sym_readonly] = ACTIONS(3497),
    [anon_sym_required] = ACTIONS(3497),
    [anon_sym_sealed] = ACTIONS(3497),
    [anon_sym_virtual] = ACTIONS(3497),
    [anon_sym_volatile] = ACTIONS(3497),
    [anon_sym_where] = ACTIONS(3497),
    [anon_sym_notnull] = ACTIONS(3497),
    [anon_sym_unmanaged] = ACTIONS(3497),
    [anon_sym_checked] = ACTIONS(3497),
    [anon_sym_BANG] = ACTIONS(3499),
    [anon_sym_TILDE] = ACTIONS(3499),
    [anon_sym_PLUS_PLUS] = ACTIONS(3499),
    [anon_sym_DASH_DASH] = ACTIONS(3499),
    [anon_sym_true] = ACTIONS(3497),
    [anon_sym_false] = ACTIONS(3497),
    [anon_sym_PLUS] = ACTIONS(3497),
    [anon_sym_DASH] = ACTIONS(3497),
    [anon_sym_STAR] = ACTIONS(3499),
    [anon_sym_CARET] = ACTIONS(3499),
    [anon_sym_AMP] = ACTIONS(3499),
    [anon_sym_this] = ACTIONS(3497),
    [anon_sym_scoped] = ACTIONS(3497),
    [anon_sym_base] = ACTIONS(3497),
    [anon_sym_var] = ACTIONS(3497),
    [sym_predefined_type] = ACTIONS(3497),
    [anon_sym_break] = ACTIONS(3497),
    [anon_sym_unchecked] = ACTIONS(3497),
    [anon_sym_continue] = ACTIONS(3497),
    [anon_sym_do] = ACTIONS(3497),
    [anon_sym_while] = ACTIONS(3497),
    [anon_sym_for] = ACTIONS(3497),
    [anon_sym_lock] = ACTIONS(3497),
    [anon_sym_yield] = ACTIONS(3497),
    [anon_sym_switch] = ACTIONS(3497),
    [anon_sym_default] = ACTIONS(3497),
    [anon_sym_throw] = ACTIONS(3497),
    [anon_sym_try] = ACTIONS(3497),
    [anon_sym_when] = ACTIONS(3497),
    [anon_sym_await] = ACTIONS(3497),
    [anon_sym_foreach] = ACTIONS(3497),
    [anon_sym_goto] = ACTIONS(3497),
    [anon_sym_if] = ACTIONS(3497),
    [anon_sym_DOT_DOT] = ACTIONS(3499),
    [anon_sym_from] = ACTIONS(3497),
    [anon_sym_into] = ACTIONS(3497),
    [anon_sym_join] = ACTIONS(3497),
    [anon_sym_on] = ACTIONS(3497),
    [anon_sym_equals] = ACTIONS(3497),
    [anon_sym_let] = ACTIONS(3497),
    [anon_sym_orderby] = ACTIONS(3497),
    [anon_sym_ascending] = ACTIONS(3497),
    [anon_sym_descending] = ACTIONS(3497),
    [anon_sym_group] = ACTIONS(3497),
    [anon_sym_by] = ACTIONS(3497),
    [anon_sym_select] = ACTIONS(3497),
    [anon_sym_stackalloc] = ACTIONS(3497),
    [anon_sym_sizeof] = ACTIONS(3497),
    [anon_sym_typeof] = ACTIONS(3497),
    [anon_sym___makeref] = ACTIONS(3497),
    [anon_sym___reftype] = ACTIONS(3497),
    [anon_sym___refvalue] = ACTIONS(3497),
    [sym_null_literal] = ACTIONS(3497),
    [anon_sym_SQUOTE] = ACTIONS(3499),
    [sym_integer_literal] = ACTIONS(3497),
    [sym_real_literal] = ACTIONS(3499),
    [anon_sym_DQUOTE] = ACTIONS(3499),
    [sym_verbatim_string_literal] = ACTIONS(3499),
    [aux_sym_preproc_if_token1] = ACTIONS(3499),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3499),
    [sym_interpolation_verbatim_start] = ACTIONS(3499),
    [sym_interpolation_raw_start] = ACTIONS(3499),
    [sym_raw_string_start] = ACTIONS(3499),
  },
  [2633] = {
    [sym_preproc_region] = STATE(2633),
    [sym_preproc_endregion] = STATE(2633),
    [sym_preproc_line] = STATE(2633),
    [sym_preproc_pragma] = STATE(2633),
    [sym_preproc_nullable] = STATE(2633),
    [sym_preproc_error] = STATE(2633),
    [sym_preproc_warning] = STATE(2633),
    [sym_preproc_define] = STATE(2633),
    [sym_preproc_undef] = STATE(2633),
    [ts_builtin_sym_end] = ACTIONS(3575),
    [sym__identifier_token] = ACTIONS(3573),
    [anon_sym_extern] = ACTIONS(3573),
    [anon_sym_alias] = ACTIONS(3573),
    [anon_sym_SEMI] = ACTIONS(3575),
    [anon_sym_global] = ACTIONS(3573),
    [anon_sym_using] = ACTIONS(3573),
    [anon_sym_unsafe] = ACTIONS(3573),
    [anon_sym_static] = ACTIONS(3573),
    [anon_sym_LBRACK] = ACTIONS(3575),
    [anon_sym_LPAREN] = ACTIONS(3575),
    [anon_sym_return] = ACTIONS(3573),
    [anon_sym_namespace] = ACTIONS(3573),
    [anon_sym_class] = ACTIONS(3573),
    [anon_sym_ref] = ACTIONS(3573),
    [anon_sym_struct] = ACTIONS(3573),
    [anon_sym_enum] = ACTIONS(3573),
    [anon_sym_LBRACE] = ACTIONS(3575),
    [anon_sym_interface] = ACTIONS(3573),
    [anon_sym_delegate] = ACTIONS(3573),
    [anon_sym_record] = ACTIONS(3573),
    [anon_sym_abstract] = ACTIONS(3573),
    [anon_sym_async] = ACTIONS(3573),
    [anon_sym_const] = ACTIONS(3573),
    [anon_sym_file] = ACTIONS(3573),
    [anon_sym_fixed] = ACTIONS(3573),
    [anon_sym_internal] = ACTIONS(3573),
    [anon_sym_new] = ACTIONS(3573),
    [anon_sym_override] = ACTIONS(3573),
    [anon_sym_partial] = ACTIONS(3573),
    [anon_sym_private] = ACTIONS(3573),
    [anon_sym_protected] = ACTIONS(3573),
    [anon_sym_public] = ACTIONS(3573),
    [anon_sym_readonly] = ACTIONS(3573),
    [anon_sym_required] = ACTIONS(3573),
    [anon_sym_sealed] = ACTIONS(3573),
    [anon_sym_virtual] = ACTIONS(3573),
    [anon_sym_volatile] = ACTIONS(3573),
    [anon_sym_where] = ACTIONS(3573),
    [anon_sym_notnull] = ACTIONS(3573),
    [anon_sym_unmanaged] = ACTIONS(3573),
    [anon_sym_checked] = ACTIONS(3573),
    [anon_sym_BANG] = ACTIONS(3575),
    [anon_sym_TILDE] = ACTIONS(3575),
    [anon_sym_PLUS_PLUS] = ACTIONS(3575),
    [anon_sym_DASH_DASH] = ACTIONS(3575),
    [anon_sym_true] = ACTIONS(3573),
    [anon_sym_false] = ACTIONS(3573),
    [anon_sym_PLUS] = ACTIONS(3573),
    [anon_sym_DASH] = ACTIONS(3573),
    [anon_sym_STAR] = ACTIONS(3575),
    [anon_sym_CARET] = ACTIONS(3575),
    [anon_sym_AMP] = ACTIONS(3575),
    [anon_sym_this] = ACTIONS(3573),
    [anon_sym_scoped] = ACTIONS(3573),
    [anon_sym_base] = ACTIONS(3573),
    [anon_sym_var] = ACTIONS(3573),
    [sym_predefined_type] = ACTIONS(3573),
    [anon_sym_break] = ACTIONS(3573),
    [anon_sym_unchecked] = ACTIONS(3573),
    [anon_sym_continue] = ACTIONS(3573),
    [anon_sym_do] = ACTIONS(3573),
    [anon_sym_while] = ACTIONS(3573),
    [anon_sym_for] = ACTIONS(3573),
    [anon_sym_lock] = ACTIONS(3573),
    [anon_sym_yield] = ACTIONS(3573),
    [anon_sym_switch] = ACTIONS(3573),
    [anon_sym_default] = ACTIONS(3573),
    [anon_sym_throw] = ACTIONS(3573),
    [anon_sym_try] = ACTIONS(3573),
    [anon_sym_when] = ACTIONS(3573),
    [anon_sym_await] = ACTIONS(3573),
    [anon_sym_foreach] = ACTIONS(3573),
    [anon_sym_goto] = ACTIONS(3573),
    [anon_sym_if] = ACTIONS(3573),
    [anon_sym_DOT_DOT] = ACTIONS(3575),
    [anon_sym_from] = ACTIONS(3573),
    [anon_sym_into] = ACTIONS(3573),
    [anon_sym_join] = ACTIONS(3573),
    [anon_sym_on] = ACTIONS(3573),
    [anon_sym_equals] = ACTIONS(3573),
    [anon_sym_let] = ACTIONS(3573),
    [anon_sym_orderby] = ACTIONS(3573),
    [anon_sym_ascending] = ACTIONS(3573),
    [anon_sym_descending] = ACTIONS(3573),
    [anon_sym_group] = ACTIONS(3573),
    [anon_sym_by] = ACTIONS(3573),
    [anon_sym_select] = ACTIONS(3573),
    [anon_sym_stackalloc] = ACTIONS(3573),
    [anon_sym_sizeof] = ACTIONS(3573),
    [anon_sym_typeof] = ACTIONS(3573),
    [anon_sym___makeref] = ACTIONS(3573),
    [anon_sym___reftype] = ACTIONS(3573),
    [anon_sym___refvalue] = ACTIONS(3573),
    [sym_null_literal] = ACTIONS(3573),
    [anon_sym_SQUOTE] = ACTIONS(3575),
    [sym_integer_literal] = ACTIONS(3573),
    [sym_real_literal] = ACTIONS(3575),
    [anon_sym_DQUOTE] = ACTIONS(3575),
    [sym_verbatim_string_literal] = ACTIONS(3575),
    [aux_sym_preproc_if_token1] = ACTIONS(3575),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3575),
    [sym_interpolation_verbatim_start] = ACTIONS(3575),
    [sym_interpolation_raw_start] = ACTIONS(3575),
    [sym_raw_string_start] = ACTIONS(3575),
  },
  [2634] = {
    [sym_preproc_region] = STATE(2634),
    [sym_preproc_endregion] = STATE(2634),
    [sym_preproc_line] = STATE(2634),
    [sym_preproc_pragma] = STATE(2634),
    [sym_preproc_nullable] = STATE(2634),
    [sym_preproc_error] = STATE(2634),
    [sym_preproc_warning] = STATE(2634),
    [sym_preproc_define] = STATE(2634),
    [sym_preproc_undef] = STATE(2634),
    [ts_builtin_sym_end] = ACTIONS(3579),
    [sym__identifier_token] = ACTIONS(3577),
    [anon_sym_extern] = ACTIONS(3577),
    [anon_sym_alias] = ACTIONS(3577),
    [anon_sym_SEMI] = ACTIONS(3579),
    [anon_sym_global] = ACTIONS(3577),
    [anon_sym_using] = ACTIONS(3577),
    [anon_sym_unsafe] = ACTIONS(3577),
    [anon_sym_static] = ACTIONS(3577),
    [anon_sym_LBRACK] = ACTIONS(3579),
    [anon_sym_LPAREN] = ACTIONS(3579),
    [anon_sym_return] = ACTIONS(3577),
    [anon_sym_namespace] = ACTIONS(3577),
    [anon_sym_class] = ACTIONS(3577),
    [anon_sym_ref] = ACTIONS(3577),
    [anon_sym_struct] = ACTIONS(3577),
    [anon_sym_enum] = ACTIONS(3577),
    [anon_sym_LBRACE] = ACTIONS(3579),
    [anon_sym_interface] = ACTIONS(3577),
    [anon_sym_delegate] = ACTIONS(3577),
    [anon_sym_record] = ACTIONS(3577),
    [anon_sym_abstract] = ACTIONS(3577),
    [anon_sym_async] = ACTIONS(3577),
    [anon_sym_const] = ACTIONS(3577),
    [anon_sym_file] = ACTIONS(3577),
    [anon_sym_fixed] = ACTIONS(3577),
    [anon_sym_internal] = ACTIONS(3577),
    [anon_sym_new] = ACTIONS(3577),
    [anon_sym_override] = ACTIONS(3577),
    [anon_sym_partial] = ACTIONS(3577),
    [anon_sym_private] = ACTIONS(3577),
    [anon_sym_protected] = ACTIONS(3577),
    [anon_sym_public] = ACTIONS(3577),
    [anon_sym_readonly] = ACTIONS(3577),
    [anon_sym_required] = ACTIONS(3577),
    [anon_sym_sealed] = ACTIONS(3577),
    [anon_sym_virtual] = ACTIONS(3577),
    [anon_sym_volatile] = ACTIONS(3577),
    [anon_sym_where] = ACTIONS(3577),
    [anon_sym_notnull] = ACTIONS(3577),
    [anon_sym_unmanaged] = ACTIONS(3577),
    [anon_sym_checked] = ACTIONS(3577),
    [anon_sym_BANG] = ACTIONS(3579),
    [anon_sym_TILDE] = ACTIONS(3579),
    [anon_sym_PLUS_PLUS] = ACTIONS(3579),
    [anon_sym_DASH_DASH] = ACTIONS(3579),
    [anon_sym_true] = ACTIONS(3577),
    [anon_sym_false] = ACTIONS(3577),
    [anon_sym_PLUS] = ACTIONS(3577),
    [anon_sym_DASH] = ACTIONS(3577),
    [anon_sym_STAR] = ACTIONS(3579),
    [anon_sym_CARET] = ACTIONS(3579),
    [anon_sym_AMP] = ACTIONS(3579),
    [anon_sym_this] = ACTIONS(3577),
    [anon_sym_scoped] = ACTIONS(3577),
    [anon_sym_base] = ACTIONS(3577),
    [anon_sym_var] = ACTIONS(3577),
    [sym_predefined_type] = ACTIONS(3577),
    [anon_sym_break] = ACTIONS(3577),
    [anon_sym_unchecked] = ACTIONS(3577),
    [anon_sym_continue] = ACTIONS(3577),
    [anon_sym_do] = ACTIONS(3577),
    [anon_sym_while] = ACTIONS(3577),
    [anon_sym_for] = ACTIONS(3577),
    [anon_sym_lock] = ACTIONS(3577),
    [anon_sym_yield] = ACTIONS(3577),
    [anon_sym_switch] = ACTIONS(3577),
    [anon_sym_default] = ACTIONS(3577),
    [anon_sym_throw] = ACTIONS(3577),
    [anon_sym_try] = ACTIONS(3577),
    [anon_sym_when] = ACTIONS(3577),
    [anon_sym_await] = ACTIONS(3577),
    [anon_sym_foreach] = ACTIONS(3577),
    [anon_sym_goto] = ACTIONS(3577),
    [anon_sym_if] = ACTIONS(3577),
    [anon_sym_DOT_DOT] = ACTIONS(3579),
    [anon_sym_from] = ACTIONS(3577),
    [anon_sym_into] = ACTIONS(3577),
    [anon_sym_join] = ACTIONS(3577),
    [anon_sym_on] = ACTIONS(3577),
    [anon_sym_equals] = ACTIONS(3577),
    [anon_sym_let] = ACTIONS(3577),
    [anon_sym_orderby] = ACTIONS(3577),
    [anon_sym_ascending] = ACTIONS(3577),
    [anon_sym_descending] = ACTIONS(3577),
    [anon_sym_group] = ACTIONS(3577),
    [anon_sym_by] = ACTIONS(3577),
    [anon_sym_select] = ACTIONS(3577),
    [anon_sym_stackalloc] = ACTIONS(3577),
    [anon_sym_sizeof] = ACTIONS(3577),
    [anon_sym_typeof] = ACTIONS(3577),
    [anon_sym___makeref] = ACTIONS(3577),
    [anon_sym___reftype] = ACTIONS(3577),
    [anon_sym___refvalue] = ACTIONS(3577),
    [sym_null_literal] = ACTIONS(3577),
    [anon_sym_SQUOTE] = ACTIONS(3579),
    [sym_integer_literal] = ACTIONS(3577),
    [sym_real_literal] = ACTIONS(3579),
    [anon_sym_DQUOTE] = ACTIONS(3579),
    [sym_verbatim_string_literal] = ACTIONS(3579),
    [aux_sym_preproc_if_token1] = ACTIONS(3579),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3579),
    [sym_interpolation_verbatim_start] = ACTIONS(3579),
    [sym_interpolation_raw_start] = ACTIONS(3579),
    [sym_raw_string_start] = ACTIONS(3579),
  },
  [2635] = {
    [sym_preproc_region] = STATE(2635),
    [sym_preproc_endregion] = STATE(2635),
    [sym_preproc_line] = STATE(2635),
    [sym_preproc_pragma] = STATE(2635),
    [sym_preproc_nullable] = STATE(2635),
    [sym_preproc_error] = STATE(2635),
    [sym_preproc_warning] = STATE(2635),
    [sym_preproc_define] = STATE(2635),
    [sym_preproc_undef] = STATE(2635),
    [ts_builtin_sym_end] = ACTIONS(3503),
    [sym__identifier_token] = ACTIONS(3501),
    [anon_sym_extern] = ACTIONS(3501),
    [anon_sym_alias] = ACTIONS(3501),
    [anon_sym_SEMI] = ACTIONS(3503),
    [anon_sym_global] = ACTIONS(3501),
    [anon_sym_using] = ACTIONS(3501),
    [anon_sym_unsafe] = ACTIONS(3501),
    [anon_sym_static] = ACTIONS(3501),
    [anon_sym_LBRACK] = ACTIONS(3503),
    [anon_sym_LPAREN] = ACTIONS(3503),
    [anon_sym_return] = ACTIONS(3501),
    [anon_sym_namespace] = ACTIONS(3501),
    [anon_sym_class] = ACTIONS(3501),
    [anon_sym_ref] = ACTIONS(3501),
    [anon_sym_struct] = ACTIONS(3501),
    [anon_sym_enum] = ACTIONS(3501),
    [anon_sym_LBRACE] = ACTIONS(3503),
    [anon_sym_interface] = ACTIONS(3501),
    [anon_sym_delegate] = ACTIONS(3501),
    [anon_sym_record] = ACTIONS(3501),
    [anon_sym_abstract] = ACTIONS(3501),
    [anon_sym_async] = ACTIONS(3501),
    [anon_sym_const] = ACTIONS(3501),
    [anon_sym_file] = ACTIONS(3501),
    [anon_sym_fixed] = ACTIONS(3501),
    [anon_sym_internal] = ACTIONS(3501),
    [anon_sym_new] = ACTIONS(3501),
    [anon_sym_override] = ACTIONS(3501),
    [anon_sym_partial] = ACTIONS(3501),
    [anon_sym_private] = ACTIONS(3501),
    [anon_sym_protected] = ACTIONS(3501),
    [anon_sym_public] = ACTIONS(3501),
    [anon_sym_readonly] = ACTIONS(3501),
    [anon_sym_required] = ACTIONS(3501),
    [anon_sym_sealed] = ACTIONS(3501),
    [anon_sym_virtual] = ACTIONS(3501),
    [anon_sym_volatile] = ACTIONS(3501),
    [anon_sym_where] = ACTIONS(3501),
    [anon_sym_notnull] = ACTIONS(3501),
    [anon_sym_unmanaged] = ACTIONS(3501),
    [anon_sym_checked] = ACTIONS(3501),
    [anon_sym_BANG] = ACTIONS(3503),
    [anon_sym_TILDE] = ACTIONS(3503),
    [anon_sym_PLUS_PLUS] = ACTIONS(3503),
    [anon_sym_DASH_DASH] = ACTIONS(3503),
    [anon_sym_true] = ACTIONS(3501),
    [anon_sym_false] = ACTIONS(3501),
    [anon_sym_PLUS] = ACTIONS(3501),
    [anon_sym_DASH] = ACTIONS(3501),
    [anon_sym_STAR] = ACTIONS(3503),
    [anon_sym_CARET] = ACTIONS(3503),
    [anon_sym_AMP] = ACTIONS(3503),
    [anon_sym_this] = ACTIONS(3501),
    [anon_sym_scoped] = ACTIONS(3501),
    [anon_sym_base] = ACTIONS(3501),
    [anon_sym_var] = ACTIONS(3501),
    [sym_predefined_type] = ACTIONS(3501),
    [anon_sym_break] = ACTIONS(3501),
    [anon_sym_unchecked] = ACTIONS(3501),
    [anon_sym_continue] = ACTIONS(3501),
    [anon_sym_do] = ACTIONS(3501),
    [anon_sym_while] = ACTIONS(3501),
    [anon_sym_for] = ACTIONS(3501),
    [anon_sym_lock] = ACTIONS(3501),
    [anon_sym_yield] = ACTIONS(3501),
    [anon_sym_switch] = ACTIONS(3501),
    [anon_sym_default] = ACTIONS(3501),
    [anon_sym_throw] = ACTIONS(3501),
    [anon_sym_try] = ACTIONS(3501),
    [anon_sym_when] = ACTIONS(3501),
    [anon_sym_await] = ACTIONS(3501),
    [anon_sym_foreach] = ACTIONS(3501),
    [anon_sym_goto] = ACTIONS(3501),
    [anon_sym_if] = ACTIONS(3501),
    [anon_sym_DOT_DOT] = ACTIONS(3503),
    [anon_sym_from] = ACTIONS(3501),
    [anon_sym_into] = ACTIONS(3501),
    [anon_sym_join] = ACTIONS(3501),
    [anon_sym_on] = ACTIONS(3501),
    [anon_sym_equals] = ACTIONS(3501),
    [anon_sym_let] = ACTIONS(3501),
    [anon_sym_orderby] = ACTIONS(3501),
    [anon_sym_ascending] = ACTIONS(3501),
    [anon_sym_descending] = ACTIONS(3501),
    [anon_sym_group] = ACTIONS(3501),
    [anon_sym_by] = ACTIONS(3501),
    [anon_sym_select] = ACTIONS(3501),
    [anon_sym_stackalloc] = ACTIONS(3501),
    [anon_sym_sizeof] = ACTIONS(3501),
    [anon_sym_typeof] = ACTIONS(3501),
    [anon_sym___makeref] = ACTIONS(3501),
    [anon_sym___reftype] = ACTIONS(3501),
    [anon_sym___refvalue] = ACTIONS(3501),
    [sym_null_literal] = ACTIONS(3501),
    [anon_sym_SQUOTE] = ACTIONS(3503),
    [sym_integer_literal] = ACTIONS(3501),
    [sym_real_literal] = ACTIONS(3503),
    [anon_sym_DQUOTE] = ACTIONS(3503),
    [sym_verbatim_string_literal] = ACTIONS(3503),
    [aux_sym_preproc_if_token1] = ACTIONS(3503),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3503),
    [sym_interpolation_verbatim_start] = ACTIONS(3503),
    [sym_interpolation_raw_start] = ACTIONS(3503),
    [sym_raw_string_start] = ACTIONS(3503),
  },
  [2636] = {
    [sym_preproc_region] = STATE(2636),
    [sym_preproc_endregion] = STATE(2636),
    [sym_preproc_line] = STATE(2636),
    [sym_preproc_pragma] = STATE(2636),
    [sym_preproc_nullable] = STATE(2636),
    [sym_preproc_error] = STATE(2636),
    [sym_preproc_warning] = STATE(2636),
    [sym_preproc_define] = STATE(2636),
    [sym_preproc_undef] = STATE(2636),
    [ts_builtin_sym_end] = ACTIONS(4027),
    [sym__identifier_token] = ACTIONS(4029),
    [anon_sym_extern] = ACTIONS(4029),
    [anon_sym_alias] = ACTIONS(4029),
    [anon_sym_SEMI] = ACTIONS(4027),
    [anon_sym_global] = ACTIONS(4029),
    [anon_sym_using] = ACTIONS(4029),
    [anon_sym_unsafe] = ACTIONS(4029),
    [anon_sym_static] = ACTIONS(4029),
    [anon_sym_LBRACK] = ACTIONS(4027),
    [anon_sym_LPAREN] = ACTIONS(4027),
    [anon_sym_return] = ACTIONS(4029),
    [anon_sym_namespace] = ACTIONS(4029),
    [anon_sym_class] = ACTIONS(4029),
    [anon_sym_ref] = ACTIONS(4029),
    [anon_sym_struct] = ACTIONS(4029),
    [anon_sym_enum] = ACTIONS(4029),
    [anon_sym_LBRACE] = ACTIONS(4027),
    [anon_sym_interface] = ACTIONS(4029),
    [anon_sym_delegate] = ACTIONS(4029),
    [anon_sym_record] = ACTIONS(4029),
    [anon_sym_abstract] = ACTIONS(4029),
    [anon_sym_async] = ACTIONS(4029),
    [anon_sym_const] = ACTIONS(4029),
    [anon_sym_file] = ACTIONS(4029),
    [anon_sym_fixed] = ACTIONS(4029),
    [anon_sym_internal] = ACTIONS(4029),
    [anon_sym_new] = ACTIONS(4029),
    [anon_sym_override] = ACTIONS(4029),
    [anon_sym_partial] = ACTIONS(4029),
    [anon_sym_private] = ACTIONS(4029),
    [anon_sym_protected] = ACTIONS(4029),
    [anon_sym_public] = ACTIONS(4029),
    [anon_sym_readonly] = ACTIONS(4029),
    [anon_sym_required] = ACTIONS(4029),
    [anon_sym_sealed] = ACTIONS(4029),
    [anon_sym_virtual] = ACTIONS(4029),
    [anon_sym_volatile] = ACTIONS(4029),
    [anon_sym_where] = ACTIONS(4029),
    [anon_sym_notnull] = ACTIONS(4029),
    [anon_sym_unmanaged] = ACTIONS(4029),
    [anon_sym_checked] = ACTIONS(4029),
    [anon_sym_BANG] = ACTIONS(4027),
    [anon_sym_TILDE] = ACTIONS(4027),
    [anon_sym_PLUS_PLUS] = ACTIONS(4027),
    [anon_sym_DASH_DASH] = ACTIONS(4027),
    [anon_sym_true] = ACTIONS(4029),
    [anon_sym_false] = ACTIONS(4029),
    [anon_sym_PLUS] = ACTIONS(4029),
    [anon_sym_DASH] = ACTIONS(4029),
    [anon_sym_STAR] = ACTIONS(4027),
    [anon_sym_CARET] = ACTIONS(4027),
    [anon_sym_AMP] = ACTIONS(4027),
    [anon_sym_this] = ACTIONS(4029),
    [anon_sym_scoped] = ACTIONS(4029),
    [anon_sym_base] = ACTIONS(4029),
    [anon_sym_var] = ACTIONS(4029),
    [sym_predefined_type] = ACTIONS(4029),
    [anon_sym_break] = ACTIONS(4029),
    [anon_sym_unchecked] = ACTIONS(4029),
    [anon_sym_continue] = ACTIONS(4029),
    [anon_sym_do] = ACTIONS(4029),
    [anon_sym_while] = ACTIONS(4029),
    [anon_sym_for] = ACTIONS(4029),
    [anon_sym_lock] = ACTIONS(4029),
    [anon_sym_yield] = ACTIONS(4029),
    [anon_sym_switch] = ACTIONS(4029),
    [anon_sym_default] = ACTIONS(4029),
    [anon_sym_throw] = ACTIONS(4029),
    [anon_sym_try] = ACTIONS(4029),
    [anon_sym_when] = ACTIONS(4029),
    [anon_sym_await] = ACTIONS(4029),
    [anon_sym_foreach] = ACTIONS(4029),
    [anon_sym_goto] = ACTIONS(4029),
    [anon_sym_if] = ACTIONS(4029),
    [anon_sym_DOT_DOT] = ACTIONS(4027),
    [anon_sym_from] = ACTIONS(4029),
    [anon_sym_into] = ACTIONS(4029),
    [anon_sym_join] = ACTIONS(4029),
    [anon_sym_on] = ACTIONS(4029),
    [anon_sym_equals] = ACTIONS(4029),
    [anon_sym_let] = ACTIONS(4029),
    [anon_sym_orderby] = ACTIONS(4029),
    [anon_sym_ascending] = ACTIONS(4029),
    [anon_sym_descending] = ACTIONS(4029),
    [anon_sym_group] = ACTIONS(4029),
    [anon_sym_by] = ACTIONS(4029),
    [anon_sym_select] = ACTIONS(4029),
    [anon_sym_stackalloc] = ACTIONS(4029),
    [anon_sym_sizeof] = ACTIONS(4029),
    [anon_sym_typeof] = ACTIONS(4029),
    [anon_sym___makeref] = ACTIONS(4029),
    [anon_sym___reftype] = ACTIONS(4029),
    [anon_sym___refvalue] = ACTIONS(4029),
    [sym_null_literal] = ACTIONS(4029),
    [anon_sym_SQUOTE] = ACTIONS(4027),
    [sym_integer_literal] = ACTIONS(4029),
    [sym_real_literal] = ACTIONS(4027),
    [anon_sym_DQUOTE] = ACTIONS(4027),
    [sym_verbatim_string_literal] = ACTIONS(4027),
    [aux_sym_preproc_if_token1] = ACTIONS(4027),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(4027),
    [sym_interpolation_verbatim_start] = ACTIONS(4027),
    [sym_interpolation_raw_start] = ACTIONS(4027),
    [sym_raw_string_start] = ACTIONS(4027),
  },
  [2637] = {
    [sym_preproc_region] = STATE(2637),
    [sym_preproc_endregion] = STATE(2637),
    [sym_preproc_line] = STATE(2637),
    [sym_preproc_pragma] = STATE(2637),
    [sym_preproc_nullable] = STATE(2637),
    [sym_preproc_error] = STATE(2637),
    [sym_preproc_warning] = STATE(2637),
    [sym_preproc_define] = STATE(2637),
    [sym_preproc_undef] = STATE(2637),
    [ts_builtin_sym_end] = ACTIONS(3471),
    [sym__identifier_token] = ACTIONS(3469),
    [anon_sym_extern] = ACTIONS(3469),
    [anon_sym_alias] = ACTIONS(3469),
    [anon_sym_SEMI] = ACTIONS(3471),
    [anon_sym_global] = ACTIONS(3469),
    [anon_sym_using] = ACTIONS(3469),
    [anon_sym_unsafe] = ACTIONS(3469),
    [anon_sym_static] = ACTIONS(3469),
    [anon_sym_LBRACK] = ACTIONS(3471),
    [anon_sym_LPAREN] = ACTIONS(3471),
    [anon_sym_return] = ACTIONS(3469),
    [anon_sym_namespace] = ACTIONS(3469),
    [anon_sym_class] = ACTIONS(3469),
    [anon_sym_ref] = ACTIONS(3469),
    [anon_sym_struct] = ACTIONS(3469),
    [anon_sym_enum] = ACTIONS(3469),
    [anon_sym_LBRACE] = ACTIONS(3471),
    [anon_sym_interface] = ACTIONS(3469),
    [anon_sym_delegate] = ACTIONS(3469),
    [anon_sym_record] = ACTIONS(3469),
    [anon_sym_abstract] = ACTIONS(3469),
    [anon_sym_async] = ACTIONS(3469),
    [anon_sym_const] = ACTIONS(3469),
    [anon_sym_file] = ACTIONS(3469),
    [anon_sym_fixed] = ACTIONS(3469),
    [anon_sym_internal] = ACTIONS(3469),
    [anon_sym_new] = ACTIONS(3469),
    [anon_sym_override] = ACTIONS(3469),
    [anon_sym_partial] = ACTIONS(3469),
    [anon_sym_private] = ACTIONS(3469),
    [anon_sym_protected] = ACTIONS(3469),
    [anon_sym_public] = ACTIONS(3469),
    [anon_sym_readonly] = ACTIONS(3469),
    [anon_sym_required] = ACTIONS(3469),
    [anon_sym_sealed] = ACTIONS(3469),
    [anon_sym_virtual] = ACTIONS(3469),
    [anon_sym_volatile] = ACTIONS(3469),
    [anon_sym_where] = ACTIONS(3469),
    [anon_sym_notnull] = ACTIONS(3469),
    [anon_sym_unmanaged] = ACTIONS(3469),
    [anon_sym_checked] = ACTIONS(3469),
    [anon_sym_BANG] = ACTIONS(3471),
    [anon_sym_TILDE] = ACTIONS(3471),
    [anon_sym_PLUS_PLUS] = ACTIONS(3471),
    [anon_sym_DASH_DASH] = ACTIONS(3471),
    [anon_sym_true] = ACTIONS(3469),
    [anon_sym_false] = ACTIONS(3469),
    [anon_sym_PLUS] = ACTIONS(3469),
    [anon_sym_DASH] = ACTIONS(3469),
    [anon_sym_STAR] = ACTIONS(3471),
    [anon_sym_CARET] = ACTIONS(3471),
    [anon_sym_AMP] = ACTIONS(3471),
    [anon_sym_this] = ACTIONS(3469),
    [anon_sym_scoped] = ACTIONS(3469),
    [anon_sym_base] = ACTIONS(3469),
    [anon_sym_var] = ACTIONS(3469),
    [sym_predefined_type] = ACTIONS(3469),
    [anon_sym_break] = ACTIONS(3469),
    [anon_sym_unchecked] = ACTIONS(3469),
    [anon_sym_continue] = ACTIONS(3469),
    [anon_sym_do] = ACTIONS(3469),
    [anon_sym_while] = ACTIONS(3469),
    [anon_sym_for] = ACTIONS(3469),
    [anon_sym_lock] = ACTIONS(3469),
    [anon_sym_yield] = ACTIONS(3469),
    [anon_sym_switch] = ACTIONS(3469),
    [anon_sym_default] = ACTIONS(3469),
    [anon_sym_throw] = ACTIONS(3469),
    [anon_sym_try] = ACTIONS(3469),
    [anon_sym_when] = ACTIONS(3469),
    [anon_sym_await] = ACTIONS(3469),
    [anon_sym_foreach] = ACTIONS(3469),
    [anon_sym_goto] = ACTIONS(3469),
    [anon_sym_if] = ACTIONS(3469),
    [anon_sym_DOT_DOT] = ACTIONS(3471),
    [anon_sym_from] = ACTIONS(3469),
    [anon_sym_into] = ACTIONS(3469),
    [anon_sym_join] = ACTIONS(3469),
    [anon_sym_on] = ACTIONS(3469),
    [anon_sym_equals] = ACTIONS(3469),
    [anon_sym_let] = ACTIONS(3469),
    [anon_sym_orderby] = ACTIONS(3469),
    [anon_sym_ascending] = ACTIONS(3469),
    [anon_sym_descending] = ACTIONS(3469),
    [anon_sym_group] = ACTIONS(3469),
    [anon_sym_by] = ACTIONS(3469),
    [anon_sym_select] = ACTIONS(3469),
    [anon_sym_stackalloc] = ACTIONS(3469),
    [anon_sym_sizeof] = ACTIONS(3469),
    [anon_sym_typeof] = ACTIONS(3469),
    [anon_sym___makeref] = ACTIONS(3469),
    [anon_sym___reftype] = ACTIONS(3469),
    [anon_sym___refvalue] = ACTIONS(3469),
    [sym_null_literal] = ACTIONS(3469),
    [anon_sym_SQUOTE] = ACTIONS(3471),
    [sym_integer_literal] = ACTIONS(3469),
    [sym_real_literal] = ACTIONS(3471),
    [anon_sym_DQUOTE] = ACTIONS(3471),
    [sym_verbatim_string_literal] = ACTIONS(3471),
    [aux_sym_preproc_if_token1] = ACTIONS(3471),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3471),
    [sym_interpolation_verbatim_start] = ACTIONS(3471),
    [sym_interpolation_raw_start] = ACTIONS(3471),
    [sym_raw_string_start] = ACTIONS(3471),
  },
  [2638] = {
    [sym_preproc_region] = STATE(2638),
    [sym_preproc_endregion] = STATE(2638),
    [sym_preproc_line] = STATE(2638),
    [sym_preproc_pragma] = STATE(2638),
    [sym_preproc_nullable] = STATE(2638),
    [sym_preproc_error] = STATE(2638),
    [sym_preproc_warning] = STATE(2638),
    [sym_preproc_define] = STATE(2638),
    [sym_preproc_undef] = STATE(2638),
    [ts_builtin_sym_end] = ACTIONS(3475),
    [sym__identifier_token] = ACTIONS(3473),
    [anon_sym_extern] = ACTIONS(3473),
    [anon_sym_alias] = ACTIONS(3473),
    [anon_sym_SEMI] = ACTIONS(3475),
    [anon_sym_global] = ACTIONS(3473),
    [anon_sym_using] = ACTIONS(3473),
    [anon_sym_unsafe] = ACTIONS(3473),
    [anon_sym_static] = ACTIONS(3473),
    [anon_sym_LBRACK] = ACTIONS(3475),
    [anon_sym_LPAREN] = ACTIONS(3475),
    [anon_sym_return] = ACTIONS(3473),
    [anon_sym_namespace] = ACTIONS(3473),
    [anon_sym_class] = ACTIONS(3473),
    [anon_sym_ref] = ACTIONS(3473),
    [anon_sym_struct] = ACTIONS(3473),
    [anon_sym_enum] = ACTIONS(3473),
    [anon_sym_LBRACE] = ACTIONS(3475),
    [anon_sym_interface] = ACTIONS(3473),
    [anon_sym_delegate] = ACTIONS(3473),
    [anon_sym_record] = ACTIONS(3473),
    [anon_sym_abstract] = ACTIONS(3473),
    [anon_sym_async] = ACTIONS(3473),
    [anon_sym_const] = ACTIONS(3473),
    [anon_sym_file] = ACTIONS(3473),
    [anon_sym_fixed] = ACTIONS(3473),
    [anon_sym_internal] = ACTIONS(3473),
    [anon_sym_new] = ACTIONS(3473),
    [anon_sym_override] = ACTIONS(3473),
    [anon_sym_partial] = ACTIONS(3473),
    [anon_sym_private] = ACTIONS(3473),
    [anon_sym_protected] = ACTIONS(3473),
    [anon_sym_public] = ACTIONS(3473),
    [anon_sym_readonly] = ACTIONS(3473),
    [anon_sym_required] = ACTIONS(3473),
    [anon_sym_sealed] = ACTIONS(3473),
    [anon_sym_virtual] = ACTIONS(3473),
    [anon_sym_volatile] = ACTIONS(3473),
    [anon_sym_where] = ACTIONS(3473),
    [anon_sym_notnull] = ACTIONS(3473),
    [anon_sym_unmanaged] = ACTIONS(3473),
    [anon_sym_checked] = ACTIONS(3473),
    [anon_sym_BANG] = ACTIONS(3475),
    [anon_sym_TILDE] = ACTIONS(3475),
    [anon_sym_PLUS_PLUS] = ACTIONS(3475),
    [anon_sym_DASH_DASH] = ACTIONS(3475),
    [anon_sym_true] = ACTIONS(3473),
    [anon_sym_false] = ACTIONS(3473),
    [anon_sym_PLUS] = ACTIONS(3473),
    [anon_sym_DASH] = ACTIONS(3473),
    [anon_sym_STAR] = ACTIONS(3475),
    [anon_sym_CARET] = ACTIONS(3475),
    [anon_sym_AMP] = ACTIONS(3475),
    [anon_sym_this] = ACTIONS(3473),
    [anon_sym_scoped] = ACTIONS(3473),
    [anon_sym_base] = ACTIONS(3473),
    [anon_sym_var] = ACTIONS(3473),
    [sym_predefined_type] = ACTIONS(3473),
    [anon_sym_break] = ACTIONS(3473),
    [anon_sym_unchecked] = ACTIONS(3473),
    [anon_sym_continue] = ACTIONS(3473),
    [anon_sym_do] = ACTIONS(3473),
    [anon_sym_while] = ACTIONS(3473),
    [anon_sym_for] = ACTIONS(3473),
    [anon_sym_lock] = ACTIONS(3473),
    [anon_sym_yield] = ACTIONS(3473),
    [anon_sym_switch] = ACTIONS(3473),
    [anon_sym_default] = ACTIONS(3473),
    [anon_sym_throw] = ACTIONS(3473),
    [anon_sym_try] = ACTIONS(3473),
    [anon_sym_when] = ACTIONS(3473),
    [anon_sym_await] = ACTIONS(3473),
    [anon_sym_foreach] = ACTIONS(3473),
    [anon_sym_goto] = ACTIONS(3473),
    [anon_sym_if] = ACTIONS(3473),
    [anon_sym_DOT_DOT] = ACTIONS(3475),
    [anon_sym_from] = ACTIONS(3473),
    [anon_sym_into] = ACTIONS(3473),
    [anon_sym_join] = ACTIONS(3473),
    [anon_sym_on] = ACTIONS(3473),
    [anon_sym_equals] = ACTIONS(3473),
    [anon_sym_let] = ACTIONS(3473),
    [anon_sym_orderby] = ACTIONS(3473),
    [anon_sym_ascending] = ACTIONS(3473),
    [anon_sym_descending] = ACTIONS(3473),
    [anon_sym_group] = ACTIONS(3473),
    [anon_sym_by] = ACTIONS(3473),
    [anon_sym_select] = ACTIONS(3473),
    [anon_sym_stackalloc] = ACTIONS(3473),
    [anon_sym_sizeof] = ACTIONS(3473),
    [anon_sym_typeof] = ACTIONS(3473),
    [anon_sym___makeref] = ACTIONS(3473),
    [anon_sym___reftype] = ACTIONS(3473),
    [anon_sym___refvalue] = ACTIONS(3473),
    [sym_null_literal] = ACTIONS(3473),
    [anon_sym_SQUOTE] = ACTIONS(3475),
    [sym_integer_literal] = ACTIONS(3473),
    [sym_real_literal] = ACTIONS(3475),
    [anon_sym_DQUOTE] = ACTIONS(3475),
    [sym_verbatim_string_literal] = ACTIONS(3475),
    [aux_sym_preproc_if_token1] = ACTIONS(3475),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3475),
    [sym_interpolation_verbatim_start] = ACTIONS(3475),
    [sym_interpolation_raw_start] = ACTIONS(3475),
    [sym_raw_string_start] = ACTIONS(3475),
  },
  [2639] = {
    [sym_preproc_region] = STATE(2639),
    [sym_preproc_endregion] = STATE(2639),
    [sym_preproc_line] = STATE(2639),
    [sym_preproc_pragma] = STATE(2639),
    [sym_preproc_nullable] = STATE(2639),
    [sym_preproc_error] = STATE(2639),
    [sym_preproc_warning] = STATE(2639),
    [sym_preproc_define] = STATE(2639),
    [sym_preproc_undef] = STATE(2639),
    [ts_builtin_sym_end] = ACTIONS(3479),
    [sym__identifier_token] = ACTIONS(3477),
    [anon_sym_extern] = ACTIONS(3477),
    [anon_sym_alias] = ACTIONS(3477),
    [anon_sym_SEMI] = ACTIONS(3479),
    [anon_sym_global] = ACTIONS(3477),
    [anon_sym_using] = ACTIONS(3477),
    [anon_sym_unsafe] = ACTIONS(3477),
    [anon_sym_static] = ACTIONS(3477),
    [anon_sym_LBRACK] = ACTIONS(3479),
    [anon_sym_LPAREN] = ACTIONS(3479),
    [anon_sym_return] = ACTIONS(3477),
    [anon_sym_namespace] = ACTIONS(3477),
    [anon_sym_class] = ACTIONS(3477),
    [anon_sym_ref] = ACTIONS(3477),
    [anon_sym_struct] = ACTIONS(3477),
    [anon_sym_enum] = ACTIONS(3477),
    [anon_sym_LBRACE] = ACTIONS(3479),
    [anon_sym_interface] = ACTIONS(3477),
    [anon_sym_delegate] = ACTIONS(3477),
    [anon_sym_record] = ACTIONS(3477),
    [anon_sym_abstract] = ACTIONS(3477),
    [anon_sym_async] = ACTIONS(3477),
    [anon_sym_const] = ACTIONS(3477),
    [anon_sym_file] = ACTIONS(3477),
    [anon_sym_fixed] = ACTIONS(3477),
    [anon_sym_internal] = ACTIONS(3477),
    [anon_sym_new] = ACTIONS(3477),
    [anon_sym_override] = ACTIONS(3477),
    [anon_sym_partial] = ACTIONS(3477),
    [anon_sym_private] = ACTIONS(3477),
    [anon_sym_protected] = ACTIONS(3477),
    [anon_sym_public] = ACTIONS(3477),
    [anon_sym_readonly] = ACTIONS(3477),
    [anon_sym_required] = ACTIONS(3477),
    [anon_sym_sealed] = ACTIONS(3477),
    [anon_sym_virtual] = ACTIONS(3477),
    [anon_sym_volatile] = ACTIONS(3477),
    [anon_sym_where] = ACTIONS(3477),
    [anon_sym_notnull] = ACTIONS(3477),
    [anon_sym_unmanaged] = ACTIONS(3477),
    [anon_sym_checked] = ACTIONS(3477),
    [anon_sym_BANG] = ACTIONS(3479),
    [anon_sym_TILDE] = ACTIONS(3479),
    [anon_sym_PLUS_PLUS] = ACTIONS(3479),
    [anon_sym_DASH_DASH] = ACTIONS(3479),
    [anon_sym_true] = ACTIONS(3477),
    [anon_sym_false] = ACTIONS(3477),
    [anon_sym_PLUS] = ACTIONS(3477),
    [anon_sym_DASH] = ACTIONS(3477),
    [anon_sym_STAR] = ACTIONS(3479),
    [anon_sym_CARET] = ACTIONS(3479),
    [anon_sym_AMP] = ACTIONS(3479),
    [anon_sym_this] = ACTIONS(3477),
    [anon_sym_scoped] = ACTIONS(3477),
    [anon_sym_base] = ACTIONS(3477),
    [anon_sym_var] = ACTIONS(3477),
    [sym_predefined_type] = ACTIONS(3477),
    [anon_sym_break] = ACTIONS(3477),
    [anon_sym_unchecked] = ACTIONS(3477),
    [anon_sym_continue] = ACTIONS(3477),
    [anon_sym_do] = ACTIONS(3477),
    [anon_sym_while] = ACTIONS(3477),
    [anon_sym_for] = ACTIONS(3477),
    [anon_sym_lock] = ACTIONS(3477),
    [anon_sym_yield] = ACTIONS(3477),
    [anon_sym_switch] = ACTIONS(3477),
    [anon_sym_default] = ACTIONS(3477),
    [anon_sym_throw] = ACTIONS(3477),
    [anon_sym_try] = ACTIONS(3477),
    [anon_sym_when] = ACTIONS(3477),
    [anon_sym_await] = ACTIONS(3477),
    [anon_sym_foreach] = ACTIONS(3477),
    [anon_sym_goto] = ACTIONS(3477),
    [anon_sym_if] = ACTIONS(3477),
    [anon_sym_DOT_DOT] = ACTIONS(3479),
    [anon_sym_from] = ACTIONS(3477),
    [anon_sym_into] = ACTIONS(3477),
    [anon_sym_join] = ACTIONS(3477),
    [anon_sym_on] = ACTIONS(3477),
    [anon_sym_equals] = ACTIONS(3477),
    [anon_sym_let] = ACTIONS(3477),
    [anon_sym_orderby] = ACTIONS(3477),
    [anon_sym_ascending] = ACTIONS(3477),
    [anon_sym_descending] = ACTIONS(3477),
    [anon_sym_group] = ACTIONS(3477),
    [anon_sym_by] = ACTIONS(3477),
    [anon_sym_select] = ACTIONS(3477),
    [anon_sym_stackalloc] = ACTIONS(3477),
    [anon_sym_sizeof] = ACTIONS(3477),
    [anon_sym_typeof] = ACTIONS(3477),
    [anon_sym___makeref] = ACTIONS(3477),
    [anon_sym___reftype] = ACTIONS(3477),
    [anon_sym___refvalue] = ACTIONS(3477),
    [sym_null_literal] = ACTIONS(3477),
    [anon_sym_SQUOTE] = ACTIONS(3479),
    [sym_integer_literal] = ACTIONS(3477),
    [sym_real_literal] = ACTIONS(3479),
    [anon_sym_DQUOTE] = ACTIONS(3479),
    [sym_verbatim_string_literal] = ACTIONS(3479),
    [aux_sym_preproc_if_token1] = ACTIONS(3479),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3479),
    [sym_interpolation_verbatim_start] = ACTIONS(3479),
    [sym_interpolation_raw_start] = ACTIONS(3479),
    [sym_raw_string_start] = ACTIONS(3479),
  },
  [2640] = {
    [sym_preproc_region] = STATE(2640),
    [sym_preproc_endregion] = STATE(2640),
    [sym_preproc_line] = STATE(2640),
    [sym_preproc_pragma] = STATE(2640),
    [sym_preproc_nullable] = STATE(2640),
    [sym_preproc_error] = STATE(2640),
    [sym_preproc_warning] = STATE(2640),
    [sym_preproc_define] = STATE(2640),
    [sym_preproc_undef] = STATE(2640),
    [ts_builtin_sym_end] = ACTIONS(3483),
    [sym__identifier_token] = ACTIONS(3481),
    [anon_sym_extern] = ACTIONS(3481),
    [anon_sym_alias] = ACTIONS(3481),
    [anon_sym_SEMI] = ACTIONS(3483),
    [anon_sym_global] = ACTIONS(3481),
    [anon_sym_using] = ACTIONS(3481),
    [anon_sym_unsafe] = ACTIONS(3481),
    [anon_sym_static] = ACTIONS(3481),
    [anon_sym_LBRACK] = ACTIONS(3483),
    [anon_sym_LPAREN] = ACTIONS(3483),
    [anon_sym_return] = ACTIONS(3481),
    [anon_sym_namespace] = ACTIONS(3481),
    [anon_sym_class] = ACTIONS(3481),
    [anon_sym_ref] = ACTIONS(3481),
    [anon_sym_struct] = ACTIONS(3481),
    [anon_sym_enum] = ACTIONS(3481),
    [anon_sym_LBRACE] = ACTIONS(3483),
    [anon_sym_interface] = ACTIONS(3481),
    [anon_sym_delegate] = ACTIONS(3481),
    [anon_sym_record] = ACTIONS(3481),
    [anon_sym_abstract] = ACTIONS(3481),
    [anon_sym_async] = ACTIONS(3481),
    [anon_sym_const] = ACTIONS(3481),
    [anon_sym_file] = ACTIONS(3481),
    [anon_sym_fixed] = ACTIONS(3481),
    [anon_sym_internal] = ACTIONS(3481),
    [anon_sym_new] = ACTIONS(3481),
    [anon_sym_override] = ACTIONS(3481),
    [anon_sym_partial] = ACTIONS(3481),
    [anon_sym_private] = ACTIONS(3481),
    [anon_sym_protected] = ACTIONS(3481),
    [anon_sym_public] = ACTIONS(3481),
    [anon_sym_readonly] = ACTIONS(3481),
    [anon_sym_required] = ACTIONS(3481),
    [anon_sym_sealed] = ACTIONS(3481),
    [anon_sym_virtual] = ACTIONS(3481),
    [anon_sym_volatile] = ACTIONS(3481),
    [anon_sym_where] = ACTIONS(3481),
    [anon_sym_notnull] = ACTIONS(3481),
    [anon_sym_unmanaged] = ACTIONS(3481),
    [anon_sym_checked] = ACTIONS(3481),
    [anon_sym_BANG] = ACTIONS(3483),
    [anon_sym_TILDE] = ACTIONS(3483),
    [anon_sym_PLUS_PLUS] = ACTIONS(3483),
    [anon_sym_DASH_DASH] = ACTIONS(3483),
    [anon_sym_true] = ACTIONS(3481),
    [anon_sym_false] = ACTIONS(3481),
    [anon_sym_PLUS] = ACTIONS(3481),
    [anon_sym_DASH] = ACTIONS(3481),
    [anon_sym_STAR] = ACTIONS(3483),
    [anon_sym_CARET] = ACTIONS(3483),
    [anon_sym_AMP] = ACTIONS(3483),
    [anon_sym_this] = ACTIONS(3481),
    [anon_sym_scoped] = ACTIONS(3481),
    [anon_sym_base] = ACTIONS(3481),
    [anon_sym_var] = ACTIONS(3481),
    [sym_predefined_type] = ACTIONS(3481),
    [anon_sym_break] = ACTIONS(3481),
    [anon_sym_unchecked] = ACTIONS(3481),
    [anon_sym_continue] = ACTIONS(3481),
    [anon_sym_do] = ACTIONS(3481),
    [anon_sym_while] = ACTIONS(3481),
    [anon_sym_for] = ACTIONS(3481),
    [anon_sym_lock] = ACTIONS(3481),
    [anon_sym_yield] = ACTIONS(3481),
    [anon_sym_switch] = ACTIONS(3481),
    [anon_sym_default] = ACTIONS(3481),
    [anon_sym_throw] = ACTIONS(3481),
    [anon_sym_try] = ACTIONS(3481),
    [anon_sym_when] = ACTIONS(3481),
    [anon_sym_await] = ACTIONS(3481),
    [anon_sym_foreach] = ACTIONS(3481),
    [anon_sym_goto] = ACTIONS(3481),
    [anon_sym_if] = ACTIONS(3481),
    [anon_sym_DOT_DOT] = ACTIONS(3483),
    [anon_sym_from] = ACTIONS(3481),
    [anon_sym_into] = ACTIONS(3481),
    [anon_sym_join] = ACTIONS(3481),
    [anon_sym_on] = ACTIONS(3481),
    [anon_sym_equals] = ACTIONS(3481),
    [anon_sym_let] = ACTIONS(3481),
    [anon_sym_orderby] = ACTIONS(3481),
    [anon_sym_ascending] = ACTIONS(3481),
    [anon_sym_descending] = ACTIONS(3481),
    [anon_sym_group] = ACTIONS(3481),
    [anon_sym_by] = ACTIONS(3481),
    [anon_sym_select] = ACTIONS(3481),
    [anon_sym_stackalloc] = ACTIONS(3481),
    [anon_sym_sizeof] = ACTIONS(3481),
    [anon_sym_typeof] = ACTIONS(3481),
    [anon_sym___makeref] = ACTIONS(3481),
    [anon_sym___reftype] = ACTIONS(3481),
    [anon_sym___refvalue] = ACTIONS(3481),
    [sym_null_literal] = ACTIONS(3481),
    [anon_sym_SQUOTE] = ACTIONS(3483),
    [sym_integer_literal] = ACTIONS(3481),
    [sym_real_literal] = ACTIONS(3483),
    [anon_sym_DQUOTE] = ACTIONS(3483),
    [sym_verbatim_string_literal] = ACTIONS(3483),
    [aux_sym_preproc_if_token1] = ACTIONS(3483),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3483),
    [sym_interpolation_verbatim_start] = ACTIONS(3483),
    [sym_interpolation_raw_start] = ACTIONS(3483),
    [sym_raw_string_start] = ACTIONS(3483),
  },
  [2641] = {
    [sym_preproc_region] = STATE(2641),
    [sym_preproc_endregion] = STATE(2641),
    [sym_preproc_line] = STATE(2641),
    [sym_preproc_pragma] = STATE(2641),
    [sym_preproc_nullable] = STATE(2641),
    [sym_preproc_error] = STATE(2641),
    [sym_preproc_warning] = STATE(2641),
    [sym_preproc_define] = STATE(2641),
    [sym_preproc_undef] = STATE(2641),
    [ts_builtin_sym_end] = ACTIONS(3487),
    [sym__identifier_token] = ACTIONS(3485),
    [anon_sym_extern] = ACTIONS(3485),
    [anon_sym_alias] = ACTIONS(3485),
    [anon_sym_SEMI] = ACTIONS(3487),
    [anon_sym_global] = ACTIONS(3485),
    [anon_sym_using] = ACTIONS(3485),
    [anon_sym_unsafe] = ACTIONS(3485),
    [anon_sym_static] = ACTIONS(3485),
    [anon_sym_LBRACK] = ACTIONS(3487),
    [anon_sym_LPAREN] = ACTIONS(3487),
    [anon_sym_return] = ACTIONS(3485),
    [anon_sym_namespace] = ACTIONS(3485),
    [anon_sym_class] = ACTIONS(3485),
    [anon_sym_ref] = ACTIONS(3485),
    [anon_sym_struct] = ACTIONS(3485),
    [anon_sym_enum] = ACTIONS(3485),
    [anon_sym_LBRACE] = ACTIONS(3487),
    [anon_sym_interface] = ACTIONS(3485),
    [anon_sym_delegate] = ACTIONS(3485),
    [anon_sym_record] = ACTIONS(3485),
    [anon_sym_abstract] = ACTIONS(3485),
    [anon_sym_async] = ACTIONS(3485),
    [anon_sym_const] = ACTIONS(3485),
    [anon_sym_file] = ACTIONS(3485),
    [anon_sym_fixed] = ACTIONS(3485),
    [anon_sym_internal] = ACTIONS(3485),
    [anon_sym_new] = ACTIONS(3485),
    [anon_sym_override] = ACTIONS(3485),
    [anon_sym_partial] = ACTIONS(3485),
    [anon_sym_private] = ACTIONS(3485),
    [anon_sym_protected] = ACTIONS(3485),
    [anon_sym_public] = ACTIONS(3485),
    [anon_sym_readonly] = ACTIONS(3485),
    [anon_sym_required] = ACTIONS(3485),
    [anon_sym_sealed] = ACTIONS(3485),
    [anon_sym_virtual] = ACTIONS(3485),
    [anon_sym_volatile] = ACTIONS(3485),
    [anon_sym_where] = ACTIONS(3485),
    [anon_sym_notnull] = ACTIONS(3485),
    [anon_sym_unmanaged] = ACTIONS(3485),
    [anon_sym_checked] = ACTIONS(3485),
    [anon_sym_BANG] = ACTIONS(3487),
    [anon_sym_TILDE] = ACTIONS(3487),
    [anon_sym_PLUS_PLUS] = ACTIONS(3487),
    [anon_sym_DASH_DASH] = ACTIONS(3487),
    [anon_sym_true] = ACTIONS(3485),
    [anon_sym_false] = ACTIONS(3485),
    [anon_sym_PLUS] = ACTIONS(3485),
    [anon_sym_DASH] = ACTIONS(3485),
    [anon_sym_STAR] = ACTIONS(3487),
    [anon_sym_CARET] = ACTIONS(3487),
    [anon_sym_AMP] = ACTIONS(3487),
    [anon_sym_this] = ACTIONS(3485),
    [anon_sym_scoped] = ACTIONS(3485),
    [anon_sym_base] = ACTIONS(3485),
    [anon_sym_var] = ACTIONS(3485),
    [sym_predefined_type] = ACTIONS(3485),
    [anon_sym_break] = ACTIONS(3485),
    [anon_sym_unchecked] = ACTIONS(3485),
    [anon_sym_continue] = ACTIONS(3485),
    [anon_sym_do] = ACTIONS(3485),
    [anon_sym_while] = ACTIONS(3485),
    [anon_sym_for] = ACTIONS(3485),
    [anon_sym_lock] = ACTIONS(3485),
    [anon_sym_yield] = ACTIONS(3485),
    [anon_sym_switch] = ACTIONS(3485),
    [anon_sym_default] = ACTIONS(3485),
    [anon_sym_throw] = ACTIONS(3485),
    [anon_sym_try] = ACTIONS(3485),
    [anon_sym_when] = ACTIONS(3485),
    [anon_sym_await] = ACTIONS(3485),
    [anon_sym_foreach] = ACTIONS(3485),
    [anon_sym_goto] = ACTIONS(3485),
    [anon_sym_if] = ACTIONS(3485),
    [anon_sym_DOT_DOT] = ACTIONS(3487),
    [anon_sym_from] = ACTIONS(3485),
    [anon_sym_into] = ACTIONS(3485),
    [anon_sym_join] = ACTIONS(3485),
    [anon_sym_on] = ACTIONS(3485),
    [anon_sym_equals] = ACTIONS(3485),
    [anon_sym_let] = ACTIONS(3485),
    [anon_sym_orderby] = ACTIONS(3485),
    [anon_sym_ascending] = ACTIONS(3485),
    [anon_sym_descending] = ACTIONS(3485),
    [anon_sym_group] = ACTIONS(3485),
    [anon_sym_by] = ACTIONS(3485),
    [anon_sym_select] = ACTIONS(3485),
    [anon_sym_stackalloc] = ACTIONS(3485),
    [anon_sym_sizeof] = ACTIONS(3485),
    [anon_sym_typeof] = ACTIONS(3485),
    [anon_sym___makeref] = ACTIONS(3485),
    [anon_sym___reftype] = ACTIONS(3485),
    [anon_sym___refvalue] = ACTIONS(3485),
    [sym_null_literal] = ACTIONS(3485),
    [anon_sym_SQUOTE] = ACTIONS(3487),
    [sym_integer_literal] = ACTIONS(3485),
    [sym_real_literal] = ACTIONS(3487),
    [anon_sym_DQUOTE] = ACTIONS(3487),
    [sym_verbatim_string_literal] = ACTIONS(3487),
    [aux_sym_preproc_if_token1] = ACTIONS(3487),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3487),
    [sym_interpolation_verbatim_start] = ACTIONS(3487),
    [sym_interpolation_raw_start] = ACTIONS(3487),
    [sym_raw_string_start] = ACTIONS(3487),
  },
  [2642] = {
    [sym_preproc_region] = STATE(2642),
    [sym_preproc_endregion] = STATE(2642),
    [sym_preproc_line] = STATE(2642),
    [sym_preproc_pragma] = STATE(2642),
    [sym_preproc_nullable] = STATE(2642),
    [sym_preproc_error] = STATE(2642),
    [sym_preproc_warning] = STATE(2642),
    [sym_preproc_define] = STATE(2642),
    [sym_preproc_undef] = STATE(2642),
    [ts_builtin_sym_end] = ACTIONS(3941),
    [sym__identifier_token] = ACTIONS(3939),
    [anon_sym_extern] = ACTIONS(3939),
    [anon_sym_alias] = ACTIONS(3939),
    [anon_sym_SEMI] = ACTIONS(3941),
    [anon_sym_global] = ACTIONS(3939),
    [anon_sym_using] = ACTIONS(3939),
    [anon_sym_unsafe] = ACTIONS(3939),
    [anon_sym_static] = ACTIONS(3939),
    [anon_sym_LBRACK] = ACTIONS(3941),
    [anon_sym_LPAREN] = ACTIONS(3941),
    [anon_sym_return] = ACTIONS(3939),
    [anon_sym_namespace] = ACTIONS(3939),
    [anon_sym_class] = ACTIONS(3939),
    [anon_sym_ref] = ACTIONS(3939),
    [anon_sym_struct] = ACTIONS(3939),
    [anon_sym_enum] = ACTIONS(3939),
    [anon_sym_LBRACE] = ACTIONS(3941),
    [anon_sym_interface] = ACTIONS(3939),
    [anon_sym_delegate] = ACTIONS(3939),
    [anon_sym_record] = ACTIONS(3939),
    [anon_sym_abstract] = ACTIONS(3939),
    [anon_sym_async] = ACTIONS(3939),
    [anon_sym_const] = ACTIONS(3939),
    [anon_sym_file] = ACTIONS(3939),
    [anon_sym_fixed] = ACTIONS(3939),
    [anon_sym_internal] = ACTIONS(3939),
    [anon_sym_new] = ACTIONS(3939),
    [anon_sym_override] = ACTIONS(3939),
    [anon_sym_partial] = ACTIONS(3939),
    [anon_sym_private] = ACTIONS(3939),
    [anon_sym_protected] = ACTIONS(3939),
    [anon_sym_public] = ACTIONS(3939),
    [anon_sym_readonly] = ACTIONS(3939),
    [anon_sym_required] = ACTIONS(3939),
    [anon_sym_sealed] = ACTIONS(3939),
    [anon_sym_virtual] = ACTIONS(3939),
    [anon_sym_volatile] = ACTIONS(3939),
    [anon_sym_where] = ACTIONS(3939),
    [anon_sym_notnull] = ACTIONS(3939),
    [anon_sym_unmanaged] = ACTIONS(3939),
    [anon_sym_checked] = ACTIONS(3939),
    [anon_sym_BANG] = ACTIONS(3941),
    [anon_sym_TILDE] = ACTIONS(3941),
    [anon_sym_PLUS_PLUS] = ACTIONS(3941),
    [anon_sym_DASH_DASH] = ACTIONS(3941),
    [anon_sym_true] = ACTIONS(3939),
    [anon_sym_false] = ACTIONS(3939),
    [anon_sym_PLUS] = ACTIONS(3939),
    [anon_sym_DASH] = ACTIONS(3939),
    [anon_sym_STAR] = ACTIONS(3941),
    [anon_sym_CARET] = ACTIONS(3941),
    [anon_sym_AMP] = ACTIONS(3941),
    [anon_sym_this] = ACTIONS(3939),
    [anon_sym_scoped] = ACTIONS(3939),
    [anon_sym_base] = ACTIONS(3939),
    [anon_sym_var] = ACTIONS(3939),
    [sym_predefined_type] = ACTIONS(3939),
    [anon_sym_break] = ACTIONS(3939),
    [anon_sym_unchecked] = ACTIONS(3939),
    [anon_sym_continue] = ACTIONS(3939),
    [anon_sym_do] = ACTIONS(3939),
    [anon_sym_while] = ACTIONS(3939),
    [anon_sym_for] = ACTIONS(3939),
    [anon_sym_lock] = ACTIONS(3939),
    [anon_sym_yield] = ACTIONS(3939),
    [anon_sym_switch] = ACTIONS(3939),
    [anon_sym_default] = ACTIONS(3939),
    [anon_sym_throw] = ACTIONS(3939),
    [anon_sym_try] = ACTIONS(3939),
    [anon_sym_when] = ACTIONS(3939),
    [anon_sym_await] = ACTIONS(3939),
    [anon_sym_foreach] = ACTIONS(3939),
    [anon_sym_goto] = ACTIONS(3939),
    [anon_sym_if] = ACTIONS(3939),
    [anon_sym_DOT_DOT] = ACTIONS(3941),
    [anon_sym_from] = ACTIONS(3939),
    [anon_sym_into] = ACTIONS(3939),
    [anon_sym_join] = ACTIONS(3939),
    [anon_sym_on] = ACTIONS(3939),
    [anon_sym_equals] = ACTIONS(3939),
    [anon_sym_let] = ACTIONS(3939),
    [anon_sym_orderby] = ACTIONS(3939),
    [anon_sym_ascending] = ACTIONS(3939),
    [anon_sym_descending] = ACTIONS(3939),
    [anon_sym_group] = ACTIONS(3939),
    [anon_sym_by] = ACTIONS(3939),
    [anon_sym_select] = ACTIONS(3939),
    [anon_sym_stackalloc] = ACTIONS(3939),
    [anon_sym_sizeof] = ACTIONS(3939),
    [anon_sym_typeof] = ACTIONS(3939),
    [anon_sym___makeref] = ACTIONS(3939),
    [anon_sym___reftype] = ACTIONS(3939),
    [anon_sym___refvalue] = ACTIONS(3939),
    [sym_null_literal] = ACTIONS(3939),
    [anon_sym_SQUOTE] = ACTIONS(3941),
    [sym_integer_literal] = ACTIONS(3939),
    [sym_real_literal] = ACTIONS(3941),
    [anon_sym_DQUOTE] = ACTIONS(3941),
    [sym_verbatim_string_literal] = ACTIONS(3941),
    [aux_sym_preproc_if_token1] = ACTIONS(3941),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3941),
    [sym_interpolation_verbatim_start] = ACTIONS(3941),
    [sym_interpolation_raw_start] = ACTIONS(3941),
    [sym_raw_string_start] = ACTIONS(3941),
  },
  [2643] = {
    [sym_preproc_region] = STATE(2643),
    [sym_preproc_endregion] = STATE(2643),
    [sym_preproc_line] = STATE(2643),
    [sym_preproc_pragma] = STATE(2643),
    [sym_preproc_nullable] = STATE(2643),
    [sym_preproc_error] = STATE(2643),
    [sym_preproc_warning] = STATE(2643),
    [sym_preproc_define] = STATE(2643),
    [sym_preproc_undef] = STATE(2643),
    [ts_builtin_sym_end] = ACTIONS(3627),
    [sym__identifier_token] = ACTIONS(3625),
    [anon_sym_extern] = ACTIONS(3625),
    [anon_sym_alias] = ACTIONS(3625),
    [anon_sym_SEMI] = ACTIONS(3627),
    [anon_sym_global] = ACTIONS(3625),
    [anon_sym_using] = ACTIONS(3625),
    [anon_sym_unsafe] = ACTIONS(3625),
    [anon_sym_static] = ACTIONS(3625),
    [anon_sym_LBRACK] = ACTIONS(3627),
    [anon_sym_LPAREN] = ACTIONS(3627),
    [anon_sym_return] = ACTIONS(3625),
    [anon_sym_namespace] = ACTIONS(3625),
    [anon_sym_class] = ACTIONS(3625),
    [anon_sym_ref] = ACTIONS(3625),
    [anon_sym_struct] = ACTIONS(3625),
    [anon_sym_enum] = ACTIONS(3625),
    [anon_sym_LBRACE] = ACTIONS(3627),
    [anon_sym_interface] = ACTIONS(3625),
    [anon_sym_delegate] = ACTIONS(3625),
    [anon_sym_record] = ACTIONS(3625),
    [anon_sym_abstract] = ACTIONS(3625),
    [anon_sym_async] = ACTIONS(3625),
    [anon_sym_const] = ACTIONS(3625),
    [anon_sym_file] = ACTIONS(3625),
    [anon_sym_fixed] = ACTIONS(3625),
    [anon_sym_internal] = ACTIONS(3625),
    [anon_sym_new] = ACTIONS(3625),
    [anon_sym_override] = ACTIONS(3625),
    [anon_sym_partial] = ACTIONS(3625),
    [anon_sym_private] = ACTIONS(3625),
    [anon_sym_protected] = ACTIONS(3625),
    [anon_sym_public] = ACTIONS(3625),
    [anon_sym_readonly] = ACTIONS(3625),
    [anon_sym_required] = ACTIONS(3625),
    [anon_sym_sealed] = ACTIONS(3625),
    [anon_sym_virtual] = ACTIONS(3625),
    [anon_sym_volatile] = ACTIONS(3625),
    [anon_sym_where] = ACTIONS(3625),
    [anon_sym_notnull] = ACTIONS(3625),
    [anon_sym_unmanaged] = ACTIONS(3625),
    [anon_sym_checked] = ACTIONS(3625),
    [anon_sym_BANG] = ACTIONS(3627),
    [anon_sym_TILDE] = ACTIONS(3627),
    [anon_sym_PLUS_PLUS] = ACTIONS(3627),
    [anon_sym_DASH_DASH] = ACTIONS(3627),
    [anon_sym_true] = ACTIONS(3625),
    [anon_sym_false] = ACTIONS(3625),
    [anon_sym_PLUS] = ACTIONS(3625),
    [anon_sym_DASH] = ACTIONS(3625),
    [anon_sym_STAR] = ACTIONS(3627),
    [anon_sym_CARET] = ACTIONS(3627),
    [anon_sym_AMP] = ACTIONS(3627),
    [anon_sym_this] = ACTIONS(3625),
    [anon_sym_scoped] = ACTIONS(3625),
    [anon_sym_base] = ACTIONS(3625),
    [anon_sym_var] = ACTIONS(3625),
    [sym_predefined_type] = ACTIONS(3625),
    [anon_sym_break] = ACTIONS(3625),
    [anon_sym_unchecked] = ACTIONS(3625),
    [anon_sym_continue] = ACTIONS(3625),
    [anon_sym_do] = ACTIONS(3625),
    [anon_sym_while] = ACTIONS(3625),
    [anon_sym_for] = ACTIONS(3625),
    [anon_sym_lock] = ACTIONS(3625),
    [anon_sym_yield] = ACTIONS(3625),
    [anon_sym_switch] = ACTIONS(3625),
    [anon_sym_default] = ACTIONS(3625),
    [anon_sym_throw] = ACTIONS(3625),
    [anon_sym_try] = ACTIONS(3625),
    [anon_sym_when] = ACTIONS(3625),
    [anon_sym_await] = ACTIONS(3625),
    [anon_sym_foreach] = ACTIONS(3625),
    [anon_sym_goto] = ACTIONS(3625),
    [anon_sym_if] = ACTIONS(3625),
    [anon_sym_DOT_DOT] = ACTIONS(3627),
    [anon_sym_from] = ACTIONS(3625),
    [anon_sym_into] = ACTIONS(3625),
    [anon_sym_join] = ACTIONS(3625),
    [anon_sym_on] = ACTIONS(3625),
    [anon_sym_equals] = ACTIONS(3625),
    [anon_sym_let] = ACTIONS(3625),
    [anon_sym_orderby] = ACTIONS(3625),
    [anon_sym_ascending] = ACTIONS(3625),
    [anon_sym_descending] = ACTIONS(3625),
    [anon_sym_group] = ACTIONS(3625),
    [anon_sym_by] = ACTIONS(3625),
    [anon_sym_select] = ACTIONS(3625),
    [anon_sym_stackalloc] = ACTIONS(3625),
    [anon_sym_sizeof] = ACTIONS(3625),
    [anon_sym_typeof] = ACTIONS(3625),
    [anon_sym___makeref] = ACTIONS(3625),
    [anon_sym___reftype] = ACTIONS(3625),
    [anon_sym___refvalue] = ACTIONS(3625),
    [sym_null_literal] = ACTIONS(3625),
    [anon_sym_SQUOTE] = ACTIONS(3627),
    [sym_integer_literal] = ACTIONS(3625),
    [sym_real_literal] = ACTIONS(3627),
    [anon_sym_DQUOTE] = ACTIONS(3627),
    [sym_verbatim_string_literal] = ACTIONS(3627),
    [aux_sym_preproc_if_token1] = ACTIONS(3627),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3627),
    [sym_interpolation_verbatim_start] = ACTIONS(3627),
    [sym_interpolation_raw_start] = ACTIONS(3627),
    [sym_raw_string_start] = ACTIONS(3627),
  },
  [2644] = {
    [sym_using_directive] = STATE(3324),
    [sym_attribute_list] = STATE(3740),
    [sym_namespace_declaration] = STATE(3324),
    [sym_class_declaration] = STATE(3324),
    [sym_struct_declaration] = STATE(3324),
    [sym_enum_declaration] = STATE(3324),
    [sym_interface_declaration] = STATE(3324),
    [sym_delegate_declaration] = STATE(3324),
    [sym_record_declaration] = STATE(3324),
    [sym_modifier] = STATE(3807),
    [sym_operator_declaration] = STATE(3324),
    [sym_conversion_operator_declaration] = STATE(3324),
    [sym_declaration] = STATE(3327),
    [sym_field_declaration] = STATE(3324),
    [sym_constructor_declaration] = STATE(3324),
    [sym_destructor_declaration] = STATE(3324),
    [sym_method_declaration] = STATE(3324),
    [sym_event_declaration] = STATE(3324),
    [sym_event_field_declaration] = STATE(3324),
    [sym_indexer_declaration] = STATE(3324),
    [sym_property_declaration] = STATE(3324),
    [sym_variable_declaration] = STATE(8996),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(6582),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(6750),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_if] = STATE(3324),
    [sym_preproc_region] = STATE(2644),
    [sym_preproc_endregion] = STATE(2644),
    [sym_preproc_line] = STATE(2644),
    [sym_preproc_pragma] = STATE(2644),
    [sym_preproc_nullable] = STATE(2644),
    [sym_preproc_error] = STATE(2644),
    [sym_preproc_warning] = STATE(2644),
    [sym_preproc_define] = STATE(2644),
    [sym_preproc_undef] = STATE(2644),
    [aux_sym_class_declaration_repeat1] = STATE(2781),
    [aux_sym_class_declaration_repeat2] = STATE(2857),
    [aux_sym_declaration_list_repeat1] = STATE(2422),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_extern] = ACTIONS(3195),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3199),
    [anon_sym_using] = ACTIONS(3201),
    [anon_sym_unsafe] = ACTIONS(65),
    [anon_sym_static] = ACTIONS(65),
    [anon_sym_LBRACK] = ACTIONS(3203),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_event] = ACTIONS(3207),
    [anon_sym_namespace] = ACTIONS(3209),
    [anon_sym_class] = ACTIONS(3211),
    [anon_sym_ref] = ACTIONS(3213),
    [anon_sym_struct] = ACTIONS(3215),
    [anon_sym_enum] = ACTIONS(3217),
    [anon_sym_RBRACE] = ACTIONS(4031),
    [anon_sym_interface] = ACTIONS(3219),
    [anon_sym_delegate] = ACTIONS(3221),
    [anon_sym_record] = ACTIONS(3223),
    [anon_sym_abstract] = ACTIONS(65),
    [anon_sym_async] = ACTIONS(65),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_file] = ACTIONS(3225),
    [anon_sym_fixed] = ACTIONS(65),
    [anon_sym_internal] = ACTIONS(65),
    [anon_sym_new] = ACTIONS(65),
    [anon_sym_override] = ACTIONS(65),
    [anon_sym_partial] = ACTIONS(65),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_public] = ACTIONS(65),
    [anon_sym_readonly] = ACTIONS(65),
    [anon_sym_required] = ACTIONS(65),
    [anon_sym_sealed] = ACTIONS(65),
    [anon_sym_virtual] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_TILDE] = ACTIONS(3227),
    [anon_sym_implicit] = ACTIONS(3229),
    [anon_sym_explicit] = ACTIONS(3229),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_if_token1] = ACTIONS(3237),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2645] = {
    [sym_using_directive] = STATE(3324),
    [sym_attribute_list] = STATE(3740),
    [sym_namespace_declaration] = STATE(3324),
    [sym_class_declaration] = STATE(3324),
    [sym_struct_declaration] = STATE(3324),
    [sym_enum_declaration] = STATE(3324),
    [sym_interface_declaration] = STATE(3324),
    [sym_delegate_declaration] = STATE(3324),
    [sym_record_declaration] = STATE(3324),
    [sym_modifier] = STATE(3807),
    [sym_operator_declaration] = STATE(3324),
    [sym_conversion_operator_declaration] = STATE(3324),
    [sym_declaration] = STATE(3327),
    [sym_field_declaration] = STATE(3324),
    [sym_constructor_declaration] = STATE(3324),
    [sym_destructor_declaration] = STATE(3324),
    [sym_method_declaration] = STATE(3324),
    [sym_event_declaration] = STATE(3324),
    [sym_event_field_declaration] = STATE(3324),
    [sym_indexer_declaration] = STATE(3324),
    [sym_property_declaration] = STATE(3324),
    [sym_variable_declaration] = STATE(8996),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(6582),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(6750),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_if] = STATE(3324),
    [sym_preproc_region] = STATE(2645),
    [sym_preproc_endregion] = STATE(2645),
    [sym_preproc_line] = STATE(2645),
    [sym_preproc_pragma] = STATE(2645),
    [sym_preproc_nullable] = STATE(2645),
    [sym_preproc_error] = STATE(2645),
    [sym_preproc_warning] = STATE(2645),
    [sym_preproc_define] = STATE(2645),
    [sym_preproc_undef] = STATE(2645),
    [aux_sym_class_declaration_repeat1] = STATE(2781),
    [aux_sym_class_declaration_repeat2] = STATE(2857),
    [aux_sym_declaration_list_repeat1] = STATE(2644),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_extern] = ACTIONS(3195),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3199),
    [anon_sym_using] = ACTIONS(3201),
    [anon_sym_unsafe] = ACTIONS(65),
    [anon_sym_static] = ACTIONS(65),
    [anon_sym_LBRACK] = ACTIONS(3203),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_event] = ACTIONS(3207),
    [anon_sym_namespace] = ACTIONS(3209),
    [anon_sym_class] = ACTIONS(3211),
    [anon_sym_ref] = ACTIONS(3213),
    [anon_sym_struct] = ACTIONS(3215),
    [anon_sym_enum] = ACTIONS(3217),
    [anon_sym_RBRACE] = ACTIONS(4033),
    [anon_sym_interface] = ACTIONS(3219),
    [anon_sym_delegate] = ACTIONS(3221),
    [anon_sym_record] = ACTIONS(3223),
    [anon_sym_abstract] = ACTIONS(65),
    [anon_sym_async] = ACTIONS(65),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_file] = ACTIONS(3225),
    [anon_sym_fixed] = ACTIONS(65),
    [anon_sym_internal] = ACTIONS(65),
    [anon_sym_new] = ACTIONS(65),
    [anon_sym_override] = ACTIONS(65),
    [anon_sym_partial] = ACTIONS(65),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_public] = ACTIONS(65),
    [anon_sym_readonly] = ACTIONS(65),
    [anon_sym_required] = ACTIONS(65),
    [anon_sym_sealed] = ACTIONS(65),
    [anon_sym_virtual] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_TILDE] = ACTIONS(3227),
    [anon_sym_implicit] = ACTIONS(3229),
    [anon_sym_explicit] = ACTIONS(3229),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_if_token1] = ACTIONS(3237),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2646] = {
    [sym_using_directive] = STATE(3324),
    [sym_attribute_list] = STATE(3740),
    [sym_namespace_declaration] = STATE(3324),
    [sym_class_declaration] = STATE(3324),
    [sym_struct_declaration] = STATE(3324),
    [sym_enum_declaration] = STATE(3324),
    [sym_interface_declaration] = STATE(3324),
    [sym_delegate_declaration] = STATE(3324),
    [sym_record_declaration] = STATE(3324),
    [sym_modifier] = STATE(3807),
    [sym_operator_declaration] = STATE(3324),
    [sym_conversion_operator_declaration] = STATE(3324),
    [sym_declaration] = STATE(3327),
    [sym_field_declaration] = STATE(3324),
    [sym_constructor_declaration] = STATE(3324),
    [sym_destructor_declaration] = STATE(3324),
    [sym_method_declaration] = STATE(3324),
    [sym_event_declaration] = STATE(3324),
    [sym_event_field_declaration] = STATE(3324),
    [sym_indexer_declaration] = STATE(3324),
    [sym_property_declaration] = STATE(3324),
    [sym_variable_declaration] = STATE(8996),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(6582),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(6750),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_if] = STATE(3324),
    [sym_preproc_region] = STATE(2646),
    [sym_preproc_endregion] = STATE(2646),
    [sym_preproc_line] = STATE(2646),
    [sym_preproc_pragma] = STATE(2646),
    [sym_preproc_nullable] = STATE(2646),
    [sym_preproc_error] = STATE(2646),
    [sym_preproc_warning] = STATE(2646),
    [sym_preproc_define] = STATE(2646),
    [sym_preproc_undef] = STATE(2646),
    [aux_sym_class_declaration_repeat1] = STATE(2781),
    [aux_sym_class_declaration_repeat2] = STATE(2857),
    [aux_sym_declaration_list_repeat1] = STATE(2647),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_extern] = ACTIONS(3195),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3199),
    [anon_sym_using] = ACTIONS(3201),
    [anon_sym_unsafe] = ACTIONS(65),
    [anon_sym_static] = ACTIONS(65),
    [anon_sym_LBRACK] = ACTIONS(3203),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_event] = ACTIONS(3207),
    [anon_sym_namespace] = ACTIONS(3209),
    [anon_sym_class] = ACTIONS(3211),
    [anon_sym_ref] = ACTIONS(3213),
    [anon_sym_struct] = ACTIONS(3215),
    [anon_sym_enum] = ACTIONS(3217),
    [anon_sym_interface] = ACTIONS(3219),
    [anon_sym_delegate] = ACTIONS(3221),
    [anon_sym_record] = ACTIONS(3223),
    [anon_sym_abstract] = ACTIONS(65),
    [anon_sym_async] = ACTIONS(65),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_file] = ACTIONS(3225),
    [anon_sym_fixed] = ACTIONS(65),
    [anon_sym_internal] = ACTIONS(65),
    [anon_sym_new] = ACTIONS(65),
    [anon_sym_override] = ACTIONS(65),
    [anon_sym_partial] = ACTIONS(65),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_public] = ACTIONS(65),
    [anon_sym_readonly] = ACTIONS(65),
    [anon_sym_required] = ACTIONS(65),
    [anon_sym_sealed] = ACTIONS(65),
    [anon_sym_virtual] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_TILDE] = ACTIONS(3227),
    [anon_sym_implicit] = ACTIONS(3229),
    [anon_sym_explicit] = ACTIONS(3229),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_if_token1] = ACTIONS(3237),
    [aux_sym_preproc_if_token3] = ACTIONS(4035),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2647] = {
    [sym_using_directive] = STATE(3324),
    [sym_attribute_list] = STATE(3740),
    [sym_namespace_declaration] = STATE(3324),
    [sym_class_declaration] = STATE(3324),
    [sym_struct_declaration] = STATE(3324),
    [sym_enum_declaration] = STATE(3324),
    [sym_interface_declaration] = STATE(3324),
    [sym_delegate_declaration] = STATE(3324),
    [sym_record_declaration] = STATE(3324),
    [sym_modifier] = STATE(3807),
    [sym_operator_declaration] = STATE(3324),
    [sym_conversion_operator_declaration] = STATE(3324),
    [sym_declaration] = STATE(3327),
    [sym_field_declaration] = STATE(3324),
    [sym_constructor_declaration] = STATE(3324),
    [sym_destructor_declaration] = STATE(3324),
    [sym_method_declaration] = STATE(3324),
    [sym_event_declaration] = STATE(3324),
    [sym_event_field_declaration] = STATE(3324),
    [sym_indexer_declaration] = STATE(3324),
    [sym_property_declaration] = STATE(3324),
    [sym_variable_declaration] = STATE(8996),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(6582),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(6750),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_if] = STATE(3324),
    [sym_preproc_region] = STATE(2647),
    [sym_preproc_endregion] = STATE(2647),
    [sym_preproc_line] = STATE(2647),
    [sym_preproc_pragma] = STATE(2647),
    [sym_preproc_nullable] = STATE(2647),
    [sym_preproc_error] = STATE(2647),
    [sym_preproc_warning] = STATE(2647),
    [sym_preproc_define] = STATE(2647),
    [sym_preproc_undef] = STATE(2647),
    [aux_sym_class_declaration_repeat1] = STATE(2781),
    [aux_sym_class_declaration_repeat2] = STATE(2857),
    [aux_sym_declaration_list_repeat1] = STATE(2422),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_extern] = ACTIONS(3195),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3199),
    [anon_sym_using] = ACTIONS(3201),
    [anon_sym_unsafe] = ACTIONS(65),
    [anon_sym_static] = ACTIONS(65),
    [anon_sym_LBRACK] = ACTIONS(3203),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_event] = ACTIONS(3207),
    [anon_sym_namespace] = ACTIONS(3209),
    [anon_sym_class] = ACTIONS(3211),
    [anon_sym_ref] = ACTIONS(3213),
    [anon_sym_struct] = ACTIONS(3215),
    [anon_sym_enum] = ACTIONS(3217),
    [anon_sym_interface] = ACTIONS(3219),
    [anon_sym_delegate] = ACTIONS(3221),
    [anon_sym_record] = ACTIONS(3223),
    [anon_sym_abstract] = ACTIONS(65),
    [anon_sym_async] = ACTIONS(65),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_file] = ACTIONS(3225),
    [anon_sym_fixed] = ACTIONS(65),
    [anon_sym_internal] = ACTIONS(65),
    [anon_sym_new] = ACTIONS(65),
    [anon_sym_override] = ACTIONS(65),
    [anon_sym_partial] = ACTIONS(65),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_public] = ACTIONS(65),
    [anon_sym_readonly] = ACTIONS(65),
    [anon_sym_required] = ACTIONS(65),
    [anon_sym_sealed] = ACTIONS(65),
    [anon_sym_virtual] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_TILDE] = ACTIONS(3227),
    [anon_sym_implicit] = ACTIONS(3229),
    [anon_sym_explicit] = ACTIONS(3229),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_if_token1] = ACTIONS(3237),
    [aux_sym_preproc_if_token3] = ACTIONS(4037),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2648] = {
    [sym_preproc_region] = STATE(2648),
    [sym_preproc_endregion] = STATE(2648),
    [sym_preproc_line] = STATE(2648),
    [sym_preproc_pragma] = STATE(2648),
    [sym_preproc_nullable] = STATE(2648),
    [sym_preproc_error] = STATE(2648),
    [sym_preproc_warning] = STATE(2648),
    [sym_preproc_define] = STATE(2648),
    [sym_preproc_undef] = STATE(2648),
    [sym__identifier_token] = ACTIONS(3045),
    [anon_sym_extern] = ACTIONS(3045),
    [anon_sym_alias] = ACTIONS(3045),
    [anon_sym_SEMI] = ACTIONS(3047),
    [anon_sym_global] = ACTIONS(3045),
    [anon_sym_using] = ACTIONS(3045),
    [anon_sym_unsafe] = ACTIONS(3045),
    [anon_sym_static] = ACTIONS(3045),
    [anon_sym_LBRACK] = ACTIONS(3047),
    [anon_sym_LPAREN] = ACTIONS(3047),
    [anon_sym_return] = ACTIONS(3045),
    [anon_sym_ref] = ACTIONS(3045),
    [anon_sym_LBRACE] = ACTIONS(3047),
    [anon_sym_RBRACE] = ACTIONS(3047),
    [anon_sym_delegate] = ACTIONS(3045),
    [anon_sym_abstract] = ACTIONS(3045),
    [anon_sym_async] = ACTIONS(3045),
    [anon_sym_const] = ACTIONS(3045),
    [anon_sym_file] = ACTIONS(3045),
    [anon_sym_fixed] = ACTIONS(3045),
    [anon_sym_internal] = ACTIONS(3045),
    [anon_sym_new] = ACTIONS(3045),
    [anon_sym_override] = ACTIONS(3045),
    [anon_sym_partial] = ACTIONS(3045),
    [anon_sym_private] = ACTIONS(3045),
    [anon_sym_protected] = ACTIONS(3045),
    [anon_sym_public] = ACTIONS(3045),
    [anon_sym_readonly] = ACTIONS(3045),
    [anon_sym_required] = ACTIONS(3045),
    [anon_sym_sealed] = ACTIONS(3045),
    [anon_sym_virtual] = ACTIONS(3045),
    [anon_sym_volatile] = ACTIONS(3045),
    [anon_sym_where] = ACTIONS(3045),
    [anon_sym_notnull] = ACTIONS(3045),
    [anon_sym_unmanaged] = ACTIONS(3045),
    [anon_sym_checked] = ACTIONS(3045),
    [anon_sym_BANG] = ACTIONS(3047),
    [anon_sym_TILDE] = ACTIONS(3047),
    [anon_sym_PLUS_PLUS] = ACTIONS(3047),
    [anon_sym_DASH_DASH] = ACTIONS(3047),
    [anon_sym_true] = ACTIONS(3045),
    [anon_sym_false] = ACTIONS(3045),
    [anon_sym_PLUS] = ACTIONS(3045),
    [anon_sym_DASH] = ACTIONS(3045),
    [anon_sym_STAR] = ACTIONS(3047),
    [anon_sym_CARET] = ACTIONS(3047),
    [anon_sym_AMP] = ACTIONS(3047),
    [anon_sym_this] = ACTIONS(3045),
    [anon_sym_scoped] = ACTIONS(3045),
    [anon_sym_base] = ACTIONS(3045),
    [anon_sym_var] = ACTIONS(3045),
    [sym_predefined_type] = ACTIONS(3045),
    [anon_sym_break] = ACTIONS(3045),
    [anon_sym_unchecked] = ACTIONS(3045),
    [anon_sym_continue] = ACTIONS(3045),
    [anon_sym_do] = ACTIONS(3045),
    [anon_sym_while] = ACTIONS(3045),
    [anon_sym_for] = ACTIONS(3045),
    [anon_sym_lock] = ACTIONS(3045),
    [anon_sym_yield] = ACTIONS(3045),
    [anon_sym_switch] = ACTIONS(3045),
    [anon_sym_case] = ACTIONS(3045),
    [anon_sym_default] = ACTIONS(3045),
    [anon_sym_throw] = ACTIONS(3045),
    [anon_sym_try] = ACTIONS(3045),
    [anon_sym_catch] = ACTIONS(3045),
    [anon_sym_when] = ACTIONS(3045),
    [anon_sym_finally] = ACTIONS(3045),
    [anon_sym_await] = ACTIONS(3045),
    [anon_sym_foreach] = ACTIONS(3045),
    [anon_sym_goto] = ACTIONS(3045),
    [anon_sym_if] = ACTIONS(3045),
    [anon_sym_else] = ACTIONS(3045),
    [anon_sym_DOT_DOT] = ACTIONS(3047),
    [anon_sym_from] = ACTIONS(3045),
    [anon_sym_into] = ACTIONS(3045),
    [anon_sym_join] = ACTIONS(3045),
    [anon_sym_on] = ACTIONS(3045),
    [anon_sym_equals] = ACTIONS(3045),
    [anon_sym_let] = ACTIONS(3045),
    [anon_sym_orderby] = ACTIONS(3045),
    [anon_sym_ascending] = ACTIONS(3045),
    [anon_sym_descending] = ACTIONS(3045),
    [anon_sym_group] = ACTIONS(3045),
    [anon_sym_by] = ACTIONS(3045),
    [anon_sym_select] = ACTIONS(3045),
    [anon_sym_stackalloc] = ACTIONS(3045),
    [anon_sym_sizeof] = ACTIONS(3045),
    [anon_sym_typeof] = ACTIONS(3045),
    [anon_sym___makeref] = ACTIONS(3045),
    [anon_sym___reftype] = ACTIONS(3045),
    [anon_sym___refvalue] = ACTIONS(3045),
    [sym_null_literal] = ACTIONS(3045),
    [anon_sym_SQUOTE] = ACTIONS(3047),
    [sym_integer_literal] = ACTIONS(3045),
    [sym_real_literal] = ACTIONS(3047),
    [anon_sym_DQUOTE] = ACTIONS(3047),
    [sym_verbatim_string_literal] = ACTIONS(3047),
    [aux_sym_preproc_if_token1] = ACTIONS(3047),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3047),
    [sym_interpolation_verbatim_start] = ACTIONS(3047),
    [sym_interpolation_raw_start] = ACTIONS(3047),
    [sym_raw_string_start] = ACTIONS(3047),
  },
  [2649] = {
    [sym_preproc_region] = STATE(2649),
    [sym_preproc_endregion] = STATE(2649),
    [sym_preproc_line] = STATE(2649),
    [sym_preproc_pragma] = STATE(2649),
    [sym_preproc_nullable] = STATE(2649),
    [sym_preproc_error] = STATE(2649),
    [sym_preproc_warning] = STATE(2649),
    [sym_preproc_define] = STATE(2649),
    [sym_preproc_undef] = STATE(2649),
    [sym__identifier_token] = ACTIONS(3037),
    [anon_sym_extern] = ACTIONS(3037),
    [anon_sym_alias] = ACTIONS(3037),
    [anon_sym_SEMI] = ACTIONS(3039),
    [anon_sym_global] = ACTIONS(3037),
    [anon_sym_using] = ACTIONS(3037),
    [anon_sym_unsafe] = ACTIONS(3037),
    [anon_sym_static] = ACTIONS(3037),
    [anon_sym_LBRACK] = ACTIONS(3039),
    [anon_sym_LPAREN] = ACTIONS(3039),
    [anon_sym_return] = ACTIONS(3037),
    [anon_sym_ref] = ACTIONS(3037),
    [anon_sym_LBRACE] = ACTIONS(3039),
    [anon_sym_RBRACE] = ACTIONS(3039),
    [anon_sym_delegate] = ACTIONS(3037),
    [anon_sym_abstract] = ACTIONS(3037),
    [anon_sym_async] = ACTIONS(3037),
    [anon_sym_const] = ACTIONS(3037),
    [anon_sym_file] = ACTIONS(3037),
    [anon_sym_fixed] = ACTIONS(3037),
    [anon_sym_internal] = ACTIONS(3037),
    [anon_sym_new] = ACTIONS(3037),
    [anon_sym_override] = ACTIONS(3037),
    [anon_sym_partial] = ACTIONS(3037),
    [anon_sym_private] = ACTIONS(3037),
    [anon_sym_protected] = ACTIONS(3037),
    [anon_sym_public] = ACTIONS(3037),
    [anon_sym_readonly] = ACTIONS(3037),
    [anon_sym_required] = ACTIONS(3037),
    [anon_sym_sealed] = ACTIONS(3037),
    [anon_sym_virtual] = ACTIONS(3037),
    [anon_sym_volatile] = ACTIONS(3037),
    [anon_sym_where] = ACTIONS(3037),
    [anon_sym_notnull] = ACTIONS(3037),
    [anon_sym_unmanaged] = ACTIONS(3037),
    [anon_sym_checked] = ACTIONS(3037),
    [anon_sym_BANG] = ACTIONS(3039),
    [anon_sym_TILDE] = ACTIONS(3039),
    [anon_sym_PLUS_PLUS] = ACTIONS(3039),
    [anon_sym_DASH_DASH] = ACTIONS(3039),
    [anon_sym_true] = ACTIONS(3037),
    [anon_sym_false] = ACTIONS(3037),
    [anon_sym_PLUS] = ACTIONS(3037),
    [anon_sym_DASH] = ACTIONS(3037),
    [anon_sym_STAR] = ACTIONS(3039),
    [anon_sym_CARET] = ACTIONS(3039),
    [anon_sym_AMP] = ACTIONS(3039),
    [anon_sym_this] = ACTIONS(3037),
    [anon_sym_scoped] = ACTIONS(3037),
    [anon_sym_base] = ACTIONS(3037),
    [anon_sym_var] = ACTIONS(3037),
    [sym_predefined_type] = ACTIONS(3037),
    [anon_sym_break] = ACTIONS(3037),
    [anon_sym_unchecked] = ACTIONS(3037),
    [anon_sym_continue] = ACTIONS(3037),
    [anon_sym_do] = ACTIONS(3037),
    [anon_sym_while] = ACTIONS(3037),
    [anon_sym_for] = ACTIONS(3037),
    [anon_sym_lock] = ACTIONS(3037),
    [anon_sym_yield] = ACTIONS(3037),
    [anon_sym_switch] = ACTIONS(3037),
    [anon_sym_case] = ACTIONS(3037),
    [anon_sym_default] = ACTIONS(3037),
    [anon_sym_throw] = ACTIONS(3037),
    [anon_sym_try] = ACTIONS(3037),
    [anon_sym_catch] = ACTIONS(3037),
    [anon_sym_when] = ACTIONS(3037),
    [anon_sym_finally] = ACTIONS(3037),
    [anon_sym_await] = ACTIONS(3037),
    [anon_sym_foreach] = ACTIONS(3037),
    [anon_sym_goto] = ACTIONS(3037),
    [anon_sym_if] = ACTIONS(3037),
    [anon_sym_else] = ACTIONS(3037),
    [anon_sym_DOT_DOT] = ACTIONS(3039),
    [anon_sym_from] = ACTIONS(3037),
    [anon_sym_into] = ACTIONS(3037),
    [anon_sym_join] = ACTIONS(3037),
    [anon_sym_on] = ACTIONS(3037),
    [anon_sym_equals] = ACTIONS(3037),
    [anon_sym_let] = ACTIONS(3037),
    [anon_sym_orderby] = ACTIONS(3037),
    [anon_sym_ascending] = ACTIONS(3037),
    [anon_sym_descending] = ACTIONS(3037),
    [anon_sym_group] = ACTIONS(3037),
    [anon_sym_by] = ACTIONS(3037),
    [anon_sym_select] = ACTIONS(3037),
    [anon_sym_stackalloc] = ACTIONS(3037),
    [anon_sym_sizeof] = ACTIONS(3037),
    [anon_sym_typeof] = ACTIONS(3037),
    [anon_sym___makeref] = ACTIONS(3037),
    [anon_sym___reftype] = ACTIONS(3037),
    [anon_sym___refvalue] = ACTIONS(3037),
    [sym_null_literal] = ACTIONS(3037),
    [anon_sym_SQUOTE] = ACTIONS(3039),
    [sym_integer_literal] = ACTIONS(3037),
    [sym_real_literal] = ACTIONS(3039),
    [anon_sym_DQUOTE] = ACTIONS(3039),
    [sym_verbatim_string_literal] = ACTIONS(3039),
    [aux_sym_preproc_if_token1] = ACTIONS(3039),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3039),
    [sym_interpolation_verbatim_start] = ACTIONS(3039),
    [sym_interpolation_raw_start] = ACTIONS(3039),
    [sym_raw_string_start] = ACTIONS(3039),
  },
  [2650] = {
    [sym_preproc_region] = STATE(2650),
    [sym_preproc_endregion] = STATE(2650),
    [sym_preproc_line] = STATE(2650),
    [sym_preproc_pragma] = STATE(2650),
    [sym_preproc_nullable] = STATE(2650),
    [sym_preproc_error] = STATE(2650),
    [sym_preproc_warning] = STATE(2650),
    [sym_preproc_define] = STATE(2650),
    [sym_preproc_undef] = STATE(2650),
    [sym__identifier_token] = ACTIONS(3041),
    [anon_sym_extern] = ACTIONS(3041),
    [anon_sym_alias] = ACTIONS(3041),
    [anon_sym_SEMI] = ACTIONS(3043),
    [anon_sym_global] = ACTIONS(3041),
    [anon_sym_using] = ACTIONS(3041),
    [anon_sym_unsafe] = ACTIONS(3041),
    [anon_sym_static] = ACTIONS(3041),
    [anon_sym_LBRACK] = ACTIONS(3043),
    [anon_sym_LPAREN] = ACTIONS(3043),
    [anon_sym_return] = ACTIONS(3041),
    [anon_sym_ref] = ACTIONS(3041),
    [anon_sym_LBRACE] = ACTIONS(3043),
    [anon_sym_RBRACE] = ACTIONS(3043),
    [anon_sym_delegate] = ACTIONS(3041),
    [anon_sym_abstract] = ACTIONS(3041),
    [anon_sym_async] = ACTIONS(3041),
    [anon_sym_const] = ACTIONS(3041),
    [anon_sym_file] = ACTIONS(3041),
    [anon_sym_fixed] = ACTIONS(3041),
    [anon_sym_internal] = ACTIONS(3041),
    [anon_sym_new] = ACTIONS(3041),
    [anon_sym_override] = ACTIONS(3041),
    [anon_sym_partial] = ACTIONS(3041),
    [anon_sym_private] = ACTIONS(3041),
    [anon_sym_protected] = ACTIONS(3041),
    [anon_sym_public] = ACTIONS(3041),
    [anon_sym_readonly] = ACTIONS(3041),
    [anon_sym_required] = ACTIONS(3041),
    [anon_sym_sealed] = ACTIONS(3041),
    [anon_sym_virtual] = ACTIONS(3041),
    [anon_sym_volatile] = ACTIONS(3041),
    [anon_sym_where] = ACTIONS(3041),
    [anon_sym_notnull] = ACTIONS(3041),
    [anon_sym_unmanaged] = ACTIONS(3041),
    [anon_sym_checked] = ACTIONS(3041),
    [anon_sym_BANG] = ACTIONS(3043),
    [anon_sym_TILDE] = ACTIONS(3043),
    [anon_sym_PLUS_PLUS] = ACTIONS(3043),
    [anon_sym_DASH_DASH] = ACTIONS(3043),
    [anon_sym_true] = ACTIONS(3041),
    [anon_sym_false] = ACTIONS(3041),
    [anon_sym_PLUS] = ACTIONS(3041),
    [anon_sym_DASH] = ACTIONS(3041),
    [anon_sym_STAR] = ACTIONS(3043),
    [anon_sym_CARET] = ACTIONS(3043),
    [anon_sym_AMP] = ACTIONS(3043),
    [anon_sym_this] = ACTIONS(3041),
    [anon_sym_scoped] = ACTIONS(3041),
    [anon_sym_base] = ACTIONS(3041),
    [anon_sym_var] = ACTIONS(3041),
    [sym_predefined_type] = ACTIONS(3041),
    [anon_sym_break] = ACTIONS(3041),
    [anon_sym_unchecked] = ACTIONS(3041),
    [anon_sym_continue] = ACTIONS(3041),
    [anon_sym_do] = ACTIONS(3041),
    [anon_sym_while] = ACTIONS(3041),
    [anon_sym_for] = ACTIONS(3041),
    [anon_sym_lock] = ACTIONS(3041),
    [anon_sym_yield] = ACTIONS(3041),
    [anon_sym_switch] = ACTIONS(3041),
    [anon_sym_case] = ACTIONS(3041),
    [anon_sym_default] = ACTIONS(3041),
    [anon_sym_throw] = ACTIONS(3041),
    [anon_sym_try] = ACTIONS(3041),
    [anon_sym_catch] = ACTIONS(3041),
    [anon_sym_when] = ACTIONS(3041),
    [anon_sym_finally] = ACTIONS(3041),
    [anon_sym_await] = ACTIONS(3041),
    [anon_sym_foreach] = ACTIONS(3041),
    [anon_sym_goto] = ACTIONS(3041),
    [anon_sym_if] = ACTIONS(3041),
    [anon_sym_else] = ACTIONS(3041),
    [anon_sym_DOT_DOT] = ACTIONS(3043),
    [anon_sym_from] = ACTIONS(3041),
    [anon_sym_into] = ACTIONS(3041),
    [anon_sym_join] = ACTIONS(3041),
    [anon_sym_on] = ACTIONS(3041),
    [anon_sym_equals] = ACTIONS(3041),
    [anon_sym_let] = ACTIONS(3041),
    [anon_sym_orderby] = ACTIONS(3041),
    [anon_sym_ascending] = ACTIONS(3041),
    [anon_sym_descending] = ACTIONS(3041),
    [anon_sym_group] = ACTIONS(3041),
    [anon_sym_by] = ACTIONS(3041),
    [anon_sym_select] = ACTIONS(3041),
    [anon_sym_stackalloc] = ACTIONS(3041),
    [anon_sym_sizeof] = ACTIONS(3041),
    [anon_sym_typeof] = ACTIONS(3041),
    [anon_sym___makeref] = ACTIONS(3041),
    [anon_sym___reftype] = ACTIONS(3041),
    [anon_sym___refvalue] = ACTIONS(3041),
    [sym_null_literal] = ACTIONS(3041),
    [anon_sym_SQUOTE] = ACTIONS(3043),
    [sym_integer_literal] = ACTIONS(3041),
    [sym_real_literal] = ACTIONS(3043),
    [anon_sym_DQUOTE] = ACTIONS(3043),
    [sym_verbatim_string_literal] = ACTIONS(3043),
    [aux_sym_preproc_if_token1] = ACTIONS(3043),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3043),
    [sym_interpolation_verbatim_start] = ACTIONS(3043),
    [sym_interpolation_raw_start] = ACTIONS(3043),
    [sym_raw_string_start] = ACTIONS(3043),
  },
  [2651] = {
    [sym_preproc_region] = STATE(2651),
    [sym_preproc_endregion] = STATE(2651),
    [sym_preproc_line] = STATE(2651),
    [sym_preproc_pragma] = STATE(2651),
    [sym_preproc_nullable] = STATE(2651),
    [sym_preproc_error] = STATE(2651),
    [sym_preproc_warning] = STATE(2651),
    [sym_preproc_define] = STATE(2651),
    [sym_preproc_undef] = STATE(2651),
    [sym__identifier_token] = ACTIONS(2995),
    [anon_sym_extern] = ACTIONS(2995),
    [anon_sym_alias] = ACTIONS(2995),
    [anon_sym_SEMI] = ACTIONS(2997),
    [anon_sym_global] = ACTIONS(2995),
    [anon_sym_using] = ACTIONS(2995),
    [anon_sym_unsafe] = ACTIONS(2995),
    [anon_sym_static] = ACTIONS(2995),
    [anon_sym_LBRACK] = ACTIONS(2997),
    [anon_sym_LPAREN] = ACTIONS(2997),
    [anon_sym_return] = ACTIONS(2995),
    [anon_sym_ref] = ACTIONS(2995),
    [anon_sym_LBRACE] = ACTIONS(2997),
    [anon_sym_RBRACE] = ACTIONS(2997),
    [anon_sym_delegate] = ACTIONS(2995),
    [anon_sym_abstract] = ACTIONS(2995),
    [anon_sym_async] = ACTIONS(2995),
    [anon_sym_const] = ACTIONS(2995),
    [anon_sym_file] = ACTIONS(2995),
    [anon_sym_fixed] = ACTIONS(2995),
    [anon_sym_internal] = ACTIONS(2995),
    [anon_sym_new] = ACTIONS(2995),
    [anon_sym_override] = ACTIONS(2995),
    [anon_sym_partial] = ACTIONS(2995),
    [anon_sym_private] = ACTIONS(2995),
    [anon_sym_protected] = ACTIONS(2995),
    [anon_sym_public] = ACTIONS(2995),
    [anon_sym_readonly] = ACTIONS(2995),
    [anon_sym_required] = ACTIONS(2995),
    [anon_sym_sealed] = ACTIONS(2995),
    [anon_sym_virtual] = ACTIONS(2995),
    [anon_sym_volatile] = ACTIONS(2995),
    [anon_sym_where] = ACTIONS(2995),
    [anon_sym_notnull] = ACTIONS(2995),
    [anon_sym_unmanaged] = ACTIONS(2995),
    [anon_sym_checked] = ACTIONS(2995),
    [anon_sym_BANG] = ACTIONS(2997),
    [anon_sym_TILDE] = ACTIONS(2997),
    [anon_sym_PLUS_PLUS] = ACTIONS(2997),
    [anon_sym_DASH_DASH] = ACTIONS(2997),
    [anon_sym_true] = ACTIONS(2995),
    [anon_sym_false] = ACTIONS(2995),
    [anon_sym_PLUS] = ACTIONS(2995),
    [anon_sym_DASH] = ACTIONS(2995),
    [anon_sym_STAR] = ACTIONS(2997),
    [anon_sym_CARET] = ACTIONS(2997),
    [anon_sym_AMP] = ACTIONS(2997),
    [anon_sym_this] = ACTIONS(2995),
    [anon_sym_scoped] = ACTIONS(2995),
    [anon_sym_base] = ACTIONS(2995),
    [anon_sym_var] = ACTIONS(2995),
    [sym_predefined_type] = ACTIONS(2995),
    [anon_sym_break] = ACTIONS(2995),
    [anon_sym_unchecked] = ACTIONS(2995),
    [anon_sym_continue] = ACTIONS(2995),
    [anon_sym_do] = ACTIONS(2995),
    [anon_sym_while] = ACTIONS(2995),
    [anon_sym_for] = ACTIONS(2995),
    [anon_sym_lock] = ACTIONS(2995),
    [anon_sym_yield] = ACTIONS(2995),
    [anon_sym_switch] = ACTIONS(2995),
    [anon_sym_case] = ACTIONS(2995),
    [anon_sym_default] = ACTIONS(2995),
    [anon_sym_throw] = ACTIONS(2995),
    [anon_sym_try] = ACTIONS(2995),
    [anon_sym_catch] = ACTIONS(2995),
    [anon_sym_when] = ACTIONS(2995),
    [anon_sym_finally] = ACTIONS(2995),
    [anon_sym_await] = ACTIONS(2995),
    [anon_sym_foreach] = ACTIONS(2995),
    [anon_sym_goto] = ACTIONS(2995),
    [anon_sym_if] = ACTIONS(2995),
    [anon_sym_else] = ACTIONS(2995),
    [anon_sym_DOT_DOT] = ACTIONS(2997),
    [anon_sym_from] = ACTIONS(2995),
    [anon_sym_into] = ACTIONS(2995),
    [anon_sym_join] = ACTIONS(2995),
    [anon_sym_on] = ACTIONS(2995),
    [anon_sym_equals] = ACTIONS(2995),
    [anon_sym_let] = ACTIONS(2995),
    [anon_sym_orderby] = ACTIONS(2995),
    [anon_sym_ascending] = ACTIONS(2995),
    [anon_sym_descending] = ACTIONS(2995),
    [anon_sym_group] = ACTIONS(2995),
    [anon_sym_by] = ACTIONS(2995),
    [anon_sym_select] = ACTIONS(2995),
    [anon_sym_stackalloc] = ACTIONS(2995),
    [anon_sym_sizeof] = ACTIONS(2995),
    [anon_sym_typeof] = ACTIONS(2995),
    [anon_sym___makeref] = ACTIONS(2995),
    [anon_sym___reftype] = ACTIONS(2995),
    [anon_sym___refvalue] = ACTIONS(2995),
    [sym_null_literal] = ACTIONS(2995),
    [anon_sym_SQUOTE] = ACTIONS(2997),
    [sym_integer_literal] = ACTIONS(2995),
    [sym_real_literal] = ACTIONS(2997),
    [anon_sym_DQUOTE] = ACTIONS(2997),
    [sym_verbatim_string_literal] = ACTIONS(2997),
    [aux_sym_preproc_if_token1] = ACTIONS(2997),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(2997),
    [sym_interpolation_verbatim_start] = ACTIONS(2997),
    [sym_interpolation_raw_start] = ACTIONS(2997),
    [sym_raw_string_start] = ACTIONS(2997),
  },
  [2652] = {
    [sym_preproc_region] = STATE(2652),
    [sym_preproc_endregion] = STATE(2652),
    [sym_preproc_line] = STATE(2652),
    [sym_preproc_pragma] = STATE(2652),
    [sym_preproc_nullable] = STATE(2652),
    [sym_preproc_error] = STATE(2652),
    [sym_preproc_warning] = STATE(2652),
    [sym_preproc_define] = STATE(2652),
    [sym_preproc_undef] = STATE(2652),
    [sym__identifier_token] = ACTIONS(3026),
    [anon_sym_extern] = ACTIONS(3026),
    [anon_sym_alias] = ACTIONS(3026),
    [anon_sym_SEMI] = ACTIONS(3028),
    [anon_sym_global] = ACTIONS(3026),
    [anon_sym_using] = ACTIONS(3026),
    [anon_sym_unsafe] = ACTIONS(3026),
    [anon_sym_static] = ACTIONS(3026),
    [anon_sym_LBRACK] = ACTIONS(3028),
    [anon_sym_LPAREN] = ACTIONS(3028),
    [anon_sym_return] = ACTIONS(3026),
    [anon_sym_ref] = ACTIONS(3026),
    [anon_sym_LBRACE] = ACTIONS(3028),
    [anon_sym_RBRACE] = ACTIONS(3028),
    [anon_sym_delegate] = ACTIONS(3026),
    [anon_sym_abstract] = ACTIONS(3026),
    [anon_sym_async] = ACTIONS(3026),
    [anon_sym_const] = ACTIONS(3026),
    [anon_sym_file] = ACTIONS(3026),
    [anon_sym_fixed] = ACTIONS(3026),
    [anon_sym_internal] = ACTIONS(3026),
    [anon_sym_new] = ACTIONS(3026),
    [anon_sym_override] = ACTIONS(3026),
    [anon_sym_partial] = ACTIONS(3026),
    [anon_sym_private] = ACTIONS(3026),
    [anon_sym_protected] = ACTIONS(3026),
    [anon_sym_public] = ACTIONS(3026),
    [anon_sym_readonly] = ACTIONS(3026),
    [anon_sym_required] = ACTIONS(3026),
    [anon_sym_sealed] = ACTIONS(3026),
    [anon_sym_virtual] = ACTIONS(3026),
    [anon_sym_volatile] = ACTIONS(3026),
    [anon_sym_where] = ACTIONS(3026),
    [anon_sym_notnull] = ACTIONS(3026),
    [anon_sym_unmanaged] = ACTIONS(3026),
    [anon_sym_checked] = ACTIONS(3026),
    [anon_sym_BANG] = ACTIONS(3028),
    [anon_sym_TILDE] = ACTIONS(3028),
    [anon_sym_PLUS_PLUS] = ACTIONS(3028),
    [anon_sym_DASH_DASH] = ACTIONS(3028),
    [anon_sym_true] = ACTIONS(3026),
    [anon_sym_false] = ACTIONS(3026),
    [anon_sym_PLUS] = ACTIONS(3026),
    [anon_sym_DASH] = ACTIONS(3026),
    [anon_sym_STAR] = ACTIONS(3028),
    [anon_sym_CARET] = ACTIONS(3028),
    [anon_sym_AMP] = ACTIONS(3028),
    [anon_sym_this] = ACTIONS(3026),
    [anon_sym_scoped] = ACTIONS(3026),
    [anon_sym_base] = ACTIONS(3026),
    [anon_sym_var] = ACTIONS(3026),
    [sym_predefined_type] = ACTIONS(3026),
    [anon_sym_break] = ACTIONS(3026),
    [anon_sym_unchecked] = ACTIONS(3026),
    [anon_sym_continue] = ACTIONS(3026),
    [anon_sym_do] = ACTIONS(3026),
    [anon_sym_while] = ACTIONS(3026),
    [anon_sym_for] = ACTIONS(3026),
    [anon_sym_lock] = ACTIONS(3026),
    [anon_sym_yield] = ACTIONS(3026),
    [anon_sym_switch] = ACTIONS(3026),
    [anon_sym_case] = ACTIONS(3026),
    [anon_sym_default] = ACTIONS(3026),
    [anon_sym_throw] = ACTIONS(3026),
    [anon_sym_try] = ACTIONS(3026),
    [anon_sym_catch] = ACTIONS(3026),
    [anon_sym_when] = ACTIONS(3026),
    [anon_sym_finally] = ACTIONS(3026),
    [anon_sym_await] = ACTIONS(3026),
    [anon_sym_foreach] = ACTIONS(3026),
    [anon_sym_goto] = ACTIONS(3026),
    [anon_sym_if] = ACTIONS(3026),
    [anon_sym_else] = ACTIONS(3026),
    [anon_sym_DOT_DOT] = ACTIONS(3028),
    [anon_sym_from] = ACTIONS(3026),
    [anon_sym_into] = ACTIONS(3026),
    [anon_sym_join] = ACTIONS(3026),
    [anon_sym_on] = ACTIONS(3026),
    [anon_sym_equals] = ACTIONS(3026),
    [anon_sym_let] = ACTIONS(3026),
    [anon_sym_orderby] = ACTIONS(3026),
    [anon_sym_ascending] = ACTIONS(3026),
    [anon_sym_descending] = ACTIONS(3026),
    [anon_sym_group] = ACTIONS(3026),
    [anon_sym_by] = ACTIONS(3026),
    [anon_sym_select] = ACTIONS(3026),
    [anon_sym_stackalloc] = ACTIONS(3026),
    [anon_sym_sizeof] = ACTIONS(3026),
    [anon_sym_typeof] = ACTIONS(3026),
    [anon_sym___makeref] = ACTIONS(3026),
    [anon_sym___reftype] = ACTIONS(3026),
    [anon_sym___refvalue] = ACTIONS(3026),
    [sym_null_literal] = ACTIONS(3026),
    [anon_sym_SQUOTE] = ACTIONS(3028),
    [sym_integer_literal] = ACTIONS(3026),
    [sym_real_literal] = ACTIONS(3028),
    [anon_sym_DQUOTE] = ACTIONS(3028),
    [sym_verbatim_string_literal] = ACTIONS(3028),
    [aux_sym_preproc_if_token1] = ACTIONS(3028),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3028),
    [sym_interpolation_verbatim_start] = ACTIONS(3028),
    [sym_interpolation_raw_start] = ACTIONS(3028),
    [sym_raw_string_start] = ACTIONS(3028),
  },
  [2653] = {
    [sym_preproc_region] = STATE(2653),
    [sym_preproc_endregion] = STATE(2653),
    [sym_preproc_line] = STATE(2653),
    [sym_preproc_pragma] = STATE(2653),
    [sym_preproc_nullable] = STATE(2653),
    [sym_preproc_error] = STATE(2653),
    [sym_preproc_warning] = STATE(2653),
    [sym_preproc_define] = STATE(2653),
    [sym_preproc_undef] = STATE(2653),
    [sym__identifier_token] = ACTIONS(3030),
    [anon_sym_extern] = ACTIONS(3030),
    [anon_sym_alias] = ACTIONS(3030),
    [anon_sym_SEMI] = ACTIONS(3032),
    [anon_sym_global] = ACTIONS(3030),
    [anon_sym_using] = ACTIONS(3030),
    [anon_sym_unsafe] = ACTIONS(3030),
    [anon_sym_static] = ACTIONS(3030),
    [anon_sym_LBRACK] = ACTIONS(3032),
    [anon_sym_LPAREN] = ACTIONS(3032),
    [anon_sym_return] = ACTIONS(3030),
    [anon_sym_ref] = ACTIONS(3030),
    [anon_sym_LBRACE] = ACTIONS(3032),
    [anon_sym_RBRACE] = ACTIONS(3032),
    [anon_sym_delegate] = ACTIONS(3030),
    [anon_sym_abstract] = ACTIONS(3030),
    [anon_sym_async] = ACTIONS(3030),
    [anon_sym_const] = ACTIONS(3030),
    [anon_sym_file] = ACTIONS(3030),
    [anon_sym_fixed] = ACTIONS(3030),
    [anon_sym_internal] = ACTIONS(3030),
    [anon_sym_new] = ACTIONS(3030),
    [anon_sym_override] = ACTIONS(3030),
    [anon_sym_partial] = ACTIONS(3030),
    [anon_sym_private] = ACTIONS(3030),
    [anon_sym_protected] = ACTIONS(3030),
    [anon_sym_public] = ACTIONS(3030),
    [anon_sym_readonly] = ACTIONS(3030),
    [anon_sym_required] = ACTIONS(3030),
    [anon_sym_sealed] = ACTIONS(3030),
    [anon_sym_virtual] = ACTIONS(3030),
    [anon_sym_volatile] = ACTIONS(3030),
    [anon_sym_where] = ACTIONS(3030),
    [anon_sym_notnull] = ACTIONS(3030),
    [anon_sym_unmanaged] = ACTIONS(3030),
    [anon_sym_checked] = ACTIONS(3030),
    [anon_sym_BANG] = ACTIONS(3032),
    [anon_sym_TILDE] = ACTIONS(3032),
    [anon_sym_PLUS_PLUS] = ACTIONS(3032),
    [anon_sym_DASH_DASH] = ACTIONS(3032),
    [anon_sym_true] = ACTIONS(3030),
    [anon_sym_false] = ACTIONS(3030),
    [anon_sym_PLUS] = ACTIONS(3030),
    [anon_sym_DASH] = ACTIONS(3030),
    [anon_sym_STAR] = ACTIONS(3032),
    [anon_sym_CARET] = ACTIONS(3032),
    [anon_sym_AMP] = ACTIONS(3032),
    [anon_sym_this] = ACTIONS(3030),
    [anon_sym_scoped] = ACTIONS(3030),
    [anon_sym_base] = ACTIONS(3030),
    [anon_sym_var] = ACTIONS(3030),
    [sym_predefined_type] = ACTIONS(3030),
    [anon_sym_break] = ACTIONS(3030),
    [anon_sym_unchecked] = ACTIONS(3030),
    [anon_sym_continue] = ACTIONS(3030),
    [anon_sym_do] = ACTIONS(3030),
    [anon_sym_while] = ACTIONS(3030),
    [anon_sym_for] = ACTIONS(3030),
    [anon_sym_lock] = ACTIONS(3030),
    [anon_sym_yield] = ACTIONS(3030),
    [anon_sym_switch] = ACTIONS(3030),
    [anon_sym_case] = ACTIONS(3030),
    [anon_sym_default] = ACTIONS(3030),
    [anon_sym_throw] = ACTIONS(3030),
    [anon_sym_try] = ACTIONS(3030),
    [anon_sym_catch] = ACTIONS(3030),
    [anon_sym_when] = ACTIONS(3030),
    [anon_sym_finally] = ACTIONS(3030),
    [anon_sym_await] = ACTIONS(3030),
    [anon_sym_foreach] = ACTIONS(3030),
    [anon_sym_goto] = ACTIONS(3030),
    [anon_sym_if] = ACTIONS(3030),
    [anon_sym_else] = ACTIONS(3030),
    [anon_sym_DOT_DOT] = ACTIONS(3032),
    [anon_sym_from] = ACTIONS(3030),
    [anon_sym_into] = ACTIONS(3030),
    [anon_sym_join] = ACTIONS(3030),
    [anon_sym_on] = ACTIONS(3030),
    [anon_sym_equals] = ACTIONS(3030),
    [anon_sym_let] = ACTIONS(3030),
    [anon_sym_orderby] = ACTIONS(3030),
    [anon_sym_ascending] = ACTIONS(3030),
    [anon_sym_descending] = ACTIONS(3030),
    [anon_sym_group] = ACTIONS(3030),
    [anon_sym_by] = ACTIONS(3030),
    [anon_sym_select] = ACTIONS(3030),
    [anon_sym_stackalloc] = ACTIONS(3030),
    [anon_sym_sizeof] = ACTIONS(3030),
    [anon_sym_typeof] = ACTIONS(3030),
    [anon_sym___makeref] = ACTIONS(3030),
    [anon_sym___reftype] = ACTIONS(3030),
    [anon_sym___refvalue] = ACTIONS(3030),
    [sym_null_literal] = ACTIONS(3030),
    [anon_sym_SQUOTE] = ACTIONS(3032),
    [sym_integer_literal] = ACTIONS(3030),
    [sym_real_literal] = ACTIONS(3032),
    [anon_sym_DQUOTE] = ACTIONS(3032),
    [sym_verbatim_string_literal] = ACTIONS(3032),
    [aux_sym_preproc_if_token1] = ACTIONS(3032),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3032),
    [sym_interpolation_verbatim_start] = ACTIONS(3032),
    [sym_interpolation_raw_start] = ACTIONS(3032),
    [sym_raw_string_start] = ACTIONS(3032),
  },
  [2654] = {
    [sym_preproc_region] = STATE(2654),
    [sym_preproc_endregion] = STATE(2654),
    [sym_preproc_line] = STATE(2654),
    [sym_preproc_pragma] = STATE(2654),
    [sym_preproc_nullable] = STATE(2654),
    [sym_preproc_error] = STATE(2654),
    [sym_preproc_warning] = STATE(2654),
    [sym_preproc_define] = STATE(2654),
    [sym_preproc_undef] = STATE(2654),
    [sym__identifier_token] = ACTIONS(4039),
    [anon_sym_extern] = ACTIONS(4042),
    [anon_sym_alias] = ACTIONS(4039),
    [anon_sym_global] = ACTIONS(4039),
    [anon_sym_unsafe] = ACTIONS(4042),
    [anon_sym_EQ] = ACTIONS(3995),
    [anon_sym_static] = ACTIONS(4042),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_COLON] = ACTIONS(3995),
    [anon_sym_LPAREN] = ACTIONS(4044),
    [anon_sym_class] = ACTIONS(4042),
    [anon_sym_ref] = ACTIONS(4042),
    [anon_sym_struct] = ACTIONS(4042),
    [anon_sym_enum] = ACTIONS(4042),
    [anon_sym_interface] = ACTIONS(4042),
    [anon_sym_delegate] = ACTIONS(4042),
    [anon_sym_record] = ACTIONS(4042),
    [anon_sym_abstract] = ACTIONS(4042),
    [anon_sym_async] = ACTIONS(4042),
    [anon_sym_const] = ACTIONS(4042),
    [anon_sym_file] = ACTIONS(4039),
    [anon_sym_fixed] = ACTIONS(4042),
    [anon_sym_internal] = ACTIONS(4042),
    [anon_sym_new] = ACTIONS(4042),
    [anon_sym_override] = ACTIONS(4042),
    [anon_sym_partial] = ACTIONS(4042),
    [anon_sym_private] = ACTIONS(4042),
    [anon_sym_protected] = ACTIONS(4042),
    [anon_sym_public] = ACTIONS(4042),
    [anon_sym_readonly] = ACTIONS(4042),
    [anon_sym_required] = ACTIONS(4042),
    [anon_sym_sealed] = ACTIONS(4042),
    [anon_sym_virtual] = ACTIONS(4042),
    [anon_sym_volatile] = ACTIONS(4042),
    [anon_sym_LT] = ACTIONS(3995),
    [anon_sym_GT] = ACTIONS(3995),
    [anon_sym_where] = ACTIONS(4039),
    [anon_sym_QMARK] = ACTIONS(3995),
    [anon_sym_notnull] = ACTIONS(4039),
    [anon_sym_unmanaged] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(3995),
    [anon_sym_PLUS_PLUS] = ACTIONS(3993),
    [anon_sym_DASH_DASH] = ACTIONS(3993),
    [anon_sym_PLUS] = ACTIONS(3995),
    [anon_sym_DASH] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3995),
    [anon_sym_SLASH] = ACTIONS(3995),
    [anon_sym_PERCENT] = ACTIONS(3995),
    [anon_sym_CARET] = ACTIONS(3995),
    [anon_sym_PIPE] = ACTIONS(3995),
    [anon_sym_AMP] = ACTIONS(3995),
    [anon_sym_LT_LT] = ACTIONS(3995),
    [anon_sym_GT_GT] = ACTIONS(3995),
    [anon_sym_GT_GT_GT] = ACTIONS(3995),
    [anon_sym_EQ_EQ] = ACTIONS(3993),
    [anon_sym_BANG_EQ] = ACTIONS(3993),
    [anon_sym_GT_EQ] = ACTIONS(3993),
    [anon_sym_LT_EQ] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3995),
    [anon_sym_scoped] = ACTIONS(4039),
    [anon_sym_EQ_GT] = ACTIONS(3993),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(4039),
    [sym_predefined_type] = ACTIONS(4042),
    [anon_sym_yield] = ACTIONS(4039),
    [anon_sym_switch] = ACTIONS(3995),
    [anon_sym_when] = ACTIONS(4039),
    [anon_sym_DOT_DOT] = ACTIONS(3993),
    [anon_sym_PLUS_EQ] = ACTIONS(3993),
    [anon_sym_DASH_EQ] = ACTIONS(3993),
    [anon_sym_STAR_EQ] = ACTIONS(3993),
    [anon_sym_SLASH_EQ] = ACTIONS(3993),
    [anon_sym_PERCENT_EQ] = ACTIONS(3993),
    [anon_sym_AMP_EQ] = ACTIONS(3993),
    [anon_sym_CARET_EQ] = ACTIONS(3993),
    [anon_sym_PIPE_EQ] = ACTIONS(3993),
    [anon_sym_LT_LT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(3993),
    [anon_sym_AMP_AMP] = ACTIONS(3993),
    [anon_sym_PIPE_PIPE] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK] = ACTIONS(3995),
    [anon_sym_from] = ACTIONS(4039),
    [anon_sym_into] = ACTIONS(4039),
    [anon_sym_join] = ACTIONS(4039),
    [anon_sym_on] = ACTIONS(4039),
    [anon_sym_equals] = ACTIONS(4039),
    [anon_sym_let] = ACTIONS(4039),
    [anon_sym_orderby] = ACTIONS(4039),
    [anon_sym_ascending] = ACTIONS(4039),
    [anon_sym_descending] = ACTIONS(4039),
    [anon_sym_group] = ACTIONS(4039),
    [anon_sym_by] = ACTIONS(4039),
    [anon_sym_select] = ACTIONS(4039),
    [anon_sym_as] = ACTIONS(3995),
    [anon_sym_is] = ACTIONS(3995),
    [anon_sym_DASH_GT] = ACTIONS(3993),
    [anon_sym_with] = ACTIONS(3995),
    [aux_sym_preproc_if_token3] = ACTIONS(3993),
    [aux_sym_preproc_else_token1] = ACTIONS(3993),
    [aux_sym_preproc_elif_token1] = ACTIONS(3993),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2655] = {
    [sym_preproc_region] = STATE(2655),
    [sym_preproc_endregion] = STATE(2655),
    [sym_preproc_line] = STATE(2655),
    [sym_preproc_pragma] = STATE(2655),
    [sym_preproc_nullable] = STATE(2655),
    [sym_preproc_error] = STATE(2655),
    [sym_preproc_warning] = STATE(2655),
    [sym_preproc_define] = STATE(2655),
    [sym_preproc_undef] = STATE(2655),
    [sym__identifier_token] = ACTIONS(3057),
    [anon_sym_extern] = ACTIONS(3057),
    [anon_sym_alias] = ACTIONS(3057),
    [anon_sym_SEMI] = ACTIONS(3059),
    [anon_sym_global] = ACTIONS(3057),
    [anon_sym_using] = ACTIONS(3057),
    [anon_sym_unsafe] = ACTIONS(3057),
    [anon_sym_static] = ACTIONS(3057),
    [anon_sym_LBRACK] = ACTIONS(3059),
    [anon_sym_LPAREN] = ACTIONS(3059),
    [anon_sym_return] = ACTIONS(3057),
    [anon_sym_ref] = ACTIONS(3057),
    [anon_sym_LBRACE] = ACTIONS(3059),
    [anon_sym_RBRACE] = ACTIONS(3059),
    [anon_sym_delegate] = ACTIONS(3057),
    [anon_sym_abstract] = ACTIONS(3057),
    [anon_sym_async] = ACTIONS(3057),
    [anon_sym_const] = ACTIONS(3057),
    [anon_sym_file] = ACTIONS(3057),
    [anon_sym_fixed] = ACTIONS(3057),
    [anon_sym_internal] = ACTIONS(3057),
    [anon_sym_new] = ACTIONS(3057),
    [anon_sym_override] = ACTIONS(3057),
    [anon_sym_partial] = ACTIONS(3057),
    [anon_sym_private] = ACTIONS(3057),
    [anon_sym_protected] = ACTIONS(3057),
    [anon_sym_public] = ACTIONS(3057),
    [anon_sym_readonly] = ACTIONS(3057),
    [anon_sym_required] = ACTIONS(3057),
    [anon_sym_sealed] = ACTIONS(3057),
    [anon_sym_virtual] = ACTIONS(3057),
    [anon_sym_volatile] = ACTIONS(3057),
    [anon_sym_where] = ACTIONS(3057),
    [anon_sym_notnull] = ACTIONS(3057),
    [anon_sym_unmanaged] = ACTIONS(3057),
    [anon_sym_checked] = ACTIONS(3057),
    [anon_sym_BANG] = ACTIONS(3059),
    [anon_sym_TILDE] = ACTIONS(3059),
    [anon_sym_PLUS_PLUS] = ACTIONS(3059),
    [anon_sym_DASH_DASH] = ACTIONS(3059),
    [anon_sym_true] = ACTIONS(3057),
    [anon_sym_false] = ACTIONS(3057),
    [anon_sym_PLUS] = ACTIONS(3057),
    [anon_sym_DASH] = ACTIONS(3057),
    [anon_sym_STAR] = ACTIONS(3059),
    [anon_sym_CARET] = ACTIONS(3059),
    [anon_sym_AMP] = ACTIONS(3059),
    [anon_sym_this] = ACTIONS(3057),
    [anon_sym_scoped] = ACTIONS(3057),
    [anon_sym_base] = ACTIONS(3057),
    [anon_sym_var] = ACTIONS(3057),
    [sym_predefined_type] = ACTIONS(3057),
    [anon_sym_break] = ACTIONS(3057),
    [anon_sym_unchecked] = ACTIONS(3057),
    [anon_sym_continue] = ACTIONS(3057),
    [anon_sym_do] = ACTIONS(3057),
    [anon_sym_while] = ACTIONS(3057),
    [anon_sym_for] = ACTIONS(3057),
    [anon_sym_lock] = ACTIONS(3057),
    [anon_sym_yield] = ACTIONS(3057),
    [anon_sym_switch] = ACTIONS(3057),
    [anon_sym_case] = ACTIONS(3057),
    [anon_sym_default] = ACTIONS(3057),
    [anon_sym_throw] = ACTIONS(3057),
    [anon_sym_try] = ACTIONS(3057),
    [anon_sym_when] = ACTIONS(3057),
    [anon_sym_await] = ACTIONS(3057),
    [anon_sym_foreach] = ACTIONS(3057),
    [anon_sym_goto] = ACTIONS(3057),
    [anon_sym_if] = ACTIONS(3057),
    [anon_sym_else] = ACTIONS(3057),
    [anon_sym_DOT_DOT] = ACTIONS(3059),
    [anon_sym_from] = ACTIONS(3057),
    [anon_sym_into] = ACTIONS(3057),
    [anon_sym_join] = ACTIONS(3057),
    [anon_sym_on] = ACTIONS(3057),
    [anon_sym_equals] = ACTIONS(3057),
    [anon_sym_let] = ACTIONS(3057),
    [anon_sym_orderby] = ACTIONS(3057),
    [anon_sym_ascending] = ACTIONS(3057),
    [anon_sym_descending] = ACTIONS(3057),
    [anon_sym_group] = ACTIONS(3057),
    [anon_sym_by] = ACTIONS(3057),
    [anon_sym_select] = ACTIONS(3057),
    [anon_sym_stackalloc] = ACTIONS(3057),
    [anon_sym_sizeof] = ACTIONS(3057),
    [anon_sym_typeof] = ACTIONS(3057),
    [anon_sym___makeref] = ACTIONS(3057),
    [anon_sym___reftype] = ACTIONS(3057),
    [anon_sym___refvalue] = ACTIONS(3057),
    [sym_null_literal] = ACTIONS(3057),
    [anon_sym_SQUOTE] = ACTIONS(3059),
    [sym_integer_literal] = ACTIONS(3057),
    [sym_real_literal] = ACTIONS(3059),
    [anon_sym_DQUOTE] = ACTIONS(3059),
    [sym_verbatim_string_literal] = ACTIONS(3059),
    [aux_sym_preproc_if_token1] = ACTIONS(3059),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3059),
    [sym_interpolation_verbatim_start] = ACTIONS(3059),
    [sym_interpolation_raw_start] = ACTIONS(3059),
    [sym_raw_string_start] = ACTIONS(3059),
  },
  [2656] = {
    [sym_preproc_region] = STATE(2656),
    [sym_preproc_endregion] = STATE(2656),
    [sym_preproc_line] = STATE(2656),
    [sym_preproc_pragma] = STATE(2656),
    [sym_preproc_nullable] = STATE(2656),
    [sym_preproc_error] = STATE(2656),
    [sym_preproc_warning] = STATE(2656),
    [sym_preproc_define] = STATE(2656),
    [sym_preproc_undef] = STATE(2656),
    [sym__identifier_token] = ACTIONS(3169),
    [anon_sym_extern] = ACTIONS(3169),
    [anon_sym_alias] = ACTIONS(3169),
    [anon_sym_SEMI] = ACTIONS(3171),
    [anon_sym_global] = ACTIONS(3169),
    [anon_sym_using] = ACTIONS(3169),
    [anon_sym_unsafe] = ACTIONS(3169),
    [anon_sym_static] = ACTIONS(3169),
    [anon_sym_LBRACK] = ACTIONS(3171),
    [anon_sym_LPAREN] = ACTIONS(3171),
    [anon_sym_return] = ACTIONS(3169),
    [anon_sym_ref] = ACTIONS(3169),
    [anon_sym_LBRACE] = ACTIONS(3171),
    [anon_sym_RBRACE] = ACTIONS(3171),
    [anon_sym_delegate] = ACTIONS(3169),
    [anon_sym_abstract] = ACTIONS(3169),
    [anon_sym_async] = ACTIONS(3169),
    [anon_sym_const] = ACTIONS(3169),
    [anon_sym_file] = ACTIONS(3169),
    [anon_sym_fixed] = ACTIONS(3169),
    [anon_sym_internal] = ACTIONS(3169),
    [anon_sym_new] = ACTIONS(3169),
    [anon_sym_override] = ACTIONS(3169),
    [anon_sym_partial] = ACTIONS(3169),
    [anon_sym_private] = ACTIONS(3169),
    [anon_sym_protected] = ACTIONS(3169),
    [anon_sym_public] = ACTIONS(3169),
    [anon_sym_readonly] = ACTIONS(3169),
    [anon_sym_required] = ACTIONS(3169),
    [anon_sym_sealed] = ACTIONS(3169),
    [anon_sym_virtual] = ACTIONS(3169),
    [anon_sym_volatile] = ACTIONS(3169),
    [anon_sym_where] = ACTIONS(3169),
    [anon_sym_notnull] = ACTIONS(3169),
    [anon_sym_unmanaged] = ACTIONS(3169),
    [anon_sym_checked] = ACTIONS(3169),
    [anon_sym_BANG] = ACTIONS(3171),
    [anon_sym_TILDE] = ACTIONS(3171),
    [anon_sym_PLUS_PLUS] = ACTIONS(3171),
    [anon_sym_DASH_DASH] = ACTIONS(3171),
    [anon_sym_true] = ACTIONS(3169),
    [anon_sym_false] = ACTIONS(3169),
    [anon_sym_PLUS] = ACTIONS(3169),
    [anon_sym_DASH] = ACTIONS(3169),
    [anon_sym_STAR] = ACTIONS(3171),
    [anon_sym_CARET] = ACTIONS(3171),
    [anon_sym_AMP] = ACTIONS(3171),
    [anon_sym_this] = ACTIONS(3169),
    [anon_sym_scoped] = ACTIONS(3169),
    [anon_sym_base] = ACTIONS(3169),
    [anon_sym_var] = ACTIONS(3169),
    [sym_predefined_type] = ACTIONS(3169),
    [anon_sym_break] = ACTIONS(3169),
    [anon_sym_unchecked] = ACTIONS(3169),
    [anon_sym_continue] = ACTIONS(3169),
    [anon_sym_do] = ACTIONS(3169),
    [anon_sym_while] = ACTIONS(3169),
    [anon_sym_for] = ACTIONS(3169),
    [anon_sym_lock] = ACTIONS(3169),
    [anon_sym_yield] = ACTIONS(3169),
    [anon_sym_switch] = ACTIONS(3169),
    [anon_sym_case] = ACTIONS(3169),
    [anon_sym_default] = ACTIONS(3169),
    [anon_sym_throw] = ACTIONS(3169),
    [anon_sym_try] = ACTIONS(3169),
    [anon_sym_when] = ACTIONS(3169),
    [anon_sym_await] = ACTIONS(3169),
    [anon_sym_foreach] = ACTIONS(3169),
    [anon_sym_goto] = ACTIONS(3169),
    [anon_sym_if] = ACTIONS(3169),
    [anon_sym_else] = ACTIONS(3169),
    [anon_sym_DOT_DOT] = ACTIONS(3171),
    [anon_sym_from] = ACTIONS(3169),
    [anon_sym_into] = ACTIONS(3169),
    [anon_sym_join] = ACTIONS(3169),
    [anon_sym_on] = ACTIONS(3169),
    [anon_sym_equals] = ACTIONS(3169),
    [anon_sym_let] = ACTIONS(3169),
    [anon_sym_orderby] = ACTIONS(3169),
    [anon_sym_ascending] = ACTIONS(3169),
    [anon_sym_descending] = ACTIONS(3169),
    [anon_sym_group] = ACTIONS(3169),
    [anon_sym_by] = ACTIONS(3169),
    [anon_sym_select] = ACTIONS(3169),
    [anon_sym_stackalloc] = ACTIONS(3169),
    [anon_sym_sizeof] = ACTIONS(3169),
    [anon_sym_typeof] = ACTIONS(3169),
    [anon_sym___makeref] = ACTIONS(3169),
    [anon_sym___reftype] = ACTIONS(3169),
    [anon_sym___refvalue] = ACTIONS(3169),
    [sym_null_literal] = ACTIONS(3169),
    [anon_sym_SQUOTE] = ACTIONS(3171),
    [sym_integer_literal] = ACTIONS(3169),
    [sym_real_literal] = ACTIONS(3171),
    [anon_sym_DQUOTE] = ACTIONS(3171),
    [sym_verbatim_string_literal] = ACTIONS(3171),
    [aux_sym_preproc_if_token1] = ACTIONS(3171),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3171),
    [sym_interpolation_verbatim_start] = ACTIONS(3171),
    [sym_interpolation_raw_start] = ACTIONS(3171),
    [sym_raw_string_start] = ACTIONS(3171),
  },
  [2657] = {
    [sym_preproc_region] = STATE(2657),
    [sym_preproc_endregion] = STATE(2657),
    [sym_preproc_line] = STATE(2657),
    [sym_preproc_pragma] = STATE(2657),
    [sym_preproc_nullable] = STATE(2657),
    [sym_preproc_error] = STATE(2657),
    [sym_preproc_warning] = STATE(2657),
    [sym_preproc_define] = STATE(2657),
    [sym_preproc_undef] = STATE(2657),
    [sym__identifier_token] = ACTIONS(3181),
    [anon_sym_extern] = ACTIONS(3181),
    [anon_sym_alias] = ACTIONS(3181),
    [anon_sym_SEMI] = ACTIONS(3183),
    [anon_sym_global] = ACTIONS(3181),
    [anon_sym_using] = ACTIONS(3181),
    [anon_sym_unsafe] = ACTIONS(3181),
    [anon_sym_static] = ACTIONS(3181),
    [anon_sym_LBRACK] = ACTIONS(3183),
    [anon_sym_LPAREN] = ACTIONS(3183),
    [anon_sym_return] = ACTIONS(3181),
    [anon_sym_ref] = ACTIONS(3181),
    [anon_sym_LBRACE] = ACTIONS(3183),
    [anon_sym_RBRACE] = ACTIONS(3183),
    [anon_sym_delegate] = ACTIONS(3181),
    [anon_sym_abstract] = ACTIONS(3181),
    [anon_sym_async] = ACTIONS(3181),
    [anon_sym_const] = ACTIONS(3181),
    [anon_sym_file] = ACTIONS(3181),
    [anon_sym_fixed] = ACTIONS(3181),
    [anon_sym_internal] = ACTIONS(3181),
    [anon_sym_new] = ACTIONS(3181),
    [anon_sym_override] = ACTIONS(3181),
    [anon_sym_partial] = ACTIONS(3181),
    [anon_sym_private] = ACTIONS(3181),
    [anon_sym_protected] = ACTIONS(3181),
    [anon_sym_public] = ACTIONS(3181),
    [anon_sym_readonly] = ACTIONS(3181),
    [anon_sym_required] = ACTIONS(3181),
    [anon_sym_sealed] = ACTIONS(3181),
    [anon_sym_virtual] = ACTIONS(3181),
    [anon_sym_volatile] = ACTIONS(3181),
    [anon_sym_where] = ACTIONS(3181),
    [anon_sym_notnull] = ACTIONS(3181),
    [anon_sym_unmanaged] = ACTIONS(3181),
    [anon_sym_checked] = ACTIONS(3181),
    [anon_sym_BANG] = ACTIONS(3183),
    [anon_sym_TILDE] = ACTIONS(3183),
    [anon_sym_PLUS_PLUS] = ACTIONS(3183),
    [anon_sym_DASH_DASH] = ACTIONS(3183),
    [anon_sym_true] = ACTIONS(3181),
    [anon_sym_false] = ACTIONS(3181),
    [anon_sym_PLUS] = ACTIONS(3181),
    [anon_sym_DASH] = ACTIONS(3181),
    [anon_sym_STAR] = ACTIONS(3183),
    [anon_sym_CARET] = ACTIONS(3183),
    [anon_sym_AMP] = ACTIONS(3183),
    [anon_sym_this] = ACTIONS(3181),
    [anon_sym_scoped] = ACTIONS(3181),
    [anon_sym_base] = ACTIONS(3181),
    [anon_sym_var] = ACTIONS(3181),
    [sym_predefined_type] = ACTIONS(3181),
    [anon_sym_break] = ACTIONS(3181),
    [anon_sym_unchecked] = ACTIONS(3181),
    [anon_sym_continue] = ACTIONS(3181),
    [anon_sym_do] = ACTIONS(3181),
    [anon_sym_while] = ACTIONS(3181),
    [anon_sym_for] = ACTIONS(3181),
    [anon_sym_lock] = ACTIONS(3181),
    [anon_sym_yield] = ACTIONS(3181),
    [anon_sym_switch] = ACTIONS(3181),
    [anon_sym_case] = ACTIONS(3181),
    [anon_sym_default] = ACTIONS(3181),
    [anon_sym_throw] = ACTIONS(3181),
    [anon_sym_try] = ACTIONS(3181),
    [anon_sym_when] = ACTIONS(3181),
    [anon_sym_await] = ACTIONS(3181),
    [anon_sym_foreach] = ACTIONS(3181),
    [anon_sym_goto] = ACTIONS(3181),
    [anon_sym_if] = ACTIONS(3181),
    [anon_sym_else] = ACTIONS(3181),
    [anon_sym_DOT_DOT] = ACTIONS(3183),
    [anon_sym_from] = ACTIONS(3181),
    [anon_sym_into] = ACTIONS(3181),
    [anon_sym_join] = ACTIONS(3181),
    [anon_sym_on] = ACTIONS(3181),
    [anon_sym_equals] = ACTIONS(3181),
    [anon_sym_let] = ACTIONS(3181),
    [anon_sym_orderby] = ACTIONS(3181),
    [anon_sym_ascending] = ACTIONS(3181),
    [anon_sym_descending] = ACTIONS(3181),
    [anon_sym_group] = ACTIONS(3181),
    [anon_sym_by] = ACTIONS(3181),
    [anon_sym_select] = ACTIONS(3181),
    [anon_sym_stackalloc] = ACTIONS(3181),
    [anon_sym_sizeof] = ACTIONS(3181),
    [anon_sym_typeof] = ACTIONS(3181),
    [anon_sym___makeref] = ACTIONS(3181),
    [anon_sym___reftype] = ACTIONS(3181),
    [anon_sym___refvalue] = ACTIONS(3181),
    [sym_null_literal] = ACTIONS(3181),
    [anon_sym_SQUOTE] = ACTIONS(3183),
    [sym_integer_literal] = ACTIONS(3181),
    [sym_real_literal] = ACTIONS(3183),
    [anon_sym_DQUOTE] = ACTIONS(3183),
    [sym_verbatim_string_literal] = ACTIONS(3183),
    [aux_sym_preproc_if_token1] = ACTIONS(3183),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3183),
    [sym_interpolation_verbatim_start] = ACTIONS(3183),
    [sym_interpolation_raw_start] = ACTIONS(3183),
    [sym_raw_string_start] = ACTIONS(3183),
  },
  [2658] = {
    [sym_preproc_region] = STATE(2658),
    [sym_preproc_endregion] = STATE(2658),
    [sym_preproc_line] = STATE(2658),
    [sym_preproc_pragma] = STATE(2658),
    [sym_preproc_nullable] = STATE(2658),
    [sym_preproc_error] = STATE(2658),
    [sym_preproc_warning] = STATE(2658),
    [sym_preproc_define] = STATE(2658),
    [sym_preproc_undef] = STATE(2658),
    [sym__identifier_token] = ACTIONS(3273),
    [anon_sym_extern] = ACTIONS(3273),
    [anon_sym_alias] = ACTIONS(3273),
    [anon_sym_SEMI] = ACTIONS(3275),
    [anon_sym_global] = ACTIONS(3273),
    [anon_sym_using] = ACTIONS(3273),
    [anon_sym_unsafe] = ACTIONS(3273),
    [anon_sym_static] = ACTIONS(3273),
    [anon_sym_LBRACK] = ACTIONS(3275),
    [anon_sym_LPAREN] = ACTIONS(3275),
    [anon_sym_return] = ACTIONS(3273),
    [anon_sym_ref] = ACTIONS(3273),
    [anon_sym_LBRACE] = ACTIONS(3275),
    [anon_sym_RBRACE] = ACTIONS(3275),
    [anon_sym_delegate] = ACTIONS(3273),
    [anon_sym_abstract] = ACTIONS(3273),
    [anon_sym_async] = ACTIONS(3273),
    [anon_sym_const] = ACTIONS(3273),
    [anon_sym_file] = ACTIONS(3273),
    [anon_sym_fixed] = ACTIONS(3273),
    [anon_sym_internal] = ACTIONS(3273),
    [anon_sym_new] = ACTIONS(3273),
    [anon_sym_override] = ACTIONS(3273),
    [anon_sym_partial] = ACTIONS(3273),
    [anon_sym_private] = ACTIONS(3273),
    [anon_sym_protected] = ACTIONS(3273),
    [anon_sym_public] = ACTIONS(3273),
    [anon_sym_readonly] = ACTIONS(3273),
    [anon_sym_required] = ACTIONS(3273),
    [anon_sym_sealed] = ACTIONS(3273),
    [anon_sym_virtual] = ACTIONS(3273),
    [anon_sym_volatile] = ACTIONS(3273),
    [anon_sym_where] = ACTIONS(3273),
    [anon_sym_notnull] = ACTIONS(3273),
    [anon_sym_unmanaged] = ACTIONS(3273),
    [anon_sym_checked] = ACTIONS(3273),
    [anon_sym_BANG] = ACTIONS(3275),
    [anon_sym_TILDE] = ACTIONS(3275),
    [anon_sym_PLUS_PLUS] = ACTIONS(3275),
    [anon_sym_DASH_DASH] = ACTIONS(3275),
    [anon_sym_true] = ACTIONS(3273),
    [anon_sym_false] = ACTIONS(3273),
    [anon_sym_PLUS] = ACTIONS(3273),
    [anon_sym_DASH] = ACTIONS(3273),
    [anon_sym_STAR] = ACTIONS(3275),
    [anon_sym_CARET] = ACTIONS(3275),
    [anon_sym_AMP] = ACTIONS(3275),
    [anon_sym_this] = ACTIONS(3273),
    [anon_sym_scoped] = ACTIONS(3273),
    [anon_sym_base] = ACTIONS(3273),
    [anon_sym_var] = ACTIONS(3273),
    [sym_predefined_type] = ACTIONS(3273),
    [anon_sym_break] = ACTIONS(3273),
    [anon_sym_unchecked] = ACTIONS(3273),
    [anon_sym_continue] = ACTIONS(3273),
    [anon_sym_do] = ACTIONS(3273),
    [anon_sym_while] = ACTIONS(3273),
    [anon_sym_for] = ACTIONS(3273),
    [anon_sym_lock] = ACTIONS(3273),
    [anon_sym_yield] = ACTIONS(3273),
    [anon_sym_switch] = ACTIONS(3273),
    [anon_sym_case] = ACTIONS(3273),
    [anon_sym_default] = ACTIONS(3273),
    [anon_sym_throw] = ACTIONS(3273),
    [anon_sym_try] = ACTIONS(3273),
    [anon_sym_when] = ACTIONS(3273),
    [anon_sym_await] = ACTIONS(3273),
    [anon_sym_foreach] = ACTIONS(3273),
    [anon_sym_goto] = ACTIONS(3273),
    [anon_sym_if] = ACTIONS(3273),
    [anon_sym_else] = ACTIONS(3273),
    [anon_sym_DOT_DOT] = ACTIONS(3275),
    [anon_sym_from] = ACTIONS(3273),
    [anon_sym_into] = ACTIONS(3273),
    [anon_sym_join] = ACTIONS(3273),
    [anon_sym_on] = ACTIONS(3273),
    [anon_sym_equals] = ACTIONS(3273),
    [anon_sym_let] = ACTIONS(3273),
    [anon_sym_orderby] = ACTIONS(3273),
    [anon_sym_ascending] = ACTIONS(3273),
    [anon_sym_descending] = ACTIONS(3273),
    [anon_sym_group] = ACTIONS(3273),
    [anon_sym_by] = ACTIONS(3273),
    [anon_sym_select] = ACTIONS(3273),
    [anon_sym_stackalloc] = ACTIONS(3273),
    [anon_sym_sizeof] = ACTIONS(3273),
    [anon_sym_typeof] = ACTIONS(3273),
    [anon_sym___makeref] = ACTIONS(3273),
    [anon_sym___reftype] = ACTIONS(3273),
    [anon_sym___refvalue] = ACTIONS(3273),
    [sym_null_literal] = ACTIONS(3273),
    [anon_sym_SQUOTE] = ACTIONS(3275),
    [sym_integer_literal] = ACTIONS(3273),
    [sym_real_literal] = ACTIONS(3275),
    [anon_sym_DQUOTE] = ACTIONS(3275),
    [sym_verbatim_string_literal] = ACTIONS(3275),
    [aux_sym_preproc_if_token1] = ACTIONS(3275),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3275),
    [sym_interpolation_verbatim_start] = ACTIONS(3275),
    [sym_interpolation_raw_start] = ACTIONS(3275),
    [sym_raw_string_start] = ACTIONS(3275),
  },
  [2659] = {
    [sym_preproc_region] = STATE(2659),
    [sym_preproc_endregion] = STATE(2659),
    [sym_preproc_line] = STATE(2659),
    [sym_preproc_pragma] = STATE(2659),
    [sym_preproc_nullable] = STATE(2659),
    [sym_preproc_error] = STATE(2659),
    [sym_preproc_warning] = STATE(2659),
    [sym_preproc_define] = STATE(2659),
    [sym_preproc_undef] = STATE(2659),
    [sym__identifier_token] = ACTIONS(3277),
    [anon_sym_extern] = ACTIONS(3277),
    [anon_sym_alias] = ACTIONS(3277),
    [anon_sym_SEMI] = ACTIONS(3279),
    [anon_sym_global] = ACTIONS(3277),
    [anon_sym_using] = ACTIONS(3277),
    [anon_sym_unsafe] = ACTIONS(3277),
    [anon_sym_static] = ACTIONS(3277),
    [anon_sym_LBRACK] = ACTIONS(3279),
    [anon_sym_LPAREN] = ACTIONS(3279),
    [anon_sym_return] = ACTIONS(3277),
    [anon_sym_ref] = ACTIONS(3277),
    [anon_sym_LBRACE] = ACTIONS(3279),
    [anon_sym_RBRACE] = ACTIONS(3279),
    [anon_sym_delegate] = ACTIONS(3277),
    [anon_sym_abstract] = ACTIONS(3277),
    [anon_sym_async] = ACTIONS(3277),
    [anon_sym_const] = ACTIONS(3277),
    [anon_sym_file] = ACTIONS(3277),
    [anon_sym_fixed] = ACTIONS(3277),
    [anon_sym_internal] = ACTIONS(3277),
    [anon_sym_new] = ACTIONS(3277),
    [anon_sym_override] = ACTIONS(3277),
    [anon_sym_partial] = ACTIONS(3277),
    [anon_sym_private] = ACTIONS(3277),
    [anon_sym_protected] = ACTIONS(3277),
    [anon_sym_public] = ACTIONS(3277),
    [anon_sym_readonly] = ACTIONS(3277),
    [anon_sym_required] = ACTIONS(3277),
    [anon_sym_sealed] = ACTIONS(3277),
    [anon_sym_virtual] = ACTIONS(3277),
    [anon_sym_volatile] = ACTIONS(3277),
    [anon_sym_where] = ACTIONS(3277),
    [anon_sym_notnull] = ACTIONS(3277),
    [anon_sym_unmanaged] = ACTIONS(3277),
    [anon_sym_checked] = ACTIONS(3277),
    [anon_sym_BANG] = ACTIONS(3279),
    [anon_sym_TILDE] = ACTIONS(3279),
    [anon_sym_PLUS_PLUS] = ACTIONS(3279),
    [anon_sym_DASH_DASH] = ACTIONS(3279),
    [anon_sym_true] = ACTIONS(3277),
    [anon_sym_false] = ACTIONS(3277),
    [anon_sym_PLUS] = ACTIONS(3277),
    [anon_sym_DASH] = ACTIONS(3277),
    [anon_sym_STAR] = ACTIONS(3279),
    [anon_sym_CARET] = ACTIONS(3279),
    [anon_sym_AMP] = ACTIONS(3279),
    [anon_sym_this] = ACTIONS(3277),
    [anon_sym_scoped] = ACTIONS(3277),
    [anon_sym_base] = ACTIONS(3277),
    [anon_sym_var] = ACTIONS(3277),
    [sym_predefined_type] = ACTIONS(3277),
    [anon_sym_break] = ACTIONS(3277),
    [anon_sym_unchecked] = ACTIONS(3277),
    [anon_sym_continue] = ACTIONS(3277),
    [anon_sym_do] = ACTIONS(3277),
    [anon_sym_while] = ACTIONS(3277),
    [anon_sym_for] = ACTIONS(3277),
    [anon_sym_lock] = ACTIONS(3277),
    [anon_sym_yield] = ACTIONS(3277),
    [anon_sym_switch] = ACTIONS(3277),
    [anon_sym_case] = ACTIONS(3277),
    [anon_sym_default] = ACTIONS(3277),
    [anon_sym_throw] = ACTIONS(3277),
    [anon_sym_try] = ACTIONS(3277),
    [anon_sym_when] = ACTIONS(3277),
    [anon_sym_await] = ACTIONS(3277),
    [anon_sym_foreach] = ACTIONS(3277),
    [anon_sym_goto] = ACTIONS(3277),
    [anon_sym_if] = ACTIONS(3277),
    [anon_sym_else] = ACTIONS(3277),
    [anon_sym_DOT_DOT] = ACTIONS(3279),
    [anon_sym_from] = ACTIONS(3277),
    [anon_sym_into] = ACTIONS(3277),
    [anon_sym_join] = ACTIONS(3277),
    [anon_sym_on] = ACTIONS(3277),
    [anon_sym_equals] = ACTIONS(3277),
    [anon_sym_let] = ACTIONS(3277),
    [anon_sym_orderby] = ACTIONS(3277),
    [anon_sym_ascending] = ACTIONS(3277),
    [anon_sym_descending] = ACTIONS(3277),
    [anon_sym_group] = ACTIONS(3277),
    [anon_sym_by] = ACTIONS(3277),
    [anon_sym_select] = ACTIONS(3277),
    [anon_sym_stackalloc] = ACTIONS(3277),
    [anon_sym_sizeof] = ACTIONS(3277),
    [anon_sym_typeof] = ACTIONS(3277),
    [anon_sym___makeref] = ACTIONS(3277),
    [anon_sym___reftype] = ACTIONS(3277),
    [anon_sym___refvalue] = ACTIONS(3277),
    [sym_null_literal] = ACTIONS(3277),
    [anon_sym_SQUOTE] = ACTIONS(3279),
    [sym_integer_literal] = ACTIONS(3277),
    [sym_real_literal] = ACTIONS(3279),
    [anon_sym_DQUOTE] = ACTIONS(3279),
    [sym_verbatim_string_literal] = ACTIONS(3279),
    [aux_sym_preproc_if_token1] = ACTIONS(3279),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3279),
    [sym_interpolation_verbatim_start] = ACTIONS(3279),
    [sym_interpolation_raw_start] = ACTIONS(3279),
    [sym_raw_string_start] = ACTIONS(3279),
  },
  [2660] = {
    [sym_preproc_region] = STATE(2660),
    [sym_preproc_endregion] = STATE(2660),
    [sym_preproc_line] = STATE(2660),
    [sym_preproc_pragma] = STATE(2660),
    [sym_preproc_nullable] = STATE(2660),
    [sym_preproc_error] = STATE(2660),
    [sym_preproc_warning] = STATE(2660),
    [sym_preproc_define] = STATE(2660),
    [sym_preproc_undef] = STATE(2660),
    [sym__identifier_token] = ACTIONS(3101),
    [anon_sym_extern] = ACTIONS(3101),
    [anon_sym_alias] = ACTIONS(3101),
    [anon_sym_SEMI] = ACTIONS(3103),
    [anon_sym_global] = ACTIONS(3101),
    [anon_sym_using] = ACTIONS(3101),
    [anon_sym_unsafe] = ACTIONS(3101),
    [anon_sym_static] = ACTIONS(3101),
    [anon_sym_LBRACK] = ACTIONS(3103),
    [anon_sym_LPAREN] = ACTIONS(3103),
    [anon_sym_return] = ACTIONS(3101),
    [anon_sym_ref] = ACTIONS(3101),
    [anon_sym_LBRACE] = ACTIONS(3103),
    [anon_sym_RBRACE] = ACTIONS(3103),
    [anon_sym_delegate] = ACTIONS(3101),
    [anon_sym_abstract] = ACTIONS(3101),
    [anon_sym_async] = ACTIONS(3101),
    [anon_sym_const] = ACTIONS(3101),
    [anon_sym_file] = ACTIONS(3101),
    [anon_sym_fixed] = ACTIONS(3101),
    [anon_sym_internal] = ACTIONS(3101),
    [anon_sym_new] = ACTIONS(3101),
    [anon_sym_override] = ACTIONS(3101),
    [anon_sym_partial] = ACTIONS(3101),
    [anon_sym_private] = ACTIONS(3101),
    [anon_sym_protected] = ACTIONS(3101),
    [anon_sym_public] = ACTIONS(3101),
    [anon_sym_readonly] = ACTIONS(3101),
    [anon_sym_required] = ACTIONS(3101),
    [anon_sym_sealed] = ACTIONS(3101),
    [anon_sym_virtual] = ACTIONS(3101),
    [anon_sym_volatile] = ACTIONS(3101),
    [anon_sym_where] = ACTIONS(3101),
    [anon_sym_notnull] = ACTIONS(3101),
    [anon_sym_unmanaged] = ACTIONS(3101),
    [anon_sym_checked] = ACTIONS(3101),
    [anon_sym_BANG] = ACTIONS(3103),
    [anon_sym_TILDE] = ACTIONS(3103),
    [anon_sym_PLUS_PLUS] = ACTIONS(3103),
    [anon_sym_DASH_DASH] = ACTIONS(3103),
    [anon_sym_true] = ACTIONS(3101),
    [anon_sym_false] = ACTIONS(3101),
    [anon_sym_PLUS] = ACTIONS(3101),
    [anon_sym_DASH] = ACTIONS(3101),
    [anon_sym_STAR] = ACTIONS(3103),
    [anon_sym_CARET] = ACTIONS(3103),
    [anon_sym_AMP] = ACTIONS(3103),
    [anon_sym_this] = ACTIONS(3101),
    [anon_sym_scoped] = ACTIONS(3101),
    [anon_sym_base] = ACTIONS(3101),
    [anon_sym_var] = ACTIONS(3101),
    [sym_predefined_type] = ACTIONS(3101),
    [anon_sym_break] = ACTIONS(3101),
    [anon_sym_unchecked] = ACTIONS(3101),
    [anon_sym_continue] = ACTIONS(3101),
    [anon_sym_do] = ACTIONS(3101),
    [anon_sym_while] = ACTIONS(3101),
    [anon_sym_for] = ACTIONS(3101),
    [anon_sym_lock] = ACTIONS(3101),
    [anon_sym_yield] = ACTIONS(3101),
    [anon_sym_switch] = ACTIONS(3101),
    [anon_sym_case] = ACTIONS(3101),
    [anon_sym_default] = ACTIONS(3101),
    [anon_sym_throw] = ACTIONS(3101),
    [anon_sym_try] = ACTIONS(3101),
    [anon_sym_when] = ACTIONS(3101),
    [anon_sym_await] = ACTIONS(3101),
    [anon_sym_foreach] = ACTIONS(3101),
    [anon_sym_goto] = ACTIONS(3101),
    [anon_sym_if] = ACTIONS(3101),
    [anon_sym_else] = ACTIONS(3101),
    [anon_sym_DOT_DOT] = ACTIONS(3103),
    [anon_sym_from] = ACTIONS(3101),
    [anon_sym_into] = ACTIONS(3101),
    [anon_sym_join] = ACTIONS(3101),
    [anon_sym_on] = ACTIONS(3101),
    [anon_sym_equals] = ACTIONS(3101),
    [anon_sym_let] = ACTIONS(3101),
    [anon_sym_orderby] = ACTIONS(3101),
    [anon_sym_ascending] = ACTIONS(3101),
    [anon_sym_descending] = ACTIONS(3101),
    [anon_sym_group] = ACTIONS(3101),
    [anon_sym_by] = ACTIONS(3101),
    [anon_sym_select] = ACTIONS(3101),
    [anon_sym_stackalloc] = ACTIONS(3101),
    [anon_sym_sizeof] = ACTIONS(3101),
    [anon_sym_typeof] = ACTIONS(3101),
    [anon_sym___makeref] = ACTIONS(3101),
    [anon_sym___reftype] = ACTIONS(3101),
    [anon_sym___refvalue] = ACTIONS(3101),
    [sym_null_literal] = ACTIONS(3101),
    [anon_sym_SQUOTE] = ACTIONS(3103),
    [sym_integer_literal] = ACTIONS(3101),
    [sym_real_literal] = ACTIONS(3103),
    [anon_sym_DQUOTE] = ACTIONS(3103),
    [sym_verbatim_string_literal] = ACTIONS(3103),
    [aux_sym_preproc_if_token1] = ACTIONS(3103),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3103),
    [sym_interpolation_verbatim_start] = ACTIONS(3103),
    [sym_interpolation_raw_start] = ACTIONS(3103),
    [sym_raw_string_start] = ACTIONS(3103),
  },
  [2661] = {
    [sym_preproc_region] = STATE(2661),
    [sym_preproc_endregion] = STATE(2661),
    [sym_preproc_line] = STATE(2661),
    [sym_preproc_pragma] = STATE(2661),
    [sym_preproc_nullable] = STATE(2661),
    [sym_preproc_error] = STATE(2661),
    [sym_preproc_warning] = STATE(2661),
    [sym_preproc_define] = STATE(2661),
    [sym_preproc_undef] = STATE(2661),
    [sym__identifier_token] = ACTIONS(3105),
    [anon_sym_extern] = ACTIONS(3105),
    [anon_sym_alias] = ACTIONS(3105),
    [anon_sym_SEMI] = ACTIONS(3107),
    [anon_sym_global] = ACTIONS(3105),
    [anon_sym_using] = ACTIONS(3105),
    [anon_sym_unsafe] = ACTIONS(3105),
    [anon_sym_static] = ACTIONS(3105),
    [anon_sym_LBRACK] = ACTIONS(3107),
    [anon_sym_LPAREN] = ACTIONS(3107),
    [anon_sym_return] = ACTIONS(3105),
    [anon_sym_ref] = ACTIONS(3105),
    [anon_sym_LBRACE] = ACTIONS(3107),
    [anon_sym_RBRACE] = ACTIONS(3107),
    [anon_sym_delegate] = ACTIONS(3105),
    [anon_sym_abstract] = ACTIONS(3105),
    [anon_sym_async] = ACTIONS(3105),
    [anon_sym_const] = ACTIONS(3105),
    [anon_sym_file] = ACTIONS(3105),
    [anon_sym_fixed] = ACTIONS(3105),
    [anon_sym_internal] = ACTIONS(3105),
    [anon_sym_new] = ACTIONS(3105),
    [anon_sym_override] = ACTIONS(3105),
    [anon_sym_partial] = ACTIONS(3105),
    [anon_sym_private] = ACTIONS(3105),
    [anon_sym_protected] = ACTIONS(3105),
    [anon_sym_public] = ACTIONS(3105),
    [anon_sym_readonly] = ACTIONS(3105),
    [anon_sym_required] = ACTIONS(3105),
    [anon_sym_sealed] = ACTIONS(3105),
    [anon_sym_virtual] = ACTIONS(3105),
    [anon_sym_volatile] = ACTIONS(3105),
    [anon_sym_where] = ACTIONS(3105),
    [anon_sym_notnull] = ACTIONS(3105),
    [anon_sym_unmanaged] = ACTIONS(3105),
    [anon_sym_checked] = ACTIONS(3105),
    [anon_sym_BANG] = ACTIONS(3107),
    [anon_sym_TILDE] = ACTIONS(3107),
    [anon_sym_PLUS_PLUS] = ACTIONS(3107),
    [anon_sym_DASH_DASH] = ACTIONS(3107),
    [anon_sym_true] = ACTIONS(3105),
    [anon_sym_false] = ACTIONS(3105),
    [anon_sym_PLUS] = ACTIONS(3105),
    [anon_sym_DASH] = ACTIONS(3105),
    [anon_sym_STAR] = ACTIONS(3107),
    [anon_sym_CARET] = ACTIONS(3107),
    [anon_sym_AMP] = ACTIONS(3107),
    [anon_sym_this] = ACTIONS(3105),
    [anon_sym_scoped] = ACTIONS(3105),
    [anon_sym_base] = ACTIONS(3105),
    [anon_sym_var] = ACTIONS(3105),
    [sym_predefined_type] = ACTIONS(3105),
    [anon_sym_break] = ACTIONS(3105),
    [anon_sym_unchecked] = ACTIONS(3105),
    [anon_sym_continue] = ACTIONS(3105),
    [anon_sym_do] = ACTIONS(3105),
    [anon_sym_while] = ACTIONS(3105),
    [anon_sym_for] = ACTIONS(3105),
    [anon_sym_lock] = ACTIONS(3105),
    [anon_sym_yield] = ACTIONS(3105),
    [anon_sym_switch] = ACTIONS(3105),
    [anon_sym_case] = ACTIONS(3105),
    [anon_sym_default] = ACTIONS(3105),
    [anon_sym_throw] = ACTIONS(3105),
    [anon_sym_try] = ACTIONS(3105),
    [anon_sym_when] = ACTIONS(3105),
    [anon_sym_await] = ACTIONS(3105),
    [anon_sym_foreach] = ACTIONS(3105),
    [anon_sym_goto] = ACTIONS(3105),
    [anon_sym_if] = ACTIONS(3105),
    [anon_sym_else] = ACTIONS(3105),
    [anon_sym_DOT_DOT] = ACTIONS(3107),
    [anon_sym_from] = ACTIONS(3105),
    [anon_sym_into] = ACTIONS(3105),
    [anon_sym_join] = ACTIONS(3105),
    [anon_sym_on] = ACTIONS(3105),
    [anon_sym_equals] = ACTIONS(3105),
    [anon_sym_let] = ACTIONS(3105),
    [anon_sym_orderby] = ACTIONS(3105),
    [anon_sym_ascending] = ACTIONS(3105),
    [anon_sym_descending] = ACTIONS(3105),
    [anon_sym_group] = ACTIONS(3105),
    [anon_sym_by] = ACTIONS(3105),
    [anon_sym_select] = ACTIONS(3105),
    [anon_sym_stackalloc] = ACTIONS(3105),
    [anon_sym_sizeof] = ACTIONS(3105),
    [anon_sym_typeof] = ACTIONS(3105),
    [anon_sym___makeref] = ACTIONS(3105),
    [anon_sym___reftype] = ACTIONS(3105),
    [anon_sym___refvalue] = ACTIONS(3105),
    [sym_null_literal] = ACTIONS(3105),
    [anon_sym_SQUOTE] = ACTIONS(3107),
    [sym_integer_literal] = ACTIONS(3105),
    [sym_real_literal] = ACTIONS(3107),
    [anon_sym_DQUOTE] = ACTIONS(3107),
    [sym_verbatim_string_literal] = ACTIONS(3107),
    [aux_sym_preproc_if_token1] = ACTIONS(3107),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3107),
    [sym_interpolation_verbatim_start] = ACTIONS(3107),
    [sym_interpolation_raw_start] = ACTIONS(3107),
    [sym_raw_string_start] = ACTIONS(3107),
  },
  [2662] = {
    [sym_preproc_region] = STATE(2662),
    [sym_preproc_endregion] = STATE(2662),
    [sym_preproc_line] = STATE(2662),
    [sym_preproc_pragma] = STATE(2662),
    [sym_preproc_nullable] = STATE(2662),
    [sym_preproc_error] = STATE(2662),
    [sym_preproc_warning] = STATE(2662),
    [sym_preproc_define] = STATE(2662),
    [sym_preproc_undef] = STATE(2662),
    [sym__identifier_token] = ACTIONS(3281),
    [anon_sym_extern] = ACTIONS(3281),
    [anon_sym_alias] = ACTIONS(3281),
    [anon_sym_SEMI] = ACTIONS(3283),
    [anon_sym_global] = ACTIONS(3281),
    [anon_sym_using] = ACTIONS(3281),
    [anon_sym_unsafe] = ACTIONS(3281),
    [anon_sym_static] = ACTIONS(3281),
    [anon_sym_LBRACK] = ACTIONS(3283),
    [anon_sym_LPAREN] = ACTIONS(3283),
    [anon_sym_return] = ACTIONS(3281),
    [anon_sym_ref] = ACTIONS(3281),
    [anon_sym_LBRACE] = ACTIONS(3283),
    [anon_sym_RBRACE] = ACTIONS(3283),
    [anon_sym_delegate] = ACTIONS(3281),
    [anon_sym_abstract] = ACTIONS(3281),
    [anon_sym_async] = ACTIONS(3281),
    [anon_sym_const] = ACTIONS(3281),
    [anon_sym_file] = ACTIONS(3281),
    [anon_sym_fixed] = ACTIONS(3281),
    [anon_sym_internal] = ACTIONS(3281),
    [anon_sym_new] = ACTIONS(3281),
    [anon_sym_override] = ACTIONS(3281),
    [anon_sym_partial] = ACTIONS(3281),
    [anon_sym_private] = ACTIONS(3281),
    [anon_sym_protected] = ACTIONS(3281),
    [anon_sym_public] = ACTIONS(3281),
    [anon_sym_readonly] = ACTIONS(3281),
    [anon_sym_required] = ACTIONS(3281),
    [anon_sym_sealed] = ACTIONS(3281),
    [anon_sym_virtual] = ACTIONS(3281),
    [anon_sym_volatile] = ACTIONS(3281),
    [anon_sym_where] = ACTIONS(3281),
    [anon_sym_notnull] = ACTIONS(3281),
    [anon_sym_unmanaged] = ACTIONS(3281),
    [anon_sym_checked] = ACTIONS(3281),
    [anon_sym_BANG] = ACTIONS(3283),
    [anon_sym_TILDE] = ACTIONS(3283),
    [anon_sym_PLUS_PLUS] = ACTIONS(3283),
    [anon_sym_DASH_DASH] = ACTIONS(3283),
    [anon_sym_true] = ACTIONS(3281),
    [anon_sym_false] = ACTIONS(3281),
    [anon_sym_PLUS] = ACTIONS(3281),
    [anon_sym_DASH] = ACTIONS(3281),
    [anon_sym_STAR] = ACTIONS(3283),
    [anon_sym_CARET] = ACTIONS(3283),
    [anon_sym_AMP] = ACTIONS(3283),
    [anon_sym_this] = ACTIONS(3281),
    [anon_sym_scoped] = ACTIONS(3281),
    [anon_sym_base] = ACTIONS(3281),
    [anon_sym_var] = ACTIONS(3281),
    [sym_predefined_type] = ACTIONS(3281),
    [anon_sym_break] = ACTIONS(3281),
    [anon_sym_unchecked] = ACTIONS(3281),
    [anon_sym_continue] = ACTIONS(3281),
    [anon_sym_do] = ACTIONS(3281),
    [anon_sym_while] = ACTIONS(3281),
    [anon_sym_for] = ACTIONS(3281),
    [anon_sym_lock] = ACTIONS(3281),
    [anon_sym_yield] = ACTIONS(3281),
    [anon_sym_switch] = ACTIONS(3281),
    [anon_sym_case] = ACTIONS(3281),
    [anon_sym_default] = ACTIONS(3281),
    [anon_sym_throw] = ACTIONS(3281),
    [anon_sym_try] = ACTIONS(3281),
    [anon_sym_when] = ACTIONS(3281),
    [anon_sym_await] = ACTIONS(3281),
    [anon_sym_foreach] = ACTIONS(3281),
    [anon_sym_goto] = ACTIONS(3281),
    [anon_sym_if] = ACTIONS(3281),
    [anon_sym_else] = ACTIONS(3281),
    [anon_sym_DOT_DOT] = ACTIONS(3283),
    [anon_sym_from] = ACTIONS(3281),
    [anon_sym_into] = ACTIONS(3281),
    [anon_sym_join] = ACTIONS(3281),
    [anon_sym_on] = ACTIONS(3281),
    [anon_sym_equals] = ACTIONS(3281),
    [anon_sym_let] = ACTIONS(3281),
    [anon_sym_orderby] = ACTIONS(3281),
    [anon_sym_ascending] = ACTIONS(3281),
    [anon_sym_descending] = ACTIONS(3281),
    [anon_sym_group] = ACTIONS(3281),
    [anon_sym_by] = ACTIONS(3281),
    [anon_sym_select] = ACTIONS(3281),
    [anon_sym_stackalloc] = ACTIONS(3281),
    [anon_sym_sizeof] = ACTIONS(3281),
    [anon_sym_typeof] = ACTIONS(3281),
    [anon_sym___makeref] = ACTIONS(3281),
    [anon_sym___reftype] = ACTIONS(3281),
    [anon_sym___refvalue] = ACTIONS(3281),
    [sym_null_literal] = ACTIONS(3281),
    [anon_sym_SQUOTE] = ACTIONS(3283),
    [sym_integer_literal] = ACTIONS(3281),
    [sym_real_literal] = ACTIONS(3283),
    [anon_sym_DQUOTE] = ACTIONS(3283),
    [sym_verbatim_string_literal] = ACTIONS(3283),
    [aux_sym_preproc_if_token1] = ACTIONS(3283),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3283),
    [sym_interpolation_verbatim_start] = ACTIONS(3283),
    [sym_interpolation_raw_start] = ACTIONS(3283),
    [sym_raw_string_start] = ACTIONS(3283),
  },
  [2663] = {
    [sym_preproc_region] = STATE(2663),
    [sym_preproc_endregion] = STATE(2663),
    [sym_preproc_line] = STATE(2663),
    [sym_preproc_pragma] = STATE(2663),
    [sym_preproc_nullable] = STATE(2663),
    [sym_preproc_error] = STATE(2663),
    [sym_preproc_warning] = STATE(2663),
    [sym_preproc_define] = STATE(2663),
    [sym_preproc_undef] = STATE(2663),
    [sym__identifier_token] = ACTIONS(3189),
    [anon_sym_extern] = ACTIONS(3189),
    [anon_sym_alias] = ACTIONS(3189),
    [anon_sym_SEMI] = ACTIONS(3191),
    [anon_sym_global] = ACTIONS(3189),
    [anon_sym_using] = ACTIONS(3189),
    [anon_sym_unsafe] = ACTIONS(3189),
    [anon_sym_static] = ACTIONS(3189),
    [anon_sym_LBRACK] = ACTIONS(3191),
    [anon_sym_LPAREN] = ACTIONS(3191),
    [anon_sym_return] = ACTIONS(3189),
    [anon_sym_ref] = ACTIONS(3189),
    [anon_sym_LBRACE] = ACTIONS(3191),
    [anon_sym_RBRACE] = ACTIONS(3191),
    [anon_sym_delegate] = ACTIONS(3189),
    [anon_sym_abstract] = ACTIONS(3189),
    [anon_sym_async] = ACTIONS(3189),
    [anon_sym_const] = ACTIONS(3189),
    [anon_sym_file] = ACTIONS(3189),
    [anon_sym_fixed] = ACTIONS(3189),
    [anon_sym_internal] = ACTIONS(3189),
    [anon_sym_new] = ACTIONS(3189),
    [anon_sym_override] = ACTIONS(3189),
    [anon_sym_partial] = ACTIONS(3189),
    [anon_sym_private] = ACTIONS(3189),
    [anon_sym_protected] = ACTIONS(3189),
    [anon_sym_public] = ACTIONS(3189),
    [anon_sym_readonly] = ACTIONS(3189),
    [anon_sym_required] = ACTIONS(3189),
    [anon_sym_sealed] = ACTIONS(3189),
    [anon_sym_virtual] = ACTIONS(3189),
    [anon_sym_volatile] = ACTIONS(3189),
    [anon_sym_where] = ACTIONS(3189),
    [anon_sym_notnull] = ACTIONS(3189),
    [anon_sym_unmanaged] = ACTIONS(3189),
    [anon_sym_checked] = ACTIONS(3189),
    [anon_sym_BANG] = ACTIONS(3191),
    [anon_sym_TILDE] = ACTIONS(3191),
    [anon_sym_PLUS_PLUS] = ACTIONS(3191),
    [anon_sym_DASH_DASH] = ACTIONS(3191),
    [anon_sym_true] = ACTIONS(3189),
    [anon_sym_false] = ACTIONS(3189),
    [anon_sym_PLUS] = ACTIONS(3189),
    [anon_sym_DASH] = ACTIONS(3189),
    [anon_sym_STAR] = ACTIONS(3191),
    [anon_sym_CARET] = ACTIONS(3191),
    [anon_sym_AMP] = ACTIONS(3191),
    [anon_sym_this] = ACTIONS(3189),
    [anon_sym_scoped] = ACTIONS(3189),
    [anon_sym_base] = ACTIONS(3189),
    [anon_sym_var] = ACTIONS(3189),
    [sym_predefined_type] = ACTIONS(3189),
    [anon_sym_break] = ACTIONS(3189),
    [anon_sym_unchecked] = ACTIONS(3189),
    [anon_sym_continue] = ACTIONS(3189),
    [anon_sym_do] = ACTIONS(3189),
    [anon_sym_while] = ACTIONS(3189),
    [anon_sym_for] = ACTIONS(3189),
    [anon_sym_lock] = ACTIONS(3189),
    [anon_sym_yield] = ACTIONS(3189),
    [anon_sym_switch] = ACTIONS(3189),
    [anon_sym_case] = ACTIONS(3189),
    [anon_sym_default] = ACTIONS(3189),
    [anon_sym_throw] = ACTIONS(3189),
    [anon_sym_try] = ACTIONS(3189),
    [anon_sym_when] = ACTIONS(3189),
    [anon_sym_await] = ACTIONS(3189),
    [anon_sym_foreach] = ACTIONS(3189),
    [anon_sym_goto] = ACTIONS(3189),
    [anon_sym_if] = ACTIONS(3189),
    [anon_sym_else] = ACTIONS(3189),
    [anon_sym_DOT_DOT] = ACTIONS(3191),
    [anon_sym_from] = ACTIONS(3189),
    [anon_sym_into] = ACTIONS(3189),
    [anon_sym_join] = ACTIONS(3189),
    [anon_sym_on] = ACTIONS(3189),
    [anon_sym_equals] = ACTIONS(3189),
    [anon_sym_let] = ACTIONS(3189),
    [anon_sym_orderby] = ACTIONS(3189),
    [anon_sym_ascending] = ACTIONS(3189),
    [anon_sym_descending] = ACTIONS(3189),
    [anon_sym_group] = ACTIONS(3189),
    [anon_sym_by] = ACTIONS(3189),
    [anon_sym_select] = ACTIONS(3189),
    [anon_sym_stackalloc] = ACTIONS(3189),
    [anon_sym_sizeof] = ACTIONS(3189),
    [anon_sym_typeof] = ACTIONS(3189),
    [anon_sym___makeref] = ACTIONS(3189),
    [anon_sym___reftype] = ACTIONS(3189),
    [anon_sym___refvalue] = ACTIONS(3189),
    [sym_null_literal] = ACTIONS(3189),
    [anon_sym_SQUOTE] = ACTIONS(3191),
    [sym_integer_literal] = ACTIONS(3189),
    [sym_real_literal] = ACTIONS(3191),
    [anon_sym_DQUOTE] = ACTIONS(3191),
    [sym_verbatim_string_literal] = ACTIONS(3191),
    [aux_sym_preproc_if_token1] = ACTIONS(3191),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3191),
    [sym_interpolation_verbatim_start] = ACTIONS(3191),
    [sym_interpolation_raw_start] = ACTIONS(3191),
    [sym_raw_string_start] = ACTIONS(3191),
  },
  [2664] = {
    [sym_preproc_region] = STATE(2664),
    [sym_preproc_endregion] = STATE(2664),
    [sym_preproc_line] = STATE(2664),
    [sym_preproc_pragma] = STATE(2664),
    [sym_preproc_nullable] = STATE(2664),
    [sym_preproc_error] = STATE(2664),
    [sym_preproc_warning] = STATE(2664),
    [sym_preproc_define] = STATE(2664),
    [sym_preproc_undef] = STATE(2664),
    [sym__identifier_token] = ACTIONS(3285),
    [anon_sym_extern] = ACTIONS(3285),
    [anon_sym_alias] = ACTIONS(3285),
    [anon_sym_SEMI] = ACTIONS(3287),
    [anon_sym_global] = ACTIONS(3285),
    [anon_sym_using] = ACTIONS(3285),
    [anon_sym_unsafe] = ACTIONS(3285),
    [anon_sym_static] = ACTIONS(3285),
    [anon_sym_LBRACK] = ACTIONS(3287),
    [anon_sym_LPAREN] = ACTIONS(3287),
    [anon_sym_return] = ACTIONS(3285),
    [anon_sym_ref] = ACTIONS(3285),
    [anon_sym_LBRACE] = ACTIONS(3287),
    [anon_sym_RBRACE] = ACTIONS(3287),
    [anon_sym_delegate] = ACTIONS(3285),
    [anon_sym_abstract] = ACTIONS(3285),
    [anon_sym_async] = ACTIONS(3285),
    [anon_sym_const] = ACTIONS(3285),
    [anon_sym_file] = ACTIONS(3285),
    [anon_sym_fixed] = ACTIONS(3285),
    [anon_sym_internal] = ACTIONS(3285),
    [anon_sym_new] = ACTIONS(3285),
    [anon_sym_override] = ACTIONS(3285),
    [anon_sym_partial] = ACTIONS(3285),
    [anon_sym_private] = ACTIONS(3285),
    [anon_sym_protected] = ACTIONS(3285),
    [anon_sym_public] = ACTIONS(3285),
    [anon_sym_readonly] = ACTIONS(3285),
    [anon_sym_required] = ACTIONS(3285),
    [anon_sym_sealed] = ACTIONS(3285),
    [anon_sym_virtual] = ACTIONS(3285),
    [anon_sym_volatile] = ACTIONS(3285),
    [anon_sym_where] = ACTIONS(3285),
    [anon_sym_notnull] = ACTIONS(3285),
    [anon_sym_unmanaged] = ACTIONS(3285),
    [anon_sym_checked] = ACTIONS(3285),
    [anon_sym_BANG] = ACTIONS(3287),
    [anon_sym_TILDE] = ACTIONS(3287),
    [anon_sym_PLUS_PLUS] = ACTIONS(3287),
    [anon_sym_DASH_DASH] = ACTIONS(3287),
    [anon_sym_true] = ACTIONS(3285),
    [anon_sym_false] = ACTIONS(3285),
    [anon_sym_PLUS] = ACTIONS(3285),
    [anon_sym_DASH] = ACTIONS(3285),
    [anon_sym_STAR] = ACTIONS(3287),
    [anon_sym_CARET] = ACTIONS(3287),
    [anon_sym_AMP] = ACTIONS(3287),
    [anon_sym_this] = ACTIONS(3285),
    [anon_sym_scoped] = ACTIONS(3285),
    [anon_sym_base] = ACTIONS(3285),
    [anon_sym_var] = ACTIONS(3285),
    [sym_predefined_type] = ACTIONS(3285),
    [anon_sym_break] = ACTIONS(3285),
    [anon_sym_unchecked] = ACTIONS(3285),
    [anon_sym_continue] = ACTIONS(3285),
    [anon_sym_do] = ACTIONS(3285),
    [anon_sym_while] = ACTIONS(3285),
    [anon_sym_for] = ACTIONS(3285),
    [anon_sym_lock] = ACTIONS(3285),
    [anon_sym_yield] = ACTIONS(3285),
    [anon_sym_switch] = ACTIONS(3285),
    [anon_sym_case] = ACTIONS(3285),
    [anon_sym_default] = ACTIONS(3285),
    [anon_sym_throw] = ACTIONS(3285),
    [anon_sym_try] = ACTIONS(3285),
    [anon_sym_when] = ACTIONS(3285),
    [anon_sym_await] = ACTIONS(3285),
    [anon_sym_foreach] = ACTIONS(3285),
    [anon_sym_goto] = ACTIONS(3285),
    [anon_sym_if] = ACTIONS(3285),
    [anon_sym_else] = ACTIONS(3285),
    [anon_sym_DOT_DOT] = ACTIONS(3287),
    [anon_sym_from] = ACTIONS(3285),
    [anon_sym_into] = ACTIONS(3285),
    [anon_sym_join] = ACTIONS(3285),
    [anon_sym_on] = ACTIONS(3285),
    [anon_sym_equals] = ACTIONS(3285),
    [anon_sym_let] = ACTIONS(3285),
    [anon_sym_orderby] = ACTIONS(3285),
    [anon_sym_ascending] = ACTIONS(3285),
    [anon_sym_descending] = ACTIONS(3285),
    [anon_sym_group] = ACTIONS(3285),
    [anon_sym_by] = ACTIONS(3285),
    [anon_sym_select] = ACTIONS(3285),
    [anon_sym_stackalloc] = ACTIONS(3285),
    [anon_sym_sizeof] = ACTIONS(3285),
    [anon_sym_typeof] = ACTIONS(3285),
    [anon_sym___makeref] = ACTIONS(3285),
    [anon_sym___reftype] = ACTIONS(3285),
    [anon_sym___refvalue] = ACTIONS(3285),
    [sym_null_literal] = ACTIONS(3285),
    [anon_sym_SQUOTE] = ACTIONS(3287),
    [sym_integer_literal] = ACTIONS(3285),
    [sym_real_literal] = ACTIONS(3287),
    [anon_sym_DQUOTE] = ACTIONS(3287),
    [sym_verbatim_string_literal] = ACTIONS(3287),
    [aux_sym_preproc_if_token1] = ACTIONS(3287),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3287),
    [sym_interpolation_verbatim_start] = ACTIONS(3287),
    [sym_interpolation_raw_start] = ACTIONS(3287),
    [sym_raw_string_start] = ACTIONS(3287),
  },
  [2665] = {
    [sym_preproc_region] = STATE(2665),
    [sym_preproc_endregion] = STATE(2665),
    [sym_preproc_line] = STATE(2665),
    [sym_preproc_pragma] = STATE(2665),
    [sym_preproc_nullable] = STATE(2665),
    [sym_preproc_error] = STATE(2665),
    [sym_preproc_warning] = STATE(2665),
    [sym_preproc_define] = STATE(2665),
    [sym_preproc_undef] = STATE(2665),
    [sym__identifier_token] = ACTIONS(3289),
    [anon_sym_extern] = ACTIONS(3289),
    [anon_sym_alias] = ACTIONS(3289),
    [anon_sym_SEMI] = ACTIONS(3291),
    [anon_sym_global] = ACTIONS(3289),
    [anon_sym_using] = ACTIONS(3289),
    [anon_sym_unsafe] = ACTIONS(3289),
    [anon_sym_static] = ACTIONS(3289),
    [anon_sym_LBRACK] = ACTIONS(3291),
    [anon_sym_LPAREN] = ACTIONS(3291),
    [anon_sym_return] = ACTIONS(3289),
    [anon_sym_ref] = ACTIONS(3289),
    [anon_sym_LBRACE] = ACTIONS(3291),
    [anon_sym_RBRACE] = ACTIONS(3291),
    [anon_sym_delegate] = ACTIONS(3289),
    [anon_sym_abstract] = ACTIONS(3289),
    [anon_sym_async] = ACTIONS(3289),
    [anon_sym_const] = ACTIONS(3289),
    [anon_sym_file] = ACTIONS(3289),
    [anon_sym_fixed] = ACTIONS(3289),
    [anon_sym_internal] = ACTIONS(3289),
    [anon_sym_new] = ACTIONS(3289),
    [anon_sym_override] = ACTIONS(3289),
    [anon_sym_partial] = ACTIONS(3289),
    [anon_sym_private] = ACTIONS(3289),
    [anon_sym_protected] = ACTIONS(3289),
    [anon_sym_public] = ACTIONS(3289),
    [anon_sym_readonly] = ACTIONS(3289),
    [anon_sym_required] = ACTIONS(3289),
    [anon_sym_sealed] = ACTIONS(3289),
    [anon_sym_virtual] = ACTIONS(3289),
    [anon_sym_volatile] = ACTIONS(3289),
    [anon_sym_where] = ACTIONS(3289),
    [anon_sym_notnull] = ACTIONS(3289),
    [anon_sym_unmanaged] = ACTIONS(3289),
    [anon_sym_checked] = ACTIONS(3289),
    [anon_sym_BANG] = ACTIONS(3291),
    [anon_sym_TILDE] = ACTIONS(3291),
    [anon_sym_PLUS_PLUS] = ACTIONS(3291),
    [anon_sym_DASH_DASH] = ACTIONS(3291),
    [anon_sym_true] = ACTIONS(3289),
    [anon_sym_false] = ACTIONS(3289),
    [anon_sym_PLUS] = ACTIONS(3289),
    [anon_sym_DASH] = ACTIONS(3289),
    [anon_sym_STAR] = ACTIONS(3291),
    [anon_sym_CARET] = ACTIONS(3291),
    [anon_sym_AMP] = ACTIONS(3291),
    [anon_sym_this] = ACTIONS(3289),
    [anon_sym_scoped] = ACTIONS(3289),
    [anon_sym_base] = ACTIONS(3289),
    [anon_sym_var] = ACTIONS(3289),
    [sym_predefined_type] = ACTIONS(3289),
    [anon_sym_break] = ACTIONS(3289),
    [anon_sym_unchecked] = ACTIONS(3289),
    [anon_sym_continue] = ACTIONS(3289),
    [anon_sym_do] = ACTIONS(3289),
    [anon_sym_while] = ACTIONS(3289),
    [anon_sym_for] = ACTIONS(3289),
    [anon_sym_lock] = ACTIONS(3289),
    [anon_sym_yield] = ACTIONS(3289),
    [anon_sym_switch] = ACTIONS(3289),
    [anon_sym_case] = ACTIONS(3289),
    [anon_sym_default] = ACTIONS(3289),
    [anon_sym_throw] = ACTIONS(3289),
    [anon_sym_try] = ACTIONS(3289),
    [anon_sym_when] = ACTIONS(3289),
    [anon_sym_await] = ACTIONS(3289),
    [anon_sym_foreach] = ACTIONS(3289),
    [anon_sym_goto] = ACTIONS(3289),
    [anon_sym_if] = ACTIONS(3289),
    [anon_sym_else] = ACTIONS(3289),
    [anon_sym_DOT_DOT] = ACTIONS(3291),
    [anon_sym_from] = ACTIONS(3289),
    [anon_sym_into] = ACTIONS(3289),
    [anon_sym_join] = ACTIONS(3289),
    [anon_sym_on] = ACTIONS(3289),
    [anon_sym_equals] = ACTIONS(3289),
    [anon_sym_let] = ACTIONS(3289),
    [anon_sym_orderby] = ACTIONS(3289),
    [anon_sym_ascending] = ACTIONS(3289),
    [anon_sym_descending] = ACTIONS(3289),
    [anon_sym_group] = ACTIONS(3289),
    [anon_sym_by] = ACTIONS(3289),
    [anon_sym_select] = ACTIONS(3289),
    [anon_sym_stackalloc] = ACTIONS(3289),
    [anon_sym_sizeof] = ACTIONS(3289),
    [anon_sym_typeof] = ACTIONS(3289),
    [anon_sym___makeref] = ACTIONS(3289),
    [anon_sym___reftype] = ACTIONS(3289),
    [anon_sym___refvalue] = ACTIONS(3289),
    [sym_null_literal] = ACTIONS(3289),
    [anon_sym_SQUOTE] = ACTIONS(3291),
    [sym_integer_literal] = ACTIONS(3289),
    [sym_real_literal] = ACTIONS(3291),
    [anon_sym_DQUOTE] = ACTIONS(3291),
    [sym_verbatim_string_literal] = ACTIONS(3291),
    [aux_sym_preproc_if_token1] = ACTIONS(3291),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3291),
    [sym_interpolation_verbatim_start] = ACTIONS(3291),
    [sym_interpolation_raw_start] = ACTIONS(3291),
    [sym_raw_string_start] = ACTIONS(3291),
  },
  [2666] = {
    [sym_preproc_region] = STATE(2666),
    [sym_preproc_endregion] = STATE(2666),
    [sym_preproc_line] = STATE(2666),
    [sym_preproc_pragma] = STATE(2666),
    [sym_preproc_nullable] = STATE(2666),
    [sym_preproc_error] = STATE(2666),
    [sym_preproc_warning] = STATE(2666),
    [sym_preproc_define] = STATE(2666),
    [sym_preproc_undef] = STATE(2666),
    [sym__identifier_token] = ACTIONS(3109),
    [anon_sym_extern] = ACTIONS(3109),
    [anon_sym_alias] = ACTIONS(3109),
    [anon_sym_SEMI] = ACTIONS(3111),
    [anon_sym_global] = ACTIONS(3109),
    [anon_sym_using] = ACTIONS(3109),
    [anon_sym_unsafe] = ACTIONS(3109),
    [anon_sym_static] = ACTIONS(3109),
    [anon_sym_LBRACK] = ACTIONS(3111),
    [anon_sym_LPAREN] = ACTIONS(3111),
    [anon_sym_return] = ACTIONS(3109),
    [anon_sym_ref] = ACTIONS(3109),
    [anon_sym_LBRACE] = ACTIONS(3111),
    [anon_sym_RBRACE] = ACTIONS(3111),
    [anon_sym_delegate] = ACTIONS(3109),
    [anon_sym_abstract] = ACTIONS(3109),
    [anon_sym_async] = ACTIONS(3109),
    [anon_sym_const] = ACTIONS(3109),
    [anon_sym_file] = ACTIONS(3109),
    [anon_sym_fixed] = ACTIONS(3109),
    [anon_sym_internal] = ACTIONS(3109),
    [anon_sym_new] = ACTIONS(3109),
    [anon_sym_override] = ACTIONS(3109),
    [anon_sym_partial] = ACTIONS(3109),
    [anon_sym_private] = ACTIONS(3109),
    [anon_sym_protected] = ACTIONS(3109),
    [anon_sym_public] = ACTIONS(3109),
    [anon_sym_readonly] = ACTIONS(3109),
    [anon_sym_required] = ACTIONS(3109),
    [anon_sym_sealed] = ACTIONS(3109),
    [anon_sym_virtual] = ACTIONS(3109),
    [anon_sym_volatile] = ACTIONS(3109),
    [anon_sym_where] = ACTIONS(3109),
    [anon_sym_notnull] = ACTIONS(3109),
    [anon_sym_unmanaged] = ACTIONS(3109),
    [anon_sym_checked] = ACTIONS(3109),
    [anon_sym_BANG] = ACTIONS(3111),
    [anon_sym_TILDE] = ACTIONS(3111),
    [anon_sym_PLUS_PLUS] = ACTIONS(3111),
    [anon_sym_DASH_DASH] = ACTIONS(3111),
    [anon_sym_true] = ACTIONS(3109),
    [anon_sym_false] = ACTIONS(3109),
    [anon_sym_PLUS] = ACTIONS(3109),
    [anon_sym_DASH] = ACTIONS(3109),
    [anon_sym_STAR] = ACTIONS(3111),
    [anon_sym_CARET] = ACTIONS(3111),
    [anon_sym_AMP] = ACTIONS(3111),
    [anon_sym_this] = ACTIONS(3109),
    [anon_sym_scoped] = ACTIONS(3109),
    [anon_sym_base] = ACTIONS(3109),
    [anon_sym_var] = ACTIONS(3109),
    [sym_predefined_type] = ACTIONS(3109),
    [anon_sym_break] = ACTIONS(3109),
    [anon_sym_unchecked] = ACTIONS(3109),
    [anon_sym_continue] = ACTIONS(3109),
    [anon_sym_do] = ACTIONS(3109),
    [anon_sym_while] = ACTIONS(3109),
    [anon_sym_for] = ACTIONS(3109),
    [anon_sym_lock] = ACTIONS(3109),
    [anon_sym_yield] = ACTIONS(3109),
    [anon_sym_switch] = ACTIONS(3109),
    [anon_sym_case] = ACTIONS(3109),
    [anon_sym_default] = ACTIONS(3109),
    [anon_sym_throw] = ACTIONS(3109),
    [anon_sym_try] = ACTIONS(3109),
    [anon_sym_when] = ACTIONS(3109),
    [anon_sym_await] = ACTIONS(3109),
    [anon_sym_foreach] = ACTIONS(3109),
    [anon_sym_goto] = ACTIONS(3109),
    [anon_sym_if] = ACTIONS(3109),
    [anon_sym_else] = ACTIONS(3109),
    [anon_sym_DOT_DOT] = ACTIONS(3111),
    [anon_sym_from] = ACTIONS(3109),
    [anon_sym_into] = ACTIONS(3109),
    [anon_sym_join] = ACTIONS(3109),
    [anon_sym_on] = ACTIONS(3109),
    [anon_sym_equals] = ACTIONS(3109),
    [anon_sym_let] = ACTIONS(3109),
    [anon_sym_orderby] = ACTIONS(3109),
    [anon_sym_ascending] = ACTIONS(3109),
    [anon_sym_descending] = ACTIONS(3109),
    [anon_sym_group] = ACTIONS(3109),
    [anon_sym_by] = ACTIONS(3109),
    [anon_sym_select] = ACTIONS(3109),
    [anon_sym_stackalloc] = ACTIONS(3109),
    [anon_sym_sizeof] = ACTIONS(3109),
    [anon_sym_typeof] = ACTIONS(3109),
    [anon_sym___makeref] = ACTIONS(3109),
    [anon_sym___reftype] = ACTIONS(3109),
    [anon_sym___refvalue] = ACTIONS(3109),
    [sym_null_literal] = ACTIONS(3109),
    [anon_sym_SQUOTE] = ACTIONS(3111),
    [sym_integer_literal] = ACTIONS(3109),
    [sym_real_literal] = ACTIONS(3111),
    [anon_sym_DQUOTE] = ACTIONS(3111),
    [sym_verbatim_string_literal] = ACTIONS(3111),
    [aux_sym_preproc_if_token1] = ACTIONS(3111),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3111),
    [sym_interpolation_verbatim_start] = ACTIONS(3111),
    [sym_interpolation_raw_start] = ACTIONS(3111),
    [sym_raw_string_start] = ACTIONS(3111),
  },
  [2667] = {
    [sym_preproc_region] = STATE(2667),
    [sym_preproc_endregion] = STATE(2667),
    [sym_preproc_line] = STATE(2667),
    [sym_preproc_pragma] = STATE(2667),
    [sym_preproc_nullable] = STATE(2667),
    [sym_preproc_error] = STATE(2667),
    [sym_preproc_warning] = STATE(2667),
    [sym_preproc_define] = STATE(2667),
    [sym_preproc_undef] = STATE(2667),
    [sym__identifier_token] = ACTIONS(3293),
    [anon_sym_extern] = ACTIONS(3293),
    [anon_sym_alias] = ACTIONS(3293),
    [anon_sym_SEMI] = ACTIONS(3295),
    [anon_sym_global] = ACTIONS(3293),
    [anon_sym_using] = ACTIONS(3293),
    [anon_sym_unsafe] = ACTIONS(3293),
    [anon_sym_static] = ACTIONS(3293),
    [anon_sym_LBRACK] = ACTIONS(3295),
    [anon_sym_LPAREN] = ACTIONS(3295),
    [anon_sym_return] = ACTIONS(3293),
    [anon_sym_ref] = ACTIONS(3293),
    [anon_sym_LBRACE] = ACTIONS(3295),
    [anon_sym_RBRACE] = ACTIONS(3295),
    [anon_sym_delegate] = ACTIONS(3293),
    [anon_sym_abstract] = ACTIONS(3293),
    [anon_sym_async] = ACTIONS(3293),
    [anon_sym_const] = ACTIONS(3293),
    [anon_sym_file] = ACTIONS(3293),
    [anon_sym_fixed] = ACTIONS(3293),
    [anon_sym_internal] = ACTIONS(3293),
    [anon_sym_new] = ACTIONS(3293),
    [anon_sym_override] = ACTIONS(3293),
    [anon_sym_partial] = ACTIONS(3293),
    [anon_sym_private] = ACTIONS(3293),
    [anon_sym_protected] = ACTIONS(3293),
    [anon_sym_public] = ACTIONS(3293),
    [anon_sym_readonly] = ACTIONS(3293),
    [anon_sym_required] = ACTIONS(3293),
    [anon_sym_sealed] = ACTIONS(3293),
    [anon_sym_virtual] = ACTIONS(3293),
    [anon_sym_volatile] = ACTIONS(3293),
    [anon_sym_where] = ACTIONS(3293),
    [anon_sym_notnull] = ACTIONS(3293),
    [anon_sym_unmanaged] = ACTIONS(3293),
    [anon_sym_checked] = ACTIONS(3293),
    [anon_sym_BANG] = ACTIONS(3295),
    [anon_sym_TILDE] = ACTIONS(3295),
    [anon_sym_PLUS_PLUS] = ACTIONS(3295),
    [anon_sym_DASH_DASH] = ACTIONS(3295),
    [anon_sym_true] = ACTIONS(3293),
    [anon_sym_false] = ACTIONS(3293),
    [anon_sym_PLUS] = ACTIONS(3293),
    [anon_sym_DASH] = ACTIONS(3293),
    [anon_sym_STAR] = ACTIONS(3295),
    [anon_sym_CARET] = ACTIONS(3295),
    [anon_sym_AMP] = ACTIONS(3295),
    [anon_sym_this] = ACTIONS(3293),
    [anon_sym_scoped] = ACTIONS(3293),
    [anon_sym_base] = ACTIONS(3293),
    [anon_sym_var] = ACTIONS(3293),
    [sym_predefined_type] = ACTIONS(3293),
    [anon_sym_break] = ACTIONS(3293),
    [anon_sym_unchecked] = ACTIONS(3293),
    [anon_sym_continue] = ACTIONS(3293),
    [anon_sym_do] = ACTIONS(3293),
    [anon_sym_while] = ACTIONS(3293),
    [anon_sym_for] = ACTIONS(3293),
    [anon_sym_lock] = ACTIONS(3293),
    [anon_sym_yield] = ACTIONS(3293),
    [anon_sym_switch] = ACTIONS(3293),
    [anon_sym_case] = ACTIONS(3293),
    [anon_sym_default] = ACTIONS(3293),
    [anon_sym_throw] = ACTIONS(3293),
    [anon_sym_try] = ACTIONS(3293),
    [anon_sym_when] = ACTIONS(3293),
    [anon_sym_await] = ACTIONS(3293),
    [anon_sym_foreach] = ACTIONS(3293),
    [anon_sym_goto] = ACTIONS(3293),
    [anon_sym_if] = ACTIONS(3293),
    [anon_sym_else] = ACTIONS(3293),
    [anon_sym_DOT_DOT] = ACTIONS(3295),
    [anon_sym_from] = ACTIONS(3293),
    [anon_sym_into] = ACTIONS(3293),
    [anon_sym_join] = ACTIONS(3293),
    [anon_sym_on] = ACTIONS(3293),
    [anon_sym_equals] = ACTIONS(3293),
    [anon_sym_let] = ACTIONS(3293),
    [anon_sym_orderby] = ACTIONS(3293),
    [anon_sym_ascending] = ACTIONS(3293),
    [anon_sym_descending] = ACTIONS(3293),
    [anon_sym_group] = ACTIONS(3293),
    [anon_sym_by] = ACTIONS(3293),
    [anon_sym_select] = ACTIONS(3293),
    [anon_sym_stackalloc] = ACTIONS(3293),
    [anon_sym_sizeof] = ACTIONS(3293),
    [anon_sym_typeof] = ACTIONS(3293),
    [anon_sym___makeref] = ACTIONS(3293),
    [anon_sym___reftype] = ACTIONS(3293),
    [anon_sym___refvalue] = ACTIONS(3293),
    [sym_null_literal] = ACTIONS(3293),
    [anon_sym_SQUOTE] = ACTIONS(3295),
    [sym_integer_literal] = ACTIONS(3293),
    [sym_real_literal] = ACTIONS(3295),
    [anon_sym_DQUOTE] = ACTIONS(3295),
    [sym_verbatim_string_literal] = ACTIONS(3295),
    [aux_sym_preproc_if_token1] = ACTIONS(3295),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3295),
    [sym_interpolation_verbatim_start] = ACTIONS(3295),
    [sym_interpolation_raw_start] = ACTIONS(3295),
    [sym_raw_string_start] = ACTIONS(3295),
  },
  [2668] = {
    [sym_preproc_region] = STATE(2668),
    [sym_preproc_endregion] = STATE(2668),
    [sym_preproc_line] = STATE(2668),
    [sym_preproc_pragma] = STATE(2668),
    [sym_preproc_nullable] = STATE(2668),
    [sym_preproc_error] = STATE(2668),
    [sym_preproc_warning] = STATE(2668),
    [sym_preproc_define] = STATE(2668),
    [sym_preproc_undef] = STATE(2668),
    [sym__identifier_token] = ACTIONS(3061),
    [anon_sym_extern] = ACTIONS(3061),
    [anon_sym_alias] = ACTIONS(3061),
    [anon_sym_SEMI] = ACTIONS(3063),
    [anon_sym_global] = ACTIONS(3061),
    [anon_sym_using] = ACTIONS(3061),
    [anon_sym_unsafe] = ACTIONS(3061),
    [anon_sym_static] = ACTIONS(3061),
    [anon_sym_LBRACK] = ACTIONS(3063),
    [anon_sym_LPAREN] = ACTIONS(3063),
    [anon_sym_return] = ACTIONS(3061),
    [anon_sym_ref] = ACTIONS(3061),
    [anon_sym_LBRACE] = ACTIONS(3063),
    [anon_sym_RBRACE] = ACTIONS(3063),
    [anon_sym_delegate] = ACTIONS(3061),
    [anon_sym_abstract] = ACTIONS(3061),
    [anon_sym_async] = ACTIONS(3061),
    [anon_sym_const] = ACTIONS(3061),
    [anon_sym_file] = ACTIONS(3061),
    [anon_sym_fixed] = ACTIONS(3061),
    [anon_sym_internal] = ACTIONS(3061),
    [anon_sym_new] = ACTIONS(3061),
    [anon_sym_override] = ACTIONS(3061),
    [anon_sym_partial] = ACTIONS(3061),
    [anon_sym_private] = ACTIONS(3061),
    [anon_sym_protected] = ACTIONS(3061),
    [anon_sym_public] = ACTIONS(3061),
    [anon_sym_readonly] = ACTIONS(3061),
    [anon_sym_required] = ACTIONS(3061),
    [anon_sym_sealed] = ACTIONS(3061),
    [anon_sym_virtual] = ACTIONS(3061),
    [anon_sym_volatile] = ACTIONS(3061),
    [anon_sym_where] = ACTIONS(3061),
    [anon_sym_notnull] = ACTIONS(3061),
    [anon_sym_unmanaged] = ACTIONS(3061),
    [anon_sym_checked] = ACTIONS(3061),
    [anon_sym_BANG] = ACTIONS(3063),
    [anon_sym_TILDE] = ACTIONS(3063),
    [anon_sym_PLUS_PLUS] = ACTIONS(3063),
    [anon_sym_DASH_DASH] = ACTIONS(3063),
    [anon_sym_true] = ACTIONS(3061),
    [anon_sym_false] = ACTIONS(3061),
    [anon_sym_PLUS] = ACTIONS(3061),
    [anon_sym_DASH] = ACTIONS(3061),
    [anon_sym_STAR] = ACTIONS(3063),
    [anon_sym_CARET] = ACTIONS(3063),
    [anon_sym_AMP] = ACTIONS(3063),
    [anon_sym_this] = ACTIONS(3061),
    [anon_sym_scoped] = ACTIONS(3061),
    [anon_sym_base] = ACTIONS(3061),
    [anon_sym_var] = ACTIONS(3061),
    [sym_predefined_type] = ACTIONS(3061),
    [anon_sym_break] = ACTIONS(3061),
    [anon_sym_unchecked] = ACTIONS(3061),
    [anon_sym_continue] = ACTIONS(3061),
    [anon_sym_do] = ACTIONS(3061),
    [anon_sym_while] = ACTIONS(3061),
    [anon_sym_for] = ACTIONS(3061),
    [anon_sym_lock] = ACTIONS(3061),
    [anon_sym_yield] = ACTIONS(3061),
    [anon_sym_switch] = ACTIONS(3061),
    [anon_sym_case] = ACTIONS(3061),
    [anon_sym_default] = ACTIONS(3061),
    [anon_sym_throw] = ACTIONS(3061),
    [anon_sym_try] = ACTIONS(3061),
    [anon_sym_when] = ACTIONS(3061),
    [anon_sym_await] = ACTIONS(3061),
    [anon_sym_foreach] = ACTIONS(3061),
    [anon_sym_goto] = ACTIONS(3061),
    [anon_sym_if] = ACTIONS(3061),
    [anon_sym_else] = ACTIONS(3061),
    [anon_sym_DOT_DOT] = ACTIONS(3063),
    [anon_sym_from] = ACTIONS(3061),
    [anon_sym_into] = ACTIONS(3061),
    [anon_sym_join] = ACTIONS(3061),
    [anon_sym_on] = ACTIONS(3061),
    [anon_sym_equals] = ACTIONS(3061),
    [anon_sym_let] = ACTIONS(3061),
    [anon_sym_orderby] = ACTIONS(3061),
    [anon_sym_ascending] = ACTIONS(3061),
    [anon_sym_descending] = ACTIONS(3061),
    [anon_sym_group] = ACTIONS(3061),
    [anon_sym_by] = ACTIONS(3061),
    [anon_sym_select] = ACTIONS(3061),
    [anon_sym_stackalloc] = ACTIONS(3061),
    [anon_sym_sizeof] = ACTIONS(3061),
    [anon_sym_typeof] = ACTIONS(3061),
    [anon_sym___makeref] = ACTIONS(3061),
    [anon_sym___reftype] = ACTIONS(3061),
    [anon_sym___refvalue] = ACTIONS(3061),
    [sym_null_literal] = ACTIONS(3061),
    [anon_sym_SQUOTE] = ACTIONS(3063),
    [sym_integer_literal] = ACTIONS(3061),
    [sym_real_literal] = ACTIONS(3063),
    [anon_sym_DQUOTE] = ACTIONS(3063),
    [sym_verbatim_string_literal] = ACTIONS(3063),
    [aux_sym_preproc_if_token1] = ACTIONS(3063),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3063),
    [sym_interpolation_verbatim_start] = ACTIONS(3063),
    [sym_interpolation_raw_start] = ACTIONS(3063),
    [sym_raw_string_start] = ACTIONS(3063),
  },
  [2669] = {
    [sym_preproc_region] = STATE(2669),
    [sym_preproc_endregion] = STATE(2669),
    [sym_preproc_line] = STATE(2669),
    [sym_preproc_pragma] = STATE(2669),
    [sym_preproc_nullable] = STATE(2669),
    [sym_preproc_error] = STATE(2669),
    [sym_preproc_warning] = STATE(2669),
    [sym_preproc_define] = STATE(2669),
    [sym_preproc_undef] = STATE(2669),
    [sym__identifier_token] = ACTIONS(3297),
    [anon_sym_extern] = ACTIONS(3297),
    [anon_sym_alias] = ACTIONS(3297),
    [anon_sym_SEMI] = ACTIONS(3299),
    [anon_sym_global] = ACTIONS(3297),
    [anon_sym_using] = ACTIONS(3297),
    [anon_sym_unsafe] = ACTIONS(3297),
    [anon_sym_static] = ACTIONS(3297),
    [anon_sym_LBRACK] = ACTIONS(3299),
    [anon_sym_LPAREN] = ACTIONS(3299),
    [anon_sym_return] = ACTIONS(3297),
    [anon_sym_ref] = ACTIONS(3297),
    [anon_sym_LBRACE] = ACTIONS(3299),
    [anon_sym_RBRACE] = ACTIONS(3299),
    [anon_sym_delegate] = ACTIONS(3297),
    [anon_sym_abstract] = ACTIONS(3297),
    [anon_sym_async] = ACTIONS(3297),
    [anon_sym_const] = ACTIONS(3297),
    [anon_sym_file] = ACTIONS(3297),
    [anon_sym_fixed] = ACTIONS(3297),
    [anon_sym_internal] = ACTIONS(3297),
    [anon_sym_new] = ACTIONS(3297),
    [anon_sym_override] = ACTIONS(3297),
    [anon_sym_partial] = ACTIONS(3297),
    [anon_sym_private] = ACTIONS(3297),
    [anon_sym_protected] = ACTIONS(3297),
    [anon_sym_public] = ACTIONS(3297),
    [anon_sym_readonly] = ACTIONS(3297),
    [anon_sym_required] = ACTIONS(3297),
    [anon_sym_sealed] = ACTIONS(3297),
    [anon_sym_virtual] = ACTIONS(3297),
    [anon_sym_volatile] = ACTIONS(3297),
    [anon_sym_where] = ACTIONS(3297),
    [anon_sym_notnull] = ACTIONS(3297),
    [anon_sym_unmanaged] = ACTIONS(3297),
    [anon_sym_checked] = ACTIONS(3297),
    [anon_sym_BANG] = ACTIONS(3299),
    [anon_sym_TILDE] = ACTIONS(3299),
    [anon_sym_PLUS_PLUS] = ACTIONS(3299),
    [anon_sym_DASH_DASH] = ACTIONS(3299),
    [anon_sym_true] = ACTIONS(3297),
    [anon_sym_false] = ACTIONS(3297),
    [anon_sym_PLUS] = ACTIONS(3297),
    [anon_sym_DASH] = ACTIONS(3297),
    [anon_sym_STAR] = ACTIONS(3299),
    [anon_sym_CARET] = ACTIONS(3299),
    [anon_sym_AMP] = ACTIONS(3299),
    [anon_sym_this] = ACTIONS(3297),
    [anon_sym_scoped] = ACTIONS(3297),
    [anon_sym_base] = ACTIONS(3297),
    [anon_sym_var] = ACTIONS(3297),
    [sym_predefined_type] = ACTIONS(3297),
    [anon_sym_break] = ACTIONS(3297),
    [anon_sym_unchecked] = ACTIONS(3297),
    [anon_sym_continue] = ACTIONS(3297),
    [anon_sym_do] = ACTIONS(3297),
    [anon_sym_while] = ACTIONS(3297),
    [anon_sym_for] = ACTIONS(3297),
    [anon_sym_lock] = ACTIONS(3297),
    [anon_sym_yield] = ACTIONS(3297),
    [anon_sym_switch] = ACTIONS(3297),
    [anon_sym_case] = ACTIONS(3297),
    [anon_sym_default] = ACTIONS(3297),
    [anon_sym_throw] = ACTIONS(3297),
    [anon_sym_try] = ACTIONS(3297),
    [anon_sym_when] = ACTIONS(3297),
    [anon_sym_await] = ACTIONS(3297),
    [anon_sym_foreach] = ACTIONS(3297),
    [anon_sym_goto] = ACTIONS(3297),
    [anon_sym_if] = ACTIONS(3297),
    [anon_sym_else] = ACTIONS(3297),
    [anon_sym_DOT_DOT] = ACTIONS(3299),
    [anon_sym_from] = ACTIONS(3297),
    [anon_sym_into] = ACTIONS(3297),
    [anon_sym_join] = ACTIONS(3297),
    [anon_sym_on] = ACTIONS(3297),
    [anon_sym_equals] = ACTIONS(3297),
    [anon_sym_let] = ACTIONS(3297),
    [anon_sym_orderby] = ACTIONS(3297),
    [anon_sym_ascending] = ACTIONS(3297),
    [anon_sym_descending] = ACTIONS(3297),
    [anon_sym_group] = ACTIONS(3297),
    [anon_sym_by] = ACTIONS(3297),
    [anon_sym_select] = ACTIONS(3297),
    [anon_sym_stackalloc] = ACTIONS(3297),
    [anon_sym_sizeof] = ACTIONS(3297),
    [anon_sym_typeof] = ACTIONS(3297),
    [anon_sym___makeref] = ACTIONS(3297),
    [anon_sym___reftype] = ACTIONS(3297),
    [anon_sym___refvalue] = ACTIONS(3297),
    [sym_null_literal] = ACTIONS(3297),
    [anon_sym_SQUOTE] = ACTIONS(3299),
    [sym_integer_literal] = ACTIONS(3297),
    [sym_real_literal] = ACTIONS(3299),
    [anon_sym_DQUOTE] = ACTIONS(3299),
    [sym_verbatim_string_literal] = ACTIONS(3299),
    [aux_sym_preproc_if_token1] = ACTIONS(3299),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3299),
    [sym_interpolation_verbatim_start] = ACTIONS(3299),
    [sym_interpolation_raw_start] = ACTIONS(3299),
    [sym_raw_string_start] = ACTIONS(3299),
  },
  [2670] = {
    [sym_preproc_region] = STATE(2670),
    [sym_preproc_endregion] = STATE(2670),
    [sym_preproc_line] = STATE(2670),
    [sym_preproc_pragma] = STATE(2670),
    [sym_preproc_nullable] = STATE(2670),
    [sym_preproc_error] = STATE(2670),
    [sym_preproc_warning] = STATE(2670),
    [sym_preproc_define] = STATE(2670),
    [sym_preproc_undef] = STATE(2670),
    [sym__identifier_token] = ACTIONS(3301),
    [anon_sym_extern] = ACTIONS(3301),
    [anon_sym_alias] = ACTIONS(3301),
    [anon_sym_SEMI] = ACTIONS(3303),
    [anon_sym_global] = ACTIONS(3301),
    [anon_sym_using] = ACTIONS(3301),
    [anon_sym_unsafe] = ACTIONS(3301),
    [anon_sym_static] = ACTIONS(3301),
    [anon_sym_LBRACK] = ACTIONS(3303),
    [anon_sym_LPAREN] = ACTIONS(3303),
    [anon_sym_return] = ACTIONS(3301),
    [anon_sym_ref] = ACTIONS(3301),
    [anon_sym_LBRACE] = ACTIONS(3303),
    [anon_sym_RBRACE] = ACTIONS(3303),
    [anon_sym_delegate] = ACTIONS(3301),
    [anon_sym_abstract] = ACTIONS(3301),
    [anon_sym_async] = ACTIONS(3301),
    [anon_sym_const] = ACTIONS(3301),
    [anon_sym_file] = ACTIONS(3301),
    [anon_sym_fixed] = ACTIONS(3301),
    [anon_sym_internal] = ACTIONS(3301),
    [anon_sym_new] = ACTIONS(3301),
    [anon_sym_override] = ACTIONS(3301),
    [anon_sym_partial] = ACTIONS(3301),
    [anon_sym_private] = ACTIONS(3301),
    [anon_sym_protected] = ACTIONS(3301),
    [anon_sym_public] = ACTIONS(3301),
    [anon_sym_readonly] = ACTIONS(3301),
    [anon_sym_required] = ACTIONS(3301),
    [anon_sym_sealed] = ACTIONS(3301),
    [anon_sym_virtual] = ACTIONS(3301),
    [anon_sym_volatile] = ACTIONS(3301),
    [anon_sym_where] = ACTIONS(3301),
    [anon_sym_notnull] = ACTIONS(3301),
    [anon_sym_unmanaged] = ACTIONS(3301),
    [anon_sym_checked] = ACTIONS(3301),
    [anon_sym_BANG] = ACTIONS(3303),
    [anon_sym_TILDE] = ACTIONS(3303),
    [anon_sym_PLUS_PLUS] = ACTIONS(3303),
    [anon_sym_DASH_DASH] = ACTIONS(3303),
    [anon_sym_true] = ACTIONS(3301),
    [anon_sym_false] = ACTIONS(3301),
    [anon_sym_PLUS] = ACTIONS(3301),
    [anon_sym_DASH] = ACTIONS(3301),
    [anon_sym_STAR] = ACTIONS(3303),
    [anon_sym_CARET] = ACTIONS(3303),
    [anon_sym_AMP] = ACTIONS(3303),
    [anon_sym_this] = ACTIONS(3301),
    [anon_sym_scoped] = ACTIONS(3301),
    [anon_sym_base] = ACTIONS(3301),
    [anon_sym_var] = ACTIONS(3301),
    [sym_predefined_type] = ACTIONS(3301),
    [anon_sym_break] = ACTIONS(3301),
    [anon_sym_unchecked] = ACTIONS(3301),
    [anon_sym_continue] = ACTIONS(3301),
    [anon_sym_do] = ACTIONS(3301),
    [anon_sym_while] = ACTIONS(3301),
    [anon_sym_for] = ACTIONS(3301),
    [anon_sym_lock] = ACTIONS(3301),
    [anon_sym_yield] = ACTIONS(3301),
    [anon_sym_switch] = ACTIONS(3301),
    [anon_sym_case] = ACTIONS(3301),
    [anon_sym_default] = ACTIONS(3301),
    [anon_sym_throw] = ACTIONS(3301),
    [anon_sym_try] = ACTIONS(3301),
    [anon_sym_when] = ACTIONS(3301),
    [anon_sym_await] = ACTIONS(3301),
    [anon_sym_foreach] = ACTIONS(3301),
    [anon_sym_goto] = ACTIONS(3301),
    [anon_sym_if] = ACTIONS(3301),
    [anon_sym_else] = ACTIONS(3301),
    [anon_sym_DOT_DOT] = ACTIONS(3303),
    [anon_sym_from] = ACTIONS(3301),
    [anon_sym_into] = ACTIONS(3301),
    [anon_sym_join] = ACTIONS(3301),
    [anon_sym_on] = ACTIONS(3301),
    [anon_sym_equals] = ACTIONS(3301),
    [anon_sym_let] = ACTIONS(3301),
    [anon_sym_orderby] = ACTIONS(3301),
    [anon_sym_ascending] = ACTIONS(3301),
    [anon_sym_descending] = ACTIONS(3301),
    [anon_sym_group] = ACTIONS(3301),
    [anon_sym_by] = ACTIONS(3301),
    [anon_sym_select] = ACTIONS(3301),
    [anon_sym_stackalloc] = ACTIONS(3301),
    [anon_sym_sizeof] = ACTIONS(3301),
    [anon_sym_typeof] = ACTIONS(3301),
    [anon_sym___makeref] = ACTIONS(3301),
    [anon_sym___reftype] = ACTIONS(3301),
    [anon_sym___refvalue] = ACTIONS(3301),
    [sym_null_literal] = ACTIONS(3301),
    [anon_sym_SQUOTE] = ACTIONS(3303),
    [sym_integer_literal] = ACTIONS(3301),
    [sym_real_literal] = ACTIONS(3303),
    [anon_sym_DQUOTE] = ACTIONS(3303),
    [sym_verbatim_string_literal] = ACTIONS(3303),
    [aux_sym_preproc_if_token1] = ACTIONS(3303),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3303),
    [sym_interpolation_verbatim_start] = ACTIONS(3303),
    [sym_interpolation_raw_start] = ACTIONS(3303),
    [sym_raw_string_start] = ACTIONS(3303),
  },
  [2671] = {
    [sym_preproc_region] = STATE(2671),
    [sym_preproc_endregion] = STATE(2671),
    [sym_preproc_line] = STATE(2671),
    [sym_preproc_pragma] = STATE(2671),
    [sym_preproc_nullable] = STATE(2671),
    [sym_preproc_error] = STATE(2671),
    [sym_preproc_warning] = STATE(2671),
    [sym_preproc_define] = STATE(2671),
    [sym_preproc_undef] = STATE(2671),
    [sym__identifier_token] = ACTIONS(3309),
    [anon_sym_extern] = ACTIONS(3309),
    [anon_sym_alias] = ACTIONS(3309),
    [anon_sym_SEMI] = ACTIONS(3311),
    [anon_sym_global] = ACTIONS(3309),
    [anon_sym_using] = ACTIONS(3309),
    [anon_sym_unsafe] = ACTIONS(3309),
    [anon_sym_static] = ACTIONS(3309),
    [anon_sym_LBRACK] = ACTIONS(3311),
    [anon_sym_LPAREN] = ACTIONS(3311),
    [anon_sym_return] = ACTIONS(3309),
    [anon_sym_ref] = ACTIONS(3309),
    [anon_sym_LBRACE] = ACTIONS(3311),
    [anon_sym_RBRACE] = ACTIONS(3311),
    [anon_sym_delegate] = ACTIONS(3309),
    [anon_sym_abstract] = ACTIONS(3309),
    [anon_sym_async] = ACTIONS(3309),
    [anon_sym_const] = ACTIONS(3309),
    [anon_sym_file] = ACTIONS(3309),
    [anon_sym_fixed] = ACTIONS(3309),
    [anon_sym_internal] = ACTIONS(3309),
    [anon_sym_new] = ACTIONS(3309),
    [anon_sym_override] = ACTIONS(3309),
    [anon_sym_partial] = ACTIONS(3309),
    [anon_sym_private] = ACTIONS(3309),
    [anon_sym_protected] = ACTIONS(3309),
    [anon_sym_public] = ACTIONS(3309),
    [anon_sym_readonly] = ACTIONS(3309),
    [anon_sym_required] = ACTIONS(3309),
    [anon_sym_sealed] = ACTIONS(3309),
    [anon_sym_virtual] = ACTIONS(3309),
    [anon_sym_volatile] = ACTIONS(3309),
    [anon_sym_where] = ACTIONS(3309),
    [anon_sym_notnull] = ACTIONS(3309),
    [anon_sym_unmanaged] = ACTIONS(3309),
    [anon_sym_checked] = ACTIONS(3309),
    [anon_sym_BANG] = ACTIONS(3311),
    [anon_sym_TILDE] = ACTIONS(3311),
    [anon_sym_PLUS_PLUS] = ACTIONS(3311),
    [anon_sym_DASH_DASH] = ACTIONS(3311),
    [anon_sym_true] = ACTIONS(3309),
    [anon_sym_false] = ACTIONS(3309),
    [anon_sym_PLUS] = ACTIONS(3309),
    [anon_sym_DASH] = ACTIONS(3309),
    [anon_sym_STAR] = ACTIONS(3311),
    [anon_sym_CARET] = ACTIONS(3311),
    [anon_sym_AMP] = ACTIONS(3311),
    [anon_sym_this] = ACTIONS(3309),
    [anon_sym_scoped] = ACTIONS(3309),
    [anon_sym_base] = ACTIONS(3309),
    [anon_sym_var] = ACTIONS(3309),
    [sym_predefined_type] = ACTIONS(3309),
    [anon_sym_break] = ACTIONS(3309),
    [anon_sym_unchecked] = ACTIONS(3309),
    [anon_sym_continue] = ACTIONS(3309),
    [anon_sym_do] = ACTIONS(3309),
    [anon_sym_while] = ACTIONS(3309),
    [anon_sym_for] = ACTIONS(3309),
    [anon_sym_lock] = ACTIONS(3309),
    [anon_sym_yield] = ACTIONS(3309),
    [anon_sym_switch] = ACTIONS(3309),
    [anon_sym_case] = ACTIONS(3309),
    [anon_sym_default] = ACTIONS(3309),
    [anon_sym_throw] = ACTIONS(3309),
    [anon_sym_try] = ACTIONS(3309),
    [anon_sym_when] = ACTIONS(3309),
    [anon_sym_await] = ACTIONS(3309),
    [anon_sym_foreach] = ACTIONS(3309),
    [anon_sym_goto] = ACTIONS(3309),
    [anon_sym_if] = ACTIONS(3309),
    [anon_sym_else] = ACTIONS(3309),
    [anon_sym_DOT_DOT] = ACTIONS(3311),
    [anon_sym_from] = ACTIONS(3309),
    [anon_sym_into] = ACTIONS(3309),
    [anon_sym_join] = ACTIONS(3309),
    [anon_sym_on] = ACTIONS(3309),
    [anon_sym_equals] = ACTIONS(3309),
    [anon_sym_let] = ACTIONS(3309),
    [anon_sym_orderby] = ACTIONS(3309),
    [anon_sym_ascending] = ACTIONS(3309),
    [anon_sym_descending] = ACTIONS(3309),
    [anon_sym_group] = ACTIONS(3309),
    [anon_sym_by] = ACTIONS(3309),
    [anon_sym_select] = ACTIONS(3309),
    [anon_sym_stackalloc] = ACTIONS(3309),
    [anon_sym_sizeof] = ACTIONS(3309),
    [anon_sym_typeof] = ACTIONS(3309),
    [anon_sym___makeref] = ACTIONS(3309),
    [anon_sym___reftype] = ACTIONS(3309),
    [anon_sym___refvalue] = ACTIONS(3309),
    [sym_null_literal] = ACTIONS(3309),
    [anon_sym_SQUOTE] = ACTIONS(3311),
    [sym_integer_literal] = ACTIONS(3309),
    [sym_real_literal] = ACTIONS(3311),
    [anon_sym_DQUOTE] = ACTIONS(3311),
    [sym_verbatim_string_literal] = ACTIONS(3311),
    [aux_sym_preproc_if_token1] = ACTIONS(3311),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3311),
    [sym_interpolation_verbatim_start] = ACTIONS(3311),
    [sym_interpolation_raw_start] = ACTIONS(3311),
    [sym_raw_string_start] = ACTIONS(3311),
  },
  [2672] = {
    [sym_preproc_region] = STATE(2672),
    [sym_preproc_endregion] = STATE(2672),
    [sym_preproc_line] = STATE(2672),
    [sym_preproc_pragma] = STATE(2672),
    [sym_preproc_nullable] = STATE(2672),
    [sym_preproc_error] = STATE(2672),
    [sym_preproc_warning] = STATE(2672),
    [sym_preproc_define] = STATE(2672),
    [sym_preproc_undef] = STATE(2672),
    [sym__identifier_token] = ACTIONS(3313),
    [anon_sym_extern] = ACTIONS(3313),
    [anon_sym_alias] = ACTIONS(3313),
    [anon_sym_SEMI] = ACTIONS(3315),
    [anon_sym_global] = ACTIONS(3313),
    [anon_sym_using] = ACTIONS(3313),
    [anon_sym_unsafe] = ACTIONS(3313),
    [anon_sym_static] = ACTIONS(3313),
    [anon_sym_LBRACK] = ACTIONS(3315),
    [anon_sym_LPAREN] = ACTIONS(3315),
    [anon_sym_return] = ACTIONS(3313),
    [anon_sym_ref] = ACTIONS(3313),
    [anon_sym_LBRACE] = ACTIONS(3315),
    [anon_sym_RBRACE] = ACTIONS(3315),
    [anon_sym_delegate] = ACTIONS(3313),
    [anon_sym_abstract] = ACTIONS(3313),
    [anon_sym_async] = ACTIONS(3313),
    [anon_sym_const] = ACTIONS(3313),
    [anon_sym_file] = ACTIONS(3313),
    [anon_sym_fixed] = ACTIONS(3313),
    [anon_sym_internal] = ACTIONS(3313),
    [anon_sym_new] = ACTIONS(3313),
    [anon_sym_override] = ACTIONS(3313),
    [anon_sym_partial] = ACTIONS(3313),
    [anon_sym_private] = ACTIONS(3313),
    [anon_sym_protected] = ACTIONS(3313),
    [anon_sym_public] = ACTIONS(3313),
    [anon_sym_readonly] = ACTIONS(3313),
    [anon_sym_required] = ACTIONS(3313),
    [anon_sym_sealed] = ACTIONS(3313),
    [anon_sym_virtual] = ACTIONS(3313),
    [anon_sym_volatile] = ACTIONS(3313),
    [anon_sym_where] = ACTIONS(3313),
    [anon_sym_notnull] = ACTIONS(3313),
    [anon_sym_unmanaged] = ACTIONS(3313),
    [anon_sym_checked] = ACTIONS(3313),
    [anon_sym_BANG] = ACTIONS(3315),
    [anon_sym_TILDE] = ACTIONS(3315),
    [anon_sym_PLUS_PLUS] = ACTIONS(3315),
    [anon_sym_DASH_DASH] = ACTIONS(3315),
    [anon_sym_true] = ACTIONS(3313),
    [anon_sym_false] = ACTIONS(3313),
    [anon_sym_PLUS] = ACTIONS(3313),
    [anon_sym_DASH] = ACTIONS(3313),
    [anon_sym_STAR] = ACTIONS(3315),
    [anon_sym_CARET] = ACTIONS(3315),
    [anon_sym_AMP] = ACTIONS(3315),
    [anon_sym_this] = ACTIONS(3313),
    [anon_sym_scoped] = ACTIONS(3313),
    [anon_sym_base] = ACTIONS(3313),
    [anon_sym_var] = ACTIONS(3313),
    [sym_predefined_type] = ACTIONS(3313),
    [anon_sym_break] = ACTIONS(3313),
    [anon_sym_unchecked] = ACTIONS(3313),
    [anon_sym_continue] = ACTIONS(3313),
    [anon_sym_do] = ACTIONS(3313),
    [anon_sym_while] = ACTIONS(3313),
    [anon_sym_for] = ACTIONS(3313),
    [anon_sym_lock] = ACTIONS(3313),
    [anon_sym_yield] = ACTIONS(3313),
    [anon_sym_switch] = ACTIONS(3313),
    [anon_sym_case] = ACTIONS(3313),
    [anon_sym_default] = ACTIONS(3313),
    [anon_sym_throw] = ACTIONS(3313),
    [anon_sym_try] = ACTIONS(3313),
    [anon_sym_when] = ACTIONS(3313),
    [anon_sym_await] = ACTIONS(3313),
    [anon_sym_foreach] = ACTIONS(3313),
    [anon_sym_goto] = ACTIONS(3313),
    [anon_sym_if] = ACTIONS(3313),
    [anon_sym_else] = ACTIONS(3313),
    [anon_sym_DOT_DOT] = ACTIONS(3315),
    [anon_sym_from] = ACTIONS(3313),
    [anon_sym_into] = ACTIONS(3313),
    [anon_sym_join] = ACTIONS(3313),
    [anon_sym_on] = ACTIONS(3313),
    [anon_sym_equals] = ACTIONS(3313),
    [anon_sym_let] = ACTIONS(3313),
    [anon_sym_orderby] = ACTIONS(3313),
    [anon_sym_ascending] = ACTIONS(3313),
    [anon_sym_descending] = ACTIONS(3313),
    [anon_sym_group] = ACTIONS(3313),
    [anon_sym_by] = ACTIONS(3313),
    [anon_sym_select] = ACTIONS(3313),
    [anon_sym_stackalloc] = ACTIONS(3313),
    [anon_sym_sizeof] = ACTIONS(3313),
    [anon_sym_typeof] = ACTIONS(3313),
    [anon_sym___makeref] = ACTIONS(3313),
    [anon_sym___reftype] = ACTIONS(3313),
    [anon_sym___refvalue] = ACTIONS(3313),
    [sym_null_literal] = ACTIONS(3313),
    [anon_sym_SQUOTE] = ACTIONS(3315),
    [sym_integer_literal] = ACTIONS(3313),
    [sym_real_literal] = ACTIONS(3315),
    [anon_sym_DQUOTE] = ACTIONS(3315),
    [sym_verbatim_string_literal] = ACTIONS(3315),
    [aux_sym_preproc_if_token1] = ACTIONS(3315),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3315),
    [sym_interpolation_verbatim_start] = ACTIONS(3315),
    [sym_interpolation_raw_start] = ACTIONS(3315),
    [sym_raw_string_start] = ACTIONS(3315),
  },
  [2673] = {
    [sym_preproc_region] = STATE(2673),
    [sym_preproc_endregion] = STATE(2673),
    [sym_preproc_line] = STATE(2673),
    [sym_preproc_pragma] = STATE(2673),
    [sym_preproc_nullable] = STATE(2673),
    [sym_preproc_error] = STATE(2673),
    [sym_preproc_warning] = STATE(2673),
    [sym_preproc_define] = STATE(2673),
    [sym_preproc_undef] = STATE(2673),
    [sym__identifier_token] = ACTIONS(3177),
    [anon_sym_extern] = ACTIONS(3177),
    [anon_sym_alias] = ACTIONS(3177),
    [anon_sym_SEMI] = ACTIONS(3179),
    [anon_sym_global] = ACTIONS(3177),
    [anon_sym_using] = ACTIONS(3177),
    [anon_sym_unsafe] = ACTIONS(3177),
    [anon_sym_static] = ACTIONS(3177),
    [anon_sym_LBRACK] = ACTIONS(3179),
    [anon_sym_LPAREN] = ACTIONS(3179),
    [anon_sym_return] = ACTIONS(3177),
    [anon_sym_ref] = ACTIONS(3177),
    [anon_sym_LBRACE] = ACTIONS(3179),
    [anon_sym_RBRACE] = ACTIONS(3179),
    [anon_sym_delegate] = ACTIONS(3177),
    [anon_sym_abstract] = ACTIONS(3177),
    [anon_sym_async] = ACTIONS(3177),
    [anon_sym_const] = ACTIONS(3177),
    [anon_sym_file] = ACTIONS(3177),
    [anon_sym_fixed] = ACTIONS(3177),
    [anon_sym_internal] = ACTIONS(3177),
    [anon_sym_new] = ACTIONS(3177),
    [anon_sym_override] = ACTIONS(3177),
    [anon_sym_partial] = ACTIONS(3177),
    [anon_sym_private] = ACTIONS(3177),
    [anon_sym_protected] = ACTIONS(3177),
    [anon_sym_public] = ACTIONS(3177),
    [anon_sym_readonly] = ACTIONS(3177),
    [anon_sym_required] = ACTIONS(3177),
    [anon_sym_sealed] = ACTIONS(3177),
    [anon_sym_virtual] = ACTIONS(3177),
    [anon_sym_volatile] = ACTIONS(3177),
    [anon_sym_where] = ACTIONS(3177),
    [anon_sym_notnull] = ACTIONS(3177),
    [anon_sym_unmanaged] = ACTIONS(3177),
    [anon_sym_checked] = ACTIONS(3177),
    [anon_sym_BANG] = ACTIONS(3179),
    [anon_sym_TILDE] = ACTIONS(3179),
    [anon_sym_PLUS_PLUS] = ACTIONS(3179),
    [anon_sym_DASH_DASH] = ACTIONS(3179),
    [anon_sym_true] = ACTIONS(3177),
    [anon_sym_false] = ACTIONS(3177),
    [anon_sym_PLUS] = ACTIONS(3177),
    [anon_sym_DASH] = ACTIONS(3177),
    [anon_sym_STAR] = ACTIONS(3179),
    [anon_sym_CARET] = ACTIONS(3179),
    [anon_sym_AMP] = ACTIONS(3179),
    [anon_sym_this] = ACTIONS(3177),
    [anon_sym_scoped] = ACTIONS(3177),
    [anon_sym_base] = ACTIONS(3177),
    [anon_sym_var] = ACTIONS(3177),
    [sym_predefined_type] = ACTIONS(3177),
    [anon_sym_break] = ACTIONS(3177),
    [anon_sym_unchecked] = ACTIONS(3177),
    [anon_sym_continue] = ACTIONS(3177),
    [anon_sym_do] = ACTIONS(3177),
    [anon_sym_while] = ACTIONS(3177),
    [anon_sym_for] = ACTIONS(3177),
    [anon_sym_lock] = ACTIONS(3177),
    [anon_sym_yield] = ACTIONS(3177),
    [anon_sym_switch] = ACTIONS(3177),
    [anon_sym_case] = ACTIONS(3177),
    [anon_sym_default] = ACTIONS(3177),
    [anon_sym_throw] = ACTIONS(3177),
    [anon_sym_try] = ACTIONS(3177),
    [anon_sym_when] = ACTIONS(3177),
    [anon_sym_await] = ACTIONS(3177),
    [anon_sym_foreach] = ACTIONS(3177),
    [anon_sym_goto] = ACTIONS(3177),
    [anon_sym_if] = ACTIONS(3177),
    [anon_sym_else] = ACTIONS(3177),
    [anon_sym_DOT_DOT] = ACTIONS(3179),
    [anon_sym_from] = ACTIONS(3177),
    [anon_sym_into] = ACTIONS(3177),
    [anon_sym_join] = ACTIONS(3177),
    [anon_sym_on] = ACTIONS(3177),
    [anon_sym_equals] = ACTIONS(3177),
    [anon_sym_let] = ACTIONS(3177),
    [anon_sym_orderby] = ACTIONS(3177),
    [anon_sym_ascending] = ACTIONS(3177),
    [anon_sym_descending] = ACTIONS(3177),
    [anon_sym_group] = ACTIONS(3177),
    [anon_sym_by] = ACTIONS(3177),
    [anon_sym_select] = ACTIONS(3177),
    [anon_sym_stackalloc] = ACTIONS(3177),
    [anon_sym_sizeof] = ACTIONS(3177),
    [anon_sym_typeof] = ACTIONS(3177),
    [anon_sym___makeref] = ACTIONS(3177),
    [anon_sym___reftype] = ACTIONS(3177),
    [anon_sym___refvalue] = ACTIONS(3177),
    [sym_null_literal] = ACTIONS(3177),
    [anon_sym_SQUOTE] = ACTIONS(3179),
    [sym_integer_literal] = ACTIONS(3177),
    [sym_real_literal] = ACTIONS(3179),
    [anon_sym_DQUOTE] = ACTIONS(3179),
    [sym_verbatim_string_literal] = ACTIONS(3179),
    [aux_sym_preproc_if_token1] = ACTIONS(3179),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3179),
    [sym_interpolation_verbatim_start] = ACTIONS(3179),
    [sym_interpolation_raw_start] = ACTIONS(3179),
    [sym_raw_string_start] = ACTIONS(3179),
  },
  [2674] = {
    [sym_preproc_region] = STATE(2674),
    [sym_preproc_endregion] = STATE(2674),
    [sym_preproc_line] = STATE(2674),
    [sym_preproc_pragma] = STATE(2674),
    [sym_preproc_nullable] = STATE(2674),
    [sym_preproc_error] = STATE(2674),
    [sym_preproc_warning] = STATE(2674),
    [sym_preproc_define] = STATE(2674),
    [sym_preproc_undef] = STATE(2674),
    [sym__identifier_token] = ACTIONS(3053),
    [anon_sym_extern] = ACTIONS(3053),
    [anon_sym_alias] = ACTIONS(3053),
    [anon_sym_SEMI] = ACTIONS(3055),
    [anon_sym_global] = ACTIONS(3053),
    [anon_sym_using] = ACTIONS(3053),
    [anon_sym_unsafe] = ACTIONS(3053),
    [anon_sym_static] = ACTIONS(3053),
    [anon_sym_LBRACK] = ACTIONS(3055),
    [anon_sym_LPAREN] = ACTIONS(3055),
    [anon_sym_return] = ACTIONS(3053),
    [anon_sym_ref] = ACTIONS(3053),
    [anon_sym_LBRACE] = ACTIONS(3055),
    [anon_sym_RBRACE] = ACTIONS(3055),
    [anon_sym_delegate] = ACTIONS(3053),
    [anon_sym_abstract] = ACTIONS(3053),
    [anon_sym_async] = ACTIONS(3053),
    [anon_sym_const] = ACTIONS(3053),
    [anon_sym_file] = ACTIONS(3053),
    [anon_sym_fixed] = ACTIONS(3053),
    [anon_sym_internal] = ACTIONS(3053),
    [anon_sym_new] = ACTIONS(3053),
    [anon_sym_override] = ACTIONS(3053),
    [anon_sym_partial] = ACTIONS(3053),
    [anon_sym_private] = ACTIONS(3053),
    [anon_sym_protected] = ACTIONS(3053),
    [anon_sym_public] = ACTIONS(3053),
    [anon_sym_readonly] = ACTIONS(3053),
    [anon_sym_required] = ACTIONS(3053),
    [anon_sym_sealed] = ACTIONS(3053),
    [anon_sym_virtual] = ACTIONS(3053),
    [anon_sym_volatile] = ACTIONS(3053),
    [anon_sym_where] = ACTIONS(3053),
    [anon_sym_notnull] = ACTIONS(3053),
    [anon_sym_unmanaged] = ACTIONS(3053),
    [anon_sym_checked] = ACTIONS(3053),
    [anon_sym_BANG] = ACTIONS(3055),
    [anon_sym_TILDE] = ACTIONS(3055),
    [anon_sym_PLUS_PLUS] = ACTIONS(3055),
    [anon_sym_DASH_DASH] = ACTIONS(3055),
    [anon_sym_true] = ACTIONS(3053),
    [anon_sym_false] = ACTIONS(3053),
    [anon_sym_PLUS] = ACTIONS(3053),
    [anon_sym_DASH] = ACTIONS(3053),
    [anon_sym_STAR] = ACTIONS(3055),
    [anon_sym_CARET] = ACTIONS(3055),
    [anon_sym_AMP] = ACTIONS(3055),
    [anon_sym_this] = ACTIONS(3053),
    [anon_sym_scoped] = ACTIONS(3053),
    [anon_sym_base] = ACTIONS(3053),
    [anon_sym_var] = ACTIONS(3053),
    [sym_predefined_type] = ACTIONS(3053),
    [anon_sym_break] = ACTIONS(3053),
    [anon_sym_unchecked] = ACTIONS(3053),
    [anon_sym_continue] = ACTIONS(3053),
    [anon_sym_do] = ACTIONS(3053),
    [anon_sym_while] = ACTIONS(3053),
    [anon_sym_for] = ACTIONS(3053),
    [anon_sym_lock] = ACTIONS(3053),
    [anon_sym_yield] = ACTIONS(3053),
    [anon_sym_switch] = ACTIONS(3053),
    [anon_sym_case] = ACTIONS(3053),
    [anon_sym_default] = ACTIONS(3053),
    [anon_sym_throw] = ACTIONS(3053),
    [anon_sym_try] = ACTIONS(3053),
    [anon_sym_when] = ACTIONS(3053),
    [anon_sym_await] = ACTIONS(3053),
    [anon_sym_foreach] = ACTIONS(3053),
    [anon_sym_goto] = ACTIONS(3053),
    [anon_sym_if] = ACTIONS(3053),
    [anon_sym_else] = ACTIONS(3053),
    [anon_sym_DOT_DOT] = ACTIONS(3055),
    [anon_sym_from] = ACTIONS(3053),
    [anon_sym_into] = ACTIONS(3053),
    [anon_sym_join] = ACTIONS(3053),
    [anon_sym_on] = ACTIONS(3053),
    [anon_sym_equals] = ACTIONS(3053),
    [anon_sym_let] = ACTIONS(3053),
    [anon_sym_orderby] = ACTIONS(3053),
    [anon_sym_ascending] = ACTIONS(3053),
    [anon_sym_descending] = ACTIONS(3053),
    [anon_sym_group] = ACTIONS(3053),
    [anon_sym_by] = ACTIONS(3053),
    [anon_sym_select] = ACTIONS(3053),
    [anon_sym_stackalloc] = ACTIONS(3053),
    [anon_sym_sizeof] = ACTIONS(3053),
    [anon_sym_typeof] = ACTIONS(3053),
    [anon_sym___makeref] = ACTIONS(3053),
    [anon_sym___reftype] = ACTIONS(3053),
    [anon_sym___refvalue] = ACTIONS(3053),
    [sym_null_literal] = ACTIONS(3053),
    [anon_sym_SQUOTE] = ACTIONS(3055),
    [sym_integer_literal] = ACTIONS(3053),
    [sym_real_literal] = ACTIONS(3055),
    [anon_sym_DQUOTE] = ACTIONS(3055),
    [sym_verbatim_string_literal] = ACTIONS(3055),
    [aux_sym_preproc_if_token1] = ACTIONS(3055),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3055),
    [sym_interpolation_verbatim_start] = ACTIONS(3055),
    [sym_interpolation_raw_start] = ACTIONS(3055),
    [sym_raw_string_start] = ACTIONS(3055),
  },
  [2675] = {
    [sym_preproc_region] = STATE(2675),
    [sym_preproc_endregion] = STATE(2675),
    [sym_preproc_line] = STATE(2675),
    [sym_preproc_pragma] = STATE(2675),
    [sym_preproc_nullable] = STATE(2675),
    [sym_preproc_error] = STATE(2675),
    [sym_preproc_warning] = STATE(2675),
    [sym_preproc_define] = STATE(2675),
    [sym_preproc_undef] = STATE(2675),
    [sym__identifier_token] = ACTIONS(3065),
    [anon_sym_extern] = ACTIONS(3065),
    [anon_sym_alias] = ACTIONS(3065),
    [anon_sym_SEMI] = ACTIONS(3067),
    [anon_sym_global] = ACTIONS(3065),
    [anon_sym_using] = ACTIONS(3065),
    [anon_sym_unsafe] = ACTIONS(3065),
    [anon_sym_static] = ACTIONS(3065),
    [anon_sym_LBRACK] = ACTIONS(3067),
    [anon_sym_LPAREN] = ACTIONS(3067),
    [anon_sym_return] = ACTIONS(3065),
    [anon_sym_ref] = ACTIONS(3065),
    [anon_sym_LBRACE] = ACTIONS(3067),
    [anon_sym_RBRACE] = ACTIONS(3067),
    [anon_sym_delegate] = ACTIONS(3065),
    [anon_sym_abstract] = ACTIONS(3065),
    [anon_sym_async] = ACTIONS(3065),
    [anon_sym_const] = ACTIONS(3065),
    [anon_sym_file] = ACTIONS(3065),
    [anon_sym_fixed] = ACTIONS(3065),
    [anon_sym_internal] = ACTIONS(3065),
    [anon_sym_new] = ACTIONS(3065),
    [anon_sym_override] = ACTIONS(3065),
    [anon_sym_partial] = ACTIONS(3065),
    [anon_sym_private] = ACTIONS(3065),
    [anon_sym_protected] = ACTIONS(3065),
    [anon_sym_public] = ACTIONS(3065),
    [anon_sym_readonly] = ACTIONS(3065),
    [anon_sym_required] = ACTIONS(3065),
    [anon_sym_sealed] = ACTIONS(3065),
    [anon_sym_virtual] = ACTIONS(3065),
    [anon_sym_volatile] = ACTIONS(3065),
    [anon_sym_where] = ACTIONS(3065),
    [anon_sym_notnull] = ACTIONS(3065),
    [anon_sym_unmanaged] = ACTIONS(3065),
    [anon_sym_checked] = ACTIONS(3065),
    [anon_sym_BANG] = ACTIONS(3067),
    [anon_sym_TILDE] = ACTIONS(3067),
    [anon_sym_PLUS_PLUS] = ACTIONS(3067),
    [anon_sym_DASH_DASH] = ACTIONS(3067),
    [anon_sym_true] = ACTIONS(3065),
    [anon_sym_false] = ACTIONS(3065),
    [anon_sym_PLUS] = ACTIONS(3065),
    [anon_sym_DASH] = ACTIONS(3065),
    [anon_sym_STAR] = ACTIONS(3067),
    [anon_sym_CARET] = ACTIONS(3067),
    [anon_sym_AMP] = ACTIONS(3067),
    [anon_sym_this] = ACTIONS(3065),
    [anon_sym_scoped] = ACTIONS(3065),
    [anon_sym_base] = ACTIONS(3065),
    [anon_sym_var] = ACTIONS(3065),
    [sym_predefined_type] = ACTIONS(3065),
    [anon_sym_break] = ACTIONS(3065),
    [anon_sym_unchecked] = ACTIONS(3065),
    [anon_sym_continue] = ACTIONS(3065),
    [anon_sym_do] = ACTIONS(3065),
    [anon_sym_while] = ACTIONS(3065),
    [anon_sym_for] = ACTIONS(3065),
    [anon_sym_lock] = ACTIONS(3065),
    [anon_sym_yield] = ACTIONS(3065),
    [anon_sym_switch] = ACTIONS(3065),
    [anon_sym_case] = ACTIONS(3065),
    [anon_sym_default] = ACTIONS(3065),
    [anon_sym_throw] = ACTIONS(3065),
    [anon_sym_try] = ACTIONS(3065),
    [anon_sym_when] = ACTIONS(3065),
    [anon_sym_await] = ACTIONS(3065),
    [anon_sym_foreach] = ACTIONS(3065),
    [anon_sym_goto] = ACTIONS(3065),
    [anon_sym_if] = ACTIONS(3065),
    [anon_sym_else] = ACTIONS(3065),
    [anon_sym_DOT_DOT] = ACTIONS(3067),
    [anon_sym_from] = ACTIONS(3065),
    [anon_sym_into] = ACTIONS(3065),
    [anon_sym_join] = ACTIONS(3065),
    [anon_sym_on] = ACTIONS(3065),
    [anon_sym_equals] = ACTIONS(3065),
    [anon_sym_let] = ACTIONS(3065),
    [anon_sym_orderby] = ACTIONS(3065),
    [anon_sym_ascending] = ACTIONS(3065),
    [anon_sym_descending] = ACTIONS(3065),
    [anon_sym_group] = ACTIONS(3065),
    [anon_sym_by] = ACTIONS(3065),
    [anon_sym_select] = ACTIONS(3065),
    [anon_sym_stackalloc] = ACTIONS(3065),
    [anon_sym_sizeof] = ACTIONS(3065),
    [anon_sym_typeof] = ACTIONS(3065),
    [anon_sym___makeref] = ACTIONS(3065),
    [anon_sym___reftype] = ACTIONS(3065),
    [anon_sym___refvalue] = ACTIONS(3065),
    [sym_null_literal] = ACTIONS(3065),
    [anon_sym_SQUOTE] = ACTIONS(3067),
    [sym_integer_literal] = ACTIONS(3065),
    [sym_real_literal] = ACTIONS(3067),
    [anon_sym_DQUOTE] = ACTIONS(3067),
    [sym_verbatim_string_literal] = ACTIONS(3067),
    [aux_sym_preproc_if_token1] = ACTIONS(3067),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3067),
    [sym_interpolation_verbatim_start] = ACTIONS(3067),
    [sym_interpolation_raw_start] = ACTIONS(3067),
    [sym_raw_string_start] = ACTIONS(3067),
  },
  [2676] = {
    [sym_preproc_region] = STATE(2676),
    [sym_preproc_endregion] = STATE(2676),
    [sym_preproc_line] = STATE(2676),
    [sym_preproc_pragma] = STATE(2676),
    [sym_preproc_nullable] = STATE(2676),
    [sym_preproc_error] = STATE(2676),
    [sym_preproc_warning] = STATE(2676),
    [sym_preproc_define] = STATE(2676),
    [sym_preproc_undef] = STATE(2676),
    [sym__identifier_token] = ACTIONS(3069),
    [anon_sym_extern] = ACTIONS(3069),
    [anon_sym_alias] = ACTIONS(3069),
    [anon_sym_SEMI] = ACTIONS(3071),
    [anon_sym_global] = ACTIONS(3069),
    [anon_sym_using] = ACTIONS(3069),
    [anon_sym_unsafe] = ACTIONS(3069),
    [anon_sym_static] = ACTIONS(3069),
    [anon_sym_LBRACK] = ACTIONS(3071),
    [anon_sym_LPAREN] = ACTIONS(3071),
    [anon_sym_return] = ACTIONS(3069),
    [anon_sym_ref] = ACTIONS(3069),
    [anon_sym_LBRACE] = ACTIONS(3071),
    [anon_sym_RBRACE] = ACTIONS(3071),
    [anon_sym_delegate] = ACTIONS(3069),
    [anon_sym_abstract] = ACTIONS(3069),
    [anon_sym_async] = ACTIONS(3069),
    [anon_sym_const] = ACTIONS(3069),
    [anon_sym_file] = ACTIONS(3069),
    [anon_sym_fixed] = ACTIONS(3069),
    [anon_sym_internal] = ACTIONS(3069),
    [anon_sym_new] = ACTIONS(3069),
    [anon_sym_override] = ACTIONS(3069),
    [anon_sym_partial] = ACTIONS(3069),
    [anon_sym_private] = ACTIONS(3069),
    [anon_sym_protected] = ACTIONS(3069),
    [anon_sym_public] = ACTIONS(3069),
    [anon_sym_readonly] = ACTIONS(3069),
    [anon_sym_required] = ACTIONS(3069),
    [anon_sym_sealed] = ACTIONS(3069),
    [anon_sym_virtual] = ACTIONS(3069),
    [anon_sym_volatile] = ACTIONS(3069),
    [anon_sym_where] = ACTIONS(3069),
    [anon_sym_notnull] = ACTIONS(3069),
    [anon_sym_unmanaged] = ACTIONS(3069),
    [anon_sym_checked] = ACTIONS(3069),
    [anon_sym_BANG] = ACTIONS(3071),
    [anon_sym_TILDE] = ACTIONS(3071),
    [anon_sym_PLUS_PLUS] = ACTIONS(3071),
    [anon_sym_DASH_DASH] = ACTIONS(3071),
    [anon_sym_true] = ACTIONS(3069),
    [anon_sym_false] = ACTIONS(3069),
    [anon_sym_PLUS] = ACTIONS(3069),
    [anon_sym_DASH] = ACTIONS(3069),
    [anon_sym_STAR] = ACTIONS(3071),
    [anon_sym_CARET] = ACTIONS(3071),
    [anon_sym_AMP] = ACTIONS(3071),
    [anon_sym_this] = ACTIONS(3069),
    [anon_sym_scoped] = ACTIONS(3069),
    [anon_sym_base] = ACTIONS(3069),
    [anon_sym_var] = ACTIONS(3069),
    [sym_predefined_type] = ACTIONS(3069),
    [anon_sym_break] = ACTIONS(3069),
    [anon_sym_unchecked] = ACTIONS(3069),
    [anon_sym_continue] = ACTIONS(3069),
    [anon_sym_do] = ACTIONS(3069),
    [anon_sym_while] = ACTIONS(3069),
    [anon_sym_for] = ACTIONS(3069),
    [anon_sym_lock] = ACTIONS(3069),
    [anon_sym_yield] = ACTIONS(3069),
    [anon_sym_switch] = ACTIONS(3069),
    [anon_sym_case] = ACTIONS(3069),
    [anon_sym_default] = ACTIONS(3069),
    [anon_sym_throw] = ACTIONS(3069),
    [anon_sym_try] = ACTIONS(3069),
    [anon_sym_when] = ACTIONS(3069),
    [anon_sym_await] = ACTIONS(3069),
    [anon_sym_foreach] = ACTIONS(3069),
    [anon_sym_goto] = ACTIONS(3069),
    [anon_sym_if] = ACTIONS(3069),
    [anon_sym_else] = ACTIONS(3069),
    [anon_sym_DOT_DOT] = ACTIONS(3071),
    [anon_sym_from] = ACTIONS(3069),
    [anon_sym_into] = ACTIONS(3069),
    [anon_sym_join] = ACTIONS(3069),
    [anon_sym_on] = ACTIONS(3069),
    [anon_sym_equals] = ACTIONS(3069),
    [anon_sym_let] = ACTIONS(3069),
    [anon_sym_orderby] = ACTIONS(3069),
    [anon_sym_ascending] = ACTIONS(3069),
    [anon_sym_descending] = ACTIONS(3069),
    [anon_sym_group] = ACTIONS(3069),
    [anon_sym_by] = ACTIONS(3069),
    [anon_sym_select] = ACTIONS(3069),
    [anon_sym_stackalloc] = ACTIONS(3069),
    [anon_sym_sizeof] = ACTIONS(3069),
    [anon_sym_typeof] = ACTIONS(3069),
    [anon_sym___makeref] = ACTIONS(3069),
    [anon_sym___reftype] = ACTIONS(3069),
    [anon_sym___refvalue] = ACTIONS(3069),
    [sym_null_literal] = ACTIONS(3069),
    [anon_sym_SQUOTE] = ACTIONS(3071),
    [sym_integer_literal] = ACTIONS(3069),
    [sym_real_literal] = ACTIONS(3071),
    [anon_sym_DQUOTE] = ACTIONS(3071),
    [sym_verbatim_string_literal] = ACTIONS(3071),
    [aux_sym_preproc_if_token1] = ACTIONS(3071),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3071),
    [sym_interpolation_verbatim_start] = ACTIONS(3071),
    [sym_interpolation_raw_start] = ACTIONS(3071),
    [sym_raw_string_start] = ACTIONS(3071),
  },
  [2677] = {
    [sym_preproc_region] = STATE(2677),
    [sym_preproc_endregion] = STATE(2677),
    [sym_preproc_line] = STATE(2677),
    [sym_preproc_pragma] = STATE(2677),
    [sym_preproc_nullable] = STATE(2677),
    [sym_preproc_error] = STATE(2677),
    [sym_preproc_warning] = STATE(2677),
    [sym_preproc_define] = STATE(2677),
    [sym_preproc_undef] = STATE(2677),
    [sym__identifier_token] = ACTIONS(3073),
    [anon_sym_extern] = ACTIONS(3073),
    [anon_sym_alias] = ACTIONS(3073),
    [anon_sym_SEMI] = ACTIONS(3075),
    [anon_sym_global] = ACTIONS(3073),
    [anon_sym_using] = ACTIONS(3073),
    [anon_sym_unsafe] = ACTIONS(3073),
    [anon_sym_static] = ACTIONS(3073),
    [anon_sym_LBRACK] = ACTIONS(3075),
    [anon_sym_LPAREN] = ACTIONS(3075),
    [anon_sym_return] = ACTIONS(3073),
    [anon_sym_ref] = ACTIONS(3073),
    [anon_sym_LBRACE] = ACTIONS(3075),
    [anon_sym_RBRACE] = ACTIONS(3075),
    [anon_sym_delegate] = ACTIONS(3073),
    [anon_sym_abstract] = ACTIONS(3073),
    [anon_sym_async] = ACTIONS(3073),
    [anon_sym_const] = ACTIONS(3073),
    [anon_sym_file] = ACTIONS(3073),
    [anon_sym_fixed] = ACTIONS(3073),
    [anon_sym_internal] = ACTIONS(3073),
    [anon_sym_new] = ACTIONS(3073),
    [anon_sym_override] = ACTIONS(3073),
    [anon_sym_partial] = ACTIONS(3073),
    [anon_sym_private] = ACTIONS(3073),
    [anon_sym_protected] = ACTIONS(3073),
    [anon_sym_public] = ACTIONS(3073),
    [anon_sym_readonly] = ACTIONS(3073),
    [anon_sym_required] = ACTIONS(3073),
    [anon_sym_sealed] = ACTIONS(3073),
    [anon_sym_virtual] = ACTIONS(3073),
    [anon_sym_volatile] = ACTIONS(3073),
    [anon_sym_where] = ACTIONS(3073),
    [anon_sym_notnull] = ACTIONS(3073),
    [anon_sym_unmanaged] = ACTIONS(3073),
    [anon_sym_checked] = ACTIONS(3073),
    [anon_sym_BANG] = ACTIONS(3075),
    [anon_sym_TILDE] = ACTIONS(3075),
    [anon_sym_PLUS_PLUS] = ACTIONS(3075),
    [anon_sym_DASH_DASH] = ACTIONS(3075),
    [anon_sym_true] = ACTIONS(3073),
    [anon_sym_false] = ACTIONS(3073),
    [anon_sym_PLUS] = ACTIONS(3073),
    [anon_sym_DASH] = ACTIONS(3073),
    [anon_sym_STAR] = ACTIONS(3075),
    [anon_sym_CARET] = ACTIONS(3075),
    [anon_sym_AMP] = ACTIONS(3075),
    [anon_sym_this] = ACTIONS(3073),
    [anon_sym_scoped] = ACTIONS(3073),
    [anon_sym_base] = ACTIONS(3073),
    [anon_sym_var] = ACTIONS(3073),
    [sym_predefined_type] = ACTIONS(3073),
    [anon_sym_break] = ACTIONS(3073),
    [anon_sym_unchecked] = ACTIONS(3073),
    [anon_sym_continue] = ACTIONS(3073),
    [anon_sym_do] = ACTIONS(3073),
    [anon_sym_while] = ACTIONS(3073),
    [anon_sym_for] = ACTIONS(3073),
    [anon_sym_lock] = ACTIONS(3073),
    [anon_sym_yield] = ACTIONS(3073),
    [anon_sym_switch] = ACTIONS(3073),
    [anon_sym_case] = ACTIONS(3073),
    [anon_sym_default] = ACTIONS(3073),
    [anon_sym_throw] = ACTIONS(3073),
    [anon_sym_try] = ACTIONS(3073),
    [anon_sym_when] = ACTIONS(3073),
    [anon_sym_await] = ACTIONS(3073),
    [anon_sym_foreach] = ACTIONS(3073),
    [anon_sym_goto] = ACTIONS(3073),
    [anon_sym_if] = ACTIONS(3073),
    [anon_sym_else] = ACTIONS(3073),
    [anon_sym_DOT_DOT] = ACTIONS(3075),
    [anon_sym_from] = ACTIONS(3073),
    [anon_sym_into] = ACTIONS(3073),
    [anon_sym_join] = ACTIONS(3073),
    [anon_sym_on] = ACTIONS(3073),
    [anon_sym_equals] = ACTIONS(3073),
    [anon_sym_let] = ACTIONS(3073),
    [anon_sym_orderby] = ACTIONS(3073),
    [anon_sym_ascending] = ACTIONS(3073),
    [anon_sym_descending] = ACTIONS(3073),
    [anon_sym_group] = ACTIONS(3073),
    [anon_sym_by] = ACTIONS(3073),
    [anon_sym_select] = ACTIONS(3073),
    [anon_sym_stackalloc] = ACTIONS(3073),
    [anon_sym_sizeof] = ACTIONS(3073),
    [anon_sym_typeof] = ACTIONS(3073),
    [anon_sym___makeref] = ACTIONS(3073),
    [anon_sym___reftype] = ACTIONS(3073),
    [anon_sym___refvalue] = ACTIONS(3073),
    [sym_null_literal] = ACTIONS(3073),
    [anon_sym_SQUOTE] = ACTIONS(3075),
    [sym_integer_literal] = ACTIONS(3073),
    [sym_real_literal] = ACTIONS(3075),
    [anon_sym_DQUOTE] = ACTIONS(3075),
    [sym_verbatim_string_literal] = ACTIONS(3075),
    [aux_sym_preproc_if_token1] = ACTIONS(3075),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3075),
    [sym_interpolation_verbatim_start] = ACTIONS(3075),
    [sym_interpolation_raw_start] = ACTIONS(3075),
    [sym_raw_string_start] = ACTIONS(3075),
  },
  [2678] = {
    [sym_preproc_region] = STATE(2678),
    [sym_preproc_endregion] = STATE(2678),
    [sym_preproc_line] = STATE(2678),
    [sym_preproc_pragma] = STATE(2678),
    [sym_preproc_nullable] = STATE(2678),
    [sym_preproc_error] = STATE(2678),
    [sym_preproc_warning] = STATE(2678),
    [sym_preproc_define] = STATE(2678),
    [sym_preproc_undef] = STATE(2678),
    [sym__identifier_token] = ACTIONS(3327),
    [anon_sym_extern] = ACTIONS(3327),
    [anon_sym_alias] = ACTIONS(3327),
    [anon_sym_SEMI] = ACTIONS(3329),
    [anon_sym_global] = ACTIONS(3327),
    [anon_sym_using] = ACTIONS(3327),
    [anon_sym_unsafe] = ACTIONS(3327),
    [anon_sym_static] = ACTIONS(3327),
    [anon_sym_LBRACK] = ACTIONS(3329),
    [anon_sym_LPAREN] = ACTIONS(3329),
    [anon_sym_return] = ACTIONS(3327),
    [anon_sym_ref] = ACTIONS(3327),
    [anon_sym_LBRACE] = ACTIONS(3329),
    [anon_sym_RBRACE] = ACTIONS(3329),
    [anon_sym_delegate] = ACTIONS(3327),
    [anon_sym_abstract] = ACTIONS(3327),
    [anon_sym_async] = ACTIONS(3327),
    [anon_sym_const] = ACTIONS(3327),
    [anon_sym_file] = ACTIONS(3327),
    [anon_sym_fixed] = ACTIONS(3327),
    [anon_sym_internal] = ACTIONS(3327),
    [anon_sym_new] = ACTIONS(3327),
    [anon_sym_override] = ACTIONS(3327),
    [anon_sym_partial] = ACTIONS(3327),
    [anon_sym_private] = ACTIONS(3327),
    [anon_sym_protected] = ACTIONS(3327),
    [anon_sym_public] = ACTIONS(3327),
    [anon_sym_readonly] = ACTIONS(3327),
    [anon_sym_required] = ACTIONS(3327),
    [anon_sym_sealed] = ACTIONS(3327),
    [anon_sym_virtual] = ACTIONS(3327),
    [anon_sym_volatile] = ACTIONS(3327),
    [anon_sym_where] = ACTIONS(3327),
    [anon_sym_notnull] = ACTIONS(3327),
    [anon_sym_unmanaged] = ACTIONS(3327),
    [anon_sym_checked] = ACTIONS(3327),
    [anon_sym_BANG] = ACTIONS(3329),
    [anon_sym_TILDE] = ACTIONS(3329),
    [anon_sym_PLUS_PLUS] = ACTIONS(3329),
    [anon_sym_DASH_DASH] = ACTIONS(3329),
    [anon_sym_true] = ACTIONS(3327),
    [anon_sym_false] = ACTIONS(3327),
    [anon_sym_PLUS] = ACTIONS(3327),
    [anon_sym_DASH] = ACTIONS(3327),
    [anon_sym_STAR] = ACTIONS(3329),
    [anon_sym_CARET] = ACTIONS(3329),
    [anon_sym_AMP] = ACTIONS(3329),
    [anon_sym_this] = ACTIONS(3327),
    [anon_sym_scoped] = ACTIONS(3327),
    [anon_sym_base] = ACTIONS(3327),
    [anon_sym_var] = ACTIONS(3327),
    [sym_predefined_type] = ACTIONS(3327),
    [anon_sym_break] = ACTIONS(3327),
    [anon_sym_unchecked] = ACTIONS(3327),
    [anon_sym_continue] = ACTIONS(3327),
    [anon_sym_do] = ACTIONS(3327),
    [anon_sym_while] = ACTIONS(3327),
    [anon_sym_for] = ACTIONS(3327),
    [anon_sym_lock] = ACTIONS(3327),
    [anon_sym_yield] = ACTIONS(3327),
    [anon_sym_switch] = ACTIONS(3327),
    [anon_sym_case] = ACTIONS(3327),
    [anon_sym_default] = ACTIONS(3327),
    [anon_sym_throw] = ACTIONS(3327),
    [anon_sym_try] = ACTIONS(3327),
    [anon_sym_when] = ACTIONS(3327),
    [anon_sym_await] = ACTIONS(3327),
    [anon_sym_foreach] = ACTIONS(3327),
    [anon_sym_goto] = ACTIONS(3327),
    [anon_sym_if] = ACTIONS(3327),
    [anon_sym_else] = ACTIONS(3327),
    [anon_sym_DOT_DOT] = ACTIONS(3329),
    [anon_sym_from] = ACTIONS(3327),
    [anon_sym_into] = ACTIONS(3327),
    [anon_sym_join] = ACTIONS(3327),
    [anon_sym_on] = ACTIONS(3327),
    [anon_sym_equals] = ACTIONS(3327),
    [anon_sym_let] = ACTIONS(3327),
    [anon_sym_orderby] = ACTIONS(3327),
    [anon_sym_ascending] = ACTIONS(3327),
    [anon_sym_descending] = ACTIONS(3327),
    [anon_sym_group] = ACTIONS(3327),
    [anon_sym_by] = ACTIONS(3327),
    [anon_sym_select] = ACTIONS(3327),
    [anon_sym_stackalloc] = ACTIONS(3327),
    [anon_sym_sizeof] = ACTIONS(3327),
    [anon_sym_typeof] = ACTIONS(3327),
    [anon_sym___makeref] = ACTIONS(3327),
    [anon_sym___reftype] = ACTIONS(3327),
    [anon_sym___refvalue] = ACTIONS(3327),
    [sym_null_literal] = ACTIONS(3327),
    [anon_sym_SQUOTE] = ACTIONS(3329),
    [sym_integer_literal] = ACTIONS(3327),
    [sym_real_literal] = ACTIONS(3329),
    [anon_sym_DQUOTE] = ACTIONS(3329),
    [sym_verbatim_string_literal] = ACTIONS(3329),
    [aux_sym_preproc_if_token1] = ACTIONS(3329),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3329),
    [sym_interpolation_verbatim_start] = ACTIONS(3329),
    [sym_interpolation_raw_start] = ACTIONS(3329),
    [sym_raw_string_start] = ACTIONS(3329),
  },
  [2679] = {
    [sym_preproc_region] = STATE(2679),
    [sym_preproc_endregion] = STATE(2679),
    [sym_preproc_line] = STATE(2679),
    [sym_preproc_pragma] = STATE(2679),
    [sym_preproc_nullable] = STATE(2679),
    [sym_preproc_error] = STATE(2679),
    [sym_preproc_warning] = STATE(2679),
    [sym_preproc_define] = STATE(2679),
    [sym_preproc_undef] = STATE(2679),
    [sym__identifier_token] = ACTIONS(3077),
    [anon_sym_extern] = ACTIONS(3077),
    [anon_sym_alias] = ACTIONS(3077),
    [anon_sym_SEMI] = ACTIONS(3079),
    [anon_sym_global] = ACTIONS(3077),
    [anon_sym_using] = ACTIONS(3077),
    [anon_sym_unsafe] = ACTIONS(3077),
    [anon_sym_static] = ACTIONS(3077),
    [anon_sym_LBRACK] = ACTIONS(3079),
    [anon_sym_LPAREN] = ACTIONS(3079),
    [anon_sym_return] = ACTIONS(3077),
    [anon_sym_ref] = ACTIONS(3077),
    [anon_sym_LBRACE] = ACTIONS(3079),
    [anon_sym_RBRACE] = ACTIONS(3079),
    [anon_sym_delegate] = ACTIONS(3077),
    [anon_sym_abstract] = ACTIONS(3077),
    [anon_sym_async] = ACTIONS(3077),
    [anon_sym_const] = ACTIONS(3077),
    [anon_sym_file] = ACTIONS(3077),
    [anon_sym_fixed] = ACTIONS(3077),
    [anon_sym_internal] = ACTIONS(3077),
    [anon_sym_new] = ACTIONS(3077),
    [anon_sym_override] = ACTIONS(3077),
    [anon_sym_partial] = ACTIONS(3077),
    [anon_sym_private] = ACTIONS(3077),
    [anon_sym_protected] = ACTIONS(3077),
    [anon_sym_public] = ACTIONS(3077),
    [anon_sym_readonly] = ACTIONS(3077),
    [anon_sym_required] = ACTIONS(3077),
    [anon_sym_sealed] = ACTIONS(3077),
    [anon_sym_virtual] = ACTIONS(3077),
    [anon_sym_volatile] = ACTIONS(3077),
    [anon_sym_where] = ACTIONS(3077),
    [anon_sym_notnull] = ACTIONS(3077),
    [anon_sym_unmanaged] = ACTIONS(3077),
    [anon_sym_checked] = ACTIONS(3077),
    [anon_sym_BANG] = ACTIONS(3079),
    [anon_sym_TILDE] = ACTIONS(3079),
    [anon_sym_PLUS_PLUS] = ACTIONS(3079),
    [anon_sym_DASH_DASH] = ACTIONS(3079),
    [anon_sym_true] = ACTIONS(3077),
    [anon_sym_false] = ACTIONS(3077),
    [anon_sym_PLUS] = ACTIONS(3077),
    [anon_sym_DASH] = ACTIONS(3077),
    [anon_sym_STAR] = ACTIONS(3079),
    [anon_sym_CARET] = ACTIONS(3079),
    [anon_sym_AMP] = ACTIONS(3079),
    [anon_sym_this] = ACTIONS(3077),
    [anon_sym_scoped] = ACTIONS(3077),
    [anon_sym_base] = ACTIONS(3077),
    [anon_sym_var] = ACTIONS(3077),
    [sym_predefined_type] = ACTIONS(3077),
    [anon_sym_break] = ACTIONS(3077),
    [anon_sym_unchecked] = ACTIONS(3077),
    [anon_sym_continue] = ACTIONS(3077),
    [anon_sym_do] = ACTIONS(3077),
    [anon_sym_while] = ACTIONS(3077),
    [anon_sym_for] = ACTIONS(3077),
    [anon_sym_lock] = ACTIONS(3077),
    [anon_sym_yield] = ACTIONS(3077),
    [anon_sym_switch] = ACTIONS(3077),
    [anon_sym_case] = ACTIONS(3077),
    [anon_sym_default] = ACTIONS(3077),
    [anon_sym_throw] = ACTIONS(3077),
    [anon_sym_try] = ACTIONS(3077),
    [anon_sym_when] = ACTIONS(3077),
    [anon_sym_await] = ACTIONS(3077),
    [anon_sym_foreach] = ACTIONS(3077),
    [anon_sym_goto] = ACTIONS(3077),
    [anon_sym_if] = ACTIONS(3077),
    [anon_sym_else] = ACTIONS(3077),
    [anon_sym_DOT_DOT] = ACTIONS(3079),
    [anon_sym_from] = ACTIONS(3077),
    [anon_sym_into] = ACTIONS(3077),
    [anon_sym_join] = ACTIONS(3077),
    [anon_sym_on] = ACTIONS(3077),
    [anon_sym_equals] = ACTIONS(3077),
    [anon_sym_let] = ACTIONS(3077),
    [anon_sym_orderby] = ACTIONS(3077),
    [anon_sym_ascending] = ACTIONS(3077),
    [anon_sym_descending] = ACTIONS(3077),
    [anon_sym_group] = ACTIONS(3077),
    [anon_sym_by] = ACTIONS(3077),
    [anon_sym_select] = ACTIONS(3077),
    [anon_sym_stackalloc] = ACTIONS(3077),
    [anon_sym_sizeof] = ACTIONS(3077),
    [anon_sym_typeof] = ACTIONS(3077),
    [anon_sym___makeref] = ACTIONS(3077),
    [anon_sym___reftype] = ACTIONS(3077),
    [anon_sym___refvalue] = ACTIONS(3077),
    [sym_null_literal] = ACTIONS(3077),
    [anon_sym_SQUOTE] = ACTIONS(3079),
    [sym_integer_literal] = ACTIONS(3077),
    [sym_real_literal] = ACTIONS(3079),
    [anon_sym_DQUOTE] = ACTIONS(3079),
    [sym_verbatim_string_literal] = ACTIONS(3079),
    [aux_sym_preproc_if_token1] = ACTIONS(3079),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3079),
    [sym_interpolation_verbatim_start] = ACTIONS(3079),
    [sym_interpolation_raw_start] = ACTIONS(3079),
    [sym_raw_string_start] = ACTIONS(3079),
  },
  [2680] = {
    [sym_preproc_region] = STATE(2680),
    [sym_preproc_endregion] = STATE(2680),
    [sym_preproc_line] = STATE(2680),
    [sym_preproc_pragma] = STATE(2680),
    [sym_preproc_nullable] = STATE(2680),
    [sym_preproc_error] = STATE(2680),
    [sym_preproc_warning] = STATE(2680),
    [sym_preproc_define] = STATE(2680),
    [sym_preproc_undef] = STATE(2680),
    [sym__identifier_token] = ACTIONS(3081),
    [anon_sym_extern] = ACTIONS(3081),
    [anon_sym_alias] = ACTIONS(3081),
    [anon_sym_SEMI] = ACTIONS(3083),
    [anon_sym_global] = ACTIONS(3081),
    [anon_sym_using] = ACTIONS(3081),
    [anon_sym_unsafe] = ACTIONS(3081),
    [anon_sym_static] = ACTIONS(3081),
    [anon_sym_LBRACK] = ACTIONS(3083),
    [anon_sym_LPAREN] = ACTIONS(3083),
    [anon_sym_return] = ACTIONS(3081),
    [anon_sym_ref] = ACTIONS(3081),
    [anon_sym_LBRACE] = ACTIONS(3083),
    [anon_sym_RBRACE] = ACTIONS(3083),
    [anon_sym_delegate] = ACTIONS(3081),
    [anon_sym_abstract] = ACTIONS(3081),
    [anon_sym_async] = ACTIONS(3081),
    [anon_sym_const] = ACTIONS(3081),
    [anon_sym_file] = ACTIONS(3081),
    [anon_sym_fixed] = ACTIONS(3081),
    [anon_sym_internal] = ACTIONS(3081),
    [anon_sym_new] = ACTIONS(3081),
    [anon_sym_override] = ACTIONS(3081),
    [anon_sym_partial] = ACTIONS(3081),
    [anon_sym_private] = ACTIONS(3081),
    [anon_sym_protected] = ACTIONS(3081),
    [anon_sym_public] = ACTIONS(3081),
    [anon_sym_readonly] = ACTIONS(3081),
    [anon_sym_required] = ACTIONS(3081),
    [anon_sym_sealed] = ACTIONS(3081),
    [anon_sym_virtual] = ACTIONS(3081),
    [anon_sym_volatile] = ACTIONS(3081),
    [anon_sym_where] = ACTIONS(3081),
    [anon_sym_notnull] = ACTIONS(3081),
    [anon_sym_unmanaged] = ACTIONS(3081),
    [anon_sym_checked] = ACTIONS(3081),
    [anon_sym_BANG] = ACTIONS(3083),
    [anon_sym_TILDE] = ACTIONS(3083),
    [anon_sym_PLUS_PLUS] = ACTIONS(3083),
    [anon_sym_DASH_DASH] = ACTIONS(3083),
    [anon_sym_true] = ACTIONS(3081),
    [anon_sym_false] = ACTIONS(3081),
    [anon_sym_PLUS] = ACTIONS(3081),
    [anon_sym_DASH] = ACTIONS(3081),
    [anon_sym_STAR] = ACTIONS(3083),
    [anon_sym_CARET] = ACTIONS(3083),
    [anon_sym_AMP] = ACTIONS(3083),
    [anon_sym_this] = ACTIONS(3081),
    [anon_sym_scoped] = ACTIONS(3081),
    [anon_sym_base] = ACTIONS(3081),
    [anon_sym_var] = ACTIONS(3081),
    [sym_predefined_type] = ACTIONS(3081),
    [anon_sym_break] = ACTIONS(3081),
    [anon_sym_unchecked] = ACTIONS(3081),
    [anon_sym_continue] = ACTIONS(3081),
    [anon_sym_do] = ACTIONS(3081),
    [anon_sym_while] = ACTIONS(3081),
    [anon_sym_for] = ACTIONS(3081),
    [anon_sym_lock] = ACTIONS(3081),
    [anon_sym_yield] = ACTIONS(3081),
    [anon_sym_switch] = ACTIONS(3081),
    [anon_sym_case] = ACTIONS(3081),
    [anon_sym_default] = ACTIONS(3081),
    [anon_sym_throw] = ACTIONS(3081),
    [anon_sym_try] = ACTIONS(3081),
    [anon_sym_when] = ACTIONS(3081),
    [anon_sym_await] = ACTIONS(3081),
    [anon_sym_foreach] = ACTIONS(3081),
    [anon_sym_goto] = ACTIONS(3081),
    [anon_sym_if] = ACTIONS(3081),
    [anon_sym_else] = ACTIONS(3081),
    [anon_sym_DOT_DOT] = ACTIONS(3083),
    [anon_sym_from] = ACTIONS(3081),
    [anon_sym_into] = ACTIONS(3081),
    [anon_sym_join] = ACTIONS(3081),
    [anon_sym_on] = ACTIONS(3081),
    [anon_sym_equals] = ACTIONS(3081),
    [anon_sym_let] = ACTIONS(3081),
    [anon_sym_orderby] = ACTIONS(3081),
    [anon_sym_ascending] = ACTIONS(3081),
    [anon_sym_descending] = ACTIONS(3081),
    [anon_sym_group] = ACTIONS(3081),
    [anon_sym_by] = ACTIONS(3081),
    [anon_sym_select] = ACTIONS(3081),
    [anon_sym_stackalloc] = ACTIONS(3081),
    [anon_sym_sizeof] = ACTIONS(3081),
    [anon_sym_typeof] = ACTIONS(3081),
    [anon_sym___makeref] = ACTIONS(3081),
    [anon_sym___reftype] = ACTIONS(3081),
    [anon_sym___refvalue] = ACTIONS(3081),
    [sym_null_literal] = ACTIONS(3081),
    [anon_sym_SQUOTE] = ACTIONS(3083),
    [sym_integer_literal] = ACTIONS(3081),
    [sym_real_literal] = ACTIONS(3083),
    [anon_sym_DQUOTE] = ACTIONS(3083),
    [sym_verbatim_string_literal] = ACTIONS(3083),
    [aux_sym_preproc_if_token1] = ACTIONS(3083),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3083),
    [sym_interpolation_verbatim_start] = ACTIONS(3083),
    [sym_interpolation_raw_start] = ACTIONS(3083),
    [sym_raw_string_start] = ACTIONS(3083),
  },
  [2681] = {
    [sym_preproc_region] = STATE(2681),
    [sym_preproc_endregion] = STATE(2681),
    [sym_preproc_line] = STATE(2681),
    [sym_preproc_pragma] = STATE(2681),
    [sym_preproc_nullable] = STATE(2681),
    [sym_preproc_error] = STATE(2681),
    [sym_preproc_warning] = STATE(2681),
    [sym_preproc_define] = STATE(2681),
    [sym_preproc_undef] = STATE(2681),
    [sym__identifier_token] = ACTIONS(3085),
    [anon_sym_extern] = ACTIONS(3085),
    [anon_sym_alias] = ACTIONS(3085),
    [anon_sym_SEMI] = ACTIONS(3087),
    [anon_sym_global] = ACTIONS(3085),
    [anon_sym_using] = ACTIONS(3085),
    [anon_sym_unsafe] = ACTIONS(3085),
    [anon_sym_static] = ACTIONS(3085),
    [anon_sym_LBRACK] = ACTIONS(3087),
    [anon_sym_LPAREN] = ACTIONS(3087),
    [anon_sym_return] = ACTIONS(3085),
    [anon_sym_ref] = ACTIONS(3085),
    [anon_sym_LBRACE] = ACTIONS(3087),
    [anon_sym_RBRACE] = ACTIONS(3087),
    [anon_sym_delegate] = ACTIONS(3085),
    [anon_sym_abstract] = ACTIONS(3085),
    [anon_sym_async] = ACTIONS(3085),
    [anon_sym_const] = ACTIONS(3085),
    [anon_sym_file] = ACTIONS(3085),
    [anon_sym_fixed] = ACTIONS(3085),
    [anon_sym_internal] = ACTIONS(3085),
    [anon_sym_new] = ACTIONS(3085),
    [anon_sym_override] = ACTIONS(3085),
    [anon_sym_partial] = ACTIONS(3085),
    [anon_sym_private] = ACTIONS(3085),
    [anon_sym_protected] = ACTIONS(3085),
    [anon_sym_public] = ACTIONS(3085),
    [anon_sym_readonly] = ACTIONS(3085),
    [anon_sym_required] = ACTIONS(3085),
    [anon_sym_sealed] = ACTIONS(3085),
    [anon_sym_virtual] = ACTIONS(3085),
    [anon_sym_volatile] = ACTIONS(3085),
    [anon_sym_where] = ACTIONS(3085),
    [anon_sym_notnull] = ACTIONS(3085),
    [anon_sym_unmanaged] = ACTIONS(3085),
    [anon_sym_checked] = ACTIONS(3085),
    [anon_sym_BANG] = ACTIONS(3087),
    [anon_sym_TILDE] = ACTIONS(3087),
    [anon_sym_PLUS_PLUS] = ACTIONS(3087),
    [anon_sym_DASH_DASH] = ACTIONS(3087),
    [anon_sym_true] = ACTIONS(3085),
    [anon_sym_false] = ACTIONS(3085),
    [anon_sym_PLUS] = ACTIONS(3085),
    [anon_sym_DASH] = ACTIONS(3085),
    [anon_sym_STAR] = ACTIONS(3087),
    [anon_sym_CARET] = ACTIONS(3087),
    [anon_sym_AMP] = ACTIONS(3087),
    [anon_sym_this] = ACTIONS(3085),
    [anon_sym_scoped] = ACTIONS(3085),
    [anon_sym_base] = ACTIONS(3085),
    [anon_sym_var] = ACTIONS(3085),
    [sym_predefined_type] = ACTIONS(3085),
    [anon_sym_break] = ACTIONS(3085),
    [anon_sym_unchecked] = ACTIONS(3085),
    [anon_sym_continue] = ACTIONS(3085),
    [anon_sym_do] = ACTIONS(3085),
    [anon_sym_while] = ACTIONS(3085),
    [anon_sym_for] = ACTIONS(3085),
    [anon_sym_lock] = ACTIONS(3085),
    [anon_sym_yield] = ACTIONS(3085),
    [anon_sym_switch] = ACTIONS(3085),
    [anon_sym_case] = ACTIONS(3085),
    [anon_sym_default] = ACTIONS(3085),
    [anon_sym_throw] = ACTIONS(3085),
    [anon_sym_try] = ACTIONS(3085),
    [anon_sym_when] = ACTIONS(3085),
    [anon_sym_await] = ACTIONS(3085),
    [anon_sym_foreach] = ACTIONS(3085),
    [anon_sym_goto] = ACTIONS(3085),
    [anon_sym_if] = ACTIONS(3085),
    [anon_sym_else] = ACTIONS(3085),
    [anon_sym_DOT_DOT] = ACTIONS(3087),
    [anon_sym_from] = ACTIONS(3085),
    [anon_sym_into] = ACTIONS(3085),
    [anon_sym_join] = ACTIONS(3085),
    [anon_sym_on] = ACTIONS(3085),
    [anon_sym_equals] = ACTIONS(3085),
    [anon_sym_let] = ACTIONS(3085),
    [anon_sym_orderby] = ACTIONS(3085),
    [anon_sym_ascending] = ACTIONS(3085),
    [anon_sym_descending] = ACTIONS(3085),
    [anon_sym_group] = ACTIONS(3085),
    [anon_sym_by] = ACTIONS(3085),
    [anon_sym_select] = ACTIONS(3085),
    [anon_sym_stackalloc] = ACTIONS(3085),
    [anon_sym_sizeof] = ACTIONS(3085),
    [anon_sym_typeof] = ACTIONS(3085),
    [anon_sym___makeref] = ACTIONS(3085),
    [anon_sym___reftype] = ACTIONS(3085),
    [anon_sym___refvalue] = ACTIONS(3085),
    [sym_null_literal] = ACTIONS(3085),
    [anon_sym_SQUOTE] = ACTIONS(3087),
    [sym_integer_literal] = ACTIONS(3085),
    [sym_real_literal] = ACTIONS(3087),
    [anon_sym_DQUOTE] = ACTIONS(3087),
    [sym_verbatim_string_literal] = ACTIONS(3087),
    [aux_sym_preproc_if_token1] = ACTIONS(3087),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3087),
    [sym_interpolation_verbatim_start] = ACTIONS(3087),
    [sym_interpolation_raw_start] = ACTIONS(3087),
    [sym_raw_string_start] = ACTIONS(3087),
  },
  [2682] = {
    [sym_preproc_region] = STATE(2682),
    [sym_preproc_endregion] = STATE(2682),
    [sym_preproc_line] = STATE(2682),
    [sym_preproc_pragma] = STATE(2682),
    [sym_preproc_nullable] = STATE(2682),
    [sym_preproc_error] = STATE(2682),
    [sym_preproc_warning] = STATE(2682),
    [sym_preproc_define] = STATE(2682),
    [sym_preproc_undef] = STATE(2682),
    [sym__identifier_token] = ACTIONS(3089),
    [anon_sym_extern] = ACTIONS(3089),
    [anon_sym_alias] = ACTIONS(3089),
    [anon_sym_SEMI] = ACTIONS(3091),
    [anon_sym_global] = ACTIONS(3089),
    [anon_sym_using] = ACTIONS(3089),
    [anon_sym_unsafe] = ACTIONS(3089),
    [anon_sym_static] = ACTIONS(3089),
    [anon_sym_LBRACK] = ACTIONS(3091),
    [anon_sym_LPAREN] = ACTIONS(3091),
    [anon_sym_return] = ACTIONS(3089),
    [anon_sym_ref] = ACTIONS(3089),
    [anon_sym_LBRACE] = ACTIONS(3091),
    [anon_sym_RBRACE] = ACTIONS(3091),
    [anon_sym_delegate] = ACTIONS(3089),
    [anon_sym_abstract] = ACTIONS(3089),
    [anon_sym_async] = ACTIONS(3089),
    [anon_sym_const] = ACTIONS(3089),
    [anon_sym_file] = ACTIONS(3089),
    [anon_sym_fixed] = ACTIONS(3089),
    [anon_sym_internal] = ACTIONS(3089),
    [anon_sym_new] = ACTIONS(3089),
    [anon_sym_override] = ACTIONS(3089),
    [anon_sym_partial] = ACTIONS(3089),
    [anon_sym_private] = ACTIONS(3089),
    [anon_sym_protected] = ACTIONS(3089),
    [anon_sym_public] = ACTIONS(3089),
    [anon_sym_readonly] = ACTIONS(3089),
    [anon_sym_required] = ACTIONS(3089),
    [anon_sym_sealed] = ACTIONS(3089),
    [anon_sym_virtual] = ACTIONS(3089),
    [anon_sym_volatile] = ACTIONS(3089),
    [anon_sym_where] = ACTIONS(3089),
    [anon_sym_notnull] = ACTIONS(3089),
    [anon_sym_unmanaged] = ACTIONS(3089),
    [anon_sym_checked] = ACTIONS(3089),
    [anon_sym_BANG] = ACTIONS(3091),
    [anon_sym_TILDE] = ACTIONS(3091),
    [anon_sym_PLUS_PLUS] = ACTIONS(3091),
    [anon_sym_DASH_DASH] = ACTIONS(3091),
    [anon_sym_true] = ACTIONS(3089),
    [anon_sym_false] = ACTIONS(3089),
    [anon_sym_PLUS] = ACTIONS(3089),
    [anon_sym_DASH] = ACTIONS(3089),
    [anon_sym_STAR] = ACTIONS(3091),
    [anon_sym_CARET] = ACTIONS(3091),
    [anon_sym_AMP] = ACTIONS(3091),
    [anon_sym_this] = ACTIONS(3089),
    [anon_sym_scoped] = ACTIONS(3089),
    [anon_sym_base] = ACTIONS(3089),
    [anon_sym_var] = ACTIONS(3089),
    [sym_predefined_type] = ACTIONS(3089),
    [anon_sym_break] = ACTIONS(3089),
    [anon_sym_unchecked] = ACTIONS(3089),
    [anon_sym_continue] = ACTIONS(3089),
    [anon_sym_do] = ACTIONS(3089),
    [anon_sym_while] = ACTIONS(3089),
    [anon_sym_for] = ACTIONS(3089),
    [anon_sym_lock] = ACTIONS(3089),
    [anon_sym_yield] = ACTIONS(3089),
    [anon_sym_switch] = ACTIONS(3089),
    [anon_sym_case] = ACTIONS(3089),
    [anon_sym_default] = ACTIONS(3089),
    [anon_sym_throw] = ACTIONS(3089),
    [anon_sym_try] = ACTIONS(3089),
    [anon_sym_when] = ACTIONS(3089),
    [anon_sym_await] = ACTIONS(3089),
    [anon_sym_foreach] = ACTIONS(3089),
    [anon_sym_goto] = ACTIONS(3089),
    [anon_sym_if] = ACTIONS(3089),
    [anon_sym_else] = ACTIONS(3089),
    [anon_sym_DOT_DOT] = ACTIONS(3091),
    [anon_sym_from] = ACTIONS(3089),
    [anon_sym_into] = ACTIONS(3089),
    [anon_sym_join] = ACTIONS(3089),
    [anon_sym_on] = ACTIONS(3089),
    [anon_sym_equals] = ACTIONS(3089),
    [anon_sym_let] = ACTIONS(3089),
    [anon_sym_orderby] = ACTIONS(3089),
    [anon_sym_ascending] = ACTIONS(3089),
    [anon_sym_descending] = ACTIONS(3089),
    [anon_sym_group] = ACTIONS(3089),
    [anon_sym_by] = ACTIONS(3089),
    [anon_sym_select] = ACTIONS(3089),
    [anon_sym_stackalloc] = ACTIONS(3089),
    [anon_sym_sizeof] = ACTIONS(3089),
    [anon_sym_typeof] = ACTIONS(3089),
    [anon_sym___makeref] = ACTIONS(3089),
    [anon_sym___reftype] = ACTIONS(3089),
    [anon_sym___refvalue] = ACTIONS(3089),
    [sym_null_literal] = ACTIONS(3089),
    [anon_sym_SQUOTE] = ACTIONS(3091),
    [sym_integer_literal] = ACTIONS(3089),
    [sym_real_literal] = ACTIONS(3091),
    [anon_sym_DQUOTE] = ACTIONS(3091),
    [sym_verbatim_string_literal] = ACTIONS(3091),
    [aux_sym_preproc_if_token1] = ACTIONS(3091),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3091),
    [sym_interpolation_verbatim_start] = ACTIONS(3091),
    [sym_interpolation_raw_start] = ACTIONS(3091),
    [sym_raw_string_start] = ACTIONS(3091),
  },
  [2683] = {
    [sym_preproc_region] = STATE(2683),
    [sym_preproc_endregion] = STATE(2683),
    [sym_preproc_line] = STATE(2683),
    [sym_preproc_pragma] = STATE(2683),
    [sym_preproc_nullable] = STATE(2683),
    [sym_preproc_error] = STATE(2683),
    [sym_preproc_warning] = STATE(2683),
    [sym_preproc_define] = STATE(2683),
    [sym_preproc_undef] = STATE(2683),
    [sym__identifier_token] = ACTIONS(3405),
    [anon_sym_extern] = ACTIONS(3405),
    [anon_sym_alias] = ACTIONS(3405),
    [anon_sym_SEMI] = ACTIONS(3407),
    [anon_sym_global] = ACTIONS(3405),
    [anon_sym_using] = ACTIONS(3405),
    [anon_sym_unsafe] = ACTIONS(3405),
    [anon_sym_static] = ACTIONS(3405),
    [anon_sym_LBRACK] = ACTIONS(3407),
    [anon_sym_LPAREN] = ACTIONS(3407),
    [anon_sym_return] = ACTIONS(3405),
    [anon_sym_ref] = ACTIONS(3405),
    [anon_sym_LBRACE] = ACTIONS(3407),
    [anon_sym_RBRACE] = ACTIONS(3407),
    [anon_sym_delegate] = ACTIONS(3405),
    [anon_sym_abstract] = ACTIONS(3405),
    [anon_sym_async] = ACTIONS(3405),
    [anon_sym_const] = ACTIONS(3405),
    [anon_sym_file] = ACTIONS(3405),
    [anon_sym_fixed] = ACTIONS(3405),
    [anon_sym_internal] = ACTIONS(3405),
    [anon_sym_new] = ACTIONS(3405),
    [anon_sym_override] = ACTIONS(3405),
    [anon_sym_partial] = ACTIONS(3405),
    [anon_sym_private] = ACTIONS(3405),
    [anon_sym_protected] = ACTIONS(3405),
    [anon_sym_public] = ACTIONS(3405),
    [anon_sym_readonly] = ACTIONS(3405),
    [anon_sym_required] = ACTIONS(3405),
    [anon_sym_sealed] = ACTIONS(3405),
    [anon_sym_virtual] = ACTIONS(3405),
    [anon_sym_volatile] = ACTIONS(3405),
    [anon_sym_where] = ACTIONS(3405),
    [anon_sym_notnull] = ACTIONS(3405),
    [anon_sym_unmanaged] = ACTIONS(3405),
    [anon_sym_checked] = ACTIONS(3405),
    [anon_sym_BANG] = ACTIONS(3407),
    [anon_sym_TILDE] = ACTIONS(3407),
    [anon_sym_PLUS_PLUS] = ACTIONS(3407),
    [anon_sym_DASH_DASH] = ACTIONS(3407),
    [anon_sym_true] = ACTIONS(3405),
    [anon_sym_false] = ACTIONS(3405),
    [anon_sym_PLUS] = ACTIONS(3405),
    [anon_sym_DASH] = ACTIONS(3405),
    [anon_sym_STAR] = ACTIONS(3407),
    [anon_sym_CARET] = ACTIONS(3407),
    [anon_sym_AMP] = ACTIONS(3407),
    [anon_sym_this] = ACTIONS(3405),
    [anon_sym_scoped] = ACTIONS(3405),
    [anon_sym_base] = ACTIONS(3405),
    [anon_sym_var] = ACTIONS(3405),
    [sym_predefined_type] = ACTIONS(3405),
    [anon_sym_break] = ACTIONS(3405),
    [anon_sym_unchecked] = ACTIONS(3405),
    [anon_sym_continue] = ACTIONS(3405),
    [anon_sym_do] = ACTIONS(3405),
    [anon_sym_while] = ACTIONS(3405),
    [anon_sym_for] = ACTIONS(3405),
    [anon_sym_lock] = ACTIONS(3405),
    [anon_sym_yield] = ACTIONS(3405),
    [anon_sym_switch] = ACTIONS(3405),
    [anon_sym_case] = ACTIONS(3405),
    [anon_sym_default] = ACTIONS(3405),
    [anon_sym_throw] = ACTIONS(3405),
    [anon_sym_try] = ACTIONS(3405),
    [anon_sym_when] = ACTIONS(3405),
    [anon_sym_await] = ACTIONS(3405),
    [anon_sym_foreach] = ACTIONS(3405),
    [anon_sym_goto] = ACTIONS(3405),
    [anon_sym_if] = ACTIONS(3405),
    [anon_sym_else] = ACTIONS(3405),
    [anon_sym_DOT_DOT] = ACTIONS(3407),
    [anon_sym_from] = ACTIONS(3405),
    [anon_sym_into] = ACTIONS(3405),
    [anon_sym_join] = ACTIONS(3405),
    [anon_sym_on] = ACTIONS(3405),
    [anon_sym_equals] = ACTIONS(3405),
    [anon_sym_let] = ACTIONS(3405),
    [anon_sym_orderby] = ACTIONS(3405),
    [anon_sym_ascending] = ACTIONS(3405),
    [anon_sym_descending] = ACTIONS(3405),
    [anon_sym_group] = ACTIONS(3405),
    [anon_sym_by] = ACTIONS(3405),
    [anon_sym_select] = ACTIONS(3405),
    [anon_sym_stackalloc] = ACTIONS(3405),
    [anon_sym_sizeof] = ACTIONS(3405),
    [anon_sym_typeof] = ACTIONS(3405),
    [anon_sym___makeref] = ACTIONS(3405),
    [anon_sym___reftype] = ACTIONS(3405),
    [anon_sym___refvalue] = ACTIONS(3405),
    [sym_null_literal] = ACTIONS(3405),
    [anon_sym_SQUOTE] = ACTIONS(3407),
    [sym_integer_literal] = ACTIONS(3405),
    [sym_real_literal] = ACTIONS(3407),
    [anon_sym_DQUOTE] = ACTIONS(3407),
    [sym_verbatim_string_literal] = ACTIONS(3407),
    [aux_sym_preproc_if_token1] = ACTIONS(3407),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3407),
    [sym_interpolation_verbatim_start] = ACTIONS(3407),
    [sym_interpolation_raw_start] = ACTIONS(3407),
    [sym_raw_string_start] = ACTIONS(3407),
  },
  [2684] = {
    [sym_preproc_region] = STATE(2684),
    [sym_preproc_endregion] = STATE(2684),
    [sym_preproc_line] = STATE(2684),
    [sym_preproc_pragma] = STATE(2684),
    [sym_preproc_nullable] = STATE(2684),
    [sym_preproc_error] = STATE(2684),
    [sym_preproc_warning] = STATE(2684),
    [sym_preproc_define] = STATE(2684),
    [sym_preproc_undef] = STATE(2684),
    [sym__identifier_token] = ACTIONS(3331),
    [anon_sym_extern] = ACTIONS(3331),
    [anon_sym_alias] = ACTIONS(3331),
    [anon_sym_SEMI] = ACTIONS(3333),
    [anon_sym_global] = ACTIONS(3331),
    [anon_sym_using] = ACTIONS(3331),
    [anon_sym_unsafe] = ACTIONS(3331),
    [anon_sym_static] = ACTIONS(3331),
    [anon_sym_LBRACK] = ACTIONS(3333),
    [anon_sym_LPAREN] = ACTIONS(3333),
    [anon_sym_return] = ACTIONS(3331),
    [anon_sym_ref] = ACTIONS(3331),
    [anon_sym_LBRACE] = ACTIONS(3333),
    [anon_sym_RBRACE] = ACTIONS(3333),
    [anon_sym_delegate] = ACTIONS(3331),
    [anon_sym_abstract] = ACTIONS(3331),
    [anon_sym_async] = ACTIONS(3331),
    [anon_sym_const] = ACTIONS(3331),
    [anon_sym_file] = ACTIONS(3331),
    [anon_sym_fixed] = ACTIONS(3331),
    [anon_sym_internal] = ACTIONS(3331),
    [anon_sym_new] = ACTIONS(3331),
    [anon_sym_override] = ACTIONS(3331),
    [anon_sym_partial] = ACTIONS(3331),
    [anon_sym_private] = ACTIONS(3331),
    [anon_sym_protected] = ACTIONS(3331),
    [anon_sym_public] = ACTIONS(3331),
    [anon_sym_readonly] = ACTIONS(3331),
    [anon_sym_required] = ACTIONS(3331),
    [anon_sym_sealed] = ACTIONS(3331),
    [anon_sym_virtual] = ACTIONS(3331),
    [anon_sym_volatile] = ACTIONS(3331),
    [anon_sym_where] = ACTIONS(3331),
    [anon_sym_notnull] = ACTIONS(3331),
    [anon_sym_unmanaged] = ACTIONS(3331),
    [anon_sym_checked] = ACTIONS(3331),
    [anon_sym_BANG] = ACTIONS(3333),
    [anon_sym_TILDE] = ACTIONS(3333),
    [anon_sym_PLUS_PLUS] = ACTIONS(3333),
    [anon_sym_DASH_DASH] = ACTIONS(3333),
    [anon_sym_true] = ACTIONS(3331),
    [anon_sym_false] = ACTIONS(3331),
    [anon_sym_PLUS] = ACTIONS(3331),
    [anon_sym_DASH] = ACTIONS(3331),
    [anon_sym_STAR] = ACTIONS(3333),
    [anon_sym_CARET] = ACTIONS(3333),
    [anon_sym_AMP] = ACTIONS(3333),
    [anon_sym_this] = ACTIONS(3331),
    [anon_sym_scoped] = ACTIONS(3331),
    [anon_sym_base] = ACTIONS(3331),
    [anon_sym_var] = ACTIONS(3331),
    [sym_predefined_type] = ACTIONS(3331),
    [anon_sym_break] = ACTIONS(3331),
    [anon_sym_unchecked] = ACTIONS(3331),
    [anon_sym_continue] = ACTIONS(3331),
    [anon_sym_do] = ACTIONS(3331),
    [anon_sym_while] = ACTIONS(3331),
    [anon_sym_for] = ACTIONS(3331),
    [anon_sym_lock] = ACTIONS(3331),
    [anon_sym_yield] = ACTIONS(3331),
    [anon_sym_switch] = ACTIONS(3331),
    [anon_sym_case] = ACTIONS(3331),
    [anon_sym_default] = ACTIONS(3331),
    [anon_sym_throw] = ACTIONS(3331),
    [anon_sym_try] = ACTIONS(3331),
    [anon_sym_when] = ACTIONS(3331),
    [anon_sym_await] = ACTIONS(3331),
    [anon_sym_foreach] = ACTIONS(3331),
    [anon_sym_goto] = ACTIONS(3331),
    [anon_sym_if] = ACTIONS(3331),
    [anon_sym_else] = ACTIONS(3331),
    [anon_sym_DOT_DOT] = ACTIONS(3333),
    [anon_sym_from] = ACTIONS(3331),
    [anon_sym_into] = ACTIONS(3331),
    [anon_sym_join] = ACTIONS(3331),
    [anon_sym_on] = ACTIONS(3331),
    [anon_sym_equals] = ACTIONS(3331),
    [anon_sym_let] = ACTIONS(3331),
    [anon_sym_orderby] = ACTIONS(3331),
    [anon_sym_ascending] = ACTIONS(3331),
    [anon_sym_descending] = ACTIONS(3331),
    [anon_sym_group] = ACTIONS(3331),
    [anon_sym_by] = ACTIONS(3331),
    [anon_sym_select] = ACTIONS(3331),
    [anon_sym_stackalloc] = ACTIONS(3331),
    [anon_sym_sizeof] = ACTIONS(3331),
    [anon_sym_typeof] = ACTIONS(3331),
    [anon_sym___makeref] = ACTIONS(3331),
    [anon_sym___reftype] = ACTIONS(3331),
    [anon_sym___refvalue] = ACTIONS(3331),
    [sym_null_literal] = ACTIONS(3331),
    [anon_sym_SQUOTE] = ACTIONS(3333),
    [sym_integer_literal] = ACTIONS(3331),
    [sym_real_literal] = ACTIONS(3333),
    [anon_sym_DQUOTE] = ACTIONS(3333),
    [sym_verbatim_string_literal] = ACTIONS(3333),
    [aux_sym_preproc_if_token1] = ACTIONS(3333),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3333),
    [sym_interpolation_verbatim_start] = ACTIONS(3333),
    [sym_interpolation_raw_start] = ACTIONS(3333),
    [sym_raw_string_start] = ACTIONS(3333),
  },
  [2685] = {
    [sym_preproc_region] = STATE(2685),
    [sym_preproc_endregion] = STATE(2685),
    [sym_preproc_line] = STATE(2685),
    [sym_preproc_pragma] = STATE(2685),
    [sym_preproc_nullable] = STATE(2685),
    [sym_preproc_error] = STATE(2685),
    [sym_preproc_warning] = STATE(2685),
    [sym_preproc_define] = STATE(2685),
    [sym_preproc_undef] = STATE(2685),
    [sym__identifier_token] = ACTIONS(3097),
    [anon_sym_extern] = ACTIONS(3097),
    [anon_sym_alias] = ACTIONS(3097),
    [anon_sym_SEMI] = ACTIONS(3099),
    [anon_sym_global] = ACTIONS(3097),
    [anon_sym_using] = ACTIONS(3097),
    [anon_sym_unsafe] = ACTIONS(3097),
    [anon_sym_static] = ACTIONS(3097),
    [anon_sym_LBRACK] = ACTIONS(3099),
    [anon_sym_LPAREN] = ACTIONS(3099),
    [anon_sym_return] = ACTIONS(3097),
    [anon_sym_ref] = ACTIONS(3097),
    [anon_sym_LBRACE] = ACTIONS(3099),
    [anon_sym_RBRACE] = ACTIONS(3099),
    [anon_sym_delegate] = ACTIONS(3097),
    [anon_sym_abstract] = ACTIONS(3097),
    [anon_sym_async] = ACTIONS(3097),
    [anon_sym_const] = ACTIONS(3097),
    [anon_sym_file] = ACTIONS(3097),
    [anon_sym_fixed] = ACTIONS(3097),
    [anon_sym_internal] = ACTIONS(3097),
    [anon_sym_new] = ACTIONS(3097),
    [anon_sym_override] = ACTIONS(3097),
    [anon_sym_partial] = ACTIONS(3097),
    [anon_sym_private] = ACTIONS(3097),
    [anon_sym_protected] = ACTIONS(3097),
    [anon_sym_public] = ACTIONS(3097),
    [anon_sym_readonly] = ACTIONS(3097),
    [anon_sym_required] = ACTIONS(3097),
    [anon_sym_sealed] = ACTIONS(3097),
    [anon_sym_virtual] = ACTIONS(3097),
    [anon_sym_volatile] = ACTIONS(3097),
    [anon_sym_where] = ACTIONS(3097),
    [anon_sym_notnull] = ACTIONS(3097),
    [anon_sym_unmanaged] = ACTIONS(3097),
    [anon_sym_checked] = ACTIONS(3097),
    [anon_sym_BANG] = ACTIONS(3099),
    [anon_sym_TILDE] = ACTIONS(3099),
    [anon_sym_PLUS_PLUS] = ACTIONS(3099),
    [anon_sym_DASH_DASH] = ACTIONS(3099),
    [anon_sym_true] = ACTIONS(3097),
    [anon_sym_false] = ACTIONS(3097),
    [anon_sym_PLUS] = ACTIONS(3097),
    [anon_sym_DASH] = ACTIONS(3097),
    [anon_sym_STAR] = ACTIONS(3099),
    [anon_sym_CARET] = ACTIONS(3099),
    [anon_sym_AMP] = ACTIONS(3099),
    [anon_sym_this] = ACTIONS(3097),
    [anon_sym_scoped] = ACTIONS(3097),
    [anon_sym_base] = ACTIONS(3097),
    [anon_sym_var] = ACTIONS(3097),
    [sym_predefined_type] = ACTIONS(3097),
    [anon_sym_break] = ACTIONS(3097),
    [anon_sym_unchecked] = ACTIONS(3097),
    [anon_sym_continue] = ACTIONS(3097),
    [anon_sym_do] = ACTIONS(3097),
    [anon_sym_while] = ACTIONS(3097),
    [anon_sym_for] = ACTIONS(3097),
    [anon_sym_lock] = ACTIONS(3097),
    [anon_sym_yield] = ACTIONS(3097),
    [anon_sym_switch] = ACTIONS(3097),
    [anon_sym_case] = ACTIONS(3097),
    [anon_sym_default] = ACTIONS(3097),
    [anon_sym_throw] = ACTIONS(3097),
    [anon_sym_try] = ACTIONS(3097),
    [anon_sym_when] = ACTIONS(3097),
    [anon_sym_await] = ACTIONS(3097),
    [anon_sym_foreach] = ACTIONS(3097),
    [anon_sym_goto] = ACTIONS(3097),
    [anon_sym_if] = ACTIONS(3097),
    [anon_sym_else] = ACTIONS(3097),
    [anon_sym_DOT_DOT] = ACTIONS(3099),
    [anon_sym_from] = ACTIONS(3097),
    [anon_sym_into] = ACTIONS(3097),
    [anon_sym_join] = ACTIONS(3097),
    [anon_sym_on] = ACTIONS(3097),
    [anon_sym_equals] = ACTIONS(3097),
    [anon_sym_let] = ACTIONS(3097),
    [anon_sym_orderby] = ACTIONS(3097),
    [anon_sym_ascending] = ACTIONS(3097),
    [anon_sym_descending] = ACTIONS(3097),
    [anon_sym_group] = ACTIONS(3097),
    [anon_sym_by] = ACTIONS(3097),
    [anon_sym_select] = ACTIONS(3097),
    [anon_sym_stackalloc] = ACTIONS(3097),
    [anon_sym_sizeof] = ACTIONS(3097),
    [anon_sym_typeof] = ACTIONS(3097),
    [anon_sym___makeref] = ACTIONS(3097),
    [anon_sym___reftype] = ACTIONS(3097),
    [anon_sym___refvalue] = ACTIONS(3097),
    [sym_null_literal] = ACTIONS(3097),
    [anon_sym_SQUOTE] = ACTIONS(3099),
    [sym_integer_literal] = ACTIONS(3097),
    [sym_real_literal] = ACTIONS(3099),
    [anon_sym_DQUOTE] = ACTIONS(3099),
    [sym_verbatim_string_literal] = ACTIONS(3099),
    [aux_sym_preproc_if_token1] = ACTIONS(3099),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3099),
    [sym_interpolation_verbatim_start] = ACTIONS(3099),
    [sym_interpolation_raw_start] = ACTIONS(3099),
    [sym_raw_string_start] = ACTIONS(3099),
  },
  [2686] = {
    [sym_preproc_region] = STATE(2686),
    [sym_preproc_endregion] = STATE(2686),
    [sym_preproc_line] = STATE(2686),
    [sym_preproc_pragma] = STATE(2686),
    [sym_preproc_nullable] = STATE(2686),
    [sym_preproc_error] = STATE(2686),
    [sym_preproc_warning] = STATE(2686),
    [sym_preproc_define] = STATE(2686),
    [sym_preproc_undef] = STATE(2686),
    [sym__identifier_token] = ACTIONS(3335),
    [anon_sym_extern] = ACTIONS(3335),
    [anon_sym_alias] = ACTIONS(3335),
    [anon_sym_SEMI] = ACTIONS(3337),
    [anon_sym_global] = ACTIONS(3335),
    [anon_sym_using] = ACTIONS(3335),
    [anon_sym_unsafe] = ACTIONS(3335),
    [anon_sym_static] = ACTIONS(3335),
    [anon_sym_LBRACK] = ACTIONS(3337),
    [anon_sym_LPAREN] = ACTIONS(3337),
    [anon_sym_return] = ACTIONS(3335),
    [anon_sym_ref] = ACTIONS(3335),
    [anon_sym_LBRACE] = ACTIONS(3337),
    [anon_sym_RBRACE] = ACTIONS(3337),
    [anon_sym_delegate] = ACTIONS(3335),
    [anon_sym_abstract] = ACTIONS(3335),
    [anon_sym_async] = ACTIONS(3335),
    [anon_sym_const] = ACTIONS(3335),
    [anon_sym_file] = ACTIONS(3335),
    [anon_sym_fixed] = ACTIONS(3335),
    [anon_sym_internal] = ACTIONS(3335),
    [anon_sym_new] = ACTIONS(3335),
    [anon_sym_override] = ACTIONS(3335),
    [anon_sym_partial] = ACTIONS(3335),
    [anon_sym_private] = ACTIONS(3335),
    [anon_sym_protected] = ACTIONS(3335),
    [anon_sym_public] = ACTIONS(3335),
    [anon_sym_readonly] = ACTIONS(3335),
    [anon_sym_required] = ACTIONS(3335),
    [anon_sym_sealed] = ACTIONS(3335),
    [anon_sym_virtual] = ACTIONS(3335),
    [anon_sym_volatile] = ACTIONS(3335),
    [anon_sym_where] = ACTIONS(3335),
    [anon_sym_notnull] = ACTIONS(3335),
    [anon_sym_unmanaged] = ACTIONS(3335),
    [anon_sym_checked] = ACTIONS(3335),
    [anon_sym_BANG] = ACTIONS(3337),
    [anon_sym_TILDE] = ACTIONS(3337),
    [anon_sym_PLUS_PLUS] = ACTIONS(3337),
    [anon_sym_DASH_DASH] = ACTIONS(3337),
    [anon_sym_true] = ACTIONS(3335),
    [anon_sym_false] = ACTIONS(3335),
    [anon_sym_PLUS] = ACTIONS(3335),
    [anon_sym_DASH] = ACTIONS(3335),
    [anon_sym_STAR] = ACTIONS(3337),
    [anon_sym_CARET] = ACTIONS(3337),
    [anon_sym_AMP] = ACTIONS(3337),
    [anon_sym_this] = ACTIONS(3335),
    [anon_sym_scoped] = ACTIONS(3335),
    [anon_sym_base] = ACTIONS(3335),
    [anon_sym_var] = ACTIONS(3335),
    [sym_predefined_type] = ACTIONS(3335),
    [anon_sym_break] = ACTIONS(3335),
    [anon_sym_unchecked] = ACTIONS(3335),
    [anon_sym_continue] = ACTIONS(3335),
    [anon_sym_do] = ACTIONS(3335),
    [anon_sym_while] = ACTIONS(3335),
    [anon_sym_for] = ACTIONS(3335),
    [anon_sym_lock] = ACTIONS(3335),
    [anon_sym_yield] = ACTIONS(3335),
    [anon_sym_switch] = ACTIONS(3335),
    [anon_sym_case] = ACTIONS(3335),
    [anon_sym_default] = ACTIONS(3335),
    [anon_sym_throw] = ACTIONS(3335),
    [anon_sym_try] = ACTIONS(3335),
    [anon_sym_when] = ACTIONS(3335),
    [anon_sym_await] = ACTIONS(3335),
    [anon_sym_foreach] = ACTIONS(3335),
    [anon_sym_goto] = ACTIONS(3335),
    [anon_sym_if] = ACTIONS(3335),
    [anon_sym_else] = ACTIONS(3335),
    [anon_sym_DOT_DOT] = ACTIONS(3337),
    [anon_sym_from] = ACTIONS(3335),
    [anon_sym_into] = ACTIONS(3335),
    [anon_sym_join] = ACTIONS(3335),
    [anon_sym_on] = ACTIONS(3335),
    [anon_sym_equals] = ACTIONS(3335),
    [anon_sym_let] = ACTIONS(3335),
    [anon_sym_orderby] = ACTIONS(3335),
    [anon_sym_ascending] = ACTIONS(3335),
    [anon_sym_descending] = ACTIONS(3335),
    [anon_sym_group] = ACTIONS(3335),
    [anon_sym_by] = ACTIONS(3335),
    [anon_sym_select] = ACTIONS(3335),
    [anon_sym_stackalloc] = ACTIONS(3335),
    [anon_sym_sizeof] = ACTIONS(3335),
    [anon_sym_typeof] = ACTIONS(3335),
    [anon_sym___makeref] = ACTIONS(3335),
    [anon_sym___reftype] = ACTIONS(3335),
    [anon_sym___refvalue] = ACTIONS(3335),
    [sym_null_literal] = ACTIONS(3335),
    [anon_sym_SQUOTE] = ACTIONS(3337),
    [sym_integer_literal] = ACTIONS(3335),
    [sym_real_literal] = ACTIONS(3337),
    [anon_sym_DQUOTE] = ACTIONS(3337),
    [sym_verbatim_string_literal] = ACTIONS(3337),
    [aux_sym_preproc_if_token1] = ACTIONS(3337),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3337),
    [sym_interpolation_verbatim_start] = ACTIONS(3337),
    [sym_interpolation_raw_start] = ACTIONS(3337),
    [sym_raw_string_start] = ACTIONS(3337),
  },
  [2687] = {
    [sym_preproc_region] = STATE(2687),
    [sym_preproc_endregion] = STATE(2687),
    [sym_preproc_line] = STATE(2687),
    [sym_preproc_pragma] = STATE(2687),
    [sym_preproc_nullable] = STATE(2687),
    [sym_preproc_error] = STATE(2687),
    [sym_preproc_warning] = STATE(2687),
    [sym_preproc_define] = STATE(2687),
    [sym_preproc_undef] = STATE(2687),
    [sym__identifier_token] = ACTIONS(3173),
    [anon_sym_extern] = ACTIONS(3173),
    [anon_sym_alias] = ACTIONS(3173),
    [anon_sym_SEMI] = ACTIONS(3175),
    [anon_sym_global] = ACTIONS(3173),
    [anon_sym_using] = ACTIONS(3173),
    [anon_sym_unsafe] = ACTIONS(3173),
    [anon_sym_static] = ACTIONS(3173),
    [anon_sym_LBRACK] = ACTIONS(3175),
    [anon_sym_LPAREN] = ACTIONS(3175),
    [anon_sym_return] = ACTIONS(3173),
    [anon_sym_ref] = ACTIONS(3173),
    [anon_sym_LBRACE] = ACTIONS(3175),
    [anon_sym_RBRACE] = ACTIONS(3175),
    [anon_sym_delegate] = ACTIONS(3173),
    [anon_sym_abstract] = ACTIONS(3173),
    [anon_sym_async] = ACTIONS(3173),
    [anon_sym_const] = ACTIONS(3173),
    [anon_sym_file] = ACTIONS(3173),
    [anon_sym_fixed] = ACTIONS(3173),
    [anon_sym_internal] = ACTIONS(3173),
    [anon_sym_new] = ACTIONS(3173),
    [anon_sym_override] = ACTIONS(3173),
    [anon_sym_partial] = ACTIONS(3173),
    [anon_sym_private] = ACTIONS(3173),
    [anon_sym_protected] = ACTIONS(3173),
    [anon_sym_public] = ACTIONS(3173),
    [anon_sym_readonly] = ACTIONS(3173),
    [anon_sym_required] = ACTIONS(3173),
    [anon_sym_sealed] = ACTIONS(3173),
    [anon_sym_virtual] = ACTIONS(3173),
    [anon_sym_volatile] = ACTIONS(3173),
    [anon_sym_where] = ACTIONS(3173),
    [anon_sym_notnull] = ACTIONS(3173),
    [anon_sym_unmanaged] = ACTIONS(3173),
    [anon_sym_checked] = ACTIONS(3173),
    [anon_sym_BANG] = ACTIONS(3175),
    [anon_sym_TILDE] = ACTIONS(3175),
    [anon_sym_PLUS_PLUS] = ACTIONS(3175),
    [anon_sym_DASH_DASH] = ACTIONS(3175),
    [anon_sym_true] = ACTIONS(3173),
    [anon_sym_false] = ACTIONS(3173),
    [anon_sym_PLUS] = ACTIONS(3173),
    [anon_sym_DASH] = ACTIONS(3173),
    [anon_sym_STAR] = ACTIONS(3175),
    [anon_sym_CARET] = ACTIONS(3175),
    [anon_sym_AMP] = ACTIONS(3175),
    [anon_sym_this] = ACTIONS(3173),
    [anon_sym_scoped] = ACTIONS(3173),
    [anon_sym_base] = ACTIONS(3173),
    [anon_sym_var] = ACTIONS(3173),
    [sym_predefined_type] = ACTIONS(3173),
    [anon_sym_break] = ACTIONS(3173),
    [anon_sym_unchecked] = ACTIONS(3173),
    [anon_sym_continue] = ACTIONS(3173),
    [anon_sym_do] = ACTIONS(3173),
    [anon_sym_while] = ACTIONS(3173),
    [anon_sym_for] = ACTIONS(3173),
    [anon_sym_lock] = ACTIONS(3173),
    [anon_sym_yield] = ACTIONS(3173),
    [anon_sym_switch] = ACTIONS(3173),
    [anon_sym_case] = ACTIONS(3173),
    [anon_sym_default] = ACTIONS(3173),
    [anon_sym_throw] = ACTIONS(3173),
    [anon_sym_try] = ACTIONS(3173),
    [anon_sym_when] = ACTIONS(3173),
    [anon_sym_await] = ACTIONS(3173),
    [anon_sym_foreach] = ACTIONS(3173),
    [anon_sym_goto] = ACTIONS(3173),
    [anon_sym_if] = ACTIONS(3173),
    [anon_sym_else] = ACTIONS(3173),
    [anon_sym_DOT_DOT] = ACTIONS(3175),
    [anon_sym_from] = ACTIONS(3173),
    [anon_sym_into] = ACTIONS(3173),
    [anon_sym_join] = ACTIONS(3173),
    [anon_sym_on] = ACTIONS(3173),
    [anon_sym_equals] = ACTIONS(3173),
    [anon_sym_let] = ACTIONS(3173),
    [anon_sym_orderby] = ACTIONS(3173),
    [anon_sym_ascending] = ACTIONS(3173),
    [anon_sym_descending] = ACTIONS(3173),
    [anon_sym_group] = ACTIONS(3173),
    [anon_sym_by] = ACTIONS(3173),
    [anon_sym_select] = ACTIONS(3173),
    [anon_sym_stackalloc] = ACTIONS(3173),
    [anon_sym_sizeof] = ACTIONS(3173),
    [anon_sym_typeof] = ACTIONS(3173),
    [anon_sym___makeref] = ACTIONS(3173),
    [anon_sym___reftype] = ACTIONS(3173),
    [anon_sym___refvalue] = ACTIONS(3173),
    [sym_null_literal] = ACTIONS(3173),
    [anon_sym_SQUOTE] = ACTIONS(3175),
    [sym_integer_literal] = ACTIONS(3173),
    [sym_real_literal] = ACTIONS(3175),
    [anon_sym_DQUOTE] = ACTIONS(3175),
    [sym_verbatim_string_literal] = ACTIONS(3175),
    [aux_sym_preproc_if_token1] = ACTIONS(3175),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3175),
    [sym_interpolation_verbatim_start] = ACTIONS(3175),
    [sym_interpolation_raw_start] = ACTIONS(3175),
    [sym_raw_string_start] = ACTIONS(3175),
  },
  [2688] = {
    [sym_preproc_region] = STATE(2688),
    [sym_preproc_endregion] = STATE(2688),
    [sym_preproc_line] = STATE(2688),
    [sym_preproc_pragma] = STATE(2688),
    [sym_preproc_nullable] = STATE(2688),
    [sym_preproc_error] = STATE(2688),
    [sym_preproc_warning] = STATE(2688),
    [sym_preproc_define] = STATE(2688),
    [sym_preproc_undef] = STATE(2688),
    [sym__identifier_token] = ACTIONS(3343),
    [anon_sym_extern] = ACTIONS(3343),
    [anon_sym_alias] = ACTIONS(3343),
    [anon_sym_SEMI] = ACTIONS(3345),
    [anon_sym_global] = ACTIONS(3343),
    [anon_sym_using] = ACTIONS(3343),
    [anon_sym_unsafe] = ACTIONS(3343),
    [anon_sym_static] = ACTIONS(3343),
    [anon_sym_LBRACK] = ACTIONS(3345),
    [anon_sym_LPAREN] = ACTIONS(3345),
    [anon_sym_return] = ACTIONS(3343),
    [anon_sym_ref] = ACTIONS(3343),
    [anon_sym_LBRACE] = ACTIONS(3345),
    [anon_sym_RBRACE] = ACTIONS(3345),
    [anon_sym_delegate] = ACTIONS(3343),
    [anon_sym_abstract] = ACTIONS(3343),
    [anon_sym_async] = ACTIONS(3343),
    [anon_sym_const] = ACTIONS(3343),
    [anon_sym_file] = ACTIONS(3343),
    [anon_sym_fixed] = ACTIONS(3343),
    [anon_sym_internal] = ACTIONS(3343),
    [anon_sym_new] = ACTIONS(3343),
    [anon_sym_override] = ACTIONS(3343),
    [anon_sym_partial] = ACTIONS(3343),
    [anon_sym_private] = ACTIONS(3343),
    [anon_sym_protected] = ACTIONS(3343),
    [anon_sym_public] = ACTIONS(3343),
    [anon_sym_readonly] = ACTIONS(3343),
    [anon_sym_required] = ACTIONS(3343),
    [anon_sym_sealed] = ACTIONS(3343),
    [anon_sym_virtual] = ACTIONS(3343),
    [anon_sym_volatile] = ACTIONS(3343),
    [anon_sym_where] = ACTIONS(3343),
    [anon_sym_notnull] = ACTIONS(3343),
    [anon_sym_unmanaged] = ACTIONS(3343),
    [anon_sym_checked] = ACTIONS(3343),
    [anon_sym_BANG] = ACTIONS(3345),
    [anon_sym_TILDE] = ACTIONS(3345),
    [anon_sym_PLUS_PLUS] = ACTIONS(3345),
    [anon_sym_DASH_DASH] = ACTIONS(3345),
    [anon_sym_true] = ACTIONS(3343),
    [anon_sym_false] = ACTIONS(3343),
    [anon_sym_PLUS] = ACTIONS(3343),
    [anon_sym_DASH] = ACTIONS(3343),
    [anon_sym_STAR] = ACTIONS(3345),
    [anon_sym_CARET] = ACTIONS(3345),
    [anon_sym_AMP] = ACTIONS(3345),
    [anon_sym_this] = ACTIONS(3343),
    [anon_sym_scoped] = ACTIONS(3343),
    [anon_sym_base] = ACTIONS(3343),
    [anon_sym_var] = ACTIONS(3343),
    [sym_predefined_type] = ACTIONS(3343),
    [anon_sym_break] = ACTIONS(3343),
    [anon_sym_unchecked] = ACTIONS(3343),
    [anon_sym_continue] = ACTIONS(3343),
    [anon_sym_do] = ACTIONS(3343),
    [anon_sym_while] = ACTIONS(3343),
    [anon_sym_for] = ACTIONS(3343),
    [anon_sym_lock] = ACTIONS(3343),
    [anon_sym_yield] = ACTIONS(3343),
    [anon_sym_switch] = ACTIONS(3343),
    [anon_sym_case] = ACTIONS(3343),
    [anon_sym_default] = ACTIONS(3343),
    [anon_sym_throw] = ACTIONS(3343),
    [anon_sym_try] = ACTIONS(3343),
    [anon_sym_when] = ACTIONS(3343),
    [anon_sym_await] = ACTIONS(3343),
    [anon_sym_foreach] = ACTIONS(3343),
    [anon_sym_goto] = ACTIONS(3343),
    [anon_sym_if] = ACTIONS(3343),
    [anon_sym_else] = ACTIONS(3343),
    [anon_sym_DOT_DOT] = ACTIONS(3345),
    [anon_sym_from] = ACTIONS(3343),
    [anon_sym_into] = ACTIONS(3343),
    [anon_sym_join] = ACTIONS(3343),
    [anon_sym_on] = ACTIONS(3343),
    [anon_sym_equals] = ACTIONS(3343),
    [anon_sym_let] = ACTIONS(3343),
    [anon_sym_orderby] = ACTIONS(3343),
    [anon_sym_ascending] = ACTIONS(3343),
    [anon_sym_descending] = ACTIONS(3343),
    [anon_sym_group] = ACTIONS(3343),
    [anon_sym_by] = ACTIONS(3343),
    [anon_sym_select] = ACTIONS(3343),
    [anon_sym_stackalloc] = ACTIONS(3343),
    [anon_sym_sizeof] = ACTIONS(3343),
    [anon_sym_typeof] = ACTIONS(3343),
    [anon_sym___makeref] = ACTIONS(3343),
    [anon_sym___reftype] = ACTIONS(3343),
    [anon_sym___refvalue] = ACTIONS(3343),
    [sym_null_literal] = ACTIONS(3343),
    [anon_sym_SQUOTE] = ACTIONS(3345),
    [sym_integer_literal] = ACTIONS(3343),
    [sym_real_literal] = ACTIONS(3345),
    [anon_sym_DQUOTE] = ACTIONS(3345),
    [sym_verbatim_string_literal] = ACTIONS(3345),
    [aux_sym_preproc_if_token1] = ACTIONS(3345),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3345),
    [sym_interpolation_verbatim_start] = ACTIONS(3345),
    [sym_interpolation_raw_start] = ACTIONS(3345),
    [sym_raw_string_start] = ACTIONS(3345),
  },
  [2689] = {
    [sym_preproc_region] = STATE(2689),
    [sym_preproc_endregion] = STATE(2689),
    [sym_preproc_line] = STATE(2689),
    [sym_preproc_pragma] = STATE(2689),
    [sym_preproc_nullable] = STATE(2689),
    [sym_preproc_error] = STATE(2689),
    [sym_preproc_warning] = STATE(2689),
    [sym_preproc_define] = STATE(2689),
    [sym_preproc_undef] = STATE(2689),
    [sym__identifier_token] = ACTIONS(3347),
    [anon_sym_extern] = ACTIONS(3347),
    [anon_sym_alias] = ACTIONS(3347),
    [anon_sym_SEMI] = ACTIONS(3349),
    [anon_sym_global] = ACTIONS(3347),
    [anon_sym_using] = ACTIONS(3347),
    [anon_sym_unsafe] = ACTIONS(3347),
    [anon_sym_static] = ACTIONS(3347),
    [anon_sym_LBRACK] = ACTIONS(3349),
    [anon_sym_LPAREN] = ACTIONS(3349),
    [anon_sym_return] = ACTIONS(3347),
    [anon_sym_ref] = ACTIONS(3347),
    [anon_sym_LBRACE] = ACTIONS(3349),
    [anon_sym_RBRACE] = ACTIONS(3349),
    [anon_sym_delegate] = ACTIONS(3347),
    [anon_sym_abstract] = ACTIONS(3347),
    [anon_sym_async] = ACTIONS(3347),
    [anon_sym_const] = ACTIONS(3347),
    [anon_sym_file] = ACTIONS(3347),
    [anon_sym_fixed] = ACTIONS(3347),
    [anon_sym_internal] = ACTIONS(3347),
    [anon_sym_new] = ACTIONS(3347),
    [anon_sym_override] = ACTIONS(3347),
    [anon_sym_partial] = ACTIONS(3347),
    [anon_sym_private] = ACTIONS(3347),
    [anon_sym_protected] = ACTIONS(3347),
    [anon_sym_public] = ACTIONS(3347),
    [anon_sym_readonly] = ACTIONS(3347),
    [anon_sym_required] = ACTIONS(3347),
    [anon_sym_sealed] = ACTIONS(3347),
    [anon_sym_virtual] = ACTIONS(3347),
    [anon_sym_volatile] = ACTIONS(3347),
    [anon_sym_where] = ACTIONS(3347),
    [anon_sym_notnull] = ACTIONS(3347),
    [anon_sym_unmanaged] = ACTIONS(3347),
    [anon_sym_checked] = ACTIONS(3347),
    [anon_sym_BANG] = ACTIONS(3349),
    [anon_sym_TILDE] = ACTIONS(3349),
    [anon_sym_PLUS_PLUS] = ACTIONS(3349),
    [anon_sym_DASH_DASH] = ACTIONS(3349),
    [anon_sym_true] = ACTIONS(3347),
    [anon_sym_false] = ACTIONS(3347),
    [anon_sym_PLUS] = ACTIONS(3347),
    [anon_sym_DASH] = ACTIONS(3347),
    [anon_sym_STAR] = ACTIONS(3349),
    [anon_sym_CARET] = ACTIONS(3349),
    [anon_sym_AMP] = ACTIONS(3349),
    [anon_sym_this] = ACTIONS(3347),
    [anon_sym_scoped] = ACTIONS(3347),
    [anon_sym_base] = ACTIONS(3347),
    [anon_sym_var] = ACTIONS(3347),
    [sym_predefined_type] = ACTIONS(3347),
    [anon_sym_break] = ACTIONS(3347),
    [anon_sym_unchecked] = ACTIONS(3347),
    [anon_sym_continue] = ACTIONS(3347),
    [anon_sym_do] = ACTIONS(3347),
    [anon_sym_while] = ACTIONS(3347),
    [anon_sym_for] = ACTIONS(3347),
    [anon_sym_lock] = ACTIONS(3347),
    [anon_sym_yield] = ACTIONS(3347),
    [anon_sym_switch] = ACTIONS(3347),
    [anon_sym_case] = ACTIONS(3347),
    [anon_sym_default] = ACTIONS(3347),
    [anon_sym_throw] = ACTIONS(3347),
    [anon_sym_try] = ACTIONS(3347),
    [anon_sym_when] = ACTIONS(3347),
    [anon_sym_await] = ACTIONS(3347),
    [anon_sym_foreach] = ACTIONS(3347),
    [anon_sym_goto] = ACTIONS(3347),
    [anon_sym_if] = ACTIONS(3347),
    [anon_sym_else] = ACTIONS(3347),
    [anon_sym_DOT_DOT] = ACTIONS(3349),
    [anon_sym_from] = ACTIONS(3347),
    [anon_sym_into] = ACTIONS(3347),
    [anon_sym_join] = ACTIONS(3347),
    [anon_sym_on] = ACTIONS(3347),
    [anon_sym_equals] = ACTIONS(3347),
    [anon_sym_let] = ACTIONS(3347),
    [anon_sym_orderby] = ACTIONS(3347),
    [anon_sym_ascending] = ACTIONS(3347),
    [anon_sym_descending] = ACTIONS(3347),
    [anon_sym_group] = ACTIONS(3347),
    [anon_sym_by] = ACTIONS(3347),
    [anon_sym_select] = ACTIONS(3347),
    [anon_sym_stackalloc] = ACTIONS(3347),
    [anon_sym_sizeof] = ACTIONS(3347),
    [anon_sym_typeof] = ACTIONS(3347),
    [anon_sym___makeref] = ACTIONS(3347),
    [anon_sym___reftype] = ACTIONS(3347),
    [anon_sym___refvalue] = ACTIONS(3347),
    [sym_null_literal] = ACTIONS(3347),
    [anon_sym_SQUOTE] = ACTIONS(3349),
    [sym_integer_literal] = ACTIONS(3347),
    [sym_real_literal] = ACTIONS(3349),
    [anon_sym_DQUOTE] = ACTIONS(3349),
    [sym_verbatim_string_literal] = ACTIONS(3349),
    [aux_sym_preproc_if_token1] = ACTIONS(3349),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3349),
    [sym_interpolation_verbatim_start] = ACTIONS(3349),
    [sym_interpolation_raw_start] = ACTIONS(3349),
    [sym_raw_string_start] = ACTIONS(3349),
  },
  [2690] = {
    [sym_preproc_region] = STATE(2690),
    [sym_preproc_endregion] = STATE(2690),
    [sym_preproc_line] = STATE(2690),
    [sym_preproc_pragma] = STATE(2690),
    [sym_preproc_nullable] = STATE(2690),
    [sym_preproc_error] = STATE(2690),
    [sym_preproc_warning] = STATE(2690),
    [sym_preproc_define] = STATE(2690),
    [sym_preproc_undef] = STATE(2690),
    [sym__identifier_token] = ACTIONS(3351),
    [anon_sym_extern] = ACTIONS(3351),
    [anon_sym_alias] = ACTIONS(3351),
    [anon_sym_SEMI] = ACTIONS(3353),
    [anon_sym_global] = ACTIONS(3351),
    [anon_sym_using] = ACTIONS(3351),
    [anon_sym_unsafe] = ACTIONS(3351),
    [anon_sym_static] = ACTIONS(3351),
    [anon_sym_LBRACK] = ACTIONS(3353),
    [anon_sym_LPAREN] = ACTIONS(3353),
    [anon_sym_return] = ACTIONS(3351),
    [anon_sym_ref] = ACTIONS(3351),
    [anon_sym_LBRACE] = ACTIONS(3353),
    [anon_sym_RBRACE] = ACTIONS(3353),
    [anon_sym_delegate] = ACTIONS(3351),
    [anon_sym_abstract] = ACTIONS(3351),
    [anon_sym_async] = ACTIONS(3351),
    [anon_sym_const] = ACTIONS(3351),
    [anon_sym_file] = ACTIONS(3351),
    [anon_sym_fixed] = ACTIONS(3351),
    [anon_sym_internal] = ACTIONS(3351),
    [anon_sym_new] = ACTIONS(3351),
    [anon_sym_override] = ACTIONS(3351),
    [anon_sym_partial] = ACTIONS(3351),
    [anon_sym_private] = ACTIONS(3351),
    [anon_sym_protected] = ACTIONS(3351),
    [anon_sym_public] = ACTIONS(3351),
    [anon_sym_readonly] = ACTIONS(3351),
    [anon_sym_required] = ACTIONS(3351),
    [anon_sym_sealed] = ACTIONS(3351),
    [anon_sym_virtual] = ACTIONS(3351),
    [anon_sym_volatile] = ACTIONS(3351),
    [anon_sym_where] = ACTIONS(3351),
    [anon_sym_notnull] = ACTIONS(3351),
    [anon_sym_unmanaged] = ACTIONS(3351),
    [anon_sym_checked] = ACTIONS(3351),
    [anon_sym_BANG] = ACTIONS(3353),
    [anon_sym_TILDE] = ACTIONS(3353),
    [anon_sym_PLUS_PLUS] = ACTIONS(3353),
    [anon_sym_DASH_DASH] = ACTIONS(3353),
    [anon_sym_true] = ACTIONS(3351),
    [anon_sym_false] = ACTIONS(3351),
    [anon_sym_PLUS] = ACTIONS(3351),
    [anon_sym_DASH] = ACTIONS(3351),
    [anon_sym_STAR] = ACTIONS(3353),
    [anon_sym_CARET] = ACTIONS(3353),
    [anon_sym_AMP] = ACTIONS(3353),
    [anon_sym_this] = ACTIONS(3351),
    [anon_sym_scoped] = ACTIONS(3351),
    [anon_sym_base] = ACTIONS(3351),
    [anon_sym_var] = ACTIONS(3351),
    [sym_predefined_type] = ACTIONS(3351),
    [anon_sym_break] = ACTIONS(3351),
    [anon_sym_unchecked] = ACTIONS(3351),
    [anon_sym_continue] = ACTIONS(3351),
    [anon_sym_do] = ACTIONS(3351),
    [anon_sym_while] = ACTIONS(3351),
    [anon_sym_for] = ACTIONS(3351),
    [anon_sym_lock] = ACTIONS(3351),
    [anon_sym_yield] = ACTIONS(3351),
    [anon_sym_switch] = ACTIONS(3351),
    [anon_sym_case] = ACTIONS(3351),
    [anon_sym_default] = ACTIONS(3351),
    [anon_sym_throw] = ACTIONS(3351),
    [anon_sym_try] = ACTIONS(3351),
    [anon_sym_when] = ACTIONS(3351),
    [anon_sym_await] = ACTIONS(3351),
    [anon_sym_foreach] = ACTIONS(3351),
    [anon_sym_goto] = ACTIONS(3351),
    [anon_sym_if] = ACTIONS(3351),
    [anon_sym_else] = ACTIONS(3351),
    [anon_sym_DOT_DOT] = ACTIONS(3353),
    [anon_sym_from] = ACTIONS(3351),
    [anon_sym_into] = ACTIONS(3351),
    [anon_sym_join] = ACTIONS(3351),
    [anon_sym_on] = ACTIONS(3351),
    [anon_sym_equals] = ACTIONS(3351),
    [anon_sym_let] = ACTIONS(3351),
    [anon_sym_orderby] = ACTIONS(3351),
    [anon_sym_ascending] = ACTIONS(3351),
    [anon_sym_descending] = ACTIONS(3351),
    [anon_sym_group] = ACTIONS(3351),
    [anon_sym_by] = ACTIONS(3351),
    [anon_sym_select] = ACTIONS(3351),
    [anon_sym_stackalloc] = ACTIONS(3351),
    [anon_sym_sizeof] = ACTIONS(3351),
    [anon_sym_typeof] = ACTIONS(3351),
    [anon_sym___makeref] = ACTIONS(3351),
    [anon_sym___reftype] = ACTIONS(3351),
    [anon_sym___refvalue] = ACTIONS(3351),
    [sym_null_literal] = ACTIONS(3351),
    [anon_sym_SQUOTE] = ACTIONS(3353),
    [sym_integer_literal] = ACTIONS(3351),
    [sym_real_literal] = ACTIONS(3353),
    [anon_sym_DQUOTE] = ACTIONS(3353),
    [sym_verbatim_string_literal] = ACTIONS(3353),
    [aux_sym_preproc_if_token1] = ACTIONS(3353),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3353),
    [sym_interpolation_verbatim_start] = ACTIONS(3353),
    [sym_interpolation_raw_start] = ACTIONS(3353),
    [sym_raw_string_start] = ACTIONS(3353),
  },
  [2691] = {
    [sym_preproc_region] = STATE(2691),
    [sym_preproc_endregion] = STATE(2691),
    [sym_preproc_line] = STATE(2691),
    [sym_preproc_pragma] = STATE(2691),
    [sym_preproc_nullable] = STATE(2691),
    [sym_preproc_error] = STATE(2691),
    [sym_preproc_warning] = STATE(2691),
    [sym_preproc_define] = STATE(2691),
    [sym_preproc_undef] = STATE(2691),
    [sym__identifier_token] = ACTIONS(3011),
    [anon_sym_extern] = ACTIONS(3011),
    [anon_sym_alias] = ACTIONS(3011),
    [anon_sym_SEMI] = ACTIONS(3013),
    [anon_sym_global] = ACTIONS(3011),
    [anon_sym_using] = ACTIONS(3011),
    [anon_sym_unsafe] = ACTIONS(3011),
    [anon_sym_static] = ACTIONS(3011),
    [anon_sym_LBRACK] = ACTIONS(3013),
    [anon_sym_LPAREN] = ACTIONS(3013),
    [anon_sym_return] = ACTIONS(3011),
    [anon_sym_ref] = ACTIONS(3011),
    [anon_sym_LBRACE] = ACTIONS(3013),
    [anon_sym_RBRACE] = ACTIONS(3013),
    [anon_sym_delegate] = ACTIONS(3011),
    [anon_sym_abstract] = ACTIONS(3011),
    [anon_sym_async] = ACTIONS(3011),
    [anon_sym_const] = ACTIONS(3011),
    [anon_sym_file] = ACTIONS(3011),
    [anon_sym_fixed] = ACTIONS(3011),
    [anon_sym_internal] = ACTIONS(3011),
    [anon_sym_new] = ACTIONS(3011),
    [anon_sym_override] = ACTIONS(3011),
    [anon_sym_partial] = ACTIONS(3011),
    [anon_sym_private] = ACTIONS(3011),
    [anon_sym_protected] = ACTIONS(3011),
    [anon_sym_public] = ACTIONS(3011),
    [anon_sym_readonly] = ACTIONS(3011),
    [anon_sym_required] = ACTIONS(3011),
    [anon_sym_sealed] = ACTIONS(3011),
    [anon_sym_virtual] = ACTIONS(3011),
    [anon_sym_volatile] = ACTIONS(3011),
    [anon_sym_where] = ACTIONS(3011),
    [anon_sym_notnull] = ACTIONS(3011),
    [anon_sym_unmanaged] = ACTIONS(3011),
    [anon_sym_checked] = ACTIONS(3011),
    [anon_sym_BANG] = ACTIONS(3013),
    [anon_sym_TILDE] = ACTIONS(3013),
    [anon_sym_PLUS_PLUS] = ACTIONS(3013),
    [anon_sym_DASH_DASH] = ACTIONS(3013),
    [anon_sym_true] = ACTIONS(3011),
    [anon_sym_false] = ACTIONS(3011),
    [anon_sym_PLUS] = ACTIONS(3011),
    [anon_sym_DASH] = ACTIONS(3011),
    [anon_sym_STAR] = ACTIONS(3013),
    [anon_sym_CARET] = ACTIONS(3013),
    [anon_sym_AMP] = ACTIONS(3013),
    [anon_sym_this] = ACTIONS(3011),
    [anon_sym_scoped] = ACTIONS(3011),
    [anon_sym_base] = ACTIONS(3011),
    [anon_sym_var] = ACTIONS(3011),
    [sym_predefined_type] = ACTIONS(3011),
    [anon_sym_break] = ACTIONS(3011),
    [anon_sym_unchecked] = ACTIONS(3011),
    [anon_sym_continue] = ACTIONS(3011),
    [anon_sym_do] = ACTIONS(3011),
    [anon_sym_while] = ACTIONS(3011),
    [anon_sym_for] = ACTIONS(3011),
    [anon_sym_lock] = ACTIONS(3011),
    [anon_sym_yield] = ACTIONS(3011),
    [anon_sym_switch] = ACTIONS(3011),
    [anon_sym_case] = ACTIONS(3011),
    [anon_sym_default] = ACTIONS(3011),
    [anon_sym_throw] = ACTIONS(3011),
    [anon_sym_try] = ACTIONS(3011),
    [anon_sym_when] = ACTIONS(3011),
    [anon_sym_await] = ACTIONS(3011),
    [anon_sym_foreach] = ACTIONS(3011),
    [anon_sym_goto] = ACTIONS(3011),
    [anon_sym_if] = ACTIONS(3011),
    [anon_sym_else] = ACTIONS(3011),
    [anon_sym_DOT_DOT] = ACTIONS(3013),
    [anon_sym_from] = ACTIONS(3011),
    [anon_sym_into] = ACTIONS(3011),
    [anon_sym_join] = ACTIONS(3011),
    [anon_sym_on] = ACTIONS(3011),
    [anon_sym_equals] = ACTIONS(3011),
    [anon_sym_let] = ACTIONS(3011),
    [anon_sym_orderby] = ACTIONS(3011),
    [anon_sym_ascending] = ACTIONS(3011),
    [anon_sym_descending] = ACTIONS(3011),
    [anon_sym_group] = ACTIONS(3011),
    [anon_sym_by] = ACTIONS(3011),
    [anon_sym_select] = ACTIONS(3011),
    [anon_sym_stackalloc] = ACTIONS(3011),
    [anon_sym_sizeof] = ACTIONS(3011),
    [anon_sym_typeof] = ACTIONS(3011),
    [anon_sym___makeref] = ACTIONS(3011),
    [anon_sym___reftype] = ACTIONS(3011),
    [anon_sym___refvalue] = ACTIONS(3011),
    [sym_null_literal] = ACTIONS(3011),
    [anon_sym_SQUOTE] = ACTIONS(3013),
    [sym_integer_literal] = ACTIONS(3011),
    [sym_real_literal] = ACTIONS(3013),
    [anon_sym_DQUOTE] = ACTIONS(3013),
    [sym_verbatim_string_literal] = ACTIONS(3013),
    [aux_sym_preproc_if_token1] = ACTIONS(3013),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3013),
    [sym_interpolation_verbatim_start] = ACTIONS(3013),
    [sym_interpolation_raw_start] = ACTIONS(3013),
    [sym_raw_string_start] = ACTIONS(3013),
  },
  [2692] = {
    [sym_preproc_region] = STATE(2692),
    [sym_preproc_endregion] = STATE(2692),
    [sym_preproc_line] = STATE(2692),
    [sym_preproc_pragma] = STATE(2692),
    [sym_preproc_nullable] = STATE(2692),
    [sym_preproc_error] = STATE(2692),
    [sym_preproc_warning] = STATE(2692),
    [sym_preproc_define] = STATE(2692),
    [sym_preproc_undef] = STATE(2692),
    [sym__identifier_token] = ACTIONS(3113),
    [anon_sym_extern] = ACTIONS(3113),
    [anon_sym_alias] = ACTIONS(3113),
    [anon_sym_SEMI] = ACTIONS(3115),
    [anon_sym_global] = ACTIONS(3113),
    [anon_sym_using] = ACTIONS(3113),
    [anon_sym_unsafe] = ACTIONS(3113),
    [anon_sym_static] = ACTIONS(3113),
    [anon_sym_LBRACK] = ACTIONS(3115),
    [anon_sym_LPAREN] = ACTIONS(3115),
    [anon_sym_return] = ACTIONS(3113),
    [anon_sym_ref] = ACTIONS(3113),
    [anon_sym_LBRACE] = ACTIONS(3115),
    [anon_sym_RBRACE] = ACTIONS(3115),
    [anon_sym_delegate] = ACTIONS(3113),
    [anon_sym_abstract] = ACTIONS(3113),
    [anon_sym_async] = ACTIONS(3113),
    [anon_sym_const] = ACTIONS(3113),
    [anon_sym_file] = ACTIONS(3113),
    [anon_sym_fixed] = ACTIONS(3113),
    [anon_sym_internal] = ACTIONS(3113),
    [anon_sym_new] = ACTIONS(3113),
    [anon_sym_override] = ACTIONS(3113),
    [anon_sym_partial] = ACTIONS(3113),
    [anon_sym_private] = ACTIONS(3113),
    [anon_sym_protected] = ACTIONS(3113),
    [anon_sym_public] = ACTIONS(3113),
    [anon_sym_readonly] = ACTIONS(3113),
    [anon_sym_required] = ACTIONS(3113),
    [anon_sym_sealed] = ACTIONS(3113),
    [anon_sym_virtual] = ACTIONS(3113),
    [anon_sym_volatile] = ACTIONS(3113),
    [anon_sym_where] = ACTIONS(3113),
    [anon_sym_notnull] = ACTIONS(3113),
    [anon_sym_unmanaged] = ACTIONS(3113),
    [anon_sym_checked] = ACTIONS(3113),
    [anon_sym_BANG] = ACTIONS(3115),
    [anon_sym_TILDE] = ACTIONS(3115),
    [anon_sym_PLUS_PLUS] = ACTIONS(3115),
    [anon_sym_DASH_DASH] = ACTIONS(3115),
    [anon_sym_true] = ACTIONS(3113),
    [anon_sym_false] = ACTIONS(3113),
    [anon_sym_PLUS] = ACTIONS(3113),
    [anon_sym_DASH] = ACTIONS(3113),
    [anon_sym_STAR] = ACTIONS(3115),
    [anon_sym_CARET] = ACTIONS(3115),
    [anon_sym_AMP] = ACTIONS(3115),
    [anon_sym_this] = ACTIONS(3113),
    [anon_sym_scoped] = ACTIONS(3113),
    [anon_sym_base] = ACTIONS(3113),
    [anon_sym_var] = ACTIONS(3113),
    [sym_predefined_type] = ACTIONS(3113),
    [anon_sym_break] = ACTIONS(3113),
    [anon_sym_unchecked] = ACTIONS(3113),
    [anon_sym_continue] = ACTIONS(3113),
    [anon_sym_do] = ACTIONS(3113),
    [anon_sym_while] = ACTIONS(3113),
    [anon_sym_for] = ACTIONS(3113),
    [anon_sym_lock] = ACTIONS(3113),
    [anon_sym_yield] = ACTIONS(3113),
    [anon_sym_switch] = ACTIONS(3113),
    [anon_sym_case] = ACTIONS(3113),
    [anon_sym_default] = ACTIONS(3113),
    [anon_sym_throw] = ACTIONS(3113),
    [anon_sym_try] = ACTIONS(3113),
    [anon_sym_when] = ACTIONS(3113),
    [anon_sym_await] = ACTIONS(3113),
    [anon_sym_foreach] = ACTIONS(3113),
    [anon_sym_goto] = ACTIONS(3113),
    [anon_sym_if] = ACTIONS(3113),
    [anon_sym_else] = ACTIONS(3113),
    [anon_sym_DOT_DOT] = ACTIONS(3115),
    [anon_sym_from] = ACTIONS(3113),
    [anon_sym_into] = ACTIONS(3113),
    [anon_sym_join] = ACTIONS(3113),
    [anon_sym_on] = ACTIONS(3113),
    [anon_sym_equals] = ACTIONS(3113),
    [anon_sym_let] = ACTIONS(3113),
    [anon_sym_orderby] = ACTIONS(3113),
    [anon_sym_ascending] = ACTIONS(3113),
    [anon_sym_descending] = ACTIONS(3113),
    [anon_sym_group] = ACTIONS(3113),
    [anon_sym_by] = ACTIONS(3113),
    [anon_sym_select] = ACTIONS(3113),
    [anon_sym_stackalloc] = ACTIONS(3113),
    [anon_sym_sizeof] = ACTIONS(3113),
    [anon_sym_typeof] = ACTIONS(3113),
    [anon_sym___makeref] = ACTIONS(3113),
    [anon_sym___reftype] = ACTIONS(3113),
    [anon_sym___refvalue] = ACTIONS(3113),
    [sym_null_literal] = ACTIONS(3113),
    [anon_sym_SQUOTE] = ACTIONS(3115),
    [sym_integer_literal] = ACTIONS(3113),
    [sym_real_literal] = ACTIONS(3115),
    [anon_sym_DQUOTE] = ACTIONS(3115),
    [sym_verbatim_string_literal] = ACTIONS(3115),
    [aux_sym_preproc_if_token1] = ACTIONS(3115),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3115),
    [sym_interpolation_verbatim_start] = ACTIONS(3115),
    [sym_interpolation_raw_start] = ACTIONS(3115),
    [sym_raw_string_start] = ACTIONS(3115),
  },
  [2693] = {
    [sym_preproc_region] = STATE(2693),
    [sym_preproc_endregion] = STATE(2693),
    [sym_preproc_line] = STATE(2693),
    [sym_preproc_pragma] = STATE(2693),
    [sym_preproc_nullable] = STATE(2693),
    [sym_preproc_error] = STATE(2693),
    [sym_preproc_warning] = STATE(2693),
    [sym_preproc_define] = STATE(2693),
    [sym_preproc_undef] = STATE(2693),
    [sym__identifier_token] = ACTIONS(3117),
    [anon_sym_extern] = ACTIONS(3117),
    [anon_sym_alias] = ACTIONS(3117),
    [anon_sym_SEMI] = ACTIONS(3119),
    [anon_sym_global] = ACTIONS(3117),
    [anon_sym_using] = ACTIONS(3117),
    [anon_sym_unsafe] = ACTIONS(3117),
    [anon_sym_static] = ACTIONS(3117),
    [anon_sym_LBRACK] = ACTIONS(3119),
    [anon_sym_LPAREN] = ACTIONS(3119),
    [anon_sym_return] = ACTIONS(3117),
    [anon_sym_ref] = ACTIONS(3117),
    [anon_sym_LBRACE] = ACTIONS(3119),
    [anon_sym_RBRACE] = ACTIONS(3119),
    [anon_sym_delegate] = ACTIONS(3117),
    [anon_sym_abstract] = ACTIONS(3117),
    [anon_sym_async] = ACTIONS(3117),
    [anon_sym_const] = ACTIONS(3117),
    [anon_sym_file] = ACTIONS(3117),
    [anon_sym_fixed] = ACTIONS(3117),
    [anon_sym_internal] = ACTIONS(3117),
    [anon_sym_new] = ACTIONS(3117),
    [anon_sym_override] = ACTIONS(3117),
    [anon_sym_partial] = ACTIONS(3117),
    [anon_sym_private] = ACTIONS(3117),
    [anon_sym_protected] = ACTIONS(3117),
    [anon_sym_public] = ACTIONS(3117),
    [anon_sym_readonly] = ACTIONS(3117),
    [anon_sym_required] = ACTIONS(3117),
    [anon_sym_sealed] = ACTIONS(3117),
    [anon_sym_virtual] = ACTIONS(3117),
    [anon_sym_volatile] = ACTIONS(3117),
    [anon_sym_where] = ACTIONS(3117),
    [anon_sym_notnull] = ACTIONS(3117),
    [anon_sym_unmanaged] = ACTIONS(3117),
    [anon_sym_checked] = ACTIONS(3117),
    [anon_sym_BANG] = ACTIONS(3119),
    [anon_sym_TILDE] = ACTIONS(3119),
    [anon_sym_PLUS_PLUS] = ACTIONS(3119),
    [anon_sym_DASH_DASH] = ACTIONS(3119),
    [anon_sym_true] = ACTIONS(3117),
    [anon_sym_false] = ACTIONS(3117),
    [anon_sym_PLUS] = ACTIONS(3117),
    [anon_sym_DASH] = ACTIONS(3117),
    [anon_sym_STAR] = ACTIONS(3119),
    [anon_sym_CARET] = ACTIONS(3119),
    [anon_sym_AMP] = ACTIONS(3119),
    [anon_sym_this] = ACTIONS(3117),
    [anon_sym_scoped] = ACTIONS(3117),
    [anon_sym_base] = ACTIONS(3117),
    [anon_sym_var] = ACTIONS(3117),
    [sym_predefined_type] = ACTIONS(3117),
    [anon_sym_break] = ACTIONS(3117),
    [anon_sym_unchecked] = ACTIONS(3117),
    [anon_sym_continue] = ACTIONS(3117),
    [anon_sym_do] = ACTIONS(3117),
    [anon_sym_while] = ACTIONS(3117),
    [anon_sym_for] = ACTIONS(3117),
    [anon_sym_lock] = ACTIONS(3117),
    [anon_sym_yield] = ACTIONS(3117),
    [anon_sym_switch] = ACTIONS(3117),
    [anon_sym_case] = ACTIONS(3117),
    [anon_sym_default] = ACTIONS(3117),
    [anon_sym_throw] = ACTIONS(3117),
    [anon_sym_try] = ACTIONS(3117),
    [anon_sym_when] = ACTIONS(3117),
    [anon_sym_await] = ACTIONS(3117),
    [anon_sym_foreach] = ACTIONS(3117),
    [anon_sym_goto] = ACTIONS(3117),
    [anon_sym_if] = ACTIONS(3117),
    [anon_sym_else] = ACTIONS(3117),
    [anon_sym_DOT_DOT] = ACTIONS(3119),
    [anon_sym_from] = ACTIONS(3117),
    [anon_sym_into] = ACTIONS(3117),
    [anon_sym_join] = ACTIONS(3117),
    [anon_sym_on] = ACTIONS(3117),
    [anon_sym_equals] = ACTIONS(3117),
    [anon_sym_let] = ACTIONS(3117),
    [anon_sym_orderby] = ACTIONS(3117),
    [anon_sym_ascending] = ACTIONS(3117),
    [anon_sym_descending] = ACTIONS(3117),
    [anon_sym_group] = ACTIONS(3117),
    [anon_sym_by] = ACTIONS(3117),
    [anon_sym_select] = ACTIONS(3117),
    [anon_sym_stackalloc] = ACTIONS(3117),
    [anon_sym_sizeof] = ACTIONS(3117),
    [anon_sym_typeof] = ACTIONS(3117),
    [anon_sym___makeref] = ACTIONS(3117),
    [anon_sym___reftype] = ACTIONS(3117),
    [anon_sym___refvalue] = ACTIONS(3117),
    [sym_null_literal] = ACTIONS(3117),
    [anon_sym_SQUOTE] = ACTIONS(3119),
    [sym_integer_literal] = ACTIONS(3117),
    [sym_real_literal] = ACTIONS(3119),
    [anon_sym_DQUOTE] = ACTIONS(3119),
    [sym_verbatim_string_literal] = ACTIONS(3119),
    [aux_sym_preproc_if_token1] = ACTIONS(3119),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3119),
    [sym_interpolation_verbatim_start] = ACTIONS(3119),
    [sym_interpolation_raw_start] = ACTIONS(3119),
    [sym_raw_string_start] = ACTIONS(3119),
  },
  [2694] = {
    [sym_preproc_region] = STATE(2694),
    [sym_preproc_endregion] = STATE(2694),
    [sym_preproc_line] = STATE(2694),
    [sym_preproc_pragma] = STATE(2694),
    [sym_preproc_nullable] = STATE(2694),
    [sym_preproc_error] = STATE(2694),
    [sym_preproc_warning] = STATE(2694),
    [sym_preproc_define] = STATE(2694),
    [sym_preproc_undef] = STATE(2694),
    [sym__identifier_token] = ACTIONS(3121),
    [anon_sym_extern] = ACTIONS(3121),
    [anon_sym_alias] = ACTIONS(3121),
    [anon_sym_SEMI] = ACTIONS(3123),
    [anon_sym_global] = ACTIONS(3121),
    [anon_sym_using] = ACTIONS(3121),
    [anon_sym_unsafe] = ACTIONS(3121),
    [anon_sym_static] = ACTIONS(3121),
    [anon_sym_LBRACK] = ACTIONS(3123),
    [anon_sym_LPAREN] = ACTIONS(3123),
    [anon_sym_return] = ACTIONS(3121),
    [anon_sym_ref] = ACTIONS(3121),
    [anon_sym_LBRACE] = ACTIONS(3123),
    [anon_sym_RBRACE] = ACTIONS(3123),
    [anon_sym_delegate] = ACTIONS(3121),
    [anon_sym_abstract] = ACTIONS(3121),
    [anon_sym_async] = ACTIONS(3121),
    [anon_sym_const] = ACTIONS(3121),
    [anon_sym_file] = ACTIONS(3121),
    [anon_sym_fixed] = ACTIONS(3121),
    [anon_sym_internal] = ACTIONS(3121),
    [anon_sym_new] = ACTIONS(3121),
    [anon_sym_override] = ACTIONS(3121),
    [anon_sym_partial] = ACTIONS(3121),
    [anon_sym_private] = ACTIONS(3121),
    [anon_sym_protected] = ACTIONS(3121),
    [anon_sym_public] = ACTIONS(3121),
    [anon_sym_readonly] = ACTIONS(3121),
    [anon_sym_required] = ACTIONS(3121),
    [anon_sym_sealed] = ACTIONS(3121),
    [anon_sym_virtual] = ACTIONS(3121),
    [anon_sym_volatile] = ACTIONS(3121),
    [anon_sym_where] = ACTIONS(3121),
    [anon_sym_notnull] = ACTIONS(3121),
    [anon_sym_unmanaged] = ACTIONS(3121),
    [anon_sym_checked] = ACTIONS(3121),
    [anon_sym_BANG] = ACTIONS(3123),
    [anon_sym_TILDE] = ACTIONS(3123),
    [anon_sym_PLUS_PLUS] = ACTIONS(3123),
    [anon_sym_DASH_DASH] = ACTIONS(3123),
    [anon_sym_true] = ACTIONS(3121),
    [anon_sym_false] = ACTIONS(3121),
    [anon_sym_PLUS] = ACTIONS(3121),
    [anon_sym_DASH] = ACTIONS(3121),
    [anon_sym_STAR] = ACTIONS(3123),
    [anon_sym_CARET] = ACTIONS(3123),
    [anon_sym_AMP] = ACTIONS(3123),
    [anon_sym_this] = ACTIONS(3121),
    [anon_sym_scoped] = ACTIONS(3121),
    [anon_sym_base] = ACTIONS(3121),
    [anon_sym_var] = ACTIONS(3121),
    [sym_predefined_type] = ACTIONS(3121),
    [anon_sym_break] = ACTIONS(3121),
    [anon_sym_unchecked] = ACTIONS(3121),
    [anon_sym_continue] = ACTIONS(3121),
    [anon_sym_do] = ACTIONS(3121),
    [anon_sym_while] = ACTIONS(3121),
    [anon_sym_for] = ACTIONS(3121),
    [anon_sym_lock] = ACTIONS(3121),
    [anon_sym_yield] = ACTIONS(3121),
    [anon_sym_switch] = ACTIONS(3121),
    [anon_sym_case] = ACTIONS(3121),
    [anon_sym_default] = ACTIONS(3121),
    [anon_sym_throw] = ACTIONS(3121),
    [anon_sym_try] = ACTIONS(3121),
    [anon_sym_when] = ACTIONS(3121),
    [anon_sym_await] = ACTIONS(3121),
    [anon_sym_foreach] = ACTIONS(3121),
    [anon_sym_goto] = ACTIONS(3121),
    [anon_sym_if] = ACTIONS(3121),
    [anon_sym_else] = ACTIONS(3121),
    [anon_sym_DOT_DOT] = ACTIONS(3123),
    [anon_sym_from] = ACTIONS(3121),
    [anon_sym_into] = ACTIONS(3121),
    [anon_sym_join] = ACTIONS(3121),
    [anon_sym_on] = ACTIONS(3121),
    [anon_sym_equals] = ACTIONS(3121),
    [anon_sym_let] = ACTIONS(3121),
    [anon_sym_orderby] = ACTIONS(3121),
    [anon_sym_ascending] = ACTIONS(3121),
    [anon_sym_descending] = ACTIONS(3121),
    [anon_sym_group] = ACTIONS(3121),
    [anon_sym_by] = ACTIONS(3121),
    [anon_sym_select] = ACTIONS(3121),
    [anon_sym_stackalloc] = ACTIONS(3121),
    [anon_sym_sizeof] = ACTIONS(3121),
    [anon_sym_typeof] = ACTIONS(3121),
    [anon_sym___makeref] = ACTIONS(3121),
    [anon_sym___reftype] = ACTIONS(3121),
    [anon_sym___refvalue] = ACTIONS(3121),
    [sym_null_literal] = ACTIONS(3121),
    [anon_sym_SQUOTE] = ACTIONS(3123),
    [sym_integer_literal] = ACTIONS(3121),
    [sym_real_literal] = ACTIONS(3123),
    [anon_sym_DQUOTE] = ACTIONS(3123),
    [sym_verbatim_string_literal] = ACTIONS(3123),
    [aux_sym_preproc_if_token1] = ACTIONS(3123),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3123),
    [sym_interpolation_verbatim_start] = ACTIONS(3123),
    [sym_interpolation_raw_start] = ACTIONS(3123),
    [sym_raw_string_start] = ACTIONS(3123),
  },
  [2695] = {
    [sym_preproc_region] = STATE(2695),
    [sym_preproc_endregion] = STATE(2695),
    [sym_preproc_line] = STATE(2695),
    [sym_preproc_pragma] = STATE(2695),
    [sym_preproc_nullable] = STATE(2695),
    [sym_preproc_error] = STATE(2695),
    [sym_preproc_warning] = STATE(2695),
    [sym_preproc_define] = STATE(2695),
    [sym_preproc_undef] = STATE(2695),
    [sym__identifier_token] = ACTIONS(3125),
    [anon_sym_extern] = ACTIONS(3125),
    [anon_sym_alias] = ACTIONS(3125),
    [anon_sym_SEMI] = ACTIONS(3127),
    [anon_sym_global] = ACTIONS(3125),
    [anon_sym_using] = ACTIONS(3125),
    [anon_sym_unsafe] = ACTIONS(3125),
    [anon_sym_static] = ACTIONS(3125),
    [anon_sym_LBRACK] = ACTIONS(3127),
    [anon_sym_LPAREN] = ACTIONS(3127),
    [anon_sym_return] = ACTIONS(3125),
    [anon_sym_ref] = ACTIONS(3125),
    [anon_sym_LBRACE] = ACTIONS(3127),
    [anon_sym_RBRACE] = ACTIONS(3127),
    [anon_sym_delegate] = ACTIONS(3125),
    [anon_sym_abstract] = ACTIONS(3125),
    [anon_sym_async] = ACTIONS(3125),
    [anon_sym_const] = ACTIONS(3125),
    [anon_sym_file] = ACTIONS(3125),
    [anon_sym_fixed] = ACTIONS(3125),
    [anon_sym_internal] = ACTIONS(3125),
    [anon_sym_new] = ACTIONS(3125),
    [anon_sym_override] = ACTIONS(3125),
    [anon_sym_partial] = ACTIONS(3125),
    [anon_sym_private] = ACTIONS(3125),
    [anon_sym_protected] = ACTIONS(3125),
    [anon_sym_public] = ACTIONS(3125),
    [anon_sym_readonly] = ACTIONS(3125),
    [anon_sym_required] = ACTIONS(3125),
    [anon_sym_sealed] = ACTIONS(3125),
    [anon_sym_virtual] = ACTIONS(3125),
    [anon_sym_volatile] = ACTIONS(3125),
    [anon_sym_where] = ACTIONS(3125),
    [anon_sym_notnull] = ACTIONS(3125),
    [anon_sym_unmanaged] = ACTIONS(3125),
    [anon_sym_checked] = ACTIONS(3125),
    [anon_sym_BANG] = ACTIONS(3127),
    [anon_sym_TILDE] = ACTIONS(3127),
    [anon_sym_PLUS_PLUS] = ACTIONS(3127),
    [anon_sym_DASH_DASH] = ACTIONS(3127),
    [anon_sym_true] = ACTIONS(3125),
    [anon_sym_false] = ACTIONS(3125),
    [anon_sym_PLUS] = ACTIONS(3125),
    [anon_sym_DASH] = ACTIONS(3125),
    [anon_sym_STAR] = ACTIONS(3127),
    [anon_sym_CARET] = ACTIONS(3127),
    [anon_sym_AMP] = ACTIONS(3127),
    [anon_sym_this] = ACTIONS(3125),
    [anon_sym_scoped] = ACTIONS(3125),
    [anon_sym_base] = ACTIONS(3125),
    [anon_sym_var] = ACTIONS(3125),
    [sym_predefined_type] = ACTIONS(3125),
    [anon_sym_break] = ACTIONS(3125),
    [anon_sym_unchecked] = ACTIONS(3125),
    [anon_sym_continue] = ACTIONS(3125),
    [anon_sym_do] = ACTIONS(3125),
    [anon_sym_while] = ACTIONS(3125),
    [anon_sym_for] = ACTIONS(3125),
    [anon_sym_lock] = ACTIONS(3125),
    [anon_sym_yield] = ACTIONS(3125),
    [anon_sym_switch] = ACTIONS(3125),
    [anon_sym_case] = ACTIONS(3125),
    [anon_sym_default] = ACTIONS(3125),
    [anon_sym_throw] = ACTIONS(3125),
    [anon_sym_try] = ACTIONS(3125),
    [anon_sym_when] = ACTIONS(3125),
    [anon_sym_await] = ACTIONS(3125),
    [anon_sym_foreach] = ACTIONS(3125),
    [anon_sym_goto] = ACTIONS(3125),
    [anon_sym_if] = ACTIONS(3125),
    [anon_sym_else] = ACTIONS(3125),
    [anon_sym_DOT_DOT] = ACTIONS(3127),
    [anon_sym_from] = ACTIONS(3125),
    [anon_sym_into] = ACTIONS(3125),
    [anon_sym_join] = ACTIONS(3125),
    [anon_sym_on] = ACTIONS(3125),
    [anon_sym_equals] = ACTIONS(3125),
    [anon_sym_let] = ACTIONS(3125),
    [anon_sym_orderby] = ACTIONS(3125),
    [anon_sym_ascending] = ACTIONS(3125),
    [anon_sym_descending] = ACTIONS(3125),
    [anon_sym_group] = ACTIONS(3125),
    [anon_sym_by] = ACTIONS(3125),
    [anon_sym_select] = ACTIONS(3125),
    [anon_sym_stackalloc] = ACTIONS(3125),
    [anon_sym_sizeof] = ACTIONS(3125),
    [anon_sym_typeof] = ACTIONS(3125),
    [anon_sym___makeref] = ACTIONS(3125),
    [anon_sym___reftype] = ACTIONS(3125),
    [anon_sym___refvalue] = ACTIONS(3125),
    [sym_null_literal] = ACTIONS(3125),
    [anon_sym_SQUOTE] = ACTIONS(3127),
    [sym_integer_literal] = ACTIONS(3125),
    [sym_real_literal] = ACTIONS(3127),
    [anon_sym_DQUOTE] = ACTIONS(3127),
    [sym_verbatim_string_literal] = ACTIONS(3127),
    [aux_sym_preproc_if_token1] = ACTIONS(3127),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3127),
    [sym_interpolation_verbatim_start] = ACTIONS(3127),
    [sym_interpolation_raw_start] = ACTIONS(3127),
    [sym_raw_string_start] = ACTIONS(3127),
  },
  [2696] = {
    [sym_preproc_region] = STATE(2696),
    [sym_preproc_endregion] = STATE(2696),
    [sym_preproc_line] = STATE(2696),
    [sym_preproc_pragma] = STATE(2696),
    [sym_preproc_nullable] = STATE(2696),
    [sym_preproc_error] = STATE(2696),
    [sym_preproc_warning] = STATE(2696),
    [sym_preproc_define] = STATE(2696),
    [sym_preproc_undef] = STATE(2696),
    [sym__identifier_token] = ACTIONS(3365),
    [anon_sym_extern] = ACTIONS(3365),
    [anon_sym_alias] = ACTIONS(3365),
    [anon_sym_SEMI] = ACTIONS(3367),
    [anon_sym_global] = ACTIONS(3365),
    [anon_sym_using] = ACTIONS(3365),
    [anon_sym_unsafe] = ACTIONS(3365),
    [anon_sym_static] = ACTIONS(3365),
    [anon_sym_LBRACK] = ACTIONS(3367),
    [anon_sym_LPAREN] = ACTIONS(3367),
    [anon_sym_return] = ACTIONS(3365),
    [anon_sym_ref] = ACTIONS(3365),
    [anon_sym_LBRACE] = ACTIONS(3367),
    [anon_sym_RBRACE] = ACTIONS(3367),
    [anon_sym_delegate] = ACTIONS(3365),
    [anon_sym_abstract] = ACTIONS(3365),
    [anon_sym_async] = ACTIONS(3365),
    [anon_sym_const] = ACTIONS(3365),
    [anon_sym_file] = ACTIONS(3365),
    [anon_sym_fixed] = ACTIONS(3365),
    [anon_sym_internal] = ACTIONS(3365),
    [anon_sym_new] = ACTIONS(3365),
    [anon_sym_override] = ACTIONS(3365),
    [anon_sym_partial] = ACTIONS(3365),
    [anon_sym_private] = ACTIONS(3365),
    [anon_sym_protected] = ACTIONS(3365),
    [anon_sym_public] = ACTIONS(3365),
    [anon_sym_readonly] = ACTIONS(3365),
    [anon_sym_required] = ACTIONS(3365),
    [anon_sym_sealed] = ACTIONS(3365),
    [anon_sym_virtual] = ACTIONS(3365),
    [anon_sym_volatile] = ACTIONS(3365),
    [anon_sym_where] = ACTIONS(3365),
    [anon_sym_notnull] = ACTIONS(3365),
    [anon_sym_unmanaged] = ACTIONS(3365),
    [anon_sym_checked] = ACTIONS(3365),
    [anon_sym_BANG] = ACTIONS(3367),
    [anon_sym_TILDE] = ACTIONS(3367),
    [anon_sym_PLUS_PLUS] = ACTIONS(3367),
    [anon_sym_DASH_DASH] = ACTIONS(3367),
    [anon_sym_true] = ACTIONS(3365),
    [anon_sym_false] = ACTIONS(3365),
    [anon_sym_PLUS] = ACTIONS(3365),
    [anon_sym_DASH] = ACTIONS(3365),
    [anon_sym_STAR] = ACTIONS(3367),
    [anon_sym_CARET] = ACTIONS(3367),
    [anon_sym_AMP] = ACTIONS(3367),
    [anon_sym_this] = ACTIONS(3365),
    [anon_sym_scoped] = ACTIONS(3365),
    [anon_sym_base] = ACTIONS(3365),
    [anon_sym_var] = ACTIONS(3365),
    [sym_predefined_type] = ACTIONS(3365),
    [anon_sym_break] = ACTIONS(3365),
    [anon_sym_unchecked] = ACTIONS(3365),
    [anon_sym_continue] = ACTIONS(3365),
    [anon_sym_do] = ACTIONS(3365),
    [anon_sym_while] = ACTIONS(3365),
    [anon_sym_for] = ACTIONS(3365),
    [anon_sym_lock] = ACTIONS(3365),
    [anon_sym_yield] = ACTIONS(3365),
    [anon_sym_switch] = ACTIONS(3365),
    [anon_sym_case] = ACTIONS(3365),
    [anon_sym_default] = ACTIONS(3365),
    [anon_sym_throw] = ACTIONS(3365),
    [anon_sym_try] = ACTIONS(3365),
    [anon_sym_when] = ACTIONS(3365),
    [anon_sym_await] = ACTIONS(3365),
    [anon_sym_foreach] = ACTIONS(3365),
    [anon_sym_goto] = ACTIONS(3365),
    [anon_sym_if] = ACTIONS(3365),
    [anon_sym_else] = ACTIONS(3365),
    [anon_sym_DOT_DOT] = ACTIONS(3367),
    [anon_sym_from] = ACTIONS(3365),
    [anon_sym_into] = ACTIONS(3365),
    [anon_sym_join] = ACTIONS(3365),
    [anon_sym_on] = ACTIONS(3365),
    [anon_sym_equals] = ACTIONS(3365),
    [anon_sym_let] = ACTIONS(3365),
    [anon_sym_orderby] = ACTIONS(3365),
    [anon_sym_ascending] = ACTIONS(3365),
    [anon_sym_descending] = ACTIONS(3365),
    [anon_sym_group] = ACTIONS(3365),
    [anon_sym_by] = ACTIONS(3365),
    [anon_sym_select] = ACTIONS(3365),
    [anon_sym_stackalloc] = ACTIONS(3365),
    [anon_sym_sizeof] = ACTIONS(3365),
    [anon_sym_typeof] = ACTIONS(3365),
    [anon_sym___makeref] = ACTIONS(3365),
    [anon_sym___reftype] = ACTIONS(3365),
    [anon_sym___refvalue] = ACTIONS(3365),
    [sym_null_literal] = ACTIONS(3365),
    [anon_sym_SQUOTE] = ACTIONS(3367),
    [sym_integer_literal] = ACTIONS(3365),
    [sym_real_literal] = ACTIONS(3367),
    [anon_sym_DQUOTE] = ACTIONS(3367),
    [sym_verbatim_string_literal] = ACTIONS(3367),
    [aux_sym_preproc_if_token1] = ACTIONS(3367),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3367),
    [sym_interpolation_verbatim_start] = ACTIONS(3367),
    [sym_interpolation_raw_start] = ACTIONS(3367),
    [sym_raw_string_start] = ACTIONS(3367),
  },
  [2697] = {
    [sym_preproc_region] = STATE(2697),
    [sym_preproc_endregion] = STATE(2697),
    [sym_preproc_line] = STATE(2697),
    [sym_preproc_pragma] = STATE(2697),
    [sym_preproc_nullable] = STATE(2697),
    [sym_preproc_error] = STATE(2697),
    [sym_preproc_warning] = STATE(2697),
    [sym_preproc_define] = STATE(2697),
    [sym_preproc_undef] = STATE(2697),
    [sym__identifier_token] = ACTIONS(3369),
    [anon_sym_extern] = ACTIONS(3369),
    [anon_sym_alias] = ACTIONS(3369),
    [anon_sym_SEMI] = ACTIONS(3371),
    [anon_sym_global] = ACTIONS(3369),
    [anon_sym_using] = ACTIONS(3369),
    [anon_sym_unsafe] = ACTIONS(3369),
    [anon_sym_static] = ACTIONS(3369),
    [anon_sym_LBRACK] = ACTIONS(3371),
    [anon_sym_LPAREN] = ACTIONS(3371),
    [anon_sym_return] = ACTIONS(3369),
    [anon_sym_ref] = ACTIONS(3369),
    [anon_sym_LBRACE] = ACTIONS(3371),
    [anon_sym_RBRACE] = ACTIONS(3371),
    [anon_sym_delegate] = ACTIONS(3369),
    [anon_sym_abstract] = ACTIONS(3369),
    [anon_sym_async] = ACTIONS(3369),
    [anon_sym_const] = ACTIONS(3369),
    [anon_sym_file] = ACTIONS(3369),
    [anon_sym_fixed] = ACTIONS(3369),
    [anon_sym_internal] = ACTIONS(3369),
    [anon_sym_new] = ACTIONS(3369),
    [anon_sym_override] = ACTIONS(3369),
    [anon_sym_partial] = ACTIONS(3369),
    [anon_sym_private] = ACTIONS(3369),
    [anon_sym_protected] = ACTIONS(3369),
    [anon_sym_public] = ACTIONS(3369),
    [anon_sym_readonly] = ACTIONS(3369),
    [anon_sym_required] = ACTIONS(3369),
    [anon_sym_sealed] = ACTIONS(3369),
    [anon_sym_virtual] = ACTIONS(3369),
    [anon_sym_volatile] = ACTIONS(3369),
    [anon_sym_where] = ACTIONS(3369),
    [anon_sym_notnull] = ACTIONS(3369),
    [anon_sym_unmanaged] = ACTIONS(3369),
    [anon_sym_checked] = ACTIONS(3369),
    [anon_sym_BANG] = ACTIONS(3371),
    [anon_sym_TILDE] = ACTIONS(3371),
    [anon_sym_PLUS_PLUS] = ACTIONS(3371),
    [anon_sym_DASH_DASH] = ACTIONS(3371),
    [anon_sym_true] = ACTIONS(3369),
    [anon_sym_false] = ACTIONS(3369),
    [anon_sym_PLUS] = ACTIONS(3369),
    [anon_sym_DASH] = ACTIONS(3369),
    [anon_sym_STAR] = ACTIONS(3371),
    [anon_sym_CARET] = ACTIONS(3371),
    [anon_sym_AMP] = ACTIONS(3371),
    [anon_sym_this] = ACTIONS(3369),
    [anon_sym_scoped] = ACTIONS(3369),
    [anon_sym_base] = ACTIONS(3369),
    [anon_sym_var] = ACTIONS(3369),
    [sym_predefined_type] = ACTIONS(3369),
    [anon_sym_break] = ACTIONS(3369),
    [anon_sym_unchecked] = ACTIONS(3369),
    [anon_sym_continue] = ACTIONS(3369),
    [anon_sym_do] = ACTIONS(3369),
    [anon_sym_while] = ACTIONS(3369),
    [anon_sym_for] = ACTIONS(3369),
    [anon_sym_lock] = ACTIONS(3369),
    [anon_sym_yield] = ACTIONS(3369),
    [anon_sym_switch] = ACTIONS(3369),
    [anon_sym_case] = ACTIONS(3369),
    [anon_sym_default] = ACTIONS(3369),
    [anon_sym_throw] = ACTIONS(3369),
    [anon_sym_try] = ACTIONS(3369),
    [anon_sym_when] = ACTIONS(3369),
    [anon_sym_await] = ACTIONS(3369),
    [anon_sym_foreach] = ACTIONS(3369),
    [anon_sym_goto] = ACTIONS(3369),
    [anon_sym_if] = ACTIONS(3369),
    [anon_sym_else] = ACTIONS(3369),
    [anon_sym_DOT_DOT] = ACTIONS(3371),
    [anon_sym_from] = ACTIONS(3369),
    [anon_sym_into] = ACTIONS(3369),
    [anon_sym_join] = ACTIONS(3369),
    [anon_sym_on] = ACTIONS(3369),
    [anon_sym_equals] = ACTIONS(3369),
    [anon_sym_let] = ACTIONS(3369),
    [anon_sym_orderby] = ACTIONS(3369),
    [anon_sym_ascending] = ACTIONS(3369),
    [anon_sym_descending] = ACTIONS(3369),
    [anon_sym_group] = ACTIONS(3369),
    [anon_sym_by] = ACTIONS(3369),
    [anon_sym_select] = ACTIONS(3369),
    [anon_sym_stackalloc] = ACTIONS(3369),
    [anon_sym_sizeof] = ACTIONS(3369),
    [anon_sym_typeof] = ACTIONS(3369),
    [anon_sym___makeref] = ACTIONS(3369),
    [anon_sym___reftype] = ACTIONS(3369),
    [anon_sym___refvalue] = ACTIONS(3369),
    [sym_null_literal] = ACTIONS(3369),
    [anon_sym_SQUOTE] = ACTIONS(3371),
    [sym_integer_literal] = ACTIONS(3369),
    [sym_real_literal] = ACTIONS(3371),
    [anon_sym_DQUOTE] = ACTIONS(3371),
    [sym_verbatim_string_literal] = ACTIONS(3371),
    [aux_sym_preproc_if_token1] = ACTIONS(3371),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3371),
    [sym_interpolation_verbatim_start] = ACTIONS(3371),
    [sym_interpolation_raw_start] = ACTIONS(3371),
    [sym_raw_string_start] = ACTIONS(3371),
  },
  [2698] = {
    [sym_preproc_region] = STATE(2698),
    [sym_preproc_endregion] = STATE(2698),
    [sym_preproc_line] = STATE(2698),
    [sym_preproc_pragma] = STATE(2698),
    [sym_preproc_nullable] = STATE(2698),
    [sym_preproc_error] = STATE(2698),
    [sym_preproc_warning] = STATE(2698),
    [sym_preproc_define] = STATE(2698),
    [sym_preproc_undef] = STATE(2698),
    [sym__identifier_token] = ACTIONS(3129),
    [anon_sym_extern] = ACTIONS(3129),
    [anon_sym_alias] = ACTIONS(3129),
    [anon_sym_SEMI] = ACTIONS(3131),
    [anon_sym_global] = ACTIONS(3129),
    [anon_sym_using] = ACTIONS(3129),
    [anon_sym_unsafe] = ACTIONS(3129),
    [anon_sym_static] = ACTIONS(3129),
    [anon_sym_LBRACK] = ACTIONS(3131),
    [anon_sym_LPAREN] = ACTIONS(3131),
    [anon_sym_return] = ACTIONS(3129),
    [anon_sym_ref] = ACTIONS(3129),
    [anon_sym_LBRACE] = ACTIONS(3131),
    [anon_sym_RBRACE] = ACTIONS(3131),
    [anon_sym_delegate] = ACTIONS(3129),
    [anon_sym_abstract] = ACTIONS(3129),
    [anon_sym_async] = ACTIONS(3129),
    [anon_sym_const] = ACTIONS(3129),
    [anon_sym_file] = ACTIONS(3129),
    [anon_sym_fixed] = ACTIONS(3129),
    [anon_sym_internal] = ACTIONS(3129),
    [anon_sym_new] = ACTIONS(3129),
    [anon_sym_override] = ACTIONS(3129),
    [anon_sym_partial] = ACTIONS(3129),
    [anon_sym_private] = ACTIONS(3129),
    [anon_sym_protected] = ACTIONS(3129),
    [anon_sym_public] = ACTIONS(3129),
    [anon_sym_readonly] = ACTIONS(3129),
    [anon_sym_required] = ACTIONS(3129),
    [anon_sym_sealed] = ACTIONS(3129),
    [anon_sym_virtual] = ACTIONS(3129),
    [anon_sym_volatile] = ACTIONS(3129),
    [anon_sym_where] = ACTIONS(3129),
    [anon_sym_notnull] = ACTIONS(3129),
    [anon_sym_unmanaged] = ACTIONS(3129),
    [anon_sym_checked] = ACTIONS(3129),
    [anon_sym_BANG] = ACTIONS(3131),
    [anon_sym_TILDE] = ACTIONS(3131),
    [anon_sym_PLUS_PLUS] = ACTIONS(3131),
    [anon_sym_DASH_DASH] = ACTIONS(3131),
    [anon_sym_true] = ACTIONS(3129),
    [anon_sym_false] = ACTIONS(3129),
    [anon_sym_PLUS] = ACTIONS(3129),
    [anon_sym_DASH] = ACTIONS(3129),
    [anon_sym_STAR] = ACTIONS(3131),
    [anon_sym_CARET] = ACTIONS(3131),
    [anon_sym_AMP] = ACTIONS(3131),
    [anon_sym_this] = ACTIONS(3129),
    [anon_sym_scoped] = ACTIONS(3129),
    [anon_sym_base] = ACTIONS(3129),
    [anon_sym_var] = ACTIONS(3129),
    [sym_predefined_type] = ACTIONS(3129),
    [anon_sym_break] = ACTIONS(3129),
    [anon_sym_unchecked] = ACTIONS(3129),
    [anon_sym_continue] = ACTIONS(3129),
    [anon_sym_do] = ACTIONS(3129),
    [anon_sym_while] = ACTIONS(3129),
    [anon_sym_for] = ACTIONS(3129),
    [anon_sym_lock] = ACTIONS(3129),
    [anon_sym_yield] = ACTIONS(3129),
    [anon_sym_switch] = ACTIONS(3129),
    [anon_sym_case] = ACTIONS(3129),
    [anon_sym_default] = ACTIONS(3129),
    [anon_sym_throw] = ACTIONS(3129),
    [anon_sym_try] = ACTIONS(3129),
    [anon_sym_when] = ACTIONS(3129),
    [anon_sym_await] = ACTIONS(3129),
    [anon_sym_foreach] = ACTIONS(3129),
    [anon_sym_goto] = ACTIONS(3129),
    [anon_sym_if] = ACTIONS(3129),
    [anon_sym_else] = ACTIONS(3129),
    [anon_sym_DOT_DOT] = ACTIONS(3131),
    [anon_sym_from] = ACTIONS(3129),
    [anon_sym_into] = ACTIONS(3129),
    [anon_sym_join] = ACTIONS(3129),
    [anon_sym_on] = ACTIONS(3129),
    [anon_sym_equals] = ACTIONS(3129),
    [anon_sym_let] = ACTIONS(3129),
    [anon_sym_orderby] = ACTIONS(3129),
    [anon_sym_ascending] = ACTIONS(3129),
    [anon_sym_descending] = ACTIONS(3129),
    [anon_sym_group] = ACTIONS(3129),
    [anon_sym_by] = ACTIONS(3129),
    [anon_sym_select] = ACTIONS(3129),
    [anon_sym_stackalloc] = ACTIONS(3129),
    [anon_sym_sizeof] = ACTIONS(3129),
    [anon_sym_typeof] = ACTIONS(3129),
    [anon_sym___makeref] = ACTIONS(3129),
    [anon_sym___reftype] = ACTIONS(3129),
    [anon_sym___refvalue] = ACTIONS(3129),
    [sym_null_literal] = ACTIONS(3129),
    [anon_sym_SQUOTE] = ACTIONS(3131),
    [sym_integer_literal] = ACTIONS(3129),
    [sym_real_literal] = ACTIONS(3131),
    [anon_sym_DQUOTE] = ACTIONS(3131),
    [sym_verbatim_string_literal] = ACTIONS(3131),
    [aux_sym_preproc_if_token1] = ACTIONS(3131),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3131),
    [sym_interpolation_verbatim_start] = ACTIONS(3131),
    [sym_interpolation_raw_start] = ACTIONS(3131),
    [sym_raw_string_start] = ACTIONS(3131),
  },
  [2699] = {
    [sym_preproc_region] = STATE(2699),
    [sym_preproc_endregion] = STATE(2699),
    [sym_preproc_line] = STATE(2699),
    [sym_preproc_pragma] = STATE(2699),
    [sym_preproc_nullable] = STATE(2699),
    [sym_preproc_error] = STATE(2699),
    [sym_preproc_warning] = STATE(2699),
    [sym_preproc_define] = STATE(2699),
    [sym_preproc_undef] = STATE(2699),
    [sym__identifier_token] = ACTIONS(3133),
    [anon_sym_extern] = ACTIONS(3133),
    [anon_sym_alias] = ACTIONS(3133),
    [anon_sym_SEMI] = ACTIONS(3135),
    [anon_sym_global] = ACTIONS(3133),
    [anon_sym_using] = ACTIONS(3133),
    [anon_sym_unsafe] = ACTIONS(3133),
    [anon_sym_static] = ACTIONS(3133),
    [anon_sym_LBRACK] = ACTIONS(3135),
    [anon_sym_LPAREN] = ACTIONS(3135),
    [anon_sym_return] = ACTIONS(3133),
    [anon_sym_ref] = ACTIONS(3133),
    [anon_sym_LBRACE] = ACTIONS(3135),
    [anon_sym_RBRACE] = ACTIONS(3135),
    [anon_sym_delegate] = ACTIONS(3133),
    [anon_sym_abstract] = ACTIONS(3133),
    [anon_sym_async] = ACTIONS(3133),
    [anon_sym_const] = ACTIONS(3133),
    [anon_sym_file] = ACTIONS(3133),
    [anon_sym_fixed] = ACTIONS(3133),
    [anon_sym_internal] = ACTIONS(3133),
    [anon_sym_new] = ACTIONS(3133),
    [anon_sym_override] = ACTIONS(3133),
    [anon_sym_partial] = ACTIONS(3133),
    [anon_sym_private] = ACTIONS(3133),
    [anon_sym_protected] = ACTIONS(3133),
    [anon_sym_public] = ACTIONS(3133),
    [anon_sym_readonly] = ACTIONS(3133),
    [anon_sym_required] = ACTIONS(3133),
    [anon_sym_sealed] = ACTIONS(3133),
    [anon_sym_virtual] = ACTIONS(3133),
    [anon_sym_volatile] = ACTIONS(3133),
    [anon_sym_where] = ACTIONS(3133),
    [anon_sym_notnull] = ACTIONS(3133),
    [anon_sym_unmanaged] = ACTIONS(3133),
    [anon_sym_checked] = ACTIONS(3133),
    [anon_sym_BANG] = ACTIONS(3135),
    [anon_sym_TILDE] = ACTIONS(3135),
    [anon_sym_PLUS_PLUS] = ACTIONS(3135),
    [anon_sym_DASH_DASH] = ACTIONS(3135),
    [anon_sym_true] = ACTIONS(3133),
    [anon_sym_false] = ACTIONS(3133),
    [anon_sym_PLUS] = ACTIONS(3133),
    [anon_sym_DASH] = ACTIONS(3133),
    [anon_sym_STAR] = ACTIONS(3135),
    [anon_sym_CARET] = ACTIONS(3135),
    [anon_sym_AMP] = ACTIONS(3135),
    [anon_sym_this] = ACTIONS(3133),
    [anon_sym_scoped] = ACTIONS(3133),
    [anon_sym_base] = ACTIONS(3133),
    [anon_sym_var] = ACTIONS(3133),
    [sym_predefined_type] = ACTIONS(3133),
    [anon_sym_break] = ACTIONS(3133),
    [anon_sym_unchecked] = ACTIONS(3133),
    [anon_sym_continue] = ACTIONS(3133),
    [anon_sym_do] = ACTIONS(3133),
    [anon_sym_while] = ACTIONS(3133),
    [anon_sym_for] = ACTIONS(3133),
    [anon_sym_lock] = ACTIONS(3133),
    [anon_sym_yield] = ACTIONS(3133),
    [anon_sym_switch] = ACTIONS(3133),
    [anon_sym_case] = ACTIONS(3133),
    [anon_sym_default] = ACTIONS(3133),
    [anon_sym_throw] = ACTIONS(3133),
    [anon_sym_try] = ACTIONS(3133),
    [anon_sym_when] = ACTIONS(3133),
    [anon_sym_await] = ACTIONS(3133),
    [anon_sym_foreach] = ACTIONS(3133),
    [anon_sym_goto] = ACTIONS(3133),
    [anon_sym_if] = ACTIONS(3133),
    [anon_sym_else] = ACTIONS(3133),
    [anon_sym_DOT_DOT] = ACTIONS(3135),
    [anon_sym_from] = ACTIONS(3133),
    [anon_sym_into] = ACTIONS(3133),
    [anon_sym_join] = ACTIONS(3133),
    [anon_sym_on] = ACTIONS(3133),
    [anon_sym_equals] = ACTIONS(3133),
    [anon_sym_let] = ACTIONS(3133),
    [anon_sym_orderby] = ACTIONS(3133),
    [anon_sym_ascending] = ACTIONS(3133),
    [anon_sym_descending] = ACTIONS(3133),
    [anon_sym_group] = ACTIONS(3133),
    [anon_sym_by] = ACTIONS(3133),
    [anon_sym_select] = ACTIONS(3133),
    [anon_sym_stackalloc] = ACTIONS(3133),
    [anon_sym_sizeof] = ACTIONS(3133),
    [anon_sym_typeof] = ACTIONS(3133),
    [anon_sym___makeref] = ACTIONS(3133),
    [anon_sym___reftype] = ACTIONS(3133),
    [anon_sym___refvalue] = ACTIONS(3133),
    [sym_null_literal] = ACTIONS(3133),
    [anon_sym_SQUOTE] = ACTIONS(3135),
    [sym_integer_literal] = ACTIONS(3133),
    [sym_real_literal] = ACTIONS(3135),
    [anon_sym_DQUOTE] = ACTIONS(3135),
    [sym_verbatim_string_literal] = ACTIONS(3135),
    [aux_sym_preproc_if_token1] = ACTIONS(3135),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3135),
    [sym_interpolation_verbatim_start] = ACTIONS(3135),
    [sym_interpolation_raw_start] = ACTIONS(3135),
    [sym_raw_string_start] = ACTIONS(3135),
  },
  [2700] = {
    [sym_preproc_region] = STATE(2700),
    [sym_preproc_endregion] = STATE(2700),
    [sym_preproc_line] = STATE(2700),
    [sym_preproc_pragma] = STATE(2700),
    [sym_preproc_nullable] = STATE(2700),
    [sym_preproc_error] = STATE(2700),
    [sym_preproc_warning] = STATE(2700),
    [sym_preproc_define] = STATE(2700),
    [sym_preproc_undef] = STATE(2700),
    [sym__identifier_token] = ACTIONS(3137),
    [anon_sym_extern] = ACTIONS(3137),
    [anon_sym_alias] = ACTIONS(3137),
    [anon_sym_SEMI] = ACTIONS(3139),
    [anon_sym_global] = ACTIONS(3137),
    [anon_sym_using] = ACTIONS(3137),
    [anon_sym_unsafe] = ACTIONS(3137),
    [anon_sym_static] = ACTIONS(3137),
    [anon_sym_LBRACK] = ACTIONS(3139),
    [anon_sym_LPAREN] = ACTIONS(3139),
    [anon_sym_return] = ACTIONS(3137),
    [anon_sym_ref] = ACTIONS(3137),
    [anon_sym_LBRACE] = ACTIONS(3139),
    [anon_sym_RBRACE] = ACTIONS(3139),
    [anon_sym_delegate] = ACTIONS(3137),
    [anon_sym_abstract] = ACTIONS(3137),
    [anon_sym_async] = ACTIONS(3137),
    [anon_sym_const] = ACTIONS(3137),
    [anon_sym_file] = ACTIONS(3137),
    [anon_sym_fixed] = ACTIONS(3137),
    [anon_sym_internal] = ACTIONS(3137),
    [anon_sym_new] = ACTIONS(3137),
    [anon_sym_override] = ACTIONS(3137),
    [anon_sym_partial] = ACTIONS(3137),
    [anon_sym_private] = ACTIONS(3137),
    [anon_sym_protected] = ACTIONS(3137),
    [anon_sym_public] = ACTIONS(3137),
    [anon_sym_readonly] = ACTIONS(3137),
    [anon_sym_required] = ACTIONS(3137),
    [anon_sym_sealed] = ACTIONS(3137),
    [anon_sym_virtual] = ACTIONS(3137),
    [anon_sym_volatile] = ACTIONS(3137),
    [anon_sym_where] = ACTIONS(3137),
    [anon_sym_notnull] = ACTIONS(3137),
    [anon_sym_unmanaged] = ACTIONS(3137),
    [anon_sym_checked] = ACTIONS(3137),
    [anon_sym_BANG] = ACTIONS(3139),
    [anon_sym_TILDE] = ACTIONS(3139),
    [anon_sym_PLUS_PLUS] = ACTIONS(3139),
    [anon_sym_DASH_DASH] = ACTIONS(3139),
    [anon_sym_true] = ACTIONS(3137),
    [anon_sym_false] = ACTIONS(3137),
    [anon_sym_PLUS] = ACTIONS(3137),
    [anon_sym_DASH] = ACTIONS(3137),
    [anon_sym_STAR] = ACTIONS(3139),
    [anon_sym_CARET] = ACTIONS(3139),
    [anon_sym_AMP] = ACTIONS(3139),
    [anon_sym_this] = ACTIONS(3137),
    [anon_sym_scoped] = ACTIONS(3137),
    [anon_sym_base] = ACTIONS(3137),
    [anon_sym_var] = ACTIONS(3137),
    [sym_predefined_type] = ACTIONS(3137),
    [anon_sym_break] = ACTIONS(3137),
    [anon_sym_unchecked] = ACTIONS(3137),
    [anon_sym_continue] = ACTIONS(3137),
    [anon_sym_do] = ACTIONS(3137),
    [anon_sym_while] = ACTIONS(3137),
    [anon_sym_for] = ACTIONS(3137),
    [anon_sym_lock] = ACTIONS(3137),
    [anon_sym_yield] = ACTIONS(3137),
    [anon_sym_switch] = ACTIONS(3137),
    [anon_sym_case] = ACTIONS(3137),
    [anon_sym_default] = ACTIONS(3137),
    [anon_sym_throw] = ACTIONS(3137),
    [anon_sym_try] = ACTIONS(3137),
    [anon_sym_when] = ACTIONS(3137),
    [anon_sym_await] = ACTIONS(3137),
    [anon_sym_foreach] = ACTIONS(3137),
    [anon_sym_goto] = ACTIONS(3137),
    [anon_sym_if] = ACTIONS(3137),
    [anon_sym_else] = ACTIONS(3137),
    [anon_sym_DOT_DOT] = ACTIONS(3139),
    [anon_sym_from] = ACTIONS(3137),
    [anon_sym_into] = ACTIONS(3137),
    [anon_sym_join] = ACTIONS(3137),
    [anon_sym_on] = ACTIONS(3137),
    [anon_sym_equals] = ACTIONS(3137),
    [anon_sym_let] = ACTIONS(3137),
    [anon_sym_orderby] = ACTIONS(3137),
    [anon_sym_ascending] = ACTIONS(3137),
    [anon_sym_descending] = ACTIONS(3137),
    [anon_sym_group] = ACTIONS(3137),
    [anon_sym_by] = ACTIONS(3137),
    [anon_sym_select] = ACTIONS(3137),
    [anon_sym_stackalloc] = ACTIONS(3137),
    [anon_sym_sizeof] = ACTIONS(3137),
    [anon_sym_typeof] = ACTIONS(3137),
    [anon_sym___makeref] = ACTIONS(3137),
    [anon_sym___reftype] = ACTIONS(3137),
    [anon_sym___refvalue] = ACTIONS(3137),
    [sym_null_literal] = ACTIONS(3137),
    [anon_sym_SQUOTE] = ACTIONS(3139),
    [sym_integer_literal] = ACTIONS(3137),
    [sym_real_literal] = ACTIONS(3139),
    [anon_sym_DQUOTE] = ACTIONS(3139),
    [sym_verbatim_string_literal] = ACTIONS(3139),
    [aux_sym_preproc_if_token1] = ACTIONS(3139),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3139),
    [sym_interpolation_verbatim_start] = ACTIONS(3139),
    [sym_interpolation_raw_start] = ACTIONS(3139),
    [sym_raw_string_start] = ACTIONS(3139),
  },
  [2701] = {
    [sym_preproc_region] = STATE(2701),
    [sym_preproc_endregion] = STATE(2701),
    [sym_preproc_line] = STATE(2701),
    [sym_preproc_pragma] = STATE(2701),
    [sym_preproc_nullable] = STATE(2701),
    [sym_preproc_error] = STATE(2701),
    [sym_preproc_warning] = STATE(2701),
    [sym_preproc_define] = STATE(2701),
    [sym_preproc_undef] = STATE(2701),
    [sym__identifier_token] = ACTIONS(3373),
    [anon_sym_extern] = ACTIONS(3373),
    [anon_sym_alias] = ACTIONS(3373),
    [anon_sym_SEMI] = ACTIONS(3375),
    [anon_sym_global] = ACTIONS(3373),
    [anon_sym_using] = ACTIONS(3373),
    [anon_sym_unsafe] = ACTIONS(3373),
    [anon_sym_static] = ACTIONS(3373),
    [anon_sym_LBRACK] = ACTIONS(3375),
    [anon_sym_LPAREN] = ACTIONS(3375),
    [anon_sym_return] = ACTIONS(3373),
    [anon_sym_ref] = ACTIONS(3373),
    [anon_sym_LBRACE] = ACTIONS(3375),
    [anon_sym_RBRACE] = ACTIONS(3375),
    [anon_sym_delegate] = ACTIONS(3373),
    [anon_sym_abstract] = ACTIONS(3373),
    [anon_sym_async] = ACTIONS(3373),
    [anon_sym_const] = ACTIONS(3373),
    [anon_sym_file] = ACTIONS(3373),
    [anon_sym_fixed] = ACTIONS(3373),
    [anon_sym_internal] = ACTIONS(3373),
    [anon_sym_new] = ACTIONS(3373),
    [anon_sym_override] = ACTIONS(3373),
    [anon_sym_partial] = ACTIONS(3373),
    [anon_sym_private] = ACTIONS(3373),
    [anon_sym_protected] = ACTIONS(3373),
    [anon_sym_public] = ACTIONS(3373),
    [anon_sym_readonly] = ACTIONS(3373),
    [anon_sym_required] = ACTIONS(3373),
    [anon_sym_sealed] = ACTIONS(3373),
    [anon_sym_virtual] = ACTIONS(3373),
    [anon_sym_volatile] = ACTIONS(3373),
    [anon_sym_where] = ACTIONS(3373),
    [anon_sym_notnull] = ACTIONS(3373),
    [anon_sym_unmanaged] = ACTIONS(3373),
    [anon_sym_checked] = ACTIONS(3373),
    [anon_sym_BANG] = ACTIONS(3375),
    [anon_sym_TILDE] = ACTIONS(3375),
    [anon_sym_PLUS_PLUS] = ACTIONS(3375),
    [anon_sym_DASH_DASH] = ACTIONS(3375),
    [anon_sym_true] = ACTIONS(3373),
    [anon_sym_false] = ACTIONS(3373),
    [anon_sym_PLUS] = ACTIONS(3373),
    [anon_sym_DASH] = ACTIONS(3373),
    [anon_sym_STAR] = ACTIONS(3375),
    [anon_sym_CARET] = ACTIONS(3375),
    [anon_sym_AMP] = ACTIONS(3375),
    [anon_sym_this] = ACTIONS(3373),
    [anon_sym_scoped] = ACTIONS(3373),
    [anon_sym_base] = ACTIONS(3373),
    [anon_sym_var] = ACTIONS(3373),
    [sym_predefined_type] = ACTIONS(3373),
    [anon_sym_break] = ACTIONS(3373),
    [anon_sym_unchecked] = ACTIONS(3373),
    [anon_sym_continue] = ACTIONS(3373),
    [anon_sym_do] = ACTIONS(3373),
    [anon_sym_while] = ACTIONS(3373),
    [anon_sym_for] = ACTIONS(3373),
    [anon_sym_lock] = ACTIONS(3373),
    [anon_sym_yield] = ACTIONS(3373),
    [anon_sym_switch] = ACTIONS(3373),
    [anon_sym_case] = ACTIONS(3373),
    [anon_sym_default] = ACTIONS(3373),
    [anon_sym_throw] = ACTIONS(3373),
    [anon_sym_try] = ACTIONS(3373),
    [anon_sym_when] = ACTIONS(3373),
    [anon_sym_await] = ACTIONS(3373),
    [anon_sym_foreach] = ACTIONS(3373),
    [anon_sym_goto] = ACTIONS(3373),
    [anon_sym_if] = ACTIONS(3373),
    [anon_sym_else] = ACTIONS(3373),
    [anon_sym_DOT_DOT] = ACTIONS(3375),
    [anon_sym_from] = ACTIONS(3373),
    [anon_sym_into] = ACTIONS(3373),
    [anon_sym_join] = ACTIONS(3373),
    [anon_sym_on] = ACTIONS(3373),
    [anon_sym_equals] = ACTIONS(3373),
    [anon_sym_let] = ACTIONS(3373),
    [anon_sym_orderby] = ACTIONS(3373),
    [anon_sym_ascending] = ACTIONS(3373),
    [anon_sym_descending] = ACTIONS(3373),
    [anon_sym_group] = ACTIONS(3373),
    [anon_sym_by] = ACTIONS(3373),
    [anon_sym_select] = ACTIONS(3373),
    [anon_sym_stackalloc] = ACTIONS(3373),
    [anon_sym_sizeof] = ACTIONS(3373),
    [anon_sym_typeof] = ACTIONS(3373),
    [anon_sym___makeref] = ACTIONS(3373),
    [anon_sym___reftype] = ACTIONS(3373),
    [anon_sym___refvalue] = ACTIONS(3373),
    [sym_null_literal] = ACTIONS(3373),
    [anon_sym_SQUOTE] = ACTIONS(3375),
    [sym_integer_literal] = ACTIONS(3373),
    [sym_real_literal] = ACTIONS(3375),
    [anon_sym_DQUOTE] = ACTIONS(3375),
    [sym_verbatim_string_literal] = ACTIONS(3375),
    [aux_sym_preproc_if_token1] = ACTIONS(3375),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3375),
    [sym_interpolation_verbatim_start] = ACTIONS(3375),
    [sym_interpolation_raw_start] = ACTIONS(3375),
    [sym_raw_string_start] = ACTIONS(3375),
  },
  [2702] = {
    [sym_preproc_region] = STATE(2702),
    [sym_preproc_endregion] = STATE(2702),
    [sym_preproc_line] = STATE(2702),
    [sym_preproc_pragma] = STATE(2702),
    [sym_preproc_nullable] = STATE(2702),
    [sym_preproc_error] = STATE(2702),
    [sym_preproc_warning] = STATE(2702),
    [sym_preproc_define] = STATE(2702),
    [sym_preproc_undef] = STATE(2702),
    [sym__identifier_token] = ACTIONS(3377),
    [anon_sym_extern] = ACTIONS(3377),
    [anon_sym_alias] = ACTIONS(3377),
    [anon_sym_SEMI] = ACTIONS(3379),
    [anon_sym_global] = ACTIONS(3377),
    [anon_sym_using] = ACTIONS(3377),
    [anon_sym_unsafe] = ACTIONS(3377),
    [anon_sym_static] = ACTIONS(3377),
    [anon_sym_LBRACK] = ACTIONS(3379),
    [anon_sym_LPAREN] = ACTIONS(3379),
    [anon_sym_return] = ACTIONS(3377),
    [anon_sym_ref] = ACTIONS(3377),
    [anon_sym_LBRACE] = ACTIONS(3379),
    [anon_sym_RBRACE] = ACTIONS(3379),
    [anon_sym_delegate] = ACTIONS(3377),
    [anon_sym_abstract] = ACTIONS(3377),
    [anon_sym_async] = ACTIONS(3377),
    [anon_sym_const] = ACTIONS(3377),
    [anon_sym_file] = ACTIONS(3377),
    [anon_sym_fixed] = ACTIONS(3377),
    [anon_sym_internal] = ACTIONS(3377),
    [anon_sym_new] = ACTIONS(3377),
    [anon_sym_override] = ACTIONS(3377),
    [anon_sym_partial] = ACTIONS(3377),
    [anon_sym_private] = ACTIONS(3377),
    [anon_sym_protected] = ACTIONS(3377),
    [anon_sym_public] = ACTIONS(3377),
    [anon_sym_readonly] = ACTIONS(3377),
    [anon_sym_required] = ACTIONS(3377),
    [anon_sym_sealed] = ACTIONS(3377),
    [anon_sym_virtual] = ACTIONS(3377),
    [anon_sym_volatile] = ACTIONS(3377),
    [anon_sym_where] = ACTIONS(3377),
    [anon_sym_notnull] = ACTIONS(3377),
    [anon_sym_unmanaged] = ACTIONS(3377),
    [anon_sym_checked] = ACTIONS(3377),
    [anon_sym_BANG] = ACTIONS(3379),
    [anon_sym_TILDE] = ACTIONS(3379),
    [anon_sym_PLUS_PLUS] = ACTIONS(3379),
    [anon_sym_DASH_DASH] = ACTIONS(3379),
    [anon_sym_true] = ACTIONS(3377),
    [anon_sym_false] = ACTIONS(3377),
    [anon_sym_PLUS] = ACTIONS(3377),
    [anon_sym_DASH] = ACTIONS(3377),
    [anon_sym_STAR] = ACTIONS(3379),
    [anon_sym_CARET] = ACTIONS(3379),
    [anon_sym_AMP] = ACTIONS(3379),
    [anon_sym_this] = ACTIONS(3377),
    [anon_sym_scoped] = ACTIONS(3377),
    [anon_sym_base] = ACTIONS(3377),
    [anon_sym_var] = ACTIONS(3377),
    [sym_predefined_type] = ACTIONS(3377),
    [anon_sym_break] = ACTIONS(3377),
    [anon_sym_unchecked] = ACTIONS(3377),
    [anon_sym_continue] = ACTIONS(3377),
    [anon_sym_do] = ACTIONS(3377),
    [anon_sym_while] = ACTIONS(3377),
    [anon_sym_for] = ACTIONS(3377),
    [anon_sym_lock] = ACTIONS(3377),
    [anon_sym_yield] = ACTIONS(3377),
    [anon_sym_switch] = ACTIONS(3377),
    [anon_sym_case] = ACTIONS(3377),
    [anon_sym_default] = ACTIONS(3377),
    [anon_sym_throw] = ACTIONS(3377),
    [anon_sym_try] = ACTIONS(3377),
    [anon_sym_when] = ACTIONS(3377),
    [anon_sym_await] = ACTIONS(3377),
    [anon_sym_foreach] = ACTIONS(3377),
    [anon_sym_goto] = ACTIONS(3377),
    [anon_sym_if] = ACTIONS(3377),
    [anon_sym_else] = ACTIONS(3377),
    [anon_sym_DOT_DOT] = ACTIONS(3379),
    [anon_sym_from] = ACTIONS(3377),
    [anon_sym_into] = ACTIONS(3377),
    [anon_sym_join] = ACTIONS(3377),
    [anon_sym_on] = ACTIONS(3377),
    [anon_sym_equals] = ACTIONS(3377),
    [anon_sym_let] = ACTIONS(3377),
    [anon_sym_orderby] = ACTIONS(3377),
    [anon_sym_ascending] = ACTIONS(3377),
    [anon_sym_descending] = ACTIONS(3377),
    [anon_sym_group] = ACTIONS(3377),
    [anon_sym_by] = ACTIONS(3377),
    [anon_sym_select] = ACTIONS(3377),
    [anon_sym_stackalloc] = ACTIONS(3377),
    [anon_sym_sizeof] = ACTIONS(3377),
    [anon_sym_typeof] = ACTIONS(3377),
    [anon_sym___makeref] = ACTIONS(3377),
    [anon_sym___reftype] = ACTIONS(3377),
    [anon_sym___refvalue] = ACTIONS(3377),
    [sym_null_literal] = ACTIONS(3377),
    [anon_sym_SQUOTE] = ACTIONS(3379),
    [sym_integer_literal] = ACTIONS(3377),
    [sym_real_literal] = ACTIONS(3379),
    [anon_sym_DQUOTE] = ACTIONS(3379),
    [sym_verbatim_string_literal] = ACTIONS(3379),
    [aux_sym_preproc_if_token1] = ACTIONS(3379),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3379),
    [sym_interpolation_verbatim_start] = ACTIONS(3379),
    [sym_interpolation_raw_start] = ACTIONS(3379),
    [sym_raw_string_start] = ACTIONS(3379),
  },
  [2703] = {
    [sym_preproc_region] = STATE(2703),
    [sym_preproc_endregion] = STATE(2703),
    [sym_preproc_line] = STATE(2703),
    [sym_preproc_pragma] = STATE(2703),
    [sym_preproc_nullable] = STATE(2703),
    [sym_preproc_error] = STATE(2703),
    [sym_preproc_warning] = STATE(2703),
    [sym_preproc_define] = STATE(2703),
    [sym_preproc_undef] = STATE(2703),
    [sym__identifier_token] = ACTIONS(3381),
    [anon_sym_extern] = ACTIONS(3381),
    [anon_sym_alias] = ACTIONS(3381),
    [anon_sym_SEMI] = ACTIONS(3383),
    [anon_sym_global] = ACTIONS(3381),
    [anon_sym_using] = ACTIONS(3381),
    [anon_sym_unsafe] = ACTIONS(3381),
    [anon_sym_static] = ACTIONS(3381),
    [anon_sym_LBRACK] = ACTIONS(3383),
    [anon_sym_LPAREN] = ACTIONS(3383),
    [anon_sym_return] = ACTIONS(3381),
    [anon_sym_ref] = ACTIONS(3381),
    [anon_sym_LBRACE] = ACTIONS(3383),
    [anon_sym_RBRACE] = ACTIONS(3383),
    [anon_sym_delegate] = ACTIONS(3381),
    [anon_sym_abstract] = ACTIONS(3381),
    [anon_sym_async] = ACTIONS(3381),
    [anon_sym_const] = ACTIONS(3381),
    [anon_sym_file] = ACTIONS(3381),
    [anon_sym_fixed] = ACTIONS(3381),
    [anon_sym_internal] = ACTIONS(3381),
    [anon_sym_new] = ACTIONS(3381),
    [anon_sym_override] = ACTIONS(3381),
    [anon_sym_partial] = ACTIONS(3381),
    [anon_sym_private] = ACTIONS(3381),
    [anon_sym_protected] = ACTIONS(3381),
    [anon_sym_public] = ACTIONS(3381),
    [anon_sym_readonly] = ACTIONS(3381),
    [anon_sym_required] = ACTIONS(3381),
    [anon_sym_sealed] = ACTIONS(3381),
    [anon_sym_virtual] = ACTIONS(3381),
    [anon_sym_volatile] = ACTIONS(3381),
    [anon_sym_where] = ACTIONS(3381),
    [anon_sym_notnull] = ACTIONS(3381),
    [anon_sym_unmanaged] = ACTIONS(3381),
    [anon_sym_checked] = ACTIONS(3381),
    [anon_sym_BANG] = ACTIONS(3383),
    [anon_sym_TILDE] = ACTIONS(3383),
    [anon_sym_PLUS_PLUS] = ACTIONS(3383),
    [anon_sym_DASH_DASH] = ACTIONS(3383),
    [anon_sym_true] = ACTIONS(3381),
    [anon_sym_false] = ACTIONS(3381),
    [anon_sym_PLUS] = ACTIONS(3381),
    [anon_sym_DASH] = ACTIONS(3381),
    [anon_sym_STAR] = ACTIONS(3383),
    [anon_sym_CARET] = ACTIONS(3383),
    [anon_sym_AMP] = ACTIONS(3383),
    [anon_sym_this] = ACTIONS(3381),
    [anon_sym_scoped] = ACTIONS(3381),
    [anon_sym_base] = ACTIONS(3381),
    [anon_sym_var] = ACTIONS(3381),
    [sym_predefined_type] = ACTIONS(3381),
    [anon_sym_break] = ACTIONS(3381),
    [anon_sym_unchecked] = ACTIONS(3381),
    [anon_sym_continue] = ACTIONS(3381),
    [anon_sym_do] = ACTIONS(3381),
    [anon_sym_while] = ACTIONS(3381),
    [anon_sym_for] = ACTIONS(3381),
    [anon_sym_lock] = ACTIONS(3381),
    [anon_sym_yield] = ACTIONS(3381),
    [anon_sym_switch] = ACTIONS(3381),
    [anon_sym_case] = ACTIONS(3381),
    [anon_sym_default] = ACTIONS(3381),
    [anon_sym_throw] = ACTIONS(3381),
    [anon_sym_try] = ACTIONS(3381),
    [anon_sym_when] = ACTIONS(3381),
    [anon_sym_await] = ACTIONS(3381),
    [anon_sym_foreach] = ACTIONS(3381),
    [anon_sym_goto] = ACTIONS(3381),
    [anon_sym_if] = ACTIONS(3381),
    [anon_sym_else] = ACTIONS(3381),
    [anon_sym_DOT_DOT] = ACTIONS(3383),
    [anon_sym_from] = ACTIONS(3381),
    [anon_sym_into] = ACTIONS(3381),
    [anon_sym_join] = ACTIONS(3381),
    [anon_sym_on] = ACTIONS(3381),
    [anon_sym_equals] = ACTIONS(3381),
    [anon_sym_let] = ACTIONS(3381),
    [anon_sym_orderby] = ACTIONS(3381),
    [anon_sym_ascending] = ACTIONS(3381),
    [anon_sym_descending] = ACTIONS(3381),
    [anon_sym_group] = ACTIONS(3381),
    [anon_sym_by] = ACTIONS(3381),
    [anon_sym_select] = ACTIONS(3381),
    [anon_sym_stackalloc] = ACTIONS(3381),
    [anon_sym_sizeof] = ACTIONS(3381),
    [anon_sym_typeof] = ACTIONS(3381),
    [anon_sym___makeref] = ACTIONS(3381),
    [anon_sym___reftype] = ACTIONS(3381),
    [anon_sym___refvalue] = ACTIONS(3381),
    [sym_null_literal] = ACTIONS(3381),
    [anon_sym_SQUOTE] = ACTIONS(3383),
    [sym_integer_literal] = ACTIONS(3381),
    [sym_real_literal] = ACTIONS(3383),
    [anon_sym_DQUOTE] = ACTIONS(3383),
    [sym_verbatim_string_literal] = ACTIONS(3383),
    [aux_sym_preproc_if_token1] = ACTIONS(3383),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3383),
    [sym_interpolation_verbatim_start] = ACTIONS(3383),
    [sym_interpolation_raw_start] = ACTIONS(3383),
    [sym_raw_string_start] = ACTIONS(3383),
  },
  [2704] = {
    [sym_preproc_region] = STATE(2704),
    [sym_preproc_endregion] = STATE(2704),
    [sym_preproc_line] = STATE(2704),
    [sym_preproc_pragma] = STATE(2704),
    [sym_preproc_nullable] = STATE(2704),
    [sym_preproc_error] = STATE(2704),
    [sym_preproc_warning] = STATE(2704),
    [sym_preproc_define] = STATE(2704),
    [sym_preproc_undef] = STATE(2704),
    [sym__identifier_token] = ACTIONS(3385),
    [anon_sym_extern] = ACTIONS(3385),
    [anon_sym_alias] = ACTIONS(3385),
    [anon_sym_SEMI] = ACTIONS(3387),
    [anon_sym_global] = ACTIONS(3385),
    [anon_sym_using] = ACTIONS(3385),
    [anon_sym_unsafe] = ACTIONS(3385),
    [anon_sym_static] = ACTIONS(3385),
    [anon_sym_LBRACK] = ACTIONS(3387),
    [anon_sym_LPAREN] = ACTIONS(3387),
    [anon_sym_return] = ACTIONS(3385),
    [anon_sym_ref] = ACTIONS(3385),
    [anon_sym_LBRACE] = ACTIONS(3387),
    [anon_sym_RBRACE] = ACTIONS(3387),
    [anon_sym_delegate] = ACTIONS(3385),
    [anon_sym_abstract] = ACTIONS(3385),
    [anon_sym_async] = ACTIONS(3385),
    [anon_sym_const] = ACTIONS(3385),
    [anon_sym_file] = ACTIONS(3385),
    [anon_sym_fixed] = ACTIONS(3385),
    [anon_sym_internal] = ACTIONS(3385),
    [anon_sym_new] = ACTIONS(3385),
    [anon_sym_override] = ACTIONS(3385),
    [anon_sym_partial] = ACTIONS(3385),
    [anon_sym_private] = ACTIONS(3385),
    [anon_sym_protected] = ACTIONS(3385),
    [anon_sym_public] = ACTIONS(3385),
    [anon_sym_readonly] = ACTIONS(3385),
    [anon_sym_required] = ACTIONS(3385),
    [anon_sym_sealed] = ACTIONS(3385),
    [anon_sym_virtual] = ACTIONS(3385),
    [anon_sym_volatile] = ACTIONS(3385),
    [anon_sym_where] = ACTIONS(3385),
    [anon_sym_notnull] = ACTIONS(3385),
    [anon_sym_unmanaged] = ACTIONS(3385),
    [anon_sym_checked] = ACTIONS(3385),
    [anon_sym_BANG] = ACTIONS(3387),
    [anon_sym_TILDE] = ACTIONS(3387),
    [anon_sym_PLUS_PLUS] = ACTIONS(3387),
    [anon_sym_DASH_DASH] = ACTIONS(3387),
    [anon_sym_true] = ACTIONS(3385),
    [anon_sym_false] = ACTIONS(3385),
    [anon_sym_PLUS] = ACTIONS(3385),
    [anon_sym_DASH] = ACTIONS(3385),
    [anon_sym_STAR] = ACTIONS(3387),
    [anon_sym_CARET] = ACTIONS(3387),
    [anon_sym_AMP] = ACTIONS(3387),
    [anon_sym_this] = ACTIONS(3385),
    [anon_sym_scoped] = ACTIONS(3385),
    [anon_sym_base] = ACTIONS(3385),
    [anon_sym_var] = ACTIONS(3385),
    [sym_predefined_type] = ACTIONS(3385),
    [anon_sym_break] = ACTIONS(3385),
    [anon_sym_unchecked] = ACTIONS(3385),
    [anon_sym_continue] = ACTIONS(3385),
    [anon_sym_do] = ACTIONS(3385),
    [anon_sym_while] = ACTIONS(3385),
    [anon_sym_for] = ACTIONS(3385),
    [anon_sym_lock] = ACTIONS(3385),
    [anon_sym_yield] = ACTIONS(3385),
    [anon_sym_switch] = ACTIONS(3385),
    [anon_sym_case] = ACTIONS(3385),
    [anon_sym_default] = ACTIONS(3385),
    [anon_sym_throw] = ACTIONS(3385),
    [anon_sym_try] = ACTIONS(3385),
    [anon_sym_when] = ACTIONS(3385),
    [anon_sym_await] = ACTIONS(3385),
    [anon_sym_foreach] = ACTIONS(3385),
    [anon_sym_goto] = ACTIONS(3385),
    [anon_sym_if] = ACTIONS(3385),
    [anon_sym_else] = ACTIONS(3385),
    [anon_sym_DOT_DOT] = ACTIONS(3387),
    [anon_sym_from] = ACTIONS(3385),
    [anon_sym_into] = ACTIONS(3385),
    [anon_sym_join] = ACTIONS(3385),
    [anon_sym_on] = ACTIONS(3385),
    [anon_sym_equals] = ACTIONS(3385),
    [anon_sym_let] = ACTIONS(3385),
    [anon_sym_orderby] = ACTIONS(3385),
    [anon_sym_ascending] = ACTIONS(3385),
    [anon_sym_descending] = ACTIONS(3385),
    [anon_sym_group] = ACTIONS(3385),
    [anon_sym_by] = ACTIONS(3385),
    [anon_sym_select] = ACTIONS(3385),
    [anon_sym_stackalloc] = ACTIONS(3385),
    [anon_sym_sizeof] = ACTIONS(3385),
    [anon_sym_typeof] = ACTIONS(3385),
    [anon_sym___makeref] = ACTIONS(3385),
    [anon_sym___reftype] = ACTIONS(3385),
    [anon_sym___refvalue] = ACTIONS(3385),
    [sym_null_literal] = ACTIONS(3385),
    [anon_sym_SQUOTE] = ACTIONS(3387),
    [sym_integer_literal] = ACTIONS(3385),
    [sym_real_literal] = ACTIONS(3387),
    [anon_sym_DQUOTE] = ACTIONS(3387),
    [sym_verbatim_string_literal] = ACTIONS(3387),
    [aux_sym_preproc_if_token1] = ACTIONS(3387),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3387),
    [sym_interpolation_verbatim_start] = ACTIONS(3387),
    [sym_interpolation_raw_start] = ACTIONS(3387),
    [sym_raw_string_start] = ACTIONS(3387),
  },
  [2705] = {
    [sym_preproc_region] = STATE(2705),
    [sym_preproc_endregion] = STATE(2705),
    [sym_preproc_line] = STATE(2705),
    [sym_preproc_pragma] = STATE(2705),
    [sym_preproc_nullable] = STATE(2705),
    [sym_preproc_error] = STATE(2705),
    [sym_preproc_warning] = STATE(2705),
    [sym_preproc_define] = STATE(2705),
    [sym_preproc_undef] = STATE(2705),
    [sym__identifier_token] = ACTIONS(3389),
    [anon_sym_extern] = ACTIONS(3389),
    [anon_sym_alias] = ACTIONS(3389),
    [anon_sym_SEMI] = ACTIONS(3391),
    [anon_sym_global] = ACTIONS(3389),
    [anon_sym_using] = ACTIONS(3389),
    [anon_sym_unsafe] = ACTIONS(3389),
    [anon_sym_static] = ACTIONS(3389),
    [anon_sym_LBRACK] = ACTIONS(3391),
    [anon_sym_LPAREN] = ACTIONS(3391),
    [anon_sym_return] = ACTIONS(3389),
    [anon_sym_ref] = ACTIONS(3389),
    [anon_sym_LBRACE] = ACTIONS(3391),
    [anon_sym_RBRACE] = ACTIONS(3391),
    [anon_sym_delegate] = ACTIONS(3389),
    [anon_sym_abstract] = ACTIONS(3389),
    [anon_sym_async] = ACTIONS(3389),
    [anon_sym_const] = ACTIONS(3389),
    [anon_sym_file] = ACTIONS(3389),
    [anon_sym_fixed] = ACTIONS(3389),
    [anon_sym_internal] = ACTIONS(3389),
    [anon_sym_new] = ACTIONS(3389),
    [anon_sym_override] = ACTIONS(3389),
    [anon_sym_partial] = ACTIONS(3389),
    [anon_sym_private] = ACTIONS(3389),
    [anon_sym_protected] = ACTIONS(3389),
    [anon_sym_public] = ACTIONS(3389),
    [anon_sym_readonly] = ACTIONS(3389),
    [anon_sym_required] = ACTIONS(3389),
    [anon_sym_sealed] = ACTIONS(3389),
    [anon_sym_virtual] = ACTIONS(3389),
    [anon_sym_volatile] = ACTIONS(3389),
    [anon_sym_where] = ACTIONS(3389),
    [anon_sym_notnull] = ACTIONS(3389),
    [anon_sym_unmanaged] = ACTIONS(3389),
    [anon_sym_checked] = ACTIONS(3389),
    [anon_sym_BANG] = ACTIONS(3391),
    [anon_sym_TILDE] = ACTIONS(3391),
    [anon_sym_PLUS_PLUS] = ACTIONS(3391),
    [anon_sym_DASH_DASH] = ACTIONS(3391),
    [anon_sym_true] = ACTIONS(3389),
    [anon_sym_false] = ACTIONS(3389),
    [anon_sym_PLUS] = ACTIONS(3389),
    [anon_sym_DASH] = ACTIONS(3389),
    [anon_sym_STAR] = ACTIONS(3391),
    [anon_sym_CARET] = ACTIONS(3391),
    [anon_sym_AMP] = ACTIONS(3391),
    [anon_sym_this] = ACTIONS(3389),
    [anon_sym_scoped] = ACTIONS(3389),
    [anon_sym_base] = ACTIONS(3389),
    [anon_sym_var] = ACTIONS(3389),
    [sym_predefined_type] = ACTIONS(3389),
    [anon_sym_break] = ACTIONS(3389),
    [anon_sym_unchecked] = ACTIONS(3389),
    [anon_sym_continue] = ACTIONS(3389),
    [anon_sym_do] = ACTIONS(3389),
    [anon_sym_while] = ACTIONS(3389),
    [anon_sym_for] = ACTIONS(3389),
    [anon_sym_lock] = ACTIONS(3389),
    [anon_sym_yield] = ACTIONS(3389),
    [anon_sym_switch] = ACTIONS(3389),
    [anon_sym_case] = ACTIONS(3389),
    [anon_sym_default] = ACTIONS(3389),
    [anon_sym_throw] = ACTIONS(3389),
    [anon_sym_try] = ACTIONS(3389),
    [anon_sym_when] = ACTIONS(3389),
    [anon_sym_await] = ACTIONS(3389),
    [anon_sym_foreach] = ACTIONS(3389),
    [anon_sym_goto] = ACTIONS(3389),
    [anon_sym_if] = ACTIONS(3389),
    [anon_sym_else] = ACTIONS(3389),
    [anon_sym_DOT_DOT] = ACTIONS(3391),
    [anon_sym_from] = ACTIONS(3389),
    [anon_sym_into] = ACTIONS(3389),
    [anon_sym_join] = ACTIONS(3389),
    [anon_sym_on] = ACTIONS(3389),
    [anon_sym_equals] = ACTIONS(3389),
    [anon_sym_let] = ACTIONS(3389),
    [anon_sym_orderby] = ACTIONS(3389),
    [anon_sym_ascending] = ACTIONS(3389),
    [anon_sym_descending] = ACTIONS(3389),
    [anon_sym_group] = ACTIONS(3389),
    [anon_sym_by] = ACTIONS(3389),
    [anon_sym_select] = ACTIONS(3389),
    [anon_sym_stackalloc] = ACTIONS(3389),
    [anon_sym_sizeof] = ACTIONS(3389),
    [anon_sym_typeof] = ACTIONS(3389),
    [anon_sym___makeref] = ACTIONS(3389),
    [anon_sym___reftype] = ACTIONS(3389),
    [anon_sym___refvalue] = ACTIONS(3389),
    [sym_null_literal] = ACTIONS(3389),
    [anon_sym_SQUOTE] = ACTIONS(3391),
    [sym_integer_literal] = ACTIONS(3389),
    [sym_real_literal] = ACTIONS(3391),
    [anon_sym_DQUOTE] = ACTIONS(3391),
    [sym_verbatim_string_literal] = ACTIONS(3391),
    [aux_sym_preproc_if_token1] = ACTIONS(3391),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3391),
    [sym_interpolation_verbatim_start] = ACTIONS(3391),
    [sym_interpolation_raw_start] = ACTIONS(3391),
    [sym_raw_string_start] = ACTIONS(3391),
  },
  [2706] = {
    [sym_preproc_region] = STATE(2706),
    [sym_preproc_endregion] = STATE(2706),
    [sym_preproc_line] = STATE(2706),
    [sym_preproc_pragma] = STATE(2706),
    [sym_preproc_nullable] = STATE(2706),
    [sym_preproc_error] = STATE(2706),
    [sym_preproc_warning] = STATE(2706),
    [sym_preproc_define] = STATE(2706),
    [sym_preproc_undef] = STATE(2706),
    [sym__identifier_token] = ACTIONS(3397),
    [anon_sym_extern] = ACTIONS(3397),
    [anon_sym_alias] = ACTIONS(3397),
    [anon_sym_SEMI] = ACTIONS(3399),
    [anon_sym_global] = ACTIONS(3397),
    [anon_sym_using] = ACTIONS(3397),
    [anon_sym_unsafe] = ACTIONS(3397),
    [anon_sym_static] = ACTIONS(3397),
    [anon_sym_LBRACK] = ACTIONS(3399),
    [anon_sym_LPAREN] = ACTIONS(3399),
    [anon_sym_return] = ACTIONS(3397),
    [anon_sym_ref] = ACTIONS(3397),
    [anon_sym_LBRACE] = ACTIONS(3399),
    [anon_sym_RBRACE] = ACTIONS(3399),
    [anon_sym_delegate] = ACTIONS(3397),
    [anon_sym_abstract] = ACTIONS(3397),
    [anon_sym_async] = ACTIONS(3397),
    [anon_sym_const] = ACTIONS(3397),
    [anon_sym_file] = ACTIONS(3397),
    [anon_sym_fixed] = ACTIONS(3397),
    [anon_sym_internal] = ACTIONS(3397),
    [anon_sym_new] = ACTIONS(3397),
    [anon_sym_override] = ACTIONS(3397),
    [anon_sym_partial] = ACTIONS(3397),
    [anon_sym_private] = ACTIONS(3397),
    [anon_sym_protected] = ACTIONS(3397),
    [anon_sym_public] = ACTIONS(3397),
    [anon_sym_readonly] = ACTIONS(3397),
    [anon_sym_required] = ACTIONS(3397),
    [anon_sym_sealed] = ACTIONS(3397),
    [anon_sym_virtual] = ACTIONS(3397),
    [anon_sym_volatile] = ACTIONS(3397),
    [anon_sym_where] = ACTIONS(3397),
    [anon_sym_notnull] = ACTIONS(3397),
    [anon_sym_unmanaged] = ACTIONS(3397),
    [anon_sym_checked] = ACTIONS(3397),
    [anon_sym_BANG] = ACTIONS(3399),
    [anon_sym_TILDE] = ACTIONS(3399),
    [anon_sym_PLUS_PLUS] = ACTIONS(3399),
    [anon_sym_DASH_DASH] = ACTIONS(3399),
    [anon_sym_true] = ACTIONS(3397),
    [anon_sym_false] = ACTIONS(3397),
    [anon_sym_PLUS] = ACTIONS(3397),
    [anon_sym_DASH] = ACTIONS(3397),
    [anon_sym_STAR] = ACTIONS(3399),
    [anon_sym_CARET] = ACTIONS(3399),
    [anon_sym_AMP] = ACTIONS(3399),
    [anon_sym_this] = ACTIONS(3397),
    [anon_sym_scoped] = ACTIONS(3397),
    [anon_sym_base] = ACTIONS(3397),
    [anon_sym_var] = ACTIONS(3397),
    [sym_predefined_type] = ACTIONS(3397),
    [anon_sym_break] = ACTIONS(3397),
    [anon_sym_unchecked] = ACTIONS(3397),
    [anon_sym_continue] = ACTIONS(3397),
    [anon_sym_do] = ACTIONS(3397),
    [anon_sym_while] = ACTIONS(3397),
    [anon_sym_for] = ACTIONS(3397),
    [anon_sym_lock] = ACTIONS(3397),
    [anon_sym_yield] = ACTIONS(3397),
    [anon_sym_switch] = ACTIONS(3397),
    [anon_sym_case] = ACTIONS(3397),
    [anon_sym_default] = ACTIONS(3397),
    [anon_sym_throw] = ACTIONS(3397),
    [anon_sym_try] = ACTIONS(3397),
    [anon_sym_when] = ACTIONS(3397),
    [anon_sym_await] = ACTIONS(3397),
    [anon_sym_foreach] = ACTIONS(3397),
    [anon_sym_goto] = ACTIONS(3397),
    [anon_sym_if] = ACTIONS(3397),
    [anon_sym_else] = ACTIONS(3397),
    [anon_sym_DOT_DOT] = ACTIONS(3399),
    [anon_sym_from] = ACTIONS(3397),
    [anon_sym_into] = ACTIONS(3397),
    [anon_sym_join] = ACTIONS(3397),
    [anon_sym_on] = ACTIONS(3397),
    [anon_sym_equals] = ACTIONS(3397),
    [anon_sym_let] = ACTIONS(3397),
    [anon_sym_orderby] = ACTIONS(3397),
    [anon_sym_ascending] = ACTIONS(3397),
    [anon_sym_descending] = ACTIONS(3397),
    [anon_sym_group] = ACTIONS(3397),
    [anon_sym_by] = ACTIONS(3397),
    [anon_sym_select] = ACTIONS(3397),
    [anon_sym_stackalloc] = ACTIONS(3397),
    [anon_sym_sizeof] = ACTIONS(3397),
    [anon_sym_typeof] = ACTIONS(3397),
    [anon_sym___makeref] = ACTIONS(3397),
    [anon_sym___reftype] = ACTIONS(3397),
    [anon_sym___refvalue] = ACTIONS(3397),
    [sym_null_literal] = ACTIONS(3397),
    [anon_sym_SQUOTE] = ACTIONS(3399),
    [sym_integer_literal] = ACTIONS(3397),
    [sym_real_literal] = ACTIONS(3399),
    [anon_sym_DQUOTE] = ACTIONS(3399),
    [sym_verbatim_string_literal] = ACTIONS(3399),
    [aux_sym_preproc_if_token1] = ACTIONS(3399),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3399),
    [sym_interpolation_verbatim_start] = ACTIONS(3399),
    [sym_interpolation_raw_start] = ACTIONS(3399),
    [sym_raw_string_start] = ACTIONS(3399),
  },
  [2707] = {
    [sym_preproc_region] = STATE(2707),
    [sym_preproc_endregion] = STATE(2707),
    [sym_preproc_line] = STATE(2707),
    [sym_preproc_pragma] = STATE(2707),
    [sym_preproc_nullable] = STATE(2707),
    [sym_preproc_error] = STATE(2707),
    [sym_preproc_warning] = STATE(2707),
    [sym_preproc_define] = STATE(2707),
    [sym_preproc_undef] = STATE(2707),
    [sym__identifier_token] = ACTIONS(3401),
    [anon_sym_extern] = ACTIONS(3401),
    [anon_sym_alias] = ACTIONS(3401),
    [anon_sym_SEMI] = ACTIONS(3403),
    [anon_sym_global] = ACTIONS(3401),
    [anon_sym_using] = ACTIONS(3401),
    [anon_sym_unsafe] = ACTIONS(3401),
    [anon_sym_static] = ACTIONS(3401),
    [anon_sym_LBRACK] = ACTIONS(3403),
    [anon_sym_LPAREN] = ACTIONS(3403),
    [anon_sym_return] = ACTIONS(3401),
    [anon_sym_ref] = ACTIONS(3401),
    [anon_sym_LBRACE] = ACTIONS(3403),
    [anon_sym_RBRACE] = ACTIONS(3403),
    [anon_sym_delegate] = ACTIONS(3401),
    [anon_sym_abstract] = ACTIONS(3401),
    [anon_sym_async] = ACTIONS(3401),
    [anon_sym_const] = ACTIONS(3401),
    [anon_sym_file] = ACTIONS(3401),
    [anon_sym_fixed] = ACTIONS(3401),
    [anon_sym_internal] = ACTIONS(3401),
    [anon_sym_new] = ACTIONS(3401),
    [anon_sym_override] = ACTIONS(3401),
    [anon_sym_partial] = ACTIONS(3401),
    [anon_sym_private] = ACTIONS(3401),
    [anon_sym_protected] = ACTIONS(3401),
    [anon_sym_public] = ACTIONS(3401),
    [anon_sym_readonly] = ACTIONS(3401),
    [anon_sym_required] = ACTIONS(3401),
    [anon_sym_sealed] = ACTIONS(3401),
    [anon_sym_virtual] = ACTIONS(3401),
    [anon_sym_volatile] = ACTIONS(3401),
    [anon_sym_where] = ACTIONS(3401),
    [anon_sym_notnull] = ACTIONS(3401),
    [anon_sym_unmanaged] = ACTIONS(3401),
    [anon_sym_checked] = ACTIONS(3401),
    [anon_sym_BANG] = ACTIONS(3403),
    [anon_sym_TILDE] = ACTIONS(3403),
    [anon_sym_PLUS_PLUS] = ACTIONS(3403),
    [anon_sym_DASH_DASH] = ACTIONS(3403),
    [anon_sym_true] = ACTIONS(3401),
    [anon_sym_false] = ACTIONS(3401),
    [anon_sym_PLUS] = ACTIONS(3401),
    [anon_sym_DASH] = ACTIONS(3401),
    [anon_sym_STAR] = ACTIONS(3403),
    [anon_sym_CARET] = ACTIONS(3403),
    [anon_sym_AMP] = ACTIONS(3403),
    [anon_sym_this] = ACTIONS(3401),
    [anon_sym_scoped] = ACTIONS(3401),
    [anon_sym_base] = ACTIONS(3401),
    [anon_sym_var] = ACTIONS(3401),
    [sym_predefined_type] = ACTIONS(3401),
    [anon_sym_break] = ACTIONS(3401),
    [anon_sym_unchecked] = ACTIONS(3401),
    [anon_sym_continue] = ACTIONS(3401),
    [anon_sym_do] = ACTIONS(3401),
    [anon_sym_while] = ACTIONS(3401),
    [anon_sym_for] = ACTIONS(3401),
    [anon_sym_lock] = ACTIONS(3401),
    [anon_sym_yield] = ACTIONS(3401),
    [anon_sym_switch] = ACTIONS(3401),
    [anon_sym_case] = ACTIONS(3401),
    [anon_sym_default] = ACTIONS(3401),
    [anon_sym_throw] = ACTIONS(3401),
    [anon_sym_try] = ACTIONS(3401),
    [anon_sym_when] = ACTIONS(3401),
    [anon_sym_await] = ACTIONS(3401),
    [anon_sym_foreach] = ACTIONS(3401),
    [anon_sym_goto] = ACTIONS(3401),
    [anon_sym_if] = ACTIONS(3401),
    [anon_sym_else] = ACTIONS(3401),
    [anon_sym_DOT_DOT] = ACTIONS(3403),
    [anon_sym_from] = ACTIONS(3401),
    [anon_sym_into] = ACTIONS(3401),
    [anon_sym_join] = ACTIONS(3401),
    [anon_sym_on] = ACTIONS(3401),
    [anon_sym_equals] = ACTIONS(3401),
    [anon_sym_let] = ACTIONS(3401),
    [anon_sym_orderby] = ACTIONS(3401),
    [anon_sym_ascending] = ACTIONS(3401),
    [anon_sym_descending] = ACTIONS(3401),
    [anon_sym_group] = ACTIONS(3401),
    [anon_sym_by] = ACTIONS(3401),
    [anon_sym_select] = ACTIONS(3401),
    [anon_sym_stackalloc] = ACTIONS(3401),
    [anon_sym_sizeof] = ACTIONS(3401),
    [anon_sym_typeof] = ACTIONS(3401),
    [anon_sym___makeref] = ACTIONS(3401),
    [anon_sym___reftype] = ACTIONS(3401),
    [anon_sym___refvalue] = ACTIONS(3401),
    [sym_null_literal] = ACTIONS(3401),
    [anon_sym_SQUOTE] = ACTIONS(3403),
    [sym_integer_literal] = ACTIONS(3401),
    [sym_real_literal] = ACTIONS(3403),
    [anon_sym_DQUOTE] = ACTIONS(3403),
    [sym_verbatim_string_literal] = ACTIONS(3403),
    [aux_sym_preproc_if_token1] = ACTIONS(3403),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3403),
    [sym_interpolation_verbatim_start] = ACTIONS(3403),
    [sym_interpolation_raw_start] = ACTIONS(3403),
    [sym_raw_string_start] = ACTIONS(3403),
  },
  [2708] = {
    [sym_preproc_region] = STATE(2708),
    [sym_preproc_endregion] = STATE(2708),
    [sym_preproc_line] = STATE(2708),
    [sym_preproc_pragma] = STATE(2708),
    [sym_preproc_nullable] = STATE(2708),
    [sym_preproc_error] = STATE(2708),
    [sym_preproc_warning] = STATE(2708),
    [sym_preproc_define] = STATE(2708),
    [sym_preproc_undef] = STATE(2708),
    [sym__identifier_token] = ACTIONS(3093),
    [anon_sym_extern] = ACTIONS(3093),
    [anon_sym_alias] = ACTIONS(3093),
    [anon_sym_SEMI] = ACTIONS(3095),
    [anon_sym_global] = ACTIONS(3093),
    [anon_sym_using] = ACTIONS(3093),
    [anon_sym_unsafe] = ACTIONS(3093),
    [anon_sym_static] = ACTIONS(3093),
    [anon_sym_LBRACK] = ACTIONS(3095),
    [anon_sym_LPAREN] = ACTIONS(3095),
    [anon_sym_return] = ACTIONS(3093),
    [anon_sym_ref] = ACTIONS(3093),
    [anon_sym_LBRACE] = ACTIONS(3095),
    [anon_sym_RBRACE] = ACTIONS(3095),
    [anon_sym_delegate] = ACTIONS(3093),
    [anon_sym_abstract] = ACTIONS(3093),
    [anon_sym_async] = ACTIONS(3093),
    [anon_sym_const] = ACTIONS(3093),
    [anon_sym_file] = ACTIONS(3093),
    [anon_sym_fixed] = ACTIONS(3093),
    [anon_sym_internal] = ACTIONS(3093),
    [anon_sym_new] = ACTIONS(3093),
    [anon_sym_override] = ACTIONS(3093),
    [anon_sym_partial] = ACTIONS(3093),
    [anon_sym_private] = ACTIONS(3093),
    [anon_sym_protected] = ACTIONS(3093),
    [anon_sym_public] = ACTIONS(3093),
    [anon_sym_readonly] = ACTIONS(3093),
    [anon_sym_required] = ACTIONS(3093),
    [anon_sym_sealed] = ACTIONS(3093),
    [anon_sym_virtual] = ACTIONS(3093),
    [anon_sym_volatile] = ACTIONS(3093),
    [anon_sym_where] = ACTIONS(3093),
    [anon_sym_notnull] = ACTIONS(3093),
    [anon_sym_unmanaged] = ACTIONS(3093),
    [anon_sym_checked] = ACTIONS(3093),
    [anon_sym_BANG] = ACTIONS(3095),
    [anon_sym_TILDE] = ACTIONS(3095),
    [anon_sym_PLUS_PLUS] = ACTIONS(3095),
    [anon_sym_DASH_DASH] = ACTIONS(3095),
    [anon_sym_true] = ACTIONS(3093),
    [anon_sym_false] = ACTIONS(3093),
    [anon_sym_PLUS] = ACTIONS(3093),
    [anon_sym_DASH] = ACTIONS(3093),
    [anon_sym_STAR] = ACTIONS(3095),
    [anon_sym_CARET] = ACTIONS(3095),
    [anon_sym_AMP] = ACTIONS(3095),
    [anon_sym_this] = ACTIONS(3093),
    [anon_sym_scoped] = ACTIONS(3093),
    [anon_sym_base] = ACTIONS(3093),
    [anon_sym_var] = ACTIONS(3093),
    [sym_predefined_type] = ACTIONS(3093),
    [anon_sym_break] = ACTIONS(3093),
    [anon_sym_unchecked] = ACTIONS(3093),
    [anon_sym_continue] = ACTIONS(3093),
    [anon_sym_do] = ACTIONS(3093),
    [anon_sym_while] = ACTIONS(3093),
    [anon_sym_for] = ACTIONS(3093),
    [anon_sym_lock] = ACTIONS(3093),
    [anon_sym_yield] = ACTIONS(3093),
    [anon_sym_switch] = ACTIONS(3093),
    [anon_sym_case] = ACTIONS(3093),
    [anon_sym_default] = ACTIONS(3093),
    [anon_sym_throw] = ACTIONS(3093),
    [anon_sym_try] = ACTIONS(3093),
    [anon_sym_when] = ACTIONS(3093),
    [anon_sym_await] = ACTIONS(3093),
    [anon_sym_foreach] = ACTIONS(3093),
    [anon_sym_goto] = ACTIONS(3093),
    [anon_sym_if] = ACTIONS(3093),
    [anon_sym_else] = ACTIONS(3093),
    [anon_sym_DOT_DOT] = ACTIONS(3095),
    [anon_sym_from] = ACTIONS(3093),
    [anon_sym_into] = ACTIONS(3093),
    [anon_sym_join] = ACTIONS(3093),
    [anon_sym_on] = ACTIONS(3093),
    [anon_sym_equals] = ACTIONS(3093),
    [anon_sym_let] = ACTIONS(3093),
    [anon_sym_orderby] = ACTIONS(3093),
    [anon_sym_ascending] = ACTIONS(3093),
    [anon_sym_descending] = ACTIONS(3093),
    [anon_sym_group] = ACTIONS(3093),
    [anon_sym_by] = ACTIONS(3093),
    [anon_sym_select] = ACTIONS(3093),
    [anon_sym_stackalloc] = ACTIONS(3093),
    [anon_sym_sizeof] = ACTIONS(3093),
    [anon_sym_typeof] = ACTIONS(3093),
    [anon_sym___makeref] = ACTIONS(3093),
    [anon_sym___reftype] = ACTIONS(3093),
    [anon_sym___refvalue] = ACTIONS(3093),
    [sym_null_literal] = ACTIONS(3093),
    [anon_sym_SQUOTE] = ACTIONS(3095),
    [sym_integer_literal] = ACTIONS(3093),
    [sym_real_literal] = ACTIONS(3095),
    [anon_sym_DQUOTE] = ACTIONS(3095),
    [sym_verbatim_string_literal] = ACTIONS(3095),
    [aux_sym_preproc_if_token1] = ACTIONS(3095),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3095),
    [sym_interpolation_verbatim_start] = ACTIONS(3095),
    [sym_interpolation_raw_start] = ACTIONS(3095),
    [sym_raw_string_start] = ACTIONS(3095),
  },
  [2709] = {
    [sym_preproc_region] = STATE(2709),
    [sym_preproc_endregion] = STATE(2709),
    [sym_preproc_line] = STATE(2709),
    [sym_preproc_pragma] = STATE(2709),
    [sym_preproc_nullable] = STATE(2709),
    [sym_preproc_error] = STATE(2709),
    [sym_preproc_warning] = STATE(2709),
    [sym_preproc_define] = STATE(2709),
    [sym_preproc_undef] = STATE(2709),
    [sym__identifier_token] = ACTIONS(3141),
    [anon_sym_extern] = ACTIONS(3141),
    [anon_sym_alias] = ACTIONS(3141),
    [anon_sym_SEMI] = ACTIONS(3143),
    [anon_sym_global] = ACTIONS(3141),
    [anon_sym_using] = ACTIONS(3141),
    [anon_sym_unsafe] = ACTIONS(3141),
    [anon_sym_static] = ACTIONS(3141),
    [anon_sym_LBRACK] = ACTIONS(3143),
    [anon_sym_LPAREN] = ACTIONS(3143),
    [anon_sym_return] = ACTIONS(3141),
    [anon_sym_ref] = ACTIONS(3141),
    [anon_sym_LBRACE] = ACTIONS(3143),
    [anon_sym_RBRACE] = ACTIONS(3143),
    [anon_sym_delegate] = ACTIONS(3141),
    [anon_sym_abstract] = ACTIONS(3141),
    [anon_sym_async] = ACTIONS(3141),
    [anon_sym_const] = ACTIONS(3141),
    [anon_sym_file] = ACTIONS(3141),
    [anon_sym_fixed] = ACTIONS(3141),
    [anon_sym_internal] = ACTIONS(3141),
    [anon_sym_new] = ACTIONS(3141),
    [anon_sym_override] = ACTIONS(3141),
    [anon_sym_partial] = ACTIONS(3141),
    [anon_sym_private] = ACTIONS(3141),
    [anon_sym_protected] = ACTIONS(3141),
    [anon_sym_public] = ACTIONS(3141),
    [anon_sym_readonly] = ACTIONS(3141),
    [anon_sym_required] = ACTIONS(3141),
    [anon_sym_sealed] = ACTIONS(3141),
    [anon_sym_virtual] = ACTIONS(3141),
    [anon_sym_volatile] = ACTIONS(3141),
    [anon_sym_where] = ACTIONS(3141),
    [anon_sym_notnull] = ACTIONS(3141),
    [anon_sym_unmanaged] = ACTIONS(3141),
    [anon_sym_checked] = ACTIONS(3141),
    [anon_sym_BANG] = ACTIONS(3143),
    [anon_sym_TILDE] = ACTIONS(3143),
    [anon_sym_PLUS_PLUS] = ACTIONS(3143),
    [anon_sym_DASH_DASH] = ACTIONS(3143),
    [anon_sym_true] = ACTIONS(3141),
    [anon_sym_false] = ACTIONS(3141),
    [anon_sym_PLUS] = ACTIONS(3141),
    [anon_sym_DASH] = ACTIONS(3141),
    [anon_sym_STAR] = ACTIONS(3143),
    [anon_sym_CARET] = ACTIONS(3143),
    [anon_sym_AMP] = ACTIONS(3143),
    [anon_sym_this] = ACTIONS(3141),
    [anon_sym_scoped] = ACTIONS(3141),
    [anon_sym_base] = ACTIONS(3141),
    [anon_sym_var] = ACTIONS(3141),
    [sym_predefined_type] = ACTIONS(3141),
    [anon_sym_break] = ACTIONS(3141),
    [anon_sym_unchecked] = ACTIONS(3141),
    [anon_sym_continue] = ACTIONS(3141),
    [anon_sym_do] = ACTIONS(3141),
    [anon_sym_while] = ACTIONS(3141),
    [anon_sym_for] = ACTIONS(3141),
    [anon_sym_lock] = ACTIONS(3141),
    [anon_sym_yield] = ACTIONS(3141),
    [anon_sym_switch] = ACTIONS(3141),
    [anon_sym_case] = ACTIONS(3141),
    [anon_sym_default] = ACTIONS(3141),
    [anon_sym_throw] = ACTIONS(3141),
    [anon_sym_try] = ACTIONS(3141),
    [anon_sym_when] = ACTIONS(3141),
    [anon_sym_await] = ACTIONS(3141),
    [anon_sym_foreach] = ACTIONS(3141),
    [anon_sym_goto] = ACTIONS(3141),
    [anon_sym_if] = ACTIONS(3141),
    [anon_sym_else] = ACTIONS(3141),
    [anon_sym_DOT_DOT] = ACTIONS(3143),
    [anon_sym_from] = ACTIONS(3141),
    [anon_sym_into] = ACTIONS(3141),
    [anon_sym_join] = ACTIONS(3141),
    [anon_sym_on] = ACTIONS(3141),
    [anon_sym_equals] = ACTIONS(3141),
    [anon_sym_let] = ACTIONS(3141),
    [anon_sym_orderby] = ACTIONS(3141),
    [anon_sym_ascending] = ACTIONS(3141),
    [anon_sym_descending] = ACTIONS(3141),
    [anon_sym_group] = ACTIONS(3141),
    [anon_sym_by] = ACTIONS(3141),
    [anon_sym_select] = ACTIONS(3141),
    [anon_sym_stackalloc] = ACTIONS(3141),
    [anon_sym_sizeof] = ACTIONS(3141),
    [anon_sym_typeof] = ACTIONS(3141),
    [anon_sym___makeref] = ACTIONS(3141),
    [anon_sym___reftype] = ACTIONS(3141),
    [anon_sym___refvalue] = ACTIONS(3141),
    [sym_null_literal] = ACTIONS(3141),
    [anon_sym_SQUOTE] = ACTIONS(3143),
    [sym_integer_literal] = ACTIONS(3141),
    [sym_real_literal] = ACTIONS(3143),
    [anon_sym_DQUOTE] = ACTIONS(3143),
    [sym_verbatim_string_literal] = ACTIONS(3143),
    [aux_sym_preproc_if_token1] = ACTIONS(3143),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3143),
    [sym_interpolation_verbatim_start] = ACTIONS(3143),
    [sym_interpolation_raw_start] = ACTIONS(3143),
    [sym_raw_string_start] = ACTIONS(3143),
  },
  [2710] = {
    [sym_preproc_region] = STATE(2710),
    [sym_preproc_endregion] = STATE(2710),
    [sym_preproc_line] = STATE(2710),
    [sym_preproc_pragma] = STATE(2710),
    [sym_preproc_nullable] = STATE(2710),
    [sym_preproc_error] = STATE(2710),
    [sym_preproc_warning] = STATE(2710),
    [sym_preproc_define] = STATE(2710),
    [sym_preproc_undef] = STATE(2710),
    [sym__identifier_token] = ACTIONS(3145),
    [anon_sym_extern] = ACTIONS(3145),
    [anon_sym_alias] = ACTIONS(3145),
    [anon_sym_SEMI] = ACTIONS(3147),
    [anon_sym_global] = ACTIONS(3145),
    [anon_sym_using] = ACTIONS(3145),
    [anon_sym_unsafe] = ACTIONS(3145),
    [anon_sym_static] = ACTIONS(3145),
    [anon_sym_LBRACK] = ACTIONS(3147),
    [anon_sym_LPAREN] = ACTIONS(3147),
    [anon_sym_return] = ACTIONS(3145),
    [anon_sym_ref] = ACTIONS(3145),
    [anon_sym_LBRACE] = ACTIONS(3147),
    [anon_sym_RBRACE] = ACTIONS(3147),
    [anon_sym_delegate] = ACTIONS(3145),
    [anon_sym_abstract] = ACTIONS(3145),
    [anon_sym_async] = ACTIONS(3145),
    [anon_sym_const] = ACTIONS(3145),
    [anon_sym_file] = ACTIONS(3145),
    [anon_sym_fixed] = ACTIONS(3145),
    [anon_sym_internal] = ACTIONS(3145),
    [anon_sym_new] = ACTIONS(3145),
    [anon_sym_override] = ACTIONS(3145),
    [anon_sym_partial] = ACTIONS(3145),
    [anon_sym_private] = ACTIONS(3145),
    [anon_sym_protected] = ACTIONS(3145),
    [anon_sym_public] = ACTIONS(3145),
    [anon_sym_readonly] = ACTIONS(3145),
    [anon_sym_required] = ACTIONS(3145),
    [anon_sym_sealed] = ACTIONS(3145),
    [anon_sym_virtual] = ACTIONS(3145),
    [anon_sym_volatile] = ACTIONS(3145),
    [anon_sym_where] = ACTIONS(3145),
    [anon_sym_notnull] = ACTIONS(3145),
    [anon_sym_unmanaged] = ACTIONS(3145),
    [anon_sym_checked] = ACTIONS(3145),
    [anon_sym_BANG] = ACTIONS(3147),
    [anon_sym_TILDE] = ACTIONS(3147),
    [anon_sym_PLUS_PLUS] = ACTIONS(3147),
    [anon_sym_DASH_DASH] = ACTIONS(3147),
    [anon_sym_true] = ACTIONS(3145),
    [anon_sym_false] = ACTIONS(3145),
    [anon_sym_PLUS] = ACTIONS(3145),
    [anon_sym_DASH] = ACTIONS(3145),
    [anon_sym_STAR] = ACTIONS(3147),
    [anon_sym_CARET] = ACTIONS(3147),
    [anon_sym_AMP] = ACTIONS(3147),
    [anon_sym_this] = ACTIONS(3145),
    [anon_sym_scoped] = ACTIONS(3145),
    [anon_sym_base] = ACTIONS(3145),
    [anon_sym_var] = ACTIONS(3145),
    [sym_predefined_type] = ACTIONS(3145),
    [anon_sym_break] = ACTIONS(3145),
    [anon_sym_unchecked] = ACTIONS(3145),
    [anon_sym_continue] = ACTIONS(3145),
    [anon_sym_do] = ACTIONS(3145),
    [anon_sym_while] = ACTIONS(3145),
    [anon_sym_for] = ACTIONS(3145),
    [anon_sym_lock] = ACTIONS(3145),
    [anon_sym_yield] = ACTIONS(3145),
    [anon_sym_switch] = ACTIONS(3145),
    [anon_sym_case] = ACTIONS(3145),
    [anon_sym_default] = ACTIONS(3145),
    [anon_sym_throw] = ACTIONS(3145),
    [anon_sym_try] = ACTIONS(3145),
    [anon_sym_when] = ACTIONS(3145),
    [anon_sym_await] = ACTIONS(3145),
    [anon_sym_foreach] = ACTIONS(3145),
    [anon_sym_goto] = ACTIONS(3145),
    [anon_sym_if] = ACTIONS(3145),
    [anon_sym_else] = ACTIONS(3145),
    [anon_sym_DOT_DOT] = ACTIONS(3147),
    [anon_sym_from] = ACTIONS(3145),
    [anon_sym_into] = ACTIONS(3145),
    [anon_sym_join] = ACTIONS(3145),
    [anon_sym_on] = ACTIONS(3145),
    [anon_sym_equals] = ACTIONS(3145),
    [anon_sym_let] = ACTIONS(3145),
    [anon_sym_orderby] = ACTIONS(3145),
    [anon_sym_ascending] = ACTIONS(3145),
    [anon_sym_descending] = ACTIONS(3145),
    [anon_sym_group] = ACTIONS(3145),
    [anon_sym_by] = ACTIONS(3145),
    [anon_sym_select] = ACTIONS(3145),
    [anon_sym_stackalloc] = ACTIONS(3145),
    [anon_sym_sizeof] = ACTIONS(3145),
    [anon_sym_typeof] = ACTIONS(3145),
    [anon_sym___makeref] = ACTIONS(3145),
    [anon_sym___reftype] = ACTIONS(3145),
    [anon_sym___refvalue] = ACTIONS(3145),
    [sym_null_literal] = ACTIONS(3145),
    [anon_sym_SQUOTE] = ACTIONS(3147),
    [sym_integer_literal] = ACTIONS(3145),
    [sym_real_literal] = ACTIONS(3147),
    [anon_sym_DQUOTE] = ACTIONS(3147),
    [sym_verbatim_string_literal] = ACTIONS(3147),
    [aux_sym_preproc_if_token1] = ACTIONS(3147),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3147),
    [sym_interpolation_verbatim_start] = ACTIONS(3147),
    [sym_interpolation_raw_start] = ACTIONS(3147),
    [sym_raw_string_start] = ACTIONS(3147),
  },
  [2711] = {
    [sym_preproc_region] = STATE(2711),
    [sym_preproc_endregion] = STATE(2711),
    [sym_preproc_line] = STATE(2711),
    [sym_preproc_pragma] = STATE(2711),
    [sym_preproc_nullable] = STATE(2711),
    [sym_preproc_error] = STATE(2711),
    [sym_preproc_warning] = STATE(2711),
    [sym_preproc_define] = STATE(2711),
    [sym_preproc_undef] = STATE(2711),
    [sym__identifier_token] = ACTIONS(3149),
    [anon_sym_extern] = ACTIONS(3149),
    [anon_sym_alias] = ACTIONS(3149),
    [anon_sym_SEMI] = ACTIONS(3151),
    [anon_sym_global] = ACTIONS(3149),
    [anon_sym_using] = ACTIONS(3149),
    [anon_sym_unsafe] = ACTIONS(3149),
    [anon_sym_static] = ACTIONS(3149),
    [anon_sym_LBRACK] = ACTIONS(3151),
    [anon_sym_LPAREN] = ACTIONS(3151),
    [anon_sym_return] = ACTIONS(3149),
    [anon_sym_ref] = ACTIONS(3149),
    [anon_sym_LBRACE] = ACTIONS(3151),
    [anon_sym_RBRACE] = ACTIONS(3151),
    [anon_sym_delegate] = ACTIONS(3149),
    [anon_sym_abstract] = ACTIONS(3149),
    [anon_sym_async] = ACTIONS(3149),
    [anon_sym_const] = ACTIONS(3149),
    [anon_sym_file] = ACTIONS(3149),
    [anon_sym_fixed] = ACTIONS(3149),
    [anon_sym_internal] = ACTIONS(3149),
    [anon_sym_new] = ACTIONS(3149),
    [anon_sym_override] = ACTIONS(3149),
    [anon_sym_partial] = ACTIONS(3149),
    [anon_sym_private] = ACTIONS(3149),
    [anon_sym_protected] = ACTIONS(3149),
    [anon_sym_public] = ACTIONS(3149),
    [anon_sym_readonly] = ACTIONS(3149),
    [anon_sym_required] = ACTIONS(3149),
    [anon_sym_sealed] = ACTIONS(3149),
    [anon_sym_virtual] = ACTIONS(3149),
    [anon_sym_volatile] = ACTIONS(3149),
    [anon_sym_where] = ACTIONS(3149),
    [anon_sym_notnull] = ACTIONS(3149),
    [anon_sym_unmanaged] = ACTIONS(3149),
    [anon_sym_checked] = ACTIONS(3149),
    [anon_sym_BANG] = ACTIONS(3151),
    [anon_sym_TILDE] = ACTIONS(3151),
    [anon_sym_PLUS_PLUS] = ACTIONS(3151),
    [anon_sym_DASH_DASH] = ACTIONS(3151),
    [anon_sym_true] = ACTIONS(3149),
    [anon_sym_false] = ACTIONS(3149),
    [anon_sym_PLUS] = ACTIONS(3149),
    [anon_sym_DASH] = ACTIONS(3149),
    [anon_sym_STAR] = ACTIONS(3151),
    [anon_sym_CARET] = ACTIONS(3151),
    [anon_sym_AMP] = ACTIONS(3151),
    [anon_sym_this] = ACTIONS(3149),
    [anon_sym_scoped] = ACTIONS(3149),
    [anon_sym_base] = ACTIONS(3149),
    [anon_sym_var] = ACTIONS(3149),
    [sym_predefined_type] = ACTIONS(3149),
    [anon_sym_break] = ACTIONS(3149),
    [anon_sym_unchecked] = ACTIONS(3149),
    [anon_sym_continue] = ACTIONS(3149),
    [anon_sym_do] = ACTIONS(3149),
    [anon_sym_while] = ACTIONS(3149),
    [anon_sym_for] = ACTIONS(3149),
    [anon_sym_lock] = ACTIONS(3149),
    [anon_sym_yield] = ACTIONS(3149),
    [anon_sym_switch] = ACTIONS(3149),
    [anon_sym_case] = ACTIONS(3149),
    [anon_sym_default] = ACTIONS(3149),
    [anon_sym_throw] = ACTIONS(3149),
    [anon_sym_try] = ACTIONS(3149),
    [anon_sym_when] = ACTIONS(3149),
    [anon_sym_await] = ACTIONS(3149),
    [anon_sym_foreach] = ACTIONS(3149),
    [anon_sym_goto] = ACTIONS(3149),
    [anon_sym_if] = ACTIONS(3149),
    [anon_sym_else] = ACTIONS(3149),
    [anon_sym_DOT_DOT] = ACTIONS(3151),
    [anon_sym_from] = ACTIONS(3149),
    [anon_sym_into] = ACTIONS(3149),
    [anon_sym_join] = ACTIONS(3149),
    [anon_sym_on] = ACTIONS(3149),
    [anon_sym_equals] = ACTIONS(3149),
    [anon_sym_let] = ACTIONS(3149),
    [anon_sym_orderby] = ACTIONS(3149),
    [anon_sym_ascending] = ACTIONS(3149),
    [anon_sym_descending] = ACTIONS(3149),
    [anon_sym_group] = ACTIONS(3149),
    [anon_sym_by] = ACTIONS(3149),
    [anon_sym_select] = ACTIONS(3149),
    [anon_sym_stackalloc] = ACTIONS(3149),
    [anon_sym_sizeof] = ACTIONS(3149),
    [anon_sym_typeof] = ACTIONS(3149),
    [anon_sym___makeref] = ACTIONS(3149),
    [anon_sym___reftype] = ACTIONS(3149),
    [anon_sym___refvalue] = ACTIONS(3149),
    [sym_null_literal] = ACTIONS(3149),
    [anon_sym_SQUOTE] = ACTIONS(3151),
    [sym_integer_literal] = ACTIONS(3149),
    [sym_real_literal] = ACTIONS(3151),
    [anon_sym_DQUOTE] = ACTIONS(3151),
    [sym_verbatim_string_literal] = ACTIONS(3151),
    [aux_sym_preproc_if_token1] = ACTIONS(3151),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3151),
    [sym_interpolation_verbatim_start] = ACTIONS(3151),
    [sym_interpolation_raw_start] = ACTIONS(3151),
    [sym_raw_string_start] = ACTIONS(3151),
  },
  [2712] = {
    [sym_preproc_region] = STATE(2712),
    [sym_preproc_endregion] = STATE(2712),
    [sym_preproc_line] = STATE(2712),
    [sym_preproc_pragma] = STATE(2712),
    [sym_preproc_nullable] = STATE(2712),
    [sym_preproc_error] = STATE(2712),
    [sym_preproc_warning] = STATE(2712),
    [sym_preproc_define] = STATE(2712),
    [sym_preproc_undef] = STATE(2712),
    [sym__identifier_token] = ACTIONS(3153),
    [anon_sym_extern] = ACTIONS(3153),
    [anon_sym_alias] = ACTIONS(3153),
    [anon_sym_SEMI] = ACTIONS(3155),
    [anon_sym_global] = ACTIONS(3153),
    [anon_sym_using] = ACTIONS(3153),
    [anon_sym_unsafe] = ACTIONS(3153),
    [anon_sym_static] = ACTIONS(3153),
    [anon_sym_LBRACK] = ACTIONS(3155),
    [anon_sym_LPAREN] = ACTIONS(3155),
    [anon_sym_return] = ACTIONS(3153),
    [anon_sym_ref] = ACTIONS(3153),
    [anon_sym_LBRACE] = ACTIONS(3155),
    [anon_sym_RBRACE] = ACTIONS(3155),
    [anon_sym_delegate] = ACTIONS(3153),
    [anon_sym_abstract] = ACTIONS(3153),
    [anon_sym_async] = ACTIONS(3153),
    [anon_sym_const] = ACTIONS(3153),
    [anon_sym_file] = ACTIONS(3153),
    [anon_sym_fixed] = ACTIONS(3153),
    [anon_sym_internal] = ACTIONS(3153),
    [anon_sym_new] = ACTIONS(3153),
    [anon_sym_override] = ACTIONS(3153),
    [anon_sym_partial] = ACTIONS(3153),
    [anon_sym_private] = ACTIONS(3153),
    [anon_sym_protected] = ACTIONS(3153),
    [anon_sym_public] = ACTIONS(3153),
    [anon_sym_readonly] = ACTIONS(3153),
    [anon_sym_required] = ACTIONS(3153),
    [anon_sym_sealed] = ACTIONS(3153),
    [anon_sym_virtual] = ACTIONS(3153),
    [anon_sym_volatile] = ACTIONS(3153),
    [anon_sym_where] = ACTIONS(3153),
    [anon_sym_notnull] = ACTIONS(3153),
    [anon_sym_unmanaged] = ACTIONS(3153),
    [anon_sym_checked] = ACTIONS(3153),
    [anon_sym_BANG] = ACTIONS(3155),
    [anon_sym_TILDE] = ACTIONS(3155),
    [anon_sym_PLUS_PLUS] = ACTIONS(3155),
    [anon_sym_DASH_DASH] = ACTIONS(3155),
    [anon_sym_true] = ACTIONS(3153),
    [anon_sym_false] = ACTIONS(3153),
    [anon_sym_PLUS] = ACTIONS(3153),
    [anon_sym_DASH] = ACTIONS(3153),
    [anon_sym_STAR] = ACTIONS(3155),
    [anon_sym_CARET] = ACTIONS(3155),
    [anon_sym_AMP] = ACTIONS(3155),
    [anon_sym_this] = ACTIONS(3153),
    [anon_sym_scoped] = ACTIONS(3153),
    [anon_sym_base] = ACTIONS(3153),
    [anon_sym_var] = ACTIONS(3153),
    [sym_predefined_type] = ACTIONS(3153),
    [anon_sym_break] = ACTIONS(3153),
    [anon_sym_unchecked] = ACTIONS(3153),
    [anon_sym_continue] = ACTIONS(3153),
    [anon_sym_do] = ACTIONS(3153),
    [anon_sym_while] = ACTIONS(3153),
    [anon_sym_for] = ACTIONS(3153),
    [anon_sym_lock] = ACTIONS(3153),
    [anon_sym_yield] = ACTIONS(3153),
    [anon_sym_switch] = ACTIONS(3153),
    [anon_sym_case] = ACTIONS(3153),
    [anon_sym_default] = ACTIONS(3153),
    [anon_sym_throw] = ACTIONS(3153),
    [anon_sym_try] = ACTIONS(3153),
    [anon_sym_when] = ACTIONS(3153),
    [anon_sym_await] = ACTIONS(3153),
    [anon_sym_foreach] = ACTIONS(3153),
    [anon_sym_goto] = ACTIONS(3153),
    [anon_sym_if] = ACTIONS(3153),
    [anon_sym_else] = ACTIONS(3153),
    [anon_sym_DOT_DOT] = ACTIONS(3155),
    [anon_sym_from] = ACTIONS(3153),
    [anon_sym_into] = ACTIONS(3153),
    [anon_sym_join] = ACTIONS(3153),
    [anon_sym_on] = ACTIONS(3153),
    [anon_sym_equals] = ACTIONS(3153),
    [anon_sym_let] = ACTIONS(3153),
    [anon_sym_orderby] = ACTIONS(3153),
    [anon_sym_ascending] = ACTIONS(3153),
    [anon_sym_descending] = ACTIONS(3153),
    [anon_sym_group] = ACTIONS(3153),
    [anon_sym_by] = ACTIONS(3153),
    [anon_sym_select] = ACTIONS(3153),
    [anon_sym_stackalloc] = ACTIONS(3153),
    [anon_sym_sizeof] = ACTIONS(3153),
    [anon_sym_typeof] = ACTIONS(3153),
    [anon_sym___makeref] = ACTIONS(3153),
    [anon_sym___reftype] = ACTIONS(3153),
    [anon_sym___refvalue] = ACTIONS(3153),
    [sym_null_literal] = ACTIONS(3153),
    [anon_sym_SQUOTE] = ACTIONS(3155),
    [sym_integer_literal] = ACTIONS(3153),
    [sym_real_literal] = ACTIONS(3155),
    [anon_sym_DQUOTE] = ACTIONS(3155),
    [sym_verbatim_string_literal] = ACTIONS(3155),
    [aux_sym_preproc_if_token1] = ACTIONS(3155),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3155),
    [sym_interpolation_verbatim_start] = ACTIONS(3155),
    [sym_interpolation_raw_start] = ACTIONS(3155),
    [sym_raw_string_start] = ACTIONS(3155),
  },
  [2713] = {
    [sym_preproc_region] = STATE(2713),
    [sym_preproc_endregion] = STATE(2713),
    [sym_preproc_line] = STATE(2713),
    [sym_preproc_pragma] = STATE(2713),
    [sym_preproc_nullable] = STATE(2713),
    [sym_preproc_error] = STATE(2713),
    [sym_preproc_warning] = STATE(2713),
    [sym_preproc_define] = STATE(2713),
    [sym_preproc_undef] = STATE(2713),
    [sym__identifier_token] = ACTIONS(3157),
    [anon_sym_extern] = ACTIONS(3157),
    [anon_sym_alias] = ACTIONS(3157),
    [anon_sym_SEMI] = ACTIONS(3159),
    [anon_sym_global] = ACTIONS(3157),
    [anon_sym_using] = ACTIONS(3157),
    [anon_sym_unsafe] = ACTIONS(3157),
    [anon_sym_static] = ACTIONS(3157),
    [anon_sym_LBRACK] = ACTIONS(3159),
    [anon_sym_LPAREN] = ACTIONS(3159),
    [anon_sym_return] = ACTIONS(3157),
    [anon_sym_ref] = ACTIONS(3157),
    [anon_sym_LBRACE] = ACTIONS(3159),
    [anon_sym_RBRACE] = ACTIONS(3159),
    [anon_sym_delegate] = ACTIONS(3157),
    [anon_sym_abstract] = ACTIONS(3157),
    [anon_sym_async] = ACTIONS(3157),
    [anon_sym_const] = ACTIONS(3157),
    [anon_sym_file] = ACTIONS(3157),
    [anon_sym_fixed] = ACTIONS(3157),
    [anon_sym_internal] = ACTIONS(3157),
    [anon_sym_new] = ACTIONS(3157),
    [anon_sym_override] = ACTIONS(3157),
    [anon_sym_partial] = ACTIONS(3157),
    [anon_sym_private] = ACTIONS(3157),
    [anon_sym_protected] = ACTIONS(3157),
    [anon_sym_public] = ACTIONS(3157),
    [anon_sym_readonly] = ACTIONS(3157),
    [anon_sym_required] = ACTIONS(3157),
    [anon_sym_sealed] = ACTIONS(3157),
    [anon_sym_virtual] = ACTIONS(3157),
    [anon_sym_volatile] = ACTIONS(3157),
    [anon_sym_where] = ACTIONS(3157),
    [anon_sym_notnull] = ACTIONS(3157),
    [anon_sym_unmanaged] = ACTIONS(3157),
    [anon_sym_checked] = ACTIONS(3157),
    [anon_sym_BANG] = ACTIONS(3159),
    [anon_sym_TILDE] = ACTIONS(3159),
    [anon_sym_PLUS_PLUS] = ACTIONS(3159),
    [anon_sym_DASH_DASH] = ACTIONS(3159),
    [anon_sym_true] = ACTIONS(3157),
    [anon_sym_false] = ACTIONS(3157),
    [anon_sym_PLUS] = ACTIONS(3157),
    [anon_sym_DASH] = ACTIONS(3157),
    [anon_sym_STAR] = ACTIONS(3159),
    [anon_sym_CARET] = ACTIONS(3159),
    [anon_sym_AMP] = ACTIONS(3159),
    [anon_sym_this] = ACTIONS(3157),
    [anon_sym_scoped] = ACTIONS(3157),
    [anon_sym_base] = ACTIONS(3157),
    [anon_sym_var] = ACTIONS(3157),
    [sym_predefined_type] = ACTIONS(3157),
    [anon_sym_break] = ACTIONS(3157),
    [anon_sym_unchecked] = ACTIONS(3157),
    [anon_sym_continue] = ACTIONS(3157),
    [anon_sym_do] = ACTIONS(3157),
    [anon_sym_while] = ACTIONS(3157),
    [anon_sym_for] = ACTIONS(3157),
    [anon_sym_lock] = ACTIONS(3157),
    [anon_sym_yield] = ACTIONS(3157),
    [anon_sym_switch] = ACTIONS(3157),
    [anon_sym_case] = ACTIONS(3157),
    [anon_sym_default] = ACTIONS(3157),
    [anon_sym_throw] = ACTIONS(3157),
    [anon_sym_try] = ACTIONS(3157),
    [anon_sym_when] = ACTIONS(3157),
    [anon_sym_await] = ACTIONS(3157),
    [anon_sym_foreach] = ACTIONS(3157),
    [anon_sym_goto] = ACTIONS(3157),
    [anon_sym_if] = ACTIONS(3157),
    [anon_sym_else] = ACTIONS(3157),
    [anon_sym_DOT_DOT] = ACTIONS(3159),
    [anon_sym_from] = ACTIONS(3157),
    [anon_sym_into] = ACTIONS(3157),
    [anon_sym_join] = ACTIONS(3157),
    [anon_sym_on] = ACTIONS(3157),
    [anon_sym_equals] = ACTIONS(3157),
    [anon_sym_let] = ACTIONS(3157),
    [anon_sym_orderby] = ACTIONS(3157),
    [anon_sym_ascending] = ACTIONS(3157),
    [anon_sym_descending] = ACTIONS(3157),
    [anon_sym_group] = ACTIONS(3157),
    [anon_sym_by] = ACTIONS(3157),
    [anon_sym_select] = ACTIONS(3157),
    [anon_sym_stackalloc] = ACTIONS(3157),
    [anon_sym_sizeof] = ACTIONS(3157),
    [anon_sym_typeof] = ACTIONS(3157),
    [anon_sym___makeref] = ACTIONS(3157),
    [anon_sym___reftype] = ACTIONS(3157),
    [anon_sym___refvalue] = ACTIONS(3157),
    [sym_null_literal] = ACTIONS(3157),
    [anon_sym_SQUOTE] = ACTIONS(3159),
    [sym_integer_literal] = ACTIONS(3157),
    [sym_real_literal] = ACTIONS(3159),
    [anon_sym_DQUOTE] = ACTIONS(3159),
    [sym_verbatim_string_literal] = ACTIONS(3159),
    [aux_sym_preproc_if_token1] = ACTIONS(3159),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3159),
    [sym_interpolation_verbatim_start] = ACTIONS(3159),
    [sym_interpolation_raw_start] = ACTIONS(3159),
    [sym_raw_string_start] = ACTIONS(3159),
  },
  [2714] = {
    [sym_preproc_region] = STATE(2714),
    [sym_preproc_endregion] = STATE(2714),
    [sym_preproc_line] = STATE(2714),
    [sym_preproc_pragma] = STATE(2714),
    [sym_preproc_nullable] = STATE(2714),
    [sym_preproc_error] = STATE(2714),
    [sym_preproc_warning] = STATE(2714),
    [sym_preproc_define] = STATE(2714),
    [sym_preproc_undef] = STATE(2714),
    [sym__identifier_token] = ACTIONS(3161),
    [anon_sym_extern] = ACTIONS(3161),
    [anon_sym_alias] = ACTIONS(3161),
    [anon_sym_SEMI] = ACTIONS(3163),
    [anon_sym_global] = ACTIONS(3161),
    [anon_sym_using] = ACTIONS(3161),
    [anon_sym_unsafe] = ACTIONS(3161),
    [anon_sym_static] = ACTIONS(3161),
    [anon_sym_LBRACK] = ACTIONS(3163),
    [anon_sym_LPAREN] = ACTIONS(3163),
    [anon_sym_return] = ACTIONS(3161),
    [anon_sym_ref] = ACTIONS(3161),
    [anon_sym_LBRACE] = ACTIONS(3163),
    [anon_sym_RBRACE] = ACTIONS(3163),
    [anon_sym_delegate] = ACTIONS(3161),
    [anon_sym_abstract] = ACTIONS(3161),
    [anon_sym_async] = ACTIONS(3161),
    [anon_sym_const] = ACTIONS(3161),
    [anon_sym_file] = ACTIONS(3161),
    [anon_sym_fixed] = ACTIONS(3161),
    [anon_sym_internal] = ACTIONS(3161),
    [anon_sym_new] = ACTIONS(3161),
    [anon_sym_override] = ACTIONS(3161),
    [anon_sym_partial] = ACTIONS(3161),
    [anon_sym_private] = ACTIONS(3161),
    [anon_sym_protected] = ACTIONS(3161),
    [anon_sym_public] = ACTIONS(3161),
    [anon_sym_readonly] = ACTIONS(3161),
    [anon_sym_required] = ACTIONS(3161),
    [anon_sym_sealed] = ACTIONS(3161),
    [anon_sym_virtual] = ACTIONS(3161),
    [anon_sym_volatile] = ACTIONS(3161),
    [anon_sym_where] = ACTIONS(3161),
    [anon_sym_notnull] = ACTIONS(3161),
    [anon_sym_unmanaged] = ACTIONS(3161),
    [anon_sym_checked] = ACTIONS(3161),
    [anon_sym_BANG] = ACTIONS(3163),
    [anon_sym_TILDE] = ACTIONS(3163),
    [anon_sym_PLUS_PLUS] = ACTIONS(3163),
    [anon_sym_DASH_DASH] = ACTIONS(3163),
    [anon_sym_true] = ACTIONS(3161),
    [anon_sym_false] = ACTIONS(3161),
    [anon_sym_PLUS] = ACTIONS(3161),
    [anon_sym_DASH] = ACTIONS(3161),
    [anon_sym_STAR] = ACTIONS(3163),
    [anon_sym_CARET] = ACTIONS(3163),
    [anon_sym_AMP] = ACTIONS(3163),
    [anon_sym_this] = ACTIONS(3161),
    [anon_sym_scoped] = ACTIONS(3161),
    [anon_sym_base] = ACTIONS(3161),
    [anon_sym_var] = ACTIONS(3161),
    [sym_predefined_type] = ACTIONS(3161),
    [anon_sym_break] = ACTIONS(3161),
    [anon_sym_unchecked] = ACTIONS(3161),
    [anon_sym_continue] = ACTIONS(3161),
    [anon_sym_do] = ACTIONS(3161),
    [anon_sym_while] = ACTIONS(3161),
    [anon_sym_for] = ACTIONS(3161),
    [anon_sym_lock] = ACTIONS(3161),
    [anon_sym_yield] = ACTIONS(3161),
    [anon_sym_switch] = ACTIONS(3161),
    [anon_sym_case] = ACTIONS(3161),
    [anon_sym_default] = ACTIONS(3161),
    [anon_sym_throw] = ACTIONS(3161),
    [anon_sym_try] = ACTIONS(3161),
    [anon_sym_when] = ACTIONS(3161),
    [anon_sym_await] = ACTIONS(3161),
    [anon_sym_foreach] = ACTIONS(3161),
    [anon_sym_goto] = ACTIONS(3161),
    [anon_sym_if] = ACTIONS(3161),
    [anon_sym_else] = ACTIONS(3161),
    [anon_sym_DOT_DOT] = ACTIONS(3163),
    [anon_sym_from] = ACTIONS(3161),
    [anon_sym_into] = ACTIONS(3161),
    [anon_sym_join] = ACTIONS(3161),
    [anon_sym_on] = ACTIONS(3161),
    [anon_sym_equals] = ACTIONS(3161),
    [anon_sym_let] = ACTIONS(3161),
    [anon_sym_orderby] = ACTIONS(3161),
    [anon_sym_ascending] = ACTIONS(3161),
    [anon_sym_descending] = ACTIONS(3161),
    [anon_sym_group] = ACTIONS(3161),
    [anon_sym_by] = ACTIONS(3161),
    [anon_sym_select] = ACTIONS(3161),
    [anon_sym_stackalloc] = ACTIONS(3161),
    [anon_sym_sizeof] = ACTIONS(3161),
    [anon_sym_typeof] = ACTIONS(3161),
    [anon_sym___makeref] = ACTIONS(3161),
    [anon_sym___reftype] = ACTIONS(3161),
    [anon_sym___refvalue] = ACTIONS(3161),
    [sym_null_literal] = ACTIONS(3161),
    [anon_sym_SQUOTE] = ACTIONS(3163),
    [sym_integer_literal] = ACTIONS(3161),
    [sym_real_literal] = ACTIONS(3163),
    [anon_sym_DQUOTE] = ACTIONS(3163),
    [sym_verbatim_string_literal] = ACTIONS(3163),
    [aux_sym_preproc_if_token1] = ACTIONS(3163),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3163),
    [sym_interpolation_verbatim_start] = ACTIONS(3163),
    [sym_interpolation_raw_start] = ACTIONS(3163),
    [sym_raw_string_start] = ACTIONS(3163),
  },
  [2715] = {
    [sym_preproc_region] = STATE(2715),
    [sym_preproc_endregion] = STATE(2715),
    [sym_preproc_line] = STATE(2715),
    [sym_preproc_pragma] = STATE(2715),
    [sym_preproc_nullable] = STATE(2715),
    [sym_preproc_error] = STATE(2715),
    [sym_preproc_warning] = STATE(2715),
    [sym_preproc_define] = STATE(2715),
    [sym_preproc_undef] = STATE(2715),
    [sym__identifier_token] = ACTIONS(3269),
    [anon_sym_extern] = ACTIONS(3269),
    [anon_sym_alias] = ACTIONS(3269),
    [anon_sym_SEMI] = ACTIONS(3271),
    [anon_sym_global] = ACTIONS(3269),
    [anon_sym_using] = ACTIONS(3269),
    [anon_sym_unsafe] = ACTIONS(3269),
    [anon_sym_static] = ACTIONS(3269),
    [anon_sym_LBRACK] = ACTIONS(3271),
    [anon_sym_LPAREN] = ACTIONS(3271),
    [anon_sym_return] = ACTIONS(3269),
    [anon_sym_ref] = ACTIONS(3269),
    [anon_sym_LBRACE] = ACTIONS(3271),
    [anon_sym_RBRACE] = ACTIONS(3271),
    [anon_sym_delegate] = ACTIONS(3269),
    [anon_sym_abstract] = ACTIONS(3269),
    [anon_sym_async] = ACTIONS(3269),
    [anon_sym_const] = ACTIONS(3269),
    [anon_sym_file] = ACTIONS(3269),
    [anon_sym_fixed] = ACTIONS(3269),
    [anon_sym_internal] = ACTIONS(3269),
    [anon_sym_new] = ACTIONS(3269),
    [anon_sym_override] = ACTIONS(3269),
    [anon_sym_partial] = ACTIONS(3269),
    [anon_sym_private] = ACTIONS(3269),
    [anon_sym_protected] = ACTIONS(3269),
    [anon_sym_public] = ACTIONS(3269),
    [anon_sym_readonly] = ACTIONS(3269),
    [anon_sym_required] = ACTIONS(3269),
    [anon_sym_sealed] = ACTIONS(3269),
    [anon_sym_virtual] = ACTIONS(3269),
    [anon_sym_volatile] = ACTIONS(3269),
    [anon_sym_where] = ACTIONS(3269),
    [anon_sym_notnull] = ACTIONS(3269),
    [anon_sym_unmanaged] = ACTIONS(3269),
    [anon_sym_checked] = ACTIONS(3269),
    [anon_sym_BANG] = ACTIONS(3271),
    [anon_sym_TILDE] = ACTIONS(3271),
    [anon_sym_PLUS_PLUS] = ACTIONS(3271),
    [anon_sym_DASH_DASH] = ACTIONS(3271),
    [anon_sym_true] = ACTIONS(3269),
    [anon_sym_false] = ACTIONS(3269),
    [anon_sym_PLUS] = ACTIONS(3269),
    [anon_sym_DASH] = ACTIONS(3269),
    [anon_sym_STAR] = ACTIONS(3271),
    [anon_sym_CARET] = ACTIONS(3271),
    [anon_sym_AMP] = ACTIONS(3271),
    [anon_sym_this] = ACTIONS(3269),
    [anon_sym_scoped] = ACTIONS(3269),
    [anon_sym_base] = ACTIONS(3269),
    [anon_sym_var] = ACTIONS(3269),
    [sym_predefined_type] = ACTIONS(3269),
    [anon_sym_break] = ACTIONS(3269),
    [anon_sym_unchecked] = ACTIONS(3269),
    [anon_sym_continue] = ACTIONS(3269),
    [anon_sym_do] = ACTIONS(3269),
    [anon_sym_while] = ACTIONS(3269),
    [anon_sym_for] = ACTIONS(3269),
    [anon_sym_lock] = ACTIONS(3269),
    [anon_sym_yield] = ACTIONS(3269),
    [anon_sym_switch] = ACTIONS(3269),
    [anon_sym_case] = ACTIONS(3269),
    [anon_sym_default] = ACTIONS(3269),
    [anon_sym_throw] = ACTIONS(3269),
    [anon_sym_try] = ACTIONS(3269),
    [anon_sym_when] = ACTIONS(3269),
    [anon_sym_await] = ACTIONS(3269),
    [anon_sym_foreach] = ACTIONS(3269),
    [anon_sym_goto] = ACTIONS(3269),
    [anon_sym_if] = ACTIONS(3269),
    [anon_sym_else] = ACTIONS(3269),
    [anon_sym_DOT_DOT] = ACTIONS(3271),
    [anon_sym_from] = ACTIONS(3269),
    [anon_sym_into] = ACTIONS(3269),
    [anon_sym_join] = ACTIONS(3269),
    [anon_sym_on] = ACTIONS(3269),
    [anon_sym_equals] = ACTIONS(3269),
    [anon_sym_let] = ACTIONS(3269),
    [anon_sym_orderby] = ACTIONS(3269),
    [anon_sym_ascending] = ACTIONS(3269),
    [anon_sym_descending] = ACTIONS(3269),
    [anon_sym_group] = ACTIONS(3269),
    [anon_sym_by] = ACTIONS(3269),
    [anon_sym_select] = ACTIONS(3269),
    [anon_sym_stackalloc] = ACTIONS(3269),
    [anon_sym_sizeof] = ACTIONS(3269),
    [anon_sym_typeof] = ACTIONS(3269),
    [anon_sym___makeref] = ACTIONS(3269),
    [anon_sym___reftype] = ACTIONS(3269),
    [anon_sym___refvalue] = ACTIONS(3269),
    [sym_null_literal] = ACTIONS(3269),
    [anon_sym_SQUOTE] = ACTIONS(3271),
    [sym_integer_literal] = ACTIONS(3269),
    [sym_real_literal] = ACTIONS(3271),
    [anon_sym_DQUOTE] = ACTIONS(3271),
    [sym_verbatim_string_literal] = ACTIONS(3271),
    [aux_sym_preproc_if_token1] = ACTIONS(3271),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3271),
    [sym_interpolation_verbatim_start] = ACTIONS(3271),
    [sym_interpolation_raw_start] = ACTIONS(3271),
    [sym_raw_string_start] = ACTIONS(3271),
  },
  [2716] = {
    [sym_preproc_region] = STATE(2716),
    [sym_preproc_endregion] = STATE(2716),
    [sym_preproc_line] = STATE(2716),
    [sym_preproc_pragma] = STATE(2716),
    [sym_preproc_nullable] = STATE(2716),
    [sym_preproc_error] = STATE(2716),
    [sym_preproc_warning] = STATE(2716),
    [sym_preproc_define] = STATE(2716),
    [sym_preproc_undef] = STATE(2716),
    [sym__identifier_token] = ACTIONS(3185),
    [anon_sym_extern] = ACTIONS(3185),
    [anon_sym_alias] = ACTIONS(3185),
    [anon_sym_SEMI] = ACTIONS(3187),
    [anon_sym_global] = ACTIONS(3185),
    [anon_sym_using] = ACTIONS(3185),
    [anon_sym_unsafe] = ACTIONS(3185),
    [anon_sym_static] = ACTIONS(3185),
    [anon_sym_LBRACK] = ACTIONS(3187),
    [anon_sym_LPAREN] = ACTIONS(3187),
    [anon_sym_return] = ACTIONS(3185),
    [anon_sym_ref] = ACTIONS(3185),
    [anon_sym_LBRACE] = ACTIONS(3187),
    [anon_sym_RBRACE] = ACTIONS(3187),
    [anon_sym_delegate] = ACTIONS(3185),
    [anon_sym_abstract] = ACTIONS(3185),
    [anon_sym_async] = ACTIONS(3185),
    [anon_sym_const] = ACTIONS(3185),
    [anon_sym_file] = ACTIONS(3185),
    [anon_sym_fixed] = ACTIONS(3185),
    [anon_sym_internal] = ACTIONS(3185),
    [anon_sym_new] = ACTIONS(3185),
    [anon_sym_override] = ACTIONS(3185),
    [anon_sym_partial] = ACTIONS(3185),
    [anon_sym_private] = ACTIONS(3185),
    [anon_sym_protected] = ACTIONS(3185),
    [anon_sym_public] = ACTIONS(3185),
    [anon_sym_readonly] = ACTIONS(3185),
    [anon_sym_required] = ACTIONS(3185),
    [anon_sym_sealed] = ACTIONS(3185),
    [anon_sym_virtual] = ACTIONS(3185),
    [anon_sym_volatile] = ACTIONS(3185),
    [anon_sym_where] = ACTIONS(3185),
    [anon_sym_notnull] = ACTIONS(3185),
    [anon_sym_unmanaged] = ACTIONS(3185),
    [anon_sym_checked] = ACTIONS(3185),
    [anon_sym_BANG] = ACTIONS(3187),
    [anon_sym_TILDE] = ACTIONS(3187),
    [anon_sym_PLUS_PLUS] = ACTIONS(3187),
    [anon_sym_DASH_DASH] = ACTIONS(3187),
    [anon_sym_true] = ACTIONS(3185),
    [anon_sym_false] = ACTIONS(3185),
    [anon_sym_PLUS] = ACTIONS(3185),
    [anon_sym_DASH] = ACTIONS(3185),
    [anon_sym_STAR] = ACTIONS(3187),
    [anon_sym_CARET] = ACTIONS(3187),
    [anon_sym_AMP] = ACTIONS(3187),
    [anon_sym_this] = ACTIONS(3185),
    [anon_sym_scoped] = ACTIONS(3185),
    [anon_sym_base] = ACTIONS(3185),
    [anon_sym_var] = ACTIONS(3185),
    [sym_predefined_type] = ACTIONS(3185),
    [anon_sym_break] = ACTIONS(3185),
    [anon_sym_unchecked] = ACTIONS(3185),
    [anon_sym_continue] = ACTIONS(3185),
    [anon_sym_do] = ACTIONS(3185),
    [anon_sym_while] = ACTIONS(3185),
    [anon_sym_for] = ACTIONS(3185),
    [anon_sym_lock] = ACTIONS(3185),
    [anon_sym_yield] = ACTIONS(3185),
    [anon_sym_switch] = ACTIONS(3185),
    [anon_sym_case] = ACTIONS(3185),
    [anon_sym_default] = ACTIONS(3185),
    [anon_sym_throw] = ACTIONS(3185),
    [anon_sym_try] = ACTIONS(3185),
    [anon_sym_when] = ACTIONS(3185),
    [anon_sym_await] = ACTIONS(3185),
    [anon_sym_foreach] = ACTIONS(3185),
    [anon_sym_goto] = ACTIONS(3185),
    [anon_sym_if] = ACTIONS(3185),
    [anon_sym_else] = ACTIONS(3185),
    [anon_sym_DOT_DOT] = ACTIONS(3187),
    [anon_sym_from] = ACTIONS(3185),
    [anon_sym_into] = ACTIONS(3185),
    [anon_sym_join] = ACTIONS(3185),
    [anon_sym_on] = ACTIONS(3185),
    [anon_sym_equals] = ACTIONS(3185),
    [anon_sym_let] = ACTIONS(3185),
    [anon_sym_orderby] = ACTIONS(3185),
    [anon_sym_ascending] = ACTIONS(3185),
    [anon_sym_descending] = ACTIONS(3185),
    [anon_sym_group] = ACTIONS(3185),
    [anon_sym_by] = ACTIONS(3185),
    [anon_sym_select] = ACTIONS(3185),
    [anon_sym_stackalloc] = ACTIONS(3185),
    [anon_sym_sizeof] = ACTIONS(3185),
    [anon_sym_typeof] = ACTIONS(3185),
    [anon_sym___makeref] = ACTIONS(3185),
    [anon_sym___reftype] = ACTIONS(3185),
    [anon_sym___refvalue] = ACTIONS(3185),
    [sym_null_literal] = ACTIONS(3185),
    [anon_sym_SQUOTE] = ACTIONS(3187),
    [sym_integer_literal] = ACTIONS(3185),
    [sym_real_literal] = ACTIONS(3187),
    [anon_sym_DQUOTE] = ACTIONS(3187),
    [sym_verbatim_string_literal] = ACTIONS(3187),
    [aux_sym_preproc_if_token1] = ACTIONS(3187),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3187),
    [sym_interpolation_verbatim_start] = ACTIONS(3187),
    [sym_interpolation_raw_start] = ACTIONS(3187),
    [sym_raw_string_start] = ACTIONS(3187),
  },
  [2717] = {
    [sym_preproc_region] = STATE(2717),
    [sym_preproc_endregion] = STATE(2717),
    [sym_preproc_line] = STATE(2717),
    [sym_preproc_pragma] = STATE(2717),
    [sym_preproc_nullable] = STATE(2717),
    [sym_preproc_error] = STATE(2717),
    [sym_preproc_warning] = STATE(2717),
    [sym_preproc_define] = STATE(2717),
    [sym_preproc_undef] = STATE(2717),
    [sym__identifier_token] = ACTIONS(3165),
    [anon_sym_extern] = ACTIONS(3165),
    [anon_sym_alias] = ACTIONS(3165),
    [anon_sym_SEMI] = ACTIONS(3167),
    [anon_sym_global] = ACTIONS(3165),
    [anon_sym_using] = ACTIONS(3165),
    [anon_sym_unsafe] = ACTIONS(3165),
    [anon_sym_static] = ACTIONS(3165),
    [anon_sym_LBRACK] = ACTIONS(3167),
    [anon_sym_LPAREN] = ACTIONS(3167),
    [anon_sym_return] = ACTIONS(3165),
    [anon_sym_ref] = ACTIONS(3165),
    [anon_sym_LBRACE] = ACTIONS(3167),
    [anon_sym_RBRACE] = ACTIONS(3167),
    [anon_sym_delegate] = ACTIONS(3165),
    [anon_sym_abstract] = ACTIONS(3165),
    [anon_sym_async] = ACTIONS(3165),
    [anon_sym_const] = ACTIONS(3165),
    [anon_sym_file] = ACTIONS(3165),
    [anon_sym_fixed] = ACTIONS(3165),
    [anon_sym_internal] = ACTIONS(3165),
    [anon_sym_new] = ACTIONS(3165),
    [anon_sym_override] = ACTIONS(3165),
    [anon_sym_partial] = ACTIONS(3165),
    [anon_sym_private] = ACTIONS(3165),
    [anon_sym_protected] = ACTIONS(3165),
    [anon_sym_public] = ACTIONS(3165),
    [anon_sym_readonly] = ACTIONS(3165),
    [anon_sym_required] = ACTIONS(3165),
    [anon_sym_sealed] = ACTIONS(3165),
    [anon_sym_virtual] = ACTIONS(3165),
    [anon_sym_volatile] = ACTIONS(3165),
    [anon_sym_where] = ACTIONS(3165),
    [anon_sym_notnull] = ACTIONS(3165),
    [anon_sym_unmanaged] = ACTIONS(3165),
    [anon_sym_checked] = ACTIONS(3165),
    [anon_sym_BANG] = ACTIONS(3167),
    [anon_sym_TILDE] = ACTIONS(3167),
    [anon_sym_PLUS_PLUS] = ACTIONS(3167),
    [anon_sym_DASH_DASH] = ACTIONS(3167),
    [anon_sym_true] = ACTIONS(3165),
    [anon_sym_false] = ACTIONS(3165),
    [anon_sym_PLUS] = ACTIONS(3165),
    [anon_sym_DASH] = ACTIONS(3165),
    [anon_sym_STAR] = ACTIONS(3167),
    [anon_sym_CARET] = ACTIONS(3167),
    [anon_sym_AMP] = ACTIONS(3167),
    [anon_sym_this] = ACTIONS(3165),
    [anon_sym_scoped] = ACTIONS(3165),
    [anon_sym_base] = ACTIONS(3165),
    [anon_sym_var] = ACTIONS(3165),
    [sym_predefined_type] = ACTIONS(3165),
    [anon_sym_break] = ACTIONS(3165),
    [anon_sym_unchecked] = ACTIONS(3165),
    [anon_sym_continue] = ACTIONS(3165),
    [anon_sym_do] = ACTIONS(3165),
    [anon_sym_while] = ACTIONS(3165),
    [anon_sym_for] = ACTIONS(3165),
    [anon_sym_lock] = ACTIONS(3165),
    [anon_sym_yield] = ACTIONS(3165),
    [anon_sym_switch] = ACTIONS(3165),
    [anon_sym_case] = ACTIONS(3165),
    [anon_sym_default] = ACTIONS(3165),
    [anon_sym_throw] = ACTIONS(3165),
    [anon_sym_try] = ACTIONS(3165),
    [anon_sym_when] = ACTIONS(3165),
    [anon_sym_await] = ACTIONS(3165),
    [anon_sym_foreach] = ACTIONS(3165),
    [anon_sym_goto] = ACTIONS(3165),
    [anon_sym_if] = ACTIONS(3165),
    [anon_sym_else] = ACTIONS(3165),
    [anon_sym_DOT_DOT] = ACTIONS(3167),
    [anon_sym_from] = ACTIONS(3165),
    [anon_sym_into] = ACTIONS(3165),
    [anon_sym_join] = ACTIONS(3165),
    [anon_sym_on] = ACTIONS(3165),
    [anon_sym_equals] = ACTIONS(3165),
    [anon_sym_let] = ACTIONS(3165),
    [anon_sym_orderby] = ACTIONS(3165),
    [anon_sym_ascending] = ACTIONS(3165),
    [anon_sym_descending] = ACTIONS(3165),
    [anon_sym_group] = ACTIONS(3165),
    [anon_sym_by] = ACTIONS(3165),
    [anon_sym_select] = ACTIONS(3165),
    [anon_sym_stackalloc] = ACTIONS(3165),
    [anon_sym_sizeof] = ACTIONS(3165),
    [anon_sym_typeof] = ACTIONS(3165),
    [anon_sym___makeref] = ACTIONS(3165),
    [anon_sym___reftype] = ACTIONS(3165),
    [anon_sym___refvalue] = ACTIONS(3165),
    [sym_null_literal] = ACTIONS(3165),
    [anon_sym_SQUOTE] = ACTIONS(3167),
    [sym_integer_literal] = ACTIONS(3165),
    [sym_real_literal] = ACTIONS(3167),
    [anon_sym_DQUOTE] = ACTIONS(3167),
    [sym_verbatim_string_literal] = ACTIONS(3167),
    [aux_sym_preproc_if_token1] = ACTIONS(3167),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3167),
    [sym_interpolation_verbatim_start] = ACTIONS(3167),
    [sym_interpolation_raw_start] = ACTIONS(3167),
    [sym_raw_string_start] = ACTIONS(3167),
  },
  [2718] = {
    [sym_preproc_region] = STATE(2718),
    [sym_preproc_endregion] = STATE(2718),
    [sym_preproc_line] = STATE(2718),
    [sym_preproc_pragma] = STATE(2718),
    [sym_preproc_nullable] = STATE(2718),
    [sym_preproc_error] = STATE(2718),
    [sym_preproc_warning] = STATE(2718),
    [sym_preproc_define] = STATE(2718),
    [sym_preproc_undef] = STATE(2718),
    [sym__identifier_token] = ACTIONS(3245),
    [anon_sym_extern] = ACTIONS(3245),
    [anon_sym_alias] = ACTIONS(3245),
    [anon_sym_SEMI] = ACTIONS(3247),
    [anon_sym_global] = ACTIONS(3245),
    [anon_sym_using] = ACTIONS(3245),
    [anon_sym_unsafe] = ACTIONS(3245),
    [anon_sym_static] = ACTIONS(3245),
    [anon_sym_LBRACK] = ACTIONS(3247),
    [anon_sym_LPAREN] = ACTIONS(3247),
    [anon_sym_return] = ACTIONS(3245),
    [anon_sym_ref] = ACTIONS(3245),
    [anon_sym_LBRACE] = ACTIONS(3247),
    [anon_sym_RBRACE] = ACTIONS(3247),
    [anon_sym_delegate] = ACTIONS(3245),
    [anon_sym_abstract] = ACTIONS(3245),
    [anon_sym_async] = ACTIONS(3245),
    [anon_sym_const] = ACTIONS(3245),
    [anon_sym_file] = ACTIONS(3245),
    [anon_sym_fixed] = ACTIONS(3245),
    [anon_sym_internal] = ACTIONS(3245),
    [anon_sym_new] = ACTIONS(3245),
    [anon_sym_override] = ACTIONS(3245),
    [anon_sym_partial] = ACTIONS(3245),
    [anon_sym_private] = ACTIONS(3245),
    [anon_sym_protected] = ACTIONS(3245),
    [anon_sym_public] = ACTIONS(3245),
    [anon_sym_readonly] = ACTIONS(3245),
    [anon_sym_required] = ACTIONS(3245),
    [anon_sym_sealed] = ACTIONS(3245),
    [anon_sym_virtual] = ACTIONS(3245),
    [anon_sym_volatile] = ACTIONS(3245),
    [anon_sym_where] = ACTIONS(3245),
    [anon_sym_notnull] = ACTIONS(3245),
    [anon_sym_unmanaged] = ACTIONS(3245),
    [anon_sym_checked] = ACTIONS(3245),
    [anon_sym_BANG] = ACTIONS(3247),
    [anon_sym_TILDE] = ACTIONS(3247),
    [anon_sym_PLUS_PLUS] = ACTIONS(3247),
    [anon_sym_DASH_DASH] = ACTIONS(3247),
    [anon_sym_true] = ACTIONS(3245),
    [anon_sym_false] = ACTIONS(3245),
    [anon_sym_PLUS] = ACTIONS(3245),
    [anon_sym_DASH] = ACTIONS(3245),
    [anon_sym_STAR] = ACTIONS(3247),
    [anon_sym_CARET] = ACTIONS(3247),
    [anon_sym_AMP] = ACTIONS(3247),
    [anon_sym_this] = ACTIONS(3245),
    [anon_sym_scoped] = ACTIONS(3245),
    [anon_sym_base] = ACTIONS(3245),
    [anon_sym_var] = ACTIONS(3245),
    [sym_predefined_type] = ACTIONS(3245),
    [anon_sym_break] = ACTIONS(3245),
    [anon_sym_unchecked] = ACTIONS(3245),
    [anon_sym_continue] = ACTIONS(3245),
    [anon_sym_do] = ACTIONS(3245),
    [anon_sym_while] = ACTIONS(3245),
    [anon_sym_for] = ACTIONS(3245),
    [anon_sym_lock] = ACTIONS(3245),
    [anon_sym_yield] = ACTIONS(3245),
    [anon_sym_switch] = ACTIONS(3245),
    [anon_sym_case] = ACTIONS(3245),
    [anon_sym_default] = ACTIONS(3245),
    [anon_sym_throw] = ACTIONS(3245),
    [anon_sym_try] = ACTIONS(3245),
    [anon_sym_when] = ACTIONS(3245),
    [anon_sym_await] = ACTIONS(3245),
    [anon_sym_foreach] = ACTIONS(3245),
    [anon_sym_goto] = ACTIONS(3245),
    [anon_sym_if] = ACTIONS(3245),
    [anon_sym_else] = ACTIONS(3245),
    [anon_sym_DOT_DOT] = ACTIONS(3247),
    [anon_sym_from] = ACTIONS(3245),
    [anon_sym_into] = ACTIONS(3245),
    [anon_sym_join] = ACTIONS(3245),
    [anon_sym_on] = ACTIONS(3245),
    [anon_sym_equals] = ACTIONS(3245),
    [anon_sym_let] = ACTIONS(3245),
    [anon_sym_orderby] = ACTIONS(3245),
    [anon_sym_ascending] = ACTIONS(3245),
    [anon_sym_descending] = ACTIONS(3245),
    [anon_sym_group] = ACTIONS(3245),
    [anon_sym_by] = ACTIONS(3245),
    [anon_sym_select] = ACTIONS(3245),
    [anon_sym_stackalloc] = ACTIONS(3245),
    [anon_sym_sizeof] = ACTIONS(3245),
    [anon_sym_typeof] = ACTIONS(3245),
    [anon_sym___makeref] = ACTIONS(3245),
    [anon_sym___reftype] = ACTIONS(3245),
    [anon_sym___refvalue] = ACTIONS(3245),
    [sym_null_literal] = ACTIONS(3245),
    [anon_sym_SQUOTE] = ACTIONS(3247),
    [sym_integer_literal] = ACTIONS(3245),
    [sym_real_literal] = ACTIONS(3247),
    [anon_sym_DQUOTE] = ACTIONS(3247),
    [sym_verbatim_string_literal] = ACTIONS(3247),
    [aux_sym_preproc_if_token1] = ACTIONS(3247),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3247),
    [sym_interpolation_verbatim_start] = ACTIONS(3247),
    [sym_interpolation_raw_start] = ACTIONS(3247),
    [sym_raw_string_start] = ACTIONS(3247),
  },
  [2719] = {
    [sym_preproc_region] = STATE(2719),
    [sym_preproc_endregion] = STATE(2719),
    [sym_preproc_line] = STATE(2719),
    [sym_preproc_pragma] = STATE(2719),
    [sym_preproc_nullable] = STATE(2719),
    [sym_preproc_error] = STATE(2719),
    [sym_preproc_warning] = STATE(2719),
    [sym_preproc_define] = STATE(2719),
    [sym_preproc_undef] = STATE(2719),
    [sym__identifier_token] = ACTIONS(3249),
    [anon_sym_extern] = ACTIONS(3249),
    [anon_sym_alias] = ACTIONS(3249),
    [anon_sym_SEMI] = ACTIONS(3251),
    [anon_sym_global] = ACTIONS(3249),
    [anon_sym_using] = ACTIONS(3249),
    [anon_sym_unsafe] = ACTIONS(3249),
    [anon_sym_static] = ACTIONS(3249),
    [anon_sym_LBRACK] = ACTIONS(3251),
    [anon_sym_LPAREN] = ACTIONS(3251),
    [anon_sym_return] = ACTIONS(3249),
    [anon_sym_ref] = ACTIONS(3249),
    [anon_sym_LBRACE] = ACTIONS(3251),
    [anon_sym_RBRACE] = ACTIONS(3251),
    [anon_sym_delegate] = ACTIONS(3249),
    [anon_sym_abstract] = ACTIONS(3249),
    [anon_sym_async] = ACTIONS(3249),
    [anon_sym_const] = ACTIONS(3249),
    [anon_sym_file] = ACTIONS(3249),
    [anon_sym_fixed] = ACTIONS(3249),
    [anon_sym_internal] = ACTIONS(3249),
    [anon_sym_new] = ACTIONS(3249),
    [anon_sym_override] = ACTIONS(3249),
    [anon_sym_partial] = ACTIONS(3249),
    [anon_sym_private] = ACTIONS(3249),
    [anon_sym_protected] = ACTIONS(3249),
    [anon_sym_public] = ACTIONS(3249),
    [anon_sym_readonly] = ACTIONS(3249),
    [anon_sym_required] = ACTIONS(3249),
    [anon_sym_sealed] = ACTIONS(3249),
    [anon_sym_virtual] = ACTIONS(3249),
    [anon_sym_volatile] = ACTIONS(3249),
    [anon_sym_where] = ACTIONS(3249),
    [anon_sym_notnull] = ACTIONS(3249),
    [anon_sym_unmanaged] = ACTIONS(3249),
    [anon_sym_checked] = ACTIONS(3249),
    [anon_sym_BANG] = ACTIONS(3251),
    [anon_sym_TILDE] = ACTIONS(3251),
    [anon_sym_PLUS_PLUS] = ACTIONS(3251),
    [anon_sym_DASH_DASH] = ACTIONS(3251),
    [anon_sym_true] = ACTIONS(3249),
    [anon_sym_false] = ACTIONS(3249),
    [anon_sym_PLUS] = ACTIONS(3249),
    [anon_sym_DASH] = ACTIONS(3249),
    [anon_sym_STAR] = ACTIONS(3251),
    [anon_sym_CARET] = ACTIONS(3251),
    [anon_sym_AMP] = ACTIONS(3251),
    [anon_sym_this] = ACTIONS(3249),
    [anon_sym_scoped] = ACTIONS(3249),
    [anon_sym_base] = ACTIONS(3249),
    [anon_sym_var] = ACTIONS(3249),
    [sym_predefined_type] = ACTIONS(3249),
    [anon_sym_break] = ACTIONS(3249),
    [anon_sym_unchecked] = ACTIONS(3249),
    [anon_sym_continue] = ACTIONS(3249),
    [anon_sym_do] = ACTIONS(3249),
    [anon_sym_while] = ACTIONS(3249),
    [anon_sym_for] = ACTIONS(3249),
    [anon_sym_lock] = ACTIONS(3249),
    [anon_sym_yield] = ACTIONS(3249),
    [anon_sym_switch] = ACTIONS(3249),
    [anon_sym_case] = ACTIONS(3249),
    [anon_sym_default] = ACTIONS(3249),
    [anon_sym_throw] = ACTIONS(3249),
    [anon_sym_try] = ACTIONS(3249),
    [anon_sym_when] = ACTIONS(3249),
    [anon_sym_await] = ACTIONS(3249),
    [anon_sym_foreach] = ACTIONS(3249),
    [anon_sym_goto] = ACTIONS(3249),
    [anon_sym_if] = ACTIONS(3249),
    [anon_sym_else] = ACTIONS(3249),
    [anon_sym_DOT_DOT] = ACTIONS(3251),
    [anon_sym_from] = ACTIONS(3249),
    [anon_sym_into] = ACTIONS(3249),
    [anon_sym_join] = ACTIONS(3249),
    [anon_sym_on] = ACTIONS(3249),
    [anon_sym_equals] = ACTIONS(3249),
    [anon_sym_let] = ACTIONS(3249),
    [anon_sym_orderby] = ACTIONS(3249),
    [anon_sym_ascending] = ACTIONS(3249),
    [anon_sym_descending] = ACTIONS(3249),
    [anon_sym_group] = ACTIONS(3249),
    [anon_sym_by] = ACTIONS(3249),
    [anon_sym_select] = ACTIONS(3249),
    [anon_sym_stackalloc] = ACTIONS(3249),
    [anon_sym_sizeof] = ACTIONS(3249),
    [anon_sym_typeof] = ACTIONS(3249),
    [anon_sym___makeref] = ACTIONS(3249),
    [anon_sym___reftype] = ACTIONS(3249),
    [anon_sym___refvalue] = ACTIONS(3249),
    [sym_null_literal] = ACTIONS(3249),
    [anon_sym_SQUOTE] = ACTIONS(3251),
    [sym_integer_literal] = ACTIONS(3249),
    [sym_real_literal] = ACTIONS(3251),
    [anon_sym_DQUOTE] = ACTIONS(3251),
    [sym_verbatim_string_literal] = ACTIONS(3251),
    [aux_sym_preproc_if_token1] = ACTIONS(3251),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3251),
    [sym_interpolation_verbatim_start] = ACTIONS(3251),
    [sym_interpolation_raw_start] = ACTIONS(3251),
    [sym_raw_string_start] = ACTIONS(3251),
  },
  [2720] = {
    [sym_preproc_region] = STATE(2720),
    [sym_preproc_endregion] = STATE(2720),
    [sym_preproc_line] = STATE(2720),
    [sym_preproc_pragma] = STATE(2720),
    [sym_preproc_nullable] = STATE(2720),
    [sym_preproc_error] = STATE(2720),
    [sym_preproc_warning] = STATE(2720),
    [sym_preproc_define] = STATE(2720),
    [sym_preproc_undef] = STATE(2720),
    [sym__identifier_token] = ACTIONS(3253),
    [anon_sym_extern] = ACTIONS(3253),
    [anon_sym_alias] = ACTIONS(3253),
    [anon_sym_SEMI] = ACTIONS(3255),
    [anon_sym_global] = ACTIONS(3253),
    [anon_sym_using] = ACTIONS(3253),
    [anon_sym_unsafe] = ACTIONS(3253),
    [anon_sym_static] = ACTIONS(3253),
    [anon_sym_LBRACK] = ACTIONS(3255),
    [anon_sym_LPAREN] = ACTIONS(3255),
    [anon_sym_return] = ACTIONS(3253),
    [anon_sym_ref] = ACTIONS(3253),
    [anon_sym_LBRACE] = ACTIONS(3255),
    [anon_sym_RBRACE] = ACTIONS(3255),
    [anon_sym_delegate] = ACTIONS(3253),
    [anon_sym_abstract] = ACTIONS(3253),
    [anon_sym_async] = ACTIONS(3253),
    [anon_sym_const] = ACTIONS(3253),
    [anon_sym_file] = ACTIONS(3253),
    [anon_sym_fixed] = ACTIONS(3253),
    [anon_sym_internal] = ACTIONS(3253),
    [anon_sym_new] = ACTIONS(3253),
    [anon_sym_override] = ACTIONS(3253),
    [anon_sym_partial] = ACTIONS(3253),
    [anon_sym_private] = ACTIONS(3253),
    [anon_sym_protected] = ACTIONS(3253),
    [anon_sym_public] = ACTIONS(3253),
    [anon_sym_readonly] = ACTIONS(3253),
    [anon_sym_required] = ACTIONS(3253),
    [anon_sym_sealed] = ACTIONS(3253),
    [anon_sym_virtual] = ACTIONS(3253),
    [anon_sym_volatile] = ACTIONS(3253),
    [anon_sym_where] = ACTIONS(3253),
    [anon_sym_notnull] = ACTIONS(3253),
    [anon_sym_unmanaged] = ACTIONS(3253),
    [anon_sym_checked] = ACTIONS(3253),
    [anon_sym_BANG] = ACTIONS(3255),
    [anon_sym_TILDE] = ACTIONS(3255),
    [anon_sym_PLUS_PLUS] = ACTIONS(3255),
    [anon_sym_DASH_DASH] = ACTIONS(3255),
    [anon_sym_true] = ACTIONS(3253),
    [anon_sym_false] = ACTIONS(3253),
    [anon_sym_PLUS] = ACTIONS(3253),
    [anon_sym_DASH] = ACTIONS(3253),
    [anon_sym_STAR] = ACTIONS(3255),
    [anon_sym_CARET] = ACTIONS(3255),
    [anon_sym_AMP] = ACTIONS(3255),
    [anon_sym_this] = ACTIONS(3253),
    [anon_sym_scoped] = ACTIONS(3253),
    [anon_sym_base] = ACTIONS(3253),
    [anon_sym_var] = ACTIONS(3253),
    [sym_predefined_type] = ACTIONS(3253),
    [anon_sym_break] = ACTIONS(3253),
    [anon_sym_unchecked] = ACTIONS(3253),
    [anon_sym_continue] = ACTIONS(3253),
    [anon_sym_do] = ACTIONS(3253),
    [anon_sym_while] = ACTIONS(3253),
    [anon_sym_for] = ACTIONS(3253),
    [anon_sym_lock] = ACTIONS(3253),
    [anon_sym_yield] = ACTIONS(3253),
    [anon_sym_switch] = ACTIONS(3253),
    [anon_sym_case] = ACTIONS(3253),
    [anon_sym_default] = ACTIONS(3253),
    [anon_sym_throw] = ACTIONS(3253),
    [anon_sym_try] = ACTIONS(3253),
    [anon_sym_when] = ACTIONS(3253),
    [anon_sym_await] = ACTIONS(3253),
    [anon_sym_foreach] = ACTIONS(3253),
    [anon_sym_goto] = ACTIONS(3253),
    [anon_sym_if] = ACTIONS(3253),
    [anon_sym_else] = ACTIONS(3253),
    [anon_sym_DOT_DOT] = ACTIONS(3255),
    [anon_sym_from] = ACTIONS(3253),
    [anon_sym_into] = ACTIONS(3253),
    [anon_sym_join] = ACTIONS(3253),
    [anon_sym_on] = ACTIONS(3253),
    [anon_sym_equals] = ACTIONS(3253),
    [anon_sym_let] = ACTIONS(3253),
    [anon_sym_orderby] = ACTIONS(3253),
    [anon_sym_ascending] = ACTIONS(3253),
    [anon_sym_descending] = ACTIONS(3253),
    [anon_sym_group] = ACTIONS(3253),
    [anon_sym_by] = ACTIONS(3253),
    [anon_sym_select] = ACTIONS(3253),
    [anon_sym_stackalloc] = ACTIONS(3253),
    [anon_sym_sizeof] = ACTIONS(3253),
    [anon_sym_typeof] = ACTIONS(3253),
    [anon_sym___makeref] = ACTIONS(3253),
    [anon_sym___reftype] = ACTIONS(3253),
    [anon_sym___refvalue] = ACTIONS(3253),
    [sym_null_literal] = ACTIONS(3253),
    [anon_sym_SQUOTE] = ACTIONS(3255),
    [sym_integer_literal] = ACTIONS(3253),
    [sym_real_literal] = ACTIONS(3255),
    [anon_sym_DQUOTE] = ACTIONS(3255),
    [sym_verbatim_string_literal] = ACTIONS(3255),
    [aux_sym_preproc_if_token1] = ACTIONS(3255),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3255),
    [sym_interpolation_verbatim_start] = ACTIONS(3255),
    [sym_interpolation_raw_start] = ACTIONS(3255),
    [sym_raw_string_start] = ACTIONS(3255),
  },
  [2721] = {
    [sym_preproc_region] = STATE(2721),
    [sym_preproc_endregion] = STATE(2721),
    [sym_preproc_line] = STATE(2721),
    [sym_preproc_pragma] = STATE(2721),
    [sym_preproc_nullable] = STATE(2721),
    [sym_preproc_error] = STATE(2721),
    [sym_preproc_warning] = STATE(2721),
    [sym_preproc_define] = STATE(2721),
    [sym_preproc_undef] = STATE(2721),
    [sym__identifier_token] = ACTIONS(3261),
    [anon_sym_extern] = ACTIONS(3261),
    [anon_sym_alias] = ACTIONS(3261),
    [anon_sym_SEMI] = ACTIONS(3263),
    [anon_sym_global] = ACTIONS(3261),
    [anon_sym_using] = ACTIONS(3261),
    [anon_sym_unsafe] = ACTIONS(3261),
    [anon_sym_static] = ACTIONS(3261),
    [anon_sym_LBRACK] = ACTIONS(3263),
    [anon_sym_LPAREN] = ACTIONS(3263),
    [anon_sym_return] = ACTIONS(3261),
    [anon_sym_ref] = ACTIONS(3261),
    [anon_sym_LBRACE] = ACTIONS(3263),
    [anon_sym_RBRACE] = ACTIONS(3263),
    [anon_sym_delegate] = ACTIONS(3261),
    [anon_sym_abstract] = ACTIONS(3261),
    [anon_sym_async] = ACTIONS(3261),
    [anon_sym_const] = ACTIONS(3261),
    [anon_sym_file] = ACTIONS(3261),
    [anon_sym_fixed] = ACTIONS(3261),
    [anon_sym_internal] = ACTIONS(3261),
    [anon_sym_new] = ACTIONS(3261),
    [anon_sym_override] = ACTIONS(3261),
    [anon_sym_partial] = ACTIONS(3261),
    [anon_sym_private] = ACTIONS(3261),
    [anon_sym_protected] = ACTIONS(3261),
    [anon_sym_public] = ACTIONS(3261),
    [anon_sym_readonly] = ACTIONS(3261),
    [anon_sym_required] = ACTIONS(3261),
    [anon_sym_sealed] = ACTIONS(3261),
    [anon_sym_virtual] = ACTIONS(3261),
    [anon_sym_volatile] = ACTIONS(3261),
    [anon_sym_where] = ACTIONS(3261),
    [anon_sym_notnull] = ACTIONS(3261),
    [anon_sym_unmanaged] = ACTIONS(3261),
    [anon_sym_checked] = ACTIONS(3261),
    [anon_sym_BANG] = ACTIONS(3263),
    [anon_sym_TILDE] = ACTIONS(3263),
    [anon_sym_PLUS_PLUS] = ACTIONS(3263),
    [anon_sym_DASH_DASH] = ACTIONS(3263),
    [anon_sym_true] = ACTIONS(3261),
    [anon_sym_false] = ACTIONS(3261),
    [anon_sym_PLUS] = ACTIONS(3261),
    [anon_sym_DASH] = ACTIONS(3261),
    [anon_sym_STAR] = ACTIONS(3263),
    [anon_sym_CARET] = ACTIONS(3263),
    [anon_sym_AMP] = ACTIONS(3263),
    [anon_sym_this] = ACTIONS(3261),
    [anon_sym_scoped] = ACTIONS(3261),
    [anon_sym_base] = ACTIONS(3261),
    [anon_sym_var] = ACTIONS(3261),
    [sym_predefined_type] = ACTIONS(3261),
    [anon_sym_break] = ACTIONS(3261),
    [anon_sym_unchecked] = ACTIONS(3261),
    [anon_sym_continue] = ACTIONS(3261),
    [anon_sym_do] = ACTIONS(3261),
    [anon_sym_while] = ACTIONS(3261),
    [anon_sym_for] = ACTIONS(3261),
    [anon_sym_lock] = ACTIONS(3261),
    [anon_sym_yield] = ACTIONS(3261),
    [anon_sym_switch] = ACTIONS(3261),
    [anon_sym_case] = ACTIONS(3261),
    [anon_sym_default] = ACTIONS(3261),
    [anon_sym_throw] = ACTIONS(3261),
    [anon_sym_try] = ACTIONS(3261),
    [anon_sym_when] = ACTIONS(3261),
    [anon_sym_await] = ACTIONS(3261),
    [anon_sym_foreach] = ACTIONS(3261),
    [anon_sym_goto] = ACTIONS(3261),
    [anon_sym_if] = ACTIONS(3261),
    [anon_sym_else] = ACTIONS(3261),
    [anon_sym_DOT_DOT] = ACTIONS(3263),
    [anon_sym_from] = ACTIONS(3261),
    [anon_sym_into] = ACTIONS(3261),
    [anon_sym_join] = ACTIONS(3261),
    [anon_sym_on] = ACTIONS(3261),
    [anon_sym_equals] = ACTIONS(3261),
    [anon_sym_let] = ACTIONS(3261),
    [anon_sym_orderby] = ACTIONS(3261),
    [anon_sym_ascending] = ACTIONS(3261),
    [anon_sym_descending] = ACTIONS(3261),
    [anon_sym_group] = ACTIONS(3261),
    [anon_sym_by] = ACTIONS(3261),
    [anon_sym_select] = ACTIONS(3261),
    [anon_sym_stackalloc] = ACTIONS(3261),
    [anon_sym_sizeof] = ACTIONS(3261),
    [anon_sym_typeof] = ACTIONS(3261),
    [anon_sym___makeref] = ACTIONS(3261),
    [anon_sym___reftype] = ACTIONS(3261),
    [anon_sym___refvalue] = ACTIONS(3261),
    [sym_null_literal] = ACTIONS(3261),
    [anon_sym_SQUOTE] = ACTIONS(3263),
    [sym_integer_literal] = ACTIONS(3261),
    [sym_real_literal] = ACTIONS(3263),
    [anon_sym_DQUOTE] = ACTIONS(3263),
    [sym_verbatim_string_literal] = ACTIONS(3263),
    [aux_sym_preproc_if_token1] = ACTIONS(3263),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3263),
    [sym_interpolation_verbatim_start] = ACTIONS(3263),
    [sym_interpolation_raw_start] = ACTIONS(3263),
    [sym_raw_string_start] = ACTIONS(3263),
  },
  [2722] = {
    [sym_preproc_region] = STATE(2722),
    [sym_preproc_endregion] = STATE(2722),
    [sym_preproc_line] = STATE(2722),
    [sym_preproc_pragma] = STATE(2722),
    [sym_preproc_nullable] = STATE(2722),
    [sym_preproc_error] = STATE(2722),
    [sym_preproc_warning] = STATE(2722),
    [sym_preproc_define] = STATE(2722),
    [sym_preproc_undef] = STATE(2722),
    [sym__identifier_token] = ACTIONS(3265),
    [anon_sym_extern] = ACTIONS(3265),
    [anon_sym_alias] = ACTIONS(3265),
    [anon_sym_SEMI] = ACTIONS(3267),
    [anon_sym_global] = ACTIONS(3265),
    [anon_sym_using] = ACTIONS(3265),
    [anon_sym_unsafe] = ACTIONS(3265),
    [anon_sym_static] = ACTIONS(3265),
    [anon_sym_LBRACK] = ACTIONS(3267),
    [anon_sym_LPAREN] = ACTIONS(3267),
    [anon_sym_return] = ACTIONS(3265),
    [anon_sym_ref] = ACTIONS(3265),
    [anon_sym_LBRACE] = ACTIONS(3267),
    [anon_sym_RBRACE] = ACTIONS(3267),
    [anon_sym_delegate] = ACTIONS(3265),
    [anon_sym_abstract] = ACTIONS(3265),
    [anon_sym_async] = ACTIONS(3265),
    [anon_sym_const] = ACTIONS(3265),
    [anon_sym_file] = ACTIONS(3265),
    [anon_sym_fixed] = ACTIONS(3265),
    [anon_sym_internal] = ACTIONS(3265),
    [anon_sym_new] = ACTIONS(3265),
    [anon_sym_override] = ACTIONS(3265),
    [anon_sym_partial] = ACTIONS(3265),
    [anon_sym_private] = ACTIONS(3265),
    [anon_sym_protected] = ACTIONS(3265),
    [anon_sym_public] = ACTIONS(3265),
    [anon_sym_readonly] = ACTIONS(3265),
    [anon_sym_required] = ACTIONS(3265),
    [anon_sym_sealed] = ACTIONS(3265),
    [anon_sym_virtual] = ACTIONS(3265),
    [anon_sym_volatile] = ACTIONS(3265),
    [anon_sym_where] = ACTIONS(3265),
    [anon_sym_notnull] = ACTIONS(3265),
    [anon_sym_unmanaged] = ACTIONS(3265),
    [anon_sym_checked] = ACTIONS(3265),
    [anon_sym_BANG] = ACTIONS(3267),
    [anon_sym_TILDE] = ACTIONS(3267),
    [anon_sym_PLUS_PLUS] = ACTIONS(3267),
    [anon_sym_DASH_DASH] = ACTIONS(3267),
    [anon_sym_true] = ACTIONS(3265),
    [anon_sym_false] = ACTIONS(3265),
    [anon_sym_PLUS] = ACTIONS(3265),
    [anon_sym_DASH] = ACTIONS(3265),
    [anon_sym_STAR] = ACTIONS(3267),
    [anon_sym_CARET] = ACTIONS(3267),
    [anon_sym_AMP] = ACTIONS(3267),
    [anon_sym_this] = ACTIONS(3265),
    [anon_sym_scoped] = ACTIONS(3265),
    [anon_sym_base] = ACTIONS(3265),
    [anon_sym_var] = ACTIONS(3265),
    [sym_predefined_type] = ACTIONS(3265),
    [anon_sym_break] = ACTIONS(3265),
    [anon_sym_unchecked] = ACTIONS(3265),
    [anon_sym_continue] = ACTIONS(3265),
    [anon_sym_do] = ACTIONS(3265),
    [anon_sym_while] = ACTIONS(3265),
    [anon_sym_for] = ACTIONS(3265),
    [anon_sym_lock] = ACTIONS(3265),
    [anon_sym_yield] = ACTIONS(3265),
    [anon_sym_switch] = ACTIONS(3265),
    [anon_sym_case] = ACTIONS(3265),
    [anon_sym_default] = ACTIONS(3265),
    [anon_sym_throw] = ACTIONS(3265),
    [anon_sym_try] = ACTIONS(3265),
    [anon_sym_when] = ACTIONS(3265),
    [anon_sym_await] = ACTIONS(3265),
    [anon_sym_foreach] = ACTIONS(3265),
    [anon_sym_goto] = ACTIONS(3265),
    [anon_sym_if] = ACTIONS(3265),
    [anon_sym_else] = ACTIONS(3265),
    [anon_sym_DOT_DOT] = ACTIONS(3267),
    [anon_sym_from] = ACTIONS(3265),
    [anon_sym_into] = ACTIONS(3265),
    [anon_sym_join] = ACTIONS(3265),
    [anon_sym_on] = ACTIONS(3265),
    [anon_sym_equals] = ACTIONS(3265),
    [anon_sym_let] = ACTIONS(3265),
    [anon_sym_orderby] = ACTIONS(3265),
    [anon_sym_ascending] = ACTIONS(3265),
    [anon_sym_descending] = ACTIONS(3265),
    [anon_sym_group] = ACTIONS(3265),
    [anon_sym_by] = ACTIONS(3265),
    [anon_sym_select] = ACTIONS(3265),
    [anon_sym_stackalloc] = ACTIONS(3265),
    [anon_sym_sizeof] = ACTIONS(3265),
    [anon_sym_typeof] = ACTIONS(3265),
    [anon_sym___makeref] = ACTIONS(3265),
    [anon_sym___reftype] = ACTIONS(3265),
    [anon_sym___refvalue] = ACTIONS(3265),
    [sym_null_literal] = ACTIONS(3265),
    [anon_sym_SQUOTE] = ACTIONS(3267),
    [sym_integer_literal] = ACTIONS(3265),
    [sym_real_literal] = ACTIONS(3267),
    [anon_sym_DQUOTE] = ACTIONS(3267),
    [sym_verbatim_string_literal] = ACTIONS(3267),
    [aux_sym_preproc_if_token1] = ACTIONS(3267),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3267),
    [sym_interpolation_verbatim_start] = ACTIONS(3267),
    [sym_interpolation_raw_start] = ACTIONS(3267),
    [sym_raw_string_start] = ACTIONS(3267),
  },
  [2723] = {
    [sym_preproc_region] = STATE(2723),
    [sym_preproc_endregion] = STATE(2723),
    [sym_preproc_line] = STATE(2723),
    [sym_preproc_pragma] = STATE(2723),
    [sym_preproc_nullable] = STATE(2723),
    [sym_preproc_error] = STATE(2723),
    [sym_preproc_warning] = STATE(2723),
    [sym_preproc_define] = STATE(2723),
    [sym_preproc_undef] = STATE(2723),
    [sym__identifier_token] = ACTIONS(3305),
    [anon_sym_extern] = ACTIONS(3305),
    [anon_sym_alias] = ACTIONS(3305),
    [anon_sym_SEMI] = ACTIONS(3307),
    [anon_sym_global] = ACTIONS(3305),
    [anon_sym_using] = ACTIONS(3305),
    [anon_sym_unsafe] = ACTIONS(3305),
    [anon_sym_static] = ACTIONS(3305),
    [anon_sym_LBRACK] = ACTIONS(3307),
    [anon_sym_LPAREN] = ACTIONS(3307),
    [anon_sym_return] = ACTIONS(3305),
    [anon_sym_ref] = ACTIONS(3305),
    [anon_sym_LBRACE] = ACTIONS(3307),
    [anon_sym_RBRACE] = ACTIONS(3307),
    [anon_sym_delegate] = ACTIONS(3305),
    [anon_sym_abstract] = ACTIONS(3305),
    [anon_sym_async] = ACTIONS(3305),
    [anon_sym_const] = ACTIONS(3305),
    [anon_sym_file] = ACTIONS(3305),
    [anon_sym_fixed] = ACTIONS(3305),
    [anon_sym_internal] = ACTIONS(3305),
    [anon_sym_new] = ACTIONS(3305),
    [anon_sym_override] = ACTIONS(3305),
    [anon_sym_partial] = ACTIONS(3305),
    [anon_sym_private] = ACTIONS(3305),
    [anon_sym_protected] = ACTIONS(3305),
    [anon_sym_public] = ACTIONS(3305),
    [anon_sym_readonly] = ACTIONS(3305),
    [anon_sym_required] = ACTIONS(3305),
    [anon_sym_sealed] = ACTIONS(3305),
    [anon_sym_virtual] = ACTIONS(3305),
    [anon_sym_volatile] = ACTIONS(3305),
    [anon_sym_where] = ACTIONS(3305),
    [anon_sym_notnull] = ACTIONS(3305),
    [anon_sym_unmanaged] = ACTIONS(3305),
    [anon_sym_checked] = ACTIONS(3305),
    [anon_sym_BANG] = ACTIONS(3307),
    [anon_sym_TILDE] = ACTIONS(3307),
    [anon_sym_PLUS_PLUS] = ACTIONS(3307),
    [anon_sym_DASH_DASH] = ACTIONS(3307),
    [anon_sym_true] = ACTIONS(3305),
    [anon_sym_false] = ACTIONS(3305),
    [anon_sym_PLUS] = ACTIONS(3305),
    [anon_sym_DASH] = ACTIONS(3305),
    [anon_sym_STAR] = ACTIONS(3307),
    [anon_sym_CARET] = ACTIONS(3307),
    [anon_sym_AMP] = ACTIONS(3307),
    [anon_sym_this] = ACTIONS(3305),
    [anon_sym_scoped] = ACTIONS(3305),
    [anon_sym_base] = ACTIONS(3305),
    [anon_sym_var] = ACTIONS(3305),
    [sym_predefined_type] = ACTIONS(3305),
    [anon_sym_break] = ACTIONS(3305),
    [anon_sym_unchecked] = ACTIONS(3305),
    [anon_sym_continue] = ACTIONS(3305),
    [anon_sym_do] = ACTIONS(3305),
    [anon_sym_while] = ACTIONS(3305),
    [anon_sym_for] = ACTIONS(3305),
    [anon_sym_lock] = ACTIONS(3305),
    [anon_sym_yield] = ACTIONS(3305),
    [anon_sym_switch] = ACTIONS(3305),
    [anon_sym_case] = ACTIONS(3305),
    [anon_sym_default] = ACTIONS(3305),
    [anon_sym_throw] = ACTIONS(3305),
    [anon_sym_try] = ACTIONS(3305),
    [anon_sym_when] = ACTIONS(3305),
    [anon_sym_await] = ACTIONS(3305),
    [anon_sym_foreach] = ACTIONS(3305),
    [anon_sym_goto] = ACTIONS(3305),
    [anon_sym_if] = ACTIONS(3305),
    [anon_sym_else] = ACTIONS(3305),
    [anon_sym_DOT_DOT] = ACTIONS(3307),
    [anon_sym_from] = ACTIONS(3305),
    [anon_sym_into] = ACTIONS(3305),
    [anon_sym_join] = ACTIONS(3305),
    [anon_sym_on] = ACTIONS(3305),
    [anon_sym_equals] = ACTIONS(3305),
    [anon_sym_let] = ACTIONS(3305),
    [anon_sym_orderby] = ACTIONS(3305),
    [anon_sym_ascending] = ACTIONS(3305),
    [anon_sym_descending] = ACTIONS(3305),
    [anon_sym_group] = ACTIONS(3305),
    [anon_sym_by] = ACTIONS(3305),
    [anon_sym_select] = ACTIONS(3305),
    [anon_sym_stackalloc] = ACTIONS(3305),
    [anon_sym_sizeof] = ACTIONS(3305),
    [anon_sym_typeof] = ACTIONS(3305),
    [anon_sym___makeref] = ACTIONS(3305),
    [anon_sym___reftype] = ACTIONS(3305),
    [anon_sym___refvalue] = ACTIONS(3305),
    [sym_null_literal] = ACTIONS(3305),
    [anon_sym_SQUOTE] = ACTIONS(3307),
    [sym_integer_literal] = ACTIONS(3305),
    [sym_real_literal] = ACTIONS(3307),
    [anon_sym_DQUOTE] = ACTIONS(3307),
    [sym_verbatim_string_literal] = ACTIONS(3307),
    [aux_sym_preproc_if_token1] = ACTIONS(3307),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3307),
    [sym_interpolation_verbatim_start] = ACTIONS(3307),
    [sym_interpolation_raw_start] = ACTIONS(3307),
    [sym_raw_string_start] = ACTIONS(3307),
  },
  [2724] = {
    [sym_preproc_region] = STATE(2724),
    [sym_preproc_endregion] = STATE(2724),
    [sym_preproc_line] = STATE(2724),
    [sym_preproc_pragma] = STATE(2724),
    [sym_preproc_nullable] = STATE(2724),
    [sym_preproc_error] = STATE(2724),
    [sym_preproc_warning] = STATE(2724),
    [sym_preproc_define] = STATE(2724),
    [sym_preproc_undef] = STATE(2724),
    [sym__identifier_token] = ACTIONS(3317),
    [anon_sym_extern] = ACTIONS(3317),
    [anon_sym_alias] = ACTIONS(3317),
    [anon_sym_SEMI] = ACTIONS(3319),
    [anon_sym_global] = ACTIONS(3317),
    [anon_sym_using] = ACTIONS(3317),
    [anon_sym_unsafe] = ACTIONS(3317),
    [anon_sym_static] = ACTIONS(3317),
    [anon_sym_LBRACK] = ACTIONS(3319),
    [anon_sym_LPAREN] = ACTIONS(3319),
    [anon_sym_return] = ACTIONS(3317),
    [anon_sym_ref] = ACTIONS(3317),
    [anon_sym_LBRACE] = ACTIONS(3319),
    [anon_sym_RBRACE] = ACTIONS(3319),
    [anon_sym_delegate] = ACTIONS(3317),
    [anon_sym_abstract] = ACTIONS(3317),
    [anon_sym_async] = ACTIONS(3317),
    [anon_sym_const] = ACTIONS(3317),
    [anon_sym_file] = ACTIONS(3317),
    [anon_sym_fixed] = ACTIONS(3317),
    [anon_sym_internal] = ACTIONS(3317),
    [anon_sym_new] = ACTIONS(3317),
    [anon_sym_override] = ACTIONS(3317),
    [anon_sym_partial] = ACTIONS(3317),
    [anon_sym_private] = ACTIONS(3317),
    [anon_sym_protected] = ACTIONS(3317),
    [anon_sym_public] = ACTIONS(3317),
    [anon_sym_readonly] = ACTIONS(3317),
    [anon_sym_required] = ACTIONS(3317),
    [anon_sym_sealed] = ACTIONS(3317),
    [anon_sym_virtual] = ACTIONS(3317),
    [anon_sym_volatile] = ACTIONS(3317),
    [anon_sym_where] = ACTIONS(3317),
    [anon_sym_notnull] = ACTIONS(3317),
    [anon_sym_unmanaged] = ACTIONS(3317),
    [anon_sym_checked] = ACTIONS(3317),
    [anon_sym_BANG] = ACTIONS(3319),
    [anon_sym_TILDE] = ACTIONS(3319),
    [anon_sym_PLUS_PLUS] = ACTIONS(3319),
    [anon_sym_DASH_DASH] = ACTIONS(3319),
    [anon_sym_true] = ACTIONS(3317),
    [anon_sym_false] = ACTIONS(3317),
    [anon_sym_PLUS] = ACTIONS(3317),
    [anon_sym_DASH] = ACTIONS(3317),
    [anon_sym_STAR] = ACTIONS(3319),
    [anon_sym_CARET] = ACTIONS(3319),
    [anon_sym_AMP] = ACTIONS(3319),
    [anon_sym_this] = ACTIONS(3317),
    [anon_sym_scoped] = ACTIONS(3317),
    [anon_sym_base] = ACTIONS(3317),
    [anon_sym_var] = ACTIONS(3317),
    [sym_predefined_type] = ACTIONS(3317),
    [anon_sym_break] = ACTIONS(3317),
    [anon_sym_unchecked] = ACTIONS(3317),
    [anon_sym_continue] = ACTIONS(3317),
    [anon_sym_do] = ACTIONS(3317),
    [anon_sym_while] = ACTIONS(3317),
    [anon_sym_for] = ACTIONS(3317),
    [anon_sym_lock] = ACTIONS(3317),
    [anon_sym_yield] = ACTIONS(3317),
    [anon_sym_switch] = ACTIONS(3317),
    [anon_sym_case] = ACTIONS(3317),
    [anon_sym_default] = ACTIONS(3317),
    [anon_sym_throw] = ACTIONS(3317),
    [anon_sym_try] = ACTIONS(3317),
    [anon_sym_when] = ACTIONS(3317),
    [anon_sym_await] = ACTIONS(3317),
    [anon_sym_foreach] = ACTIONS(3317),
    [anon_sym_goto] = ACTIONS(3317),
    [anon_sym_if] = ACTIONS(3317),
    [anon_sym_else] = ACTIONS(4047),
    [anon_sym_DOT_DOT] = ACTIONS(3319),
    [anon_sym_from] = ACTIONS(3317),
    [anon_sym_into] = ACTIONS(3317),
    [anon_sym_join] = ACTIONS(3317),
    [anon_sym_on] = ACTIONS(3317),
    [anon_sym_equals] = ACTIONS(3317),
    [anon_sym_let] = ACTIONS(3317),
    [anon_sym_orderby] = ACTIONS(3317),
    [anon_sym_ascending] = ACTIONS(3317),
    [anon_sym_descending] = ACTIONS(3317),
    [anon_sym_group] = ACTIONS(3317),
    [anon_sym_by] = ACTIONS(3317),
    [anon_sym_select] = ACTIONS(3317),
    [anon_sym_stackalloc] = ACTIONS(3317),
    [anon_sym_sizeof] = ACTIONS(3317),
    [anon_sym_typeof] = ACTIONS(3317),
    [anon_sym___makeref] = ACTIONS(3317),
    [anon_sym___reftype] = ACTIONS(3317),
    [anon_sym___refvalue] = ACTIONS(3317),
    [sym_null_literal] = ACTIONS(3317),
    [anon_sym_SQUOTE] = ACTIONS(3319),
    [sym_integer_literal] = ACTIONS(3317),
    [sym_real_literal] = ACTIONS(3319),
    [anon_sym_DQUOTE] = ACTIONS(3319),
    [sym_verbatim_string_literal] = ACTIONS(3319),
    [aux_sym_preproc_if_token1] = ACTIONS(3319),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3319),
    [sym_interpolation_verbatim_start] = ACTIONS(3319),
    [sym_interpolation_raw_start] = ACTIONS(3319),
    [sym_raw_string_start] = ACTIONS(3319),
  },
  [2725] = {
    [sym_preproc_region] = STATE(2725),
    [sym_preproc_endregion] = STATE(2725),
    [sym_preproc_line] = STATE(2725),
    [sym_preproc_pragma] = STATE(2725),
    [sym_preproc_nullable] = STATE(2725),
    [sym_preproc_error] = STATE(2725),
    [sym_preproc_warning] = STATE(2725),
    [sym_preproc_define] = STATE(2725),
    [sym_preproc_undef] = STATE(2725),
    [sym__identifier_token] = ACTIONS(3323),
    [anon_sym_extern] = ACTIONS(3323),
    [anon_sym_alias] = ACTIONS(3323),
    [anon_sym_SEMI] = ACTIONS(3325),
    [anon_sym_global] = ACTIONS(3323),
    [anon_sym_using] = ACTIONS(3323),
    [anon_sym_unsafe] = ACTIONS(3323),
    [anon_sym_static] = ACTIONS(3323),
    [anon_sym_LBRACK] = ACTIONS(3325),
    [anon_sym_LPAREN] = ACTIONS(3325),
    [anon_sym_return] = ACTIONS(3323),
    [anon_sym_ref] = ACTIONS(3323),
    [anon_sym_LBRACE] = ACTIONS(3325),
    [anon_sym_RBRACE] = ACTIONS(3325),
    [anon_sym_delegate] = ACTIONS(3323),
    [anon_sym_abstract] = ACTIONS(3323),
    [anon_sym_async] = ACTIONS(3323),
    [anon_sym_const] = ACTIONS(3323),
    [anon_sym_file] = ACTIONS(3323),
    [anon_sym_fixed] = ACTIONS(3323),
    [anon_sym_internal] = ACTIONS(3323),
    [anon_sym_new] = ACTIONS(3323),
    [anon_sym_override] = ACTIONS(3323),
    [anon_sym_partial] = ACTIONS(3323),
    [anon_sym_private] = ACTIONS(3323),
    [anon_sym_protected] = ACTIONS(3323),
    [anon_sym_public] = ACTIONS(3323),
    [anon_sym_readonly] = ACTIONS(3323),
    [anon_sym_required] = ACTIONS(3323),
    [anon_sym_sealed] = ACTIONS(3323),
    [anon_sym_virtual] = ACTIONS(3323),
    [anon_sym_volatile] = ACTIONS(3323),
    [anon_sym_where] = ACTIONS(3323),
    [anon_sym_notnull] = ACTIONS(3323),
    [anon_sym_unmanaged] = ACTIONS(3323),
    [anon_sym_checked] = ACTIONS(3323),
    [anon_sym_BANG] = ACTIONS(3325),
    [anon_sym_TILDE] = ACTIONS(3325),
    [anon_sym_PLUS_PLUS] = ACTIONS(3325),
    [anon_sym_DASH_DASH] = ACTIONS(3325),
    [anon_sym_true] = ACTIONS(3323),
    [anon_sym_false] = ACTIONS(3323),
    [anon_sym_PLUS] = ACTIONS(3323),
    [anon_sym_DASH] = ACTIONS(3323),
    [anon_sym_STAR] = ACTIONS(3325),
    [anon_sym_CARET] = ACTIONS(3325),
    [anon_sym_AMP] = ACTIONS(3325),
    [anon_sym_this] = ACTIONS(3323),
    [anon_sym_scoped] = ACTIONS(3323),
    [anon_sym_base] = ACTIONS(3323),
    [anon_sym_var] = ACTIONS(3323),
    [sym_predefined_type] = ACTIONS(3323),
    [anon_sym_break] = ACTIONS(3323),
    [anon_sym_unchecked] = ACTIONS(3323),
    [anon_sym_continue] = ACTIONS(3323),
    [anon_sym_do] = ACTIONS(3323),
    [anon_sym_while] = ACTIONS(3323),
    [anon_sym_for] = ACTIONS(3323),
    [anon_sym_lock] = ACTIONS(3323),
    [anon_sym_yield] = ACTIONS(3323),
    [anon_sym_switch] = ACTIONS(3323),
    [anon_sym_case] = ACTIONS(3323),
    [anon_sym_default] = ACTIONS(3323),
    [anon_sym_throw] = ACTIONS(3323),
    [anon_sym_try] = ACTIONS(3323),
    [anon_sym_when] = ACTIONS(3323),
    [anon_sym_await] = ACTIONS(3323),
    [anon_sym_foreach] = ACTIONS(3323),
    [anon_sym_goto] = ACTIONS(3323),
    [anon_sym_if] = ACTIONS(3323),
    [anon_sym_else] = ACTIONS(3323),
    [anon_sym_DOT_DOT] = ACTIONS(3325),
    [anon_sym_from] = ACTIONS(3323),
    [anon_sym_into] = ACTIONS(3323),
    [anon_sym_join] = ACTIONS(3323),
    [anon_sym_on] = ACTIONS(3323),
    [anon_sym_equals] = ACTIONS(3323),
    [anon_sym_let] = ACTIONS(3323),
    [anon_sym_orderby] = ACTIONS(3323),
    [anon_sym_ascending] = ACTIONS(3323),
    [anon_sym_descending] = ACTIONS(3323),
    [anon_sym_group] = ACTIONS(3323),
    [anon_sym_by] = ACTIONS(3323),
    [anon_sym_select] = ACTIONS(3323),
    [anon_sym_stackalloc] = ACTIONS(3323),
    [anon_sym_sizeof] = ACTIONS(3323),
    [anon_sym_typeof] = ACTIONS(3323),
    [anon_sym___makeref] = ACTIONS(3323),
    [anon_sym___reftype] = ACTIONS(3323),
    [anon_sym___refvalue] = ACTIONS(3323),
    [sym_null_literal] = ACTIONS(3323),
    [anon_sym_SQUOTE] = ACTIONS(3325),
    [sym_integer_literal] = ACTIONS(3323),
    [sym_real_literal] = ACTIONS(3325),
    [anon_sym_DQUOTE] = ACTIONS(3325),
    [sym_verbatim_string_literal] = ACTIONS(3325),
    [aux_sym_preproc_if_token1] = ACTIONS(3325),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3325),
    [sym_interpolation_verbatim_start] = ACTIONS(3325),
    [sym_interpolation_raw_start] = ACTIONS(3325),
    [sym_raw_string_start] = ACTIONS(3325),
  },
  [2726] = {
    [sym_preproc_region] = STATE(2726),
    [sym_preproc_endregion] = STATE(2726),
    [sym_preproc_line] = STATE(2726),
    [sym_preproc_pragma] = STATE(2726),
    [sym_preproc_nullable] = STATE(2726),
    [sym_preproc_error] = STATE(2726),
    [sym_preproc_warning] = STATE(2726),
    [sym_preproc_define] = STATE(2726),
    [sym_preproc_undef] = STATE(2726),
    [sym__identifier_token] = ACTIONS(3339),
    [anon_sym_extern] = ACTIONS(3339),
    [anon_sym_alias] = ACTIONS(3339),
    [anon_sym_SEMI] = ACTIONS(3341),
    [anon_sym_global] = ACTIONS(3339),
    [anon_sym_using] = ACTIONS(3339),
    [anon_sym_unsafe] = ACTIONS(3339),
    [anon_sym_static] = ACTIONS(3339),
    [anon_sym_LBRACK] = ACTIONS(3341),
    [anon_sym_LPAREN] = ACTIONS(3341),
    [anon_sym_return] = ACTIONS(3339),
    [anon_sym_ref] = ACTIONS(3339),
    [anon_sym_LBRACE] = ACTIONS(3341),
    [anon_sym_RBRACE] = ACTIONS(3341),
    [anon_sym_delegate] = ACTIONS(3339),
    [anon_sym_abstract] = ACTIONS(3339),
    [anon_sym_async] = ACTIONS(3339),
    [anon_sym_const] = ACTIONS(3339),
    [anon_sym_file] = ACTIONS(3339),
    [anon_sym_fixed] = ACTIONS(3339),
    [anon_sym_internal] = ACTIONS(3339),
    [anon_sym_new] = ACTIONS(3339),
    [anon_sym_override] = ACTIONS(3339),
    [anon_sym_partial] = ACTIONS(3339),
    [anon_sym_private] = ACTIONS(3339),
    [anon_sym_protected] = ACTIONS(3339),
    [anon_sym_public] = ACTIONS(3339),
    [anon_sym_readonly] = ACTIONS(3339),
    [anon_sym_required] = ACTIONS(3339),
    [anon_sym_sealed] = ACTIONS(3339),
    [anon_sym_virtual] = ACTIONS(3339),
    [anon_sym_volatile] = ACTIONS(3339),
    [anon_sym_where] = ACTIONS(3339),
    [anon_sym_notnull] = ACTIONS(3339),
    [anon_sym_unmanaged] = ACTIONS(3339),
    [anon_sym_checked] = ACTIONS(3339),
    [anon_sym_BANG] = ACTIONS(3341),
    [anon_sym_TILDE] = ACTIONS(3341),
    [anon_sym_PLUS_PLUS] = ACTIONS(3341),
    [anon_sym_DASH_DASH] = ACTIONS(3341),
    [anon_sym_true] = ACTIONS(3339),
    [anon_sym_false] = ACTIONS(3339),
    [anon_sym_PLUS] = ACTIONS(3339),
    [anon_sym_DASH] = ACTIONS(3339),
    [anon_sym_STAR] = ACTIONS(3341),
    [anon_sym_CARET] = ACTIONS(3341),
    [anon_sym_AMP] = ACTIONS(3341),
    [anon_sym_this] = ACTIONS(3339),
    [anon_sym_scoped] = ACTIONS(3339),
    [anon_sym_base] = ACTIONS(3339),
    [anon_sym_var] = ACTIONS(3339),
    [sym_predefined_type] = ACTIONS(3339),
    [anon_sym_break] = ACTIONS(3339),
    [anon_sym_unchecked] = ACTIONS(3339),
    [anon_sym_continue] = ACTIONS(3339),
    [anon_sym_do] = ACTIONS(3339),
    [anon_sym_while] = ACTIONS(3339),
    [anon_sym_for] = ACTIONS(3339),
    [anon_sym_lock] = ACTIONS(3339),
    [anon_sym_yield] = ACTIONS(3339),
    [anon_sym_switch] = ACTIONS(3339),
    [anon_sym_case] = ACTIONS(3339),
    [anon_sym_default] = ACTIONS(3339),
    [anon_sym_throw] = ACTIONS(3339),
    [anon_sym_try] = ACTIONS(3339),
    [anon_sym_when] = ACTIONS(3339),
    [anon_sym_await] = ACTIONS(3339),
    [anon_sym_foreach] = ACTIONS(3339),
    [anon_sym_goto] = ACTIONS(3339),
    [anon_sym_if] = ACTIONS(3339),
    [anon_sym_else] = ACTIONS(3339),
    [anon_sym_DOT_DOT] = ACTIONS(3341),
    [anon_sym_from] = ACTIONS(3339),
    [anon_sym_into] = ACTIONS(3339),
    [anon_sym_join] = ACTIONS(3339),
    [anon_sym_on] = ACTIONS(3339),
    [anon_sym_equals] = ACTIONS(3339),
    [anon_sym_let] = ACTIONS(3339),
    [anon_sym_orderby] = ACTIONS(3339),
    [anon_sym_ascending] = ACTIONS(3339),
    [anon_sym_descending] = ACTIONS(3339),
    [anon_sym_group] = ACTIONS(3339),
    [anon_sym_by] = ACTIONS(3339),
    [anon_sym_select] = ACTIONS(3339),
    [anon_sym_stackalloc] = ACTIONS(3339),
    [anon_sym_sizeof] = ACTIONS(3339),
    [anon_sym_typeof] = ACTIONS(3339),
    [anon_sym___makeref] = ACTIONS(3339),
    [anon_sym___reftype] = ACTIONS(3339),
    [anon_sym___refvalue] = ACTIONS(3339),
    [sym_null_literal] = ACTIONS(3339),
    [anon_sym_SQUOTE] = ACTIONS(3341),
    [sym_integer_literal] = ACTIONS(3339),
    [sym_real_literal] = ACTIONS(3341),
    [anon_sym_DQUOTE] = ACTIONS(3341),
    [sym_verbatim_string_literal] = ACTIONS(3341),
    [aux_sym_preproc_if_token1] = ACTIONS(3341),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3341),
    [sym_interpolation_verbatim_start] = ACTIONS(3341),
    [sym_interpolation_raw_start] = ACTIONS(3341),
    [sym_raw_string_start] = ACTIONS(3341),
  },
  [2727] = {
    [sym_preproc_region] = STATE(2727),
    [sym_preproc_endregion] = STATE(2727),
    [sym_preproc_line] = STATE(2727),
    [sym_preproc_pragma] = STATE(2727),
    [sym_preproc_nullable] = STATE(2727),
    [sym_preproc_error] = STATE(2727),
    [sym_preproc_warning] = STATE(2727),
    [sym_preproc_define] = STATE(2727),
    [sym_preproc_undef] = STATE(2727),
    [sym__identifier_token] = ACTIONS(3355),
    [anon_sym_extern] = ACTIONS(3355),
    [anon_sym_alias] = ACTIONS(3355),
    [anon_sym_SEMI] = ACTIONS(3357),
    [anon_sym_global] = ACTIONS(3355),
    [anon_sym_using] = ACTIONS(3355),
    [anon_sym_unsafe] = ACTIONS(3355),
    [anon_sym_static] = ACTIONS(3355),
    [anon_sym_LBRACK] = ACTIONS(3357),
    [anon_sym_LPAREN] = ACTIONS(3357),
    [anon_sym_return] = ACTIONS(3355),
    [anon_sym_ref] = ACTIONS(3355),
    [anon_sym_LBRACE] = ACTIONS(3357),
    [anon_sym_RBRACE] = ACTIONS(3357),
    [anon_sym_delegate] = ACTIONS(3355),
    [anon_sym_abstract] = ACTIONS(3355),
    [anon_sym_async] = ACTIONS(3355),
    [anon_sym_const] = ACTIONS(3355),
    [anon_sym_file] = ACTIONS(3355),
    [anon_sym_fixed] = ACTIONS(3355),
    [anon_sym_internal] = ACTIONS(3355),
    [anon_sym_new] = ACTIONS(3355),
    [anon_sym_override] = ACTIONS(3355),
    [anon_sym_partial] = ACTIONS(3355),
    [anon_sym_private] = ACTIONS(3355),
    [anon_sym_protected] = ACTIONS(3355),
    [anon_sym_public] = ACTIONS(3355),
    [anon_sym_readonly] = ACTIONS(3355),
    [anon_sym_required] = ACTIONS(3355),
    [anon_sym_sealed] = ACTIONS(3355),
    [anon_sym_virtual] = ACTIONS(3355),
    [anon_sym_volatile] = ACTIONS(3355),
    [anon_sym_where] = ACTIONS(3355),
    [anon_sym_notnull] = ACTIONS(3355),
    [anon_sym_unmanaged] = ACTIONS(3355),
    [anon_sym_checked] = ACTIONS(3355),
    [anon_sym_BANG] = ACTIONS(3357),
    [anon_sym_TILDE] = ACTIONS(3357),
    [anon_sym_PLUS_PLUS] = ACTIONS(3357),
    [anon_sym_DASH_DASH] = ACTIONS(3357),
    [anon_sym_true] = ACTIONS(3355),
    [anon_sym_false] = ACTIONS(3355),
    [anon_sym_PLUS] = ACTIONS(3355),
    [anon_sym_DASH] = ACTIONS(3355),
    [anon_sym_STAR] = ACTIONS(3357),
    [anon_sym_CARET] = ACTIONS(3357),
    [anon_sym_AMP] = ACTIONS(3357),
    [anon_sym_this] = ACTIONS(3355),
    [anon_sym_scoped] = ACTIONS(3355),
    [anon_sym_base] = ACTIONS(3355),
    [anon_sym_var] = ACTIONS(3355),
    [sym_predefined_type] = ACTIONS(3355),
    [anon_sym_break] = ACTIONS(3355),
    [anon_sym_unchecked] = ACTIONS(3355),
    [anon_sym_continue] = ACTIONS(3355),
    [anon_sym_do] = ACTIONS(3355),
    [anon_sym_while] = ACTIONS(3355),
    [anon_sym_for] = ACTIONS(3355),
    [anon_sym_lock] = ACTIONS(3355),
    [anon_sym_yield] = ACTIONS(3355),
    [anon_sym_switch] = ACTIONS(3355),
    [anon_sym_case] = ACTIONS(3355),
    [anon_sym_default] = ACTIONS(3355),
    [anon_sym_throw] = ACTIONS(3355),
    [anon_sym_try] = ACTIONS(3355),
    [anon_sym_when] = ACTIONS(3355),
    [anon_sym_await] = ACTIONS(3355),
    [anon_sym_foreach] = ACTIONS(3355),
    [anon_sym_goto] = ACTIONS(3355),
    [anon_sym_if] = ACTIONS(3355),
    [anon_sym_else] = ACTIONS(3355),
    [anon_sym_DOT_DOT] = ACTIONS(3357),
    [anon_sym_from] = ACTIONS(3355),
    [anon_sym_into] = ACTIONS(3355),
    [anon_sym_join] = ACTIONS(3355),
    [anon_sym_on] = ACTIONS(3355),
    [anon_sym_equals] = ACTIONS(3355),
    [anon_sym_let] = ACTIONS(3355),
    [anon_sym_orderby] = ACTIONS(3355),
    [anon_sym_ascending] = ACTIONS(3355),
    [anon_sym_descending] = ACTIONS(3355),
    [anon_sym_group] = ACTIONS(3355),
    [anon_sym_by] = ACTIONS(3355),
    [anon_sym_select] = ACTIONS(3355),
    [anon_sym_stackalloc] = ACTIONS(3355),
    [anon_sym_sizeof] = ACTIONS(3355),
    [anon_sym_typeof] = ACTIONS(3355),
    [anon_sym___makeref] = ACTIONS(3355),
    [anon_sym___reftype] = ACTIONS(3355),
    [anon_sym___refvalue] = ACTIONS(3355),
    [sym_null_literal] = ACTIONS(3355),
    [anon_sym_SQUOTE] = ACTIONS(3357),
    [sym_integer_literal] = ACTIONS(3355),
    [sym_real_literal] = ACTIONS(3357),
    [anon_sym_DQUOTE] = ACTIONS(3357),
    [sym_verbatim_string_literal] = ACTIONS(3357),
    [aux_sym_preproc_if_token1] = ACTIONS(3357),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3357),
    [sym_interpolation_verbatim_start] = ACTIONS(3357),
    [sym_interpolation_raw_start] = ACTIONS(3357),
    [sym_raw_string_start] = ACTIONS(3357),
  },
  [2728] = {
    [sym_preproc_region] = STATE(2728),
    [sym_preproc_endregion] = STATE(2728),
    [sym_preproc_line] = STATE(2728),
    [sym_preproc_pragma] = STATE(2728),
    [sym_preproc_nullable] = STATE(2728),
    [sym_preproc_error] = STATE(2728),
    [sym_preproc_warning] = STATE(2728),
    [sym_preproc_define] = STATE(2728),
    [sym_preproc_undef] = STATE(2728),
    [sym__identifier_token] = ACTIONS(3049),
    [anon_sym_extern] = ACTIONS(3049),
    [anon_sym_alias] = ACTIONS(3049),
    [anon_sym_SEMI] = ACTIONS(3051),
    [anon_sym_global] = ACTIONS(3049),
    [anon_sym_using] = ACTIONS(3049),
    [anon_sym_unsafe] = ACTIONS(3049),
    [anon_sym_static] = ACTIONS(3049),
    [anon_sym_LBRACK] = ACTIONS(3051),
    [anon_sym_LPAREN] = ACTIONS(3051),
    [anon_sym_return] = ACTIONS(3049),
    [anon_sym_ref] = ACTIONS(3049),
    [anon_sym_LBRACE] = ACTIONS(3051),
    [anon_sym_RBRACE] = ACTIONS(3051),
    [anon_sym_delegate] = ACTIONS(3049),
    [anon_sym_abstract] = ACTIONS(3049),
    [anon_sym_async] = ACTIONS(3049),
    [anon_sym_const] = ACTIONS(3049),
    [anon_sym_file] = ACTIONS(3049),
    [anon_sym_fixed] = ACTIONS(3049),
    [anon_sym_internal] = ACTIONS(3049),
    [anon_sym_new] = ACTIONS(3049),
    [anon_sym_override] = ACTIONS(3049),
    [anon_sym_partial] = ACTIONS(3049),
    [anon_sym_private] = ACTIONS(3049),
    [anon_sym_protected] = ACTIONS(3049),
    [anon_sym_public] = ACTIONS(3049),
    [anon_sym_readonly] = ACTIONS(3049),
    [anon_sym_required] = ACTIONS(3049),
    [anon_sym_sealed] = ACTIONS(3049),
    [anon_sym_virtual] = ACTIONS(3049),
    [anon_sym_volatile] = ACTIONS(3049),
    [anon_sym_where] = ACTIONS(3049),
    [anon_sym_notnull] = ACTIONS(3049),
    [anon_sym_unmanaged] = ACTIONS(3049),
    [anon_sym_checked] = ACTIONS(3049),
    [anon_sym_BANG] = ACTIONS(3051),
    [anon_sym_TILDE] = ACTIONS(3051),
    [anon_sym_PLUS_PLUS] = ACTIONS(3051),
    [anon_sym_DASH_DASH] = ACTIONS(3051),
    [anon_sym_true] = ACTIONS(3049),
    [anon_sym_false] = ACTIONS(3049),
    [anon_sym_PLUS] = ACTIONS(3049),
    [anon_sym_DASH] = ACTIONS(3049),
    [anon_sym_STAR] = ACTIONS(3051),
    [anon_sym_CARET] = ACTIONS(3051),
    [anon_sym_AMP] = ACTIONS(3051),
    [anon_sym_this] = ACTIONS(3049),
    [anon_sym_scoped] = ACTIONS(3049),
    [anon_sym_base] = ACTIONS(3049),
    [anon_sym_var] = ACTIONS(3049),
    [sym_predefined_type] = ACTIONS(3049),
    [anon_sym_break] = ACTIONS(3049),
    [anon_sym_unchecked] = ACTIONS(3049),
    [anon_sym_continue] = ACTIONS(3049),
    [anon_sym_do] = ACTIONS(3049),
    [anon_sym_while] = ACTIONS(3049),
    [anon_sym_for] = ACTIONS(3049),
    [anon_sym_lock] = ACTIONS(3049),
    [anon_sym_yield] = ACTIONS(3049),
    [anon_sym_switch] = ACTIONS(3049),
    [anon_sym_case] = ACTIONS(3049),
    [anon_sym_default] = ACTIONS(3049),
    [anon_sym_throw] = ACTIONS(3049),
    [anon_sym_try] = ACTIONS(3049),
    [anon_sym_when] = ACTIONS(3049),
    [anon_sym_await] = ACTIONS(3049),
    [anon_sym_foreach] = ACTIONS(3049),
    [anon_sym_goto] = ACTIONS(3049),
    [anon_sym_if] = ACTIONS(3049),
    [anon_sym_else] = ACTIONS(3049),
    [anon_sym_DOT_DOT] = ACTIONS(3051),
    [anon_sym_from] = ACTIONS(3049),
    [anon_sym_into] = ACTIONS(3049),
    [anon_sym_join] = ACTIONS(3049),
    [anon_sym_on] = ACTIONS(3049),
    [anon_sym_equals] = ACTIONS(3049),
    [anon_sym_let] = ACTIONS(3049),
    [anon_sym_orderby] = ACTIONS(3049),
    [anon_sym_ascending] = ACTIONS(3049),
    [anon_sym_descending] = ACTIONS(3049),
    [anon_sym_group] = ACTIONS(3049),
    [anon_sym_by] = ACTIONS(3049),
    [anon_sym_select] = ACTIONS(3049),
    [anon_sym_stackalloc] = ACTIONS(3049),
    [anon_sym_sizeof] = ACTIONS(3049),
    [anon_sym_typeof] = ACTIONS(3049),
    [anon_sym___makeref] = ACTIONS(3049),
    [anon_sym___reftype] = ACTIONS(3049),
    [anon_sym___refvalue] = ACTIONS(3049),
    [sym_null_literal] = ACTIONS(3049),
    [anon_sym_SQUOTE] = ACTIONS(3051),
    [sym_integer_literal] = ACTIONS(3049),
    [sym_real_literal] = ACTIONS(3051),
    [anon_sym_DQUOTE] = ACTIONS(3051),
    [sym_verbatim_string_literal] = ACTIONS(3051),
    [aux_sym_preproc_if_token1] = ACTIONS(3051),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3051),
    [sym_interpolation_verbatim_start] = ACTIONS(3051),
    [sym_interpolation_raw_start] = ACTIONS(3051),
    [sym_raw_string_start] = ACTIONS(3051),
  },
  [2729] = {
    [sym_preproc_region] = STATE(2729),
    [sym_preproc_endregion] = STATE(2729),
    [sym_preproc_line] = STATE(2729),
    [sym_preproc_pragma] = STATE(2729),
    [sym_preproc_nullable] = STATE(2729),
    [sym_preproc_error] = STATE(2729),
    [sym_preproc_warning] = STATE(2729),
    [sym_preproc_define] = STATE(2729),
    [sym_preproc_undef] = STATE(2729),
    [sym__identifier_token] = ACTIONS(3393),
    [anon_sym_extern] = ACTIONS(3393),
    [anon_sym_alias] = ACTIONS(3393),
    [anon_sym_SEMI] = ACTIONS(3395),
    [anon_sym_global] = ACTIONS(3393),
    [anon_sym_using] = ACTIONS(3393),
    [anon_sym_unsafe] = ACTIONS(3393),
    [anon_sym_static] = ACTIONS(3393),
    [anon_sym_LBRACK] = ACTIONS(3395),
    [anon_sym_LPAREN] = ACTIONS(3395),
    [anon_sym_return] = ACTIONS(3393),
    [anon_sym_ref] = ACTIONS(3393),
    [anon_sym_LBRACE] = ACTIONS(3395),
    [anon_sym_RBRACE] = ACTIONS(3395),
    [anon_sym_delegate] = ACTIONS(3393),
    [anon_sym_abstract] = ACTIONS(3393),
    [anon_sym_async] = ACTIONS(3393),
    [anon_sym_const] = ACTIONS(3393),
    [anon_sym_file] = ACTIONS(3393),
    [anon_sym_fixed] = ACTIONS(3393),
    [anon_sym_internal] = ACTIONS(3393),
    [anon_sym_new] = ACTIONS(3393),
    [anon_sym_override] = ACTIONS(3393),
    [anon_sym_partial] = ACTIONS(3393),
    [anon_sym_private] = ACTIONS(3393),
    [anon_sym_protected] = ACTIONS(3393),
    [anon_sym_public] = ACTIONS(3393),
    [anon_sym_readonly] = ACTIONS(3393),
    [anon_sym_required] = ACTIONS(3393),
    [anon_sym_sealed] = ACTIONS(3393),
    [anon_sym_virtual] = ACTIONS(3393),
    [anon_sym_volatile] = ACTIONS(3393),
    [anon_sym_where] = ACTIONS(3393),
    [anon_sym_notnull] = ACTIONS(3393),
    [anon_sym_unmanaged] = ACTIONS(3393),
    [anon_sym_checked] = ACTIONS(3393),
    [anon_sym_BANG] = ACTIONS(3395),
    [anon_sym_TILDE] = ACTIONS(3395),
    [anon_sym_PLUS_PLUS] = ACTIONS(3395),
    [anon_sym_DASH_DASH] = ACTIONS(3395),
    [anon_sym_true] = ACTIONS(3393),
    [anon_sym_false] = ACTIONS(3393),
    [anon_sym_PLUS] = ACTIONS(3393),
    [anon_sym_DASH] = ACTIONS(3393),
    [anon_sym_STAR] = ACTIONS(3395),
    [anon_sym_CARET] = ACTIONS(3395),
    [anon_sym_AMP] = ACTIONS(3395),
    [anon_sym_this] = ACTIONS(3393),
    [anon_sym_scoped] = ACTIONS(3393),
    [anon_sym_base] = ACTIONS(3393),
    [anon_sym_var] = ACTIONS(3393),
    [sym_predefined_type] = ACTIONS(3393),
    [anon_sym_break] = ACTIONS(3393),
    [anon_sym_unchecked] = ACTIONS(3393),
    [anon_sym_continue] = ACTIONS(3393),
    [anon_sym_do] = ACTIONS(3393),
    [anon_sym_while] = ACTIONS(3393),
    [anon_sym_for] = ACTIONS(3393),
    [anon_sym_lock] = ACTIONS(3393),
    [anon_sym_yield] = ACTIONS(3393),
    [anon_sym_switch] = ACTIONS(3393),
    [anon_sym_case] = ACTIONS(3393),
    [anon_sym_default] = ACTIONS(3393),
    [anon_sym_throw] = ACTIONS(3393),
    [anon_sym_try] = ACTIONS(3393),
    [anon_sym_when] = ACTIONS(3393),
    [anon_sym_await] = ACTIONS(3393),
    [anon_sym_foreach] = ACTIONS(3393),
    [anon_sym_goto] = ACTIONS(3393),
    [anon_sym_if] = ACTIONS(3393),
    [anon_sym_else] = ACTIONS(3393),
    [anon_sym_DOT_DOT] = ACTIONS(3395),
    [anon_sym_from] = ACTIONS(3393),
    [anon_sym_into] = ACTIONS(3393),
    [anon_sym_join] = ACTIONS(3393),
    [anon_sym_on] = ACTIONS(3393),
    [anon_sym_equals] = ACTIONS(3393),
    [anon_sym_let] = ACTIONS(3393),
    [anon_sym_orderby] = ACTIONS(3393),
    [anon_sym_ascending] = ACTIONS(3393),
    [anon_sym_descending] = ACTIONS(3393),
    [anon_sym_group] = ACTIONS(3393),
    [anon_sym_by] = ACTIONS(3393),
    [anon_sym_select] = ACTIONS(3393),
    [anon_sym_stackalloc] = ACTIONS(3393),
    [anon_sym_sizeof] = ACTIONS(3393),
    [anon_sym_typeof] = ACTIONS(3393),
    [anon_sym___makeref] = ACTIONS(3393),
    [anon_sym___reftype] = ACTIONS(3393),
    [anon_sym___refvalue] = ACTIONS(3393),
    [sym_null_literal] = ACTIONS(3393),
    [anon_sym_SQUOTE] = ACTIONS(3395),
    [sym_integer_literal] = ACTIONS(3393),
    [sym_real_literal] = ACTIONS(3395),
    [anon_sym_DQUOTE] = ACTIONS(3395),
    [sym_verbatim_string_literal] = ACTIONS(3395),
    [aux_sym_preproc_if_token1] = ACTIONS(3395),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3395),
    [sym_interpolation_verbatim_start] = ACTIONS(3395),
    [sym_interpolation_raw_start] = ACTIONS(3395),
    [sym_raw_string_start] = ACTIONS(3395),
  },
  [2730] = {
    [sym_preproc_region] = STATE(2730),
    [sym_preproc_endregion] = STATE(2730),
    [sym_preproc_line] = STATE(2730),
    [sym_preproc_pragma] = STATE(2730),
    [sym_preproc_nullable] = STATE(2730),
    [sym_preproc_error] = STATE(2730),
    [sym_preproc_warning] = STATE(2730),
    [sym_preproc_define] = STATE(2730),
    [sym_preproc_undef] = STATE(2730),
    [sym__identifier_token] = ACTIONS(3359),
    [anon_sym_extern] = ACTIONS(3359),
    [anon_sym_alias] = ACTIONS(3359),
    [anon_sym_SEMI] = ACTIONS(3361),
    [anon_sym_global] = ACTIONS(3359),
    [anon_sym_using] = ACTIONS(3359),
    [anon_sym_unsafe] = ACTIONS(3359),
    [anon_sym_static] = ACTIONS(3359),
    [anon_sym_LBRACK] = ACTIONS(3361),
    [anon_sym_LPAREN] = ACTIONS(3361),
    [anon_sym_return] = ACTIONS(3359),
    [anon_sym_ref] = ACTIONS(3359),
    [anon_sym_LBRACE] = ACTIONS(3361),
    [anon_sym_RBRACE] = ACTIONS(3361),
    [anon_sym_delegate] = ACTIONS(3359),
    [anon_sym_abstract] = ACTIONS(3359),
    [anon_sym_async] = ACTIONS(3359),
    [anon_sym_const] = ACTIONS(3359),
    [anon_sym_file] = ACTIONS(3359),
    [anon_sym_fixed] = ACTIONS(3359),
    [anon_sym_internal] = ACTIONS(3359),
    [anon_sym_new] = ACTIONS(3359),
    [anon_sym_override] = ACTIONS(3359),
    [anon_sym_partial] = ACTIONS(3359),
    [anon_sym_private] = ACTIONS(3359),
    [anon_sym_protected] = ACTIONS(3359),
    [anon_sym_public] = ACTIONS(3359),
    [anon_sym_readonly] = ACTIONS(3359),
    [anon_sym_required] = ACTIONS(3359),
    [anon_sym_sealed] = ACTIONS(3359),
    [anon_sym_virtual] = ACTIONS(3359),
    [anon_sym_volatile] = ACTIONS(3359),
    [anon_sym_where] = ACTIONS(3359),
    [anon_sym_notnull] = ACTIONS(3359),
    [anon_sym_unmanaged] = ACTIONS(3359),
    [anon_sym_checked] = ACTIONS(3359),
    [anon_sym_BANG] = ACTIONS(3361),
    [anon_sym_TILDE] = ACTIONS(3361),
    [anon_sym_PLUS_PLUS] = ACTIONS(3361),
    [anon_sym_DASH_DASH] = ACTIONS(3361),
    [anon_sym_true] = ACTIONS(3359),
    [anon_sym_false] = ACTIONS(3359),
    [anon_sym_PLUS] = ACTIONS(3359),
    [anon_sym_DASH] = ACTIONS(3359),
    [anon_sym_STAR] = ACTIONS(3361),
    [anon_sym_CARET] = ACTIONS(3361),
    [anon_sym_AMP] = ACTIONS(3361),
    [anon_sym_this] = ACTIONS(3359),
    [anon_sym_scoped] = ACTIONS(3359),
    [anon_sym_base] = ACTIONS(3359),
    [anon_sym_var] = ACTIONS(3359),
    [sym_predefined_type] = ACTIONS(3359),
    [anon_sym_break] = ACTIONS(3359),
    [anon_sym_unchecked] = ACTIONS(3359),
    [anon_sym_continue] = ACTIONS(3359),
    [anon_sym_do] = ACTIONS(3359),
    [anon_sym_while] = ACTIONS(3359),
    [anon_sym_for] = ACTIONS(3359),
    [anon_sym_lock] = ACTIONS(3359),
    [anon_sym_yield] = ACTIONS(3359),
    [anon_sym_switch] = ACTIONS(3359),
    [anon_sym_case] = ACTIONS(3359),
    [anon_sym_default] = ACTIONS(3359),
    [anon_sym_throw] = ACTIONS(3359),
    [anon_sym_try] = ACTIONS(3359),
    [anon_sym_when] = ACTIONS(3359),
    [anon_sym_await] = ACTIONS(3359),
    [anon_sym_foreach] = ACTIONS(3359),
    [anon_sym_goto] = ACTIONS(3359),
    [anon_sym_if] = ACTIONS(3359),
    [anon_sym_else] = ACTIONS(3359),
    [anon_sym_DOT_DOT] = ACTIONS(3361),
    [anon_sym_from] = ACTIONS(3359),
    [anon_sym_into] = ACTIONS(3359),
    [anon_sym_join] = ACTIONS(3359),
    [anon_sym_on] = ACTIONS(3359),
    [anon_sym_equals] = ACTIONS(3359),
    [anon_sym_let] = ACTIONS(3359),
    [anon_sym_orderby] = ACTIONS(3359),
    [anon_sym_ascending] = ACTIONS(3359),
    [anon_sym_descending] = ACTIONS(3359),
    [anon_sym_group] = ACTIONS(3359),
    [anon_sym_by] = ACTIONS(3359),
    [anon_sym_select] = ACTIONS(3359),
    [anon_sym_stackalloc] = ACTIONS(3359),
    [anon_sym_sizeof] = ACTIONS(3359),
    [anon_sym_typeof] = ACTIONS(3359),
    [anon_sym___makeref] = ACTIONS(3359),
    [anon_sym___reftype] = ACTIONS(3359),
    [anon_sym___refvalue] = ACTIONS(3359),
    [sym_null_literal] = ACTIONS(3359),
    [anon_sym_SQUOTE] = ACTIONS(3361),
    [sym_integer_literal] = ACTIONS(3359),
    [sym_real_literal] = ACTIONS(3361),
    [anon_sym_DQUOTE] = ACTIONS(3361),
    [sym_verbatim_string_literal] = ACTIONS(3361),
    [aux_sym_preproc_if_token1] = ACTIONS(3361),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(3361),
    [sym_interpolation_verbatim_start] = ACTIONS(3361),
    [sym_interpolation_raw_start] = ACTIONS(3361),
    [sym_raw_string_start] = ACTIONS(3361),
  },
  [2731] = {
    [sym_preproc_region] = STATE(2731),
    [sym_preproc_endregion] = STATE(2731),
    [sym_preproc_line] = STATE(2731),
    [sym_preproc_pragma] = STATE(2731),
    [sym_preproc_nullable] = STATE(2731),
    [sym_preproc_error] = STATE(2731),
    [sym_preproc_warning] = STATE(2731),
    [sym_preproc_define] = STATE(2731),
    [sym_preproc_undef] = STATE(2731),
    [sym__identifier_token] = ACTIONS(4039),
    [anon_sym_extern] = ACTIONS(4042),
    [anon_sym_alias] = ACTIONS(4039),
    [anon_sym_SEMI] = ACTIONS(3993),
    [anon_sym_global] = ACTIONS(4039),
    [anon_sym_unsafe] = ACTIONS(4042),
    [anon_sym_EQ] = ACTIONS(3995),
    [anon_sym_static] = ACTIONS(4042),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_COLON] = ACTIONS(3995),
    [anon_sym_COMMA] = ACTIONS(3993),
    [anon_sym_LPAREN] = ACTIONS(4044),
    [anon_sym_ref] = ACTIONS(4042),
    [anon_sym_RBRACE] = ACTIONS(3993),
    [anon_sym_delegate] = ACTIONS(4042),
    [anon_sym_abstract] = ACTIONS(4042),
    [anon_sym_async] = ACTIONS(4042),
    [anon_sym_const] = ACTIONS(4042),
    [anon_sym_file] = ACTIONS(4039),
    [anon_sym_fixed] = ACTIONS(4042),
    [anon_sym_internal] = ACTIONS(4042),
    [anon_sym_new] = ACTIONS(4042),
    [anon_sym_override] = ACTIONS(4042),
    [anon_sym_partial] = ACTIONS(4042),
    [anon_sym_private] = ACTIONS(4042),
    [anon_sym_protected] = ACTIONS(4042),
    [anon_sym_public] = ACTIONS(4042),
    [anon_sym_readonly] = ACTIONS(4042),
    [anon_sym_required] = ACTIONS(4042),
    [anon_sym_sealed] = ACTIONS(4042),
    [anon_sym_virtual] = ACTIONS(4042),
    [anon_sym_volatile] = ACTIONS(4042),
    [anon_sym_LT] = ACTIONS(3995),
    [anon_sym_GT] = ACTIONS(3995),
    [anon_sym_where] = ACTIONS(4039),
    [anon_sym_QMARK] = ACTIONS(3995),
    [anon_sym_notnull] = ACTIONS(4039),
    [anon_sym_unmanaged] = ACTIONS(4039),
    [anon_sym_BANG] = ACTIONS(3995),
    [anon_sym_PLUS_PLUS] = ACTIONS(3993),
    [anon_sym_DASH_DASH] = ACTIONS(3993),
    [anon_sym_PLUS] = ACTIONS(3995),
    [anon_sym_DASH] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3995),
    [anon_sym_SLASH] = ACTIONS(3995),
    [anon_sym_PERCENT] = ACTIONS(3995),
    [anon_sym_CARET] = ACTIONS(3995),
    [anon_sym_PIPE] = ACTIONS(3995),
    [anon_sym_AMP] = ACTIONS(3995),
    [anon_sym_LT_LT] = ACTIONS(3995),
    [anon_sym_GT_GT] = ACTIONS(3995),
    [anon_sym_GT_GT_GT] = ACTIONS(3995),
    [anon_sym_EQ_EQ] = ACTIONS(3993),
    [anon_sym_BANG_EQ] = ACTIONS(3993),
    [anon_sym_GT_EQ] = ACTIONS(3993),
    [anon_sym_LT_EQ] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3995),
    [anon_sym_scoped] = ACTIONS(4039),
    [anon_sym_EQ_GT] = ACTIONS(3993),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(4039),
    [sym_predefined_type] = ACTIONS(4042),
    [anon_sym_yield] = ACTIONS(4039),
    [anon_sym_switch] = ACTIONS(3995),
    [anon_sym_when] = ACTIONS(4039),
    [anon_sym_DOT_DOT] = ACTIONS(3993),
    [anon_sym_PLUS_EQ] = ACTIONS(3993),
    [anon_sym_DASH_EQ] = ACTIONS(3993),
    [anon_sym_STAR_EQ] = ACTIONS(3993),
    [anon_sym_SLASH_EQ] = ACTIONS(3993),
    [anon_sym_PERCENT_EQ] = ACTIONS(3993),
    [anon_sym_AMP_EQ] = ACTIONS(3993),
    [anon_sym_CARET_EQ] = ACTIONS(3993),
    [anon_sym_PIPE_EQ] = ACTIONS(3993),
    [anon_sym_LT_LT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(3993),
    [anon_sym_AMP_AMP] = ACTIONS(3993),
    [anon_sym_PIPE_PIPE] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK] = ACTIONS(3995),
    [anon_sym_from] = ACTIONS(4039),
    [anon_sym_into] = ACTIONS(4039),
    [anon_sym_join] = ACTIONS(4039),
    [anon_sym_on] = ACTIONS(4039),
    [anon_sym_equals] = ACTIONS(4039),
    [anon_sym_let] = ACTIONS(4039),
    [anon_sym_orderby] = ACTIONS(4039),
    [anon_sym_ascending] = ACTIONS(4039),
    [anon_sym_descending] = ACTIONS(4039),
    [anon_sym_group] = ACTIONS(4039),
    [anon_sym_by] = ACTIONS(4039),
    [anon_sym_select] = ACTIONS(4039),
    [anon_sym_as] = ACTIONS(3995),
    [anon_sym_is] = ACTIONS(3995),
    [anon_sym_DASH_GT] = ACTIONS(3993),
    [anon_sym_with] = ACTIONS(3995),
    [aux_sym_preproc_if_token3] = ACTIONS(3993),
    [aux_sym_preproc_else_token1] = ACTIONS(3993),
    [aux_sym_preproc_elif_token1] = ACTIONS(3993),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2732] = {
    [sym_preproc_region] = STATE(2732),
    [sym_preproc_endregion] = STATE(2732),
    [sym_preproc_line] = STATE(2732),
    [sym_preproc_pragma] = STATE(2732),
    [sym_preproc_nullable] = STATE(2732),
    [sym_preproc_error] = STATE(2732),
    [sym_preproc_warning] = STATE(2732),
    [sym_preproc_define] = STATE(2732),
    [sym_preproc_undef] = STATE(2732),
    [sym__identifier_token] = ACTIONS(4049),
    [anon_sym_extern] = ACTIONS(4049),
    [anon_sym_alias] = ACTIONS(4049),
    [anon_sym_SEMI] = ACTIONS(4051),
    [anon_sym_global] = ACTIONS(4049),
    [anon_sym_using] = ACTIONS(4049),
    [anon_sym_unsafe] = ACTIONS(4049),
    [anon_sym_static] = ACTIONS(4049),
    [anon_sym_LBRACK] = ACTIONS(4051),
    [anon_sym_LPAREN] = ACTIONS(4051),
    [anon_sym_return] = ACTIONS(4049),
    [anon_sym_ref] = ACTIONS(4049),
    [anon_sym_LBRACE] = ACTIONS(4051),
    [anon_sym_RBRACE] = ACTIONS(4051),
    [anon_sym_delegate] = ACTIONS(4049),
    [anon_sym_abstract] = ACTIONS(4049),
    [anon_sym_async] = ACTIONS(4049),
    [anon_sym_const] = ACTIONS(4049),
    [anon_sym_file] = ACTIONS(4049),
    [anon_sym_fixed] = ACTIONS(4049),
    [anon_sym_internal] = ACTIONS(4049),
    [anon_sym_new] = ACTIONS(4049),
    [anon_sym_override] = ACTIONS(4049),
    [anon_sym_partial] = ACTIONS(4049),
    [anon_sym_private] = ACTIONS(4049),
    [anon_sym_protected] = ACTIONS(4049),
    [anon_sym_public] = ACTIONS(4049),
    [anon_sym_readonly] = ACTIONS(4049),
    [anon_sym_required] = ACTIONS(4049),
    [anon_sym_sealed] = ACTIONS(4049),
    [anon_sym_virtual] = ACTIONS(4049),
    [anon_sym_volatile] = ACTIONS(4049),
    [anon_sym_where] = ACTIONS(4049),
    [anon_sym_notnull] = ACTIONS(4049),
    [anon_sym_unmanaged] = ACTIONS(4049),
    [anon_sym_checked] = ACTIONS(4049),
    [anon_sym_BANG] = ACTIONS(4051),
    [anon_sym_TILDE] = ACTIONS(4051),
    [anon_sym_PLUS_PLUS] = ACTIONS(4051),
    [anon_sym_DASH_DASH] = ACTIONS(4051),
    [anon_sym_true] = ACTIONS(4049),
    [anon_sym_false] = ACTIONS(4049),
    [anon_sym_PLUS] = ACTIONS(4049),
    [anon_sym_DASH] = ACTIONS(4049),
    [anon_sym_STAR] = ACTIONS(4051),
    [anon_sym_CARET] = ACTIONS(4051),
    [anon_sym_AMP] = ACTIONS(4051),
    [anon_sym_this] = ACTIONS(4049),
    [anon_sym_scoped] = ACTIONS(4049),
    [anon_sym_base] = ACTIONS(4049),
    [anon_sym_var] = ACTIONS(4049),
    [sym_predefined_type] = ACTIONS(4049),
    [anon_sym_break] = ACTIONS(4049),
    [anon_sym_unchecked] = ACTIONS(4049),
    [anon_sym_continue] = ACTIONS(4049),
    [anon_sym_do] = ACTIONS(4049),
    [anon_sym_while] = ACTIONS(4049),
    [anon_sym_for] = ACTIONS(4049),
    [anon_sym_lock] = ACTIONS(4049),
    [anon_sym_yield] = ACTIONS(4049),
    [anon_sym_switch] = ACTIONS(4049),
    [anon_sym_case] = ACTIONS(4049),
    [anon_sym_default] = ACTIONS(4049),
    [anon_sym_throw] = ACTIONS(4049),
    [anon_sym_try] = ACTIONS(4049),
    [anon_sym_when] = ACTIONS(4049),
    [anon_sym_await] = ACTIONS(4049),
    [anon_sym_foreach] = ACTIONS(4049),
    [anon_sym_goto] = ACTIONS(4049),
    [anon_sym_if] = ACTIONS(4049),
    [anon_sym_DOT_DOT] = ACTIONS(4051),
    [anon_sym_from] = ACTIONS(4049),
    [anon_sym_into] = ACTIONS(4049),
    [anon_sym_join] = ACTIONS(4049),
    [anon_sym_on] = ACTIONS(4049),
    [anon_sym_equals] = ACTIONS(4049),
    [anon_sym_let] = ACTIONS(4049),
    [anon_sym_orderby] = ACTIONS(4049),
    [anon_sym_ascending] = ACTIONS(4049),
    [anon_sym_descending] = ACTIONS(4049),
    [anon_sym_group] = ACTIONS(4049),
    [anon_sym_by] = ACTIONS(4049),
    [anon_sym_select] = ACTIONS(4049),
    [anon_sym_stackalloc] = ACTIONS(4049),
    [anon_sym_sizeof] = ACTIONS(4049),
    [anon_sym_typeof] = ACTIONS(4049),
    [anon_sym___makeref] = ACTIONS(4049),
    [anon_sym___reftype] = ACTIONS(4049),
    [anon_sym___refvalue] = ACTIONS(4049),
    [sym_null_literal] = ACTIONS(4049),
    [anon_sym_SQUOTE] = ACTIONS(4051),
    [sym_integer_literal] = ACTIONS(4049),
    [sym_real_literal] = ACTIONS(4051),
    [anon_sym_DQUOTE] = ACTIONS(4051),
    [sym_verbatim_string_literal] = ACTIONS(4051),
    [aux_sym_preproc_if_token1] = ACTIONS(4051),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_regular_start] = ACTIONS(4051),
    [sym_interpolation_verbatim_start] = ACTIONS(4051),
    [sym_interpolation_raw_start] = ACTIONS(4051),
    [sym_raw_string_start] = ACTIONS(4051),
  },
  [2733] = {
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7339),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(6820),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(2733),
    [sym_preproc_endregion] = STATE(2733),
    [sym_preproc_line] = STATE(2733),
    [sym_preproc_pragma] = STATE(2733),
    [sym_preproc_nullable] = STATE(2733),
    [sym_preproc_error] = STATE(2733),
    [sym_preproc_warning] = STATE(2733),
    [sym_preproc_define] = STATE(2733),
    [sym_preproc_undef] = STATE(2733),
    [sym__identifier_token] = ACTIONS(3987),
    [anon_sym_alias] = ACTIONS(3990),
    [anon_sym_global] = ACTIONS(3990),
    [anon_sym_EQ] = ACTIONS(3995),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_COLON] = ACTIONS(3995),
    [anon_sym_COMMA] = ACTIONS(3993),
    [anon_sym_LPAREN] = ACTIONS(3997),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_LBRACE] = ACTIONS(3993),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_file] = ACTIONS(3990),
    [anon_sym_LT] = ACTIONS(3995),
    [anon_sym_GT] = ACTIONS(3995),
    [anon_sym_where] = ACTIONS(3990),
    [anon_sym_QMARK] = ACTIONS(3995),
    [anon_sym_notnull] = ACTIONS(3990),
    [anon_sym_unmanaged] = ACTIONS(3990),
    [anon_sym_BANG] = ACTIONS(3995),
    [anon_sym_PLUS_PLUS] = ACTIONS(3993),
    [anon_sym_DASH_DASH] = ACTIONS(3993),
    [anon_sym_PLUS] = ACTIONS(3995),
    [anon_sym_DASH] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3995),
    [anon_sym_SLASH] = ACTIONS(3995),
    [anon_sym_PERCENT] = ACTIONS(3995),
    [anon_sym_CARET] = ACTIONS(3995),
    [anon_sym_PIPE] = ACTIONS(3995),
    [anon_sym_AMP] = ACTIONS(3995),
    [anon_sym_LT_LT] = ACTIONS(3995),
    [anon_sym_GT_GT] = ACTIONS(3995),
    [anon_sym_GT_GT_GT] = ACTIONS(3995),
    [anon_sym_EQ_EQ] = ACTIONS(3993),
    [anon_sym_BANG_EQ] = ACTIONS(3993),
    [anon_sym_GT_EQ] = ACTIONS(3993),
    [anon_sym_LT_EQ] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3995),
    [anon_sym_scoped] = ACTIONS(4004),
    [anon_sym_EQ_GT] = ACTIONS(3993),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(4007),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3990),
    [anon_sym_switch] = ACTIONS(3995),
    [anon_sym_when] = ACTIONS(3990),
    [sym_discard] = ACTIONS(3995),
    [anon_sym_DOT_DOT] = ACTIONS(3993),
    [anon_sym_and] = ACTIONS(3995),
    [anon_sym_or] = ACTIONS(3995),
    [anon_sym_PLUS_EQ] = ACTIONS(3993),
    [anon_sym_DASH_EQ] = ACTIONS(3993),
    [anon_sym_STAR_EQ] = ACTIONS(3993),
    [anon_sym_SLASH_EQ] = ACTIONS(3993),
    [anon_sym_PERCENT_EQ] = ACTIONS(3993),
    [anon_sym_AMP_EQ] = ACTIONS(3993),
    [anon_sym_CARET_EQ] = ACTIONS(3993),
    [anon_sym_PIPE_EQ] = ACTIONS(3993),
    [anon_sym_LT_LT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(3993),
    [anon_sym_AMP_AMP] = ACTIONS(3993),
    [anon_sym_PIPE_PIPE] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK] = ACTIONS(3995),
    [anon_sym_from] = ACTIONS(3990),
    [anon_sym_into] = ACTIONS(3990),
    [anon_sym_join] = ACTIONS(3990),
    [anon_sym_on] = ACTIONS(3990),
    [anon_sym_equals] = ACTIONS(3990),
    [anon_sym_let] = ACTIONS(3990),
    [anon_sym_orderby] = ACTIONS(3990),
    [anon_sym_ascending] = ACTIONS(3990),
    [anon_sym_descending] = ACTIONS(3990),
    [anon_sym_group] = ACTIONS(3990),
    [anon_sym_by] = ACTIONS(3990),
    [anon_sym_select] = ACTIONS(3990),
    [anon_sym_as] = ACTIONS(3995),
    [anon_sym_is] = ACTIONS(3995),
    [anon_sym_DASH_GT] = ACTIONS(3993),
    [anon_sym_with] = ACTIONS(3995),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(3993),
  },
  [2734] = {
    [sym__name] = STATE(3015),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2956),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2944),
    [sym_ref_type] = STATE(2883),
    [sym__scoped_base_type] = STATE(2885),
    [sym_identifier] = STATE(2920),
    [sym__reserved_identifier] = STATE(2928),
    [sym_preproc_region] = STATE(2734),
    [sym_preproc_endregion] = STATE(2734),
    [sym_preproc_line] = STATE(2734),
    [sym_preproc_pragma] = STATE(2734),
    [sym_preproc_nullable] = STATE(2734),
    [sym_preproc_error] = STATE(2734),
    [sym_preproc_warning] = STATE(2734),
    [sym_preproc_define] = STATE(2734),
    [sym_preproc_undef] = STATE(2734),
    [sym__identifier_token] = ACTIONS(4053),
    [anon_sym_alias] = ACTIONS(4056),
    [anon_sym_SEMI] = ACTIONS(3993),
    [anon_sym_global] = ACTIONS(4056),
    [anon_sym_EQ] = ACTIONS(3995),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_COMMA] = ACTIONS(3993),
    [anon_sym_RBRACK] = ACTIONS(3993),
    [anon_sym_LPAREN] = ACTIONS(3993),
    [anon_sym_RPAREN] = ACTIONS(3993),
    [anon_sym_ref] = ACTIONS(4059),
    [anon_sym_LBRACE] = ACTIONS(3993),
    [anon_sym_RBRACE] = ACTIONS(3993),
    [anon_sym_file] = ACTIONS(4056),
    [anon_sym_LT] = ACTIONS(3995),
    [anon_sym_GT] = ACTIONS(3995),
    [anon_sym_in] = ACTIONS(3995),
    [anon_sym_where] = ACTIONS(4056),
    [anon_sym_QMARK] = ACTIONS(3995),
    [anon_sym_notnull] = ACTIONS(4056),
    [anon_sym_unmanaged] = ACTIONS(4056),
    [anon_sym_BANG] = ACTIONS(3995),
    [anon_sym_PLUS_PLUS] = ACTIONS(3993),
    [anon_sym_DASH_DASH] = ACTIONS(3993),
    [anon_sym_PLUS] = ACTIONS(3995),
    [anon_sym_DASH] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3995),
    [anon_sym_SLASH] = ACTIONS(3995),
    [anon_sym_PERCENT] = ACTIONS(3995),
    [anon_sym_CARET] = ACTIONS(3995),
    [anon_sym_PIPE] = ACTIONS(3995),
    [anon_sym_AMP] = ACTIONS(3995),
    [anon_sym_LT_LT] = ACTIONS(3995),
    [anon_sym_GT_GT] = ACTIONS(3995),
    [anon_sym_GT_GT_GT] = ACTIONS(3995),
    [anon_sym_EQ_EQ] = ACTIONS(3993),
    [anon_sym_BANG_EQ] = ACTIONS(3993),
    [anon_sym_GT_EQ] = ACTIONS(3993),
    [anon_sym_LT_EQ] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3995),
    [anon_sym_scoped] = ACTIONS(4056),
    [anon_sym_EQ_GT] = ACTIONS(3993),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(4056),
    [anon_sym_yield] = ACTIONS(4056),
    [anon_sym_switch] = ACTIONS(3995),
    [anon_sym_when] = ACTIONS(4056),
    [sym_discard] = ACTIONS(3995),
    [anon_sym_DOT_DOT] = ACTIONS(3993),
    [anon_sym_and] = ACTIONS(3995),
    [anon_sym_or] = ACTIONS(3995),
    [anon_sym_PLUS_EQ] = ACTIONS(3993),
    [anon_sym_DASH_EQ] = ACTIONS(3993),
    [anon_sym_STAR_EQ] = ACTIONS(3993),
    [anon_sym_SLASH_EQ] = ACTIONS(3993),
    [anon_sym_PERCENT_EQ] = ACTIONS(3993),
    [anon_sym_AMP_EQ] = ACTIONS(3993),
    [anon_sym_CARET_EQ] = ACTIONS(3993),
    [anon_sym_PIPE_EQ] = ACTIONS(3993),
    [anon_sym_LT_LT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(3993),
    [anon_sym_AMP_AMP] = ACTIONS(3993),
    [anon_sym_PIPE_PIPE] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK] = ACTIONS(3995),
    [anon_sym_from] = ACTIONS(4056),
    [anon_sym_into] = ACTIONS(4056),
    [anon_sym_join] = ACTIONS(4056),
    [anon_sym_on] = ACTIONS(4056),
    [anon_sym_equals] = ACTIONS(4056),
    [anon_sym_let] = ACTIONS(4056),
    [anon_sym_orderby] = ACTIONS(4056),
    [anon_sym_ascending] = ACTIONS(4056),
    [anon_sym_descending] = ACTIONS(4056),
    [anon_sym_group] = ACTIONS(4056),
    [anon_sym_by] = ACTIONS(4056),
    [anon_sym_select] = ACTIONS(4056),
    [anon_sym_as] = ACTIONS(3995),
    [anon_sym_is] = ACTIONS(3995),
    [anon_sym_DASH_GT] = ACTIONS(3993),
    [anon_sym_with] = ACTIONS(3995),
    [aux_sym_preproc_if_token3] = ACTIONS(3993),
    [aux_sym_preproc_else_token1] = ACTIONS(3993),
    [aux_sym_preproc_elif_token1] = ACTIONS(3993),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2735] = {
    [sym__name] = STATE(6202),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_ref_type] = STATE(2883),
    [sym__scoped_base_type] = STATE(2885),
    [sym_identifier] = STATE(5346),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_region] = STATE(2735),
    [sym_preproc_endregion] = STATE(2735),
    [sym_preproc_line] = STATE(2735),
    [sym_preproc_pragma] = STATE(2735),
    [sym_preproc_nullable] = STATE(2735),
    [sym_preproc_error] = STATE(2735),
    [sym_preproc_warning] = STATE(2735),
    [sym_preproc_define] = STATE(2735),
    [sym_preproc_undef] = STATE(2735),
    [sym__identifier_token] = ACTIONS(4061),
    [anon_sym_alias] = ACTIONS(4065),
    [anon_sym_global] = ACTIONS(4065),
    [anon_sym_EQ] = ACTIONS(3995),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_COLON] = ACTIONS(3995),
    [anon_sym_COMMA] = ACTIONS(3993),
    [anon_sym_LPAREN] = ACTIONS(4069),
    [anon_sym_RPAREN] = ACTIONS(3993),
    [anon_sym_ref] = ACTIONS(2669),
    [anon_sym_LBRACE] = ACTIONS(3993),
    [anon_sym_delegate] = ACTIONS(2669),
    [anon_sym_file] = ACTIONS(4065),
    [anon_sym_readonly] = ACTIONS(2669),
    [anon_sym_LT] = ACTIONS(3995),
    [anon_sym_GT] = ACTIONS(3995),
    [anon_sym_in] = ACTIONS(2669),
    [anon_sym_out] = ACTIONS(2669),
    [anon_sym_where] = ACTIONS(4065),
    [anon_sym_QMARK] = ACTIONS(3995),
    [anon_sym_notnull] = ACTIONS(4065),
    [anon_sym_unmanaged] = ACTIONS(4065),
    [anon_sym_BANG] = ACTIONS(3995),
    [anon_sym_PLUS_PLUS] = ACTIONS(3993),
    [anon_sym_DASH_DASH] = ACTIONS(3993),
    [anon_sym_PLUS] = ACTIONS(3995),
    [anon_sym_DASH] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3995),
    [anon_sym_SLASH] = ACTIONS(3995),
    [anon_sym_PERCENT] = ACTIONS(3995),
    [anon_sym_CARET] = ACTIONS(3995),
    [anon_sym_PIPE] = ACTIONS(3995),
    [anon_sym_AMP] = ACTIONS(3995),
    [anon_sym_LT_LT] = ACTIONS(3995),
    [anon_sym_GT_GT] = ACTIONS(3995),
    [anon_sym_GT_GT_GT] = ACTIONS(3995),
    [anon_sym_EQ_EQ] = ACTIONS(3993),
    [anon_sym_BANG_EQ] = ACTIONS(3993),
    [anon_sym_GT_EQ] = ACTIONS(3993),
    [anon_sym_LT_EQ] = ACTIONS(3993),
    [anon_sym_this] = ACTIONS(2669),
    [anon_sym_DOT] = ACTIONS(3995),
    [anon_sym_scoped] = ACTIONS(4065),
    [anon_sym_EQ_GT] = ACTIONS(3993),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(4065),
    [sym_predefined_type] = ACTIONS(2669),
    [anon_sym_yield] = ACTIONS(4065),
    [anon_sym_switch] = ACTIONS(3995),
    [anon_sym_when] = ACTIONS(4065),
    [sym_discard] = ACTIONS(3995),
    [anon_sym_DOT_DOT] = ACTIONS(3993),
    [anon_sym_and] = ACTIONS(3995),
    [anon_sym_or] = ACTIONS(3995),
    [anon_sym_PLUS_EQ] = ACTIONS(3993),
    [anon_sym_DASH_EQ] = ACTIONS(3993),
    [anon_sym_STAR_EQ] = ACTIONS(3993),
    [anon_sym_SLASH_EQ] = ACTIONS(3993),
    [anon_sym_PERCENT_EQ] = ACTIONS(3993),
    [anon_sym_AMP_EQ] = ACTIONS(3993),
    [anon_sym_CARET_EQ] = ACTIONS(3993),
    [anon_sym_PIPE_EQ] = ACTIONS(3993),
    [anon_sym_LT_LT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(3993),
    [anon_sym_AMP_AMP] = ACTIONS(3993),
    [anon_sym_PIPE_PIPE] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK] = ACTIONS(3995),
    [anon_sym_from] = ACTIONS(4065),
    [anon_sym_into] = ACTIONS(4065),
    [anon_sym_join] = ACTIONS(4065),
    [anon_sym_on] = ACTIONS(4065),
    [anon_sym_equals] = ACTIONS(4065),
    [anon_sym_let] = ACTIONS(4065),
    [anon_sym_orderby] = ACTIONS(4065),
    [anon_sym_ascending] = ACTIONS(4065),
    [anon_sym_descending] = ACTIONS(4065),
    [anon_sym_group] = ACTIONS(4065),
    [anon_sym_by] = ACTIONS(4065),
    [anon_sym_select] = ACTIONS(4065),
    [anon_sym_as] = ACTIONS(3995),
    [anon_sym_is] = ACTIONS(3995),
    [anon_sym_DASH_GT] = ACTIONS(3993),
    [anon_sym_with] = ACTIONS(3995),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2736] = {
    [sym__name] = STATE(6202),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_ref_type] = STATE(2883),
    [sym__scoped_base_type] = STATE(2885),
    [sym_identifier] = STATE(5346),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_region] = STATE(2736),
    [sym_preproc_endregion] = STATE(2736),
    [sym_preproc_line] = STATE(2736),
    [sym_preproc_pragma] = STATE(2736),
    [sym_preproc_nullable] = STATE(2736),
    [sym_preproc_error] = STATE(2736),
    [sym_preproc_warning] = STATE(2736),
    [sym_preproc_define] = STATE(2736),
    [sym_preproc_undef] = STATE(2736),
    [sym__identifier_token] = ACTIONS(4072),
    [anon_sym_alias] = ACTIONS(4075),
    [anon_sym_SEMI] = ACTIONS(3993),
    [anon_sym_global] = ACTIONS(4075),
    [anon_sym_EQ] = ACTIONS(3995),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_COLON] = ACTIONS(3995),
    [anon_sym_COMMA] = ACTIONS(3993),
    [anon_sym_RBRACK] = ACTIONS(3993),
    [anon_sym_LPAREN] = ACTIONS(3993),
    [anon_sym_RPAREN] = ACTIONS(3993),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_RBRACE] = ACTIONS(3993),
    [anon_sym_file] = ACTIONS(4075),
    [anon_sym_LT] = ACTIONS(3995),
    [anon_sym_GT] = ACTIONS(3995),
    [anon_sym_in] = ACTIONS(3995),
    [anon_sym_where] = ACTIONS(4075),
    [anon_sym_QMARK] = ACTIONS(3995),
    [anon_sym_notnull] = ACTIONS(4075),
    [anon_sym_unmanaged] = ACTIONS(4075),
    [anon_sym_BANG] = ACTIONS(3995),
    [anon_sym_PLUS_PLUS] = ACTIONS(3993),
    [anon_sym_DASH_DASH] = ACTIONS(3993),
    [anon_sym_PLUS] = ACTIONS(3995),
    [anon_sym_DASH] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3995),
    [anon_sym_SLASH] = ACTIONS(3995),
    [anon_sym_PERCENT] = ACTIONS(3995),
    [anon_sym_CARET] = ACTIONS(3995),
    [anon_sym_PIPE] = ACTIONS(3995),
    [anon_sym_AMP] = ACTIONS(3995),
    [anon_sym_LT_LT] = ACTIONS(3995),
    [anon_sym_GT_GT] = ACTIONS(3995),
    [anon_sym_GT_GT_GT] = ACTIONS(3995),
    [anon_sym_EQ_EQ] = ACTIONS(3993),
    [anon_sym_BANG_EQ] = ACTIONS(3993),
    [anon_sym_GT_EQ] = ACTIONS(3993),
    [anon_sym_LT_EQ] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3995),
    [anon_sym_scoped] = ACTIONS(4075),
    [anon_sym_EQ_GT] = ACTIONS(3993),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(4075),
    [anon_sym_yield] = ACTIONS(4075),
    [anon_sym_switch] = ACTIONS(3995),
    [anon_sym_when] = ACTIONS(4075),
    [anon_sym_DOT_DOT] = ACTIONS(3993),
    [anon_sym_and] = ACTIONS(3995),
    [anon_sym_or] = ACTIONS(3995),
    [anon_sym_PLUS_EQ] = ACTIONS(3993),
    [anon_sym_DASH_EQ] = ACTIONS(3993),
    [anon_sym_STAR_EQ] = ACTIONS(3993),
    [anon_sym_SLASH_EQ] = ACTIONS(3993),
    [anon_sym_PERCENT_EQ] = ACTIONS(3993),
    [anon_sym_AMP_EQ] = ACTIONS(3993),
    [anon_sym_CARET_EQ] = ACTIONS(3993),
    [anon_sym_PIPE_EQ] = ACTIONS(3993),
    [anon_sym_LT_LT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(3993),
    [anon_sym_AMP_AMP] = ACTIONS(3993),
    [anon_sym_PIPE_PIPE] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK] = ACTIONS(3995),
    [anon_sym_from] = ACTIONS(4075),
    [anon_sym_into] = ACTIONS(4075),
    [anon_sym_join] = ACTIONS(4075),
    [anon_sym_on] = ACTIONS(4075),
    [anon_sym_equals] = ACTIONS(4075),
    [anon_sym_let] = ACTIONS(4075),
    [anon_sym_orderby] = ACTIONS(4075),
    [anon_sym_ascending] = ACTIONS(4075),
    [anon_sym_descending] = ACTIONS(4075),
    [anon_sym_group] = ACTIONS(4075),
    [anon_sym_by] = ACTIONS(4075),
    [anon_sym_select] = ACTIONS(4075),
    [anon_sym_as] = ACTIONS(3995),
    [anon_sym_is] = ACTIONS(3995),
    [anon_sym_DASH_GT] = ACTIONS(3993),
    [anon_sym_with] = ACTIONS(3995),
    [aux_sym_preproc_if_token3] = ACTIONS(3993),
    [aux_sym_preproc_else_token1] = ACTIONS(3993),
    [aux_sym_preproc_elif_token1] = ACTIONS(3993),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2737] = {
    [sym__name] = STATE(6202),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_ref_type] = STATE(2883),
    [sym__scoped_base_type] = STATE(2885),
    [sym_identifier] = STATE(5346),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_region] = STATE(2737),
    [sym_preproc_endregion] = STATE(2737),
    [sym_preproc_line] = STATE(2737),
    [sym_preproc_pragma] = STATE(2737),
    [sym_preproc_nullable] = STATE(2737),
    [sym_preproc_error] = STATE(2737),
    [sym_preproc_warning] = STATE(2737),
    [sym_preproc_define] = STATE(2737),
    [sym_preproc_undef] = STATE(2737),
    [sym__identifier_token] = ACTIONS(4072),
    [anon_sym_alias] = ACTIONS(4075),
    [anon_sym_global] = ACTIONS(4075),
    [anon_sym_EQ] = ACTIONS(3995),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_COLON] = ACTIONS(3995),
    [anon_sym_COMMA] = ACTIONS(3993),
    [anon_sym_RBRACK] = ACTIONS(3993),
    [anon_sym_LPAREN] = ACTIONS(3993),
    [anon_sym_RPAREN] = ACTIONS(3993),
    [anon_sym_ref] = ACTIONS(4078),
    [anon_sym_LBRACE] = ACTIONS(3993),
    [anon_sym_RBRACE] = ACTIONS(3993),
    [anon_sym_file] = ACTIONS(4075),
    [anon_sym_LT] = ACTIONS(3995),
    [anon_sym_GT] = ACTIONS(3995),
    [anon_sym_where] = ACTIONS(4075),
    [anon_sym_QMARK] = ACTIONS(3995),
    [anon_sym_notnull] = ACTIONS(4075),
    [anon_sym_unmanaged] = ACTIONS(4075),
    [anon_sym_BANG] = ACTIONS(3995),
    [anon_sym_PLUS_PLUS] = ACTIONS(3993),
    [anon_sym_DASH_DASH] = ACTIONS(3993),
    [anon_sym_PLUS] = ACTIONS(3995),
    [anon_sym_DASH] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3995),
    [anon_sym_SLASH] = ACTIONS(3995),
    [anon_sym_PERCENT] = ACTIONS(3995),
    [anon_sym_CARET] = ACTIONS(3995),
    [anon_sym_PIPE] = ACTIONS(3995),
    [anon_sym_AMP] = ACTIONS(3995),
    [anon_sym_LT_LT] = ACTIONS(3995),
    [anon_sym_GT_GT] = ACTIONS(3995),
    [anon_sym_GT_GT_GT] = ACTIONS(3995),
    [anon_sym_EQ_EQ] = ACTIONS(3993),
    [anon_sym_BANG_EQ] = ACTIONS(3993),
    [anon_sym_GT_EQ] = ACTIONS(3993),
    [anon_sym_LT_EQ] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3995),
    [anon_sym_scoped] = ACTIONS(4075),
    [anon_sym_EQ_GT] = ACTIONS(3993),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(4075),
    [anon_sym_yield] = ACTIONS(4075),
    [anon_sym_switch] = ACTIONS(3995),
    [anon_sym_when] = ACTIONS(4075),
    [sym_discard] = ACTIONS(3995),
    [anon_sym_DOT_DOT] = ACTIONS(3993),
    [anon_sym_and] = ACTIONS(3995),
    [anon_sym_or] = ACTIONS(3995),
    [anon_sym_PLUS_EQ] = ACTIONS(3993),
    [anon_sym_DASH_EQ] = ACTIONS(3993),
    [anon_sym_STAR_EQ] = ACTIONS(3993),
    [anon_sym_SLASH_EQ] = ACTIONS(3993),
    [anon_sym_PERCENT_EQ] = ACTIONS(3993),
    [anon_sym_AMP_EQ] = ACTIONS(3993),
    [anon_sym_CARET_EQ] = ACTIONS(3993),
    [anon_sym_PIPE_EQ] = ACTIONS(3993),
    [anon_sym_LT_LT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(3993),
    [anon_sym_AMP_AMP] = ACTIONS(3993),
    [anon_sym_PIPE_PIPE] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK] = ACTIONS(3995),
    [anon_sym_from] = ACTIONS(4075),
    [anon_sym_into] = ACTIONS(4075),
    [anon_sym_join] = ACTIONS(4075),
    [anon_sym_on] = ACTIONS(4075),
    [anon_sym_equals] = ACTIONS(4075),
    [anon_sym_let] = ACTIONS(4075),
    [anon_sym_orderby] = ACTIONS(4075),
    [anon_sym_ascending] = ACTIONS(4075),
    [anon_sym_descending] = ACTIONS(4075),
    [anon_sym_group] = ACTIONS(4075),
    [anon_sym_by] = ACTIONS(4075),
    [anon_sym_select] = ACTIONS(4075),
    [anon_sym_as] = ACTIONS(3995),
    [anon_sym_is] = ACTIONS(3995),
    [anon_sym_DASH_GT] = ACTIONS(3993),
    [anon_sym_with] = ACTIONS(3995),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2738] = {
    [sym__variable_designation] = STATE(3981),
    [sym_parenthesized_variable_designation] = STATE(3966),
    [sym_identifier] = STATE(3983),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(2738),
    [sym_preproc_endregion] = STATE(2738),
    [sym_preproc_line] = STATE(2738),
    [sym_preproc_pragma] = STATE(2738),
    [sym_preproc_nullable] = STATE(2738),
    [sym_preproc_error] = STATE(2738),
    [sym_preproc_warning] = STATE(2738),
    [sym_preproc_define] = STATE(2738),
    [sym_preproc_undef] = STATE(2738),
    [sym__identifier_token] = ACTIONS(4080),
    [anon_sym_alias] = ACTIONS(4084),
    [anon_sym_SEMI] = ACTIONS(4088),
    [anon_sym_global] = ACTIONS(4084),
    [anon_sym_EQ] = ACTIONS(3995),
    [anon_sym_LBRACK] = ACTIONS(4088),
    [anon_sym_COLON] = ACTIONS(4091),
    [anon_sym_COMMA] = ACTIONS(4088),
    [anon_sym_RBRACK] = ACTIONS(4088),
    [anon_sym_LPAREN] = ACTIONS(4094),
    [anon_sym_RPAREN] = ACTIONS(4088),
    [anon_sym_LBRACE] = ACTIONS(4088),
    [anon_sym_RBRACE] = ACTIONS(4088),
    [anon_sym_file] = ACTIONS(4084),
    [anon_sym_LT] = ACTIONS(4091),
    [anon_sym_GT] = ACTIONS(4091),
    [anon_sym_in] = ACTIONS(4091),
    [anon_sym_where] = ACTIONS(4084),
    [anon_sym_QMARK] = ACTIONS(4091),
    [anon_sym_notnull] = ACTIONS(4084),
    [anon_sym_unmanaged] = ACTIONS(4084),
    [anon_sym_BANG] = ACTIONS(4091),
    [anon_sym_PLUS_PLUS] = ACTIONS(4088),
    [anon_sym_DASH_DASH] = ACTIONS(4088),
    [anon_sym_PLUS] = ACTIONS(4091),
    [anon_sym_DASH] = ACTIONS(4091),
    [anon_sym_STAR] = ACTIONS(4091),
    [anon_sym_SLASH] = ACTIONS(4091),
    [anon_sym_PERCENT] = ACTIONS(4091),
    [anon_sym_CARET] = ACTIONS(4091),
    [anon_sym_PIPE] = ACTIONS(4091),
    [anon_sym_AMP] = ACTIONS(4091),
    [anon_sym_LT_LT] = ACTIONS(4091),
    [anon_sym_GT_GT] = ACTIONS(4091),
    [anon_sym_GT_GT_GT] = ACTIONS(4091),
    [anon_sym_EQ_EQ] = ACTIONS(4088),
    [anon_sym_BANG_EQ] = ACTIONS(4088),
    [anon_sym_GT_EQ] = ACTIONS(4088),
    [anon_sym_LT_EQ] = ACTIONS(4088),
    [anon_sym_DOT] = ACTIONS(4091),
    [anon_sym_scoped] = ACTIONS(4084),
    [anon_sym_EQ_GT] = ACTIONS(3993),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(4084),
    [anon_sym_yield] = ACTIONS(4084),
    [anon_sym_switch] = ACTIONS(4091),
    [anon_sym_when] = ACTIONS(4084),
    [sym_discard] = ACTIONS(4098),
    [anon_sym_DOT_DOT] = ACTIONS(4088),
    [anon_sym_and] = ACTIONS(4091),
    [anon_sym_or] = ACTIONS(4091),
    [anon_sym_PLUS_EQ] = ACTIONS(3993),
    [anon_sym_DASH_EQ] = ACTIONS(3993),
    [anon_sym_STAR_EQ] = ACTIONS(3993),
    [anon_sym_SLASH_EQ] = ACTIONS(3993),
    [anon_sym_PERCENT_EQ] = ACTIONS(3993),
    [anon_sym_AMP_EQ] = ACTIONS(3993),
    [anon_sym_CARET_EQ] = ACTIONS(3993),
    [anon_sym_PIPE_EQ] = ACTIONS(3993),
    [anon_sym_LT_LT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(3993),
    [anon_sym_AMP_AMP] = ACTIONS(4088),
    [anon_sym_PIPE_PIPE] = ACTIONS(4088),
    [anon_sym_QMARK_QMARK] = ACTIONS(4091),
    [anon_sym_from] = ACTIONS(4084),
    [anon_sym_into] = ACTIONS(4084),
    [anon_sym_join] = ACTIONS(4084),
    [anon_sym_on] = ACTIONS(4084),
    [anon_sym_equals] = ACTIONS(4084),
    [anon_sym_let] = ACTIONS(4084),
    [anon_sym_orderby] = ACTIONS(4084),
    [anon_sym_ascending] = ACTIONS(4084),
    [anon_sym_descending] = ACTIONS(4084),
    [anon_sym_group] = ACTIONS(4084),
    [anon_sym_by] = ACTIONS(4084),
    [anon_sym_select] = ACTIONS(4084),
    [anon_sym_as] = ACTIONS(4091),
    [anon_sym_is] = ACTIONS(4091),
    [anon_sym_DASH_GT] = ACTIONS(4088),
    [anon_sym_with] = ACTIONS(4091),
    [aux_sym_preproc_if_token3] = ACTIONS(4088),
    [aux_sym_preproc_else_token1] = ACTIONS(4088),
    [aux_sym_preproc_elif_token1] = ACTIONS(4088),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2739] = {
    [sym__name] = STATE(3199),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2956),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2944),
    [sym_ref_type] = STATE(2883),
    [sym__scoped_base_type] = STATE(2885),
    [sym_identifier] = STATE(3123),
    [sym__reserved_identifier] = STATE(2928),
    [sym_preproc_region] = STATE(2739),
    [sym_preproc_endregion] = STATE(2739),
    [sym_preproc_line] = STATE(2739),
    [sym_preproc_pragma] = STATE(2739),
    [sym_preproc_nullable] = STATE(2739),
    [sym_preproc_error] = STATE(2739),
    [sym_preproc_warning] = STATE(2739),
    [sym_preproc_define] = STATE(2739),
    [sym_preproc_undef] = STATE(2739),
    [sym__identifier_token] = ACTIONS(4053),
    [anon_sym_alias] = ACTIONS(4056),
    [anon_sym_global] = ACTIONS(4056),
    [anon_sym_EQ] = ACTIONS(3995),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_COLON] = ACTIONS(3995),
    [anon_sym_COMMA] = ACTIONS(3993),
    [anon_sym_LPAREN] = ACTIONS(3993),
    [anon_sym_RPAREN] = ACTIONS(3993),
    [anon_sym_ref] = ACTIONS(4102),
    [anon_sym_LBRACE] = ACTIONS(3993),
    [anon_sym_RBRACE] = ACTIONS(3993),
    [anon_sym_file] = ACTIONS(4056),
    [anon_sym_LT] = ACTIONS(3995),
    [anon_sym_GT] = ACTIONS(3995),
    [anon_sym_where] = ACTIONS(4056),
    [anon_sym_QMARK] = ACTIONS(3995),
    [anon_sym_notnull] = ACTIONS(4056),
    [anon_sym_unmanaged] = ACTIONS(4056),
    [anon_sym_BANG] = ACTIONS(3995),
    [anon_sym_PLUS_PLUS] = ACTIONS(3993),
    [anon_sym_DASH_DASH] = ACTIONS(3993),
    [anon_sym_PLUS] = ACTIONS(3995),
    [anon_sym_DASH] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3995),
    [anon_sym_SLASH] = ACTIONS(3995),
    [anon_sym_PERCENT] = ACTIONS(3995),
    [anon_sym_CARET] = ACTIONS(3995),
    [anon_sym_PIPE] = ACTIONS(3995),
    [anon_sym_AMP] = ACTIONS(3995),
    [anon_sym_LT_LT] = ACTIONS(3995),
    [anon_sym_GT_GT] = ACTIONS(3995),
    [anon_sym_GT_GT_GT] = ACTIONS(3995),
    [anon_sym_EQ_EQ] = ACTIONS(3993),
    [anon_sym_BANG_EQ] = ACTIONS(3993),
    [anon_sym_GT_EQ] = ACTIONS(3993),
    [anon_sym_LT_EQ] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3995),
    [anon_sym_scoped] = ACTIONS(4056),
    [anon_sym_EQ_GT] = ACTIONS(3993),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(4056),
    [anon_sym_yield] = ACTIONS(4056),
    [anon_sym_switch] = ACTIONS(3995),
    [anon_sym_when] = ACTIONS(4056),
    [sym_discard] = ACTIONS(3995),
    [anon_sym_DOT_DOT] = ACTIONS(3993),
    [anon_sym_and] = ACTIONS(3995),
    [anon_sym_or] = ACTIONS(3995),
    [anon_sym_PLUS_EQ] = ACTIONS(3993),
    [anon_sym_DASH_EQ] = ACTIONS(3993),
    [anon_sym_STAR_EQ] = ACTIONS(3993),
    [anon_sym_SLASH_EQ] = ACTIONS(3993),
    [anon_sym_PERCENT_EQ] = ACTIONS(3993),
    [anon_sym_AMP_EQ] = ACTIONS(3993),
    [anon_sym_CARET_EQ] = ACTIONS(3993),
    [anon_sym_PIPE_EQ] = ACTIONS(3993),
    [anon_sym_LT_LT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(3993),
    [anon_sym_AMP_AMP] = ACTIONS(3993),
    [anon_sym_PIPE_PIPE] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK] = ACTIONS(3995),
    [anon_sym_from] = ACTIONS(4056),
    [anon_sym_into] = ACTIONS(4056),
    [anon_sym_join] = ACTIONS(4056),
    [anon_sym_on] = ACTIONS(4056),
    [anon_sym_equals] = ACTIONS(4056),
    [anon_sym_let] = ACTIONS(4056),
    [anon_sym_orderby] = ACTIONS(4056),
    [anon_sym_ascending] = ACTIONS(4056),
    [anon_sym_descending] = ACTIONS(4056),
    [anon_sym_group] = ACTIONS(4056),
    [anon_sym_by] = ACTIONS(4056),
    [anon_sym_select] = ACTIONS(4056),
    [anon_sym_as] = ACTIONS(3995),
    [anon_sym_is] = ACTIONS(3995),
    [anon_sym_DASH_GT] = ACTIONS(3993),
    [anon_sym_with] = ACTIONS(3995),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2740] = {
    [sym__name] = STATE(3365),
    [sym_alias_qualified_name] = STATE(3486),
    [sym__simple_name] = STATE(3486),
    [sym_qualified_name] = STATE(3486),
    [sym_generic_name] = STATE(3326),
    [sym_ref_type] = STATE(3368),
    [sym__scoped_base_type] = STATE(3369),
    [sym_identifier] = STATE(3158),
    [sym__reserved_identifier] = STATE(3178),
    [sym_preproc_region] = STATE(2740),
    [sym_preproc_endregion] = STATE(2740),
    [sym_preproc_line] = STATE(2740),
    [sym_preproc_pragma] = STATE(2740),
    [sym_preproc_nullable] = STATE(2740),
    [sym_preproc_error] = STATE(2740),
    [sym_preproc_warning] = STATE(2740),
    [sym_preproc_define] = STATE(2740),
    [sym_preproc_undef] = STATE(2740),
    [sym__identifier_token] = ACTIONS(4104),
    [anon_sym_alias] = ACTIONS(4107),
    [anon_sym_global] = ACTIONS(4107),
    [anon_sym_EQ] = ACTIONS(3995),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_COLON] = ACTIONS(3995),
    [anon_sym_COMMA] = ACTIONS(3993),
    [anon_sym_LPAREN] = ACTIONS(3993),
    [anon_sym_ref] = ACTIONS(4110),
    [anon_sym_LBRACE] = ACTIONS(3993),
    [anon_sym_file] = ACTIONS(4107),
    [anon_sym_LT] = ACTIONS(3995),
    [anon_sym_GT] = ACTIONS(3995),
    [anon_sym_where] = ACTIONS(4107),
    [anon_sym_QMARK] = ACTIONS(3995),
    [anon_sym_notnull] = ACTIONS(4107),
    [anon_sym_unmanaged] = ACTIONS(4107),
    [anon_sym_BANG] = ACTIONS(3995),
    [anon_sym_PLUS_PLUS] = ACTIONS(3993),
    [anon_sym_DASH_DASH] = ACTIONS(3993),
    [anon_sym_PLUS] = ACTIONS(3995),
    [anon_sym_DASH] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3995),
    [anon_sym_SLASH] = ACTIONS(3995),
    [anon_sym_PERCENT] = ACTIONS(3995),
    [anon_sym_CARET] = ACTIONS(3995),
    [anon_sym_PIPE] = ACTIONS(3995),
    [anon_sym_AMP] = ACTIONS(3995),
    [anon_sym_LT_LT] = ACTIONS(3995),
    [anon_sym_GT_GT] = ACTIONS(3995),
    [anon_sym_GT_GT_GT] = ACTIONS(3995),
    [anon_sym_EQ_EQ] = ACTIONS(3993),
    [anon_sym_BANG_EQ] = ACTIONS(3993),
    [anon_sym_GT_EQ] = ACTIONS(3993),
    [anon_sym_LT_EQ] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3995),
    [anon_sym_scoped] = ACTIONS(4107),
    [anon_sym_EQ_GT] = ACTIONS(3993),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(4107),
    [anon_sym_yield] = ACTIONS(4107),
    [anon_sym_switch] = ACTIONS(3995),
    [anon_sym_when] = ACTIONS(4107),
    [sym_discard] = ACTIONS(3995),
    [anon_sym_DOT_DOT] = ACTIONS(3993),
    [anon_sym_and] = ACTIONS(3995),
    [anon_sym_or] = ACTIONS(3995),
    [anon_sym_PLUS_EQ] = ACTIONS(3993),
    [anon_sym_DASH_EQ] = ACTIONS(3993),
    [anon_sym_STAR_EQ] = ACTIONS(3993),
    [anon_sym_SLASH_EQ] = ACTIONS(3993),
    [anon_sym_PERCENT_EQ] = ACTIONS(3993),
    [anon_sym_AMP_EQ] = ACTIONS(3993),
    [anon_sym_CARET_EQ] = ACTIONS(3993),
    [anon_sym_PIPE_EQ] = ACTIONS(3993),
    [anon_sym_LT_LT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(3993),
    [anon_sym_AMP_AMP] = ACTIONS(3993),
    [anon_sym_PIPE_PIPE] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK] = ACTIONS(3995),
    [anon_sym_from] = ACTIONS(4107),
    [anon_sym_into] = ACTIONS(4107),
    [anon_sym_join] = ACTIONS(4107),
    [anon_sym_on] = ACTIONS(4107),
    [anon_sym_equals] = ACTIONS(4107),
    [anon_sym_let] = ACTIONS(4107),
    [anon_sym_orderby] = ACTIONS(4107),
    [anon_sym_ascending] = ACTIONS(4107),
    [anon_sym_descending] = ACTIONS(4107),
    [anon_sym_group] = ACTIONS(4107),
    [anon_sym_by] = ACTIONS(4107),
    [anon_sym_select] = ACTIONS(4107),
    [anon_sym_as] = ACTIONS(3995),
    [anon_sym_is] = ACTIONS(3995),
    [anon_sym_DASH_GT] = ACTIONS(3993),
    [anon_sym_with] = ACTIONS(3995),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(3993),
  },
  [2741] = {
    [sym__name] = STATE(6202),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_ref_type] = STATE(2883),
    [sym__scoped_base_type] = STATE(2885),
    [sym_identifier] = STATE(5346),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_region] = STATE(2741),
    [sym_preproc_endregion] = STATE(2741),
    [sym_preproc_line] = STATE(2741),
    [sym_preproc_pragma] = STATE(2741),
    [sym_preproc_nullable] = STATE(2741),
    [sym_preproc_error] = STATE(2741),
    [sym_preproc_warning] = STATE(2741),
    [sym_preproc_define] = STATE(2741),
    [sym_preproc_undef] = STATE(2741),
    [sym__identifier_token] = ACTIONS(4072),
    [anon_sym_alias] = ACTIONS(4075),
    [anon_sym_global] = ACTIONS(4075),
    [anon_sym_EQ] = ACTIONS(3995),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_COLON] = ACTIONS(3995),
    [anon_sym_COMMA] = ACTIONS(3993),
    [anon_sym_LPAREN] = ACTIONS(3993),
    [anon_sym_RPAREN] = ACTIONS(3993),
    [anon_sym_ref] = ACTIONS(4112),
    [anon_sym_LBRACE] = ACTIONS(3993),
    [anon_sym_file] = ACTIONS(4075),
    [anon_sym_LT] = ACTIONS(3995),
    [anon_sym_GT] = ACTIONS(3995),
    [anon_sym_where] = ACTIONS(4075),
    [anon_sym_QMARK] = ACTIONS(3995),
    [anon_sym_notnull] = ACTIONS(4075),
    [anon_sym_unmanaged] = ACTIONS(4075),
    [anon_sym_BANG] = ACTIONS(3995),
    [anon_sym_PLUS_PLUS] = ACTIONS(3993),
    [anon_sym_DASH_DASH] = ACTIONS(3993),
    [anon_sym_PLUS] = ACTIONS(3995),
    [anon_sym_DASH] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3995),
    [anon_sym_SLASH] = ACTIONS(3995),
    [anon_sym_PERCENT] = ACTIONS(3995),
    [anon_sym_CARET] = ACTIONS(3995),
    [anon_sym_PIPE] = ACTIONS(3995),
    [anon_sym_AMP] = ACTIONS(3995),
    [anon_sym_LT_LT] = ACTIONS(3995),
    [anon_sym_GT_GT] = ACTIONS(3995),
    [anon_sym_GT_GT_GT] = ACTIONS(3995),
    [anon_sym_EQ_EQ] = ACTIONS(3993),
    [anon_sym_BANG_EQ] = ACTIONS(3993),
    [anon_sym_GT_EQ] = ACTIONS(3993),
    [anon_sym_LT_EQ] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3995),
    [anon_sym_scoped] = ACTIONS(4075),
    [anon_sym_EQ_GT] = ACTIONS(3993),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(4075),
    [anon_sym_yield] = ACTIONS(4075),
    [anon_sym_switch] = ACTIONS(3995),
    [anon_sym_when] = ACTIONS(4075),
    [sym_discard] = ACTIONS(3995),
    [anon_sym_DOT_DOT] = ACTIONS(3993),
    [anon_sym_and] = ACTIONS(3995),
    [anon_sym_or] = ACTIONS(3995),
    [anon_sym_PLUS_EQ] = ACTIONS(3993),
    [anon_sym_DASH_EQ] = ACTIONS(3993),
    [anon_sym_STAR_EQ] = ACTIONS(3993),
    [anon_sym_SLASH_EQ] = ACTIONS(3993),
    [anon_sym_PERCENT_EQ] = ACTIONS(3993),
    [anon_sym_AMP_EQ] = ACTIONS(3993),
    [anon_sym_CARET_EQ] = ACTIONS(3993),
    [anon_sym_PIPE_EQ] = ACTIONS(3993),
    [anon_sym_LT_LT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(3993),
    [anon_sym_AMP_AMP] = ACTIONS(3993),
    [anon_sym_PIPE_PIPE] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK] = ACTIONS(3995),
    [anon_sym_from] = ACTIONS(4075),
    [anon_sym_into] = ACTIONS(4075),
    [anon_sym_join] = ACTIONS(4075),
    [anon_sym_on] = ACTIONS(4075),
    [anon_sym_equals] = ACTIONS(4075),
    [anon_sym_let] = ACTIONS(4075),
    [anon_sym_orderby] = ACTIONS(4075),
    [anon_sym_ascending] = ACTIONS(4075),
    [anon_sym_descending] = ACTIONS(4075),
    [anon_sym_group] = ACTIONS(4075),
    [anon_sym_by] = ACTIONS(4075),
    [anon_sym_select] = ACTIONS(4075),
    [anon_sym_as] = ACTIONS(3995),
    [anon_sym_is] = ACTIONS(3995),
    [anon_sym_DASH_GT] = ACTIONS(3993),
    [anon_sym_with] = ACTIONS(3995),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2742] = {
    [sym__variable_designation] = STATE(4155),
    [sym_parenthesized_variable_designation] = STATE(4153),
    [sym_identifier] = STATE(4156),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(2742),
    [sym_preproc_endregion] = STATE(2742),
    [sym_preproc_line] = STATE(2742),
    [sym_preproc_pragma] = STATE(2742),
    [sym_preproc_nullable] = STATE(2742),
    [sym_preproc_error] = STATE(2742),
    [sym_preproc_warning] = STATE(2742),
    [sym_preproc_define] = STATE(2742),
    [sym_preproc_undef] = STATE(2742),
    [sym__identifier_token] = ACTIONS(4080),
    [anon_sym_alias] = ACTIONS(4084),
    [anon_sym_SEMI] = ACTIONS(4088),
    [anon_sym_global] = ACTIONS(4084),
    [anon_sym_EQ] = ACTIONS(3995),
    [anon_sym_LBRACK] = ACTIONS(4088),
    [anon_sym_COLON] = ACTIONS(4091),
    [anon_sym_COMMA] = ACTIONS(4088),
    [anon_sym_RBRACK] = ACTIONS(4088),
    [anon_sym_LPAREN] = ACTIONS(4114),
    [anon_sym_RPAREN] = ACTIONS(4088),
    [anon_sym_LBRACE] = ACTIONS(4088),
    [anon_sym_RBRACE] = ACTIONS(4088),
    [anon_sym_file] = ACTIONS(4084),
    [anon_sym_LT] = ACTIONS(4091),
    [anon_sym_GT] = ACTIONS(4091),
    [anon_sym_where] = ACTIONS(4084),
    [anon_sym_QMARK] = ACTIONS(4091),
    [anon_sym_notnull] = ACTIONS(4084),
    [anon_sym_unmanaged] = ACTIONS(4084),
    [anon_sym_BANG] = ACTIONS(4091),
    [anon_sym_PLUS_PLUS] = ACTIONS(4088),
    [anon_sym_DASH_DASH] = ACTIONS(4088),
    [anon_sym_PLUS] = ACTIONS(4091),
    [anon_sym_DASH] = ACTIONS(4091),
    [anon_sym_STAR] = ACTIONS(4091),
    [anon_sym_SLASH] = ACTIONS(4091),
    [anon_sym_PERCENT] = ACTIONS(4091),
    [anon_sym_CARET] = ACTIONS(4091),
    [anon_sym_PIPE] = ACTIONS(4091),
    [anon_sym_AMP] = ACTIONS(4091),
    [anon_sym_LT_LT] = ACTIONS(4091),
    [anon_sym_GT_GT] = ACTIONS(4091),
    [anon_sym_GT_GT_GT] = ACTIONS(4091),
    [anon_sym_EQ_EQ] = ACTIONS(4088),
    [anon_sym_BANG_EQ] = ACTIONS(4088),
    [anon_sym_GT_EQ] = ACTIONS(4088),
    [anon_sym_LT_EQ] = ACTIONS(4088),
    [anon_sym_DOT] = ACTIONS(4091),
    [anon_sym_scoped] = ACTIONS(4084),
    [anon_sym_EQ_GT] = ACTIONS(3993),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(4084),
    [anon_sym_yield] = ACTIONS(4084),
    [anon_sym_switch] = ACTIONS(4091),
    [anon_sym_when] = ACTIONS(4084),
    [sym_discard] = ACTIONS(4118),
    [anon_sym_DOT_DOT] = ACTIONS(4088),
    [anon_sym_and] = ACTIONS(4091),
    [anon_sym_or] = ACTIONS(4091),
    [anon_sym_PLUS_EQ] = ACTIONS(3993),
    [anon_sym_DASH_EQ] = ACTIONS(3993),
    [anon_sym_STAR_EQ] = ACTIONS(3993),
    [anon_sym_SLASH_EQ] = ACTIONS(3993),
    [anon_sym_PERCENT_EQ] = ACTIONS(3993),
    [anon_sym_AMP_EQ] = ACTIONS(3993),
    [anon_sym_CARET_EQ] = ACTIONS(3993),
    [anon_sym_PIPE_EQ] = ACTIONS(3993),
    [anon_sym_LT_LT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(3993),
    [anon_sym_AMP_AMP] = ACTIONS(4088),
    [anon_sym_PIPE_PIPE] = ACTIONS(4088),
    [anon_sym_QMARK_QMARK] = ACTIONS(4091),
    [anon_sym_from] = ACTIONS(4084),
    [anon_sym_into] = ACTIONS(4084),
    [anon_sym_join] = ACTIONS(4084),
    [anon_sym_on] = ACTIONS(4084),
    [anon_sym_equals] = ACTIONS(4084),
    [anon_sym_let] = ACTIONS(4084),
    [anon_sym_orderby] = ACTIONS(4084),
    [anon_sym_ascending] = ACTIONS(4084),
    [anon_sym_descending] = ACTIONS(4084),
    [anon_sym_group] = ACTIONS(4084),
    [anon_sym_by] = ACTIONS(4084),
    [anon_sym_select] = ACTIONS(4084),
    [anon_sym_as] = ACTIONS(4091),
    [anon_sym_is] = ACTIONS(4091),
    [anon_sym_DASH_GT] = ACTIONS(4088),
    [anon_sym_with] = ACTIONS(4091),
    [aux_sym_preproc_if_token3] = ACTIONS(4088),
    [aux_sym_preproc_else_token1] = ACTIONS(4088),
    [aux_sym_preproc_elif_token1] = ACTIONS(4088),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2743] = {
    [sym_preproc_region] = STATE(2743),
    [sym_preproc_endregion] = STATE(2743),
    [sym_preproc_line] = STATE(2743),
    [sym_preproc_pragma] = STATE(2743),
    [sym_preproc_nullable] = STATE(2743),
    [sym_preproc_error] = STATE(2743),
    [sym_preproc_warning] = STATE(2743),
    [sym_preproc_define] = STATE(2743),
    [sym_preproc_undef] = STATE(2743),
    [sym__identifier_token] = ACTIONS(3995),
    [anon_sym_alias] = ACTIONS(3995),
    [anon_sym_SEMI] = ACTIONS(3993),
    [anon_sym_global] = ACTIONS(3995),
    [anon_sym_EQ] = ACTIONS(3995),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_COLON] = ACTIONS(3995),
    [anon_sym_COMMA] = ACTIONS(3993),
    [anon_sym_RBRACK] = ACTIONS(3993),
    [anon_sym_LPAREN] = ACTIONS(3993),
    [anon_sym_RPAREN] = ACTIONS(3993),
    [anon_sym_LBRACE] = ACTIONS(3993),
    [anon_sym_RBRACE] = ACTIONS(3993),
    [anon_sym_file] = ACTIONS(3995),
    [anon_sym_LT] = ACTIONS(3995),
    [anon_sym_GT] = ACTIONS(3995),
    [anon_sym_in] = ACTIONS(3995),
    [anon_sym_where] = ACTIONS(3995),
    [anon_sym_QMARK] = ACTIONS(3995),
    [anon_sym_notnull] = ACTIONS(3995),
    [anon_sym_unmanaged] = ACTIONS(3995),
    [anon_sym_operator] = ACTIONS(3995),
    [anon_sym_BANG] = ACTIONS(3995),
    [anon_sym_PLUS_PLUS] = ACTIONS(3993),
    [anon_sym_DASH_DASH] = ACTIONS(3993),
    [anon_sym_PLUS] = ACTIONS(3995),
    [anon_sym_DASH] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3995),
    [anon_sym_SLASH] = ACTIONS(3995),
    [anon_sym_PERCENT] = ACTIONS(3995),
    [anon_sym_CARET] = ACTIONS(3995),
    [anon_sym_PIPE] = ACTIONS(3995),
    [anon_sym_AMP] = ACTIONS(3995),
    [anon_sym_LT_LT] = ACTIONS(3995),
    [anon_sym_GT_GT] = ACTIONS(3995),
    [anon_sym_GT_GT_GT] = ACTIONS(3995),
    [anon_sym_EQ_EQ] = ACTIONS(3993),
    [anon_sym_BANG_EQ] = ACTIONS(3993),
    [anon_sym_GT_EQ] = ACTIONS(3993),
    [anon_sym_LT_EQ] = ACTIONS(3993),
    [anon_sym_this] = ACTIONS(3995),
    [anon_sym_DOT] = ACTIONS(3995),
    [anon_sym_scoped] = ACTIONS(3995),
    [anon_sym_EQ_GT] = ACTIONS(3993),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(3995),
    [anon_sym_yield] = ACTIONS(3995),
    [anon_sym_switch] = ACTIONS(3995),
    [anon_sym_when] = ACTIONS(3995),
    [sym_discard] = ACTIONS(3995),
    [anon_sym_DOT_DOT] = ACTIONS(3993),
    [anon_sym_and] = ACTIONS(3995),
    [anon_sym_or] = ACTIONS(3995),
    [anon_sym_PLUS_EQ] = ACTIONS(3993),
    [anon_sym_DASH_EQ] = ACTIONS(3993),
    [anon_sym_STAR_EQ] = ACTIONS(3993),
    [anon_sym_SLASH_EQ] = ACTIONS(3993),
    [anon_sym_PERCENT_EQ] = ACTIONS(3993),
    [anon_sym_AMP_EQ] = ACTIONS(3993),
    [anon_sym_CARET_EQ] = ACTIONS(3993),
    [anon_sym_PIPE_EQ] = ACTIONS(3993),
    [anon_sym_LT_LT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(3993),
    [anon_sym_AMP_AMP] = ACTIONS(3993),
    [anon_sym_PIPE_PIPE] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK] = ACTIONS(3995),
    [anon_sym_from] = ACTIONS(3995),
    [anon_sym_into] = ACTIONS(3995),
    [anon_sym_join] = ACTIONS(3995),
    [anon_sym_on] = ACTIONS(3995),
    [anon_sym_equals] = ACTIONS(3995),
    [anon_sym_let] = ACTIONS(3995),
    [anon_sym_orderby] = ACTIONS(3995),
    [anon_sym_ascending] = ACTIONS(3995),
    [anon_sym_descending] = ACTIONS(3995),
    [anon_sym_group] = ACTIONS(3995),
    [anon_sym_by] = ACTIONS(3995),
    [anon_sym_select] = ACTIONS(3995),
    [anon_sym_as] = ACTIONS(3995),
    [anon_sym_is] = ACTIONS(3995),
    [anon_sym_DASH_GT] = ACTIONS(3993),
    [anon_sym_with] = ACTIONS(3995),
    [aux_sym_preproc_if_token3] = ACTIONS(3993),
    [aux_sym_preproc_else_token1] = ACTIONS(3993),
    [aux_sym_preproc_elif_token1] = ACTIONS(3993),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2744] = {
    [sym_preproc_region] = STATE(2744),
    [sym_preproc_endregion] = STATE(2744),
    [sym_preproc_line] = STATE(2744),
    [sym_preproc_pragma] = STATE(2744),
    [sym_preproc_nullable] = STATE(2744),
    [sym_preproc_error] = STATE(2744),
    [sym_preproc_warning] = STATE(2744),
    [sym_preproc_define] = STATE(2744),
    [sym_preproc_undef] = STATE(2744),
    [sym__identifier_token] = ACTIONS(4122),
    [anon_sym_alias] = ACTIONS(4122),
    [anon_sym_SEMI] = ACTIONS(4124),
    [anon_sym_global] = ACTIONS(4122),
    [anon_sym_EQ] = ACTIONS(4122),
    [anon_sym_LBRACK] = ACTIONS(4124),
    [anon_sym_COLON] = ACTIONS(4122),
    [anon_sym_COMMA] = ACTIONS(4124),
    [anon_sym_RBRACK] = ACTIONS(4124),
    [anon_sym_LPAREN] = ACTIONS(4124),
    [anon_sym_RPAREN] = ACTIONS(4124),
    [anon_sym_LBRACE] = ACTIONS(4124),
    [anon_sym_RBRACE] = ACTIONS(4124),
    [anon_sym_file] = ACTIONS(4122),
    [anon_sym_LT] = ACTIONS(4122),
    [anon_sym_GT] = ACTIONS(4122),
    [anon_sym_in] = ACTIONS(4122),
    [anon_sym_where] = ACTIONS(4122),
    [anon_sym_QMARK] = ACTIONS(4122),
    [anon_sym_notnull] = ACTIONS(4122),
    [anon_sym_unmanaged] = ACTIONS(4122),
    [anon_sym_operator] = ACTIONS(4122),
    [anon_sym_BANG] = ACTIONS(4122),
    [anon_sym_PLUS_PLUS] = ACTIONS(4124),
    [anon_sym_DASH_DASH] = ACTIONS(4124),
    [anon_sym_PLUS] = ACTIONS(4122),
    [anon_sym_DASH] = ACTIONS(4122),
    [anon_sym_STAR] = ACTIONS(4122),
    [anon_sym_SLASH] = ACTIONS(4122),
    [anon_sym_PERCENT] = ACTIONS(4122),
    [anon_sym_CARET] = ACTIONS(4122),
    [anon_sym_PIPE] = ACTIONS(4122),
    [anon_sym_AMP] = ACTIONS(4122),
    [anon_sym_LT_LT] = ACTIONS(4122),
    [anon_sym_GT_GT] = ACTIONS(4122),
    [anon_sym_GT_GT_GT] = ACTIONS(4122),
    [anon_sym_EQ_EQ] = ACTIONS(4124),
    [anon_sym_BANG_EQ] = ACTIONS(4124),
    [anon_sym_GT_EQ] = ACTIONS(4124),
    [anon_sym_LT_EQ] = ACTIONS(4124),
    [anon_sym_this] = ACTIONS(4122),
    [anon_sym_DOT] = ACTIONS(4122),
    [anon_sym_scoped] = ACTIONS(4122),
    [anon_sym_EQ_GT] = ACTIONS(4124),
    [anon_sym_COLON_COLON] = ACTIONS(4124),
    [anon_sym_var] = ACTIONS(4122),
    [anon_sym_yield] = ACTIONS(4122),
    [anon_sym_switch] = ACTIONS(4122),
    [anon_sym_when] = ACTIONS(4122),
    [sym_discard] = ACTIONS(4122),
    [anon_sym_DOT_DOT] = ACTIONS(4124),
    [anon_sym_and] = ACTIONS(4122),
    [anon_sym_or] = ACTIONS(4122),
    [anon_sym_PLUS_EQ] = ACTIONS(4124),
    [anon_sym_DASH_EQ] = ACTIONS(4124),
    [anon_sym_STAR_EQ] = ACTIONS(4124),
    [anon_sym_SLASH_EQ] = ACTIONS(4124),
    [anon_sym_PERCENT_EQ] = ACTIONS(4124),
    [anon_sym_AMP_EQ] = ACTIONS(4124),
    [anon_sym_CARET_EQ] = ACTIONS(4124),
    [anon_sym_PIPE_EQ] = ACTIONS(4124),
    [anon_sym_LT_LT_EQ] = ACTIONS(4124),
    [anon_sym_GT_GT_EQ] = ACTIONS(4124),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4124),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4124),
    [anon_sym_AMP_AMP] = ACTIONS(4124),
    [anon_sym_PIPE_PIPE] = ACTIONS(4124),
    [anon_sym_QMARK_QMARK] = ACTIONS(4122),
    [anon_sym_from] = ACTIONS(4122),
    [anon_sym_into] = ACTIONS(4122),
    [anon_sym_join] = ACTIONS(4122),
    [anon_sym_on] = ACTIONS(4122),
    [anon_sym_equals] = ACTIONS(4122),
    [anon_sym_let] = ACTIONS(4122),
    [anon_sym_orderby] = ACTIONS(4122),
    [anon_sym_ascending] = ACTIONS(4122),
    [anon_sym_descending] = ACTIONS(4122),
    [anon_sym_group] = ACTIONS(4122),
    [anon_sym_by] = ACTIONS(4122),
    [anon_sym_select] = ACTIONS(4122),
    [anon_sym_as] = ACTIONS(4122),
    [anon_sym_is] = ACTIONS(4122),
    [anon_sym_DASH_GT] = ACTIONS(4124),
    [anon_sym_with] = ACTIONS(4122),
    [aux_sym_preproc_if_token3] = ACTIONS(4124),
    [aux_sym_preproc_else_token1] = ACTIONS(4124),
    [aux_sym_preproc_elif_token1] = ACTIONS(4124),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2745] = {
    [sym_preproc_region] = STATE(2745),
    [sym_preproc_endregion] = STATE(2745),
    [sym_preproc_line] = STATE(2745),
    [sym_preproc_pragma] = STATE(2745),
    [sym_preproc_nullable] = STATE(2745),
    [sym_preproc_error] = STATE(2745),
    [sym_preproc_warning] = STATE(2745),
    [sym_preproc_define] = STATE(2745),
    [sym_preproc_undef] = STATE(2745),
    [sym__identifier_token] = ACTIONS(4126),
    [anon_sym_alias] = ACTIONS(4126),
    [anon_sym_SEMI] = ACTIONS(4128),
    [anon_sym_global] = ACTIONS(4126),
    [anon_sym_EQ] = ACTIONS(4126),
    [anon_sym_LBRACK] = ACTIONS(4128),
    [anon_sym_COLON] = ACTIONS(4128),
    [anon_sym_COMMA] = ACTIONS(4128),
    [anon_sym_RBRACK] = ACTIONS(4128),
    [anon_sym_LPAREN] = ACTIONS(4128),
    [anon_sym_RPAREN] = ACTIONS(4128),
    [anon_sym_LBRACE] = ACTIONS(4128),
    [anon_sym_RBRACE] = ACTIONS(4128),
    [anon_sym_file] = ACTIONS(4126),
    [anon_sym_LT] = ACTIONS(4126),
    [anon_sym_GT] = ACTIONS(4126),
    [anon_sym_in] = ACTIONS(4126),
    [anon_sym_where] = ACTIONS(4126),
    [anon_sym_QMARK] = ACTIONS(4126),
    [anon_sym_notnull] = ACTIONS(4126),
    [anon_sym_unmanaged] = ACTIONS(4126),
    [anon_sym_operator] = ACTIONS(4126),
    [anon_sym_BANG] = ACTIONS(4126),
    [anon_sym_PLUS_PLUS] = ACTIONS(4128),
    [anon_sym_DASH_DASH] = ACTIONS(4128),
    [anon_sym_PLUS] = ACTIONS(4126),
    [anon_sym_DASH] = ACTIONS(4126),
    [anon_sym_STAR] = ACTIONS(4126),
    [anon_sym_SLASH] = ACTIONS(4126),
    [anon_sym_PERCENT] = ACTIONS(4126),
    [anon_sym_CARET] = ACTIONS(4126),
    [anon_sym_PIPE] = ACTIONS(4126),
    [anon_sym_AMP] = ACTIONS(4126),
    [anon_sym_LT_LT] = ACTIONS(4126),
    [anon_sym_GT_GT] = ACTIONS(4126),
    [anon_sym_GT_GT_GT] = ACTIONS(4126),
    [anon_sym_EQ_EQ] = ACTIONS(4128),
    [anon_sym_BANG_EQ] = ACTIONS(4128),
    [anon_sym_GT_EQ] = ACTIONS(4128),
    [anon_sym_LT_EQ] = ACTIONS(4128),
    [anon_sym_this] = ACTIONS(4126),
    [anon_sym_DOT] = ACTIONS(4126),
    [anon_sym_scoped] = ACTIONS(4126),
    [anon_sym_EQ_GT] = ACTIONS(4128),
    [anon_sym_var] = ACTIONS(4126),
    [anon_sym_yield] = ACTIONS(4126),
    [anon_sym_switch] = ACTIONS(4126),
    [anon_sym_when] = ACTIONS(4126),
    [sym_discard] = ACTIONS(4126),
    [anon_sym_DOT_DOT] = ACTIONS(4128),
    [anon_sym_and] = ACTIONS(4126),
    [anon_sym_or] = ACTIONS(4126),
    [anon_sym_PLUS_EQ] = ACTIONS(4128),
    [anon_sym_DASH_EQ] = ACTIONS(4128),
    [anon_sym_STAR_EQ] = ACTIONS(4128),
    [anon_sym_SLASH_EQ] = ACTIONS(4128),
    [anon_sym_PERCENT_EQ] = ACTIONS(4128),
    [anon_sym_AMP_EQ] = ACTIONS(4128),
    [anon_sym_CARET_EQ] = ACTIONS(4128),
    [anon_sym_PIPE_EQ] = ACTIONS(4128),
    [anon_sym_LT_LT_EQ] = ACTIONS(4128),
    [anon_sym_GT_GT_EQ] = ACTIONS(4128),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4128),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4128),
    [anon_sym_AMP_AMP] = ACTIONS(4128),
    [anon_sym_PIPE_PIPE] = ACTIONS(4128),
    [anon_sym_QMARK_QMARK] = ACTIONS(4126),
    [anon_sym_from] = ACTIONS(4126),
    [anon_sym_into] = ACTIONS(4126),
    [anon_sym_join] = ACTIONS(4126),
    [anon_sym_on] = ACTIONS(4126),
    [anon_sym_equals] = ACTIONS(4126),
    [anon_sym_let] = ACTIONS(4126),
    [anon_sym_orderby] = ACTIONS(4126),
    [anon_sym_ascending] = ACTIONS(4126),
    [anon_sym_descending] = ACTIONS(4126),
    [anon_sym_group] = ACTIONS(4126),
    [anon_sym_by] = ACTIONS(4126),
    [anon_sym_select] = ACTIONS(4126),
    [anon_sym_as] = ACTIONS(4126),
    [anon_sym_is] = ACTIONS(4126),
    [anon_sym_DASH_GT] = ACTIONS(4128),
    [anon_sym_with] = ACTIONS(4126),
    [aux_sym_preproc_if_token3] = ACTIONS(4128),
    [aux_sym_preproc_else_token1] = ACTIONS(4128),
    [aux_sym_preproc_elif_token1] = ACTIONS(4128),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2746] = {
    [sym_preproc_region] = STATE(2746),
    [sym_preproc_endregion] = STATE(2746),
    [sym_preproc_line] = STATE(2746),
    [sym_preproc_pragma] = STATE(2746),
    [sym_preproc_nullable] = STATE(2746),
    [sym_preproc_error] = STATE(2746),
    [sym_preproc_warning] = STATE(2746),
    [sym_preproc_define] = STATE(2746),
    [sym_preproc_undef] = STATE(2746),
    [sym__identifier_token] = ACTIONS(4130),
    [anon_sym_alias] = ACTIONS(4130),
    [anon_sym_SEMI] = ACTIONS(4132),
    [anon_sym_global] = ACTIONS(4130),
    [anon_sym_EQ] = ACTIONS(4130),
    [anon_sym_LBRACK] = ACTIONS(4132),
    [anon_sym_COLON] = ACTIONS(4132),
    [anon_sym_COMMA] = ACTIONS(4132),
    [anon_sym_RBRACK] = ACTIONS(4132),
    [anon_sym_LPAREN] = ACTIONS(4132),
    [anon_sym_RPAREN] = ACTIONS(4132),
    [anon_sym_LBRACE] = ACTIONS(4132),
    [anon_sym_RBRACE] = ACTIONS(4132),
    [anon_sym_file] = ACTIONS(4130),
    [anon_sym_LT] = ACTIONS(4130),
    [anon_sym_GT] = ACTIONS(4130),
    [anon_sym_in] = ACTIONS(4130),
    [anon_sym_where] = ACTIONS(4130),
    [anon_sym_QMARK] = ACTIONS(4130),
    [anon_sym_notnull] = ACTIONS(4130),
    [anon_sym_unmanaged] = ACTIONS(4130),
    [anon_sym_operator] = ACTIONS(4130),
    [anon_sym_BANG] = ACTIONS(4130),
    [anon_sym_PLUS_PLUS] = ACTIONS(4132),
    [anon_sym_DASH_DASH] = ACTIONS(4132),
    [anon_sym_PLUS] = ACTIONS(4130),
    [anon_sym_DASH] = ACTIONS(4130),
    [anon_sym_STAR] = ACTIONS(4130),
    [anon_sym_SLASH] = ACTIONS(4130),
    [anon_sym_PERCENT] = ACTIONS(4130),
    [anon_sym_CARET] = ACTIONS(4130),
    [anon_sym_PIPE] = ACTIONS(4130),
    [anon_sym_AMP] = ACTIONS(4130),
    [anon_sym_LT_LT] = ACTIONS(4130),
    [anon_sym_GT_GT] = ACTIONS(4130),
    [anon_sym_GT_GT_GT] = ACTIONS(4130),
    [anon_sym_EQ_EQ] = ACTIONS(4132),
    [anon_sym_BANG_EQ] = ACTIONS(4132),
    [anon_sym_GT_EQ] = ACTIONS(4132),
    [anon_sym_LT_EQ] = ACTIONS(4132),
    [anon_sym_this] = ACTIONS(4130),
    [anon_sym_DOT] = ACTIONS(4130),
    [anon_sym_scoped] = ACTIONS(4130),
    [anon_sym_EQ_GT] = ACTIONS(4132),
    [anon_sym_var] = ACTIONS(4130),
    [anon_sym_yield] = ACTIONS(4130),
    [anon_sym_switch] = ACTIONS(4130),
    [anon_sym_when] = ACTIONS(4130),
    [sym_discard] = ACTIONS(4130),
    [anon_sym_DOT_DOT] = ACTIONS(4132),
    [anon_sym_and] = ACTIONS(4130),
    [anon_sym_or] = ACTIONS(4130),
    [anon_sym_PLUS_EQ] = ACTIONS(4132),
    [anon_sym_DASH_EQ] = ACTIONS(4132),
    [anon_sym_STAR_EQ] = ACTIONS(4132),
    [anon_sym_SLASH_EQ] = ACTIONS(4132),
    [anon_sym_PERCENT_EQ] = ACTIONS(4132),
    [anon_sym_AMP_EQ] = ACTIONS(4132),
    [anon_sym_CARET_EQ] = ACTIONS(4132),
    [anon_sym_PIPE_EQ] = ACTIONS(4132),
    [anon_sym_LT_LT_EQ] = ACTIONS(4132),
    [anon_sym_GT_GT_EQ] = ACTIONS(4132),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4132),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4132),
    [anon_sym_AMP_AMP] = ACTIONS(4132),
    [anon_sym_PIPE_PIPE] = ACTIONS(4132),
    [anon_sym_QMARK_QMARK] = ACTIONS(4130),
    [anon_sym_from] = ACTIONS(4130),
    [anon_sym_into] = ACTIONS(4130),
    [anon_sym_join] = ACTIONS(4130),
    [anon_sym_on] = ACTIONS(4130),
    [anon_sym_equals] = ACTIONS(4130),
    [anon_sym_let] = ACTIONS(4130),
    [anon_sym_orderby] = ACTIONS(4130),
    [anon_sym_ascending] = ACTIONS(4130),
    [anon_sym_descending] = ACTIONS(4130),
    [anon_sym_group] = ACTIONS(4130),
    [anon_sym_by] = ACTIONS(4130),
    [anon_sym_select] = ACTIONS(4130),
    [anon_sym_as] = ACTIONS(4130),
    [anon_sym_is] = ACTIONS(4130),
    [anon_sym_DASH_GT] = ACTIONS(4132),
    [anon_sym_with] = ACTIONS(4130),
    [aux_sym_preproc_if_token3] = ACTIONS(4132),
    [aux_sym_preproc_else_token1] = ACTIONS(4132),
    [aux_sym_preproc_elif_token1] = ACTIONS(4132),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2747] = {
    [sym_preproc_region] = STATE(2747),
    [sym_preproc_endregion] = STATE(2747),
    [sym_preproc_line] = STATE(2747),
    [sym_preproc_pragma] = STATE(2747),
    [sym_preproc_nullable] = STATE(2747),
    [sym_preproc_error] = STATE(2747),
    [sym_preproc_warning] = STATE(2747),
    [sym_preproc_define] = STATE(2747),
    [sym_preproc_undef] = STATE(2747),
    [sym__identifier_token] = ACTIONS(4134),
    [anon_sym_alias] = ACTIONS(4134),
    [anon_sym_SEMI] = ACTIONS(4136),
    [anon_sym_global] = ACTIONS(4134),
    [anon_sym_EQ] = ACTIONS(4134),
    [anon_sym_LBRACK] = ACTIONS(4136),
    [anon_sym_COLON] = ACTIONS(4136),
    [anon_sym_COMMA] = ACTIONS(4136),
    [anon_sym_RBRACK] = ACTIONS(4136),
    [anon_sym_LPAREN] = ACTIONS(4136),
    [anon_sym_RPAREN] = ACTIONS(4136),
    [anon_sym_LBRACE] = ACTIONS(4136),
    [anon_sym_RBRACE] = ACTIONS(4136),
    [anon_sym_file] = ACTIONS(4134),
    [anon_sym_LT] = ACTIONS(4134),
    [anon_sym_GT] = ACTIONS(4134),
    [anon_sym_in] = ACTIONS(4134),
    [anon_sym_where] = ACTIONS(4134),
    [anon_sym_QMARK] = ACTIONS(4134),
    [anon_sym_notnull] = ACTIONS(4134),
    [anon_sym_unmanaged] = ACTIONS(4134),
    [anon_sym_operator] = ACTIONS(4134),
    [anon_sym_BANG] = ACTIONS(4134),
    [anon_sym_PLUS_PLUS] = ACTIONS(4136),
    [anon_sym_DASH_DASH] = ACTIONS(4136),
    [anon_sym_PLUS] = ACTIONS(4134),
    [anon_sym_DASH] = ACTIONS(4134),
    [anon_sym_STAR] = ACTIONS(4134),
    [anon_sym_SLASH] = ACTIONS(4134),
    [anon_sym_PERCENT] = ACTIONS(4134),
    [anon_sym_CARET] = ACTIONS(4134),
    [anon_sym_PIPE] = ACTIONS(4134),
    [anon_sym_AMP] = ACTIONS(4134),
    [anon_sym_LT_LT] = ACTIONS(4134),
    [anon_sym_GT_GT] = ACTIONS(4134),
    [anon_sym_GT_GT_GT] = ACTIONS(4134),
    [anon_sym_EQ_EQ] = ACTIONS(4136),
    [anon_sym_BANG_EQ] = ACTIONS(4136),
    [anon_sym_GT_EQ] = ACTIONS(4136),
    [anon_sym_LT_EQ] = ACTIONS(4136),
    [anon_sym_this] = ACTIONS(4134),
    [anon_sym_DOT] = ACTIONS(4134),
    [anon_sym_scoped] = ACTIONS(4134),
    [anon_sym_EQ_GT] = ACTIONS(4136),
    [anon_sym_var] = ACTIONS(4134),
    [anon_sym_yield] = ACTIONS(4134),
    [anon_sym_switch] = ACTIONS(4134),
    [anon_sym_when] = ACTIONS(4134),
    [sym_discard] = ACTIONS(4134),
    [anon_sym_DOT_DOT] = ACTIONS(4136),
    [anon_sym_and] = ACTIONS(4134),
    [anon_sym_or] = ACTIONS(4134),
    [anon_sym_PLUS_EQ] = ACTIONS(4136),
    [anon_sym_DASH_EQ] = ACTIONS(4136),
    [anon_sym_STAR_EQ] = ACTIONS(4136),
    [anon_sym_SLASH_EQ] = ACTIONS(4136),
    [anon_sym_PERCENT_EQ] = ACTIONS(4136),
    [anon_sym_AMP_EQ] = ACTIONS(4136),
    [anon_sym_CARET_EQ] = ACTIONS(4136),
    [anon_sym_PIPE_EQ] = ACTIONS(4136),
    [anon_sym_LT_LT_EQ] = ACTIONS(4136),
    [anon_sym_GT_GT_EQ] = ACTIONS(4136),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4136),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4136),
    [anon_sym_AMP_AMP] = ACTIONS(4136),
    [anon_sym_PIPE_PIPE] = ACTIONS(4136),
    [anon_sym_QMARK_QMARK] = ACTIONS(4134),
    [anon_sym_from] = ACTIONS(4134),
    [anon_sym_into] = ACTIONS(4134),
    [anon_sym_join] = ACTIONS(4134),
    [anon_sym_on] = ACTIONS(4134),
    [anon_sym_equals] = ACTIONS(4134),
    [anon_sym_let] = ACTIONS(4134),
    [anon_sym_orderby] = ACTIONS(4134),
    [anon_sym_ascending] = ACTIONS(4134),
    [anon_sym_descending] = ACTIONS(4134),
    [anon_sym_group] = ACTIONS(4134),
    [anon_sym_by] = ACTIONS(4134),
    [anon_sym_select] = ACTIONS(4134),
    [anon_sym_as] = ACTIONS(4134),
    [anon_sym_is] = ACTIONS(4134),
    [anon_sym_DASH_GT] = ACTIONS(4136),
    [anon_sym_with] = ACTIONS(4134),
    [aux_sym_preproc_if_token3] = ACTIONS(4136),
    [aux_sym_preproc_else_token1] = ACTIONS(4136),
    [aux_sym_preproc_elif_token1] = ACTIONS(4136),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2748] = {
    [sym_type_argument_list] = STATE(2746),
    [sym_preproc_region] = STATE(2748),
    [sym_preproc_endregion] = STATE(2748),
    [sym_preproc_line] = STATE(2748),
    [sym_preproc_pragma] = STATE(2748),
    [sym_preproc_nullable] = STATE(2748),
    [sym_preproc_error] = STATE(2748),
    [sym_preproc_warning] = STATE(2748),
    [sym_preproc_define] = STATE(2748),
    [sym_preproc_undef] = STATE(2748),
    [sym__identifier_token] = ACTIONS(4138),
    [anon_sym_alias] = ACTIONS(4138),
    [anon_sym_SEMI] = ACTIONS(4140),
    [anon_sym_global] = ACTIONS(4138),
    [anon_sym_EQ] = ACTIONS(4138),
    [anon_sym_LBRACK] = ACTIONS(4140),
    [anon_sym_COLON] = ACTIONS(4138),
    [anon_sym_COMMA] = ACTIONS(4140),
    [anon_sym_RBRACK] = ACTIONS(4140),
    [anon_sym_LPAREN] = ACTIONS(4140),
    [anon_sym_RPAREN] = ACTIONS(4140),
    [anon_sym_LBRACE] = ACTIONS(4140),
    [anon_sym_RBRACE] = ACTIONS(4140),
    [anon_sym_file] = ACTIONS(4138),
    [anon_sym_LT] = ACTIONS(4142),
    [anon_sym_GT] = ACTIONS(4138),
    [anon_sym_in] = ACTIONS(4138),
    [anon_sym_where] = ACTIONS(4138),
    [anon_sym_QMARK] = ACTIONS(4138),
    [anon_sym_notnull] = ACTIONS(4138),
    [anon_sym_unmanaged] = ACTIONS(4138),
    [anon_sym_BANG] = ACTIONS(4138),
    [anon_sym_PLUS_PLUS] = ACTIONS(4140),
    [anon_sym_DASH_DASH] = ACTIONS(4140),
    [anon_sym_PLUS] = ACTIONS(4138),
    [anon_sym_DASH] = ACTIONS(4138),
    [anon_sym_STAR] = ACTIONS(4138),
    [anon_sym_SLASH] = ACTIONS(4138),
    [anon_sym_PERCENT] = ACTIONS(4138),
    [anon_sym_CARET] = ACTIONS(4138),
    [anon_sym_PIPE] = ACTIONS(4138),
    [anon_sym_AMP] = ACTIONS(4138),
    [anon_sym_LT_LT] = ACTIONS(4138),
    [anon_sym_GT_GT] = ACTIONS(4138),
    [anon_sym_GT_GT_GT] = ACTIONS(4138),
    [anon_sym_EQ_EQ] = ACTIONS(4140),
    [anon_sym_BANG_EQ] = ACTIONS(4140),
    [anon_sym_GT_EQ] = ACTIONS(4140),
    [anon_sym_LT_EQ] = ACTIONS(4140),
    [anon_sym_DOT] = ACTIONS(4138),
    [anon_sym_scoped] = ACTIONS(4138),
    [anon_sym_EQ_GT] = ACTIONS(4145),
    [anon_sym_COLON_COLON] = ACTIONS(4147),
    [anon_sym_var] = ACTIONS(4138),
    [anon_sym_yield] = ACTIONS(4138),
    [anon_sym_switch] = ACTIONS(4138),
    [anon_sym_when] = ACTIONS(4138),
    [sym_discard] = ACTIONS(4138),
    [anon_sym_DOT_DOT] = ACTIONS(4140),
    [anon_sym_and] = ACTIONS(4138),
    [anon_sym_or] = ACTIONS(4138),
    [anon_sym_PLUS_EQ] = ACTIONS(4140),
    [anon_sym_DASH_EQ] = ACTIONS(4140),
    [anon_sym_STAR_EQ] = ACTIONS(4140),
    [anon_sym_SLASH_EQ] = ACTIONS(4140),
    [anon_sym_PERCENT_EQ] = ACTIONS(4140),
    [anon_sym_AMP_EQ] = ACTIONS(4140),
    [anon_sym_CARET_EQ] = ACTIONS(4140),
    [anon_sym_PIPE_EQ] = ACTIONS(4140),
    [anon_sym_LT_LT_EQ] = ACTIONS(4140),
    [anon_sym_GT_GT_EQ] = ACTIONS(4140),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4140),
    [anon_sym_AMP_AMP] = ACTIONS(4140),
    [anon_sym_PIPE_PIPE] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK] = ACTIONS(4138),
    [anon_sym_from] = ACTIONS(4138),
    [anon_sym_into] = ACTIONS(4138),
    [anon_sym_join] = ACTIONS(4138),
    [anon_sym_on] = ACTIONS(4138),
    [anon_sym_equals] = ACTIONS(4138),
    [anon_sym_let] = ACTIONS(4138),
    [anon_sym_orderby] = ACTIONS(4138),
    [anon_sym_ascending] = ACTIONS(4138),
    [anon_sym_descending] = ACTIONS(4138),
    [anon_sym_group] = ACTIONS(4138),
    [anon_sym_by] = ACTIONS(4138),
    [anon_sym_select] = ACTIONS(4138),
    [anon_sym_as] = ACTIONS(4138),
    [anon_sym_is] = ACTIONS(4138),
    [anon_sym_DASH_GT] = ACTIONS(4140),
    [anon_sym_with] = ACTIONS(4138),
    [aux_sym_preproc_if_token3] = ACTIONS(4140),
    [aux_sym_preproc_else_token1] = ACTIONS(4140),
    [aux_sym_preproc_elif_token1] = ACTIONS(4140),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2749] = {
    [sym_preproc_region] = STATE(2749),
    [sym_preproc_endregion] = STATE(2749),
    [sym_preproc_line] = STATE(2749),
    [sym_preproc_pragma] = STATE(2749),
    [sym_preproc_nullable] = STATE(2749),
    [sym_preproc_error] = STATE(2749),
    [sym_preproc_warning] = STATE(2749),
    [sym_preproc_define] = STATE(2749),
    [sym_preproc_undef] = STATE(2749),
    [sym__identifier_token] = ACTIONS(4138),
    [anon_sym_alias] = ACTIONS(4138),
    [anon_sym_SEMI] = ACTIONS(4140),
    [anon_sym_global] = ACTIONS(4138),
    [anon_sym_EQ] = ACTIONS(4138),
    [anon_sym_LBRACK] = ACTIONS(4140),
    [anon_sym_COLON] = ACTIONS(4140),
    [anon_sym_COMMA] = ACTIONS(4140),
    [anon_sym_RBRACK] = ACTIONS(4140),
    [anon_sym_LPAREN] = ACTIONS(4140),
    [anon_sym_RPAREN] = ACTIONS(4140),
    [anon_sym_LBRACE] = ACTIONS(4140),
    [anon_sym_RBRACE] = ACTIONS(4140),
    [anon_sym_file] = ACTIONS(4138),
    [anon_sym_LT] = ACTIONS(4138),
    [anon_sym_GT] = ACTIONS(4138),
    [anon_sym_in] = ACTIONS(4138),
    [anon_sym_where] = ACTIONS(4138),
    [anon_sym_QMARK] = ACTIONS(4138),
    [anon_sym_notnull] = ACTIONS(4138),
    [anon_sym_unmanaged] = ACTIONS(4138),
    [anon_sym_operator] = ACTIONS(4138),
    [anon_sym_BANG] = ACTIONS(4138),
    [anon_sym_PLUS_PLUS] = ACTIONS(4140),
    [anon_sym_DASH_DASH] = ACTIONS(4140),
    [anon_sym_PLUS] = ACTIONS(4138),
    [anon_sym_DASH] = ACTIONS(4138),
    [anon_sym_STAR] = ACTIONS(4138),
    [anon_sym_SLASH] = ACTIONS(4138),
    [anon_sym_PERCENT] = ACTIONS(4138),
    [anon_sym_CARET] = ACTIONS(4138),
    [anon_sym_PIPE] = ACTIONS(4138),
    [anon_sym_AMP] = ACTIONS(4138),
    [anon_sym_LT_LT] = ACTIONS(4138),
    [anon_sym_GT_GT] = ACTIONS(4138),
    [anon_sym_GT_GT_GT] = ACTIONS(4138),
    [anon_sym_EQ_EQ] = ACTIONS(4140),
    [anon_sym_BANG_EQ] = ACTIONS(4140),
    [anon_sym_GT_EQ] = ACTIONS(4140),
    [anon_sym_LT_EQ] = ACTIONS(4140),
    [anon_sym_this] = ACTIONS(4138),
    [anon_sym_DOT] = ACTIONS(4138),
    [anon_sym_scoped] = ACTIONS(4138),
    [anon_sym_EQ_GT] = ACTIONS(4140),
    [anon_sym_var] = ACTIONS(4138),
    [anon_sym_yield] = ACTIONS(4138),
    [anon_sym_switch] = ACTIONS(4138),
    [anon_sym_when] = ACTIONS(4138),
    [sym_discard] = ACTIONS(4138),
    [anon_sym_DOT_DOT] = ACTIONS(4140),
    [anon_sym_and] = ACTIONS(4138),
    [anon_sym_or] = ACTIONS(4138),
    [anon_sym_PLUS_EQ] = ACTIONS(4140),
    [anon_sym_DASH_EQ] = ACTIONS(4140),
    [anon_sym_STAR_EQ] = ACTIONS(4140),
    [anon_sym_SLASH_EQ] = ACTIONS(4140),
    [anon_sym_PERCENT_EQ] = ACTIONS(4140),
    [anon_sym_AMP_EQ] = ACTIONS(4140),
    [anon_sym_CARET_EQ] = ACTIONS(4140),
    [anon_sym_PIPE_EQ] = ACTIONS(4140),
    [anon_sym_LT_LT_EQ] = ACTIONS(4140),
    [anon_sym_GT_GT_EQ] = ACTIONS(4140),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4140),
    [anon_sym_AMP_AMP] = ACTIONS(4140),
    [anon_sym_PIPE_PIPE] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK] = ACTIONS(4138),
    [anon_sym_from] = ACTIONS(4138),
    [anon_sym_into] = ACTIONS(4138),
    [anon_sym_join] = ACTIONS(4138),
    [anon_sym_on] = ACTIONS(4138),
    [anon_sym_equals] = ACTIONS(4138),
    [anon_sym_let] = ACTIONS(4138),
    [anon_sym_orderby] = ACTIONS(4138),
    [anon_sym_ascending] = ACTIONS(4138),
    [anon_sym_descending] = ACTIONS(4138),
    [anon_sym_group] = ACTIONS(4138),
    [anon_sym_by] = ACTIONS(4138),
    [anon_sym_select] = ACTIONS(4138),
    [anon_sym_as] = ACTIONS(4138),
    [anon_sym_is] = ACTIONS(4138),
    [anon_sym_DASH_GT] = ACTIONS(4140),
    [anon_sym_with] = ACTIONS(4138),
    [aux_sym_preproc_if_token3] = ACTIONS(4140),
    [aux_sym_preproc_else_token1] = ACTIONS(4140),
    [aux_sym_preproc_elif_token1] = ACTIONS(4140),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2750] = {
    [sym_preproc_region] = STATE(2750),
    [sym_preproc_endregion] = STATE(2750),
    [sym_preproc_line] = STATE(2750),
    [sym_preproc_pragma] = STATE(2750),
    [sym_preproc_nullable] = STATE(2750),
    [sym_preproc_error] = STATE(2750),
    [sym_preproc_warning] = STATE(2750),
    [sym_preproc_define] = STATE(2750),
    [sym_preproc_undef] = STATE(2750),
    [sym__identifier_token] = ACTIONS(4149),
    [anon_sym_alias] = ACTIONS(4149),
    [anon_sym_SEMI] = ACTIONS(4151),
    [anon_sym_global] = ACTIONS(4149),
    [anon_sym_EQ] = ACTIONS(4149),
    [anon_sym_LBRACK] = ACTIONS(4151),
    [anon_sym_COLON] = ACTIONS(4151),
    [anon_sym_COMMA] = ACTIONS(4151),
    [anon_sym_RBRACK] = ACTIONS(4151),
    [anon_sym_LPAREN] = ACTIONS(4151),
    [anon_sym_RPAREN] = ACTIONS(4151),
    [anon_sym_LBRACE] = ACTIONS(4151),
    [anon_sym_RBRACE] = ACTIONS(4151),
    [anon_sym_file] = ACTIONS(4149),
    [anon_sym_LT] = ACTIONS(4149),
    [anon_sym_GT] = ACTIONS(4149),
    [anon_sym_in] = ACTIONS(4149),
    [anon_sym_where] = ACTIONS(4149),
    [anon_sym_QMARK] = ACTIONS(4149),
    [anon_sym_notnull] = ACTIONS(4149),
    [anon_sym_unmanaged] = ACTIONS(4149),
    [anon_sym_operator] = ACTIONS(4149),
    [anon_sym_BANG] = ACTIONS(4149),
    [anon_sym_PLUS_PLUS] = ACTIONS(4151),
    [anon_sym_DASH_DASH] = ACTIONS(4151),
    [anon_sym_PLUS] = ACTIONS(4149),
    [anon_sym_DASH] = ACTIONS(4149),
    [anon_sym_STAR] = ACTIONS(4149),
    [anon_sym_SLASH] = ACTIONS(4149),
    [anon_sym_PERCENT] = ACTIONS(4149),
    [anon_sym_CARET] = ACTIONS(4149),
    [anon_sym_PIPE] = ACTIONS(4149),
    [anon_sym_AMP] = ACTIONS(4149),
    [anon_sym_LT_LT] = ACTIONS(4149),
    [anon_sym_GT_GT] = ACTIONS(4149),
    [anon_sym_GT_GT_GT] = ACTIONS(4149),
    [anon_sym_EQ_EQ] = ACTIONS(4151),
    [anon_sym_BANG_EQ] = ACTIONS(4151),
    [anon_sym_GT_EQ] = ACTIONS(4151),
    [anon_sym_LT_EQ] = ACTIONS(4151),
    [anon_sym_this] = ACTIONS(4149),
    [anon_sym_DOT] = ACTIONS(4149),
    [anon_sym_scoped] = ACTIONS(4149),
    [anon_sym_EQ_GT] = ACTIONS(4151),
    [anon_sym_var] = ACTIONS(4149),
    [anon_sym_yield] = ACTIONS(4149),
    [anon_sym_switch] = ACTIONS(4149),
    [anon_sym_when] = ACTIONS(4149),
    [sym_discard] = ACTIONS(4149),
    [anon_sym_DOT_DOT] = ACTIONS(4151),
    [anon_sym_and] = ACTIONS(4149),
    [anon_sym_or] = ACTIONS(4149),
    [anon_sym_PLUS_EQ] = ACTIONS(4151),
    [anon_sym_DASH_EQ] = ACTIONS(4151),
    [anon_sym_STAR_EQ] = ACTIONS(4151),
    [anon_sym_SLASH_EQ] = ACTIONS(4151),
    [anon_sym_PERCENT_EQ] = ACTIONS(4151),
    [anon_sym_AMP_EQ] = ACTIONS(4151),
    [anon_sym_CARET_EQ] = ACTIONS(4151),
    [anon_sym_PIPE_EQ] = ACTIONS(4151),
    [anon_sym_LT_LT_EQ] = ACTIONS(4151),
    [anon_sym_GT_GT_EQ] = ACTIONS(4151),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4151),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4151),
    [anon_sym_AMP_AMP] = ACTIONS(4151),
    [anon_sym_PIPE_PIPE] = ACTIONS(4151),
    [anon_sym_QMARK_QMARK] = ACTIONS(4149),
    [anon_sym_from] = ACTIONS(4149),
    [anon_sym_into] = ACTIONS(4149),
    [anon_sym_join] = ACTIONS(4149),
    [anon_sym_on] = ACTIONS(4149),
    [anon_sym_equals] = ACTIONS(4149),
    [anon_sym_let] = ACTIONS(4149),
    [anon_sym_orderby] = ACTIONS(4149),
    [anon_sym_ascending] = ACTIONS(4149),
    [anon_sym_descending] = ACTIONS(4149),
    [anon_sym_group] = ACTIONS(4149),
    [anon_sym_by] = ACTIONS(4149),
    [anon_sym_select] = ACTIONS(4149),
    [anon_sym_as] = ACTIONS(4149),
    [anon_sym_is] = ACTIONS(4149),
    [anon_sym_DASH_GT] = ACTIONS(4151),
    [anon_sym_with] = ACTIONS(4149),
    [aux_sym_preproc_if_token3] = ACTIONS(4151),
    [aux_sym_preproc_else_token1] = ACTIONS(4151),
    [aux_sym_preproc_elif_token1] = ACTIONS(4151),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2751] = {
    [sym__name] = STATE(6202),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_ref_type] = STATE(2883),
    [sym__scoped_base_type] = STATE(2885),
    [sym_identifier] = STATE(5346),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_region] = STATE(2751),
    [sym_preproc_endregion] = STATE(2751),
    [sym_preproc_line] = STATE(2751),
    [sym_preproc_pragma] = STATE(2751),
    [sym_preproc_nullable] = STATE(2751),
    [sym_preproc_error] = STATE(2751),
    [sym_preproc_warning] = STATE(2751),
    [sym_preproc_define] = STATE(2751),
    [sym_preproc_undef] = STATE(2751),
    [sym__identifier_token] = ACTIONS(4072),
    [anon_sym_alias] = ACTIONS(4075),
    [anon_sym_global] = ACTIONS(4075),
    [anon_sym_EQ] = ACTIONS(3995),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_COLON] = ACTIONS(3995),
    [anon_sym_COMMA] = ACTIONS(3993),
    [anon_sym_LPAREN] = ACTIONS(3993),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_file] = ACTIONS(4075),
    [anon_sym_LT] = ACTIONS(3995),
    [anon_sym_GT] = ACTIONS(3995),
    [anon_sym_where] = ACTIONS(4075),
    [anon_sym_QMARK] = ACTIONS(3995),
    [anon_sym_notnull] = ACTIONS(4075),
    [anon_sym_unmanaged] = ACTIONS(4075),
    [anon_sym_BANG] = ACTIONS(3995),
    [anon_sym_PLUS_PLUS] = ACTIONS(3993),
    [anon_sym_DASH_DASH] = ACTIONS(3993),
    [anon_sym_PLUS] = ACTIONS(3995),
    [anon_sym_DASH] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3995),
    [anon_sym_SLASH] = ACTIONS(3995),
    [anon_sym_PERCENT] = ACTIONS(3995),
    [anon_sym_CARET] = ACTIONS(3995),
    [anon_sym_PIPE] = ACTIONS(3995),
    [anon_sym_AMP] = ACTIONS(3995),
    [anon_sym_LT_LT] = ACTIONS(3995),
    [anon_sym_GT_GT] = ACTIONS(3995),
    [anon_sym_GT_GT_GT] = ACTIONS(3995),
    [anon_sym_EQ_EQ] = ACTIONS(3993),
    [anon_sym_BANG_EQ] = ACTIONS(3993),
    [anon_sym_GT_EQ] = ACTIONS(3993),
    [anon_sym_LT_EQ] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3995),
    [anon_sym_scoped] = ACTIONS(4075),
    [anon_sym_EQ_GT] = ACTIONS(3993),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(4075),
    [anon_sym_yield] = ACTIONS(4075),
    [anon_sym_switch] = ACTIONS(3995),
    [anon_sym_when] = ACTIONS(4075),
    [anon_sym_DOT_DOT] = ACTIONS(3993),
    [anon_sym_and] = ACTIONS(3995),
    [anon_sym_or] = ACTIONS(3995),
    [anon_sym_PLUS_EQ] = ACTIONS(3993),
    [anon_sym_DASH_EQ] = ACTIONS(3993),
    [anon_sym_STAR_EQ] = ACTIONS(3993),
    [anon_sym_SLASH_EQ] = ACTIONS(3993),
    [anon_sym_PERCENT_EQ] = ACTIONS(3993),
    [anon_sym_AMP_EQ] = ACTIONS(3993),
    [anon_sym_CARET_EQ] = ACTIONS(3993),
    [anon_sym_PIPE_EQ] = ACTIONS(3993),
    [anon_sym_LT_LT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(3993),
    [anon_sym_AMP_AMP] = ACTIONS(3993),
    [anon_sym_PIPE_PIPE] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK] = ACTIONS(3995),
    [anon_sym_from] = ACTIONS(4075),
    [anon_sym_into] = ACTIONS(4075),
    [anon_sym_join] = ACTIONS(4075),
    [anon_sym_on] = ACTIONS(4075),
    [anon_sym_equals] = ACTIONS(4075),
    [anon_sym_let] = ACTIONS(4075),
    [anon_sym_orderby] = ACTIONS(4075),
    [anon_sym_ascending] = ACTIONS(4075),
    [anon_sym_descending] = ACTIONS(4075),
    [anon_sym_group] = ACTIONS(4075),
    [anon_sym_by] = ACTIONS(4075),
    [anon_sym_select] = ACTIONS(4075),
    [anon_sym_as] = ACTIONS(3995),
    [anon_sym_is] = ACTIONS(3995),
    [anon_sym_DASH_GT] = ACTIONS(3993),
    [anon_sym_with] = ACTIONS(3995),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(3993),
  },
  [2752] = {
    [sym__name] = STATE(6889),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_ref_type] = STATE(2883),
    [sym__scoped_base_type] = STATE(2885),
    [sym_identifier] = STATE(6769),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_region] = STATE(2752),
    [sym_preproc_endregion] = STATE(2752),
    [sym_preproc_line] = STATE(2752),
    [sym_preproc_pragma] = STATE(2752),
    [sym_preproc_nullable] = STATE(2752),
    [sym_preproc_error] = STATE(2752),
    [sym_preproc_warning] = STATE(2752),
    [sym_preproc_define] = STATE(2752),
    [sym_preproc_undef] = STATE(2752),
    [sym__identifier_token] = ACTIONS(4072),
    [anon_sym_alias] = ACTIONS(4075),
    [anon_sym_global] = ACTIONS(4075),
    [anon_sym_EQ] = ACTIONS(3995),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_COLON] = ACTIONS(3995),
    [anon_sym_LPAREN] = ACTIONS(3993),
    [anon_sym_ref] = ACTIONS(4153),
    [anon_sym_LBRACE] = ACTIONS(3993),
    [anon_sym_file] = ACTIONS(4075),
    [anon_sym_LT] = ACTIONS(3995),
    [anon_sym_GT] = ACTIONS(3995),
    [anon_sym_where] = ACTIONS(4075),
    [anon_sym_QMARK] = ACTIONS(3995),
    [anon_sym_notnull] = ACTIONS(4075),
    [anon_sym_unmanaged] = ACTIONS(4075),
    [anon_sym_BANG] = ACTIONS(3995),
    [anon_sym_PLUS_PLUS] = ACTIONS(3993),
    [anon_sym_DASH_DASH] = ACTIONS(3993),
    [anon_sym_PLUS] = ACTIONS(3995),
    [anon_sym_DASH] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3995),
    [anon_sym_SLASH] = ACTIONS(3995),
    [anon_sym_PERCENT] = ACTIONS(3995),
    [anon_sym_CARET] = ACTIONS(3995),
    [anon_sym_PIPE] = ACTIONS(3995),
    [anon_sym_AMP] = ACTIONS(3995),
    [anon_sym_LT_LT] = ACTIONS(3995),
    [anon_sym_GT_GT] = ACTIONS(3995),
    [anon_sym_GT_GT_GT] = ACTIONS(3995),
    [anon_sym_EQ_EQ] = ACTIONS(3993),
    [anon_sym_BANG_EQ] = ACTIONS(3993),
    [anon_sym_GT_EQ] = ACTIONS(3993),
    [anon_sym_LT_EQ] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3995),
    [anon_sym_scoped] = ACTIONS(4075),
    [anon_sym_EQ_GT] = ACTIONS(3993),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(4075),
    [anon_sym_yield] = ACTIONS(4075),
    [anon_sym_switch] = ACTIONS(3995),
    [anon_sym_when] = ACTIONS(4075),
    [sym_discard] = ACTIONS(3995),
    [anon_sym_DOT_DOT] = ACTIONS(3993),
    [anon_sym_and] = ACTIONS(3995),
    [anon_sym_or] = ACTIONS(3995),
    [anon_sym_PLUS_EQ] = ACTIONS(3993),
    [anon_sym_DASH_EQ] = ACTIONS(3993),
    [anon_sym_STAR_EQ] = ACTIONS(3993),
    [anon_sym_SLASH_EQ] = ACTIONS(3993),
    [anon_sym_PERCENT_EQ] = ACTIONS(3993),
    [anon_sym_AMP_EQ] = ACTIONS(3993),
    [anon_sym_CARET_EQ] = ACTIONS(3993),
    [anon_sym_PIPE_EQ] = ACTIONS(3993),
    [anon_sym_LT_LT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(3993),
    [anon_sym_AMP_AMP] = ACTIONS(3993),
    [anon_sym_PIPE_PIPE] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK] = ACTIONS(3995),
    [anon_sym_from] = ACTIONS(4075),
    [anon_sym_into] = ACTIONS(4075),
    [anon_sym_join] = ACTIONS(4075),
    [anon_sym_on] = ACTIONS(4075),
    [anon_sym_equals] = ACTIONS(4075),
    [anon_sym_let] = ACTIONS(4075),
    [anon_sym_orderby] = ACTIONS(4075),
    [anon_sym_ascending] = ACTIONS(4075),
    [anon_sym_descending] = ACTIONS(4075),
    [anon_sym_group] = ACTIONS(4075),
    [anon_sym_by] = ACTIONS(4075),
    [anon_sym_select] = ACTIONS(4075),
    [anon_sym_as] = ACTIONS(3995),
    [anon_sym_is] = ACTIONS(3995),
    [anon_sym_DASH_GT] = ACTIONS(3993),
    [anon_sym_with] = ACTIONS(3995),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2753] = {
    [sym_type_argument_list] = STATE(2746),
    [sym_preproc_region] = STATE(2753),
    [sym_preproc_endregion] = STATE(2753),
    [sym_preproc_line] = STATE(2753),
    [sym_preproc_pragma] = STATE(2753),
    [sym_preproc_nullable] = STATE(2753),
    [sym_preproc_error] = STATE(2753),
    [sym_preproc_warning] = STATE(2753),
    [sym_preproc_define] = STATE(2753),
    [sym_preproc_undef] = STATE(2753),
    [sym__identifier_token] = ACTIONS(4138),
    [anon_sym_alias] = ACTIONS(4138),
    [anon_sym_SEMI] = ACTIONS(4140),
    [anon_sym_global] = ACTIONS(4138),
    [anon_sym_EQ] = ACTIONS(4138),
    [anon_sym_LBRACK] = ACTIONS(4140),
    [anon_sym_COLON] = ACTIONS(4140),
    [anon_sym_COMMA] = ACTIONS(4140),
    [anon_sym_RBRACK] = ACTIONS(4140),
    [anon_sym_LPAREN] = ACTIONS(4140),
    [anon_sym_RPAREN] = ACTIONS(4140),
    [anon_sym_LBRACE] = ACTIONS(4140),
    [anon_sym_RBRACE] = ACTIONS(4140),
    [anon_sym_file] = ACTIONS(4138),
    [anon_sym_LT] = ACTIONS(4142),
    [anon_sym_GT] = ACTIONS(4138),
    [anon_sym_in] = ACTIONS(4138),
    [anon_sym_where] = ACTIONS(4138),
    [anon_sym_QMARK] = ACTIONS(4138),
    [anon_sym_notnull] = ACTIONS(4138),
    [anon_sym_unmanaged] = ACTIONS(4138),
    [anon_sym_BANG] = ACTIONS(4138),
    [anon_sym_PLUS_PLUS] = ACTIONS(4140),
    [anon_sym_DASH_DASH] = ACTIONS(4140),
    [anon_sym_PLUS] = ACTIONS(4138),
    [anon_sym_DASH] = ACTIONS(4138),
    [anon_sym_STAR] = ACTIONS(4138),
    [anon_sym_SLASH] = ACTIONS(4138),
    [anon_sym_PERCENT] = ACTIONS(4138),
    [anon_sym_CARET] = ACTIONS(4138),
    [anon_sym_PIPE] = ACTIONS(4138),
    [anon_sym_AMP] = ACTIONS(4138),
    [anon_sym_LT_LT] = ACTIONS(4138),
    [anon_sym_GT_GT] = ACTIONS(4138),
    [anon_sym_GT_GT_GT] = ACTIONS(4138),
    [anon_sym_EQ_EQ] = ACTIONS(4140),
    [anon_sym_BANG_EQ] = ACTIONS(4140),
    [anon_sym_GT_EQ] = ACTIONS(4140),
    [anon_sym_LT_EQ] = ACTIONS(4140),
    [anon_sym_DOT] = ACTIONS(4138),
    [anon_sym_scoped] = ACTIONS(4138),
    [anon_sym_EQ_GT] = ACTIONS(4140),
    [anon_sym_var] = ACTIONS(4138),
    [anon_sym_yield] = ACTIONS(4138),
    [anon_sym_switch] = ACTIONS(4138),
    [anon_sym_when] = ACTIONS(4138),
    [sym_discard] = ACTIONS(4138),
    [anon_sym_DOT_DOT] = ACTIONS(4140),
    [anon_sym_and] = ACTIONS(4138),
    [anon_sym_or] = ACTIONS(4138),
    [anon_sym_PLUS_EQ] = ACTIONS(4140),
    [anon_sym_DASH_EQ] = ACTIONS(4140),
    [anon_sym_STAR_EQ] = ACTIONS(4140),
    [anon_sym_SLASH_EQ] = ACTIONS(4140),
    [anon_sym_PERCENT_EQ] = ACTIONS(4140),
    [anon_sym_AMP_EQ] = ACTIONS(4140),
    [anon_sym_CARET_EQ] = ACTIONS(4140),
    [anon_sym_PIPE_EQ] = ACTIONS(4140),
    [anon_sym_LT_LT_EQ] = ACTIONS(4140),
    [anon_sym_GT_GT_EQ] = ACTIONS(4140),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4140),
    [anon_sym_AMP_AMP] = ACTIONS(4140),
    [anon_sym_PIPE_PIPE] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK] = ACTIONS(4138),
    [anon_sym_from] = ACTIONS(4138),
    [anon_sym_into] = ACTIONS(4138),
    [anon_sym_join] = ACTIONS(4138),
    [anon_sym_on] = ACTIONS(4138),
    [anon_sym_equals] = ACTIONS(4138),
    [anon_sym_let] = ACTIONS(4138),
    [anon_sym_orderby] = ACTIONS(4138),
    [anon_sym_ascending] = ACTIONS(4138),
    [anon_sym_descending] = ACTIONS(4138),
    [anon_sym_group] = ACTIONS(4138),
    [anon_sym_by] = ACTIONS(4138),
    [anon_sym_select] = ACTIONS(4138),
    [anon_sym_as] = ACTIONS(4138),
    [anon_sym_is] = ACTIONS(4138),
    [anon_sym_DASH_GT] = ACTIONS(4140),
    [anon_sym_with] = ACTIONS(4138),
    [aux_sym_preproc_if_token3] = ACTIONS(4140),
    [aux_sym_preproc_else_token1] = ACTIONS(4140),
    [aux_sym_preproc_elif_token1] = ACTIONS(4140),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2754] = {
    [sym_preproc_region] = STATE(2754),
    [sym_preproc_endregion] = STATE(2754),
    [sym_preproc_line] = STATE(2754),
    [sym_preproc_pragma] = STATE(2754),
    [sym_preproc_nullable] = STATE(2754),
    [sym_preproc_error] = STATE(2754),
    [sym_preproc_warning] = STATE(2754),
    [sym_preproc_define] = STATE(2754),
    [sym_preproc_undef] = STATE(2754),
    [sym__identifier_token] = ACTIONS(4091),
    [anon_sym_alias] = ACTIONS(4091),
    [anon_sym_SEMI] = ACTIONS(4088),
    [anon_sym_global] = ACTIONS(4091),
    [anon_sym_EQ] = ACTIONS(3995),
    [anon_sym_LBRACK] = ACTIONS(4088),
    [anon_sym_COLON] = ACTIONS(4091),
    [anon_sym_COMMA] = ACTIONS(4088),
    [anon_sym_RBRACK] = ACTIONS(4088),
    [anon_sym_LPAREN] = ACTIONS(4088),
    [anon_sym_RPAREN] = ACTIONS(4088),
    [anon_sym_LBRACE] = ACTIONS(4088),
    [anon_sym_RBRACE] = ACTIONS(4088),
    [anon_sym_file] = ACTIONS(4091),
    [anon_sym_LT] = ACTIONS(4091),
    [anon_sym_GT] = ACTIONS(4091),
    [anon_sym_in] = ACTIONS(4091),
    [anon_sym_where] = ACTIONS(4091),
    [anon_sym_QMARK] = ACTIONS(4091),
    [anon_sym_notnull] = ACTIONS(4091),
    [anon_sym_unmanaged] = ACTIONS(4091),
    [anon_sym_BANG] = ACTIONS(4091),
    [anon_sym_PLUS_PLUS] = ACTIONS(4088),
    [anon_sym_DASH_DASH] = ACTIONS(4088),
    [anon_sym_PLUS] = ACTIONS(4091),
    [anon_sym_DASH] = ACTIONS(4091),
    [anon_sym_STAR] = ACTIONS(4091),
    [anon_sym_SLASH] = ACTIONS(4091),
    [anon_sym_PERCENT] = ACTIONS(4091),
    [anon_sym_CARET] = ACTIONS(4091),
    [anon_sym_PIPE] = ACTIONS(4091),
    [anon_sym_AMP] = ACTIONS(4091),
    [anon_sym_LT_LT] = ACTIONS(4091),
    [anon_sym_GT_GT] = ACTIONS(4091),
    [anon_sym_GT_GT_GT] = ACTIONS(4091),
    [anon_sym_EQ_EQ] = ACTIONS(4088),
    [anon_sym_BANG_EQ] = ACTIONS(4088),
    [anon_sym_GT_EQ] = ACTIONS(4088),
    [anon_sym_LT_EQ] = ACTIONS(4088),
    [anon_sym_DOT] = ACTIONS(4091),
    [anon_sym_scoped] = ACTIONS(4091),
    [anon_sym_EQ_GT] = ACTIONS(3993),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(4091),
    [anon_sym_yield] = ACTIONS(4091),
    [anon_sym_switch] = ACTIONS(4091),
    [anon_sym_when] = ACTIONS(4091),
    [sym_discard] = ACTIONS(4091),
    [anon_sym_DOT_DOT] = ACTIONS(4088),
    [anon_sym_and] = ACTIONS(4091),
    [anon_sym_or] = ACTIONS(4091),
    [anon_sym_PLUS_EQ] = ACTIONS(3993),
    [anon_sym_DASH_EQ] = ACTIONS(3993),
    [anon_sym_STAR_EQ] = ACTIONS(3993),
    [anon_sym_SLASH_EQ] = ACTIONS(3993),
    [anon_sym_PERCENT_EQ] = ACTIONS(3993),
    [anon_sym_AMP_EQ] = ACTIONS(3993),
    [anon_sym_CARET_EQ] = ACTIONS(3993),
    [anon_sym_PIPE_EQ] = ACTIONS(3993),
    [anon_sym_LT_LT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(3993),
    [anon_sym_AMP_AMP] = ACTIONS(4088),
    [anon_sym_PIPE_PIPE] = ACTIONS(4088),
    [anon_sym_QMARK_QMARK] = ACTIONS(4091),
    [anon_sym_from] = ACTIONS(4091),
    [anon_sym_into] = ACTIONS(4091),
    [anon_sym_join] = ACTIONS(4091),
    [anon_sym_on] = ACTIONS(4091),
    [anon_sym_equals] = ACTIONS(4091),
    [anon_sym_let] = ACTIONS(4091),
    [anon_sym_orderby] = ACTIONS(4091),
    [anon_sym_ascending] = ACTIONS(4091),
    [anon_sym_descending] = ACTIONS(4091),
    [anon_sym_group] = ACTIONS(4091),
    [anon_sym_by] = ACTIONS(4091),
    [anon_sym_select] = ACTIONS(4091),
    [anon_sym_as] = ACTIONS(4091),
    [anon_sym_is] = ACTIONS(4091),
    [anon_sym_DASH_GT] = ACTIONS(4088),
    [anon_sym_with] = ACTIONS(4091),
    [aux_sym_preproc_if_token3] = ACTIONS(4088),
    [aux_sym_preproc_else_token1] = ACTIONS(4088),
    [aux_sym_preproc_elif_token1] = ACTIONS(4088),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2755] = {
    [sym_type_argument_list] = STATE(2746),
    [sym_preproc_region] = STATE(2755),
    [sym_preproc_endregion] = STATE(2755),
    [sym_preproc_line] = STATE(2755),
    [sym_preproc_pragma] = STATE(2755),
    [sym_preproc_nullable] = STATE(2755),
    [sym_preproc_error] = STATE(2755),
    [sym_preproc_warning] = STATE(2755),
    [sym_preproc_define] = STATE(2755),
    [sym_preproc_undef] = STATE(2755),
    [sym__identifier_token] = ACTIONS(4138),
    [anon_sym_alias] = ACTIONS(4138),
    [anon_sym_SEMI] = ACTIONS(4140),
    [anon_sym_global] = ACTIONS(4138),
    [anon_sym_EQ] = ACTIONS(4138),
    [anon_sym_LBRACK] = ACTIONS(4140),
    [anon_sym_COMMA] = ACTIONS(4140),
    [anon_sym_RBRACK] = ACTIONS(4140),
    [anon_sym_LPAREN] = ACTIONS(4140),
    [anon_sym_RPAREN] = ACTIONS(4140),
    [anon_sym_LBRACE] = ACTIONS(4140),
    [anon_sym_RBRACE] = ACTIONS(4140),
    [anon_sym_file] = ACTIONS(4138),
    [anon_sym_LT] = ACTIONS(4142),
    [anon_sym_GT] = ACTIONS(4138),
    [anon_sym_in] = ACTIONS(4138),
    [anon_sym_where] = ACTIONS(4138),
    [anon_sym_QMARK] = ACTIONS(4138),
    [anon_sym_notnull] = ACTIONS(4138),
    [anon_sym_unmanaged] = ACTIONS(4138),
    [anon_sym_BANG] = ACTIONS(4138),
    [anon_sym_PLUS_PLUS] = ACTIONS(4140),
    [anon_sym_DASH_DASH] = ACTIONS(4140),
    [anon_sym_PLUS] = ACTIONS(4138),
    [anon_sym_DASH] = ACTIONS(4138),
    [anon_sym_STAR] = ACTIONS(4138),
    [anon_sym_SLASH] = ACTIONS(4138),
    [anon_sym_PERCENT] = ACTIONS(4138),
    [anon_sym_CARET] = ACTIONS(4138),
    [anon_sym_PIPE] = ACTIONS(4138),
    [anon_sym_AMP] = ACTIONS(4138),
    [anon_sym_LT_LT] = ACTIONS(4138),
    [anon_sym_GT_GT] = ACTIONS(4138),
    [anon_sym_GT_GT_GT] = ACTIONS(4138),
    [anon_sym_EQ_EQ] = ACTIONS(4140),
    [anon_sym_BANG_EQ] = ACTIONS(4140),
    [anon_sym_GT_EQ] = ACTIONS(4140),
    [anon_sym_LT_EQ] = ACTIONS(4140),
    [anon_sym_DOT] = ACTIONS(4138),
    [anon_sym_scoped] = ACTIONS(4138),
    [anon_sym_EQ_GT] = ACTIONS(4145),
    [anon_sym_COLON_COLON] = ACTIONS(4155),
    [anon_sym_var] = ACTIONS(4138),
    [anon_sym_yield] = ACTIONS(4138),
    [anon_sym_switch] = ACTIONS(4138),
    [anon_sym_when] = ACTIONS(4138),
    [sym_discard] = ACTIONS(4138),
    [anon_sym_DOT_DOT] = ACTIONS(4140),
    [anon_sym_and] = ACTIONS(4138),
    [anon_sym_or] = ACTIONS(4138),
    [anon_sym_PLUS_EQ] = ACTIONS(4140),
    [anon_sym_DASH_EQ] = ACTIONS(4140),
    [anon_sym_STAR_EQ] = ACTIONS(4140),
    [anon_sym_SLASH_EQ] = ACTIONS(4140),
    [anon_sym_PERCENT_EQ] = ACTIONS(4140),
    [anon_sym_AMP_EQ] = ACTIONS(4140),
    [anon_sym_CARET_EQ] = ACTIONS(4140),
    [anon_sym_PIPE_EQ] = ACTIONS(4140),
    [anon_sym_LT_LT_EQ] = ACTIONS(4140),
    [anon_sym_GT_GT_EQ] = ACTIONS(4140),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4140),
    [anon_sym_AMP_AMP] = ACTIONS(4140),
    [anon_sym_PIPE_PIPE] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK] = ACTIONS(4138),
    [anon_sym_from] = ACTIONS(4138),
    [anon_sym_into] = ACTIONS(4138),
    [anon_sym_join] = ACTIONS(4138),
    [anon_sym_on] = ACTIONS(4138),
    [anon_sym_equals] = ACTIONS(4138),
    [anon_sym_let] = ACTIONS(4138),
    [anon_sym_orderby] = ACTIONS(4138),
    [anon_sym_ascending] = ACTIONS(4138),
    [anon_sym_descending] = ACTIONS(4138),
    [anon_sym_group] = ACTIONS(4138),
    [anon_sym_by] = ACTIONS(4138),
    [anon_sym_select] = ACTIONS(4138),
    [anon_sym_as] = ACTIONS(4138),
    [anon_sym_is] = ACTIONS(4138),
    [anon_sym_DASH_GT] = ACTIONS(4140),
    [anon_sym_with] = ACTIONS(4138),
    [aux_sym_preproc_if_token3] = ACTIONS(4140),
    [aux_sym_preproc_else_token1] = ACTIONS(4140),
    [aux_sym_preproc_elif_token1] = ACTIONS(4140),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2756] = {
    [sym_preproc_region] = STATE(2756),
    [sym_preproc_endregion] = STATE(2756),
    [sym_preproc_line] = STATE(2756),
    [sym_preproc_pragma] = STATE(2756),
    [sym_preproc_nullable] = STATE(2756),
    [sym_preproc_error] = STATE(2756),
    [sym_preproc_warning] = STATE(2756),
    [sym_preproc_define] = STATE(2756),
    [sym_preproc_undef] = STATE(2756),
    [sym__identifier_token] = ACTIONS(4157),
    [anon_sym_alias] = ACTIONS(4157),
    [anon_sym_SEMI] = ACTIONS(4159),
    [anon_sym_global] = ACTIONS(4157),
    [anon_sym_EQ] = ACTIONS(4162),
    [anon_sym_LBRACK] = ACTIONS(4164),
    [anon_sym_COLON] = ACTIONS(4159),
    [anon_sym_COMMA] = ACTIONS(4159),
    [anon_sym_RBRACK] = ACTIONS(4159),
    [anon_sym_LPAREN] = ACTIONS(4164),
    [anon_sym_RPAREN] = ACTIONS(4159),
    [anon_sym_LBRACE] = ACTIONS(4168),
    [anon_sym_RBRACE] = ACTIONS(4159),
    [anon_sym_file] = ACTIONS(4157),
    [anon_sym_LT] = ACTIONS(4170),
    [anon_sym_GT] = ACTIONS(4170),
    [anon_sym_in] = ACTIONS(4174),
    [anon_sym_where] = ACTIONS(4157),
    [anon_sym_QMARK] = ACTIONS(4170),
    [anon_sym_notnull] = ACTIONS(4157),
    [anon_sym_unmanaged] = ACTIONS(4157),
    [anon_sym_BANG] = ACTIONS(4170),
    [anon_sym_PLUS_PLUS] = ACTIONS(4164),
    [anon_sym_DASH_DASH] = ACTIONS(4164),
    [anon_sym_PLUS] = ACTIONS(4170),
    [anon_sym_DASH] = ACTIONS(4170),
    [anon_sym_STAR] = ACTIONS(4170),
    [anon_sym_SLASH] = ACTIONS(4170),
    [anon_sym_PERCENT] = ACTIONS(4170),
    [anon_sym_CARET] = ACTIONS(4170),
    [anon_sym_PIPE] = ACTIONS(4170),
    [anon_sym_AMP] = ACTIONS(4170),
    [anon_sym_LT_LT] = ACTIONS(4170),
    [anon_sym_GT_GT] = ACTIONS(4170),
    [anon_sym_GT_GT_GT] = ACTIONS(4170),
    [anon_sym_EQ_EQ] = ACTIONS(4164),
    [anon_sym_BANG_EQ] = ACTIONS(4164),
    [anon_sym_GT_EQ] = ACTIONS(4164),
    [anon_sym_LT_EQ] = ACTIONS(4164),
    [anon_sym_DOT] = ACTIONS(4170),
    [anon_sym_scoped] = ACTIONS(4157),
    [anon_sym_EQ_GT] = ACTIONS(4159),
    [anon_sym_var] = ACTIONS(4157),
    [anon_sym_yield] = ACTIONS(4157),
    [anon_sym_switch] = ACTIONS(4170),
    [anon_sym_when] = ACTIONS(4157),
    [sym_discard] = ACTIONS(4157),
    [anon_sym_DOT_DOT] = ACTIONS(4164),
    [anon_sym_and] = ACTIONS(4174),
    [anon_sym_or] = ACTIONS(4174),
    [anon_sym_PLUS_EQ] = ACTIONS(4177),
    [anon_sym_DASH_EQ] = ACTIONS(4177),
    [anon_sym_STAR_EQ] = ACTIONS(4177),
    [anon_sym_SLASH_EQ] = ACTIONS(4177),
    [anon_sym_PERCENT_EQ] = ACTIONS(4177),
    [anon_sym_AMP_EQ] = ACTIONS(4177),
    [anon_sym_CARET_EQ] = ACTIONS(4177),
    [anon_sym_PIPE_EQ] = ACTIONS(4177),
    [anon_sym_LT_LT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4177),
    [anon_sym_AMP_AMP] = ACTIONS(4164),
    [anon_sym_PIPE_PIPE] = ACTIONS(4164),
    [anon_sym_QMARK_QMARK] = ACTIONS(4170),
    [anon_sym_from] = ACTIONS(4157),
    [anon_sym_into] = ACTIONS(4157),
    [anon_sym_join] = ACTIONS(4157),
    [anon_sym_on] = ACTIONS(4157),
    [anon_sym_equals] = ACTIONS(4157),
    [anon_sym_let] = ACTIONS(4157),
    [anon_sym_orderby] = ACTIONS(4157),
    [anon_sym_ascending] = ACTIONS(4157),
    [anon_sym_descending] = ACTIONS(4157),
    [anon_sym_group] = ACTIONS(4157),
    [anon_sym_by] = ACTIONS(4157),
    [anon_sym_select] = ACTIONS(4157),
    [anon_sym_as] = ACTIONS(4170),
    [anon_sym_is] = ACTIONS(4170),
    [anon_sym_DASH_GT] = ACTIONS(4164),
    [anon_sym_with] = ACTIONS(4170),
    [aux_sym_preproc_if_token3] = ACTIONS(4159),
    [aux_sym_preproc_else_token1] = ACTIONS(4159),
    [aux_sym_preproc_elif_token1] = ACTIONS(4159),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2757] = {
    [sym_preproc_region] = STATE(2757),
    [sym_preproc_endregion] = STATE(2757),
    [sym_preproc_line] = STATE(2757),
    [sym_preproc_pragma] = STATE(2757),
    [sym_preproc_nullable] = STATE(2757),
    [sym_preproc_error] = STATE(2757),
    [sym_preproc_warning] = STATE(2757),
    [sym_preproc_define] = STATE(2757),
    [sym_preproc_undef] = STATE(2757),
    [sym__identifier_token] = ACTIONS(4179),
    [anon_sym_alias] = ACTIONS(4179),
    [anon_sym_SEMI] = ACTIONS(4181),
    [anon_sym_global] = ACTIONS(4179),
    [anon_sym_EQ] = ACTIONS(4183),
    [anon_sym_LBRACK] = ACTIONS(4185),
    [anon_sym_COLON] = ACTIONS(4181),
    [anon_sym_COMMA] = ACTIONS(4181),
    [anon_sym_RBRACK] = ACTIONS(4181),
    [anon_sym_LPAREN] = ACTIONS(4185),
    [anon_sym_RPAREN] = ACTIONS(4181),
    [anon_sym_LBRACE] = ACTIONS(4181),
    [anon_sym_RBRACE] = ACTIONS(4181),
    [anon_sym_file] = ACTIONS(4179),
    [anon_sym_LT] = ACTIONS(4188),
    [anon_sym_GT] = ACTIONS(4188),
    [anon_sym_in] = ACTIONS(4179),
    [anon_sym_where] = ACTIONS(4179),
    [anon_sym_QMARK] = ACTIONS(4188),
    [anon_sym_notnull] = ACTIONS(4179),
    [anon_sym_unmanaged] = ACTIONS(4179),
    [anon_sym_BANG] = ACTIONS(4188),
    [anon_sym_PLUS_PLUS] = ACTIONS(4185),
    [anon_sym_DASH_DASH] = ACTIONS(4185),
    [anon_sym_PLUS] = ACTIONS(4188),
    [anon_sym_DASH] = ACTIONS(4188),
    [anon_sym_STAR] = ACTIONS(4188),
    [anon_sym_SLASH] = ACTIONS(4188),
    [anon_sym_PERCENT] = ACTIONS(4188),
    [anon_sym_CARET] = ACTIONS(4188),
    [anon_sym_PIPE] = ACTIONS(4188),
    [anon_sym_AMP] = ACTIONS(4188),
    [anon_sym_LT_LT] = ACTIONS(4188),
    [anon_sym_GT_GT] = ACTIONS(4188),
    [anon_sym_GT_GT_GT] = ACTIONS(4188),
    [anon_sym_EQ_EQ] = ACTIONS(4185),
    [anon_sym_BANG_EQ] = ACTIONS(4185),
    [anon_sym_GT_EQ] = ACTIONS(4185),
    [anon_sym_LT_EQ] = ACTIONS(4185),
    [anon_sym_DOT] = ACTIONS(4188),
    [anon_sym_scoped] = ACTIONS(4179),
    [anon_sym_EQ_GT] = ACTIONS(4181),
    [anon_sym_var] = ACTIONS(4179),
    [anon_sym_yield] = ACTIONS(4179),
    [anon_sym_switch] = ACTIONS(4188),
    [anon_sym_when] = ACTIONS(4179),
    [sym_discard] = ACTIONS(4179),
    [anon_sym_DOT_DOT] = ACTIONS(4185),
    [anon_sym_and] = ACTIONS(4179),
    [anon_sym_or] = ACTIONS(4179),
    [anon_sym_PLUS_EQ] = ACTIONS(4191),
    [anon_sym_DASH_EQ] = ACTIONS(4191),
    [anon_sym_STAR_EQ] = ACTIONS(4191),
    [anon_sym_SLASH_EQ] = ACTIONS(4191),
    [anon_sym_PERCENT_EQ] = ACTIONS(4191),
    [anon_sym_AMP_EQ] = ACTIONS(4191),
    [anon_sym_CARET_EQ] = ACTIONS(4191),
    [anon_sym_PIPE_EQ] = ACTIONS(4191),
    [anon_sym_LT_LT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4191),
    [anon_sym_AMP_AMP] = ACTIONS(4185),
    [anon_sym_PIPE_PIPE] = ACTIONS(4185),
    [anon_sym_QMARK_QMARK] = ACTIONS(4188),
    [anon_sym_from] = ACTIONS(4179),
    [anon_sym_into] = ACTIONS(4179),
    [anon_sym_join] = ACTIONS(4179),
    [anon_sym_on] = ACTIONS(4179),
    [anon_sym_equals] = ACTIONS(4179),
    [anon_sym_let] = ACTIONS(4179),
    [anon_sym_orderby] = ACTIONS(4179),
    [anon_sym_ascending] = ACTIONS(4179),
    [anon_sym_descending] = ACTIONS(4179),
    [anon_sym_group] = ACTIONS(4179),
    [anon_sym_by] = ACTIONS(4179),
    [anon_sym_select] = ACTIONS(4179),
    [anon_sym_as] = ACTIONS(4188),
    [anon_sym_is] = ACTIONS(4188),
    [anon_sym_DASH_GT] = ACTIONS(4185),
    [anon_sym_with] = ACTIONS(4188),
    [aux_sym_preproc_if_token3] = ACTIONS(4181),
    [aux_sym_preproc_else_token1] = ACTIONS(4181),
    [aux_sym_preproc_elif_token1] = ACTIONS(4181),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2758] = {
    [sym_preproc_region] = STATE(2758),
    [sym_preproc_endregion] = STATE(2758),
    [sym_preproc_line] = STATE(2758),
    [sym_preproc_pragma] = STATE(2758),
    [sym_preproc_nullable] = STATE(2758),
    [sym_preproc_error] = STATE(2758),
    [sym_preproc_warning] = STATE(2758),
    [sym_preproc_define] = STATE(2758),
    [sym_preproc_undef] = STATE(2758),
    [sym__identifier_token] = ACTIONS(4179),
    [anon_sym_alias] = ACTIONS(4179),
    [anon_sym_SEMI] = ACTIONS(4191),
    [anon_sym_global] = ACTIONS(4179),
    [anon_sym_EQ] = ACTIONS(4183),
    [anon_sym_LBRACK] = ACTIONS(4185),
    [anon_sym_COLON] = ACTIONS(4191),
    [anon_sym_COMMA] = ACTIONS(4185),
    [anon_sym_RBRACK] = ACTIONS(4185),
    [anon_sym_LPAREN] = ACTIONS(4185),
    [anon_sym_RPAREN] = ACTIONS(4185),
    [anon_sym_LBRACE] = ACTIONS(4181),
    [anon_sym_RBRACE] = ACTIONS(4185),
    [anon_sym_file] = ACTIONS(4179),
    [anon_sym_LT] = ACTIONS(4183),
    [anon_sym_GT] = ACTIONS(4183),
    [anon_sym_in] = ACTIONS(4183),
    [anon_sym_where] = ACTIONS(4179),
    [anon_sym_QMARK] = ACTIONS(4188),
    [anon_sym_notnull] = ACTIONS(4179),
    [anon_sym_unmanaged] = ACTIONS(4179),
    [anon_sym_BANG] = ACTIONS(4183),
    [anon_sym_PLUS_PLUS] = ACTIONS(4191),
    [anon_sym_DASH_DASH] = ACTIONS(4191),
    [anon_sym_PLUS] = ACTIONS(4183),
    [anon_sym_DASH] = ACTIONS(4183),
    [anon_sym_STAR] = ACTIONS(4188),
    [anon_sym_SLASH] = ACTIONS(4183),
    [anon_sym_PERCENT] = ACTIONS(4183),
    [anon_sym_CARET] = ACTIONS(4183),
    [anon_sym_PIPE] = ACTIONS(4183),
    [anon_sym_AMP] = ACTIONS(4183),
    [anon_sym_LT_LT] = ACTIONS(4183),
    [anon_sym_GT_GT] = ACTIONS(4183),
    [anon_sym_GT_GT_GT] = ACTIONS(4183),
    [anon_sym_EQ_EQ] = ACTIONS(4191),
    [anon_sym_BANG_EQ] = ACTIONS(4191),
    [anon_sym_GT_EQ] = ACTIONS(4191),
    [anon_sym_LT_EQ] = ACTIONS(4191),
    [anon_sym_DOT] = ACTIONS(4188),
    [anon_sym_scoped] = ACTIONS(4179),
    [anon_sym_EQ_GT] = ACTIONS(4191),
    [anon_sym_var] = ACTIONS(4179),
    [anon_sym_yield] = ACTIONS(4179),
    [anon_sym_switch] = ACTIONS(4183),
    [anon_sym_when] = ACTIONS(4179),
    [sym_discard] = ACTIONS(4179),
    [anon_sym_DOT_DOT] = ACTIONS(4191),
    [anon_sym_and] = ACTIONS(4188),
    [anon_sym_or] = ACTIONS(4188),
    [anon_sym_PLUS_EQ] = ACTIONS(4191),
    [anon_sym_DASH_EQ] = ACTIONS(4191),
    [anon_sym_STAR_EQ] = ACTIONS(4191),
    [anon_sym_SLASH_EQ] = ACTIONS(4191),
    [anon_sym_PERCENT_EQ] = ACTIONS(4191),
    [anon_sym_AMP_EQ] = ACTIONS(4191),
    [anon_sym_CARET_EQ] = ACTIONS(4191),
    [anon_sym_PIPE_EQ] = ACTIONS(4191),
    [anon_sym_LT_LT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4191),
    [anon_sym_AMP_AMP] = ACTIONS(4191),
    [anon_sym_PIPE_PIPE] = ACTIONS(4191),
    [anon_sym_QMARK_QMARK] = ACTIONS(4183),
    [anon_sym_from] = ACTIONS(4179),
    [anon_sym_into] = ACTIONS(4179),
    [anon_sym_join] = ACTIONS(4179),
    [anon_sym_on] = ACTIONS(4179),
    [anon_sym_equals] = ACTIONS(4179),
    [anon_sym_let] = ACTIONS(4179),
    [anon_sym_orderby] = ACTIONS(4179),
    [anon_sym_ascending] = ACTIONS(4179),
    [anon_sym_descending] = ACTIONS(4179),
    [anon_sym_group] = ACTIONS(4179),
    [anon_sym_by] = ACTIONS(4179),
    [anon_sym_select] = ACTIONS(4179),
    [anon_sym_as] = ACTIONS(4183),
    [anon_sym_is] = ACTIONS(4183),
    [anon_sym_DASH_GT] = ACTIONS(4185),
    [anon_sym_with] = ACTIONS(4183),
    [aux_sym_preproc_if_token3] = ACTIONS(4191),
    [aux_sym_preproc_else_token1] = ACTIONS(4191),
    [aux_sym_preproc_elif_token1] = ACTIONS(4191),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2759] = {
    [sym_preproc_region] = STATE(2759),
    [sym_preproc_endregion] = STATE(2759),
    [sym_preproc_line] = STATE(2759),
    [sym_preproc_pragma] = STATE(2759),
    [sym_preproc_nullable] = STATE(2759),
    [sym_preproc_error] = STATE(2759),
    [sym_preproc_warning] = STATE(2759),
    [sym_preproc_define] = STATE(2759),
    [sym_preproc_undef] = STATE(2759),
    [sym__identifier_token] = ACTIONS(4179),
    [anon_sym_alias] = ACTIONS(4179),
    [anon_sym_SEMI] = ACTIONS(4185),
    [anon_sym_global] = ACTIONS(4179),
    [anon_sym_EQ] = ACTIONS(4183),
    [anon_sym_LBRACK] = ACTIONS(4185),
    [anon_sym_COLON] = ACTIONS(4185),
    [anon_sym_COMMA] = ACTIONS(4185),
    [anon_sym_RBRACK] = ACTIONS(4185),
    [anon_sym_LPAREN] = ACTIONS(4185),
    [anon_sym_RPAREN] = ACTIONS(4185),
    [anon_sym_LBRACE] = ACTIONS(4181),
    [anon_sym_RBRACE] = ACTIONS(4185),
    [anon_sym_file] = ACTIONS(4179),
    [anon_sym_LT] = ACTIONS(4188),
    [anon_sym_GT] = ACTIONS(4188),
    [anon_sym_in] = ACTIONS(4188),
    [anon_sym_where] = ACTIONS(4179),
    [anon_sym_QMARK] = ACTIONS(4188),
    [anon_sym_notnull] = ACTIONS(4179),
    [anon_sym_unmanaged] = ACTIONS(4179),
    [anon_sym_BANG] = ACTIONS(4188),
    [anon_sym_PLUS_PLUS] = ACTIONS(4185),
    [anon_sym_DASH_DASH] = ACTIONS(4185),
    [anon_sym_PLUS] = ACTIONS(4188),
    [anon_sym_DASH] = ACTIONS(4188),
    [anon_sym_STAR] = ACTIONS(4188),
    [anon_sym_SLASH] = ACTIONS(4188),
    [anon_sym_PERCENT] = ACTIONS(4188),
    [anon_sym_CARET] = ACTIONS(4188),
    [anon_sym_PIPE] = ACTIONS(4188),
    [anon_sym_AMP] = ACTIONS(4188),
    [anon_sym_LT_LT] = ACTIONS(4188),
    [anon_sym_GT_GT] = ACTIONS(4188),
    [anon_sym_GT_GT_GT] = ACTIONS(4188),
    [anon_sym_EQ_EQ] = ACTIONS(4185),
    [anon_sym_BANG_EQ] = ACTIONS(4185),
    [anon_sym_GT_EQ] = ACTIONS(4185),
    [anon_sym_LT_EQ] = ACTIONS(4185),
    [anon_sym_DOT] = ACTIONS(4188),
    [anon_sym_scoped] = ACTIONS(4179),
    [anon_sym_EQ_GT] = ACTIONS(4185),
    [anon_sym_var] = ACTIONS(4179),
    [anon_sym_yield] = ACTIONS(4179),
    [anon_sym_switch] = ACTIONS(4188),
    [anon_sym_when] = ACTIONS(4179),
    [sym_discard] = ACTIONS(4179),
    [anon_sym_DOT_DOT] = ACTIONS(4185),
    [anon_sym_and] = ACTIONS(4188),
    [anon_sym_or] = ACTIONS(4188),
    [anon_sym_PLUS_EQ] = ACTIONS(4191),
    [anon_sym_DASH_EQ] = ACTIONS(4191),
    [anon_sym_STAR_EQ] = ACTIONS(4191),
    [anon_sym_SLASH_EQ] = ACTIONS(4191),
    [anon_sym_PERCENT_EQ] = ACTIONS(4191),
    [anon_sym_AMP_EQ] = ACTIONS(4191),
    [anon_sym_CARET_EQ] = ACTIONS(4191),
    [anon_sym_PIPE_EQ] = ACTIONS(4191),
    [anon_sym_LT_LT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4191),
    [anon_sym_AMP_AMP] = ACTIONS(4185),
    [anon_sym_PIPE_PIPE] = ACTIONS(4185),
    [anon_sym_QMARK_QMARK] = ACTIONS(4188),
    [anon_sym_from] = ACTIONS(4179),
    [anon_sym_into] = ACTIONS(4179),
    [anon_sym_join] = ACTIONS(4179),
    [anon_sym_on] = ACTIONS(4179),
    [anon_sym_equals] = ACTIONS(4179),
    [anon_sym_let] = ACTIONS(4179),
    [anon_sym_orderby] = ACTIONS(4179),
    [anon_sym_ascending] = ACTIONS(4179),
    [anon_sym_descending] = ACTIONS(4179),
    [anon_sym_group] = ACTIONS(4179),
    [anon_sym_by] = ACTIONS(4179),
    [anon_sym_select] = ACTIONS(4179),
    [anon_sym_as] = ACTIONS(4188),
    [anon_sym_is] = ACTIONS(4188),
    [anon_sym_DASH_GT] = ACTIONS(4185),
    [anon_sym_with] = ACTIONS(4188),
    [aux_sym_preproc_if_token3] = ACTIONS(4185),
    [aux_sym_preproc_else_token1] = ACTIONS(4185),
    [aux_sym_preproc_elif_token1] = ACTIONS(4185),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2760] = {
    [sym_preproc_region] = STATE(2760),
    [sym_preproc_endregion] = STATE(2760),
    [sym_preproc_line] = STATE(2760),
    [sym_preproc_pragma] = STATE(2760),
    [sym_preproc_nullable] = STATE(2760),
    [sym_preproc_error] = STATE(2760),
    [sym_preproc_warning] = STATE(2760),
    [sym_preproc_define] = STATE(2760),
    [sym_preproc_undef] = STATE(2760),
    [sym__identifier_token] = ACTIONS(4157),
    [anon_sym_alias] = ACTIONS(4157),
    [anon_sym_SEMI] = ACTIONS(4168),
    [anon_sym_global] = ACTIONS(4157),
    [anon_sym_EQ] = ACTIONS(4162),
    [anon_sym_LBRACK] = ACTIONS(4193),
    [anon_sym_COLON] = ACTIONS(4168),
    [anon_sym_COMMA] = ACTIONS(4168),
    [anon_sym_RBRACK] = ACTIONS(4168),
    [anon_sym_LPAREN] = ACTIONS(4193),
    [anon_sym_RPAREN] = ACTIONS(4168),
    [anon_sym_LBRACE] = ACTIONS(4168),
    [anon_sym_RBRACE] = ACTIONS(4168),
    [anon_sym_file] = ACTIONS(4157),
    [anon_sym_LT] = ACTIONS(4196),
    [anon_sym_GT] = ACTIONS(4196),
    [anon_sym_in] = ACTIONS(4157),
    [anon_sym_where] = ACTIONS(4157),
    [anon_sym_QMARK] = ACTIONS(4196),
    [anon_sym_notnull] = ACTIONS(4157),
    [anon_sym_unmanaged] = ACTIONS(4157),
    [anon_sym_BANG] = ACTIONS(4196),
    [anon_sym_PLUS_PLUS] = ACTIONS(4193),
    [anon_sym_DASH_DASH] = ACTIONS(4193),
    [anon_sym_PLUS] = ACTIONS(4196),
    [anon_sym_DASH] = ACTIONS(4196),
    [anon_sym_STAR] = ACTIONS(4196),
    [anon_sym_SLASH] = ACTIONS(4196),
    [anon_sym_PERCENT] = ACTIONS(4196),
    [anon_sym_CARET] = ACTIONS(4196),
    [anon_sym_PIPE] = ACTIONS(4196),
    [anon_sym_AMP] = ACTIONS(4196),
    [anon_sym_LT_LT] = ACTIONS(4196),
    [anon_sym_GT_GT] = ACTIONS(4196),
    [anon_sym_GT_GT_GT] = ACTIONS(4196),
    [anon_sym_EQ_EQ] = ACTIONS(4193),
    [anon_sym_BANG_EQ] = ACTIONS(4193),
    [anon_sym_GT_EQ] = ACTIONS(4193),
    [anon_sym_LT_EQ] = ACTIONS(4193),
    [anon_sym_DOT] = ACTIONS(4196),
    [anon_sym_scoped] = ACTIONS(4157),
    [anon_sym_EQ_GT] = ACTIONS(4168),
    [anon_sym_var] = ACTIONS(4157),
    [anon_sym_yield] = ACTIONS(4157),
    [anon_sym_switch] = ACTIONS(4196),
    [anon_sym_when] = ACTIONS(4157),
    [sym_discard] = ACTIONS(4157),
    [anon_sym_DOT_DOT] = ACTIONS(4193),
    [anon_sym_and] = ACTIONS(4157),
    [anon_sym_or] = ACTIONS(4157),
    [anon_sym_PLUS_EQ] = ACTIONS(4177),
    [anon_sym_DASH_EQ] = ACTIONS(4177),
    [anon_sym_STAR_EQ] = ACTIONS(4177),
    [anon_sym_SLASH_EQ] = ACTIONS(4177),
    [anon_sym_PERCENT_EQ] = ACTIONS(4177),
    [anon_sym_AMP_EQ] = ACTIONS(4177),
    [anon_sym_CARET_EQ] = ACTIONS(4177),
    [anon_sym_PIPE_EQ] = ACTIONS(4177),
    [anon_sym_LT_LT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4177),
    [anon_sym_AMP_AMP] = ACTIONS(4193),
    [anon_sym_PIPE_PIPE] = ACTIONS(4193),
    [anon_sym_QMARK_QMARK] = ACTIONS(4196),
    [anon_sym_from] = ACTIONS(4157),
    [anon_sym_into] = ACTIONS(4157),
    [anon_sym_join] = ACTIONS(4157),
    [anon_sym_on] = ACTIONS(4157),
    [anon_sym_equals] = ACTIONS(4157),
    [anon_sym_let] = ACTIONS(4157),
    [anon_sym_orderby] = ACTIONS(4157),
    [anon_sym_ascending] = ACTIONS(4157),
    [anon_sym_descending] = ACTIONS(4157),
    [anon_sym_group] = ACTIONS(4157),
    [anon_sym_by] = ACTIONS(4157),
    [anon_sym_select] = ACTIONS(4157),
    [anon_sym_as] = ACTIONS(4196),
    [anon_sym_is] = ACTIONS(4196),
    [anon_sym_DASH_GT] = ACTIONS(4193),
    [anon_sym_with] = ACTIONS(4196),
    [aux_sym_preproc_if_token3] = ACTIONS(4168),
    [aux_sym_preproc_else_token1] = ACTIONS(4168),
    [aux_sym_preproc_elif_token1] = ACTIONS(4168),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2761] = {
    [sym_preproc_region] = STATE(2761),
    [sym_preproc_endregion] = STATE(2761),
    [sym_preproc_line] = STATE(2761),
    [sym_preproc_pragma] = STATE(2761),
    [sym_preproc_nullable] = STATE(2761),
    [sym_preproc_error] = STATE(2761),
    [sym_preproc_warning] = STATE(2761),
    [sym_preproc_define] = STATE(2761),
    [sym_preproc_undef] = STATE(2761),
    [sym__identifier_token] = ACTIONS(4157),
    [anon_sym_alias] = ACTIONS(4157),
    [anon_sym_SEMI] = ACTIONS(4159),
    [anon_sym_global] = ACTIONS(4157),
    [anon_sym_EQ] = ACTIONS(4162),
    [anon_sym_LBRACK] = ACTIONS(4164),
    [anon_sym_COLON] = ACTIONS(4159),
    [anon_sym_COMMA] = ACTIONS(4159),
    [anon_sym_RBRACK] = ACTIONS(4159),
    [anon_sym_LPAREN] = ACTIONS(4164),
    [anon_sym_RPAREN] = ACTIONS(4159),
    [anon_sym_LBRACE] = ACTIONS(4168),
    [anon_sym_RBRACE] = ACTIONS(4159),
    [anon_sym_file] = ACTIONS(4157),
    [anon_sym_LT] = ACTIONS(4170),
    [anon_sym_GT] = ACTIONS(4170),
    [anon_sym_in] = ACTIONS(4174),
    [anon_sym_where] = ACTIONS(4157),
    [anon_sym_QMARK] = ACTIONS(4170),
    [anon_sym_notnull] = ACTIONS(4157),
    [anon_sym_unmanaged] = ACTIONS(4157),
    [anon_sym_BANG] = ACTIONS(4170),
    [anon_sym_PLUS_PLUS] = ACTIONS(4164),
    [anon_sym_DASH_DASH] = ACTIONS(4164),
    [anon_sym_PLUS] = ACTIONS(4170),
    [anon_sym_DASH] = ACTIONS(4170),
    [anon_sym_STAR] = ACTIONS(4170),
    [anon_sym_SLASH] = ACTIONS(4170),
    [anon_sym_PERCENT] = ACTIONS(4170),
    [anon_sym_CARET] = ACTIONS(4170),
    [anon_sym_PIPE] = ACTIONS(4170),
    [anon_sym_AMP] = ACTIONS(4170),
    [anon_sym_LT_LT] = ACTIONS(4170),
    [anon_sym_GT_GT] = ACTIONS(4170),
    [anon_sym_GT_GT_GT] = ACTIONS(4170),
    [anon_sym_EQ_EQ] = ACTIONS(4164),
    [anon_sym_BANG_EQ] = ACTIONS(4164),
    [anon_sym_GT_EQ] = ACTIONS(4164),
    [anon_sym_LT_EQ] = ACTIONS(4164),
    [anon_sym_DOT] = ACTIONS(4170),
    [anon_sym_scoped] = ACTIONS(4157),
    [anon_sym_EQ_GT] = ACTIONS(4159),
    [anon_sym_var] = ACTIONS(4157),
    [anon_sym_yield] = ACTIONS(4157),
    [anon_sym_switch] = ACTIONS(4170),
    [anon_sym_when] = ACTIONS(4157),
    [sym_discard] = ACTIONS(4157),
    [anon_sym_DOT_DOT] = ACTIONS(4164),
    [anon_sym_and] = ACTIONS(4174),
    [anon_sym_or] = ACTIONS(4174),
    [anon_sym_PLUS_EQ] = ACTIONS(4177),
    [anon_sym_DASH_EQ] = ACTIONS(4177),
    [anon_sym_STAR_EQ] = ACTIONS(4177),
    [anon_sym_SLASH_EQ] = ACTIONS(4177),
    [anon_sym_PERCENT_EQ] = ACTIONS(4177),
    [anon_sym_AMP_EQ] = ACTIONS(4177),
    [anon_sym_CARET_EQ] = ACTIONS(4177),
    [anon_sym_PIPE_EQ] = ACTIONS(4177),
    [anon_sym_LT_LT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4177),
    [anon_sym_AMP_AMP] = ACTIONS(4164),
    [anon_sym_PIPE_PIPE] = ACTIONS(4164),
    [anon_sym_QMARK_QMARK] = ACTIONS(4170),
    [anon_sym_from] = ACTIONS(4157),
    [anon_sym_into] = ACTIONS(4174),
    [anon_sym_join] = ACTIONS(4157),
    [anon_sym_on] = ACTIONS(4157),
    [anon_sym_equals] = ACTIONS(4157),
    [anon_sym_let] = ACTIONS(4157),
    [anon_sym_orderby] = ACTIONS(4157),
    [anon_sym_ascending] = ACTIONS(4157),
    [anon_sym_descending] = ACTIONS(4157),
    [anon_sym_group] = ACTIONS(4157),
    [anon_sym_by] = ACTIONS(4157),
    [anon_sym_select] = ACTIONS(4157),
    [anon_sym_as] = ACTIONS(4170),
    [anon_sym_is] = ACTIONS(4170),
    [anon_sym_DASH_GT] = ACTIONS(4164),
    [anon_sym_with] = ACTIONS(4170),
    [aux_sym_preproc_if_token3] = ACTIONS(4159),
    [aux_sym_preproc_else_token1] = ACTIONS(4159),
    [aux_sym_preproc_elif_token1] = ACTIONS(4159),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2762] = {
    [sym_preproc_region] = STATE(2762),
    [sym_preproc_endregion] = STATE(2762),
    [sym_preproc_line] = STATE(2762),
    [sym_preproc_pragma] = STATE(2762),
    [sym_preproc_nullable] = STATE(2762),
    [sym_preproc_error] = STATE(2762),
    [sym_preproc_warning] = STATE(2762),
    [sym_preproc_define] = STATE(2762),
    [sym_preproc_undef] = STATE(2762),
    [sym__identifier_token] = ACTIONS(4179),
    [anon_sym_alias] = ACTIONS(4179),
    [anon_sym_SEMI] = ACTIONS(4185),
    [anon_sym_global] = ACTIONS(4179),
    [anon_sym_EQ] = ACTIONS(4183),
    [anon_sym_LBRACK] = ACTIONS(4185),
    [anon_sym_COLON] = ACTIONS(4185),
    [anon_sym_COMMA] = ACTIONS(4185),
    [anon_sym_RBRACK] = ACTIONS(4185),
    [anon_sym_LPAREN] = ACTIONS(4185),
    [anon_sym_RPAREN] = ACTIONS(4185),
    [anon_sym_LBRACE] = ACTIONS(4181),
    [anon_sym_RBRACE] = ACTIONS(4185),
    [anon_sym_file] = ACTIONS(4179),
    [anon_sym_LT] = ACTIONS(4188),
    [anon_sym_GT] = ACTIONS(4188),
    [anon_sym_in] = ACTIONS(4188),
    [anon_sym_where] = ACTIONS(4179),
    [anon_sym_QMARK] = ACTIONS(4188),
    [anon_sym_notnull] = ACTIONS(4179),
    [anon_sym_unmanaged] = ACTIONS(4179),
    [anon_sym_BANG] = ACTIONS(4188),
    [anon_sym_PLUS_PLUS] = ACTIONS(4185),
    [anon_sym_DASH_DASH] = ACTIONS(4185),
    [anon_sym_PLUS] = ACTIONS(4188),
    [anon_sym_DASH] = ACTIONS(4188),
    [anon_sym_STAR] = ACTIONS(4188),
    [anon_sym_SLASH] = ACTIONS(4188),
    [anon_sym_PERCENT] = ACTIONS(4188),
    [anon_sym_CARET] = ACTIONS(4188),
    [anon_sym_PIPE] = ACTIONS(4188),
    [anon_sym_AMP] = ACTIONS(4188),
    [anon_sym_LT_LT] = ACTIONS(4188),
    [anon_sym_GT_GT] = ACTIONS(4188),
    [anon_sym_GT_GT_GT] = ACTIONS(4188),
    [anon_sym_EQ_EQ] = ACTIONS(4185),
    [anon_sym_BANG_EQ] = ACTIONS(4185),
    [anon_sym_GT_EQ] = ACTIONS(4185),
    [anon_sym_LT_EQ] = ACTIONS(4185),
    [anon_sym_DOT] = ACTIONS(4188),
    [anon_sym_scoped] = ACTIONS(4179),
    [anon_sym_EQ_GT] = ACTIONS(4185),
    [anon_sym_var] = ACTIONS(4179),
    [anon_sym_yield] = ACTIONS(4179),
    [anon_sym_switch] = ACTIONS(4188),
    [anon_sym_when] = ACTIONS(4179),
    [sym_discard] = ACTIONS(4179),
    [anon_sym_DOT_DOT] = ACTIONS(4185),
    [anon_sym_and] = ACTIONS(4188),
    [anon_sym_or] = ACTIONS(4188),
    [anon_sym_PLUS_EQ] = ACTIONS(4191),
    [anon_sym_DASH_EQ] = ACTIONS(4191),
    [anon_sym_STAR_EQ] = ACTIONS(4191),
    [anon_sym_SLASH_EQ] = ACTIONS(4191),
    [anon_sym_PERCENT_EQ] = ACTIONS(4191),
    [anon_sym_AMP_EQ] = ACTIONS(4191),
    [anon_sym_CARET_EQ] = ACTIONS(4191),
    [anon_sym_PIPE_EQ] = ACTIONS(4191),
    [anon_sym_LT_LT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4191),
    [anon_sym_AMP_AMP] = ACTIONS(4185),
    [anon_sym_PIPE_PIPE] = ACTIONS(4185),
    [anon_sym_QMARK_QMARK] = ACTIONS(4188),
    [anon_sym_from] = ACTIONS(4179),
    [anon_sym_into] = ACTIONS(4188),
    [anon_sym_join] = ACTIONS(4179),
    [anon_sym_on] = ACTIONS(4179),
    [anon_sym_equals] = ACTIONS(4179),
    [anon_sym_let] = ACTIONS(4179),
    [anon_sym_orderby] = ACTIONS(4179),
    [anon_sym_ascending] = ACTIONS(4179),
    [anon_sym_descending] = ACTIONS(4179),
    [anon_sym_group] = ACTIONS(4179),
    [anon_sym_by] = ACTIONS(4179),
    [anon_sym_select] = ACTIONS(4179),
    [anon_sym_as] = ACTIONS(4188),
    [anon_sym_is] = ACTIONS(4188),
    [anon_sym_DASH_GT] = ACTIONS(4185),
    [anon_sym_with] = ACTIONS(4188),
    [aux_sym_preproc_if_token3] = ACTIONS(4185),
    [aux_sym_preproc_else_token1] = ACTIONS(4185),
    [aux_sym_preproc_elif_token1] = ACTIONS(4185),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2763] = {
    [sym__variable_designation] = STATE(4155),
    [sym_parenthesized_variable_designation] = STATE(4153),
    [sym_identifier] = STATE(4156),
    [sym__reserved_identifier] = STATE(3165),
    [sym_preproc_region] = STATE(2763),
    [sym_preproc_endregion] = STATE(2763),
    [sym_preproc_line] = STATE(2763),
    [sym_preproc_pragma] = STATE(2763),
    [sym_preproc_nullable] = STATE(2763),
    [sym_preproc_error] = STATE(2763),
    [sym_preproc_warning] = STATE(2763),
    [sym_preproc_define] = STATE(2763),
    [sym_preproc_undef] = STATE(2763),
    [sym__identifier_token] = ACTIONS(4199),
    [anon_sym_alias] = ACTIONS(4203),
    [anon_sym_global] = ACTIONS(4203),
    [anon_sym_EQ] = ACTIONS(3995),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_COLON] = ACTIONS(3995),
    [anon_sym_COMMA] = ACTIONS(4088),
    [anon_sym_RBRACK] = ACTIONS(4088),
    [anon_sym_LPAREN] = ACTIONS(4114),
    [anon_sym_RPAREN] = ACTIONS(4088),
    [anon_sym_LBRACE] = ACTIONS(4088),
    [anon_sym_RBRACE] = ACTIONS(4088),
    [anon_sym_file] = ACTIONS(4203),
    [anon_sym_LT] = ACTIONS(3995),
    [anon_sym_GT] = ACTIONS(3995),
    [anon_sym_where] = ACTIONS(4203),
    [anon_sym_QMARK] = ACTIONS(3995),
    [anon_sym_notnull] = ACTIONS(4203),
    [anon_sym_unmanaged] = ACTIONS(4203),
    [anon_sym_BANG] = ACTIONS(3995),
    [anon_sym_PLUS_PLUS] = ACTIONS(3993),
    [anon_sym_DASH_DASH] = ACTIONS(3993),
    [anon_sym_PLUS] = ACTIONS(3995),
    [anon_sym_DASH] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3995),
    [anon_sym_SLASH] = ACTIONS(3995),
    [anon_sym_PERCENT] = ACTIONS(3995),
    [anon_sym_CARET] = ACTIONS(3995),
    [anon_sym_PIPE] = ACTIONS(3995),
    [anon_sym_AMP] = ACTIONS(3995),
    [anon_sym_LT_LT] = ACTIONS(3995),
    [anon_sym_GT_GT] = ACTIONS(3995),
    [anon_sym_GT_GT_GT] = ACTIONS(3995),
    [anon_sym_EQ_EQ] = ACTIONS(3993),
    [anon_sym_BANG_EQ] = ACTIONS(3993),
    [anon_sym_GT_EQ] = ACTIONS(3993),
    [anon_sym_LT_EQ] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3995),
    [anon_sym_scoped] = ACTIONS(4203),
    [anon_sym_EQ_GT] = ACTIONS(3993),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(4203),
    [anon_sym_yield] = ACTIONS(4203),
    [anon_sym_switch] = ACTIONS(3995),
    [anon_sym_when] = ACTIONS(4203),
    [sym_discard] = ACTIONS(4118),
    [anon_sym_DOT_DOT] = ACTIONS(3993),
    [anon_sym_and] = ACTIONS(4091),
    [anon_sym_or] = ACTIONS(4091),
    [anon_sym_PLUS_EQ] = ACTIONS(3993),
    [anon_sym_DASH_EQ] = ACTIONS(3993),
    [anon_sym_STAR_EQ] = ACTIONS(3993),
    [anon_sym_SLASH_EQ] = ACTIONS(3993),
    [anon_sym_PERCENT_EQ] = ACTIONS(3993),
    [anon_sym_AMP_EQ] = ACTIONS(3993),
    [anon_sym_CARET_EQ] = ACTIONS(3993),
    [anon_sym_PIPE_EQ] = ACTIONS(3993),
    [anon_sym_LT_LT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(3993),
    [anon_sym_AMP_AMP] = ACTIONS(3993),
    [anon_sym_PIPE_PIPE] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK] = ACTIONS(3995),
    [anon_sym_from] = ACTIONS(4203),
    [anon_sym_into] = ACTIONS(4203),
    [anon_sym_join] = ACTIONS(4203),
    [anon_sym_on] = ACTIONS(4203),
    [anon_sym_equals] = ACTIONS(4203),
    [anon_sym_let] = ACTIONS(4203),
    [anon_sym_orderby] = ACTIONS(4203),
    [anon_sym_ascending] = ACTIONS(4203),
    [anon_sym_descending] = ACTIONS(4203),
    [anon_sym_group] = ACTIONS(4203),
    [anon_sym_by] = ACTIONS(4203),
    [anon_sym_select] = ACTIONS(4203),
    [anon_sym_as] = ACTIONS(3995),
    [anon_sym_is] = ACTIONS(3995),
    [anon_sym_DASH_GT] = ACTIONS(3993),
    [anon_sym_with] = ACTIONS(3995),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2764] = {
    [sym_preproc_region] = STATE(2764),
    [sym_preproc_endregion] = STATE(2764),
    [sym_preproc_line] = STATE(2764),
    [sym_preproc_pragma] = STATE(2764),
    [sym_preproc_nullable] = STATE(2764),
    [sym_preproc_error] = STATE(2764),
    [sym_preproc_warning] = STATE(2764),
    [sym_preproc_define] = STATE(2764),
    [sym_preproc_undef] = STATE(2764),
    [sym__identifier_token] = ACTIONS(4091),
    [anon_sym_alias] = ACTIONS(4091),
    [anon_sym_SEMI] = ACTIONS(3993),
    [anon_sym_global] = ACTIONS(4091),
    [anon_sym_EQ] = ACTIONS(3995),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_COLON] = ACTIONS(3995),
    [anon_sym_COMMA] = ACTIONS(3993),
    [anon_sym_RBRACK] = ACTIONS(3993),
    [anon_sym_LPAREN] = ACTIONS(4088),
    [anon_sym_RPAREN] = ACTIONS(3993),
    [anon_sym_RBRACE] = ACTIONS(3993),
    [anon_sym_file] = ACTIONS(4091),
    [anon_sym_LT] = ACTIONS(3995),
    [anon_sym_GT] = ACTIONS(3995),
    [anon_sym_in] = ACTIONS(3995),
    [anon_sym_where] = ACTIONS(4091),
    [anon_sym_QMARK] = ACTIONS(3995),
    [anon_sym_notnull] = ACTIONS(4091),
    [anon_sym_unmanaged] = ACTIONS(4091),
    [anon_sym_BANG] = ACTIONS(3995),
    [anon_sym_PLUS_PLUS] = ACTIONS(3993),
    [anon_sym_DASH_DASH] = ACTIONS(3993),
    [anon_sym_PLUS] = ACTIONS(3995),
    [anon_sym_DASH] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3995),
    [anon_sym_SLASH] = ACTIONS(3995),
    [anon_sym_PERCENT] = ACTIONS(3995),
    [anon_sym_CARET] = ACTIONS(3995),
    [anon_sym_PIPE] = ACTIONS(3995),
    [anon_sym_AMP] = ACTIONS(3995),
    [anon_sym_LT_LT] = ACTIONS(3995),
    [anon_sym_GT_GT] = ACTIONS(3995),
    [anon_sym_GT_GT_GT] = ACTIONS(3995),
    [anon_sym_EQ_EQ] = ACTIONS(3993),
    [anon_sym_BANG_EQ] = ACTIONS(3993),
    [anon_sym_GT_EQ] = ACTIONS(3993),
    [anon_sym_LT_EQ] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3995),
    [anon_sym_scoped] = ACTIONS(4091),
    [anon_sym_EQ_GT] = ACTIONS(3993),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(4091),
    [anon_sym_yield] = ACTIONS(4091),
    [anon_sym_switch] = ACTIONS(3995),
    [anon_sym_when] = ACTIONS(4091),
    [anon_sym_DOT_DOT] = ACTIONS(3993),
    [anon_sym_and] = ACTIONS(3995),
    [anon_sym_or] = ACTIONS(3995),
    [anon_sym_PLUS_EQ] = ACTIONS(3993),
    [anon_sym_DASH_EQ] = ACTIONS(3993),
    [anon_sym_STAR_EQ] = ACTIONS(3993),
    [anon_sym_SLASH_EQ] = ACTIONS(3993),
    [anon_sym_PERCENT_EQ] = ACTIONS(3993),
    [anon_sym_AMP_EQ] = ACTIONS(3993),
    [anon_sym_CARET_EQ] = ACTIONS(3993),
    [anon_sym_PIPE_EQ] = ACTIONS(3993),
    [anon_sym_LT_LT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(3993),
    [anon_sym_AMP_AMP] = ACTIONS(3993),
    [anon_sym_PIPE_PIPE] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK] = ACTIONS(3995),
    [anon_sym_from] = ACTIONS(4091),
    [anon_sym_into] = ACTIONS(4091),
    [anon_sym_join] = ACTIONS(4091),
    [anon_sym_on] = ACTIONS(4091),
    [anon_sym_equals] = ACTIONS(4091),
    [anon_sym_let] = ACTIONS(4091),
    [anon_sym_orderby] = ACTIONS(4091),
    [anon_sym_ascending] = ACTIONS(4091),
    [anon_sym_descending] = ACTIONS(4091),
    [anon_sym_group] = ACTIONS(4091),
    [anon_sym_by] = ACTIONS(4091),
    [anon_sym_select] = ACTIONS(4091),
    [anon_sym_as] = ACTIONS(3995),
    [anon_sym_is] = ACTIONS(3995),
    [anon_sym_DASH_GT] = ACTIONS(3993),
    [anon_sym_with] = ACTIONS(3995),
    [aux_sym_preproc_if_token3] = ACTIONS(3993),
    [aux_sym_preproc_else_token1] = ACTIONS(3993),
    [aux_sym_preproc_elif_token1] = ACTIONS(3993),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2765] = {
    [sym_preproc_region] = STATE(2765),
    [sym_preproc_endregion] = STATE(2765),
    [sym_preproc_line] = STATE(2765),
    [sym_preproc_pragma] = STATE(2765),
    [sym_preproc_nullable] = STATE(2765),
    [sym_preproc_error] = STATE(2765),
    [sym_preproc_warning] = STATE(2765),
    [sym_preproc_define] = STATE(2765),
    [sym_preproc_undef] = STATE(2765),
    [sym__identifier_token] = ACTIONS(4157),
    [anon_sym_alias] = ACTIONS(4157),
    [anon_sym_SEMI] = ACTIONS(4177),
    [anon_sym_global] = ACTIONS(4157),
    [anon_sym_EQ] = ACTIONS(4162),
    [anon_sym_LBRACK] = ACTIONS(4193),
    [anon_sym_COLON] = ACTIONS(4177),
    [anon_sym_COMMA] = ACTIONS(4177),
    [anon_sym_RBRACK] = ACTIONS(4177),
    [anon_sym_LPAREN] = ACTIONS(4193),
    [anon_sym_RPAREN] = ACTIONS(4177),
    [anon_sym_RBRACE] = ACTIONS(4177),
    [anon_sym_file] = ACTIONS(4157),
    [anon_sym_LT] = ACTIONS(4162),
    [anon_sym_GT] = ACTIONS(4162),
    [anon_sym_in] = ACTIONS(4162),
    [anon_sym_where] = ACTIONS(4157),
    [anon_sym_QMARK] = ACTIONS(4196),
    [anon_sym_notnull] = ACTIONS(4157),
    [anon_sym_unmanaged] = ACTIONS(4157),
    [anon_sym_BANG] = ACTIONS(4162),
    [anon_sym_PLUS_PLUS] = ACTIONS(4177),
    [anon_sym_DASH_DASH] = ACTIONS(4177),
    [anon_sym_PLUS] = ACTIONS(4162),
    [anon_sym_DASH] = ACTIONS(4162),
    [anon_sym_STAR] = ACTIONS(4196),
    [anon_sym_SLASH] = ACTIONS(4162),
    [anon_sym_PERCENT] = ACTIONS(4162),
    [anon_sym_CARET] = ACTIONS(4162),
    [anon_sym_PIPE] = ACTIONS(4162),
    [anon_sym_AMP] = ACTIONS(4162),
    [anon_sym_LT_LT] = ACTIONS(4162),
    [anon_sym_GT_GT] = ACTIONS(4162),
    [anon_sym_GT_GT_GT] = ACTIONS(4162),
    [anon_sym_EQ_EQ] = ACTIONS(4177),
    [anon_sym_BANG_EQ] = ACTIONS(4177),
    [anon_sym_GT_EQ] = ACTIONS(4177),
    [anon_sym_LT_EQ] = ACTIONS(4177),
    [anon_sym_DOT] = ACTIONS(4196),
    [anon_sym_scoped] = ACTIONS(4157),
    [anon_sym_EQ_GT] = ACTIONS(4177),
    [anon_sym_var] = ACTIONS(4157),
    [anon_sym_yield] = ACTIONS(4157),
    [anon_sym_switch] = ACTIONS(4162),
    [anon_sym_when] = ACTIONS(4157),
    [anon_sym_DOT_DOT] = ACTIONS(4177),
    [anon_sym_and] = ACTIONS(4162),
    [anon_sym_or] = ACTIONS(4162),
    [anon_sym_PLUS_EQ] = ACTIONS(4177),
    [anon_sym_DASH_EQ] = ACTIONS(4177),
    [anon_sym_STAR_EQ] = ACTIONS(4177),
    [anon_sym_SLASH_EQ] = ACTIONS(4177),
    [anon_sym_PERCENT_EQ] = ACTIONS(4177),
    [anon_sym_AMP_EQ] = ACTIONS(4177),
    [anon_sym_CARET_EQ] = ACTIONS(4177),
    [anon_sym_PIPE_EQ] = ACTIONS(4177),
    [anon_sym_LT_LT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4177),
    [anon_sym_AMP_AMP] = ACTIONS(4177),
    [anon_sym_PIPE_PIPE] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK] = ACTIONS(4162),
    [anon_sym_from] = ACTIONS(4157),
    [anon_sym_into] = ACTIONS(4196),
    [anon_sym_join] = ACTIONS(4157),
    [anon_sym_on] = ACTIONS(4157),
    [anon_sym_equals] = ACTIONS(4157),
    [anon_sym_let] = ACTIONS(4157),
    [anon_sym_orderby] = ACTIONS(4157),
    [anon_sym_ascending] = ACTIONS(4157),
    [anon_sym_descending] = ACTIONS(4157),
    [anon_sym_group] = ACTIONS(4157),
    [anon_sym_by] = ACTIONS(4157),
    [anon_sym_select] = ACTIONS(4157),
    [anon_sym_as] = ACTIONS(4162),
    [anon_sym_is] = ACTIONS(4162),
    [anon_sym_DASH_GT] = ACTIONS(4193),
    [anon_sym_with] = ACTIONS(4162),
    [aux_sym_preproc_if_token3] = ACTIONS(4177),
    [aux_sym_preproc_else_token1] = ACTIONS(4177),
    [aux_sym_preproc_elif_token1] = ACTIONS(4177),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2766] = {
    [sym_preproc_region] = STATE(2766),
    [sym_preproc_endregion] = STATE(2766),
    [sym_preproc_line] = STATE(2766),
    [sym_preproc_pragma] = STATE(2766),
    [sym_preproc_nullable] = STATE(2766),
    [sym_preproc_error] = STATE(2766),
    [sym_preproc_warning] = STATE(2766),
    [sym_preproc_define] = STATE(2766),
    [sym_preproc_undef] = STATE(2766),
    [sym__identifier_token] = ACTIONS(4179),
    [anon_sym_alias] = ACTIONS(4179),
    [anon_sym_SEMI] = ACTIONS(4191),
    [anon_sym_global] = ACTIONS(4179),
    [anon_sym_EQ] = ACTIONS(4183),
    [anon_sym_LBRACK] = ACTIONS(4185),
    [anon_sym_COLON] = ACTIONS(4191),
    [anon_sym_COMMA] = ACTIONS(4191),
    [anon_sym_RBRACK] = ACTIONS(4191),
    [anon_sym_LPAREN] = ACTIONS(4185),
    [anon_sym_RPAREN] = ACTIONS(4191),
    [anon_sym_RBRACE] = ACTIONS(4191),
    [anon_sym_file] = ACTIONS(4179),
    [anon_sym_LT] = ACTIONS(4183),
    [anon_sym_GT] = ACTIONS(4183),
    [anon_sym_in] = ACTIONS(4183),
    [anon_sym_where] = ACTIONS(4179),
    [anon_sym_QMARK] = ACTIONS(4188),
    [anon_sym_notnull] = ACTIONS(4179),
    [anon_sym_unmanaged] = ACTIONS(4179),
    [anon_sym_BANG] = ACTIONS(4183),
    [anon_sym_PLUS_PLUS] = ACTIONS(4191),
    [anon_sym_DASH_DASH] = ACTIONS(4191),
    [anon_sym_PLUS] = ACTIONS(4183),
    [anon_sym_DASH] = ACTIONS(4183),
    [anon_sym_STAR] = ACTIONS(4188),
    [anon_sym_SLASH] = ACTIONS(4183),
    [anon_sym_PERCENT] = ACTIONS(4183),
    [anon_sym_CARET] = ACTIONS(4183),
    [anon_sym_PIPE] = ACTIONS(4183),
    [anon_sym_AMP] = ACTIONS(4183),
    [anon_sym_LT_LT] = ACTIONS(4183),
    [anon_sym_GT_GT] = ACTIONS(4183),
    [anon_sym_GT_GT_GT] = ACTIONS(4183),
    [anon_sym_EQ_EQ] = ACTIONS(4191),
    [anon_sym_BANG_EQ] = ACTIONS(4191),
    [anon_sym_GT_EQ] = ACTIONS(4191),
    [anon_sym_LT_EQ] = ACTIONS(4191),
    [anon_sym_DOT] = ACTIONS(4188),
    [anon_sym_scoped] = ACTIONS(4179),
    [anon_sym_EQ_GT] = ACTIONS(4191),
    [anon_sym_var] = ACTIONS(4179),
    [anon_sym_yield] = ACTIONS(4179),
    [anon_sym_switch] = ACTIONS(4183),
    [anon_sym_when] = ACTIONS(4179),
    [anon_sym_DOT_DOT] = ACTIONS(4191),
    [anon_sym_and] = ACTIONS(4183),
    [anon_sym_or] = ACTIONS(4183),
    [anon_sym_PLUS_EQ] = ACTIONS(4191),
    [anon_sym_DASH_EQ] = ACTIONS(4191),
    [anon_sym_STAR_EQ] = ACTIONS(4191),
    [anon_sym_SLASH_EQ] = ACTIONS(4191),
    [anon_sym_PERCENT_EQ] = ACTIONS(4191),
    [anon_sym_AMP_EQ] = ACTIONS(4191),
    [anon_sym_CARET_EQ] = ACTIONS(4191),
    [anon_sym_PIPE_EQ] = ACTIONS(4191),
    [anon_sym_LT_LT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4191),
    [anon_sym_AMP_AMP] = ACTIONS(4191),
    [anon_sym_PIPE_PIPE] = ACTIONS(4191),
    [anon_sym_QMARK_QMARK] = ACTIONS(4183),
    [anon_sym_from] = ACTIONS(4179),
    [anon_sym_into] = ACTIONS(4179),
    [anon_sym_join] = ACTIONS(4179),
    [anon_sym_on] = ACTIONS(4179),
    [anon_sym_equals] = ACTIONS(4179),
    [anon_sym_let] = ACTIONS(4179),
    [anon_sym_orderby] = ACTIONS(4179),
    [anon_sym_ascending] = ACTIONS(4179),
    [anon_sym_descending] = ACTIONS(4179),
    [anon_sym_group] = ACTIONS(4179),
    [anon_sym_by] = ACTIONS(4179),
    [anon_sym_select] = ACTIONS(4179),
    [anon_sym_as] = ACTIONS(4183),
    [anon_sym_is] = ACTIONS(4183),
    [anon_sym_DASH_GT] = ACTIONS(4185),
    [anon_sym_with] = ACTIONS(4183),
    [aux_sym_preproc_if_token3] = ACTIONS(4191),
    [aux_sym_preproc_else_token1] = ACTIONS(4191),
    [aux_sym_preproc_elif_token1] = ACTIONS(4191),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2767] = {
    [sym_preproc_region] = STATE(2767),
    [sym_preproc_endregion] = STATE(2767),
    [sym_preproc_line] = STATE(2767),
    [sym_preproc_pragma] = STATE(2767),
    [sym_preproc_nullable] = STATE(2767),
    [sym_preproc_error] = STATE(2767),
    [sym_preproc_warning] = STATE(2767),
    [sym_preproc_define] = STATE(2767),
    [sym_preproc_undef] = STATE(2767),
    [sym__identifier_token] = ACTIONS(4179),
    [anon_sym_alias] = ACTIONS(4179),
    [anon_sym_SEMI] = ACTIONS(4191),
    [anon_sym_global] = ACTIONS(4179),
    [anon_sym_EQ] = ACTIONS(4183),
    [anon_sym_LBRACK] = ACTIONS(4185),
    [anon_sym_COLON] = ACTIONS(4191),
    [anon_sym_COMMA] = ACTIONS(4191),
    [anon_sym_RBRACK] = ACTIONS(4191),
    [anon_sym_LPAREN] = ACTIONS(4185),
    [anon_sym_RPAREN] = ACTIONS(4191),
    [anon_sym_RBRACE] = ACTIONS(4191),
    [anon_sym_file] = ACTIONS(4179),
    [anon_sym_LT] = ACTIONS(4183),
    [anon_sym_GT] = ACTIONS(4183),
    [anon_sym_in] = ACTIONS(4183),
    [anon_sym_where] = ACTIONS(4179),
    [anon_sym_QMARK] = ACTIONS(4188),
    [anon_sym_notnull] = ACTIONS(4179),
    [anon_sym_unmanaged] = ACTIONS(4179),
    [anon_sym_BANG] = ACTIONS(4183),
    [anon_sym_PLUS_PLUS] = ACTIONS(4191),
    [anon_sym_DASH_DASH] = ACTIONS(4191),
    [anon_sym_PLUS] = ACTIONS(4183),
    [anon_sym_DASH] = ACTIONS(4183),
    [anon_sym_STAR] = ACTIONS(4188),
    [anon_sym_SLASH] = ACTIONS(4183),
    [anon_sym_PERCENT] = ACTIONS(4183),
    [anon_sym_CARET] = ACTIONS(4183),
    [anon_sym_PIPE] = ACTIONS(4183),
    [anon_sym_AMP] = ACTIONS(4183),
    [anon_sym_LT_LT] = ACTIONS(4183),
    [anon_sym_GT_GT] = ACTIONS(4183),
    [anon_sym_GT_GT_GT] = ACTIONS(4183),
    [anon_sym_EQ_EQ] = ACTIONS(4191),
    [anon_sym_BANG_EQ] = ACTIONS(4191),
    [anon_sym_GT_EQ] = ACTIONS(4191),
    [anon_sym_LT_EQ] = ACTIONS(4191),
    [anon_sym_DOT] = ACTIONS(4188),
    [anon_sym_scoped] = ACTIONS(4179),
    [anon_sym_EQ_GT] = ACTIONS(4191),
    [anon_sym_var] = ACTIONS(4179),
    [anon_sym_yield] = ACTIONS(4179),
    [anon_sym_switch] = ACTIONS(4183),
    [anon_sym_when] = ACTIONS(4179),
    [anon_sym_DOT_DOT] = ACTIONS(4191),
    [anon_sym_and] = ACTIONS(4183),
    [anon_sym_or] = ACTIONS(4183),
    [anon_sym_PLUS_EQ] = ACTIONS(4191),
    [anon_sym_DASH_EQ] = ACTIONS(4191),
    [anon_sym_STAR_EQ] = ACTIONS(4191),
    [anon_sym_SLASH_EQ] = ACTIONS(4191),
    [anon_sym_PERCENT_EQ] = ACTIONS(4191),
    [anon_sym_AMP_EQ] = ACTIONS(4191),
    [anon_sym_CARET_EQ] = ACTIONS(4191),
    [anon_sym_PIPE_EQ] = ACTIONS(4191),
    [anon_sym_LT_LT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4191),
    [anon_sym_AMP_AMP] = ACTIONS(4191),
    [anon_sym_PIPE_PIPE] = ACTIONS(4191),
    [anon_sym_QMARK_QMARK] = ACTIONS(4183),
    [anon_sym_from] = ACTIONS(4179),
    [anon_sym_into] = ACTIONS(4188),
    [anon_sym_join] = ACTIONS(4179),
    [anon_sym_on] = ACTIONS(4179),
    [anon_sym_equals] = ACTIONS(4179),
    [anon_sym_let] = ACTIONS(4179),
    [anon_sym_orderby] = ACTIONS(4179),
    [anon_sym_ascending] = ACTIONS(4179),
    [anon_sym_descending] = ACTIONS(4179),
    [anon_sym_group] = ACTIONS(4179),
    [anon_sym_by] = ACTIONS(4179),
    [anon_sym_select] = ACTIONS(4179),
    [anon_sym_as] = ACTIONS(4183),
    [anon_sym_is] = ACTIONS(4183),
    [anon_sym_DASH_GT] = ACTIONS(4185),
    [anon_sym_with] = ACTIONS(4183),
    [aux_sym_preproc_if_token3] = ACTIONS(4191),
    [aux_sym_preproc_else_token1] = ACTIONS(4191),
    [aux_sym_preproc_elif_token1] = ACTIONS(4191),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2768] = {
    [sym__variable_designation] = STATE(5774),
    [sym_parenthesized_variable_designation] = STATE(5773),
    [sym_identifier] = STATE(5775),
    [sym__reserved_identifier] = STATE(5200),
    [sym_preproc_region] = STATE(2768),
    [sym_preproc_endregion] = STATE(2768),
    [sym_preproc_line] = STATE(2768),
    [sym_preproc_pragma] = STATE(2768),
    [sym_preproc_nullable] = STATE(2768),
    [sym_preproc_error] = STATE(2768),
    [sym_preproc_warning] = STATE(2768),
    [sym_preproc_define] = STATE(2768),
    [sym_preproc_undef] = STATE(2768),
    [sym__identifier_token] = ACTIONS(4207),
    [anon_sym_alias] = ACTIONS(4211),
    [anon_sym_global] = ACTIONS(4211),
    [anon_sym_EQ] = ACTIONS(3995),
    [anon_sym_LBRACK] = ACTIONS(4088),
    [anon_sym_COLON] = ACTIONS(4091),
    [anon_sym_COMMA] = ACTIONS(4088),
    [anon_sym_LPAREN] = ACTIONS(4215),
    [anon_sym_LBRACE] = ACTIONS(4088),
    [anon_sym_file] = ACTIONS(4211),
    [anon_sym_LT] = ACTIONS(4091),
    [anon_sym_GT] = ACTIONS(4091),
    [anon_sym_where] = ACTIONS(4211),
    [anon_sym_QMARK] = ACTIONS(4091),
    [anon_sym_notnull] = ACTIONS(4211),
    [anon_sym_unmanaged] = ACTIONS(4211),
    [anon_sym_BANG] = ACTIONS(4091),
    [anon_sym_PLUS_PLUS] = ACTIONS(4088),
    [anon_sym_DASH_DASH] = ACTIONS(4088),
    [anon_sym_PLUS] = ACTIONS(4091),
    [anon_sym_DASH] = ACTIONS(4091),
    [anon_sym_STAR] = ACTIONS(4091),
    [anon_sym_SLASH] = ACTIONS(4091),
    [anon_sym_PERCENT] = ACTIONS(4091),
    [anon_sym_CARET] = ACTIONS(4091),
    [anon_sym_PIPE] = ACTIONS(4091),
    [anon_sym_AMP] = ACTIONS(4091),
    [anon_sym_LT_LT] = ACTIONS(4091),
    [anon_sym_GT_GT] = ACTIONS(4091),
    [anon_sym_GT_GT_GT] = ACTIONS(4091),
    [anon_sym_EQ_EQ] = ACTIONS(4088),
    [anon_sym_BANG_EQ] = ACTIONS(4088),
    [anon_sym_GT_EQ] = ACTIONS(4088),
    [anon_sym_LT_EQ] = ACTIONS(4088),
    [anon_sym_DOT] = ACTIONS(4091),
    [anon_sym_scoped] = ACTIONS(4211),
    [anon_sym_EQ_GT] = ACTIONS(3993),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(4211),
    [anon_sym_yield] = ACTIONS(4211),
    [anon_sym_switch] = ACTIONS(4091),
    [anon_sym_when] = ACTIONS(4211),
    [sym_discard] = ACTIONS(4219),
    [anon_sym_DOT_DOT] = ACTIONS(4088),
    [anon_sym_and] = ACTIONS(4091),
    [anon_sym_or] = ACTIONS(4091),
    [anon_sym_PLUS_EQ] = ACTIONS(3993),
    [anon_sym_DASH_EQ] = ACTIONS(3993),
    [anon_sym_STAR_EQ] = ACTIONS(3993),
    [anon_sym_SLASH_EQ] = ACTIONS(3993),
    [anon_sym_PERCENT_EQ] = ACTIONS(3993),
    [anon_sym_AMP_EQ] = ACTIONS(3993),
    [anon_sym_CARET_EQ] = ACTIONS(3993),
    [anon_sym_PIPE_EQ] = ACTIONS(3993),
    [anon_sym_LT_LT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(3993),
    [anon_sym_AMP_AMP] = ACTIONS(4088),
    [anon_sym_PIPE_PIPE] = ACTIONS(4088),
    [anon_sym_QMARK_QMARK] = ACTIONS(4091),
    [anon_sym_from] = ACTIONS(4211),
    [anon_sym_into] = ACTIONS(4211),
    [anon_sym_join] = ACTIONS(4211),
    [anon_sym_on] = ACTIONS(4211),
    [anon_sym_equals] = ACTIONS(4211),
    [anon_sym_let] = ACTIONS(4211),
    [anon_sym_orderby] = ACTIONS(4211),
    [anon_sym_ascending] = ACTIONS(4211),
    [anon_sym_descending] = ACTIONS(4211),
    [anon_sym_group] = ACTIONS(4211),
    [anon_sym_by] = ACTIONS(4211),
    [anon_sym_select] = ACTIONS(4211),
    [anon_sym_as] = ACTIONS(4091),
    [anon_sym_is] = ACTIONS(4091),
    [anon_sym_DASH_GT] = ACTIONS(4088),
    [anon_sym_with] = ACTIONS(4091),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4088),
  },
  [2769] = {
    [sym__variable_designation] = STATE(4155),
    [sym_parenthesized_variable_designation] = STATE(4153),
    [sym_identifier] = STATE(4156),
    [sym__reserved_identifier] = STATE(3165),
    [sym_preproc_region] = STATE(2769),
    [sym_preproc_endregion] = STATE(2769),
    [sym_preproc_line] = STATE(2769),
    [sym_preproc_pragma] = STATE(2769),
    [sym_preproc_nullable] = STATE(2769),
    [sym_preproc_error] = STATE(2769),
    [sym_preproc_warning] = STATE(2769),
    [sym_preproc_define] = STATE(2769),
    [sym_preproc_undef] = STATE(2769),
    [sym__identifier_token] = ACTIONS(4199),
    [anon_sym_alias] = ACTIONS(4203),
    [anon_sym_global] = ACTIONS(4203),
    [anon_sym_EQ] = ACTIONS(3995),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_COLON] = ACTIONS(3995),
    [anon_sym_COMMA] = ACTIONS(4088),
    [anon_sym_LPAREN] = ACTIONS(4114),
    [anon_sym_RPAREN] = ACTIONS(3993),
    [anon_sym_LBRACE] = ACTIONS(4088),
    [anon_sym_file] = ACTIONS(4203),
    [anon_sym_LT] = ACTIONS(3995),
    [anon_sym_GT] = ACTIONS(3995),
    [anon_sym_where] = ACTIONS(4203),
    [anon_sym_QMARK] = ACTIONS(3995),
    [anon_sym_notnull] = ACTIONS(4203),
    [anon_sym_unmanaged] = ACTIONS(4203),
    [anon_sym_BANG] = ACTIONS(3995),
    [anon_sym_PLUS_PLUS] = ACTIONS(3993),
    [anon_sym_DASH_DASH] = ACTIONS(3993),
    [anon_sym_PLUS] = ACTIONS(3995),
    [anon_sym_DASH] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3995),
    [anon_sym_SLASH] = ACTIONS(3995),
    [anon_sym_PERCENT] = ACTIONS(3995),
    [anon_sym_CARET] = ACTIONS(3995),
    [anon_sym_PIPE] = ACTIONS(3995),
    [anon_sym_AMP] = ACTIONS(3995),
    [anon_sym_LT_LT] = ACTIONS(3995),
    [anon_sym_GT_GT] = ACTIONS(3995),
    [anon_sym_GT_GT_GT] = ACTIONS(3995),
    [anon_sym_EQ_EQ] = ACTIONS(3993),
    [anon_sym_BANG_EQ] = ACTIONS(3993),
    [anon_sym_GT_EQ] = ACTIONS(3993),
    [anon_sym_LT_EQ] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3995),
    [anon_sym_scoped] = ACTIONS(4203),
    [anon_sym_EQ_GT] = ACTIONS(3993),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(4203),
    [anon_sym_yield] = ACTIONS(4203),
    [anon_sym_switch] = ACTIONS(3995),
    [anon_sym_when] = ACTIONS(4203),
    [sym_discard] = ACTIONS(4118),
    [anon_sym_DOT_DOT] = ACTIONS(3993),
    [anon_sym_and] = ACTIONS(4091),
    [anon_sym_or] = ACTIONS(4091),
    [anon_sym_PLUS_EQ] = ACTIONS(3993),
    [anon_sym_DASH_EQ] = ACTIONS(3993),
    [anon_sym_STAR_EQ] = ACTIONS(3993),
    [anon_sym_SLASH_EQ] = ACTIONS(3993),
    [anon_sym_PERCENT_EQ] = ACTIONS(3993),
    [anon_sym_AMP_EQ] = ACTIONS(3993),
    [anon_sym_CARET_EQ] = ACTIONS(3993),
    [anon_sym_PIPE_EQ] = ACTIONS(3993),
    [anon_sym_LT_LT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(3993),
    [anon_sym_AMP_AMP] = ACTIONS(3993),
    [anon_sym_PIPE_PIPE] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK] = ACTIONS(3995),
    [anon_sym_from] = ACTIONS(4203),
    [anon_sym_into] = ACTIONS(4203),
    [anon_sym_join] = ACTIONS(4203),
    [anon_sym_on] = ACTIONS(4203),
    [anon_sym_equals] = ACTIONS(4203),
    [anon_sym_let] = ACTIONS(4203),
    [anon_sym_orderby] = ACTIONS(4203),
    [anon_sym_ascending] = ACTIONS(4203),
    [anon_sym_descending] = ACTIONS(4203),
    [anon_sym_group] = ACTIONS(4203),
    [anon_sym_by] = ACTIONS(4203),
    [anon_sym_select] = ACTIONS(4203),
    [anon_sym_as] = ACTIONS(3995),
    [anon_sym_is] = ACTIONS(3995),
    [anon_sym_DASH_GT] = ACTIONS(3993),
    [anon_sym_with] = ACTIONS(3995),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2770] = {
    [sym__name] = STATE(3912),
    [sym_alias_qualified_name] = STATE(3924),
    [sym__simple_name] = STATE(3924),
    [sym_qualified_name] = STATE(3924),
    [sym_generic_name] = STATE(3900),
    [sym_ref_type] = STATE(3954),
    [sym__scoped_base_type] = STATE(3916),
    [sym_identifier] = STATE(3808),
    [sym__reserved_identifier] = STATE(3871),
    [sym_preproc_region] = STATE(2770),
    [sym_preproc_endregion] = STATE(2770),
    [sym_preproc_line] = STATE(2770),
    [sym_preproc_pragma] = STATE(2770),
    [sym_preproc_nullable] = STATE(2770),
    [sym_preproc_error] = STATE(2770),
    [sym_preproc_warning] = STATE(2770),
    [sym_preproc_define] = STATE(2770),
    [sym_preproc_undef] = STATE(2770),
    [sym__identifier_token] = ACTIONS(4223),
    [anon_sym_alias] = ACTIONS(4225),
    [anon_sym_SEMI] = ACTIONS(3993),
    [anon_sym_global] = ACTIONS(4225),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_COLON] = ACTIONS(3995),
    [anon_sym_COMMA] = ACTIONS(3993),
    [anon_sym_RBRACK] = ACTIONS(3993),
    [anon_sym_LPAREN] = ACTIONS(3993),
    [anon_sym_RPAREN] = ACTIONS(3993),
    [anon_sym_ref] = ACTIONS(4227),
    [anon_sym_LBRACE] = ACTIONS(3993),
    [anon_sym_RBRACE] = ACTIONS(3993),
    [anon_sym_file] = ACTIONS(4225),
    [anon_sym_LT] = ACTIONS(3995),
    [anon_sym_GT] = ACTIONS(3995),
    [anon_sym_in] = ACTIONS(3995),
    [anon_sym_where] = ACTIONS(4225),
    [anon_sym_QMARK] = ACTIONS(3995),
    [anon_sym_notnull] = ACTIONS(4225),
    [anon_sym_unmanaged] = ACTIONS(4225),
    [anon_sym_BANG] = ACTIONS(3995),
    [anon_sym_PLUS_PLUS] = ACTIONS(3993),
    [anon_sym_DASH_DASH] = ACTIONS(3993),
    [anon_sym_PLUS] = ACTIONS(3995),
    [anon_sym_DASH] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3993),
    [anon_sym_SLASH] = ACTIONS(3995),
    [anon_sym_PERCENT] = ACTIONS(3993),
    [anon_sym_CARET] = ACTIONS(3993),
    [anon_sym_PIPE] = ACTIONS(3995),
    [anon_sym_AMP] = ACTIONS(3995),
    [anon_sym_LT_LT] = ACTIONS(3993),
    [anon_sym_GT_GT] = ACTIONS(3995),
    [anon_sym_GT_GT_GT] = ACTIONS(3993),
    [anon_sym_EQ_EQ] = ACTIONS(3993),
    [anon_sym_BANG_EQ] = ACTIONS(3993),
    [anon_sym_GT_EQ] = ACTIONS(3993),
    [anon_sym_LT_EQ] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3995),
    [anon_sym_scoped] = ACTIONS(4225),
    [anon_sym_EQ_GT] = ACTIONS(3993),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(4225),
    [anon_sym_yield] = ACTIONS(4225),
    [anon_sym_switch] = ACTIONS(3995),
    [anon_sym_when] = ACTIONS(4225),
    [anon_sym_DOT_DOT] = ACTIONS(3993),
    [anon_sym_and] = ACTIONS(3995),
    [anon_sym_or] = ACTIONS(3995),
    [anon_sym_AMP_AMP] = ACTIONS(3993),
    [anon_sym_PIPE_PIPE] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK] = ACTIONS(3993),
    [anon_sym_from] = ACTIONS(4225),
    [anon_sym_into] = ACTIONS(4229),
    [anon_sym_join] = ACTIONS(4225),
    [anon_sym_on] = ACTIONS(4225),
    [anon_sym_equals] = ACTIONS(4225),
    [anon_sym_let] = ACTIONS(4225),
    [anon_sym_orderby] = ACTIONS(4225),
    [anon_sym_ascending] = ACTIONS(4225),
    [anon_sym_descending] = ACTIONS(4225),
    [anon_sym_group] = ACTIONS(4225),
    [anon_sym_by] = ACTIONS(4225),
    [anon_sym_select] = ACTIONS(4225),
    [anon_sym_as] = ACTIONS(3995),
    [anon_sym_is] = ACTIONS(3995),
    [anon_sym_DASH_GT] = ACTIONS(3993),
    [anon_sym_with] = ACTIONS(3995),
    [aux_sym_preproc_if_token3] = ACTIONS(3993),
    [aux_sym_preproc_else_token1] = ACTIONS(3993),
    [aux_sym_preproc_elif_token1] = ACTIONS(3993),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2771] = {
    [sym__name] = STATE(3015),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2956),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2944),
    [sym_ref_type] = STATE(2883),
    [sym__scoped_base_type] = STATE(2885),
    [sym_identifier] = STATE(2920),
    [sym__reserved_identifier] = STATE(2928),
    [sym_preproc_region] = STATE(2771),
    [sym_preproc_endregion] = STATE(2771),
    [sym_preproc_line] = STATE(2771),
    [sym_preproc_pragma] = STATE(2771),
    [sym_preproc_nullable] = STATE(2771),
    [sym_preproc_error] = STATE(2771),
    [sym_preproc_warning] = STATE(2771),
    [sym_preproc_define] = STATE(2771),
    [sym_preproc_undef] = STATE(2771),
    [sym__identifier_token] = ACTIONS(4053),
    [anon_sym_alias] = ACTIONS(4056),
    [anon_sym_SEMI] = ACTIONS(3993),
    [anon_sym_global] = ACTIONS(4056),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_COMMA] = ACTIONS(3993),
    [anon_sym_RBRACK] = ACTIONS(3993),
    [anon_sym_LPAREN] = ACTIONS(3993),
    [anon_sym_RPAREN] = ACTIONS(3993),
    [anon_sym_ref] = ACTIONS(4059),
    [anon_sym_LBRACE] = ACTIONS(3993),
    [anon_sym_RBRACE] = ACTIONS(3993),
    [anon_sym_file] = ACTIONS(4056),
    [anon_sym_LT] = ACTIONS(3995),
    [anon_sym_GT] = ACTIONS(3995),
    [anon_sym_in] = ACTIONS(3995),
    [anon_sym_where] = ACTIONS(4056),
    [anon_sym_QMARK] = ACTIONS(3995),
    [anon_sym_notnull] = ACTIONS(4056),
    [anon_sym_unmanaged] = ACTIONS(4056),
    [anon_sym_BANG] = ACTIONS(3995),
    [anon_sym_PLUS_PLUS] = ACTIONS(3993),
    [anon_sym_DASH_DASH] = ACTIONS(3993),
    [anon_sym_PLUS] = ACTIONS(3995),
    [anon_sym_DASH] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3993),
    [anon_sym_SLASH] = ACTIONS(3995),
    [anon_sym_PERCENT] = ACTIONS(3993),
    [anon_sym_CARET] = ACTIONS(3993),
    [anon_sym_PIPE] = ACTIONS(3995),
    [anon_sym_AMP] = ACTIONS(3995),
    [anon_sym_LT_LT] = ACTIONS(3993),
    [anon_sym_GT_GT] = ACTIONS(3995),
    [anon_sym_GT_GT_GT] = ACTIONS(3993),
    [anon_sym_EQ_EQ] = ACTIONS(3993),
    [anon_sym_BANG_EQ] = ACTIONS(3993),
    [anon_sym_GT_EQ] = ACTIONS(3993),
    [anon_sym_LT_EQ] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3995),
    [anon_sym_scoped] = ACTIONS(4056),
    [anon_sym_EQ_GT] = ACTIONS(3993),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(4056),
    [anon_sym_yield] = ACTIONS(4056),
    [anon_sym_switch] = ACTIONS(3995),
    [anon_sym_when] = ACTIONS(4056),
    [sym_discard] = ACTIONS(3995),
    [anon_sym_DOT_DOT] = ACTIONS(3993),
    [anon_sym_and] = ACTIONS(3995),
    [anon_sym_or] = ACTIONS(3995),
    [anon_sym_AMP_AMP] = ACTIONS(3993),
    [anon_sym_PIPE_PIPE] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK] = ACTIONS(3993),
    [anon_sym_from] = ACTIONS(4056),
    [anon_sym_into] = ACTIONS(4056),
    [anon_sym_join] = ACTIONS(4056),
    [anon_sym_on] = ACTIONS(4056),
    [anon_sym_equals] = ACTIONS(4056),
    [anon_sym_let] = ACTIONS(4056),
    [anon_sym_orderby] = ACTIONS(4056),
    [anon_sym_ascending] = ACTIONS(4056),
    [anon_sym_descending] = ACTIONS(4056),
    [anon_sym_group] = ACTIONS(4056),
    [anon_sym_by] = ACTIONS(4056),
    [anon_sym_select] = ACTIONS(4056),
    [anon_sym_as] = ACTIONS(3995),
    [anon_sym_is] = ACTIONS(3995),
    [anon_sym_DASH_GT] = ACTIONS(3993),
    [anon_sym_with] = ACTIONS(3995),
    [aux_sym_preproc_if_token3] = ACTIONS(3993),
    [aux_sym_preproc_else_token1] = ACTIONS(3993),
    [aux_sym_preproc_elif_token1] = ACTIONS(3993),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2772] = {
    [sym_preproc_region] = STATE(2772),
    [sym_preproc_endregion] = STATE(2772),
    [sym_preproc_line] = STATE(2772),
    [sym_preproc_pragma] = STATE(2772),
    [sym_preproc_nullable] = STATE(2772),
    [sym_preproc_error] = STATE(2772),
    [sym_preproc_warning] = STATE(2772),
    [sym_preproc_define] = STATE(2772),
    [sym_preproc_undef] = STATE(2772),
    [sym__identifier_token] = ACTIONS(4157),
    [anon_sym_alias] = ACTIONS(4157),
    [anon_sym_SEMI] = ACTIONS(4177),
    [anon_sym_global] = ACTIONS(4157),
    [anon_sym_EQ] = ACTIONS(4162),
    [anon_sym_LBRACK] = ACTIONS(4193),
    [anon_sym_COLON] = ACTIONS(4177),
    [anon_sym_COMMA] = ACTIONS(4193),
    [anon_sym_RBRACK] = ACTIONS(4193),
    [anon_sym_LPAREN] = ACTIONS(4193),
    [anon_sym_RPAREN] = ACTIONS(4193),
    [anon_sym_file] = ACTIONS(4157),
    [anon_sym_LT] = ACTIONS(4162),
    [anon_sym_GT] = ACTIONS(4162),
    [anon_sym_in] = ACTIONS(4162),
    [anon_sym_where] = ACTIONS(4157),
    [anon_sym_QMARK] = ACTIONS(4196),
    [anon_sym_notnull] = ACTIONS(4157),
    [anon_sym_unmanaged] = ACTIONS(4157),
    [anon_sym_BANG] = ACTIONS(4162),
    [anon_sym_PLUS_PLUS] = ACTIONS(4177),
    [anon_sym_DASH_DASH] = ACTIONS(4177),
    [anon_sym_PLUS] = ACTIONS(4162),
    [anon_sym_DASH] = ACTIONS(4162),
    [anon_sym_STAR] = ACTIONS(4196),
    [anon_sym_SLASH] = ACTIONS(4162),
    [anon_sym_PERCENT] = ACTIONS(4162),
    [anon_sym_CARET] = ACTIONS(4162),
    [anon_sym_PIPE] = ACTIONS(4162),
    [anon_sym_AMP] = ACTIONS(4162),
    [anon_sym_LT_LT] = ACTIONS(4162),
    [anon_sym_GT_GT] = ACTIONS(4162),
    [anon_sym_GT_GT_GT] = ACTIONS(4162),
    [anon_sym_EQ_EQ] = ACTIONS(4177),
    [anon_sym_BANG_EQ] = ACTIONS(4177),
    [anon_sym_GT_EQ] = ACTIONS(4177),
    [anon_sym_LT_EQ] = ACTIONS(4177),
    [anon_sym_DOT] = ACTIONS(4196),
    [anon_sym_scoped] = ACTIONS(4157),
    [anon_sym_EQ_GT] = ACTIONS(4177),
    [anon_sym_var] = ACTIONS(4157),
    [anon_sym_yield] = ACTIONS(4157),
    [anon_sym_switch] = ACTIONS(4162),
    [anon_sym_when] = ACTIONS(4157),
    [anon_sym_DOT_DOT] = ACTIONS(4177),
    [anon_sym_and] = ACTIONS(4162),
    [anon_sym_or] = ACTIONS(4162),
    [anon_sym_PLUS_EQ] = ACTIONS(4177),
    [anon_sym_DASH_EQ] = ACTIONS(4177),
    [anon_sym_STAR_EQ] = ACTIONS(4177),
    [anon_sym_SLASH_EQ] = ACTIONS(4177),
    [anon_sym_PERCENT_EQ] = ACTIONS(4177),
    [anon_sym_AMP_EQ] = ACTIONS(4177),
    [anon_sym_CARET_EQ] = ACTIONS(4177),
    [anon_sym_PIPE_EQ] = ACTIONS(4177),
    [anon_sym_LT_LT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4177),
    [anon_sym_AMP_AMP] = ACTIONS(4177),
    [anon_sym_PIPE_PIPE] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK] = ACTIONS(4162),
    [anon_sym_from] = ACTIONS(4157),
    [anon_sym_into] = ACTIONS(4157),
    [anon_sym_join] = ACTIONS(4157),
    [anon_sym_on] = ACTIONS(4157),
    [anon_sym_equals] = ACTIONS(4157),
    [anon_sym_let] = ACTIONS(4157),
    [anon_sym_orderby] = ACTIONS(4157),
    [anon_sym_ascending] = ACTIONS(4157),
    [anon_sym_descending] = ACTIONS(4157),
    [anon_sym_group] = ACTIONS(4157),
    [anon_sym_by] = ACTIONS(4157),
    [anon_sym_select] = ACTIONS(4157),
    [anon_sym_as] = ACTIONS(4162),
    [anon_sym_is] = ACTIONS(4162),
    [anon_sym_DASH_GT] = ACTIONS(4193),
    [anon_sym_with] = ACTIONS(4162),
    [aux_sym_preproc_if_token3] = ACTIONS(4177),
    [aux_sym_preproc_else_token1] = ACTIONS(4177),
    [aux_sym_preproc_elif_token1] = ACTIONS(4177),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2773] = {
    [sym__variable_designation] = STATE(4547),
    [sym_parenthesized_variable_designation] = STATE(4748),
    [sym_identifier] = STATE(4548),
    [sym__reserved_identifier] = STATE(2928),
    [sym_preproc_region] = STATE(2773),
    [sym_preproc_endregion] = STATE(2773),
    [sym_preproc_line] = STATE(2773),
    [sym_preproc_pragma] = STATE(2773),
    [sym_preproc_nullable] = STATE(2773),
    [sym_preproc_error] = STATE(2773),
    [sym_preproc_warning] = STATE(2773),
    [sym_preproc_define] = STATE(2773),
    [sym_preproc_undef] = STATE(2773),
    [sym__identifier_token] = ACTIONS(4232),
    [anon_sym_alias] = ACTIONS(4236),
    [anon_sym_global] = ACTIONS(4236),
    [anon_sym_EQ] = ACTIONS(3995),
    [anon_sym_LBRACK] = ACTIONS(4088),
    [anon_sym_COMMA] = ACTIONS(4088),
    [anon_sym_LPAREN] = ACTIONS(4240),
    [anon_sym_LBRACE] = ACTIONS(4088),
    [anon_sym_file] = ACTIONS(4236),
    [anon_sym_LT] = ACTIONS(4091),
    [anon_sym_GT] = ACTIONS(4091),
    [anon_sym_where] = ACTIONS(4236),
    [anon_sym_QMARK] = ACTIONS(4091),
    [anon_sym_notnull] = ACTIONS(4236),
    [anon_sym_unmanaged] = ACTIONS(4236),
    [anon_sym_BANG] = ACTIONS(4091),
    [anon_sym_PLUS_PLUS] = ACTIONS(4088),
    [anon_sym_DASH_DASH] = ACTIONS(4088),
    [anon_sym_PLUS] = ACTIONS(4091),
    [anon_sym_DASH] = ACTIONS(4091),
    [anon_sym_STAR] = ACTIONS(4091),
    [anon_sym_SLASH] = ACTIONS(4091),
    [anon_sym_PERCENT] = ACTIONS(4091),
    [anon_sym_CARET] = ACTIONS(4091),
    [anon_sym_PIPE] = ACTIONS(4091),
    [anon_sym_AMP] = ACTIONS(4091),
    [anon_sym_LT_LT] = ACTIONS(4091),
    [anon_sym_GT_GT] = ACTIONS(4091),
    [anon_sym_GT_GT_GT] = ACTIONS(4091),
    [anon_sym_EQ_EQ] = ACTIONS(4088),
    [anon_sym_BANG_EQ] = ACTIONS(4088),
    [anon_sym_GT_EQ] = ACTIONS(4088),
    [anon_sym_LT_EQ] = ACTIONS(4088),
    [anon_sym_DOT] = ACTIONS(4091),
    [anon_sym_scoped] = ACTIONS(4236),
    [anon_sym_EQ_GT] = ACTIONS(3993),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(4236),
    [anon_sym_yield] = ACTIONS(4236),
    [anon_sym_switch] = ACTIONS(4091),
    [anon_sym_when] = ACTIONS(4236),
    [sym_discard] = ACTIONS(4244),
    [anon_sym_DOT_DOT] = ACTIONS(4088),
    [anon_sym_and] = ACTIONS(4091),
    [anon_sym_or] = ACTIONS(4091),
    [anon_sym_PLUS_EQ] = ACTIONS(3993),
    [anon_sym_DASH_EQ] = ACTIONS(3993),
    [anon_sym_STAR_EQ] = ACTIONS(3993),
    [anon_sym_SLASH_EQ] = ACTIONS(3993),
    [anon_sym_PERCENT_EQ] = ACTIONS(3993),
    [anon_sym_AMP_EQ] = ACTIONS(3993),
    [anon_sym_CARET_EQ] = ACTIONS(3993),
    [anon_sym_PIPE_EQ] = ACTIONS(3993),
    [anon_sym_LT_LT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(3993),
    [anon_sym_AMP_AMP] = ACTIONS(4088),
    [anon_sym_PIPE_PIPE] = ACTIONS(4088),
    [anon_sym_QMARK_QMARK] = ACTIONS(4091),
    [anon_sym_from] = ACTIONS(4236),
    [anon_sym_into] = ACTIONS(4236),
    [anon_sym_join] = ACTIONS(4236),
    [anon_sym_on] = ACTIONS(4236),
    [anon_sym_equals] = ACTIONS(4236),
    [anon_sym_let] = ACTIONS(4236),
    [anon_sym_orderby] = ACTIONS(4236),
    [anon_sym_ascending] = ACTIONS(4236),
    [anon_sym_descending] = ACTIONS(4236),
    [anon_sym_group] = ACTIONS(4236),
    [anon_sym_by] = ACTIONS(4236),
    [anon_sym_select] = ACTIONS(4236),
    [anon_sym_as] = ACTIONS(4091),
    [anon_sym_is] = ACTIONS(4091),
    [anon_sym_DASH_GT] = ACTIONS(4088),
    [anon_sym_with] = ACTIONS(4091),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2774] = {
    [sym__name] = STATE(4159),
    [sym_alias_qualified_name] = STATE(4085),
    [sym__simple_name] = STATE(4085),
    [sym_qualified_name] = STATE(4085),
    [sym_generic_name] = STATE(3959),
    [sym_ref_type] = STATE(3971),
    [sym__scoped_base_type] = STATE(3973),
    [sym_identifier] = STATE(3889),
    [sym__reserved_identifier] = STATE(3911),
    [sym_preproc_region] = STATE(2774),
    [sym_preproc_endregion] = STATE(2774),
    [sym_preproc_line] = STATE(2774),
    [sym_preproc_pragma] = STATE(2774),
    [sym_preproc_nullable] = STATE(2774),
    [sym_preproc_error] = STATE(2774),
    [sym_preproc_warning] = STATE(2774),
    [sym_preproc_define] = STATE(2774),
    [sym_preproc_undef] = STATE(2774),
    [sym__identifier_token] = ACTIONS(4248),
    [anon_sym_alias] = ACTIONS(4250),
    [anon_sym_SEMI] = ACTIONS(3993),
    [anon_sym_global] = ACTIONS(4250),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_COLON] = ACTIONS(3995),
    [anon_sym_COMMA] = ACTIONS(3993),
    [anon_sym_RBRACK] = ACTIONS(3993),
    [anon_sym_LPAREN] = ACTIONS(3993),
    [anon_sym_RPAREN] = ACTIONS(3993),
    [anon_sym_ref] = ACTIONS(4252),
    [anon_sym_LBRACE] = ACTIONS(3993),
    [anon_sym_RBRACE] = ACTIONS(3993),
    [anon_sym_file] = ACTIONS(4250),
    [anon_sym_LT] = ACTIONS(3995),
    [anon_sym_GT] = ACTIONS(3995),
    [anon_sym_where] = ACTIONS(4250),
    [anon_sym_QMARK] = ACTIONS(3995),
    [anon_sym_notnull] = ACTIONS(4250),
    [anon_sym_unmanaged] = ACTIONS(4250),
    [anon_sym_BANG] = ACTIONS(3995),
    [anon_sym_PLUS_PLUS] = ACTIONS(3993),
    [anon_sym_DASH_DASH] = ACTIONS(3993),
    [anon_sym_PLUS] = ACTIONS(3995),
    [anon_sym_DASH] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3993),
    [anon_sym_SLASH] = ACTIONS(3995),
    [anon_sym_PERCENT] = ACTIONS(3993),
    [anon_sym_CARET] = ACTIONS(3993),
    [anon_sym_PIPE] = ACTIONS(3995),
    [anon_sym_AMP] = ACTIONS(3995),
    [anon_sym_LT_LT] = ACTIONS(3993),
    [anon_sym_GT_GT] = ACTIONS(3995),
    [anon_sym_GT_GT_GT] = ACTIONS(3993),
    [anon_sym_EQ_EQ] = ACTIONS(3993),
    [anon_sym_BANG_EQ] = ACTIONS(3993),
    [anon_sym_GT_EQ] = ACTIONS(3993),
    [anon_sym_LT_EQ] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3995),
    [anon_sym_scoped] = ACTIONS(4250),
    [anon_sym_EQ_GT] = ACTIONS(3993),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(4250),
    [anon_sym_yield] = ACTIONS(4250),
    [anon_sym_switch] = ACTIONS(3995),
    [anon_sym_when] = ACTIONS(4250),
    [anon_sym_DOT_DOT] = ACTIONS(3993),
    [anon_sym_and] = ACTIONS(3995),
    [anon_sym_or] = ACTIONS(3995),
    [anon_sym_AMP_AMP] = ACTIONS(3993),
    [anon_sym_PIPE_PIPE] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK] = ACTIONS(3993),
    [anon_sym_from] = ACTIONS(4250),
    [anon_sym_into] = ACTIONS(4250),
    [anon_sym_join] = ACTIONS(4250),
    [anon_sym_on] = ACTIONS(4250),
    [anon_sym_equals] = ACTIONS(4250),
    [anon_sym_let] = ACTIONS(4250),
    [anon_sym_orderby] = ACTIONS(4250),
    [anon_sym_ascending] = ACTIONS(4250),
    [anon_sym_descending] = ACTIONS(4250),
    [anon_sym_group] = ACTIONS(4250),
    [anon_sym_by] = ACTIONS(4250),
    [anon_sym_select] = ACTIONS(4250),
    [anon_sym_as] = ACTIONS(3995),
    [anon_sym_is] = ACTIONS(3995),
    [anon_sym_DASH_GT] = ACTIONS(3993),
    [anon_sym_with] = ACTIONS(3995),
    [aux_sym_preproc_if_token3] = ACTIONS(3993),
    [aux_sym_preproc_else_token1] = ACTIONS(3993),
    [aux_sym_preproc_elif_token1] = ACTIONS(3993),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2775] = {
    [sym_preproc_region] = STATE(2775),
    [sym_preproc_endregion] = STATE(2775),
    [sym_preproc_line] = STATE(2775),
    [sym_preproc_pragma] = STATE(2775),
    [sym_preproc_nullable] = STATE(2775),
    [sym_preproc_error] = STATE(2775),
    [sym_preproc_warning] = STATE(2775),
    [sym_preproc_define] = STATE(2775),
    [sym_preproc_undef] = STATE(2775),
    [sym__identifier_token] = ACTIONS(4091),
    [anon_sym_alias] = ACTIONS(4091),
    [anon_sym_global] = ACTIONS(4091),
    [anon_sym_EQ] = ACTIONS(3995),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_COLON] = ACTIONS(4091),
    [anon_sym_COMMA] = ACTIONS(4088),
    [anon_sym_RBRACK] = ACTIONS(4088),
    [anon_sym_LPAREN] = ACTIONS(4088),
    [anon_sym_RPAREN] = ACTIONS(3993),
    [anon_sym_LBRACE] = ACTIONS(4088),
    [anon_sym_RBRACE] = ACTIONS(4088),
    [anon_sym_file] = ACTIONS(4091),
    [anon_sym_LT] = ACTIONS(3995),
    [anon_sym_GT] = ACTIONS(3995),
    [anon_sym_where] = ACTIONS(4091),
    [anon_sym_QMARK] = ACTIONS(3995),
    [anon_sym_notnull] = ACTIONS(4091),
    [anon_sym_unmanaged] = ACTIONS(4091),
    [anon_sym_BANG] = ACTIONS(3995),
    [anon_sym_PLUS_PLUS] = ACTIONS(3993),
    [anon_sym_DASH_DASH] = ACTIONS(3993),
    [anon_sym_PLUS] = ACTIONS(3995),
    [anon_sym_DASH] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3995),
    [anon_sym_SLASH] = ACTIONS(3995),
    [anon_sym_PERCENT] = ACTIONS(3995),
    [anon_sym_CARET] = ACTIONS(3995),
    [anon_sym_PIPE] = ACTIONS(3995),
    [anon_sym_AMP] = ACTIONS(3995),
    [anon_sym_LT_LT] = ACTIONS(3995),
    [anon_sym_GT_GT] = ACTIONS(3995),
    [anon_sym_GT_GT_GT] = ACTIONS(3995),
    [anon_sym_EQ_EQ] = ACTIONS(3993),
    [anon_sym_BANG_EQ] = ACTIONS(3993),
    [anon_sym_GT_EQ] = ACTIONS(3993),
    [anon_sym_LT_EQ] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3995),
    [anon_sym_scoped] = ACTIONS(4091),
    [anon_sym_EQ_GT] = ACTIONS(3993),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(4091),
    [anon_sym_yield] = ACTIONS(4091),
    [anon_sym_switch] = ACTIONS(3995),
    [anon_sym_when] = ACTIONS(4091),
    [sym_discard] = ACTIONS(4091),
    [anon_sym_DOT_DOT] = ACTIONS(3993),
    [anon_sym_and] = ACTIONS(4091),
    [anon_sym_or] = ACTIONS(4091),
    [anon_sym_PLUS_EQ] = ACTIONS(3993),
    [anon_sym_DASH_EQ] = ACTIONS(3993),
    [anon_sym_STAR_EQ] = ACTIONS(3993),
    [anon_sym_SLASH_EQ] = ACTIONS(3993),
    [anon_sym_PERCENT_EQ] = ACTIONS(3993),
    [anon_sym_AMP_EQ] = ACTIONS(3993),
    [anon_sym_CARET_EQ] = ACTIONS(3993),
    [anon_sym_PIPE_EQ] = ACTIONS(3993),
    [anon_sym_LT_LT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(3993),
    [anon_sym_AMP_AMP] = ACTIONS(3993),
    [anon_sym_PIPE_PIPE] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK] = ACTIONS(3995),
    [anon_sym_from] = ACTIONS(4091),
    [anon_sym_into] = ACTIONS(4091),
    [anon_sym_join] = ACTIONS(4091),
    [anon_sym_on] = ACTIONS(4091),
    [anon_sym_equals] = ACTIONS(4091),
    [anon_sym_let] = ACTIONS(4091),
    [anon_sym_orderby] = ACTIONS(4091),
    [anon_sym_ascending] = ACTIONS(4091),
    [anon_sym_descending] = ACTIONS(4091),
    [anon_sym_group] = ACTIONS(4091),
    [anon_sym_by] = ACTIONS(4091),
    [anon_sym_select] = ACTIONS(4091),
    [anon_sym_as] = ACTIONS(3995),
    [anon_sym_is] = ACTIONS(3995),
    [anon_sym_DASH_GT] = ACTIONS(3993),
    [anon_sym_with] = ACTIONS(3995),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2776] = {
    [sym_type_argument_list] = STATE(2746),
    [sym_preproc_region] = STATE(2776),
    [sym_preproc_endregion] = STATE(2776),
    [sym_preproc_line] = STATE(2776),
    [sym_preproc_pragma] = STATE(2776),
    [sym_preproc_nullable] = STATE(2776),
    [sym_preproc_error] = STATE(2776),
    [sym_preproc_warning] = STATE(2776),
    [sym_preproc_define] = STATE(2776),
    [sym_preproc_undef] = STATE(2776),
    [sym__identifier_token] = ACTIONS(4138),
    [anon_sym_alias] = ACTIONS(4138),
    [anon_sym_global] = ACTIONS(4138),
    [anon_sym_EQ] = ACTIONS(4138),
    [anon_sym_LBRACK] = ACTIONS(4140),
    [anon_sym_COLON] = ACTIONS(4138),
    [anon_sym_COMMA] = ACTIONS(4140),
    [anon_sym_LPAREN] = ACTIONS(4140),
    [anon_sym_RPAREN] = ACTIONS(4140),
    [anon_sym_LBRACE] = ACTIONS(4140),
    [anon_sym_RBRACE] = ACTIONS(4140),
    [anon_sym_file] = ACTIONS(4138),
    [anon_sym_LT] = ACTIONS(4142),
    [anon_sym_GT] = ACTIONS(4138),
    [anon_sym_where] = ACTIONS(4138),
    [anon_sym_QMARK] = ACTIONS(4138),
    [anon_sym_notnull] = ACTIONS(4138),
    [anon_sym_unmanaged] = ACTIONS(4138),
    [anon_sym_BANG] = ACTIONS(4138),
    [anon_sym_PLUS_PLUS] = ACTIONS(4140),
    [anon_sym_DASH_DASH] = ACTIONS(4140),
    [anon_sym_PLUS] = ACTIONS(4138),
    [anon_sym_DASH] = ACTIONS(4138),
    [anon_sym_STAR] = ACTIONS(4138),
    [anon_sym_SLASH] = ACTIONS(4138),
    [anon_sym_PERCENT] = ACTIONS(4138),
    [anon_sym_CARET] = ACTIONS(4138),
    [anon_sym_PIPE] = ACTIONS(4138),
    [anon_sym_AMP] = ACTIONS(4138),
    [anon_sym_LT_LT] = ACTIONS(4138),
    [anon_sym_GT_GT] = ACTIONS(4138),
    [anon_sym_GT_GT_GT] = ACTIONS(4138),
    [anon_sym_EQ_EQ] = ACTIONS(4140),
    [anon_sym_BANG_EQ] = ACTIONS(4140),
    [anon_sym_GT_EQ] = ACTIONS(4140),
    [anon_sym_LT_EQ] = ACTIONS(4140),
    [anon_sym_DOT] = ACTIONS(4138),
    [anon_sym_scoped] = ACTIONS(4138),
    [anon_sym_EQ_GT] = ACTIONS(4145),
    [anon_sym_COLON_COLON] = ACTIONS(4254),
    [anon_sym_var] = ACTIONS(4138),
    [anon_sym_yield] = ACTIONS(4138),
    [anon_sym_switch] = ACTIONS(4138),
    [anon_sym_when] = ACTIONS(4138),
    [sym_discard] = ACTIONS(4138),
    [anon_sym_DOT_DOT] = ACTIONS(4140),
    [anon_sym_and] = ACTIONS(4138),
    [anon_sym_or] = ACTIONS(4138),
    [anon_sym_PLUS_EQ] = ACTIONS(4140),
    [anon_sym_DASH_EQ] = ACTIONS(4140),
    [anon_sym_STAR_EQ] = ACTIONS(4140),
    [anon_sym_SLASH_EQ] = ACTIONS(4140),
    [anon_sym_PERCENT_EQ] = ACTIONS(4140),
    [anon_sym_AMP_EQ] = ACTIONS(4140),
    [anon_sym_CARET_EQ] = ACTIONS(4140),
    [anon_sym_PIPE_EQ] = ACTIONS(4140),
    [anon_sym_LT_LT_EQ] = ACTIONS(4140),
    [anon_sym_GT_GT_EQ] = ACTIONS(4140),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4140),
    [anon_sym_AMP_AMP] = ACTIONS(4140),
    [anon_sym_PIPE_PIPE] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK] = ACTIONS(4138),
    [anon_sym_from] = ACTIONS(4138),
    [anon_sym_into] = ACTIONS(4138),
    [anon_sym_join] = ACTIONS(4138),
    [anon_sym_on] = ACTIONS(4138),
    [anon_sym_equals] = ACTIONS(4138),
    [anon_sym_let] = ACTIONS(4138),
    [anon_sym_orderby] = ACTIONS(4138),
    [anon_sym_ascending] = ACTIONS(4138),
    [anon_sym_descending] = ACTIONS(4138),
    [anon_sym_group] = ACTIONS(4138),
    [anon_sym_by] = ACTIONS(4138),
    [anon_sym_select] = ACTIONS(4138),
    [anon_sym_as] = ACTIONS(4138),
    [anon_sym_is] = ACTIONS(4138),
    [anon_sym_DASH_GT] = ACTIONS(4140),
    [anon_sym_with] = ACTIONS(4138),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2777] = {
    [sym__variable_designation] = STATE(4155),
    [sym_parenthesized_variable_designation] = STATE(4153),
    [sym_identifier] = STATE(4156),
    [sym__reserved_identifier] = STATE(3911),
    [sym_preproc_region] = STATE(2777),
    [sym_preproc_endregion] = STATE(2777),
    [sym_preproc_line] = STATE(2777),
    [sym_preproc_pragma] = STATE(2777),
    [sym_preproc_nullable] = STATE(2777),
    [sym_preproc_error] = STATE(2777),
    [sym_preproc_warning] = STATE(2777),
    [sym_preproc_define] = STATE(2777),
    [sym_preproc_undef] = STATE(2777),
    [sym__identifier_token] = ACTIONS(4256),
    [anon_sym_alias] = ACTIONS(4260),
    [anon_sym_global] = ACTIONS(4260),
    [anon_sym_EQ] = ACTIONS(3995),
    [anon_sym_LBRACK] = ACTIONS(4088),
    [anon_sym_LPAREN] = ACTIONS(4114),
    [anon_sym_LBRACE] = ACTIONS(4088),
    [anon_sym_file] = ACTIONS(4260),
    [anon_sym_LT] = ACTIONS(4091),
    [anon_sym_GT] = ACTIONS(4091),
    [anon_sym_in] = ACTIONS(4091),
    [anon_sym_where] = ACTIONS(4260),
    [anon_sym_QMARK] = ACTIONS(4091),
    [anon_sym_notnull] = ACTIONS(4260),
    [anon_sym_unmanaged] = ACTIONS(4260),
    [anon_sym_BANG] = ACTIONS(4091),
    [anon_sym_PLUS_PLUS] = ACTIONS(4088),
    [anon_sym_DASH_DASH] = ACTIONS(4088),
    [anon_sym_PLUS] = ACTIONS(4091),
    [anon_sym_DASH] = ACTIONS(4091),
    [anon_sym_STAR] = ACTIONS(4091),
    [anon_sym_SLASH] = ACTIONS(4091),
    [anon_sym_PERCENT] = ACTIONS(4091),
    [anon_sym_CARET] = ACTIONS(4091),
    [anon_sym_PIPE] = ACTIONS(4091),
    [anon_sym_AMP] = ACTIONS(4091),
    [anon_sym_LT_LT] = ACTIONS(4091),
    [anon_sym_GT_GT] = ACTIONS(4091),
    [anon_sym_GT_GT_GT] = ACTIONS(4091),
    [anon_sym_EQ_EQ] = ACTIONS(4088),
    [anon_sym_BANG_EQ] = ACTIONS(4088),
    [anon_sym_GT_EQ] = ACTIONS(4088),
    [anon_sym_LT_EQ] = ACTIONS(4088),
    [anon_sym_DOT] = ACTIONS(4091),
    [anon_sym_scoped] = ACTIONS(4260),
    [anon_sym_EQ_GT] = ACTIONS(3993),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(4260),
    [anon_sym_yield] = ACTIONS(4260),
    [anon_sym_switch] = ACTIONS(4091),
    [anon_sym_when] = ACTIONS(4260),
    [sym_discard] = ACTIONS(4118),
    [anon_sym_DOT_DOT] = ACTIONS(4088),
    [anon_sym_and] = ACTIONS(4091),
    [anon_sym_or] = ACTIONS(4091),
    [anon_sym_PLUS_EQ] = ACTIONS(3993),
    [anon_sym_DASH_EQ] = ACTIONS(3993),
    [anon_sym_STAR_EQ] = ACTIONS(3993),
    [anon_sym_SLASH_EQ] = ACTIONS(3993),
    [anon_sym_PERCENT_EQ] = ACTIONS(3993),
    [anon_sym_AMP_EQ] = ACTIONS(3993),
    [anon_sym_CARET_EQ] = ACTIONS(3993),
    [anon_sym_PIPE_EQ] = ACTIONS(3993),
    [anon_sym_LT_LT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(3993),
    [anon_sym_AMP_AMP] = ACTIONS(4088),
    [anon_sym_PIPE_PIPE] = ACTIONS(4088),
    [anon_sym_QMARK_QMARK] = ACTIONS(4091),
    [anon_sym_from] = ACTIONS(4260),
    [anon_sym_into] = ACTIONS(4260),
    [anon_sym_join] = ACTIONS(4260),
    [anon_sym_on] = ACTIONS(4260),
    [anon_sym_equals] = ACTIONS(4260),
    [anon_sym_let] = ACTIONS(4260),
    [anon_sym_orderby] = ACTIONS(4260),
    [anon_sym_ascending] = ACTIONS(4260),
    [anon_sym_descending] = ACTIONS(4260),
    [anon_sym_group] = ACTIONS(4260),
    [anon_sym_by] = ACTIONS(4260),
    [anon_sym_select] = ACTIONS(4260),
    [anon_sym_as] = ACTIONS(4091),
    [anon_sym_is] = ACTIONS(4091),
    [anon_sym_DASH_GT] = ACTIONS(4088),
    [anon_sym_with] = ACTIONS(4091),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2778] = {
    [sym__variable_designation] = STATE(4155),
    [sym_parenthesized_variable_designation] = STATE(4153),
    [sym_identifier] = STATE(4156),
    [sym__reserved_identifier] = STATE(3165),
    [sym_preproc_region] = STATE(2778),
    [sym_preproc_endregion] = STATE(2778),
    [sym_preproc_line] = STATE(2778),
    [sym_preproc_pragma] = STATE(2778),
    [sym_preproc_nullable] = STATE(2778),
    [sym_preproc_error] = STATE(2778),
    [sym_preproc_warning] = STATE(2778),
    [sym_preproc_define] = STATE(2778),
    [sym_preproc_undef] = STATE(2778),
    [sym__identifier_token] = ACTIONS(4199),
    [anon_sym_alias] = ACTIONS(4203),
    [anon_sym_global] = ACTIONS(4203),
    [anon_sym_EQ] = ACTIONS(3995),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_COLON] = ACTIONS(4091),
    [anon_sym_LPAREN] = ACTIONS(4114),
    [anon_sym_LBRACE] = ACTIONS(4088),
    [anon_sym_file] = ACTIONS(4203),
    [anon_sym_LT] = ACTIONS(3995),
    [anon_sym_GT] = ACTIONS(3995),
    [anon_sym_where] = ACTIONS(4203),
    [anon_sym_QMARK] = ACTIONS(3995),
    [anon_sym_notnull] = ACTIONS(4203),
    [anon_sym_unmanaged] = ACTIONS(4203),
    [anon_sym_BANG] = ACTIONS(3995),
    [anon_sym_PLUS_PLUS] = ACTIONS(3993),
    [anon_sym_DASH_DASH] = ACTIONS(3993),
    [anon_sym_PLUS] = ACTIONS(3995),
    [anon_sym_DASH] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3995),
    [anon_sym_SLASH] = ACTIONS(3995),
    [anon_sym_PERCENT] = ACTIONS(3995),
    [anon_sym_CARET] = ACTIONS(3995),
    [anon_sym_PIPE] = ACTIONS(3995),
    [anon_sym_AMP] = ACTIONS(3995),
    [anon_sym_LT_LT] = ACTIONS(3995),
    [anon_sym_GT_GT] = ACTIONS(3995),
    [anon_sym_GT_GT_GT] = ACTIONS(3995),
    [anon_sym_EQ_EQ] = ACTIONS(3993),
    [anon_sym_BANG_EQ] = ACTIONS(3993),
    [anon_sym_GT_EQ] = ACTIONS(3993),
    [anon_sym_LT_EQ] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3995),
    [anon_sym_scoped] = ACTIONS(4203),
    [anon_sym_EQ_GT] = ACTIONS(3993),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(4203),
    [anon_sym_yield] = ACTIONS(4203),
    [anon_sym_switch] = ACTIONS(3995),
    [anon_sym_when] = ACTIONS(4203),
    [sym_discard] = ACTIONS(4118),
    [anon_sym_DOT_DOT] = ACTIONS(3993),
    [anon_sym_and] = ACTIONS(4091),
    [anon_sym_or] = ACTIONS(4091),
    [anon_sym_PLUS_EQ] = ACTIONS(3993),
    [anon_sym_DASH_EQ] = ACTIONS(3993),
    [anon_sym_STAR_EQ] = ACTIONS(3993),
    [anon_sym_SLASH_EQ] = ACTIONS(3993),
    [anon_sym_PERCENT_EQ] = ACTIONS(3993),
    [anon_sym_AMP_EQ] = ACTIONS(3993),
    [anon_sym_CARET_EQ] = ACTIONS(3993),
    [anon_sym_PIPE_EQ] = ACTIONS(3993),
    [anon_sym_LT_LT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(3993),
    [anon_sym_AMP_AMP] = ACTIONS(3993),
    [anon_sym_PIPE_PIPE] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK] = ACTIONS(3995),
    [anon_sym_from] = ACTIONS(4203),
    [anon_sym_into] = ACTIONS(4203),
    [anon_sym_join] = ACTIONS(4203),
    [anon_sym_on] = ACTIONS(4203),
    [anon_sym_equals] = ACTIONS(4203),
    [anon_sym_let] = ACTIONS(4203),
    [anon_sym_orderby] = ACTIONS(4203),
    [anon_sym_ascending] = ACTIONS(4203),
    [anon_sym_descending] = ACTIONS(4203),
    [anon_sym_group] = ACTIONS(4203),
    [anon_sym_by] = ACTIONS(4203),
    [anon_sym_select] = ACTIONS(4203),
    [anon_sym_as] = ACTIONS(3995),
    [anon_sym_is] = ACTIONS(3995),
    [anon_sym_DASH_GT] = ACTIONS(3993),
    [anon_sym_with] = ACTIONS(3995),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2779] = {
    [sym_type_argument_list] = STATE(2746),
    [sym_preproc_region] = STATE(2779),
    [sym_preproc_endregion] = STATE(2779),
    [sym_preproc_line] = STATE(2779),
    [sym_preproc_pragma] = STATE(2779),
    [sym_preproc_nullable] = STATE(2779),
    [sym_preproc_error] = STATE(2779),
    [sym_preproc_warning] = STATE(2779),
    [sym_preproc_define] = STATE(2779),
    [sym_preproc_undef] = STATE(2779),
    [sym__identifier_token] = ACTIONS(4138),
    [anon_sym_alias] = ACTIONS(4138),
    [anon_sym_global] = ACTIONS(4138),
    [anon_sym_EQ] = ACTIONS(4138),
    [anon_sym_LBRACK] = ACTIONS(4140),
    [anon_sym_COLON] = ACTIONS(4264),
    [anon_sym_COMMA] = ACTIONS(4140),
    [anon_sym_RBRACK] = ACTIONS(4140),
    [anon_sym_LPAREN] = ACTIONS(4140),
    [anon_sym_RPAREN] = ACTIONS(4140),
    [anon_sym_LBRACE] = ACTIONS(4140),
    [anon_sym_file] = ACTIONS(4138),
    [anon_sym_LT] = ACTIONS(4142),
    [anon_sym_GT] = ACTIONS(4138),
    [anon_sym_where] = ACTIONS(4138),
    [anon_sym_QMARK] = ACTIONS(4138),
    [anon_sym_notnull] = ACTIONS(4138),
    [anon_sym_unmanaged] = ACTIONS(4138),
    [anon_sym_BANG] = ACTIONS(4138),
    [anon_sym_PLUS_PLUS] = ACTIONS(4140),
    [anon_sym_DASH_DASH] = ACTIONS(4140),
    [anon_sym_PLUS] = ACTIONS(4138),
    [anon_sym_DASH] = ACTIONS(4138),
    [anon_sym_STAR] = ACTIONS(4138),
    [anon_sym_SLASH] = ACTIONS(4138),
    [anon_sym_PERCENT] = ACTIONS(4138),
    [anon_sym_CARET] = ACTIONS(4138),
    [anon_sym_PIPE] = ACTIONS(4138),
    [anon_sym_AMP] = ACTIONS(4138),
    [anon_sym_LT_LT] = ACTIONS(4138),
    [anon_sym_GT_GT] = ACTIONS(4138),
    [anon_sym_GT_GT_GT] = ACTIONS(4138),
    [anon_sym_EQ_EQ] = ACTIONS(4140),
    [anon_sym_BANG_EQ] = ACTIONS(4140),
    [anon_sym_GT_EQ] = ACTIONS(4140),
    [anon_sym_LT_EQ] = ACTIONS(4140),
    [anon_sym_DOT] = ACTIONS(4138),
    [anon_sym_scoped] = ACTIONS(4138),
    [anon_sym_EQ_GT] = ACTIONS(4145),
    [anon_sym_COLON_COLON] = ACTIONS(4147),
    [anon_sym_var] = ACTIONS(4138),
    [anon_sym_yield] = ACTIONS(4138),
    [anon_sym_switch] = ACTIONS(4138),
    [anon_sym_when] = ACTIONS(4138),
    [sym_discard] = ACTIONS(4138),
    [anon_sym_DOT_DOT] = ACTIONS(4140),
    [anon_sym_and] = ACTIONS(4138),
    [anon_sym_or] = ACTIONS(4138),
    [anon_sym_PLUS_EQ] = ACTIONS(4140),
    [anon_sym_DASH_EQ] = ACTIONS(4140),
    [anon_sym_STAR_EQ] = ACTIONS(4140),
    [anon_sym_SLASH_EQ] = ACTIONS(4140),
    [anon_sym_PERCENT_EQ] = ACTIONS(4140),
    [anon_sym_AMP_EQ] = ACTIONS(4140),
    [anon_sym_CARET_EQ] = ACTIONS(4140),
    [anon_sym_PIPE_EQ] = ACTIONS(4140),
    [anon_sym_LT_LT_EQ] = ACTIONS(4140),
    [anon_sym_GT_GT_EQ] = ACTIONS(4140),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4140),
    [anon_sym_AMP_AMP] = ACTIONS(4140),
    [anon_sym_PIPE_PIPE] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK] = ACTIONS(4138),
    [anon_sym_from] = ACTIONS(4138),
    [anon_sym_into] = ACTIONS(4138),
    [anon_sym_join] = ACTIONS(4138),
    [anon_sym_on] = ACTIONS(4138),
    [anon_sym_equals] = ACTIONS(4138),
    [anon_sym_let] = ACTIONS(4138),
    [anon_sym_orderby] = ACTIONS(4138),
    [anon_sym_ascending] = ACTIONS(4138),
    [anon_sym_descending] = ACTIONS(4138),
    [anon_sym_group] = ACTIONS(4138),
    [anon_sym_by] = ACTIONS(4138),
    [anon_sym_select] = ACTIONS(4138),
    [anon_sym_as] = ACTIONS(4138),
    [anon_sym_is] = ACTIONS(4138),
    [anon_sym_DASH_GT] = ACTIONS(4140),
    [anon_sym_with] = ACTIONS(4138),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2780] = {
    [sym_type_argument_list] = STATE(2746),
    [sym_preproc_region] = STATE(2780),
    [sym_preproc_endregion] = STATE(2780),
    [sym_preproc_line] = STATE(2780),
    [sym_preproc_pragma] = STATE(2780),
    [sym_preproc_nullable] = STATE(2780),
    [sym_preproc_error] = STATE(2780),
    [sym_preproc_warning] = STATE(2780),
    [sym_preproc_define] = STATE(2780),
    [sym_preproc_undef] = STATE(2780),
    [sym__identifier_token] = ACTIONS(4138),
    [anon_sym_alias] = ACTIONS(4138),
    [anon_sym_global] = ACTIONS(4138),
    [anon_sym_EQ] = ACTIONS(4266),
    [anon_sym_LBRACK] = ACTIONS(4140),
    [anon_sym_COLON] = ACTIONS(4264),
    [anon_sym_COMMA] = ACTIONS(4269),
    [anon_sym_LPAREN] = ACTIONS(4140),
    [anon_sym_RPAREN] = ACTIONS(4269),
    [anon_sym_LBRACE] = ACTIONS(4140),
    [anon_sym_file] = ACTIONS(4138),
    [anon_sym_LT] = ACTIONS(4142),
    [anon_sym_GT] = ACTIONS(4138),
    [anon_sym_where] = ACTIONS(4138),
    [anon_sym_QMARK] = ACTIONS(4138),
    [anon_sym_notnull] = ACTIONS(4138),
    [anon_sym_unmanaged] = ACTIONS(4138),
    [anon_sym_BANG] = ACTIONS(4138),
    [anon_sym_PLUS_PLUS] = ACTIONS(4140),
    [anon_sym_DASH_DASH] = ACTIONS(4140),
    [anon_sym_PLUS] = ACTIONS(4138),
    [anon_sym_DASH] = ACTIONS(4138),
    [anon_sym_STAR] = ACTIONS(4138),
    [anon_sym_SLASH] = ACTIONS(4138),
    [anon_sym_PERCENT] = ACTIONS(4138),
    [anon_sym_CARET] = ACTIONS(4138),
    [anon_sym_PIPE] = ACTIONS(4138),
    [anon_sym_AMP] = ACTIONS(4138),
    [anon_sym_LT_LT] = ACTIONS(4138),
    [anon_sym_GT_GT] = ACTIONS(4138),
    [anon_sym_GT_GT_GT] = ACTIONS(4138),
    [anon_sym_EQ_EQ] = ACTIONS(4140),
    [anon_sym_BANG_EQ] = ACTIONS(4140),
    [anon_sym_GT_EQ] = ACTIONS(4140),
    [anon_sym_LT_EQ] = ACTIONS(4140),
    [anon_sym_DOT] = ACTIONS(4138),
    [anon_sym_scoped] = ACTIONS(4138),
    [anon_sym_EQ_GT] = ACTIONS(4145),
    [anon_sym_COLON_COLON] = ACTIONS(4147),
    [anon_sym_var] = ACTIONS(4138),
    [anon_sym_yield] = ACTIONS(4138),
    [anon_sym_switch] = ACTIONS(4138),
    [anon_sym_when] = ACTIONS(4138),
    [sym_discard] = ACTIONS(4138),
    [anon_sym_DOT_DOT] = ACTIONS(4140),
    [anon_sym_and] = ACTIONS(4138),
    [anon_sym_or] = ACTIONS(4138),
    [anon_sym_PLUS_EQ] = ACTIONS(4140),
    [anon_sym_DASH_EQ] = ACTIONS(4140),
    [anon_sym_STAR_EQ] = ACTIONS(4140),
    [anon_sym_SLASH_EQ] = ACTIONS(4140),
    [anon_sym_PERCENT_EQ] = ACTIONS(4140),
    [anon_sym_AMP_EQ] = ACTIONS(4140),
    [anon_sym_CARET_EQ] = ACTIONS(4140),
    [anon_sym_PIPE_EQ] = ACTIONS(4140),
    [anon_sym_LT_LT_EQ] = ACTIONS(4140),
    [anon_sym_GT_GT_EQ] = ACTIONS(4140),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4140),
    [anon_sym_AMP_AMP] = ACTIONS(4140),
    [anon_sym_PIPE_PIPE] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK] = ACTIONS(4138),
    [anon_sym_from] = ACTIONS(4138),
    [anon_sym_into] = ACTIONS(4138),
    [anon_sym_join] = ACTIONS(4138),
    [anon_sym_on] = ACTIONS(4138),
    [anon_sym_equals] = ACTIONS(4138),
    [anon_sym_let] = ACTIONS(4138),
    [anon_sym_orderby] = ACTIONS(4138),
    [anon_sym_ascending] = ACTIONS(4138),
    [anon_sym_descending] = ACTIONS(4138),
    [anon_sym_group] = ACTIONS(4138),
    [anon_sym_by] = ACTIONS(4138),
    [anon_sym_select] = ACTIONS(4138),
    [anon_sym_as] = ACTIONS(4138),
    [anon_sym_is] = ACTIONS(4138),
    [anon_sym_DASH_GT] = ACTIONS(4140),
    [anon_sym_with] = ACTIONS(4138),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2781] = {
    [sym_attribute_list] = STATE(3740),
    [sym_modifier] = STATE(3807),
    [sym_variable_declaration] = STATE(9113),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(6417),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(6756),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(2781),
    [sym_preproc_endregion] = STATE(2781),
    [sym_preproc_line] = STATE(2781),
    [sym_preproc_pragma] = STATE(2781),
    [sym_preproc_nullable] = STATE(2781),
    [sym_preproc_error] = STATE(2781),
    [sym_preproc_warning] = STATE(2781),
    [sym_preproc_define] = STATE(2781),
    [sym_preproc_undef] = STATE(2781),
    [aux_sym_class_declaration_repeat1] = STATE(3628),
    [aux_sym_class_declaration_repeat2] = STATE(2848),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_extern] = ACTIONS(4272),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_unsafe] = ACTIONS(65),
    [anon_sym_static] = ACTIONS(65),
    [anon_sym_LBRACK] = ACTIONS(3203),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_event] = ACTIONS(4274),
    [anon_sym_class] = ACTIONS(4276),
    [anon_sym_ref] = ACTIONS(4278),
    [anon_sym_struct] = ACTIONS(4280),
    [anon_sym_enum] = ACTIONS(4282),
    [anon_sym_interface] = ACTIONS(4284),
    [anon_sym_delegate] = ACTIONS(4286),
    [anon_sym_record] = ACTIONS(4288),
    [anon_sym_abstract] = ACTIONS(65),
    [anon_sym_async] = ACTIONS(65),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_file] = ACTIONS(3225),
    [anon_sym_fixed] = ACTIONS(65),
    [anon_sym_internal] = ACTIONS(65),
    [anon_sym_new] = ACTIONS(65),
    [anon_sym_override] = ACTIONS(65),
    [anon_sym_partial] = ACTIONS(65),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_public] = ACTIONS(65),
    [anon_sym_readonly] = ACTIONS(65),
    [anon_sym_required] = ACTIONS(65),
    [anon_sym_sealed] = ACTIONS(65),
    [anon_sym_virtual] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_TILDE] = ACTIONS(4290),
    [anon_sym_implicit] = ACTIONS(4292),
    [anon_sym_explicit] = ACTIONS(4292),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2782] = {
    [sym_preproc_region] = STATE(2782),
    [sym_preproc_endregion] = STATE(2782),
    [sym_preproc_line] = STATE(2782),
    [sym_preproc_pragma] = STATE(2782),
    [sym_preproc_nullable] = STATE(2782),
    [sym_preproc_error] = STATE(2782),
    [sym_preproc_warning] = STATE(2782),
    [sym_preproc_define] = STATE(2782),
    [sym_preproc_undef] = STATE(2782),
    [sym__identifier_token] = ACTIONS(4179),
    [anon_sym_alias] = ACTIONS(4179),
    [anon_sym_global] = ACTIONS(4179),
    [anon_sym_EQ] = ACTIONS(4183),
    [anon_sym_LBRACK] = ACTIONS(4185),
    [anon_sym_COLON] = ACTIONS(4191),
    [anon_sym_COMMA] = ACTIONS(4181),
    [anon_sym_RBRACK] = ACTIONS(4181),
    [anon_sym_LPAREN] = ACTIONS(4185),
    [anon_sym_RPAREN] = ACTIONS(4191),
    [anon_sym_LBRACE] = ACTIONS(4181),
    [anon_sym_RBRACE] = ACTIONS(4181),
    [anon_sym_file] = ACTIONS(4179),
    [anon_sym_LT] = ACTIONS(4183),
    [anon_sym_GT] = ACTIONS(4183),
    [anon_sym_where] = ACTIONS(4179),
    [anon_sym_QMARK] = ACTIONS(4188),
    [anon_sym_notnull] = ACTIONS(4179),
    [anon_sym_unmanaged] = ACTIONS(4179),
    [anon_sym_BANG] = ACTIONS(4183),
    [anon_sym_PLUS_PLUS] = ACTIONS(4191),
    [anon_sym_DASH_DASH] = ACTIONS(4191),
    [anon_sym_PLUS] = ACTIONS(4183),
    [anon_sym_DASH] = ACTIONS(4183),
    [anon_sym_STAR] = ACTIONS(4188),
    [anon_sym_SLASH] = ACTIONS(4183),
    [anon_sym_PERCENT] = ACTIONS(4183),
    [anon_sym_CARET] = ACTIONS(4183),
    [anon_sym_PIPE] = ACTIONS(4183),
    [anon_sym_AMP] = ACTIONS(4183),
    [anon_sym_LT_LT] = ACTIONS(4183),
    [anon_sym_GT_GT] = ACTIONS(4183),
    [anon_sym_GT_GT_GT] = ACTIONS(4183),
    [anon_sym_EQ_EQ] = ACTIONS(4191),
    [anon_sym_BANG_EQ] = ACTIONS(4191),
    [anon_sym_GT_EQ] = ACTIONS(4191),
    [anon_sym_LT_EQ] = ACTIONS(4191),
    [anon_sym_DOT] = ACTIONS(4188),
    [anon_sym_scoped] = ACTIONS(4179),
    [anon_sym_EQ_GT] = ACTIONS(4181),
    [anon_sym_var] = ACTIONS(4179),
    [anon_sym_yield] = ACTIONS(4179),
    [anon_sym_switch] = ACTIONS(4183),
    [anon_sym_when] = ACTIONS(4179),
    [sym_discard] = ACTIONS(4179),
    [anon_sym_DOT_DOT] = ACTIONS(4191),
    [anon_sym_and] = ACTIONS(4179),
    [anon_sym_or] = ACTIONS(4179),
    [anon_sym_PLUS_EQ] = ACTIONS(4191),
    [anon_sym_DASH_EQ] = ACTIONS(4191),
    [anon_sym_STAR_EQ] = ACTIONS(4191),
    [anon_sym_SLASH_EQ] = ACTIONS(4191),
    [anon_sym_PERCENT_EQ] = ACTIONS(4191),
    [anon_sym_AMP_EQ] = ACTIONS(4191),
    [anon_sym_CARET_EQ] = ACTIONS(4191),
    [anon_sym_PIPE_EQ] = ACTIONS(4191),
    [anon_sym_LT_LT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4191),
    [anon_sym_AMP_AMP] = ACTIONS(4191),
    [anon_sym_PIPE_PIPE] = ACTIONS(4191),
    [anon_sym_QMARK_QMARK] = ACTIONS(4183),
    [anon_sym_from] = ACTIONS(4179),
    [anon_sym_into] = ACTIONS(4179),
    [anon_sym_join] = ACTIONS(4179),
    [anon_sym_on] = ACTIONS(4179),
    [anon_sym_equals] = ACTIONS(4179),
    [anon_sym_let] = ACTIONS(4179),
    [anon_sym_orderby] = ACTIONS(4179),
    [anon_sym_ascending] = ACTIONS(4179),
    [anon_sym_descending] = ACTIONS(4179),
    [anon_sym_group] = ACTIONS(4179),
    [anon_sym_by] = ACTIONS(4179),
    [anon_sym_select] = ACTIONS(4179),
    [anon_sym_as] = ACTIONS(4183),
    [anon_sym_is] = ACTIONS(4183),
    [anon_sym_DASH_GT] = ACTIONS(4185),
    [anon_sym_with] = ACTIONS(4183),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2783] = {
    [sym__variable_designation] = STATE(4155),
    [sym_parenthesized_variable_designation] = STATE(4153),
    [sym_identifier] = STATE(4156),
    [sym__reserved_identifier] = STATE(3165),
    [sym_preproc_region] = STATE(2783),
    [sym_preproc_endregion] = STATE(2783),
    [sym_preproc_line] = STATE(2783),
    [sym_preproc_pragma] = STATE(2783),
    [sym_preproc_nullable] = STATE(2783),
    [sym_preproc_error] = STATE(2783),
    [sym_preproc_warning] = STATE(2783),
    [sym_preproc_define] = STATE(2783),
    [sym_preproc_undef] = STATE(2783),
    [sym__identifier_token] = ACTIONS(4199),
    [anon_sym_alias] = ACTIONS(4203),
    [anon_sym_global] = ACTIONS(4203),
    [anon_sym_EQ] = ACTIONS(3995),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_LPAREN] = ACTIONS(4114),
    [anon_sym_LBRACE] = ACTIONS(4088),
    [anon_sym_file] = ACTIONS(4203),
    [anon_sym_LT] = ACTIONS(3995),
    [anon_sym_GT] = ACTIONS(3995),
    [anon_sym_where] = ACTIONS(4203),
    [anon_sym_QMARK] = ACTIONS(3995),
    [anon_sym_notnull] = ACTIONS(4203),
    [anon_sym_unmanaged] = ACTIONS(4203),
    [anon_sym_BANG] = ACTIONS(3995),
    [anon_sym_PLUS_PLUS] = ACTIONS(3993),
    [anon_sym_DASH_DASH] = ACTIONS(3993),
    [anon_sym_PLUS] = ACTIONS(3995),
    [anon_sym_DASH] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3995),
    [anon_sym_SLASH] = ACTIONS(3995),
    [anon_sym_PERCENT] = ACTIONS(3995),
    [anon_sym_CARET] = ACTIONS(3995),
    [anon_sym_PIPE] = ACTIONS(3995),
    [anon_sym_AMP] = ACTIONS(3995),
    [anon_sym_LT_LT] = ACTIONS(3995),
    [anon_sym_GT_GT] = ACTIONS(3995),
    [anon_sym_GT_GT_GT] = ACTIONS(3995),
    [anon_sym_EQ_EQ] = ACTIONS(3993),
    [anon_sym_BANG_EQ] = ACTIONS(3993),
    [anon_sym_GT_EQ] = ACTIONS(3993),
    [anon_sym_LT_EQ] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3995),
    [anon_sym_scoped] = ACTIONS(4203),
    [anon_sym_EQ_GT] = ACTIONS(4088),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(4203),
    [anon_sym_yield] = ACTIONS(4203),
    [anon_sym_switch] = ACTIONS(3995),
    [anon_sym_when] = ACTIONS(4203),
    [sym_discard] = ACTIONS(4118),
    [anon_sym_DOT_DOT] = ACTIONS(3993),
    [anon_sym_and] = ACTIONS(4091),
    [anon_sym_or] = ACTIONS(4091),
    [anon_sym_PLUS_EQ] = ACTIONS(3993),
    [anon_sym_DASH_EQ] = ACTIONS(3993),
    [anon_sym_STAR_EQ] = ACTIONS(3993),
    [anon_sym_SLASH_EQ] = ACTIONS(3993),
    [anon_sym_PERCENT_EQ] = ACTIONS(3993),
    [anon_sym_AMP_EQ] = ACTIONS(3993),
    [anon_sym_CARET_EQ] = ACTIONS(3993),
    [anon_sym_PIPE_EQ] = ACTIONS(3993),
    [anon_sym_LT_LT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(3993),
    [anon_sym_AMP_AMP] = ACTIONS(3993),
    [anon_sym_PIPE_PIPE] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK] = ACTIONS(3995),
    [anon_sym_from] = ACTIONS(4203),
    [anon_sym_into] = ACTIONS(4203),
    [anon_sym_join] = ACTIONS(4203),
    [anon_sym_on] = ACTIONS(4203),
    [anon_sym_equals] = ACTIONS(4203),
    [anon_sym_let] = ACTIONS(4203),
    [anon_sym_orderby] = ACTIONS(4203),
    [anon_sym_ascending] = ACTIONS(4203),
    [anon_sym_descending] = ACTIONS(4203),
    [anon_sym_group] = ACTIONS(4203),
    [anon_sym_by] = ACTIONS(4203),
    [anon_sym_select] = ACTIONS(4203),
    [anon_sym_as] = ACTIONS(3995),
    [anon_sym_is] = ACTIONS(3995),
    [anon_sym_DASH_GT] = ACTIONS(3993),
    [anon_sym_with] = ACTIONS(3995),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2784] = {
    [sym__variable_designation] = STATE(5033),
    [sym_parenthesized_variable_designation] = STATE(5027),
    [sym_identifier] = STATE(5034),
    [sym__reserved_identifier] = STATE(3572),
    [sym_preproc_region] = STATE(2784),
    [sym_preproc_endregion] = STATE(2784),
    [sym_preproc_line] = STATE(2784),
    [sym_preproc_pragma] = STATE(2784),
    [sym_preproc_nullable] = STATE(2784),
    [sym_preproc_error] = STATE(2784),
    [sym_preproc_warning] = STATE(2784),
    [sym_preproc_define] = STATE(2784),
    [sym_preproc_undef] = STATE(2784),
    [sym__identifier_token] = ACTIONS(4294),
    [anon_sym_alias] = ACTIONS(4298),
    [anon_sym_global] = ACTIONS(4298),
    [anon_sym_EQ] = ACTIONS(3995),
    [anon_sym_LBRACK] = ACTIONS(4088),
    [anon_sym_LPAREN] = ACTIONS(4302),
    [anon_sym_LBRACE] = ACTIONS(4088),
    [anon_sym_file] = ACTIONS(4298),
    [anon_sym_LT] = ACTIONS(4091),
    [anon_sym_GT] = ACTIONS(4091),
    [anon_sym_where] = ACTIONS(4298),
    [anon_sym_QMARK] = ACTIONS(4091),
    [anon_sym_notnull] = ACTIONS(4298),
    [anon_sym_unmanaged] = ACTIONS(4298),
    [anon_sym_BANG] = ACTIONS(4091),
    [anon_sym_PLUS_PLUS] = ACTIONS(4088),
    [anon_sym_DASH_DASH] = ACTIONS(4088),
    [anon_sym_PLUS] = ACTIONS(4091),
    [anon_sym_DASH] = ACTIONS(4091),
    [anon_sym_STAR] = ACTIONS(4091),
    [anon_sym_SLASH] = ACTIONS(4091),
    [anon_sym_PERCENT] = ACTIONS(4091),
    [anon_sym_CARET] = ACTIONS(4091),
    [anon_sym_PIPE] = ACTIONS(4091),
    [anon_sym_AMP] = ACTIONS(4091),
    [anon_sym_LT_LT] = ACTIONS(4091),
    [anon_sym_GT_GT] = ACTIONS(4091),
    [anon_sym_GT_GT_GT] = ACTIONS(4091),
    [anon_sym_EQ_EQ] = ACTIONS(4088),
    [anon_sym_BANG_EQ] = ACTIONS(4088),
    [anon_sym_GT_EQ] = ACTIONS(4088),
    [anon_sym_LT_EQ] = ACTIONS(4088),
    [anon_sym_DOT] = ACTIONS(4091),
    [anon_sym_scoped] = ACTIONS(4298),
    [anon_sym_EQ_GT] = ACTIONS(3993),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(4298),
    [anon_sym_yield] = ACTIONS(4298),
    [anon_sym_switch] = ACTIONS(4091),
    [anon_sym_when] = ACTIONS(4298),
    [sym_discard] = ACTIONS(4306),
    [anon_sym_DOT_DOT] = ACTIONS(4088),
    [anon_sym_and] = ACTIONS(4091),
    [anon_sym_or] = ACTIONS(4091),
    [anon_sym_PLUS_EQ] = ACTIONS(3993),
    [anon_sym_DASH_EQ] = ACTIONS(3993),
    [anon_sym_STAR_EQ] = ACTIONS(3993),
    [anon_sym_SLASH_EQ] = ACTIONS(3993),
    [anon_sym_PERCENT_EQ] = ACTIONS(3993),
    [anon_sym_AMP_EQ] = ACTIONS(3993),
    [anon_sym_CARET_EQ] = ACTIONS(3993),
    [anon_sym_PIPE_EQ] = ACTIONS(3993),
    [anon_sym_LT_LT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(3993),
    [anon_sym_AMP_AMP] = ACTIONS(4088),
    [anon_sym_PIPE_PIPE] = ACTIONS(4088),
    [anon_sym_QMARK_QMARK] = ACTIONS(4091),
    [anon_sym_from] = ACTIONS(4298),
    [anon_sym_into] = ACTIONS(4298),
    [anon_sym_join] = ACTIONS(4298),
    [anon_sym_on] = ACTIONS(4298),
    [anon_sym_equals] = ACTIONS(4298),
    [anon_sym_let] = ACTIONS(4298),
    [anon_sym_orderby] = ACTIONS(4298),
    [anon_sym_ascending] = ACTIONS(4298),
    [anon_sym_descending] = ACTIONS(4298),
    [anon_sym_group] = ACTIONS(4298),
    [anon_sym_by] = ACTIONS(4298),
    [anon_sym_select] = ACTIONS(4298),
    [anon_sym_as] = ACTIONS(4091),
    [anon_sym_is] = ACTIONS(4091),
    [anon_sym_DASH_GT] = ACTIONS(4088),
    [anon_sym_with] = ACTIONS(4091),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2785] = {
    [sym_type_argument_list] = STATE(2746),
    [sym_preproc_region] = STATE(2785),
    [sym_preproc_endregion] = STATE(2785),
    [sym_preproc_line] = STATE(2785),
    [sym_preproc_pragma] = STATE(2785),
    [sym_preproc_nullable] = STATE(2785),
    [sym_preproc_error] = STATE(2785),
    [sym_preproc_warning] = STATE(2785),
    [sym_preproc_define] = STATE(2785),
    [sym_preproc_undef] = STATE(2785),
    [sym__identifier_token] = ACTIONS(4138),
    [anon_sym_alias] = ACTIONS(4138),
    [anon_sym_global] = ACTIONS(4138),
    [anon_sym_EQ] = ACTIONS(4266),
    [anon_sym_LBRACK] = ACTIONS(4140),
    [anon_sym_COLON] = ACTIONS(4264),
    [anon_sym_COMMA] = ACTIONS(4310),
    [anon_sym_LPAREN] = ACTIONS(4140),
    [anon_sym_RPAREN] = ACTIONS(4310),
    [anon_sym_LBRACE] = ACTIONS(4140),
    [anon_sym_file] = ACTIONS(4138),
    [anon_sym_LT] = ACTIONS(4142),
    [anon_sym_GT] = ACTIONS(4138),
    [anon_sym_where] = ACTIONS(4138),
    [anon_sym_QMARK] = ACTIONS(4138),
    [anon_sym_notnull] = ACTIONS(4138),
    [anon_sym_unmanaged] = ACTIONS(4138),
    [anon_sym_BANG] = ACTIONS(4138),
    [anon_sym_PLUS_PLUS] = ACTIONS(4140),
    [anon_sym_DASH_DASH] = ACTIONS(4140),
    [anon_sym_PLUS] = ACTIONS(4138),
    [anon_sym_DASH] = ACTIONS(4138),
    [anon_sym_STAR] = ACTIONS(4138),
    [anon_sym_SLASH] = ACTIONS(4138),
    [anon_sym_PERCENT] = ACTIONS(4138),
    [anon_sym_CARET] = ACTIONS(4138),
    [anon_sym_PIPE] = ACTIONS(4138),
    [anon_sym_AMP] = ACTIONS(4138),
    [anon_sym_LT_LT] = ACTIONS(4138),
    [anon_sym_GT_GT] = ACTIONS(4138),
    [anon_sym_GT_GT_GT] = ACTIONS(4138),
    [anon_sym_EQ_EQ] = ACTIONS(4140),
    [anon_sym_BANG_EQ] = ACTIONS(4140),
    [anon_sym_GT_EQ] = ACTIONS(4140),
    [anon_sym_LT_EQ] = ACTIONS(4140),
    [anon_sym_DOT] = ACTIONS(4138),
    [anon_sym_scoped] = ACTIONS(4138),
    [anon_sym_EQ_GT] = ACTIONS(4145),
    [anon_sym_COLON_COLON] = ACTIONS(4147),
    [anon_sym_var] = ACTIONS(4138),
    [anon_sym_yield] = ACTIONS(4138),
    [anon_sym_switch] = ACTIONS(4138),
    [anon_sym_when] = ACTIONS(4138),
    [sym_discard] = ACTIONS(4138),
    [anon_sym_DOT_DOT] = ACTIONS(4140),
    [anon_sym_and] = ACTIONS(4138),
    [anon_sym_or] = ACTIONS(4138),
    [anon_sym_PLUS_EQ] = ACTIONS(4140),
    [anon_sym_DASH_EQ] = ACTIONS(4140),
    [anon_sym_STAR_EQ] = ACTIONS(4140),
    [anon_sym_SLASH_EQ] = ACTIONS(4140),
    [anon_sym_PERCENT_EQ] = ACTIONS(4140),
    [anon_sym_AMP_EQ] = ACTIONS(4140),
    [anon_sym_CARET_EQ] = ACTIONS(4140),
    [anon_sym_PIPE_EQ] = ACTIONS(4140),
    [anon_sym_LT_LT_EQ] = ACTIONS(4140),
    [anon_sym_GT_GT_EQ] = ACTIONS(4140),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4140),
    [anon_sym_AMP_AMP] = ACTIONS(4140),
    [anon_sym_PIPE_PIPE] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK] = ACTIONS(4138),
    [anon_sym_from] = ACTIONS(4138),
    [anon_sym_into] = ACTIONS(4138),
    [anon_sym_join] = ACTIONS(4138),
    [anon_sym_on] = ACTIONS(4138),
    [anon_sym_equals] = ACTIONS(4138),
    [anon_sym_let] = ACTIONS(4138),
    [anon_sym_orderby] = ACTIONS(4138),
    [anon_sym_ascending] = ACTIONS(4138),
    [anon_sym_descending] = ACTIONS(4138),
    [anon_sym_group] = ACTIONS(4138),
    [anon_sym_by] = ACTIONS(4138),
    [anon_sym_select] = ACTIONS(4138),
    [anon_sym_as] = ACTIONS(4138),
    [anon_sym_is] = ACTIONS(4138),
    [anon_sym_DASH_GT] = ACTIONS(4140),
    [anon_sym_with] = ACTIONS(4138),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2786] = {
    [sym__variable_designation] = STATE(5033),
    [sym_parenthesized_variable_designation] = STATE(5027),
    [sym_identifier] = STATE(5034),
    [sym__reserved_identifier] = STATE(3625),
    [sym_preproc_region] = STATE(2786),
    [sym_preproc_endregion] = STATE(2786),
    [sym_preproc_line] = STATE(2786),
    [sym_preproc_pragma] = STATE(2786),
    [sym_preproc_nullable] = STATE(2786),
    [sym_preproc_error] = STATE(2786),
    [sym_preproc_warning] = STATE(2786),
    [sym_preproc_define] = STATE(2786),
    [sym_preproc_undef] = STATE(2786),
    [sym__identifier_token] = ACTIONS(4312),
    [anon_sym_alias] = ACTIONS(4316),
    [anon_sym_global] = ACTIONS(4316),
    [anon_sym_EQ] = ACTIONS(3995),
    [anon_sym_LBRACK] = ACTIONS(4088),
    [anon_sym_LPAREN] = ACTIONS(4302),
    [anon_sym_LBRACE] = ACTIONS(4088),
    [anon_sym_file] = ACTIONS(4316),
    [anon_sym_LT] = ACTIONS(4091),
    [anon_sym_GT] = ACTIONS(4091),
    [anon_sym_where] = ACTIONS(4316),
    [anon_sym_QMARK] = ACTIONS(4091),
    [anon_sym_notnull] = ACTIONS(4316),
    [anon_sym_unmanaged] = ACTIONS(4316),
    [anon_sym_BANG] = ACTIONS(4091),
    [anon_sym_PLUS_PLUS] = ACTIONS(4088),
    [anon_sym_DASH_DASH] = ACTIONS(4088),
    [anon_sym_PLUS] = ACTIONS(4091),
    [anon_sym_DASH] = ACTIONS(4091),
    [anon_sym_STAR] = ACTIONS(4091),
    [anon_sym_SLASH] = ACTIONS(4091),
    [anon_sym_PERCENT] = ACTIONS(4091),
    [anon_sym_CARET] = ACTIONS(4091),
    [anon_sym_PIPE] = ACTIONS(4091),
    [anon_sym_AMP] = ACTIONS(4091),
    [anon_sym_LT_LT] = ACTIONS(4091),
    [anon_sym_GT_GT] = ACTIONS(4091),
    [anon_sym_GT_GT_GT] = ACTIONS(4091),
    [anon_sym_EQ_EQ] = ACTIONS(4088),
    [anon_sym_BANG_EQ] = ACTIONS(4088),
    [anon_sym_GT_EQ] = ACTIONS(4088),
    [anon_sym_LT_EQ] = ACTIONS(4088),
    [anon_sym_DOT] = ACTIONS(4091),
    [anon_sym_scoped] = ACTIONS(4316),
    [anon_sym_EQ_GT] = ACTIONS(3993),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(4316),
    [anon_sym_yield] = ACTIONS(4316),
    [anon_sym_switch] = ACTIONS(4091),
    [anon_sym_when] = ACTIONS(4316),
    [sym_discard] = ACTIONS(4306),
    [anon_sym_DOT_DOT] = ACTIONS(4088),
    [anon_sym_and] = ACTIONS(4091),
    [anon_sym_or] = ACTIONS(4091),
    [anon_sym_PLUS_EQ] = ACTIONS(3993),
    [anon_sym_DASH_EQ] = ACTIONS(3993),
    [anon_sym_STAR_EQ] = ACTIONS(3993),
    [anon_sym_SLASH_EQ] = ACTIONS(3993),
    [anon_sym_PERCENT_EQ] = ACTIONS(3993),
    [anon_sym_AMP_EQ] = ACTIONS(3993),
    [anon_sym_CARET_EQ] = ACTIONS(3993),
    [anon_sym_PIPE_EQ] = ACTIONS(3993),
    [anon_sym_LT_LT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(3993),
    [anon_sym_AMP_AMP] = ACTIONS(4088),
    [anon_sym_PIPE_PIPE] = ACTIONS(4088),
    [anon_sym_QMARK_QMARK] = ACTIONS(4091),
    [anon_sym_from] = ACTIONS(4316),
    [anon_sym_into] = ACTIONS(4316),
    [anon_sym_join] = ACTIONS(4316),
    [anon_sym_on] = ACTIONS(4316),
    [anon_sym_equals] = ACTIONS(4316),
    [anon_sym_let] = ACTIONS(4316),
    [anon_sym_orderby] = ACTIONS(4316),
    [anon_sym_ascending] = ACTIONS(4316),
    [anon_sym_descending] = ACTIONS(4316),
    [anon_sym_group] = ACTIONS(4316),
    [anon_sym_by] = ACTIONS(4316),
    [anon_sym_select] = ACTIONS(4316),
    [anon_sym_as] = ACTIONS(4091),
    [anon_sym_is] = ACTIONS(4091),
    [anon_sym_DASH_GT] = ACTIONS(4088),
    [anon_sym_with] = ACTIONS(4091),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2787] = {
    [sym_preproc_region] = STATE(2787),
    [sym_preproc_endregion] = STATE(2787),
    [sym_preproc_line] = STATE(2787),
    [sym_preproc_pragma] = STATE(2787),
    [sym_preproc_nullable] = STATE(2787),
    [sym_preproc_error] = STATE(2787),
    [sym_preproc_warning] = STATE(2787),
    [sym_preproc_define] = STATE(2787),
    [sym_preproc_undef] = STATE(2787),
    [sym__identifier_token] = ACTIONS(4091),
    [anon_sym_alias] = ACTIONS(4091),
    [anon_sym_global] = ACTIONS(4091),
    [anon_sym_EQ] = ACTIONS(3995),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_COLON] = ACTIONS(3995),
    [anon_sym_COMMA] = ACTIONS(4088),
    [anon_sym_LPAREN] = ACTIONS(4088),
    [anon_sym_RPAREN] = ACTIONS(4088),
    [anon_sym_LBRACE] = ACTIONS(4088),
    [anon_sym_RBRACE] = ACTIONS(4088),
    [anon_sym_file] = ACTIONS(4091),
    [anon_sym_LT] = ACTIONS(3995),
    [anon_sym_GT] = ACTIONS(3995),
    [anon_sym_where] = ACTIONS(4091),
    [anon_sym_QMARK] = ACTIONS(3995),
    [anon_sym_notnull] = ACTIONS(4091),
    [anon_sym_unmanaged] = ACTIONS(4091),
    [anon_sym_BANG] = ACTIONS(3995),
    [anon_sym_PLUS_PLUS] = ACTIONS(3993),
    [anon_sym_DASH_DASH] = ACTIONS(3993),
    [anon_sym_PLUS] = ACTIONS(3995),
    [anon_sym_DASH] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3995),
    [anon_sym_SLASH] = ACTIONS(3995),
    [anon_sym_PERCENT] = ACTIONS(3995),
    [anon_sym_CARET] = ACTIONS(3995),
    [anon_sym_PIPE] = ACTIONS(3995),
    [anon_sym_AMP] = ACTIONS(3995),
    [anon_sym_LT_LT] = ACTIONS(3995),
    [anon_sym_GT_GT] = ACTIONS(3995),
    [anon_sym_GT_GT_GT] = ACTIONS(3995),
    [anon_sym_EQ_EQ] = ACTIONS(3993),
    [anon_sym_BANG_EQ] = ACTIONS(3993),
    [anon_sym_GT_EQ] = ACTIONS(3993),
    [anon_sym_LT_EQ] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3995),
    [anon_sym_scoped] = ACTIONS(4091),
    [anon_sym_EQ_GT] = ACTIONS(3993),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(4091),
    [anon_sym_yield] = ACTIONS(4091),
    [anon_sym_switch] = ACTIONS(3995),
    [anon_sym_when] = ACTIONS(4091),
    [sym_discard] = ACTIONS(4091),
    [anon_sym_DOT_DOT] = ACTIONS(3993),
    [anon_sym_and] = ACTIONS(4091),
    [anon_sym_or] = ACTIONS(4091),
    [anon_sym_PLUS_EQ] = ACTIONS(3993),
    [anon_sym_DASH_EQ] = ACTIONS(3993),
    [anon_sym_STAR_EQ] = ACTIONS(3993),
    [anon_sym_SLASH_EQ] = ACTIONS(3993),
    [anon_sym_PERCENT_EQ] = ACTIONS(3993),
    [anon_sym_AMP_EQ] = ACTIONS(3993),
    [anon_sym_CARET_EQ] = ACTIONS(3993),
    [anon_sym_PIPE_EQ] = ACTIONS(3993),
    [anon_sym_LT_LT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(3993),
    [anon_sym_AMP_AMP] = ACTIONS(3993),
    [anon_sym_PIPE_PIPE] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK] = ACTIONS(3995),
    [anon_sym_from] = ACTIONS(4091),
    [anon_sym_into] = ACTIONS(4091),
    [anon_sym_join] = ACTIONS(4091),
    [anon_sym_on] = ACTIONS(4091),
    [anon_sym_equals] = ACTIONS(4091),
    [anon_sym_let] = ACTIONS(4091),
    [anon_sym_orderby] = ACTIONS(4091),
    [anon_sym_ascending] = ACTIONS(4091),
    [anon_sym_descending] = ACTIONS(4091),
    [anon_sym_group] = ACTIONS(4091),
    [anon_sym_by] = ACTIONS(4091),
    [anon_sym_select] = ACTIONS(4091),
    [anon_sym_as] = ACTIONS(3995),
    [anon_sym_is] = ACTIONS(3995),
    [anon_sym_DASH_GT] = ACTIONS(3993),
    [anon_sym_with] = ACTIONS(3995),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2788] = {
    [sym__variable_designation] = STATE(4155),
    [sym_parenthesized_variable_designation] = STATE(4153),
    [sym_identifier] = STATE(4156),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(2788),
    [sym_preproc_endregion] = STATE(2788),
    [sym_preproc_line] = STATE(2788),
    [sym_preproc_pragma] = STATE(2788),
    [sym_preproc_nullable] = STATE(2788),
    [sym_preproc_error] = STATE(2788),
    [sym_preproc_warning] = STATE(2788),
    [sym_preproc_define] = STATE(2788),
    [sym_preproc_undef] = STATE(2788),
    [sym__identifier_token] = ACTIONS(4080),
    [anon_sym_alias] = ACTIONS(4084),
    [anon_sym_global] = ACTIONS(4084),
    [anon_sym_EQ] = ACTIONS(3995),
    [anon_sym_LBRACK] = ACTIONS(4088),
    [anon_sym_LPAREN] = ACTIONS(4114),
    [anon_sym_LBRACE] = ACTIONS(4088),
    [anon_sym_file] = ACTIONS(4084),
    [anon_sym_LT] = ACTIONS(4091),
    [anon_sym_GT] = ACTIONS(4091),
    [anon_sym_where] = ACTIONS(4084),
    [anon_sym_QMARK] = ACTIONS(4091),
    [anon_sym_notnull] = ACTIONS(4084),
    [anon_sym_unmanaged] = ACTIONS(4084),
    [anon_sym_BANG] = ACTIONS(4091),
    [anon_sym_PLUS_PLUS] = ACTIONS(4088),
    [anon_sym_DASH_DASH] = ACTIONS(4088),
    [anon_sym_PLUS] = ACTIONS(4091),
    [anon_sym_DASH] = ACTIONS(4091),
    [anon_sym_STAR] = ACTIONS(4091),
    [anon_sym_SLASH] = ACTIONS(4091),
    [anon_sym_PERCENT] = ACTIONS(4091),
    [anon_sym_CARET] = ACTIONS(4091),
    [anon_sym_PIPE] = ACTIONS(4091),
    [anon_sym_AMP] = ACTIONS(4091),
    [anon_sym_LT_LT] = ACTIONS(4091),
    [anon_sym_GT_GT] = ACTIONS(4091),
    [anon_sym_GT_GT_GT] = ACTIONS(4091),
    [anon_sym_EQ_EQ] = ACTIONS(4088),
    [anon_sym_BANG_EQ] = ACTIONS(4088),
    [anon_sym_GT_EQ] = ACTIONS(4088),
    [anon_sym_LT_EQ] = ACTIONS(4088),
    [anon_sym_DOT] = ACTIONS(4091),
    [anon_sym_scoped] = ACTIONS(4084),
    [anon_sym_EQ_GT] = ACTIONS(4088),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(4084),
    [anon_sym_yield] = ACTIONS(4084),
    [anon_sym_switch] = ACTIONS(4091),
    [anon_sym_when] = ACTIONS(4084),
    [sym_discard] = ACTIONS(4118),
    [anon_sym_DOT_DOT] = ACTIONS(4088),
    [anon_sym_and] = ACTIONS(4091),
    [anon_sym_or] = ACTIONS(4091),
    [anon_sym_PLUS_EQ] = ACTIONS(3993),
    [anon_sym_DASH_EQ] = ACTIONS(3993),
    [anon_sym_STAR_EQ] = ACTIONS(3993),
    [anon_sym_SLASH_EQ] = ACTIONS(3993),
    [anon_sym_PERCENT_EQ] = ACTIONS(3993),
    [anon_sym_AMP_EQ] = ACTIONS(3993),
    [anon_sym_CARET_EQ] = ACTIONS(3993),
    [anon_sym_PIPE_EQ] = ACTIONS(3993),
    [anon_sym_LT_LT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(3993),
    [anon_sym_AMP_AMP] = ACTIONS(4088),
    [anon_sym_PIPE_PIPE] = ACTIONS(4088),
    [anon_sym_QMARK_QMARK] = ACTIONS(4091),
    [anon_sym_from] = ACTIONS(4084),
    [anon_sym_into] = ACTIONS(4084),
    [anon_sym_join] = ACTIONS(4084),
    [anon_sym_on] = ACTIONS(4084),
    [anon_sym_equals] = ACTIONS(4084),
    [anon_sym_let] = ACTIONS(4084),
    [anon_sym_orderby] = ACTIONS(4084),
    [anon_sym_ascending] = ACTIONS(4084),
    [anon_sym_descending] = ACTIONS(4084),
    [anon_sym_group] = ACTIONS(4084),
    [anon_sym_by] = ACTIONS(4084),
    [anon_sym_select] = ACTIONS(4084),
    [anon_sym_as] = ACTIONS(4091),
    [anon_sym_is] = ACTIONS(4091),
    [anon_sym_DASH_GT] = ACTIONS(4088),
    [anon_sym_with] = ACTIONS(4091),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2789] = {
    [sym_preproc_region] = STATE(2789),
    [sym_preproc_endregion] = STATE(2789),
    [sym_preproc_line] = STATE(2789),
    [sym_preproc_pragma] = STATE(2789),
    [sym_preproc_nullable] = STATE(2789),
    [sym_preproc_error] = STATE(2789),
    [sym_preproc_warning] = STATE(2789),
    [sym_preproc_define] = STATE(2789),
    [sym_preproc_undef] = STATE(2789),
    [sym__identifier_token] = ACTIONS(4157),
    [anon_sym_alias] = ACTIONS(4157),
    [anon_sym_global] = ACTIONS(4157),
    [anon_sym_EQ] = ACTIONS(4162),
    [anon_sym_LBRACK] = ACTIONS(4193),
    [anon_sym_COLON] = ACTIONS(4177),
    [anon_sym_COMMA] = ACTIONS(4168),
    [anon_sym_RBRACK] = ACTIONS(4168),
    [anon_sym_LPAREN] = ACTIONS(4193),
    [anon_sym_RPAREN] = ACTIONS(4177),
    [anon_sym_LBRACE] = ACTIONS(4168),
    [anon_sym_RBRACE] = ACTIONS(4168),
    [anon_sym_file] = ACTIONS(4157),
    [anon_sym_LT] = ACTIONS(4162),
    [anon_sym_GT] = ACTIONS(4162),
    [anon_sym_where] = ACTIONS(4157),
    [anon_sym_QMARK] = ACTIONS(4196),
    [anon_sym_notnull] = ACTIONS(4157),
    [anon_sym_unmanaged] = ACTIONS(4157),
    [anon_sym_BANG] = ACTIONS(4162),
    [anon_sym_PLUS_PLUS] = ACTIONS(4177),
    [anon_sym_DASH_DASH] = ACTIONS(4177),
    [anon_sym_PLUS] = ACTIONS(4162),
    [anon_sym_DASH] = ACTIONS(4162),
    [anon_sym_STAR] = ACTIONS(4196),
    [anon_sym_SLASH] = ACTIONS(4162),
    [anon_sym_PERCENT] = ACTIONS(4162),
    [anon_sym_CARET] = ACTIONS(4162),
    [anon_sym_PIPE] = ACTIONS(4162),
    [anon_sym_AMP] = ACTIONS(4162),
    [anon_sym_LT_LT] = ACTIONS(4162),
    [anon_sym_GT_GT] = ACTIONS(4162),
    [anon_sym_GT_GT_GT] = ACTIONS(4162),
    [anon_sym_EQ_EQ] = ACTIONS(4177),
    [anon_sym_BANG_EQ] = ACTIONS(4177),
    [anon_sym_GT_EQ] = ACTIONS(4177),
    [anon_sym_LT_EQ] = ACTIONS(4177),
    [anon_sym_DOT] = ACTIONS(4196),
    [anon_sym_scoped] = ACTIONS(4157),
    [anon_sym_EQ_GT] = ACTIONS(4168),
    [anon_sym_var] = ACTIONS(4157),
    [anon_sym_yield] = ACTIONS(4157),
    [anon_sym_switch] = ACTIONS(4162),
    [anon_sym_when] = ACTIONS(4157),
    [sym_discard] = ACTIONS(4157),
    [anon_sym_DOT_DOT] = ACTIONS(4177),
    [anon_sym_and] = ACTIONS(4157),
    [anon_sym_or] = ACTIONS(4157),
    [anon_sym_PLUS_EQ] = ACTIONS(4177),
    [anon_sym_DASH_EQ] = ACTIONS(4177),
    [anon_sym_STAR_EQ] = ACTIONS(4177),
    [anon_sym_SLASH_EQ] = ACTIONS(4177),
    [anon_sym_PERCENT_EQ] = ACTIONS(4177),
    [anon_sym_AMP_EQ] = ACTIONS(4177),
    [anon_sym_CARET_EQ] = ACTIONS(4177),
    [anon_sym_PIPE_EQ] = ACTIONS(4177),
    [anon_sym_LT_LT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4177),
    [anon_sym_AMP_AMP] = ACTIONS(4177),
    [anon_sym_PIPE_PIPE] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK] = ACTIONS(4162),
    [anon_sym_from] = ACTIONS(4157),
    [anon_sym_into] = ACTIONS(4157),
    [anon_sym_join] = ACTIONS(4157),
    [anon_sym_on] = ACTIONS(4157),
    [anon_sym_equals] = ACTIONS(4157),
    [anon_sym_let] = ACTIONS(4157),
    [anon_sym_orderby] = ACTIONS(4157),
    [anon_sym_ascending] = ACTIONS(4157),
    [anon_sym_descending] = ACTIONS(4157),
    [anon_sym_group] = ACTIONS(4157),
    [anon_sym_by] = ACTIONS(4157),
    [anon_sym_select] = ACTIONS(4157),
    [anon_sym_as] = ACTIONS(4162),
    [anon_sym_is] = ACTIONS(4162),
    [anon_sym_DASH_GT] = ACTIONS(4193),
    [anon_sym_with] = ACTIONS(4162),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2790] = {
    [sym_type_argument_list] = STATE(2746),
    [sym_preproc_region] = STATE(2790),
    [sym_preproc_endregion] = STATE(2790),
    [sym_preproc_line] = STATE(2790),
    [sym_preproc_pragma] = STATE(2790),
    [sym_preproc_nullable] = STATE(2790),
    [sym_preproc_error] = STATE(2790),
    [sym_preproc_warning] = STATE(2790),
    [sym_preproc_define] = STATE(2790),
    [sym_preproc_undef] = STATE(2790),
    [sym__identifier_token] = ACTIONS(4138),
    [anon_sym_alias] = ACTIONS(4138),
    [anon_sym_global] = ACTIONS(4138),
    [anon_sym_EQ] = ACTIONS(4266),
    [anon_sym_LBRACK] = ACTIONS(4140),
    [anon_sym_COLON] = ACTIONS(4138),
    [anon_sym_COMMA] = ACTIONS(4310),
    [anon_sym_LPAREN] = ACTIONS(4140),
    [anon_sym_RPAREN] = ACTIONS(4310),
    [anon_sym_LBRACE] = ACTIONS(4140),
    [anon_sym_file] = ACTIONS(4138),
    [anon_sym_LT] = ACTIONS(4142),
    [anon_sym_GT] = ACTIONS(4138),
    [anon_sym_where] = ACTIONS(4138),
    [anon_sym_QMARK] = ACTIONS(4138),
    [anon_sym_notnull] = ACTIONS(4138),
    [anon_sym_unmanaged] = ACTIONS(4138),
    [anon_sym_BANG] = ACTIONS(4138),
    [anon_sym_PLUS_PLUS] = ACTIONS(4140),
    [anon_sym_DASH_DASH] = ACTIONS(4140),
    [anon_sym_PLUS] = ACTIONS(4138),
    [anon_sym_DASH] = ACTIONS(4138),
    [anon_sym_STAR] = ACTIONS(4138),
    [anon_sym_SLASH] = ACTIONS(4138),
    [anon_sym_PERCENT] = ACTIONS(4138),
    [anon_sym_CARET] = ACTIONS(4138),
    [anon_sym_PIPE] = ACTIONS(4138),
    [anon_sym_AMP] = ACTIONS(4138),
    [anon_sym_LT_LT] = ACTIONS(4138),
    [anon_sym_GT_GT] = ACTIONS(4138),
    [anon_sym_GT_GT_GT] = ACTIONS(4138),
    [anon_sym_EQ_EQ] = ACTIONS(4140),
    [anon_sym_BANG_EQ] = ACTIONS(4140),
    [anon_sym_GT_EQ] = ACTIONS(4140),
    [anon_sym_LT_EQ] = ACTIONS(4140),
    [anon_sym_DOT] = ACTIONS(4138),
    [anon_sym_scoped] = ACTIONS(4138),
    [anon_sym_EQ_GT] = ACTIONS(4145),
    [anon_sym_COLON_COLON] = ACTIONS(4147),
    [anon_sym_var] = ACTIONS(4138),
    [anon_sym_yield] = ACTIONS(4138),
    [anon_sym_switch] = ACTIONS(4138),
    [anon_sym_when] = ACTIONS(4138),
    [sym_discard] = ACTIONS(4138),
    [anon_sym_DOT_DOT] = ACTIONS(4140),
    [anon_sym_and] = ACTIONS(4138),
    [anon_sym_or] = ACTIONS(4138),
    [anon_sym_PLUS_EQ] = ACTIONS(4140),
    [anon_sym_DASH_EQ] = ACTIONS(4140),
    [anon_sym_STAR_EQ] = ACTIONS(4140),
    [anon_sym_SLASH_EQ] = ACTIONS(4140),
    [anon_sym_PERCENT_EQ] = ACTIONS(4140),
    [anon_sym_AMP_EQ] = ACTIONS(4140),
    [anon_sym_CARET_EQ] = ACTIONS(4140),
    [anon_sym_PIPE_EQ] = ACTIONS(4140),
    [anon_sym_LT_LT_EQ] = ACTIONS(4140),
    [anon_sym_GT_GT_EQ] = ACTIONS(4140),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4140),
    [anon_sym_AMP_AMP] = ACTIONS(4140),
    [anon_sym_PIPE_PIPE] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK] = ACTIONS(4138),
    [anon_sym_from] = ACTIONS(4138),
    [anon_sym_into] = ACTIONS(4138),
    [anon_sym_join] = ACTIONS(4138),
    [anon_sym_on] = ACTIONS(4138),
    [anon_sym_equals] = ACTIONS(4138),
    [anon_sym_let] = ACTIONS(4138),
    [anon_sym_orderby] = ACTIONS(4138),
    [anon_sym_ascending] = ACTIONS(4138),
    [anon_sym_descending] = ACTIONS(4138),
    [anon_sym_group] = ACTIONS(4138),
    [anon_sym_by] = ACTIONS(4138),
    [anon_sym_select] = ACTIONS(4138),
    [anon_sym_as] = ACTIONS(4138),
    [anon_sym_is] = ACTIONS(4138),
    [anon_sym_DASH_GT] = ACTIONS(4140),
    [anon_sym_with] = ACTIONS(4138),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2791] = {
    [sym_preproc_region] = STATE(2791),
    [sym_preproc_endregion] = STATE(2791),
    [sym_preproc_line] = STATE(2791),
    [sym_preproc_pragma] = STATE(2791),
    [sym_preproc_nullable] = STATE(2791),
    [sym_preproc_error] = STATE(2791),
    [sym_preproc_warning] = STATE(2791),
    [sym_preproc_define] = STATE(2791),
    [sym_preproc_undef] = STATE(2791),
    [sym__identifier_token] = ACTIONS(2669),
    [anon_sym_alias] = ACTIONS(2669),
    [anon_sym_global] = ACTIONS(2669),
    [anon_sym_EQ] = ACTIONS(4162),
    [anon_sym_LBRACK] = ACTIONS(4177),
    [anon_sym_COLON] = ACTIONS(4177),
    [anon_sym_COMMA] = ACTIONS(4177),
    [anon_sym_LPAREN] = ACTIONS(4320),
    [anon_sym_RPAREN] = ACTIONS(4177),
    [anon_sym_ref] = ACTIONS(2669),
    [anon_sym_delegate] = ACTIONS(2669),
    [anon_sym_file] = ACTIONS(2669),
    [anon_sym_readonly] = ACTIONS(2669),
    [anon_sym_LT] = ACTIONS(4162),
    [anon_sym_GT] = ACTIONS(4162),
    [anon_sym_in] = ACTIONS(2669),
    [anon_sym_out] = ACTIONS(2669),
    [anon_sym_where] = ACTIONS(2669),
    [anon_sym_QMARK] = ACTIONS(4162),
    [anon_sym_notnull] = ACTIONS(2669),
    [anon_sym_unmanaged] = ACTIONS(2669),
    [anon_sym_BANG] = ACTIONS(4162),
    [anon_sym_PLUS_PLUS] = ACTIONS(4177),
    [anon_sym_DASH_DASH] = ACTIONS(4177),
    [anon_sym_PLUS] = ACTIONS(4162),
    [anon_sym_DASH] = ACTIONS(4162),
    [anon_sym_STAR] = ACTIONS(4162),
    [anon_sym_SLASH] = ACTIONS(4162),
    [anon_sym_PERCENT] = ACTIONS(4162),
    [anon_sym_CARET] = ACTIONS(4162),
    [anon_sym_PIPE] = ACTIONS(4162),
    [anon_sym_AMP] = ACTIONS(4162),
    [anon_sym_LT_LT] = ACTIONS(4162),
    [anon_sym_GT_GT] = ACTIONS(4162),
    [anon_sym_GT_GT_GT] = ACTIONS(4162),
    [anon_sym_EQ_EQ] = ACTIONS(4177),
    [anon_sym_BANG_EQ] = ACTIONS(4177),
    [anon_sym_GT_EQ] = ACTIONS(4177),
    [anon_sym_LT_EQ] = ACTIONS(4177),
    [anon_sym_this] = ACTIONS(2669),
    [anon_sym_DOT] = ACTIONS(4162),
    [anon_sym_scoped] = ACTIONS(2669),
    [anon_sym_var] = ACTIONS(2669),
    [sym_predefined_type] = ACTIONS(2669),
    [anon_sym_yield] = ACTIONS(2669),
    [anon_sym_switch] = ACTIONS(4162),
    [anon_sym_when] = ACTIONS(2669),
    [anon_sym_DOT_DOT] = ACTIONS(4177),
    [anon_sym_PLUS_EQ] = ACTIONS(4177),
    [anon_sym_DASH_EQ] = ACTIONS(4177),
    [anon_sym_STAR_EQ] = ACTIONS(4177),
    [anon_sym_SLASH_EQ] = ACTIONS(4177),
    [anon_sym_PERCENT_EQ] = ACTIONS(4177),
    [anon_sym_AMP_EQ] = ACTIONS(4177),
    [anon_sym_CARET_EQ] = ACTIONS(4177),
    [anon_sym_PIPE_EQ] = ACTIONS(4177),
    [anon_sym_LT_LT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4177),
    [anon_sym_AMP_AMP] = ACTIONS(4177),
    [anon_sym_PIPE_PIPE] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK] = ACTIONS(4162),
    [anon_sym_from] = ACTIONS(2669),
    [anon_sym_into] = ACTIONS(2669),
    [anon_sym_join] = ACTIONS(2669),
    [anon_sym_on] = ACTIONS(2669),
    [anon_sym_equals] = ACTIONS(2669),
    [anon_sym_let] = ACTIONS(2669),
    [anon_sym_orderby] = ACTIONS(2669),
    [anon_sym_ascending] = ACTIONS(2669),
    [anon_sym_descending] = ACTIONS(2669),
    [anon_sym_group] = ACTIONS(2669),
    [anon_sym_by] = ACTIONS(2669),
    [anon_sym_select] = ACTIONS(2669),
    [anon_sym_as] = ACTIONS(4162),
    [anon_sym_is] = ACTIONS(4162),
    [anon_sym_DASH_GT] = ACTIONS(4177),
    [anon_sym_with] = ACTIONS(4162),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2792] = {
    [sym_type_argument_list] = STATE(2821),
    [sym_preproc_region] = STATE(2792),
    [sym_preproc_endregion] = STATE(2792),
    [sym_preproc_line] = STATE(2792),
    [sym_preproc_pragma] = STATE(2792),
    [sym_preproc_nullable] = STATE(2792),
    [sym_preproc_error] = STATE(2792),
    [sym_preproc_warning] = STATE(2792),
    [sym_preproc_define] = STATE(2792),
    [sym_preproc_undef] = STATE(2792),
    [sym__identifier_token] = ACTIONS(4138),
    [anon_sym_alias] = ACTIONS(4138),
    [anon_sym_global] = ACTIONS(4138),
    [anon_sym_EQ] = ACTIONS(4138),
    [anon_sym_LBRACK] = ACTIONS(4140),
    [anon_sym_COLON] = ACTIONS(4138),
    [anon_sym_COMMA] = ACTIONS(4140),
    [anon_sym_LPAREN] = ACTIONS(4140),
    [anon_sym_LBRACE] = ACTIONS(4140),
    [anon_sym_file] = ACTIONS(4138),
    [anon_sym_LT] = ACTIONS(4323),
    [anon_sym_GT] = ACTIONS(4138),
    [anon_sym_where] = ACTIONS(4138),
    [anon_sym_QMARK] = ACTIONS(4138),
    [anon_sym_notnull] = ACTIONS(4138),
    [anon_sym_unmanaged] = ACTIONS(4138),
    [anon_sym_BANG] = ACTIONS(4138),
    [anon_sym_PLUS_PLUS] = ACTIONS(4140),
    [anon_sym_DASH_DASH] = ACTIONS(4140),
    [anon_sym_PLUS] = ACTIONS(4138),
    [anon_sym_DASH] = ACTIONS(4138),
    [anon_sym_STAR] = ACTIONS(4138),
    [anon_sym_SLASH] = ACTIONS(4138),
    [anon_sym_PERCENT] = ACTIONS(4138),
    [anon_sym_CARET] = ACTIONS(4138),
    [anon_sym_PIPE] = ACTIONS(4138),
    [anon_sym_AMP] = ACTIONS(4138),
    [anon_sym_LT_LT] = ACTIONS(4138),
    [anon_sym_GT_GT] = ACTIONS(4138),
    [anon_sym_GT_GT_GT] = ACTIONS(4138),
    [anon_sym_EQ_EQ] = ACTIONS(4140),
    [anon_sym_BANG_EQ] = ACTIONS(4140),
    [anon_sym_GT_EQ] = ACTIONS(4140),
    [anon_sym_LT_EQ] = ACTIONS(4140),
    [anon_sym_DOT] = ACTIONS(4138),
    [anon_sym_scoped] = ACTIONS(4138),
    [anon_sym_EQ_GT] = ACTIONS(4145),
    [anon_sym_COLON_COLON] = ACTIONS(4326),
    [anon_sym_var] = ACTIONS(4138),
    [anon_sym_yield] = ACTIONS(4138),
    [anon_sym_switch] = ACTIONS(4138),
    [anon_sym_when] = ACTIONS(4138),
    [sym_discard] = ACTIONS(4138),
    [anon_sym_DOT_DOT] = ACTIONS(4140),
    [anon_sym_and] = ACTIONS(4138),
    [anon_sym_or] = ACTIONS(4138),
    [anon_sym_PLUS_EQ] = ACTIONS(4140),
    [anon_sym_DASH_EQ] = ACTIONS(4140),
    [anon_sym_STAR_EQ] = ACTIONS(4140),
    [anon_sym_SLASH_EQ] = ACTIONS(4140),
    [anon_sym_PERCENT_EQ] = ACTIONS(4140),
    [anon_sym_AMP_EQ] = ACTIONS(4140),
    [anon_sym_CARET_EQ] = ACTIONS(4140),
    [anon_sym_PIPE_EQ] = ACTIONS(4140),
    [anon_sym_LT_LT_EQ] = ACTIONS(4140),
    [anon_sym_GT_GT_EQ] = ACTIONS(4140),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4140),
    [anon_sym_AMP_AMP] = ACTIONS(4140),
    [anon_sym_PIPE_PIPE] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK] = ACTIONS(4138),
    [anon_sym_from] = ACTIONS(4138),
    [anon_sym_into] = ACTIONS(4138),
    [anon_sym_join] = ACTIONS(4138),
    [anon_sym_on] = ACTIONS(4138),
    [anon_sym_equals] = ACTIONS(4138),
    [anon_sym_let] = ACTIONS(4138),
    [anon_sym_orderby] = ACTIONS(4138),
    [anon_sym_ascending] = ACTIONS(4138),
    [anon_sym_descending] = ACTIONS(4138),
    [anon_sym_group] = ACTIONS(4138),
    [anon_sym_by] = ACTIONS(4138),
    [anon_sym_select] = ACTIONS(4138),
    [anon_sym_as] = ACTIONS(4138),
    [anon_sym_is] = ACTIONS(4138),
    [anon_sym_DASH_GT] = ACTIONS(4140),
    [anon_sym_with] = ACTIONS(4138),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4140),
  },
  [2793] = {
    [sym__name] = STATE(4348),
    [sym_alias_qualified_name] = STATE(3588),
    [sym__simple_name] = STATE(3588),
    [sym_qualified_name] = STATE(3588),
    [sym_generic_name] = STATE(3597),
    [sym_ref_type] = STATE(3601),
    [sym__scoped_base_type] = STATE(3606),
    [sym_identifier] = STATE(4004),
    [sym__reserved_identifier] = STATE(3572),
    [sym_preproc_region] = STATE(2793),
    [sym_preproc_endregion] = STATE(2793),
    [sym_preproc_line] = STATE(2793),
    [sym_preproc_pragma] = STATE(2793),
    [sym_preproc_nullable] = STATE(2793),
    [sym_preproc_error] = STATE(2793),
    [sym_preproc_warning] = STATE(2793),
    [sym_preproc_define] = STATE(2793),
    [sym_preproc_undef] = STATE(2793),
    [sym__identifier_token] = ACTIONS(4328),
    [anon_sym_alias] = ACTIONS(4330),
    [anon_sym_SEMI] = ACTIONS(3993),
    [anon_sym_global] = ACTIONS(4330),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_COLON] = ACTIONS(3995),
    [anon_sym_COMMA] = ACTIONS(3993),
    [anon_sym_RBRACK] = ACTIONS(3993),
    [anon_sym_LPAREN] = ACTIONS(3993),
    [anon_sym_RPAREN] = ACTIONS(3993),
    [anon_sym_ref] = ACTIONS(4332),
    [anon_sym_LBRACE] = ACTIONS(3993),
    [anon_sym_RBRACE] = ACTIONS(3993),
    [anon_sym_file] = ACTIONS(4330),
    [anon_sym_LT] = ACTIONS(3995),
    [anon_sym_GT] = ACTIONS(3995),
    [anon_sym_in] = ACTIONS(3995),
    [anon_sym_where] = ACTIONS(4330),
    [anon_sym_QMARK] = ACTIONS(3995),
    [anon_sym_notnull] = ACTIONS(4330),
    [anon_sym_unmanaged] = ACTIONS(4330),
    [anon_sym_BANG] = ACTIONS(3995),
    [anon_sym_PLUS_PLUS] = ACTIONS(3993),
    [anon_sym_DASH_DASH] = ACTIONS(3993),
    [anon_sym_PLUS] = ACTIONS(3995),
    [anon_sym_DASH] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3993),
    [anon_sym_SLASH] = ACTIONS(3995),
    [anon_sym_PERCENT] = ACTIONS(3993),
    [anon_sym_CARET] = ACTIONS(3993),
    [anon_sym_PIPE] = ACTIONS(3995),
    [anon_sym_AMP] = ACTIONS(3995),
    [anon_sym_LT_LT] = ACTIONS(3993),
    [anon_sym_GT_GT] = ACTIONS(3995),
    [anon_sym_GT_GT_GT] = ACTIONS(3993),
    [anon_sym_EQ_EQ] = ACTIONS(3993),
    [anon_sym_BANG_EQ] = ACTIONS(3993),
    [anon_sym_GT_EQ] = ACTIONS(3993),
    [anon_sym_LT_EQ] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3995),
    [anon_sym_scoped] = ACTIONS(4330),
    [anon_sym_EQ_GT] = ACTIONS(3993),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(4330),
    [anon_sym_yield] = ACTIONS(4330),
    [anon_sym_switch] = ACTIONS(3995),
    [anon_sym_when] = ACTIONS(4330),
    [anon_sym_DOT_DOT] = ACTIONS(3993),
    [anon_sym_AMP_AMP] = ACTIONS(3993),
    [anon_sym_PIPE_PIPE] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK] = ACTIONS(3993),
    [anon_sym_from] = ACTIONS(4330),
    [anon_sym_into] = ACTIONS(4334),
    [anon_sym_join] = ACTIONS(4330),
    [anon_sym_on] = ACTIONS(4330),
    [anon_sym_equals] = ACTIONS(4330),
    [anon_sym_let] = ACTIONS(4330),
    [anon_sym_orderby] = ACTIONS(4330),
    [anon_sym_ascending] = ACTIONS(4330),
    [anon_sym_descending] = ACTIONS(4330),
    [anon_sym_group] = ACTIONS(4330),
    [anon_sym_by] = ACTIONS(4330),
    [anon_sym_select] = ACTIONS(4330),
    [anon_sym_as] = ACTIONS(3995),
    [anon_sym_is] = ACTIONS(3995),
    [anon_sym_DASH_GT] = ACTIONS(3993),
    [anon_sym_with] = ACTIONS(3995),
    [aux_sym_preproc_if_token3] = ACTIONS(3993),
    [aux_sym_preproc_else_token1] = ACTIONS(3993),
    [aux_sym_preproc_elif_token1] = ACTIONS(3993),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2794] = {
    [sym__variable_designation] = STATE(3981),
    [sym_parenthesized_variable_designation] = STATE(3966),
    [sym_identifier] = STATE(3983),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(2794),
    [sym_preproc_endregion] = STATE(2794),
    [sym_preproc_line] = STATE(2794),
    [sym_preproc_pragma] = STATE(2794),
    [sym_preproc_nullable] = STATE(2794),
    [sym_preproc_error] = STATE(2794),
    [sym_preproc_warning] = STATE(2794),
    [sym_preproc_define] = STATE(2794),
    [sym_preproc_undef] = STATE(2794),
    [sym__identifier_token] = ACTIONS(4080),
    [anon_sym_alias] = ACTIONS(4084),
    [anon_sym_global] = ACTIONS(4084),
    [anon_sym_EQ] = ACTIONS(3995),
    [anon_sym_LBRACK] = ACTIONS(4088),
    [anon_sym_LPAREN] = ACTIONS(4094),
    [anon_sym_LBRACE] = ACTIONS(4088),
    [anon_sym_file] = ACTIONS(4084),
    [anon_sym_LT] = ACTIONS(4091),
    [anon_sym_GT] = ACTIONS(4091),
    [anon_sym_where] = ACTIONS(4084),
    [anon_sym_QMARK] = ACTIONS(4091),
    [anon_sym_notnull] = ACTIONS(4084),
    [anon_sym_unmanaged] = ACTIONS(4084),
    [anon_sym_BANG] = ACTIONS(4091),
    [anon_sym_PLUS_PLUS] = ACTIONS(4088),
    [anon_sym_DASH_DASH] = ACTIONS(4088),
    [anon_sym_PLUS] = ACTIONS(4091),
    [anon_sym_DASH] = ACTIONS(4091),
    [anon_sym_STAR] = ACTIONS(4091),
    [anon_sym_SLASH] = ACTIONS(4091),
    [anon_sym_PERCENT] = ACTIONS(4091),
    [anon_sym_CARET] = ACTIONS(4091),
    [anon_sym_PIPE] = ACTIONS(4091),
    [anon_sym_AMP] = ACTIONS(4091),
    [anon_sym_LT_LT] = ACTIONS(4091),
    [anon_sym_GT_GT] = ACTIONS(4091),
    [anon_sym_GT_GT_GT] = ACTIONS(4091),
    [anon_sym_EQ_EQ] = ACTIONS(4088),
    [anon_sym_BANG_EQ] = ACTIONS(4088),
    [anon_sym_GT_EQ] = ACTIONS(4088),
    [anon_sym_LT_EQ] = ACTIONS(4088),
    [anon_sym_DOT] = ACTIONS(4091),
    [anon_sym_scoped] = ACTIONS(4084),
    [anon_sym_EQ_GT] = ACTIONS(4088),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(4084),
    [anon_sym_yield] = ACTIONS(4084),
    [anon_sym_switch] = ACTIONS(4091),
    [anon_sym_when] = ACTIONS(4084),
    [sym_discard] = ACTIONS(4098),
    [anon_sym_DOT_DOT] = ACTIONS(4088),
    [anon_sym_and] = ACTIONS(4091),
    [anon_sym_or] = ACTIONS(4091),
    [anon_sym_PLUS_EQ] = ACTIONS(3993),
    [anon_sym_DASH_EQ] = ACTIONS(3993),
    [anon_sym_STAR_EQ] = ACTIONS(3993),
    [anon_sym_SLASH_EQ] = ACTIONS(3993),
    [anon_sym_PERCENT_EQ] = ACTIONS(3993),
    [anon_sym_AMP_EQ] = ACTIONS(3993),
    [anon_sym_CARET_EQ] = ACTIONS(3993),
    [anon_sym_PIPE_EQ] = ACTIONS(3993),
    [anon_sym_LT_LT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(3993),
    [anon_sym_AMP_AMP] = ACTIONS(4088),
    [anon_sym_PIPE_PIPE] = ACTIONS(4088),
    [anon_sym_QMARK_QMARK] = ACTIONS(4091),
    [anon_sym_from] = ACTIONS(4084),
    [anon_sym_into] = ACTIONS(4084),
    [anon_sym_join] = ACTIONS(4084),
    [anon_sym_on] = ACTIONS(4084),
    [anon_sym_equals] = ACTIONS(4084),
    [anon_sym_let] = ACTIONS(4084),
    [anon_sym_orderby] = ACTIONS(4084),
    [anon_sym_ascending] = ACTIONS(4084),
    [anon_sym_descending] = ACTIONS(4084),
    [anon_sym_group] = ACTIONS(4084),
    [anon_sym_by] = ACTIONS(4084),
    [anon_sym_select] = ACTIONS(4084),
    [anon_sym_as] = ACTIONS(4091),
    [anon_sym_is] = ACTIONS(4091),
    [anon_sym_DASH_GT] = ACTIONS(4088),
    [anon_sym_with] = ACTIONS(4091),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2795] = {
    [sym_parameter_list] = STATE(9685),
    [sym_positional_pattern_clause] = STATE(2842),
    [sym_property_pattern_clause] = STATE(2879),
    [sym__variable_designation] = STATE(4091),
    [sym_parenthesized_variable_designation] = STATE(3966),
    [sym__lambda_parameters] = STATE(9890),
    [sym_identifier] = STATE(4070),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(2795),
    [sym_preproc_endregion] = STATE(2795),
    [sym_preproc_line] = STATE(2795),
    [sym_preproc_pragma] = STATE(2795),
    [sym_preproc_nullable] = STATE(2795),
    [sym_preproc_error] = STATE(2795),
    [sym_preproc_warning] = STATE(2795),
    [sym_preproc_define] = STATE(2795),
    [sym_preproc_undef] = STATE(2795),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_SEMI] = ACTIONS(4341),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4341),
    [anon_sym_COLON] = ACTIONS(4341),
    [anon_sym_COMMA] = ACTIONS(4341),
    [anon_sym_RBRACK] = ACTIONS(4341),
    [anon_sym_LPAREN] = ACTIONS(4341),
    [anon_sym_RPAREN] = ACTIONS(4341),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_RBRACE] = ACTIONS(4341),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4345),
    [anon_sym_GT] = ACTIONS(4345),
    [anon_sym_in] = ACTIONS(4345),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4345),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4345),
    [anon_sym_PLUS_PLUS] = ACTIONS(4341),
    [anon_sym_DASH_DASH] = ACTIONS(4341),
    [anon_sym_PLUS] = ACTIONS(4345),
    [anon_sym_DASH] = ACTIONS(4345),
    [anon_sym_STAR] = ACTIONS(4341),
    [anon_sym_SLASH] = ACTIONS(4345),
    [anon_sym_PERCENT] = ACTIONS(4341),
    [anon_sym_CARET] = ACTIONS(4341),
    [anon_sym_PIPE] = ACTIONS(4345),
    [anon_sym_AMP] = ACTIONS(4345),
    [anon_sym_LT_LT] = ACTIONS(4341),
    [anon_sym_GT_GT] = ACTIONS(4345),
    [anon_sym_GT_GT_GT] = ACTIONS(4341),
    [anon_sym_EQ_EQ] = ACTIONS(4341),
    [anon_sym_BANG_EQ] = ACTIONS(4341),
    [anon_sym_GT_EQ] = ACTIONS(4341),
    [anon_sym_LT_EQ] = ACTIONS(4341),
    [anon_sym_DOT] = ACTIONS(4345),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4345),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4347),
    [anon_sym_DOT_DOT] = ACTIONS(4341),
    [anon_sym_and] = ACTIONS(4345),
    [anon_sym_or] = ACTIONS(4345),
    [anon_sym_AMP_AMP] = ACTIONS(4341),
    [anon_sym_PIPE_PIPE] = ACTIONS(4341),
    [anon_sym_QMARK_QMARK] = ACTIONS(4341),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4345),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4345),
    [anon_sym_is] = ACTIONS(4345),
    [anon_sym_DASH_GT] = ACTIONS(4341),
    [anon_sym_with] = ACTIONS(4345),
    [aux_sym_preproc_if_token3] = ACTIONS(4341),
    [aux_sym_preproc_else_token1] = ACTIONS(4341),
    [aux_sym_preproc_elif_token1] = ACTIONS(4341),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2796] = {
    [sym__name] = STATE(3748),
    [sym_alias_qualified_name] = STATE(3680),
    [sym__simple_name] = STATE(3680),
    [sym_qualified_name] = STATE(3680),
    [sym_generic_name] = STATE(3648),
    [sym_ref_type] = STATE(3643),
    [sym__scoped_base_type] = STATE(3647),
    [sym_identifier] = STATE(3590),
    [sym__reserved_identifier] = STATE(3625),
    [sym_preproc_region] = STATE(2796),
    [sym_preproc_endregion] = STATE(2796),
    [sym_preproc_line] = STATE(2796),
    [sym_preproc_pragma] = STATE(2796),
    [sym_preproc_nullable] = STATE(2796),
    [sym_preproc_error] = STATE(2796),
    [sym_preproc_warning] = STATE(2796),
    [sym_preproc_define] = STATE(2796),
    [sym_preproc_undef] = STATE(2796),
    [sym__identifier_token] = ACTIONS(4349),
    [anon_sym_alias] = ACTIONS(4351),
    [anon_sym_SEMI] = ACTIONS(3993),
    [anon_sym_global] = ACTIONS(4351),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_COMMA] = ACTIONS(3993),
    [anon_sym_RBRACK] = ACTIONS(3993),
    [anon_sym_LPAREN] = ACTIONS(3993),
    [anon_sym_RPAREN] = ACTIONS(3993),
    [anon_sym_ref] = ACTIONS(4353),
    [anon_sym_LBRACE] = ACTIONS(3993),
    [anon_sym_RBRACE] = ACTIONS(3993),
    [anon_sym_file] = ACTIONS(4351),
    [anon_sym_LT] = ACTIONS(3995),
    [anon_sym_GT] = ACTIONS(3995),
    [anon_sym_in] = ACTIONS(3995),
    [anon_sym_where] = ACTIONS(4351),
    [anon_sym_QMARK] = ACTIONS(3995),
    [anon_sym_notnull] = ACTIONS(4351),
    [anon_sym_unmanaged] = ACTIONS(4351),
    [anon_sym_BANG] = ACTIONS(3995),
    [anon_sym_PLUS_PLUS] = ACTIONS(3993),
    [anon_sym_DASH_DASH] = ACTIONS(3993),
    [anon_sym_PLUS] = ACTIONS(3995),
    [anon_sym_DASH] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3993),
    [anon_sym_SLASH] = ACTIONS(3995),
    [anon_sym_PERCENT] = ACTIONS(3993),
    [anon_sym_CARET] = ACTIONS(3993),
    [anon_sym_PIPE] = ACTIONS(3995),
    [anon_sym_AMP] = ACTIONS(3995),
    [anon_sym_LT_LT] = ACTIONS(3993),
    [anon_sym_GT_GT] = ACTIONS(3995),
    [anon_sym_GT_GT_GT] = ACTIONS(3993),
    [anon_sym_EQ_EQ] = ACTIONS(3993),
    [anon_sym_BANG_EQ] = ACTIONS(3993),
    [anon_sym_GT_EQ] = ACTIONS(3993),
    [anon_sym_LT_EQ] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3995),
    [anon_sym_scoped] = ACTIONS(4351),
    [anon_sym_EQ_GT] = ACTIONS(3993),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(4351),
    [anon_sym_yield] = ACTIONS(4351),
    [anon_sym_switch] = ACTIONS(3995),
    [anon_sym_when] = ACTIONS(4351),
    [anon_sym_DOT_DOT] = ACTIONS(3993),
    [anon_sym_AMP_AMP] = ACTIONS(3993),
    [anon_sym_PIPE_PIPE] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK] = ACTIONS(3993),
    [anon_sym_from] = ACTIONS(4351),
    [anon_sym_into] = ACTIONS(4351),
    [anon_sym_join] = ACTIONS(4351),
    [anon_sym_on] = ACTIONS(4351),
    [anon_sym_equals] = ACTIONS(4351),
    [anon_sym_let] = ACTIONS(4351),
    [anon_sym_orderby] = ACTIONS(4351),
    [anon_sym_ascending] = ACTIONS(4351),
    [anon_sym_descending] = ACTIONS(4351),
    [anon_sym_group] = ACTIONS(4351),
    [anon_sym_by] = ACTIONS(4351),
    [anon_sym_select] = ACTIONS(4351),
    [anon_sym_as] = ACTIONS(3995),
    [anon_sym_is] = ACTIONS(3995),
    [anon_sym_DASH_GT] = ACTIONS(3993),
    [anon_sym_with] = ACTIONS(3995),
    [aux_sym_preproc_if_token3] = ACTIONS(3993),
    [aux_sym_preproc_else_token1] = ACTIONS(3993),
    [aux_sym_preproc_elif_token1] = ACTIONS(3993),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2797] = {
    [sym_preproc_region] = STATE(2797),
    [sym_preproc_endregion] = STATE(2797),
    [sym_preproc_line] = STATE(2797),
    [sym_preproc_pragma] = STATE(2797),
    [sym_preproc_nullable] = STATE(2797),
    [sym_preproc_error] = STATE(2797),
    [sym_preproc_warning] = STATE(2797),
    [sym_preproc_define] = STATE(2797),
    [sym_preproc_undef] = STATE(2797),
    [sym__identifier_token] = ACTIONS(4179),
    [anon_sym_alias] = ACTIONS(4179),
    [anon_sym_global] = ACTIONS(4179),
    [anon_sym_EQ] = ACTIONS(4183),
    [anon_sym_LBRACK] = ACTIONS(4185),
    [anon_sym_COLON] = ACTIONS(4191),
    [anon_sym_COMMA] = ACTIONS(4185),
    [anon_sym_RBRACK] = ACTIONS(4185),
    [anon_sym_LPAREN] = ACTIONS(4185),
    [anon_sym_RPAREN] = ACTIONS(4191),
    [anon_sym_LBRACE] = ACTIONS(4181),
    [anon_sym_RBRACE] = ACTIONS(4185),
    [anon_sym_file] = ACTIONS(4179),
    [anon_sym_LT] = ACTIONS(4183),
    [anon_sym_GT] = ACTIONS(4183),
    [anon_sym_where] = ACTIONS(4179),
    [anon_sym_QMARK] = ACTIONS(4188),
    [anon_sym_notnull] = ACTIONS(4179),
    [anon_sym_unmanaged] = ACTIONS(4179),
    [anon_sym_BANG] = ACTIONS(4183),
    [anon_sym_PLUS_PLUS] = ACTIONS(4191),
    [anon_sym_DASH_DASH] = ACTIONS(4191),
    [anon_sym_PLUS] = ACTIONS(4183),
    [anon_sym_DASH] = ACTIONS(4183),
    [anon_sym_STAR] = ACTIONS(4188),
    [anon_sym_SLASH] = ACTIONS(4183),
    [anon_sym_PERCENT] = ACTIONS(4183),
    [anon_sym_CARET] = ACTIONS(4183),
    [anon_sym_PIPE] = ACTIONS(4183),
    [anon_sym_AMP] = ACTIONS(4183),
    [anon_sym_LT_LT] = ACTIONS(4183),
    [anon_sym_GT_GT] = ACTIONS(4183),
    [anon_sym_GT_GT_GT] = ACTIONS(4183),
    [anon_sym_EQ_EQ] = ACTIONS(4191),
    [anon_sym_BANG_EQ] = ACTIONS(4191),
    [anon_sym_GT_EQ] = ACTIONS(4191),
    [anon_sym_LT_EQ] = ACTIONS(4191),
    [anon_sym_DOT] = ACTIONS(4188),
    [anon_sym_scoped] = ACTIONS(4179),
    [anon_sym_var] = ACTIONS(4179),
    [anon_sym_yield] = ACTIONS(4179),
    [anon_sym_switch] = ACTIONS(4183),
    [anon_sym_when] = ACTIONS(4179),
    [sym_discard] = ACTIONS(4179),
    [anon_sym_DOT_DOT] = ACTIONS(4191),
    [anon_sym_and] = ACTIONS(4179),
    [anon_sym_or] = ACTIONS(4179),
    [anon_sym_PLUS_EQ] = ACTIONS(4191),
    [anon_sym_DASH_EQ] = ACTIONS(4191),
    [anon_sym_STAR_EQ] = ACTIONS(4191),
    [anon_sym_SLASH_EQ] = ACTIONS(4191),
    [anon_sym_PERCENT_EQ] = ACTIONS(4191),
    [anon_sym_AMP_EQ] = ACTIONS(4191),
    [anon_sym_CARET_EQ] = ACTIONS(4191),
    [anon_sym_PIPE_EQ] = ACTIONS(4191),
    [anon_sym_LT_LT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4191),
    [anon_sym_AMP_AMP] = ACTIONS(4191),
    [anon_sym_PIPE_PIPE] = ACTIONS(4191),
    [anon_sym_QMARK_QMARK] = ACTIONS(4183),
    [anon_sym_from] = ACTIONS(4179),
    [anon_sym_into] = ACTIONS(4179),
    [anon_sym_join] = ACTIONS(4179),
    [anon_sym_on] = ACTIONS(4179),
    [anon_sym_equals] = ACTIONS(4179),
    [anon_sym_let] = ACTIONS(4179),
    [anon_sym_orderby] = ACTIONS(4179),
    [anon_sym_ascending] = ACTIONS(4179),
    [anon_sym_descending] = ACTIONS(4179),
    [anon_sym_group] = ACTIONS(4179),
    [anon_sym_by] = ACTIONS(4179),
    [anon_sym_select] = ACTIONS(4179),
    [anon_sym_as] = ACTIONS(4183),
    [anon_sym_is] = ACTIONS(4183),
    [anon_sym_DASH_GT] = ACTIONS(4185),
    [anon_sym_with] = ACTIONS(4183),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2798] = {
    [sym_preproc_region] = STATE(2798),
    [sym_preproc_endregion] = STATE(2798),
    [sym_preproc_line] = STATE(2798),
    [sym_preproc_pragma] = STATE(2798),
    [sym_preproc_nullable] = STATE(2798),
    [sym_preproc_error] = STATE(2798),
    [sym_preproc_warning] = STATE(2798),
    [sym_preproc_define] = STATE(2798),
    [sym_preproc_undef] = STATE(2798),
    [sym__identifier_token] = ACTIONS(4157),
    [anon_sym_alias] = ACTIONS(4157),
    [anon_sym_global] = ACTIONS(4157),
    [anon_sym_EQ] = ACTIONS(4162),
    [anon_sym_LBRACK] = ACTIONS(4193),
    [anon_sym_COLON] = ACTIONS(4177),
    [anon_sym_COMMA] = ACTIONS(4164),
    [anon_sym_RBRACK] = ACTIONS(4164),
    [anon_sym_LPAREN] = ACTIONS(4193),
    [anon_sym_RPAREN] = ACTIONS(4164),
    [anon_sym_LBRACE] = ACTIONS(4168),
    [anon_sym_RBRACE] = ACTIONS(4164),
    [anon_sym_file] = ACTIONS(4157),
    [anon_sym_LT] = ACTIONS(4162),
    [anon_sym_GT] = ACTIONS(4162),
    [anon_sym_where] = ACTIONS(4157),
    [anon_sym_QMARK] = ACTIONS(4196),
    [anon_sym_notnull] = ACTIONS(4157),
    [anon_sym_unmanaged] = ACTIONS(4157),
    [anon_sym_BANG] = ACTIONS(4162),
    [anon_sym_PLUS_PLUS] = ACTIONS(4177),
    [anon_sym_DASH_DASH] = ACTIONS(4177),
    [anon_sym_PLUS] = ACTIONS(4162),
    [anon_sym_DASH] = ACTIONS(4162),
    [anon_sym_STAR] = ACTIONS(4196),
    [anon_sym_SLASH] = ACTIONS(4162),
    [anon_sym_PERCENT] = ACTIONS(4162),
    [anon_sym_CARET] = ACTIONS(4162),
    [anon_sym_PIPE] = ACTIONS(4162),
    [anon_sym_AMP] = ACTIONS(4162),
    [anon_sym_LT_LT] = ACTIONS(4162),
    [anon_sym_GT_GT] = ACTIONS(4162),
    [anon_sym_GT_GT_GT] = ACTIONS(4162),
    [anon_sym_EQ_EQ] = ACTIONS(4177),
    [anon_sym_BANG_EQ] = ACTIONS(4177),
    [anon_sym_GT_EQ] = ACTIONS(4177),
    [anon_sym_LT_EQ] = ACTIONS(4177),
    [anon_sym_DOT] = ACTIONS(4196),
    [anon_sym_scoped] = ACTIONS(4157),
    [anon_sym_var] = ACTIONS(4157),
    [anon_sym_yield] = ACTIONS(4157),
    [anon_sym_switch] = ACTIONS(4162),
    [anon_sym_when] = ACTIONS(4157),
    [sym_discard] = ACTIONS(4157),
    [anon_sym_DOT_DOT] = ACTIONS(4177),
    [anon_sym_and] = ACTIONS(4174),
    [anon_sym_or] = ACTIONS(4174),
    [anon_sym_PLUS_EQ] = ACTIONS(4177),
    [anon_sym_DASH_EQ] = ACTIONS(4177),
    [anon_sym_STAR_EQ] = ACTIONS(4177),
    [anon_sym_SLASH_EQ] = ACTIONS(4177),
    [anon_sym_PERCENT_EQ] = ACTIONS(4177),
    [anon_sym_AMP_EQ] = ACTIONS(4177),
    [anon_sym_CARET_EQ] = ACTIONS(4177),
    [anon_sym_PIPE_EQ] = ACTIONS(4177),
    [anon_sym_LT_LT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4177),
    [anon_sym_AMP_AMP] = ACTIONS(4177),
    [anon_sym_PIPE_PIPE] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK] = ACTIONS(4162),
    [anon_sym_from] = ACTIONS(4157),
    [anon_sym_into] = ACTIONS(4157),
    [anon_sym_join] = ACTIONS(4157),
    [anon_sym_on] = ACTIONS(4157),
    [anon_sym_equals] = ACTIONS(4157),
    [anon_sym_let] = ACTIONS(4157),
    [anon_sym_orderby] = ACTIONS(4157),
    [anon_sym_ascending] = ACTIONS(4157),
    [anon_sym_descending] = ACTIONS(4157),
    [anon_sym_group] = ACTIONS(4157),
    [anon_sym_by] = ACTIONS(4157),
    [anon_sym_select] = ACTIONS(4157),
    [anon_sym_as] = ACTIONS(4162),
    [anon_sym_is] = ACTIONS(4162),
    [anon_sym_DASH_GT] = ACTIONS(4193),
    [anon_sym_with] = ACTIONS(4162),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2799] = {
    [sym_preproc_region] = STATE(2799),
    [sym_preproc_endregion] = STATE(2799),
    [sym_preproc_line] = STATE(2799),
    [sym_preproc_pragma] = STATE(2799),
    [sym_preproc_nullable] = STATE(2799),
    [sym_preproc_error] = STATE(2799),
    [sym_preproc_warning] = STATE(2799),
    [sym_preproc_define] = STATE(2799),
    [sym_preproc_undef] = STATE(2799),
    [sym__identifier_token] = ACTIONS(4091),
    [anon_sym_alias] = ACTIONS(4091),
    [anon_sym_global] = ACTIONS(4091),
    [anon_sym_EQ] = ACTIONS(3995),
    [anon_sym_LBRACK] = ACTIONS(4088),
    [anon_sym_COLON] = ACTIONS(4091),
    [anon_sym_COMMA] = ACTIONS(4088),
    [anon_sym_LPAREN] = ACTIONS(4088),
    [anon_sym_LBRACE] = ACTIONS(4088),
    [anon_sym_file] = ACTIONS(4091),
    [anon_sym_LT] = ACTIONS(4091),
    [anon_sym_GT] = ACTIONS(4091),
    [anon_sym_where] = ACTIONS(4091),
    [anon_sym_QMARK] = ACTIONS(4091),
    [anon_sym_notnull] = ACTIONS(4091),
    [anon_sym_unmanaged] = ACTIONS(4091),
    [anon_sym_BANG] = ACTIONS(4091),
    [anon_sym_PLUS_PLUS] = ACTIONS(4088),
    [anon_sym_DASH_DASH] = ACTIONS(4088),
    [anon_sym_PLUS] = ACTIONS(4091),
    [anon_sym_DASH] = ACTIONS(4091),
    [anon_sym_STAR] = ACTIONS(4091),
    [anon_sym_SLASH] = ACTIONS(4091),
    [anon_sym_PERCENT] = ACTIONS(4091),
    [anon_sym_CARET] = ACTIONS(4091),
    [anon_sym_PIPE] = ACTIONS(4091),
    [anon_sym_AMP] = ACTIONS(4091),
    [anon_sym_LT_LT] = ACTIONS(4091),
    [anon_sym_GT_GT] = ACTIONS(4091),
    [anon_sym_GT_GT_GT] = ACTIONS(4091),
    [anon_sym_EQ_EQ] = ACTIONS(4088),
    [anon_sym_BANG_EQ] = ACTIONS(4088),
    [anon_sym_GT_EQ] = ACTIONS(4088),
    [anon_sym_LT_EQ] = ACTIONS(4088),
    [anon_sym_DOT] = ACTIONS(4091),
    [anon_sym_scoped] = ACTIONS(4091),
    [anon_sym_EQ_GT] = ACTIONS(3993),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(4091),
    [anon_sym_yield] = ACTIONS(4091),
    [anon_sym_switch] = ACTIONS(4091),
    [anon_sym_when] = ACTIONS(4091),
    [sym_discard] = ACTIONS(4091),
    [anon_sym_DOT_DOT] = ACTIONS(4088),
    [anon_sym_and] = ACTIONS(4091),
    [anon_sym_or] = ACTIONS(4091),
    [anon_sym_PLUS_EQ] = ACTIONS(3993),
    [anon_sym_DASH_EQ] = ACTIONS(3993),
    [anon_sym_STAR_EQ] = ACTIONS(3993),
    [anon_sym_SLASH_EQ] = ACTIONS(3993),
    [anon_sym_PERCENT_EQ] = ACTIONS(3993),
    [anon_sym_AMP_EQ] = ACTIONS(3993),
    [anon_sym_CARET_EQ] = ACTIONS(3993),
    [anon_sym_PIPE_EQ] = ACTIONS(3993),
    [anon_sym_LT_LT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(3993),
    [anon_sym_AMP_AMP] = ACTIONS(4088),
    [anon_sym_PIPE_PIPE] = ACTIONS(4088),
    [anon_sym_QMARK_QMARK] = ACTIONS(4091),
    [anon_sym_from] = ACTIONS(4091),
    [anon_sym_into] = ACTIONS(4091),
    [anon_sym_join] = ACTIONS(4091),
    [anon_sym_on] = ACTIONS(4091),
    [anon_sym_equals] = ACTIONS(4091),
    [anon_sym_let] = ACTIONS(4091),
    [anon_sym_orderby] = ACTIONS(4091),
    [anon_sym_ascending] = ACTIONS(4091),
    [anon_sym_descending] = ACTIONS(4091),
    [anon_sym_group] = ACTIONS(4091),
    [anon_sym_by] = ACTIONS(4091),
    [anon_sym_select] = ACTIONS(4091),
    [anon_sym_as] = ACTIONS(4091),
    [anon_sym_is] = ACTIONS(4091),
    [anon_sym_DASH_GT] = ACTIONS(4088),
    [anon_sym_with] = ACTIONS(4091),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4088),
  },
  [2800] = {
    [sym_parameter_list] = STATE(9685),
    [sym_positional_pattern_clause] = STATE(2842),
    [sym_property_pattern_clause] = STATE(2879),
    [sym__variable_designation] = STATE(4091),
    [sym_parenthesized_variable_designation] = STATE(3966),
    [sym__lambda_parameters] = STATE(9890),
    [sym_identifier] = STATE(4070),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(2800),
    [sym_preproc_endregion] = STATE(2800),
    [sym_preproc_line] = STATE(2800),
    [sym_preproc_pragma] = STATE(2800),
    [sym_preproc_nullable] = STATE(2800),
    [sym_preproc_error] = STATE(2800),
    [sym_preproc_warning] = STATE(2800),
    [sym_preproc_define] = STATE(2800),
    [sym_preproc_undef] = STATE(2800),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_SEMI] = ACTIONS(4341),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4341),
    [anon_sym_COLON] = ACTIONS(4341),
    [anon_sym_COMMA] = ACTIONS(4341),
    [anon_sym_RBRACK] = ACTIONS(4341),
    [anon_sym_LPAREN] = ACTIONS(4341),
    [anon_sym_RPAREN] = ACTIONS(4341),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_RBRACE] = ACTIONS(4341),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4345),
    [anon_sym_GT] = ACTIONS(4345),
    [anon_sym_in] = ACTIONS(4345),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4345),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4345),
    [anon_sym_PLUS_PLUS] = ACTIONS(4341),
    [anon_sym_DASH_DASH] = ACTIONS(4341),
    [anon_sym_PLUS] = ACTIONS(4345),
    [anon_sym_DASH] = ACTIONS(4345),
    [anon_sym_STAR] = ACTIONS(4341),
    [anon_sym_SLASH] = ACTIONS(4345),
    [anon_sym_PERCENT] = ACTIONS(4341),
    [anon_sym_CARET] = ACTIONS(4341),
    [anon_sym_PIPE] = ACTIONS(4345),
    [anon_sym_AMP] = ACTIONS(4345),
    [anon_sym_LT_LT] = ACTIONS(4341),
    [anon_sym_GT_GT] = ACTIONS(4345),
    [anon_sym_GT_GT_GT] = ACTIONS(4341),
    [anon_sym_EQ_EQ] = ACTIONS(4341),
    [anon_sym_BANG_EQ] = ACTIONS(4341),
    [anon_sym_GT_EQ] = ACTIONS(4341),
    [anon_sym_LT_EQ] = ACTIONS(4341),
    [anon_sym_DOT] = ACTIONS(4345),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4345),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4347),
    [anon_sym_DOT_DOT] = ACTIONS(4341),
    [anon_sym_and] = ACTIONS(4355),
    [anon_sym_or] = ACTIONS(4355),
    [anon_sym_AMP_AMP] = ACTIONS(4341),
    [anon_sym_PIPE_PIPE] = ACTIONS(4341),
    [anon_sym_QMARK_QMARK] = ACTIONS(4341),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4345),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4345),
    [anon_sym_is] = ACTIONS(4345),
    [anon_sym_DASH_GT] = ACTIONS(4341),
    [anon_sym_with] = ACTIONS(4345),
    [aux_sym_preproc_if_token3] = ACTIONS(4341),
    [aux_sym_preproc_else_token1] = ACTIONS(4341),
    [aux_sym_preproc_elif_token1] = ACTIONS(4341),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2801] = {
    [sym_preproc_region] = STATE(2801),
    [sym_preproc_endregion] = STATE(2801),
    [sym_preproc_line] = STATE(2801),
    [sym_preproc_pragma] = STATE(2801),
    [sym_preproc_nullable] = STATE(2801),
    [sym_preproc_error] = STATE(2801),
    [sym_preproc_warning] = STATE(2801),
    [sym_preproc_define] = STATE(2801),
    [sym_preproc_undef] = STATE(2801),
    [sym__identifier_token] = ACTIONS(4157),
    [anon_sym_alias] = ACTIONS(4157),
    [anon_sym_global] = ACTIONS(4157),
    [anon_sym_EQ] = ACTIONS(4162),
    [anon_sym_LBRACK] = ACTIONS(4193),
    [anon_sym_COLON] = ACTIONS(4177),
    [anon_sym_COMMA] = ACTIONS(4193),
    [anon_sym_RBRACK] = ACTIONS(4193),
    [anon_sym_LPAREN] = ACTIONS(4193),
    [anon_sym_RPAREN] = ACTIONS(4177),
    [anon_sym_LBRACE] = ACTIONS(4168),
    [anon_sym_RBRACE] = ACTIONS(4193),
    [anon_sym_file] = ACTIONS(4157),
    [anon_sym_LT] = ACTIONS(4162),
    [anon_sym_GT] = ACTIONS(4162),
    [anon_sym_where] = ACTIONS(4157),
    [anon_sym_QMARK] = ACTIONS(4196),
    [anon_sym_notnull] = ACTIONS(4157),
    [anon_sym_unmanaged] = ACTIONS(4157),
    [anon_sym_BANG] = ACTIONS(4162),
    [anon_sym_PLUS_PLUS] = ACTIONS(4177),
    [anon_sym_DASH_DASH] = ACTIONS(4177),
    [anon_sym_PLUS] = ACTIONS(4162),
    [anon_sym_DASH] = ACTIONS(4162),
    [anon_sym_STAR] = ACTIONS(4196),
    [anon_sym_SLASH] = ACTIONS(4162),
    [anon_sym_PERCENT] = ACTIONS(4162),
    [anon_sym_CARET] = ACTIONS(4162),
    [anon_sym_PIPE] = ACTIONS(4162),
    [anon_sym_AMP] = ACTIONS(4162),
    [anon_sym_LT_LT] = ACTIONS(4162),
    [anon_sym_GT_GT] = ACTIONS(4162),
    [anon_sym_GT_GT_GT] = ACTIONS(4162),
    [anon_sym_EQ_EQ] = ACTIONS(4177),
    [anon_sym_BANG_EQ] = ACTIONS(4177),
    [anon_sym_GT_EQ] = ACTIONS(4177),
    [anon_sym_LT_EQ] = ACTIONS(4177),
    [anon_sym_DOT] = ACTIONS(4196),
    [anon_sym_scoped] = ACTIONS(4157),
    [anon_sym_var] = ACTIONS(4157),
    [anon_sym_yield] = ACTIONS(4157),
    [anon_sym_switch] = ACTIONS(4162),
    [anon_sym_when] = ACTIONS(4157),
    [sym_discard] = ACTIONS(4157),
    [anon_sym_DOT_DOT] = ACTIONS(4177),
    [anon_sym_and] = ACTIONS(4157),
    [anon_sym_or] = ACTIONS(4157),
    [anon_sym_PLUS_EQ] = ACTIONS(4177),
    [anon_sym_DASH_EQ] = ACTIONS(4177),
    [anon_sym_STAR_EQ] = ACTIONS(4177),
    [anon_sym_SLASH_EQ] = ACTIONS(4177),
    [anon_sym_PERCENT_EQ] = ACTIONS(4177),
    [anon_sym_AMP_EQ] = ACTIONS(4177),
    [anon_sym_CARET_EQ] = ACTIONS(4177),
    [anon_sym_PIPE_EQ] = ACTIONS(4177),
    [anon_sym_LT_LT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4177),
    [anon_sym_AMP_AMP] = ACTIONS(4177),
    [anon_sym_PIPE_PIPE] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK] = ACTIONS(4162),
    [anon_sym_from] = ACTIONS(4157),
    [anon_sym_into] = ACTIONS(4157),
    [anon_sym_join] = ACTIONS(4157),
    [anon_sym_on] = ACTIONS(4157),
    [anon_sym_equals] = ACTIONS(4157),
    [anon_sym_let] = ACTIONS(4157),
    [anon_sym_orderby] = ACTIONS(4157),
    [anon_sym_ascending] = ACTIONS(4157),
    [anon_sym_descending] = ACTIONS(4157),
    [anon_sym_group] = ACTIONS(4157),
    [anon_sym_by] = ACTIONS(4157),
    [anon_sym_select] = ACTIONS(4157),
    [anon_sym_as] = ACTIONS(4162),
    [anon_sym_is] = ACTIONS(4162),
    [anon_sym_DASH_GT] = ACTIONS(4193),
    [anon_sym_with] = ACTIONS(4162),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2802] = {
    [sym_preproc_region] = STATE(2802),
    [sym_preproc_endregion] = STATE(2802),
    [sym_preproc_line] = STATE(2802),
    [sym_preproc_pragma] = STATE(2802),
    [sym_preproc_nullable] = STATE(2802),
    [sym_preproc_error] = STATE(2802),
    [sym_preproc_warning] = STATE(2802),
    [sym_preproc_define] = STATE(2802),
    [sym_preproc_undef] = STATE(2802),
    [sym__identifier_token] = ACTIONS(4157),
    [anon_sym_alias] = ACTIONS(4157),
    [anon_sym_global] = ACTIONS(4157),
    [anon_sym_EQ] = ACTIONS(4162),
    [anon_sym_LBRACK] = ACTIONS(4193),
    [anon_sym_COLON] = ACTIONS(4177),
    [anon_sym_COMMA] = ACTIONS(4159),
    [anon_sym_RBRACK] = ACTIONS(4159),
    [anon_sym_LPAREN] = ACTIONS(4193),
    [anon_sym_RPAREN] = ACTIONS(4159),
    [anon_sym_LBRACE] = ACTIONS(4168),
    [anon_sym_RBRACE] = ACTIONS(4159),
    [anon_sym_file] = ACTIONS(4157),
    [anon_sym_LT] = ACTIONS(4162),
    [anon_sym_GT] = ACTIONS(4162),
    [anon_sym_where] = ACTIONS(4157),
    [anon_sym_QMARK] = ACTIONS(4196),
    [anon_sym_notnull] = ACTIONS(4157),
    [anon_sym_unmanaged] = ACTIONS(4157),
    [anon_sym_BANG] = ACTIONS(4162),
    [anon_sym_PLUS_PLUS] = ACTIONS(4177),
    [anon_sym_DASH_DASH] = ACTIONS(4177),
    [anon_sym_PLUS] = ACTIONS(4162),
    [anon_sym_DASH] = ACTIONS(4162),
    [anon_sym_STAR] = ACTIONS(4196),
    [anon_sym_SLASH] = ACTIONS(4162),
    [anon_sym_PERCENT] = ACTIONS(4162),
    [anon_sym_CARET] = ACTIONS(4162),
    [anon_sym_PIPE] = ACTIONS(4162),
    [anon_sym_AMP] = ACTIONS(4162),
    [anon_sym_LT_LT] = ACTIONS(4162),
    [anon_sym_GT_GT] = ACTIONS(4162),
    [anon_sym_GT_GT_GT] = ACTIONS(4162),
    [anon_sym_EQ_EQ] = ACTIONS(4177),
    [anon_sym_BANG_EQ] = ACTIONS(4177),
    [anon_sym_GT_EQ] = ACTIONS(4177),
    [anon_sym_LT_EQ] = ACTIONS(4177),
    [anon_sym_DOT] = ACTIONS(4196),
    [anon_sym_scoped] = ACTIONS(4157),
    [anon_sym_var] = ACTIONS(4157),
    [anon_sym_yield] = ACTIONS(4157),
    [anon_sym_switch] = ACTIONS(4162),
    [anon_sym_when] = ACTIONS(4157),
    [sym_discard] = ACTIONS(4157),
    [anon_sym_DOT_DOT] = ACTIONS(4177),
    [anon_sym_and] = ACTIONS(4174),
    [anon_sym_or] = ACTIONS(4174),
    [anon_sym_PLUS_EQ] = ACTIONS(4177),
    [anon_sym_DASH_EQ] = ACTIONS(4177),
    [anon_sym_STAR_EQ] = ACTIONS(4177),
    [anon_sym_SLASH_EQ] = ACTIONS(4177),
    [anon_sym_PERCENT_EQ] = ACTIONS(4177),
    [anon_sym_AMP_EQ] = ACTIONS(4177),
    [anon_sym_CARET_EQ] = ACTIONS(4177),
    [anon_sym_PIPE_EQ] = ACTIONS(4177),
    [anon_sym_LT_LT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4177),
    [anon_sym_AMP_AMP] = ACTIONS(4177),
    [anon_sym_PIPE_PIPE] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK] = ACTIONS(4162),
    [anon_sym_from] = ACTIONS(4157),
    [anon_sym_into] = ACTIONS(4157),
    [anon_sym_join] = ACTIONS(4157),
    [anon_sym_on] = ACTIONS(4157),
    [anon_sym_equals] = ACTIONS(4157),
    [anon_sym_let] = ACTIONS(4157),
    [anon_sym_orderby] = ACTIONS(4157),
    [anon_sym_ascending] = ACTIONS(4157),
    [anon_sym_descending] = ACTIONS(4157),
    [anon_sym_group] = ACTIONS(4157),
    [anon_sym_by] = ACTIONS(4157),
    [anon_sym_select] = ACTIONS(4157),
    [anon_sym_as] = ACTIONS(4162),
    [anon_sym_is] = ACTIONS(4162),
    [anon_sym_DASH_GT] = ACTIONS(4193),
    [anon_sym_with] = ACTIONS(4162),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2803] = {
    [sym_preproc_region] = STATE(2803),
    [sym_preproc_endregion] = STATE(2803),
    [sym_preproc_line] = STATE(2803),
    [sym_preproc_pragma] = STATE(2803),
    [sym_preproc_nullable] = STATE(2803),
    [sym_preproc_error] = STATE(2803),
    [sym_preproc_warning] = STATE(2803),
    [sym_preproc_define] = STATE(2803),
    [sym_preproc_undef] = STATE(2803),
    [sym__identifier_token] = ACTIONS(3995),
    [anon_sym_alias] = ACTIONS(3995),
    [anon_sym_global] = ACTIONS(3995),
    [anon_sym_EQ] = ACTIONS(3995),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_COLON] = ACTIONS(3995),
    [anon_sym_COMMA] = ACTIONS(3993),
    [anon_sym_LPAREN] = ACTIONS(3993),
    [anon_sym_LBRACE] = ACTIONS(3993),
    [anon_sym_file] = ACTIONS(3995),
    [anon_sym_LT] = ACTIONS(3995),
    [anon_sym_GT] = ACTIONS(3995),
    [anon_sym_where] = ACTIONS(3995),
    [anon_sym_QMARK] = ACTIONS(3995),
    [anon_sym_notnull] = ACTIONS(3995),
    [anon_sym_unmanaged] = ACTIONS(3995),
    [anon_sym_BANG] = ACTIONS(3995),
    [anon_sym_PLUS_PLUS] = ACTIONS(3993),
    [anon_sym_DASH_DASH] = ACTIONS(3993),
    [anon_sym_PLUS] = ACTIONS(3995),
    [anon_sym_DASH] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3995),
    [anon_sym_SLASH] = ACTIONS(3995),
    [anon_sym_PERCENT] = ACTIONS(3995),
    [anon_sym_CARET] = ACTIONS(3995),
    [anon_sym_PIPE] = ACTIONS(3995),
    [anon_sym_AMP] = ACTIONS(3995),
    [anon_sym_LT_LT] = ACTIONS(3995),
    [anon_sym_GT_GT] = ACTIONS(3995),
    [anon_sym_GT_GT_GT] = ACTIONS(3995),
    [anon_sym_EQ_EQ] = ACTIONS(3993),
    [anon_sym_BANG_EQ] = ACTIONS(3993),
    [anon_sym_GT_EQ] = ACTIONS(3993),
    [anon_sym_LT_EQ] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3995),
    [anon_sym_scoped] = ACTIONS(3995),
    [anon_sym_EQ_GT] = ACTIONS(3993),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(3995),
    [anon_sym_yield] = ACTIONS(3995),
    [anon_sym_switch] = ACTIONS(3995),
    [anon_sym_when] = ACTIONS(3995),
    [sym_discard] = ACTIONS(3995),
    [anon_sym_DOT_DOT] = ACTIONS(3993),
    [anon_sym_and] = ACTIONS(3995),
    [anon_sym_or] = ACTIONS(3995),
    [anon_sym_PLUS_EQ] = ACTIONS(3993),
    [anon_sym_DASH_EQ] = ACTIONS(3993),
    [anon_sym_STAR_EQ] = ACTIONS(3993),
    [anon_sym_SLASH_EQ] = ACTIONS(3993),
    [anon_sym_PERCENT_EQ] = ACTIONS(3993),
    [anon_sym_AMP_EQ] = ACTIONS(3993),
    [anon_sym_CARET_EQ] = ACTIONS(3993),
    [anon_sym_PIPE_EQ] = ACTIONS(3993),
    [anon_sym_LT_LT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(3993),
    [anon_sym_AMP_AMP] = ACTIONS(3993),
    [anon_sym_PIPE_PIPE] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK] = ACTIONS(3995),
    [anon_sym_from] = ACTIONS(3995),
    [anon_sym_into] = ACTIONS(3995),
    [anon_sym_join] = ACTIONS(3995),
    [anon_sym_on] = ACTIONS(3995),
    [anon_sym_equals] = ACTIONS(3995),
    [anon_sym_let] = ACTIONS(3995),
    [anon_sym_orderby] = ACTIONS(3995),
    [anon_sym_ascending] = ACTIONS(3995),
    [anon_sym_descending] = ACTIONS(3995),
    [anon_sym_group] = ACTIONS(3995),
    [anon_sym_by] = ACTIONS(3995),
    [anon_sym_select] = ACTIONS(3995),
    [anon_sym_as] = ACTIONS(3995),
    [anon_sym_is] = ACTIONS(3995),
    [anon_sym_DASH_GT] = ACTIONS(3993),
    [anon_sym_with] = ACTIONS(3995),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(3993),
  },
  [2804] = {
    [sym_preproc_region] = STATE(2804),
    [sym_preproc_endregion] = STATE(2804),
    [sym_preproc_line] = STATE(2804),
    [sym_preproc_pragma] = STATE(2804),
    [sym_preproc_nullable] = STATE(2804),
    [sym_preproc_error] = STATE(2804),
    [sym_preproc_warning] = STATE(2804),
    [sym_preproc_define] = STATE(2804),
    [sym_preproc_undef] = STATE(2804),
    [sym__identifier_token] = ACTIONS(4122),
    [anon_sym_alias] = ACTIONS(4122),
    [anon_sym_global] = ACTIONS(4122),
    [anon_sym_EQ] = ACTIONS(4122),
    [anon_sym_LBRACK] = ACTIONS(4124),
    [anon_sym_COLON] = ACTIONS(4122),
    [anon_sym_COMMA] = ACTIONS(4124),
    [anon_sym_LPAREN] = ACTIONS(4124),
    [anon_sym_LBRACE] = ACTIONS(4124),
    [anon_sym_file] = ACTIONS(4122),
    [anon_sym_LT] = ACTIONS(4122),
    [anon_sym_GT] = ACTIONS(4122),
    [anon_sym_where] = ACTIONS(4122),
    [anon_sym_QMARK] = ACTIONS(4122),
    [anon_sym_notnull] = ACTIONS(4122),
    [anon_sym_unmanaged] = ACTIONS(4122),
    [anon_sym_BANG] = ACTIONS(4122),
    [anon_sym_PLUS_PLUS] = ACTIONS(4124),
    [anon_sym_DASH_DASH] = ACTIONS(4124),
    [anon_sym_PLUS] = ACTIONS(4122),
    [anon_sym_DASH] = ACTIONS(4122),
    [anon_sym_STAR] = ACTIONS(4122),
    [anon_sym_SLASH] = ACTIONS(4122),
    [anon_sym_PERCENT] = ACTIONS(4122),
    [anon_sym_CARET] = ACTIONS(4122),
    [anon_sym_PIPE] = ACTIONS(4122),
    [anon_sym_AMP] = ACTIONS(4122),
    [anon_sym_LT_LT] = ACTIONS(4122),
    [anon_sym_GT_GT] = ACTIONS(4122),
    [anon_sym_GT_GT_GT] = ACTIONS(4122),
    [anon_sym_EQ_EQ] = ACTIONS(4124),
    [anon_sym_BANG_EQ] = ACTIONS(4124),
    [anon_sym_GT_EQ] = ACTIONS(4124),
    [anon_sym_LT_EQ] = ACTIONS(4124),
    [anon_sym_DOT] = ACTIONS(4122),
    [anon_sym_scoped] = ACTIONS(4122),
    [anon_sym_EQ_GT] = ACTIONS(4124),
    [anon_sym_COLON_COLON] = ACTIONS(4124),
    [anon_sym_var] = ACTIONS(4122),
    [anon_sym_yield] = ACTIONS(4122),
    [anon_sym_switch] = ACTIONS(4122),
    [anon_sym_when] = ACTIONS(4122),
    [sym_discard] = ACTIONS(4122),
    [anon_sym_DOT_DOT] = ACTIONS(4124),
    [anon_sym_and] = ACTIONS(4122),
    [anon_sym_or] = ACTIONS(4122),
    [anon_sym_PLUS_EQ] = ACTIONS(4124),
    [anon_sym_DASH_EQ] = ACTIONS(4124),
    [anon_sym_STAR_EQ] = ACTIONS(4124),
    [anon_sym_SLASH_EQ] = ACTIONS(4124),
    [anon_sym_PERCENT_EQ] = ACTIONS(4124),
    [anon_sym_AMP_EQ] = ACTIONS(4124),
    [anon_sym_CARET_EQ] = ACTIONS(4124),
    [anon_sym_PIPE_EQ] = ACTIONS(4124),
    [anon_sym_LT_LT_EQ] = ACTIONS(4124),
    [anon_sym_GT_GT_EQ] = ACTIONS(4124),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4124),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4124),
    [anon_sym_AMP_AMP] = ACTIONS(4124),
    [anon_sym_PIPE_PIPE] = ACTIONS(4124),
    [anon_sym_QMARK_QMARK] = ACTIONS(4122),
    [anon_sym_from] = ACTIONS(4122),
    [anon_sym_into] = ACTIONS(4122),
    [anon_sym_join] = ACTIONS(4122),
    [anon_sym_on] = ACTIONS(4122),
    [anon_sym_equals] = ACTIONS(4122),
    [anon_sym_let] = ACTIONS(4122),
    [anon_sym_orderby] = ACTIONS(4122),
    [anon_sym_ascending] = ACTIONS(4122),
    [anon_sym_descending] = ACTIONS(4122),
    [anon_sym_group] = ACTIONS(4122),
    [anon_sym_by] = ACTIONS(4122),
    [anon_sym_select] = ACTIONS(4122),
    [anon_sym_as] = ACTIONS(4122),
    [anon_sym_is] = ACTIONS(4122),
    [anon_sym_DASH_GT] = ACTIONS(4124),
    [anon_sym_with] = ACTIONS(4122),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4124),
  },
  [2805] = {
    [sym_parameter_list] = STATE(9685),
    [sym_positional_pattern_clause] = STATE(2842),
    [sym_property_pattern_clause] = STATE(2879),
    [sym__variable_designation] = STATE(4091),
    [sym_parenthesized_variable_designation] = STATE(3966),
    [sym__lambda_parameters] = STATE(9890),
    [sym_identifier] = STATE(4070),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(2805),
    [sym_preproc_endregion] = STATE(2805),
    [sym_preproc_line] = STATE(2805),
    [sym_preproc_pragma] = STATE(2805),
    [sym_preproc_nullable] = STATE(2805),
    [sym_preproc_error] = STATE(2805),
    [sym_preproc_warning] = STATE(2805),
    [sym_preproc_define] = STATE(2805),
    [sym_preproc_undef] = STATE(2805),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_SEMI] = ACTIONS(4357),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4357),
    [anon_sym_COLON] = ACTIONS(4357),
    [anon_sym_COMMA] = ACTIONS(4357),
    [anon_sym_RBRACK] = ACTIONS(4357),
    [anon_sym_LPAREN] = ACTIONS(4357),
    [anon_sym_RPAREN] = ACTIONS(4357),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_RBRACE] = ACTIONS(4357),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4355),
    [anon_sym_GT] = ACTIONS(4355),
    [anon_sym_in] = ACTIONS(4355),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4355),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4355),
    [anon_sym_PLUS_PLUS] = ACTIONS(4357),
    [anon_sym_DASH_DASH] = ACTIONS(4357),
    [anon_sym_PLUS] = ACTIONS(4355),
    [anon_sym_DASH] = ACTIONS(4355),
    [anon_sym_STAR] = ACTIONS(4357),
    [anon_sym_SLASH] = ACTIONS(4355),
    [anon_sym_PERCENT] = ACTIONS(4357),
    [anon_sym_CARET] = ACTIONS(4357),
    [anon_sym_PIPE] = ACTIONS(4355),
    [anon_sym_AMP] = ACTIONS(4355),
    [anon_sym_LT_LT] = ACTIONS(4357),
    [anon_sym_GT_GT] = ACTIONS(4355),
    [anon_sym_GT_GT_GT] = ACTIONS(4357),
    [anon_sym_EQ_EQ] = ACTIONS(4357),
    [anon_sym_BANG_EQ] = ACTIONS(4357),
    [anon_sym_GT_EQ] = ACTIONS(4357),
    [anon_sym_LT_EQ] = ACTIONS(4357),
    [anon_sym_DOT] = ACTIONS(4355),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4355),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4347),
    [anon_sym_DOT_DOT] = ACTIONS(4357),
    [anon_sym_and] = ACTIONS(4355),
    [anon_sym_or] = ACTIONS(4355),
    [anon_sym_AMP_AMP] = ACTIONS(4357),
    [anon_sym_PIPE_PIPE] = ACTIONS(4357),
    [anon_sym_QMARK_QMARK] = ACTIONS(4357),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4355),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4355),
    [anon_sym_is] = ACTIONS(4355),
    [anon_sym_DASH_GT] = ACTIONS(4357),
    [anon_sym_with] = ACTIONS(4355),
    [aux_sym_preproc_if_token3] = ACTIONS(4357),
    [aux_sym_preproc_else_token1] = ACTIONS(4357),
    [aux_sym_preproc_elif_token1] = ACTIONS(4357),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2806] = {
    [sym_preproc_region] = STATE(2806),
    [sym_preproc_endregion] = STATE(2806),
    [sym_preproc_line] = STATE(2806),
    [sym_preproc_pragma] = STATE(2806),
    [sym_preproc_nullable] = STATE(2806),
    [sym_preproc_error] = STATE(2806),
    [sym_preproc_warning] = STATE(2806),
    [sym_preproc_define] = STATE(2806),
    [sym_preproc_undef] = STATE(2806),
    [sym__identifier_token] = ACTIONS(4157),
    [anon_sym_alias] = ACTIONS(4157),
    [anon_sym_SEMI] = ACTIONS(4177),
    [anon_sym_global] = ACTIONS(4157),
    [anon_sym_EQ] = ACTIONS(4162),
    [anon_sym_LBRACK] = ACTIONS(4193),
    [anon_sym_COLON] = ACTIONS(4177),
    [anon_sym_COMMA] = ACTIONS(4177),
    [anon_sym_RBRACK] = ACTIONS(4177),
    [anon_sym_LPAREN] = ACTIONS(4193),
    [anon_sym_RPAREN] = ACTIONS(4177),
    [anon_sym_RBRACE] = ACTIONS(4177),
    [anon_sym_file] = ACTIONS(4157),
    [anon_sym_LT] = ACTIONS(4162),
    [anon_sym_GT] = ACTIONS(4162),
    [anon_sym_where] = ACTIONS(4157),
    [anon_sym_QMARK] = ACTIONS(4196),
    [anon_sym_notnull] = ACTIONS(4157),
    [anon_sym_unmanaged] = ACTIONS(4157),
    [anon_sym_BANG] = ACTIONS(4162),
    [anon_sym_PLUS_PLUS] = ACTIONS(4177),
    [anon_sym_DASH_DASH] = ACTIONS(4177),
    [anon_sym_PLUS] = ACTIONS(4162),
    [anon_sym_DASH] = ACTIONS(4162),
    [anon_sym_STAR] = ACTIONS(4196),
    [anon_sym_SLASH] = ACTIONS(4162),
    [anon_sym_PERCENT] = ACTIONS(4162),
    [anon_sym_CARET] = ACTIONS(4162),
    [anon_sym_PIPE] = ACTIONS(4162),
    [anon_sym_AMP] = ACTIONS(4162),
    [anon_sym_LT_LT] = ACTIONS(4162),
    [anon_sym_GT_GT] = ACTIONS(4162),
    [anon_sym_GT_GT_GT] = ACTIONS(4162),
    [anon_sym_EQ_EQ] = ACTIONS(4177),
    [anon_sym_BANG_EQ] = ACTIONS(4177),
    [anon_sym_GT_EQ] = ACTIONS(4177),
    [anon_sym_LT_EQ] = ACTIONS(4177),
    [anon_sym_DOT] = ACTIONS(4196),
    [anon_sym_scoped] = ACTIONS(4157),
    [anon_sym_var] = ACTIONS(4157),
    [anon_sym_yield] = ACTIONS(4157),
    [anon_sym_switch] = ACTIONS(4162),
    [anon_sym_when] = ACTIONS(4157),
    [anon_sym_DOT_DOT] = ACTIONS(4177),
    [anon_sym_and] = ACTIONS(4162),
    [anon_sym_or] = ACTIONS(4162),
    [anon_sym_PLUS_EQ] = ACTIONS(4177),
    [anon_sym_DASH_EQ] = ACTIONS(4177),
    [anon_sym_STAR_EQ] = ACTIONS(4177),
    [anon_sym_SLASH_EQ] = ACTIONS(4177),
    [anon_sym_PERCENT_EQ] = ACTIONS(4177),
    [anon_sym_AMP_EQ] = ACTIONS(4177),
    [anon_sym_CARET_EQ] = ACTIONS(4177),
    [anon_sym_PIPE_EQ] = ACTIONS(4177),
    [anon_sym_LT_LT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4177),
    [anon_sym_AMP_AMP] = ACTIONS(4177),
    [anon_sym_PIPE_PIPE] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK] = ACTIONS(4162),
    [anon_sym_from] = ACTIONS(4157),
    [anon_sym_into] = ACTIONS(4157),
    [anon_sym_join] = ACTIONS(4157),
    [anon_sym_on] = ACTIONS(4157),
    [anon_sym_equals] = ACTIONS(4157),
    [anon_sym_let] = ACTIONS(4157),
    [anon_sym_orderby] = ACTIONS(4157),
    [anon_sym_ascending] = ACTIONS(4157),
    [anon_sym_descending] = ACTIONS(4157),
    [anon_sym_group] = ACTIONS(4157),
    [anon_sym_by] = ACTIONS(4157),
    [anon_sym_select] = ACTIONS(4157),
    [anon_sym_as] = ACTIONS(4162),
    [anon_sym_is] = ACTIONS(4162),
    [anon_sym_DASH_GT] = ACTIONS(4193),
    [anon_sym_with] = ACTIONS(4162),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2807] = {
    [sym_type_argument_list] = STATE(2821),
    [sym_preproc_region] = STATE(2807),
    [sym_preproc_endregion] = STATE(2807),
    [sym_preproc_line] = STATE(2807),
    [sym_preproc_pragma] = STATE(2807),
    [sym_preproc_nullable] = STATE(2807),
    [sym_preproc_error] = STATE(2807),
    [sym_preproc_warning] = STATE(2807),
    [sym_preproc_define] = STATE(2807),
    [sym_preproc_undef] = STATE(2807),
    [sym__identifier_token] = ACTIONS(4138),
    [anon_sym_alias] = ACTIONS(4138),
    [anon_sym_global] = ACTIONS(4138),
    [anon_sym_EQ] = ACTIONS(4138),
    [anon_sym_LBRACK] = ACTIONS(4140),
    [anon_sym_COLON] = ACTIONS(4138),
    [anon_sym_COMMA] = ACTIONS(4140),
    [anon_sym_LPAREN] = ACTIONS(4140),
    [anon_sym_file] = ACTIONS(4138),
    [anon_sym_LT] = ACTIONS(4323),
    [anon_sym_GT] = ACTIONS(4138),
    [anon_sym_where] = ACTIONS(4138),
    [anon_sym_QMARK] = ACTIONS(4138),
    [anon_sym_notnull] = ACTIONS(4138),
    [anon_sym_unmanaged] = ACTIONS(4138),
    [anon_sym_BANG] = ACTIONS(4138),
    [anon_sym_PLUS_PLUS] = ACTIONS(4140),
    [anon_sym_DASH_DASH] = ACTIONS(4140),
    [anon_sym_PLUS] = ACTIONS(4138),
    [anon_sym_DASH] = ACTIONS(4138),
    [anon_sym_STAR] = ACTIONS(4138),
    [anon_sym_SLASH] = ACTIONS(4138),
    [anon_sym_PERCENT] = ACTIONS(4138),
    [anon_sym_CARET] = ACTIONS(4138),
    [anon_sym_PIPE] = ACTIONS(4138),
    [anon_sym_AMP] = ACTIONS(4138),
    [anon_sym_LT_LT] = ACTIONS(4138),
    [anon_sym_GT_GT] = ACTIONS(4138),
    [anon_sym_GT_GT_GT] = ACTIONS(4138),
    [anon_sym_EQ_EQ] = ACTIONS(4140),
    [anon_sym_BANG_EQ] = ACTIONS(4140),
    [anon_sym_GT_EQ] = ACTIONS(4140),
    [anon_sym_LT_EQ] = ACTIONS(4140),
    [anon_sym_DOT] = ACTIONS(4138),
    [anon_sym_scoped] = ACTIONS(4138),
    [anon_sym_EQ_GT] = ACTIONS(4145),
    [anon_sym_COLON_COLON] = ACTIONS(4147),
    [anon_sym_var] = ACTIONS(4138),
    [anon_sym_yield] = ACTIONS(4138),
    [anon_sym_switch] = ACTIONS(4138),
    [anon_sym_when] = ACTIONS(4138),
    [anon_sym_DOT_DOT] = ACTIONS(4140),
    [anon_sym_and] = ACTIONS(4138),
    [anon_sym_or] = ACTIONS(4138),
    [anon_sym_PLUS_EQ] = ACTIONS(4140),
    [anon_sym_DASH_EQ] = ACTIONS(4140),
    [anon_sym_STAR_EQ] = ACTIONS(4140),
    [anon_sym_SLASH_EQ] = ACTIONS(4140),
    [anon_sym_PERCENT_EQ] = ACTIONS(4140),
    [anon_sym_AMP_EQ] = ACTIONS(4140),
    [anon_sym_CARET_EQ] = ACTIONS(4140),
    [anon_sym_PIPE_EQ] = ACTIONS(4140),
    [anon_sym_LT_LT_EQ] = ACTIONS(4140),
    [anon_sym_GT_GT_EQ] = ACTIONS(4140),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4140),
    [anon_sym_AMP_AMP] = ACTIONS(4140),
    [anon_sym_PIPE_PIPE] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK] = ACTIONS(4138),
    [anon_sym_from] = ACTIONS(4138),
    [anon_sym_into] = ACTIONS(4138),
    [anon_sym_join] = ACTIONS(4138),
    [anon_sym_on] = ACTIONS(4138),
    [anon_sym_equals] = ACTIONS(4138),
    [anon_sym_let] = ACTIONS(4138),
    [anon_sym_orderby] = ACTIONS(4138),
    [anon_sym_ascending] = ACTIONS(4138),
    [anon_sym_descending] = ACTIONS(4138),
    [anon_sym_group] = ACTIONS(4138),
    [anon_sym_by] = ACTIONS(4138),
    [anon_sym_select] = ACTIONS(4138),
    [anon_sym_as] = ACTIONS(4138),
    [anon_sym_is] = ACTIONS(4138),
    [anon_sym_DASH_GT] = ACTIONS(4140),
    [anon_sym_with] = ACTIONS(4138),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4140),
  },
  [2808] = {
    [sym_type_argument_list] = STATE(2821),
    [sym_preproc_region] = STATE(2808),
    [sym_preproc_endregion] = STATE(2808),
    [sym_preproc_line] = STATE(2808),
    [sym_preproc_pragma] = STATE(2808),
    [sym_preproc_nullable] = STATE(2808),
    [sym_preproc_error] = STATE(2808),
    [sym_preproc_warning] = STATE(2808),
    [sym_preproc_define] = STATE(2808),
    [sym_preproc_undef] = STATE(2808),
    [sym__identifier_token] = ACTIONS(4138),
    [anon_sym_alias] = ACTIONS(4138),
    [anon_sym_global] = ACTIONS(4138),
    [anon_sym_EQ] = ACTIONS(4138),
    [anon_sym_LBRACK] = ACTIONS(4140),
    [anon_sym_COLON] = ACTIONS(4140),
    [anon_sym_COMMA] = ACTIONS(4140),
    [anon_sym_LPAREN] = ACTIONS(4140),
    [anon_sym_LBRACE] = ACTIONS(4140),
    [anon_sym_file] = ACTIONS(4138),
    [anon_sym_LT] = ACTIONS(4323),
    [anon_sym_GT] = ACTIONS(4138),
    [anon_sym_where] = ACTIONS(4138),
    [anon_sym_QMARK] = ACTIONS(4138),
    [anon_sym_notnull] = ACTIONS(4138),
    [anon_sym_unmanaged] = ACTIONS(4138),
    [anon_sym_BANG] = ACTIONS(4138),
    [anon_sym_PLUS_PLUS] = ACTIONS(4140),
    [anon_sym_DASH_DASH] = ACTIONS(4140),
    [anon_sym_PLUS] = ACTIONS(4138),
    [anon_sym_DASH] = ACTIONS(4138),
    [anon_sym_STAR] = ACTIONS(4138),
    [anon_sym_SLASH] = ACTIONS(4138),
    [anon_sym_PERCENT] = ACTIONS(4138),
    [anon_sym_CARET] = ACTIONS(4138),
    [anon_sym_PIPE] = ACTIONS(4138),
    [anon_sym_AMP] = ACTIONS(4138),
    [anon_sym_LT_LT] = ACTIONS(4138),
    [anon_sym_GT_GT] = ACTIONS(4138),
    [anon_sym_GT_GT_GT] = ACTIONS(4138),
    [anon_sym_EQ_EQ] = ACTIONS(4140),
    [anon_sym_BANG_EQ] = ACTIONS(4140),
    [anon_sym_GT_EQ] = ACTIONS(4140),
    [anon_sym_LT_EQ] = ACTIONS(4140),
    [anon_sym_DOT] = ACTIONS(4138),
    [anon_sym_scoped] = ACTIONS(4138),
    [anon_sym_var] = ACTIONS(4138),
    [anon_sym_yield] = ACTIONS(4138),
    [anon_sym_switch] = ACTIONS(4138),
    [anon_sym_when] = ACTIONS(4138),
    [sym_discard] = ACTIONS(4138),
    [anon_sym_DOT_DOT] = ACTIONS(4140),
    [anon_sym_and] = ACTIONS(4138),
    [anon_sym_or] = ACTIONS(4138),
    [anon_sym_PLUS_EQ] = ACTIONS(4140),
    [anon_sym_DASH_EQ] = ACTIONS(4140),
    [anon_sym_STAR_EQ] = ACTIONS(4140),
    [anon_sym_SLASH_EQ] = ACTIONS(4140),
    [anon_sym_PERCENT_EQ] = ACTIONS(4140),
    [anon_sym_AMP_EQ] = ACTIONS(4140),
    [anon_sym_CARET_EQ] = ACTIONS(4140),
    [anon_sym_PIPE_EQ] = ACTIONS(4140),
    [anon_sym_LT_LT_EQ] = ACTIONS(4140),
    [anon_sym_GT_GT_EQ] = ACTIONS(4140),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4140),
    [anon_sym_AMP_AMP] = ACTIONS(4140),
    [anon_sym_PIPE_PIPE] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK] = ACTIONS(4138),
    [anon_sym_from] = ACTIONS(4138),
    [anon_sym_into] = ACTIONS(4138),
    [anon_sym_join] = ACTIONS(4138),
    [anon_sym_on] = ACTIONS(4138),
    [anon_sym_equals] = ACTIONS(4138),
    [anon_sym_let] = ACTIONS(4138),
    [anon_sym_orderby] = ACTIONS(4138),
    [anon_sym_ascending] = ACTIONS(4138),
    [anon_sym_descending] = ACTIONS(4138),
    [anon_sym_group] = ACTIONS(4138),
    [anon_sym_by] = ACTIONS(4138),
    [anon_sym_select] = ACTIONS(4138),
    [anon_sym_as] = ACTIONS(4138),
    [anon_sym_is] = ACTIONS(4138),
    [anon_sym_DASH_GT] = ACTIONS(4140),
    [anon_sym_with] = ACTIONS(4138),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4140),
  },
  [2809] = {
    [sym_parameter_list] = STATE(9685),
    [sym_positional_pattern_clause] = STATE(2854),
    [sym_property_pattern_clause] = STATE(2886),
    [sym__variable_designation] = STATE(4162),
    [sym_parenthesized_variable_designation] = STATE(4153),
    [sym__lambda_parameters] = STATE(9890),
    [sym_identifier] = STATE(4163),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(2809),
    [sym_preproc_endregion] = STATE(2809),
    [sym_preproc_line] = STATE(2809),
    [sym_preproc_pragma] = STATE(2809),
    [sym_preproc_nullable] = STATE(2809),
    [sym_preproc_error] = STATE(2809),
    [sym_preproc_warning] = STATE(2809),
    [sym_preproc_define] = STATE(2809),
    [sym_preproc_undef] = STATE(2809),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_SEMI] = ACTIONS(4341),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4341),
    [anon_sym_COLON] = ACTIONS(4341),
    [anon_sym_COMMA] = ACTIONS(4341),
    [anon_sym_RBRACK] = ACTIONS(4341),
    [anon_sym_LPAREN] = ACTIONS(4341),
    [anon_sym_RPAREN] = ACTIONS(4341),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_RBRACE] = ACTIONS(4341),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4345),
    [anon_sym_GT] = ACTIONS(4345),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4345),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4345),
    [anon_sym_PLUS_PLUS] = ACTIONS(4341),
    [anon_sym_DASH_DASH] = ACTIONS(4341),
    [anon_sym_PLUS] = ACTIONS(4345),
    [anon_sym_DASH] = ACTIONS(4345),
    [anon_sym_STAR] = ACTIONS(4341),
    [anon_sym_SLASH] = ACTIONS(4345),
    [anon_sym_PERCENT] = ACTIONS(4341),
    [anon_sym_CARET] = ACTIONS(4341),
    [anon_sym_PIPE] = ACTIONS(4345),
    [anon_sym_AMP] = ACTIONS(4345),
    [anon_sym_LT_LT] = ACTIONS(4341),
    [anon_sym_GT_GT] = ACTIONS(4345),
    [anon_sym_GT_GT_GT] = ACTIONS(4341),
    [anon_sym_EQ_EQ] = ACTIONS(4341),
    [anon_sym_BANG_EQ] = ACTIONS(4341),
    [anon_sym_GT_EQ] = ACTIONS(4341),
    [anon_sym_LT_EQ] = ACTIONS(4341),
    [anon_sym_DOT] = ACTIONS(4345),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4345),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4359),
    [anon_sym_DOT_DOT] = ACTIONS(4341),
    [anon_sym_and] = ACTIONS(4355),
    [anon_sym_or] = ACTIONS(4355),
    [anon_sym_AMP_AMP] = ACTIONS(4341),
    [anon_sym_PIPE_PIPE] = ACTIONS(4341),
    [anon_sym_QMARK_QMARK] = ACTIONS(4341),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4339),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4345),
    [anon_sym_is] = ACTIONS(4345),
    [anon_sym_DASH_GT] = ACTIONS(4341),
    [anon_sym_with] = ACTIONS(4345),
    [aux_sym_preproc_if_token3] = ACTIONS(4341),
    [aux_sym_preproc_else_token1] = ACTIONS(4341),
    [aux_sym_preproc_elif_token1] = ACTIONS(4341),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2810] = {
    [sym_type_argument_list] = STATE(2746),
    [sym_preproc_region] = STATE(2810),
    [sym_preproc_endregion] = STATE(2810),
    [sym_preproc_line] = STATE(2810),
    [sym_preproc_pragma] = STATE(2810),
    [sym_preproc_nullable] = STATE(2810),
    [sym_preproc_error] = STATE(2810),
    [sym_preproc_warning] = STATE(2810),
    [sym_preproc_define] = STATE(2810),
    [sym_preproc_undef] = STATE(2810),
    [sym__identifier_token] = ACTIONS(4138),
    [anon_sym_alias] = ACTIONS(4138),
    [anon_sym_global] = ACTIONS(4138),
    [anon_sym_EQ] = ACTIONS(4138),
    [anon_sym_LBRACK] = ACTIONS(4140),
    [anon_sym_COLON] = ACTIONS(4138),
    [anon_sym_LPAREN] = ACTIONS(4140),
    [anon_sym_LBRACE] = ACTIONS(4140),
    [anon_sym_file] = ACTIONS(4138),
    [anon_sym_LT] = ACTIONS(4142),
    [anon_sym_GT] = ACTIONS(4138),
    [anon_sym_where] = ACTIONS(4138),
    [anon_sym_QMARK] = ACTIONS(4138),
    [anon_sym_notnull] = ACTIONS(4138),
    [anon_sym_unmanaged] = ACTIONS(4138),
    [anon_sym_BANG] = ACTIONS(4138),
    [anon_sym_PLUS_PLUS] = ACTIONS(4140),
    [anon_sym_DASH_DASH] = ACTIONS(4140),
    [anon_sym_PLUS] = ACTIONS(4138),
    [anon_sym_DASH] = ACTIONS(4138),
    [anon_sym_STAR] = ACTIONS(4138),
    [anon_sym_SLASH] = ACTIONS(4138),
    [anon_sym_PERCENT] = ACTIONS(4138),
    [anon_sym_CARET] = ACTIONS(4138),
    [anon_sym_PIPE] = ACTIONS(4138),
    [anon_sym_AMP] = ACTIONS(4138),
    [anon_sym_LT_LT] = ACTIONS(4138),
    [anon_sym_GT_GT] = ACTIONS(4138),
    [anon_sym_GT_GT_GT] = ACTIONS(4138),
    [anon_sym_EQ_EQ] = ACTIONS(4140),
    [anon_sym_BANG_EQ] = ACTIONS(4140),
    [anon_sym_GT_EQ] = ACTIONS(4140),
    [anon_sym_LT_EQ] = ACTIONS(4140),
    [anon_sym_DOT] = ACTIONS(4138),
    [anon_sym_scoped] = ACTIONS(4138),
    [anon_sym_EQ_GT] = ACTIONS(4145),
    [anon_sym_COLON_COLON] = ACTIONS(4361),
    [anon_sym_var] = ACTIONS(4138),
    [anon_sym_yield] = ACTIONS(4138),
    [anon_sym_switch] = ACTIONS(4138),
    [anon_sym_when] = ACTIONS(4138),
    [sym_discard] = ACTIONS(4138),
    [anon_sym_DOT_DOT] = ACTIONS(4140),
    [anon_sym_and] = ACTIONS(4138),
    [anon_sym_or] = ACTIONS(4138),
    [anon_sym_PLUS_EQ] = ACTIONS(4140),
    [anon_sym_DASH_EQ] = ACTIONS(4140),
    [anon_sym_STAR_EQ] = ACTIONS(4140),
    [anon_sym_SLASH_EQ] = ACTIONS(4140),
    [anon_sym_PERCENT_EQ] = ACTIONS(4140),
    [anon_sym_AMP_EQ] = ACTIONS(4140),
    [anon_sym_CARET_EQ] = ACTIONS(4140),
    [anon_sym_PIPE_EQ] = ACTIONS(4140),
    [anon_sym_LT_LT_EQ] = ACTIONS(4140),
    [anon_sym_GT_GT_EQ] = ACTIONS(4140),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4140),
    [anon_sym_AMP_AMP] = ACTIONS(4140),
    [anon_sym_PIPE_PIPE] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK] = ACTIONS(4138),
    [anon_sym_from] = ACTIONS(4138),
    [anon_sym_into] = ACTIONS(4138),
    [anon_sym_join] = ACTIONS(4138),
    [anon_sym_on] = ACTIONS(4138),
    [anon_sym_equals] = ACTIONS(4138),
    [anon_sym_let] = ACTIONS(4138),
    [anon_sym_orderby] = ACTIONS(4138),
    [anon_sym_ascending] = ACTIONS(4138),
    [anon_sym_descending] = ACTIONS(4138),
    [anon_sym_group] = ACTIONS(4138),
    [anon_sym_by] = ACTIONS(4138),
    [anon_sym_select] = ACTIONS(4138),
    [anon_sym_as] = ACTIONS(4138),
    [anon_sym_is] = ACTIONS(4138),
    [anon_sym_DASH_GT] = ACTIONS(4140),
    [anon_sym_with] = ACTIONS(4138),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2811] = {
    [sym_preproc_region] = STATE(2811),
    [sym_preproc_endregion] = STATE(2811),
    [sym_preproc_line] = STATE(2811),
    [sym_preproc_pragma] = STATE(2811),
    [sym_preproc_nullable] = STATE(2811),
    [sym_preproc_error] = STATE(2811),
    [sym_preproc_warning] = STATE(2811),
    [sym_preproc_define] = STATE(2811),
    [sym_preproc_undef] = STATE(2811),
    [sym__identifier_token] = ACTIONS(3995),
    [anon_sym_alias] = ACTIONS(3995),
    [anon_sym_global] = ACTIONS(3995),
    [anon_sym_EQ] = ACTIONS(3995),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_COLON] = ACTIONS(3995),
    [anon_sym_LPAREN] = ACTIONS(3993),
    [anon_sym_return] = ACTIONS(4363),
    [anon_sym_file] = ACTIONS(3995),
    [anon_sym_LT] = ACTIONS(3995),
    [anon_sym_GT] = ACTIONS(3995),
    [anon_sym_where] = ACTIONS(3995),
    [anon_sym_QMARK] = ACTIONS(3995),
    [anon_sym_notnull] = ACTIONS(3995),
    [anon_sym_unmanaged] = ACTIONS(3995),
    [anon_sym_BANG] = ACTIONS(3995),
    [anon_sym_PLUS_PLUS] = ACTIONS(3993),
    [anon_sym_DASH_DASH] = ACTIONS(3993),
    [anon_sym_PLUS] = ACTIONS(3995),
    [anon_sym_DASH] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3995),
    [anon_sym_SLASH] = ACTIONS(3995),
    [anon_sym_PERCENT] = ACTIONS(3995),
    [anon_sym_CARET] = ACTIONS(3995),
    [anon_sym_PIPE] = ACTIONS(3995),
    [anon_sym_AMP] = ACTIONS(3995),
    [anon_sym_LT_LT] = ACTIONS(3995),
    [anon_sym_GT_GT] = ACTIONS(3995),
    [anon_sym_GT_GT_GT] = ACTIONS(3995),
    [anon_sym_EQ_EQ] = ACTIONS(3993),
    [anon_sym_BANG_EQ] = ACTIONS(3993),
    [anon_sym_GT_EQ] = ACTIONS(3993),
    [anon_sym_LT_EQ] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3995),
    [anon_sym_scoped] = ACTIONS(3995),
    [anon_sym_EQ_GT] = ACTIONS(3993),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(3995),
    [anon_sym_break] = ACTIONS(4365),
    [anon_sym_yield] = ACTIONS(3995),
    [anon_sym_switch] = ACTIONS(3995),
    [anon_sym_when] = ACTIONS(3995),
    [anon_sym_DOT_DOT] = ACTIONS(3993),
    [anon_sym_PLUS_EQ] = ACTIONS(3993),
    [anon_sym_DASH_EQ] = ACTIONS(3993),
    [anon_sym_STAR_EQ] = ACTIONS(3993),
    [anon_sym_SLASH_EQ] = ACTIONS(3993),
    [anon_sym_PERCENT_EQ] = ACTIONS(3993),
    [anon_sym_AMP_EQ] = ACTIONS(3993),
    [anon_sym_CARET_EQ] = ACTIONS(3993),
    [anon_sym_PIPE_EQ] = ACTIONS(3993),
    [anon_sym_LT_LT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(3993),
    [anon_sym_AMP_AMP] = ACTIONS(3993),
    [anon_sym_PIPE_PIPE] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK] = ACTIONS(3995),
    [anon_sym_from] = ACTIONS(3995),
    [anon_sym_into] = ACTIONS(3995),
    [anon_sym_join] = ACTIONS(3995),
    [anon_sym_on] = ACTIONS(3995),
    [anon_sym_equals] = ACTIONS(3995),
    [anon_sym_let] = ACTIONS(3995),
    [anon_sym_orderby] = ACTIONS(3995),
    [anon_sym_ascending] = ACTIONS(3995),
    [anon_sym_descending] = ACTIONS(3995),
    [anon_sym_group] = ACTIONS(3995),
    [anon_sym_by] = ACTIONS(3995),
    [anon_sym_select] = ACTIONS(3995),
    [anon_sym_as] = ACTIONS(3995),
    [anon_sym_is] = ACTIONS(3995),
    [anon_sym_DASH_GT] = ACTIONS(3993),
    [anon_sym_with] = ACTIONS(3995),
    [aux_sym_preproc_if_token3] = ACTIONS(3993),
    [aux_sym_preproc_else_token1] = ACTIONS(3993),
    [aux_sym_preproc_elif_token1] = ACTIONS(3993),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2812] = {
    [sym_preproc_region] = STATE(2812),
    [sym_preproc_endregion] = STATE(2812),
    [sym_preproc_line] = STATE(2812),
    [sym_preproc_pragma] = STATE(2812),
    [sym_preproc_nullable] = STATE(2812),
    [sym_preproc_error] = STATE(2812),
    [sym_preproc_warning] = STATE(2812),
    [sym_preproc_define] = STATE(2812),
    [sym_preproc_undef] = STATE(2812),
    [sym__identifier_token] = ACTIONS(4122),
    [anon_sym_alias] = ACTIONS(4122),
    [anon_sym_global] = ACTIONS(4122),
    [anon_sym_EQ] = ACTIONS(4122),
    [anon_sym_LBRACK] = ACTIONS(4124),
    [anon_sym_COLON] = ACTIONS(4124),
    [anon_sym_COMMA] = ACTIONS(4124),
    [anon_sym_LPAREN] = ACTIONS(4124),
    [anon_sym_RPAREN] = ACTIONS(4124),
    [anon_sym_LBRACE] = ACTIONS(4124),
    [anon_sym_RBRACE] = ACTIONS(4124),
    [anon_sym_file] = ACTIONS(4122),
    [anon_sym_LT] = ACTIONS(4122),
    [anon_sym_GT] = ACTIONS(4122),
    [anon_sym_where] = ACTIONS(4122),
    [anon_sym_QMARK] = ACTIONS(4122),
    [anon_sym_notnull] = ACTIONS(4122),
    [anon_sym_unmanaged] = ACTIONS(4122),
    [anon_sym_BANG] = ACTIONS(4122),
    [anon_sym_PLUS_PLUS] = ACTIONS(4124),
    [anon_sym_DASH_DASH] = ACTIONS(4124),
    [anon_sym_PLUS] = ACTIONS(4122),
    [anon_sym_DASH] = ACTIONS(4122),
    [anon_sym_STAR] = ACTIONS(4122),
    [anon_sym_SLASH] = ACTIONS(4122),
    [anon_sym_PERCENT] = ACTIONS(4122),
    [anon_sym_CARET] = ACTIONS(4122),
    [anon_sym_PIPE] = ACTIONS(4122),
    [anon_sym_AMP] = ACTIONS(4122),
    [anon_sym_LT_LT] = ACTIONS(4122),
    [anon_sym_GT_GT] = ACTIONS(4122),
    [anon_sym_GT_GT_GT] = ACTIONS(4122),
    [anon_sym_EQ_EQ] = ACTIONS(4124),
    [anon_sym_BANG_EQ] = ACTIONS(4124),
    [anon_sym_GT_EQ] = ACTIONS(4124),
    [anon_sym_LT_EQ] = ACTIONS(4124),
    [anon_sym_DOT] = ACTIONS(4122),
    [anon_sym_scoped] = ACTIONS(4122),
    [anon_sym_var] = ACTIONS(4122),
    [anon_sym_yield] = ACTIONS(4122),
    [anon_sym_switch] = ACTIONS(4122),
    [anon_sym_when] = ACTIONS(4122),
    [sym_discard] = ACTIONS(4122),
    [anon_sym_DOT_DOT] = ACTIONS(4124),
    [anon_sym_and] = ACTIONS(4122),
    [anon_sym_or] = ACTIONS(4122),
    [anon_sym_PLUS_EQ] = ACTIONS(4124),
    [anon_sym_DASH_EQ] = ACTIONS(4124),
    [anon_sym_STAR_EQ] = ACTIONS(4124),
    [anon_sym_SLASH_EQ] = ACTIONS(4124),
    [anon_sym_PERCENT_EQ] = ACTIONS(4124),
    [anon_sym_AMP_EQ] = ACTIONS(4124),
    [anon_sym_CARET_EQ] = ACTIONS(4124),
    [anon_sym_PIPE_EQ] = ACTIONS(4124),
    [anon_sym_LT_LT_EQ] = ACTIONS(4124),
    [anon_sym_GT_GT_EQ] = ACTIONS(4124),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4124),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4124),
    [anon_sym_AMP_AMP] = ACTIONS(4124),
    [anon_sym_PIPE_PIPE] = ACTIONS(4124),
    [anon_sym_QMARK_QMARK] = ACTIONS(4122),
    [anon_sym_from] = ACTIONS(4122),
    [anon_sym_into] = ACTIONS(4122),
    [anon_sym_join] = ACTIONS(4122),
    [anon_sym_on] = ACTIONS(4122),
    [anon_sym_equals] = ACTIONS(4122),
    [anon_sym_let] = ACTIONS(4122),
    [anon_sym_orderby] = ACTIONS(4122),
    [anon_sym_ascending] = ACTIONS(4122),
    [anon_sym_descending] = ACTIONS(4122),
    [anon_sym_group] = ACTIONS(4122),
    [anon_sym_by] = ACTIONS(4122),
    [anon_sym_select] = ACTIONS(4122),
    [anon_sym_as] = ACTIONS(4122),
    [anon_sym_is] = ACTIONS(4122),
    [anon_sym_DASH_GT] = ACTIONS(4124),
    [anon_sym_with] = ACTIONS(4122),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2813] = {
    [sym_parameter_list] = STATE(9685),
    [sym_positional_pattern_clause] = STATE(2854),
    [sym_property_pattern_clause] = STATE(2886),
    [sym__variable_designation] = STATE(4162),
    [sym_parenthesized_variable_designation] = STATE(4153),
    [sym__lambda_parameters] = STATE(9890),
    [sym_identifier] = STATE(4163),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(2813),
    [sym_preproc_endregion] = STATE(2813),
    [sym_preproc_line] = STATE(2813),
    [sym_preproc_pragma] = STATE(2813),
    [sym_preproc_nullable] = STATE(2813),
    [sym_preproc_error] = STATE(2813),
    [sym_preproc_warning] = STATE(2813),
    [sym_preproc_define] = STATE(2813),
    [sym_preproc_undef] = STATE(2813),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_SEMI] = ACTIONS(4341),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4341),
    [anon_sym_COLON] = ACTIONS(4341),
    [anon_sym_COMMA] = ACTIONS(4341),
    [anon_sym_RBRACK] = ACTIONS(4341),
    [anon_sym_LPAREN] = ACTIONS(4341),
    [anon_sym_RPAREN] = ACTIONS(4341),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_RBRACE] = ACTIONS(4341),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4345),
    [anon_sym_GT] = ACTIONS(4345),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4345),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4345),
    [anon_sym_PLUS_PLUS] = ACTIONS(4341),
    [anon_sym_DASH_DASH] = ACTIONS(4341),
    [anon_sym_PLUS] = ACTIONS(4345),
    [anon_sym_DASH] = ACTIONS(4345),
    [anon_sym_STAR] = ACTIONS(4341),
    [anon_sym_SLASH] = ACTIONS(4345),
    [anon_sym_PERCENT] = ACTIONS(4341),
    [anon_sym_CARET] = ACTIONS(4341),
    [anon_sym_PIPE] = ACTIONS(4345),
    [anon_sym_AMP] = ACTIONS(4345),
    [anon_sym_LT_LT] = ACTIONS(4341),
    [anon_sym_GT_GT] = ACTIONS(4345),
    [anon_sym_GT_GT_GT] = ACTIONS(4341),
    [anon_sym_EQ_EQ] = ACTIONS(4341),
    [anon_sym_BANG_EQ] = ACTIONS(4341),
    [anon_sym_GT_EQ] = ACTIONS(4341),
    [anon_sym_LT_EQ] = ACTIONS(4341),
    [anon_sym_DOT] = ACTIONS(4345),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4345),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4359),
    [anon_sym_DOT_DOT] = ACTIONS(4341),
    [anon_sym_and] = ACTIONS(4345),
    [anon_sym_or] = ACTIONS(4345),
    [anon_sym_AMP_AMP] = ACTIONS(4341),
    [anon_sym_PIPE_PIPE] = ACTIONS(4341),
    [anon_sym_QMARK_QMARK] = ACTIONS(4341),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4339),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4345),
    [anon_sym_is] = ACTIONS(4345),
    [anon_sym_DASH_GT] = ACTIONS(4341),
    [anon_sym_with] = ACTIONS(4345),
    [aux_sym_preproc_if_token3] = ACTIONS(4341),
    [aux_sym_preproc_else_token1] = ACTIONS(4341),
    [aux_sym_preproc_elif_token1] = ACTIONS(4341),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2814] = {
    [sym_parameter_list] = STATE(9685),
    [sym_positional_pattern_clause] = STATE(2854),
    [sym_property_pattern_clause] = STATE(2886),
    [sym__variable_designation] = STATE(4162),
    [sym_parenthesized_variable_designation] = STATE(4153),
    [sym__lambda_parameters] = STATE(9890),
    [sym_identifier] = STATE(4163),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(2814),
    [sym_preproc_endregion] = STATE(2814),
    [sym_preproc_line] = STATE(2814),
    [sym_preproc_pragma] = STATE(2814),
    [sym_preproc_nullable] = STATE(2814),
    [sym_preproc_error] = STATE(2814),
    [sym_preproc_warning] = STATE(2814),
    [sym_preproc_define] = STATE(2814),
    [sym_preproc_undef] = STATE(2814),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_SEMI] = ACTIONS(4357),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4357),
    [anon_sym_COLON] = ACTIONS(4357),
    [anon_sym_COMMA] = ACTIONS(4357),
    [anon_sym_RBRACK] = ACTIONS(4357),
    [anon_sym_LPAREN] = ACTIONS(4357),
    [anon_sym_RPAREN] = ACTIONS(4357),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_RBRACE] = ACTIONS(4357),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4355),
    [anon_sym_GT] = ACTIONS(4355),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4355),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4355),
    [anon_sym_PLUS_PLUS] = ACTIONS(4357),
    [anon_sym_DASH_DASH] = ACTIONS(4357),
    [anon_sym_PLUS] = ACTIONS(4355),
    [anon_sym_DASH] = ACTIONS(4355),
    [anon_sym_STAR] = ACTIONS(4357),
    [anon_sym_SLASH] = ACTIONS(4355),
    [anon_sym_PERCENT] = ACTIONS(4357),
    [anon_sym_CARET] = ACTIONS(4357),
    [anon_sym_PIPE] = ACTIONS(4355),
    [anon_sym_AMP] = ACTIONS(4355),
    [anon_sym_LT_LT] = ACTIONS(4357),
    [anon_sym_GT_GT] = ACTIONS(4355),
    [anon_sym_GT_GT_GT] = ACTIONS(4357),
    [anon_sym_EQ_EQ] = ACTIONS(4357),
    [anon_sym_BANG_EQ] = ACTIONS(4357),
    [anon_sym_GT_EQ] = ACTIONS(4357),
    [anon_sym_LT_EQ] = ACTIONS(4357),
    [anon_sym_DOT] = ACTIONS(4355),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4355),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4359),
    [anon_sym_DOT_DOT] = ACTIONS(4357),
    [anon_sym_and] = ACTIONS(4355),
    [anon_sym_or] = ACTIONS(4355),
    [anon_sym_AMP_AMP] = ACTIONS(4357),
    [anon_sym_PIPE_PIPE] = ACTIONS(4357),
    [anon_sym_QMARK_QMARK] = ACTIONS(4357),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4339),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4355),
    [anon_sym_is] = ACTIONS(4355),
    [anon_sym_DASH_GT] = ACTIONS(4357),
    [anon_sym_with] = ACTIONS(4355),
    [aux_sym_preproc_if_token3] = ACTIONS(4357),
    [aux_sym_preproc_else_token1] = ACTIONS(4357),
    [aux_sym_preproc_elif_token1] = ACTIONS(4357),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2815] = {
    [sym_attribute_list] = STATE(3740),
    [sym_modifier] = STATE(3807),
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(6959),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9876),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(2815),
    [sym_preproc_endregion] = STATE(2815),
    [sym_preproc_line] = STATE(2815),
    [sym_preproc_pragma] = STATE(2815),
    [sym_preproc_nullable] = STATE(2815),
    [sym_preproc_error] = STATE(2815),
    [sym_preproc_warning] = STATE(2815),
    [sym_preproc_define] = STATE(2815),
    [sym_preproc_undef] = STATE(2815),
    [aux_sym_class_declaration_repeat1] = STATE(3628),
    [aux_sym_class_declaration_repeat2] = STATE(2965),
    [aux_sym_lambda_expression_repeat1] = STATE(4288),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_extern] = ACTIONS(65),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_unsafe] = ACTIONS(65),
    [anon_sym_static] = ACTIONS(39),
    [anon_sym_LBRACK] = ACTIONS(3203),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_class] = ACTIONS(4369),
    [anon_sym_ref] = ACTIONS(4371),
    [anon_sym_struct] = ACTIONS(2821),
    [anon_sym_enum] = ACTIONS(4373),
    [anon_sym_interface] = ACTIONS(4375),
    [anon_sym_delegate] = ACTIONS(4377),
    [anon_sym_record] = ACTIONS(4379),
    [anon_sym_abstract] = ACTIONS(65),
    [anon_sym_async] = ACTIONS(39),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_file] = ACTIONS(3225),
    [anon_sym_fixed] = ACTIONS(65),
    [anon_sym_internal] = ACTIONS(65),
    [anon_sym_new] = ACTIONS(65),
    [anon_sym_override] = ACTIONS(65),
    [anon_sym_partial] = ACTIONS(65),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_public] = ACTIONS(65),
    [anon_sym_readonly] = ACTIONS(65),
    [anon_sym_required] = ACTIONS(65),
    [anon_sym_sealed] = ACTIONS(65),
    [anon_sym_virtual] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2816] = {
    [sym_preproc_region] = STATE(2816),
    [sym_preproc_endregion] = STATE(2816),
    [sym_preproc_line] = STATE(2816),
    [sym_preproc_pragma] = STATE(2816),
    [sym_preproc_nullable] = STATE(2816),
    [sym_preproc_error] = STATE(2816),
    [sym_preproc_warning] = STATE(2816),
    [sym_preproc_define] = STATE(2816),
    [sym_preproc_undef] = STATE(2816),
    [sym__identifier_token] = ACTIONS(3995),
    [anon_sym_alias] = ACTIONS(3995),
    [anon_sym_global] = ACTIONS(3995),
    [anon_sym_EQ] = ACTIONS(3995),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_COLON] = ACTIONS(3993),
    [anon_sym_COMMA] = ACTIONS(3993),
    [anon_sym_LPAREN] = ACTIONS(3993),
    [anon_sym_RPAREN] = ACTIONS(3993),
    [anon_sym_LBRACE] = ACTIONS(3993),
    [anon_sym_RBRACE] = ACTIONS(3993),
    [anon_sym_file] = ACTIONS(3995),
    [anon_sym_LT] = ACTIONS(3995),
    [anon_sym_GT] = ACTIONS(3995),
    [anon_sym_where] = ACTIONS(3995),
    [anon_sym_QMARK] = ACTIONS(3995),
    [anon_sym_notnull] = ACTIONS(3995),
    [anon_sym_unmanaged] = ACTIONS(3995),
    [anon_sym_BANG] = ACTIONS(3995),
    [anon_sym_PLUS_PLUS] = ACTIONS(3993),
    [anon_sym_DASH_DASH] = ACTIONS(3993),
    [anon_sym_PLUS] = ACTIONS(3995),
    [anon_sym_DASH] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3995),
    [anon_sym_SLASH] = ACTIONS(3995),
    [anon_sym_PERCENT] = ACTIONS(3995),
    [anon_sym_CARET] = ACTIONS(3995),
    [anon_sym_PIPE] = ACTIONS(3995),
    [anon_sym_AMP] = ACTIONS(3995),
    [anon_sym_LT_LT] = ACTIONS(3995),
    [anon_sym_GT_GT] = ACTIONS(3995),
    [anon_sym_GT_GT_GT] = ACTIONS(3995),
    [anon_sym_EQ_EQ] = ACTIONS(3993),
    [anon_sym_BANG_EQ] = ACTIONS(3993),
    [anon_sym_GT_EQ] = ACTIONS(3993),
    [anon_sym_LT_EQ] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3995),
    [anon_sym_scoped] = ACTIONS(3995),
    [anon_sym_var] = ACTIONS(3995),
    [anon_sym_yield] = ACTIONS(3995),
    [anon_sym_switch] = ACTIONS(3995),
    [anon_sym_when] = ACTIONS(3995),
    [sym_discard] = ACTIONS(3995),
    [anon_sym_DOT_DOT] = ACTIONS(3993),
    [anon_sym_and] = ACTIONS(3995),
    [anon_sym_or] = ACTIONS(3995),
    [anon_sym_PLUS_EQ] = ACTIONS(3993),
    [anon_sym_DASH_EQ] = ACTIONS(3993),
    [anon_sym_STAR_EQ] = ACTIONS(3993),
    [anon_sym_SLASH_EQ] = ACTIONS(3993),
    [anon_sym_PERCENT_EQ] = ACTIONS(3993),
    [anon_sym_AMP_EQ] = ACTIONS(3993),
    [anon_sym_CARET_EQ] = ACTIONS(3993),
    [anon_sym_PIPE_EQ] = ACTIONS(3993),
    [anon_sym_LT_LT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(3993),
    [anon_sym_AMP_AMP] = ACTIONS(3993),
    [anon_sym_PIPE_PIPE] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK] = ACTIONS(3995),
    [anon_sym_from] = ACTIONS(3995),
    [anon_sym_into] = ACTIONS(3995),
    [anon_sym_join] = ACTIONS(3995),
    [anon_sym_on] = ACTIONS(3995),
    [anon_sym_equals] = ACTIONS(3995),
    [anon_sym_let] = ACTIONS(3995),
    [anon_sym_orderby] = ACTIONS(3995),
    [anon_sym_ascending] = ACTIONS(3995),
    [anon_sym_descending] = ACTIONS(3995),
    [anon_sym_group] = ACTIONS(3995),
    [anon_sym_by] = ACTIONS(3995),
    [anon_sym_select] = ACTIONS(3995),
    [anon_sym_as] = ACTIONS(3995),
    [anon_sym_is] = ACTIONS(3995),
    [anon_sym_DASH_GT] = ACTIONS(3993),
    [anon_sym_with] = ACTIONS(3995),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2817] = {
    [sym_attribute_list] = STATE(3740),
    [sym_modifier] = STATE(3807),
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7119),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9876),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(2817),
    [sym_preproc_endregion] = STATE(2817),
    [sym_preproc_line] = STATE(2817),
    [sym_preproc_pragma] = STATE(2817),
    [sym_preproc_nullable] = STATE(2817),
    [sym_preproc_error] = STATE(2817),
    [sym_preproc_warning] = STATE(2817),
    [sym_preproc_define] = STATE(2817),
    [sym_preproc_undef] = STATE(2817),
    [aux_sym_class_declaration_repeat1] = STATE(3628),
    [aux_sym_class_declaration_repeat2] = STATE(2958),
    [aux_sym_lambda_expression_repeat1] = STATE(4288),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_extern] = ACTIONS(65),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_unsafe] = ACTIONS(65),
    [anon_sym_static] = ACTIONS(39),
    [anon_sym_LBRACK] = ACTIONS(3203),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_class] = ACTIONS(4381),
    [anon_sym_ref] = ACTIONS(4383),
    [anon_sym_struct] = ACTIONS(2823),
    [anon_sym_enum] = ACTIONS(4385),
    [anon_sym_interface] = ACTIONS(4387),
    [anon_sym_delegate] = ACTIONS(4389),
    [anon_sym_record] = ACTIONS(4391),
    [anon_sym_abstract] = ACTIONS(65),
    [anon_sym_async] = ACTIONS(39),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_file] = ACTIONS(3225),
    [anon_sym_fixed] = ACTIONS(65),
    [anon_sym_internal] = ACTIONS(65),
    [anon_sym_new] = ACTIONS(65),
    [anon_sym_override] = ACTIONS(65),
    [anon_sym_partial] = ACTIONS(65),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_public] = ACTIONS(65),
    [anon_sym_readonly] = ACTIONS(65),
    [anon_sym_required] = ACTIONS(65),
    [anon_sym_sealed] = ACTIONS(65),
    [anon_sym_virtual] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2818] = {
    [sym_preproc_region] = STATE(2818),
    [sym_preproc_endregion] = STATE(2818),
    [sym_preproc_line] = STATE(2818),
    [sym_preproc_pragma] = STATE(2818),
    [sym_preproc_nullable] = STATE(2818),
    [sym_preproc_error] = STATE(2818),
    [sym_preproc_warning] = STATE(2818),
    [sym_preproc_define] = STATE(2818),
    [sym_preproc_undef] = STATE(2818),
    [sym__identifier_token] = ACTIONS(4126),
    [anon_sym_alias] = ACTIONS(4126),
    [anon_sym_global] = ACTIONS(4126),
    [anon_sym_EQ] = ACTIONS(4126),
    [anon_sym_LBRACK] = ACTIONS(4128),
    [anon_sym_COLON] = ACTIONS(4128),
    [anon_sym_COMMA] = ACTIONS(4128),
    [anon_sym_LPAREN] = ACTIONS(4128),
    [anon_sym_LBRACE] = ACTIONS(4128),
    [anon_sym_file] = ACTIONS(4126),
    [anon_sym_LT] = ACTIONS(4126),
    [anon_sym_GT] = ACTIONS(4126),
    [anon_sym_where] = ACTIONS(4126),
    [anon_sym_QMARK] = ACTIONS(4126),
    [anon_sym_notnull] = ACTIONS(4126),
    [anon_sym_unmanaged] = ACTIONS(4126),
    [anon_sym_BANG] = ACTIONS(4126),
    [anon_sym_PLUS_PLUS] = ACTIONS(4128),
    [anon_sym_DASH_DASH] = ACTIONS(4128),
    [anon_sym_PLUS] = ACTIONS(4126),
    [anon_sym_DASH] = ACTIONS(4126),
    [anon_sym_STAR] = ACTIONS(4126),
    [anon_sym_SLASH] = ACTIONS(4126),
    [anon_sym_PERCENT] = ACTIONS(4126),
    [anon_sym_CARET] = ACTIONS(4126),
    [anon_sym_PIPE] = ACTIONS(4126),
    [anon_sym_AMP] = ACTIONS(4126),
    [anon_sym_LT_LT] = ACTIONS(4126),
    [anon_sym_GT_GT] = ACTIONS(4126),
    [anon_sym_GT_GT_GT] = ACTIONS(4126),
    [anon_sym_EQ_EQ] = ACTIONS(4128),
    [anon_sym_BANG_EQ] = ACTIONS(4128),
    [anon_sym_GT_EQ] = ACTIONS(4128),
    [anon_sym_LT_EQ] = ACTIONS(4128),
    [anon_sym_DOT] = ACTIONS(4126),
    [anon_sym_scoped] = ACTIONS(4126),
    [anon_sym_var] = ACTIONS(4126),
    [anon_sym_yield] = ACTIONS(4126),
    [anon_sym_switch] = ACTIONS(4126),
    [anon_sym_when] = ACTIONS(4126),
    [sym_discard] = ACTIONS(4126),
    [anon_sym_DOT_DOT] = ACTIONS(4128),
    [anon_sym_and] = ACTIONS(4126),
    [anon_sym_or] = ACTIONS(4126),
    [anon_sym_PLUS_EQ] = ACTIONS(4128),
    [anon_sym_DASH_EQ] = ACTIONS(4128),
    [anon_sym_STAR_EQ] = ACTIONS(4128),
    [anon_sym_SLASH_EQ] = ACTIONS(4128),
    [anon_sym_PERCENT_EQ] = ACTIONS(4128),
    [anon_sym_AMP_EQ] = ACTIONS(4128),
    [anon_sym_CARET_EQ] = ACTIONS(4128),
    [anon_sym_PIPE_EQ] = ACTIONS(4128),
    [anon_sym_LT_LT_EQ] = ACTIONS(4128),
    [anon_sym_GT_GT_EQ] = ACTIONS(4128),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4128),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4128),
    [anon_sym_AMP_AMP] = ACTIONS(4128),
    [anon_sym_PIPE_PIPE] = ACTIONS(4128),
    [anon_sym_QMARK_QMARK] = ACTIONS(4126),
    [anon_sym_from] = ACTIONS(4126),
    [anon_sym_into] = ACTIONS(4126),
    [anon_sym_join] = ACTIONS(4126),
    [anon_sym_on] = ACTIONS(4126),
    [anon_sym_equals] = ACTIONS(4126),
    [anon_sym_let] = ACTIONS(4126),
    [anon_sym_orderby] = ACTIONS(4126),
    [anon_sym_ascending] = ACTIONS(4126),
    [anon_sym_descending] = ACTIONS(4126),
    [anon_sym_group] = ACTIONS(4126),
    [anon_sym_by] = ACTIONS(4126),
    [anon_sym_select] = ACTIONS(4126),
    [anon_sym_as] = ACTIONS(4126),
    [anon_sym_is] = ACTIONS(4126),
    [anon_sym_DASH_GT] = ACTIONS(4128),
    [anon_sym_with] = ACTIONS(4126),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4128),
  },
  [2819] = {
    [sym_preproc_region] = STATE(2819),
    [sym_preproc_endregion] = STATE(2819),
    [sym_preproc_line] = STATE(2819),
    [sym_preproc_pragma] = STATE(2819),
    [sym_preproc_nullable] = STATE(2819),
    [sym_preproc_error] = STATE(2819),
    [sym_preproc_warning] = STATE(2819),
    [sym_preproc_define] = STATE(2819),
    [sym_preproc_undef] = STATE(2819),
    [sym__identifier_token] = ACTIONS(4179),
    [anon_sym_alias] = ACTIONS(4179),
    [anon_sym_global] = ACTIONS(4179),
    [anon_sym_EQ] = ACTIONS(4183),
    [anon_sym_LBRACK] = ACTIONS(4185),
    [anon_sym_COLON] = ACTIONS(4191),
    [anon_sym_COMMA] = ACTIONS(4185),
    [anon_sym_LPAREN] = ACTIONS(4185),
    [anon_sym_RPAREN] = ACTIONS(4185),
    [anon_sym_LBRACE] = ACTIONS(4181),
    [anon_sym_file] = ACTIONS(4179),
    [anon_sym_LT] = ACTIONS(4183),
    [anon_sym_GT] = ACTIONS(4183),
    [anon_sym_where] = ACTIONS(4179),
    [anon_sym_QMARK] = ACTIONS(4188),
    [anon_sym_notnull] = ACTIONS(4179),
    [anon_sym_unmanaged] = ACTIONS(4179),
    [anon_sym_BANG] = ACTIONS(4183),
    [anon_sym_PLUS_PLUS] = ACTIONS(4191),
    [anon_sym_DASH_DASH] = ACTIONS(4191),
    [anon_sym_PLUS] = ACTIONS(4183),
    [anon_sym_DASH] = ACTIONS(4183),
    [anon_sym_STAR] = ACTIONS(4188),
    [anon_sym_SLASH] = ACTIONS(4183),
    [anon_sym_PERCENT] = ACTIONS(4183),
    [anon_sym_CARET] = ACTIONS(4183),
    [anon_sym_PIPE] = ACTIONS(4183),
    [anon_sym_AMP] = ACTIONS(4183),
    [anon_sym_LT_LT] = ACTIONS(4183),
    [anon_sym_GT_GT] = ACTIONS(4183),
    [anon_sym_GT_GT_GT] = ACTIONS(4183),
    [anon_sym_EQ_EQ] = ACTIONS(4191),
    [anon_sym_BANG_EQ] = ACTIONS(4191),
    [anon_sym_GT_EQ] = ACTIONS(4191),
    [anon_sym_LT_EQ] = ACTIONS(4191),
    [anon_sym_DOT] = ACTIONS(4188),
    [anon_sym_scoped] = ACTIONS(4179),
    [anon_sym_var] = ACTIONS(4179),
    [anon_sym_yield] = ACTIONS(4179),
    [anon_sym_switch] = ACTIONS(4183),
    [anon_sym_when] = ACTIONS(4179),
    [sym_discard] = ACTIONS(4179),
    [anon_sym_DOT_DOT] = ACTIONS(4191),
    [anon_sym_and] = ACTIONS(4179),
    [anon_sym_or] = ACTIONS(4179),
    [anon_sym_PLUS_EQ] = ACTIONS(4191),
    [anon_sym_DASH_EQ] = ACTIONS(4191),
    [anon_sym_STAR_EQ] = ACTIONS(4191),
    [anon_sym_SLASH_EQ] = ACTIONS(4191),
    [anon_sym_PERCENT_EQ] = ACTIONS(4191),
    [anon_sym_AMP_EQ] = ACTIONS(4191),
    [anon_sym_CARET_EQ] = ACTIONS(4191),
    [anon_sym_PIPE_EQ] = ACTIONS(4191),
    [anon_sym_LT_LT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4191),
    [anon_sym_AMP_AMP] = ACTIONS(4191),
    [anon_sym_PIPE_PIPE] = ACTIONS(4191),
    [anon_sym_QMARK_QMARK] = ACTIONS(4183),
    [anon_sym_from] = ACTIONS(4179),
    [anon_sym_into] = ACTIONS(4179),
    [anon_sym_join] = ACTIONS(4179),
    [anon_sym_on] = ACTIONS(4179),
    [anon_sym_equals] = ACTIONS(4179),
    [anon_sym_let] = ACTIONS(4179),
    [anon_sym_orderby] = ACTIONS(4179),
    [anon_sym_ascending] = ACTIONS(4179),
    [anon_sym_descending] = ACTIONS(4179),
    [anon_sym_group] = ACTIONS(4179),
    [anon_sym_by] = ACTIONS(4179),
    [anon_sym_select] = ACTIONS(4179),
    [anon_sym_as] = ACTIONS(4183),
    [anon_sym_is] = ACTIONS(4183),
    [anon_sym_DASH_GT] = ACTIONS(4185),
    [anon_sym_with] = ACTIONS(4183),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2820] = {
    [sym_preproc_region] = STATE(2820),
    [sym_preproc_endregion] = STATE(2820),
    [sym_preproc_line] = STATE(2820),
    [sym_preproc_pragma] = STATE(2820),
    [sym_preproc_nullable] = STATE(2820),
    [sym_preproc_error] = STATE(2820),
    [sym_preproc_warning] = STATE(2820),
    [sym_preproc_define] = STATE(2820),
    [sym_preproc_undef] = STATE(2820),
    [sym__identifier_token] = ACTIONS(3995),
    [anon_sym_alias] = ACTIONS(3995),
    [anon_sym_global] = ACTIONS(3995),
    [anon_sym_EQ] = ACTIONS(3995),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_COLON] = ACTIONS(3993),
    [anon_sym_COMMA] = ACTIONS(3993),
    [anon_sym_LPAREN] = ACTIONS(3993),
    [anon_sym_LBRACE] = ACTIONS(3993),
    [anon_sym_file] = ACTIONS(3995),
    [anon_sym_LT] = ACTIONS(3995),
    [anon_sym_GT] = ACTIONS(3995),
    [anon_sym_where] = ACTIONS(3995),
    [anon_sym_QMARK] = ACTIONS(3995),
    [anon_sym_notnull] = ACTIONS(3995),
    [anon_sym_unmanaged] = ACTIONS(3995),
    [anon_sym_BANG] = ACTIONS(3995),
    [anon_sym_PLUS_PLUS] = ACTIONS(3993),
    [anon_sym_DASH_DASH] = ACTIONS(3993),
    [anon_sym_PLUS] = ACTIONS(3995),
    [anon_sym_DASH] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3995),
    [anon_sym_SLASH] = ACTIONS(3995),
    [anon_sym_PERCENT] = ACTIONS(3995),
    [anon_sym_CARET] = ACTIONS(3995),
    [anon_sym_PIPE] = ACTIONS(3995),
    [anon_sym_AMP] = ACTIONS(3995),
    [anon_sym_LT_LT] = ACTIONS(3995),
    [anon_sym_GT_GT] = ACTIONS(3995),
    [anon_sym_GT_GT_GT] = ACTIONS(3995),
    [anon_sym_EQ_EQ] = ACTIONS(3993),
    [anon_sym_BANG_EQ] = ACTIONS(3993),
    [anon_sym_GT_EQ] = ACTIONS(3993),
    [anon_sym_LT_EQ] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3995),
    [anon_sym_scoped] = ACTIONS(3995),
    [anon_sym_var] = ACTIONS(3995),
    [anon_sym_yield] = ACTIONS(3995),
    [anon_sym_switch] = ACTIONS(3995),
    [anon_sym_when] = ACTIONS(3995),
    [sym_discard] = ACTIONS(3995),
    [anon_sym_DOT_DOT] = ACTIONS(3993),
    [anon_sym_and] = ACTIONS(3995),
    [anon_sym_or] = ACTIONS(3995),
    [anon_sym_PLUS_EQ] = ACTIONS(3993),
    [anon_sym_DASH_EQ] = ACTIONS(3993),
    [anon_sym_STAR_EQ] = ACTIONS(3993),
    [anon_sym_SLASH_EQ] = ACTIONS(3993),
    [anon_sym_PERCENT_EQ] = ACTIONS(3993),
    [anon_sym_AMP_EQ] = ACTIONS(3993),
    [anon_sym_CARET_EQ] = ACTIONS(3993),
    [anon_sym_PIPE_EQ] = ACTIONS(3993),
    [anon_sym_LT_LT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(3993),
    [anon_sym_AMP_AMP] = ACTIONS(3993),
    [anon_sym_PIPE_PIPE] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK] = ACTIONS(3995),
    [anon_sym_from] = ACTIONS(3995),
    [anon_sym_into] = ACTIONS(3995),
    [anon_sym_join] = ACTIONS(3995),
    [anon_sym_on] = ACTIONS(3995),
    [anon_sym_equals] = ACTIONS(3995),
    [anon_sym_let] = ACTIONS(3995),
    [anon_sym_orderby] = ACTIONS(3995),
    [anon_sym_ascending] = ACTIONS(3995),
    [anon_sym_descending] = ACTIONS(3995),
    [anon_sym_group] = ACTIONS(3995),
    [anon_sym_by] = ACTIONS(3995),
    [anon_sym_select] = ACTIONS(3995),
    [anon_sym_as] = ACTIONS(3995),
    [anon_sym_is] = ACTIONS(3995),
    [anon_sym_DASH_GT] = ACTIONS(3993),
    [anon_sym_with] = ACTIONS(3995),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(3993),
  },
  [2821] = {
    [sym_preproc_region] = STATE(2821),
    [sym_preproc_endregion] = STATE(2821),
    [sym_preproc_line] = STATE(2821),
    [sym_preproc_pragma] = STATE(2821),
    [sym_preproc_nullable] = STATE(2821),
    [sym_preproc_error] = STATE(2821),
    [sym_preproc_warning] = STATE(2821),
    [sym_preproc_define] = STATE(2821),
    [sym_preproc_undef] = STATE(2821),
    [sym__identifier_token] = ACTIONS(4130),
    [anon_sym_alias] = ACTIONS(4130),
    [anon_sym_global] = ACTIONS(4130),
    [anon_sym_EQ] = ACTIONS(4130),
    [anon_sym_LBRACK] = ACTIONS(4132),
    [anon_sym_COLON] = ACTIONS(4132),
    [anon_sym_COMMA] = ACTIONS(4132),
    [anon_sym_LPAREN] = ACTIONS(4132),
    [anon_sym_LBRACE] = ACTIONS(4132),
    [anon_sym_file] = ACTIONS(4130),
    [anon_sym_LT] = ACTIONS(4130),
    [anon_sym_GT] = ACTIONS(4130),
    [anon_sym_where] = ACTIONS(4130),
    [anon_sym_QMARK] = ACTIONS(4130),
    [anon_sym_notnull] = ACTIONS(4130),
    [anon_sym_unmanaged] = ACTIONS(4130),
    [anon_sym_BANG] = ACTIONS(4130),
    [anon_sym_PLUS_PLUS] = ACTIONS(4132),
    [anon_sym_DASH_DASH] = ACTIONS(4132),
    [anon_sym_PLUS] = ACTIONS(4130),
    [anon_sym_DASH] = ACTIONS(4130),
    [anon_sym_STAR] = ACTIONS(4130),
    [anon_sym_SLASH] = ACTIONS(4130),
    [anon_sym_PERCENT] = ACTIONS(4130),
    [anon_sym_CARET] = ACTIONS(4130),
    [anon_sym_PIPE] = ACTIONS(4130),
    [anon_sym_AMP] = ACTIONS(4130),
    [anon_sym_LT_LT] = ACTIONS(4130),
    [anon_sym_GT_GT] = ACTIONS(4130),
    [anon_sym_GT_GT_GT] = ACTIONS(4130),
    [anon_sym_EQ_EQ] = ACTIONS(4132),
    [anon_sym_BANG_EQ] = ACTIONS(4132),
    [anon_sym_GT_EQ] = ACTIONS(4132),
    [anon_sym_LT_EQ] = ACTIONS(4132),
    [anon_sym_DOT] = ACTIONS(4130),
    [anon_sym_scoped] = ACTIONS(4130),
    [anon_sym_var] = ACTIONS(4130),
    [anon_sym_yield] = ACTIONS(4130),
    [anon_sym_switch] = ACTIONS(4130),
    [anon_sym_when] = ACTIONS(4130),
    [sym_discard] = ACTIONS(4130),
    [anon_sym_DOT_DOT] = ACTIONS(4132),
    [anon_sym_and] = ACTIONS(4130),
    [anon_sym_or] = ACTIONS(4130),
    [anon_sym_PLUS_EQ] = ACTIONS(4132),
    [anon_sym_DASH_EQ] = ACTIONS(4132),
    [anon_sym_STAR_EQ] = ACTIONS(4132),
    [anon_sym_SLASH_EQ] = ACTIONS(4132),
    [anon_sym_PERCENT_EQ] = ACTIONS(4132),
    [anon_sym_AMP_EQ] = ACTIONS(4132),
    [anon_sym_CARET_EQ] = ACTIONS(4132),
    [anon_sym_PIPE_EQ] = ACTIONS(4132),
    [anon_sym_LT_LT_EQ] = ACTIONS(4132),
    [anon_sym_GT_GT_EQ] = ACTIONS(4132),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4132),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4132),
    [anon_sym_AMP_AMP] = ACTIONS(4132),
    [anon_sym_PIPE_PIPE] = ACTIONS(4132),
    [anon_sym_QMARK_QMARK] = ACTIONS(4130),
    [anon_sym_from] = ACTIONS(4130),
    [anon_sym_into] = ACTIONS(4130),
    [anon_sym_join] = ACTIONS(4130),
    [anon_sym_on] = ACTIONS(4130),
    [anon_sym_equals] = ACTIONS(4130),
    [anon_sym_let] = ACTIONS(4130),
    [anon_sym_orderby] = ACTIONS(4130),
    [anon_sym_ascending] = ACTIONS(4130),
    [anon_sym_descending] = ACTIONS(4130),
    [anon_sym_group] = ACTIONS(4130),
    [anon_sym_by] = ACTIONS(4130),
    [anon_sym_select] = ACTIONS(4130),
    [anon_sym_as] = ACTIONS(4130),
    [anon_sym_is] = ACTIONS(4130),
    [anon_sym_DASH_GT] = ACTIONS(4132),
    [anon_sym_with] = ACTIONS(4130),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4132),
  },
  [2822] = {
    [sym_preproc_region] = STATE(2822),
    [sym_preproc_endregion] = STATE(2822),
    [sym_preproc_line] = STATE(2822),
    [sym_preproc_pragma] = STATE(2822),
    [sym_preproc_nullable] = STATE(2822),
    [sym_preproc_error] = STATE(2822),
    [sym_preproc_warning] = STATE(2822),
    [sym_preproc_define] = STATE(2822),
    [sym_preproc_undef] = STATE(2822),
    [sym__identifier_token] = ACTIONS(4138),
    [anon_sym_alias] = ACTIONS(4138),
    [anon_sym_global] = ACTIONS(4138),
    [anon_sym_EQ] = ACTIONS(4138),
    [anon_sym_LBRACK] = ACTIONS(4140),
    [anon_sym_COLON] = ACTIONS(4140),
    [anon_sym_COMMA] = ACTIONS(4140),
    [anon_sym_LPAREN] = ACTIONS(4140),
    [anon_sym_LBRACE] = ACTIONS(4140),
    [anon_sym_file] = ACTIONS(4138),
    [anon_sym_LT] = ACTIONS(4138),
    [anon_sym_GT] = ACTIONS(4138),
    [anon_sym_where] = ACTIONS(4138),
    [anon_sym_QMARK] = ACTIONS(4138),
    [anon_sym_notnull] = ACTIONS(4138),
    [anon_sym_unmanaged] = ACTIONS(4138),
    [anon_sym_BANG] = ACTIONS(4138),
    [anon_sym_PLUS_PLUS] = ACTIONS(4140),
    [anon_sym_DASH_DASH] = ACTIONS(4140),
    [anon_sym_PLUS] = ACTIONS(4138),
    [anon_sym_DASH] = ACTIONS(4138),
    [anon_sym_STAR] = ACTIONS(4138),
    [anon_sym_SLASH] = ACTIONS(4138),
    [anon_sym_PERCENT] = ACTIONS(4138),
    [anon_sym_CARET] = ACTIONS(4138),
    [anon_sym_PIPE] = ACTIONS(4138),
    [anon_sym_AMP] = ACTIONS(4138),
    [anon_sym_LT_LT] = ACTIONS(4138),
    [anon_sym_GT_GT] = ACTIONS(4138),
    [anon_sym_GT_GT_GT] = ACTIONS(4138),
    [anon_sym_EQ_EQ] = ACTIONS(4140),
    [anon_sym_BANG_EQ] = ACTIONS(4140),
    [anon_sym_GT_EQ] = ACTIONS(4140),
    [anon_sym_LT_EQ] = ACTIONS(4140),
    [anon_sym_DOT] = ACTIONS(4138),
    [anon_sym_scoped] = ACTIONS(4138),
    [anon_sym_var] = ACTIONS(4138),
    [anon_sym_yield] = ACTIONS(4138),
    [anon_sym_switch] = ACTIONS(4138),
    [anon_sym_when] = ACTIONS(4138),
    [sym_discard] = ACTIONS(4138),
    [anon_sym_DOT_DOT] = ACTIONS(4140),
    [anon_sym_and] = ACTIONS(4138),
    [anon_sym_or] = ACTIONS(4138),
    [anon_sym_PLUS_EQ] = ACTIONS(4140),
    [anon_sym_DASH_EQ] = ACTIONS(4140),
    [anon_sym_STAR_EQ] = ACTIONS(4140),
    [anon_sym_SLASH_EQ] = ACTIONS(4140),
    [anon_sym_PERCENT_EQ] = ACTIONS(4140),
    [anon_sym_AMP_EQ] = ACTIONS(4140),
    [anon_sym_CARET_EQ] = ACTIONS(4140),
    [anon_sym_PIPE_EQ] = ACTIONS(4140),
    [anon_sym_LT_LT_EQ] = ACTIONS(4140),
    [anon_sym_GT_GT_EQ] = ACTIONS(4140),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4140),
    [anon_sym_AMP_AMP] = ACTIONS(4140),
    [anon_sym_PIPE_PIPE] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK] = ACTIONS(4138),
    [anon_sym_from] = ACTIONS(4138),
    [anon_sym_into] = ACTIONS(4138),
    [anon_sym_join] = ACTIONS(4138),
    [anon_sym_on] = ACTIONS(4138),
    [anon_sym_equals] = ACTIONS(4138),
    [anon_sym_let] = ACTIONS(4138),
    [anon_sym_orderby] = ACTIONS(4138),
    [anon_sym_ascending] = ACTIONS(4138),
    [anon_sym_descending] = ACTIONS(4138),
    [anon_sym_group] = ACTIONS(4138),
    [anon_sym_by] = ACTIONS(4138),
    [anon_sym_select] = ACTIONS(4138),
    [anon_sym_as] = ACTIONS(4138),
    [anon_sym_is] = ACTIONS(4138),
    [anon_sym_DASH_GT] = ACTIONS(4140),
    [anon_sym_with] = ACTIONS(4138),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4140),
  },
  [2823] = {
    [sym_type_argument_list] = STATE(2746),
    [sym_preproc_region] = STATE(2823),
    [sym_preproc_endregion] = STATE(2823),
    [sym_preproc_line] = STATE(2823),
    [sym_preproc_pragma] = STATE(2823),
    [sym_preproc_nullable] = STATE(2823),
    [sym_preproc_error] = STATE(2823),
    [sym_preproc_warning] = STATE(2823),
    [sym_preproc_define] = STATE(2823),
    [sym_preproc_undef] = STATE(2823),
    [sym__identifier_token] = ACTIONS(4138),
    [anon_sym_alias] = ACTIONS(4138),
    [anon_sym_global] = ACTIONS(4138),
    [anon_sym_EQ] = ACTIONS(4138),
    [anon_sym_LBRACK] = ACTIONS(4140),
    [anon_sym_LPAREN] = ACTIONS(4140),
    [anon_sym_LBRACE] = ACTIONS(4140),
    [anon_sym_file] = ACTIONS(4138),
    [anon_sym_LT] = ACTIONS(4142),
    [anon_sym_GT] = ACTIONS(4138),
    [anon_sym_where] = ACTIONS(4138),
    [anon_sym_QMARK] = ACTIONS(4138),
    [anon_sym_notnull] = ACTIONS(4138),
    [anon_sym_unmanaged] = ACTIONS(4138),
    [anon_sym_BANG] = ACTIONS(4138),
    [anon_sym_PLUS_PLUS] = ACTIONS(4140),
    [anon_sym_DASH_DASH] = ACTIONS(4140),
    [anon_sym_PLUS] = ACTIONS(4138),
    [anon_sym_DASH] = ACTIONS(4138),
    [anon_sym_STAR] = ACTIONS(4138),
    [anon_sym_SLASH] = ACTIONS(4138),
    [anon_sym_PERCENT] = ACTIONS(4138),
    [anon_sym_CARET] = ACTIONS(4138),
    [anon_sym_PIPE] = ACTIONS(4138),
    [anon_sym_AMP] = ACTIONS(4138),
    [anon_sym_LT_LT] = ACTIONS(4138),
    [anon_sym_GT_GT] = ACTIONS(4138),
    [anon_sym_GT_GT_GT] = ACTIONS(4138),
    [anon_sym_EQ_EQ] = ACTIONS(4140),
    [anon_sym_BANG_EQ] = ACTIONS(4140),
    [anon_sym_GT_EQ] = ACTIONS(4140),
    [anon_sym_LT_EQ] = ACTIONS(4140),
    [anon_sym_DOT] = ACTIONS(4138),
    [anon_sym_scoped] = ACTIONS(4138),
    [anon_sym_EQ_GT] = ACTIONS(4140),
    [anon_sym_COLON_COLON] = ACTIONS(4147),
    [anon_sym_var] = ACTIONS(4138),
    [anon_sym_yield] = ACTIONS(4138),
    [anon_sym_switch] = ACTIONS(4138),
    [anon_sym_when] = ACTIONS(4138),
    [sym_discard] = ACTIONS(4138),
    [anon_sym_DOT_DOT] = ACTIONS(4140),
    [anon_sym_and] = ACTIONS(4138),
    [anon_sym_or] = ACTIONS(4138),
    [anon_sym_PLUS_EQ] = ACTIONS(4140),
    [anon_sym_DASH_EQ] = ACTIONS(4140),
    [anon_sym_STAR_EQ] = ACTIONS(4140),
    [anon_sym_SLASH_EQ] = ACTIONS(4140),
    [anon_sym_PERCENT_EQ] = ACTIONS(4140),
    [anon_sym_AMP_EQ] = ACTIONS(4140),
    [anon_sym_CARET_EQ] = ACTIONS(4140),
    [anon_sym_PIPE_EQ] = ACTIONS(4140),
    [anon_sym_LT_LT_EQ] = ACTIONS(4140),
    [anon_sym_GT_GT_EQ] = ACTIONS(4140),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4140),
    [anon_sym_AMP_AMP] = ACTIONS(4140),
    [anon_sym_PIPE_PIPE] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK] = ACTIONS(4138),
    [anon_sym_from] = ACTIONS(4138),
    [anon_sym_into] = ACTIONS(4138),
    [anon_sym_join] = ACTIONS(4138),
    [anon_sym_on] = ACTIONS(4138),
    [anon_sym_equals] = ACTIONS(4138),
    [anon_sym_let] = ACTIONS(4138),
    [anon_sym_orderby] = ACTIONS(4138),
    [anon_sym_ascending] = ACTIONS(4138),
    [anon_sym_descending] = ACTIONS(4138),
    [anon_sym_group] = ACTIONS(4138),
    [anon_sym_by] = ACTIONS(4138),
    [anon_sym_select] = ACTIONS(4138),
    [anon_sym_as] = ACTIONS(4138),
    [anon_sym_is] = ACTIONS(4138),
    [anon_sym_DASH_GT] = ACTIONS(4140),
    [anon_sym_with] = ACTIONS(4138),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2824] = {
    [sym_preproc_region] = STATE(2824),
    [sym_preproc_endregion] = STATE(2824),
    [sym_preproc_line] = STATE(2824),
    [sym_preproc_pragma] = STATE(2824),
    [sym_preproc_nullable] = STATE(2824),
    [sym_preproc_error] = STATE(2824),
    [sym_preproc_warning] = STATE(2824),
    [sym_preproc_define] = STATE(2824),
    [sym_preproc_undef] = STATE(2824),
    [sym__identifier_token] = ACTIONS(4091),
    [anon_sym_alias] = ACTIONS(4091),
    [anon_sym_global] = ACTIONS(4091),
    [anon_sym_EQ] = ACTIONS(3995),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_COLON] = ACTIONS(3995),
    [anon_sym_COMMA] = ACTIONS(3993),
    [anon_sym_LPAREN] = ACTIONS(4088),
    [anon_sym_file] = ACTIONS(4091),
    [anon_sym_LT] = ACTIONS(3995),
    [anon_sym_GT] = ACTIONS(3995),
    [anon_sym_where] = ACTIONS(4091),
    [anon_sym_QMARK] = ACTIONS(3995),
    [anon_sym_notnull] = ACTIONS(4091),
    [anon_sym_unmanaged] = ACTIONS(4091),
    [anon_sym_BANG] = ACTIONS(3995),
    [anon_sym_PLUS_PLUS] = ACTIONS(3993),
    [anon_sym_DASH_DASH] = ACTIONS(3993),
    [anon_sym_PLUS] = ACTIONS(3995),
    [anon_sym_DASH] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3995),
    [anon_sym_SLASH] = ACTIONS(3995),
    [anon_sym_PERCENT] = ACTIONS(3995),
    [anon_sym_CARET] = ACTIONS(3995),
    [anon_sym_PIPE] = ACTIONS(3995),
    [anon_sym_AMP] = ACTIONS(3995),
    [anon_sym_LT_LT] = ACTIONS(3995),
    [anon_sym_GT_GT] = ACTIONS(3995),
    [anon_sym_GT_GT_GT] = ACTIONS(3995),
    [anon_sym_EQ_EQ] = ACTIONS(3993),
    [anon_sym_BANG_EQ] = ACTIONS(3993),
    [anon_sym_GT_EQ] = ACTIONS(3993),
    [anon_sym_LT_EQ] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3995),
    [anon_sym_scoped] = ACTIONS(4091),
    [anon_sym_EQ_GT] = ACTIONS(3993),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(4091),
    [anon_sym_yield] = ACTIONS(4091),
    [anon_sym_switch] = ACTIONS(3995),
    [anon_sym_when] = ACTIONS(4091),
    [anon_sym_DOT_DOT] = ACTIONS(3993),
    [anon_sym_and] = ACTIONS(3995),
    [anon_sym_or] = ACTIONS(3995),
    [anon_sym_PLUS_EQ] = ACTIONS(3993),
    [anon_sym_DASH_EQ] = ACTIONS(3993),
    [anon_sym_STAR_EQ] = ACTIONS(3993),
    [anon_sym_SLASH_EQ] = ACTIONS(3993),
    [anon_sym_PERCENT_EQ] = ACTIONS(3993),
    [anon_sym_AMP_EQ] = ACTIONS(3993),
    [anon_sym_CARET_EQ] = ACTIONS(3993),
    [anon_sym_PIPE_EQ] = ACTIONS(3993),
    [anon_sym_LT_LT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(3993),
    [anon_sym_AMP_AMP] = ACTIONS(3993),
    [anon_sym_PIPE_PIPE] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK] = ACTIONS(3995),
    [anon_sym_from] = ACTIONS(4091),
    [anon_sym_into] = ACTIONS(4091),
    [anon_sym_join] = ACTIONS(4091),
    [anon_sym_on] = ACTIONS(4091),
    [anon_sym_equals] = ACTIONS(4091),
    [anon_sym_let] = ACTIONS(4091),
    [anon_sym_orderby] = ACTIONS(4091),
    [anon_sym_ascending] = ACTIONS(4091),
    [anon_sym_descending] = ACTIONS(4091),
    [anon_sym_group] = ACTIONS(4091),
    [anon_sym_by] = ACTIONS(4091),
    [anon_sym_select] = ACTIONS(4091),
    [anon_sym_as] = ACTIONS(3995),
    [anon_sym_is] = ACTIONS(3995),
    [anon_sym_DASH_GT] = ACTIONS(3993),
    [anon_sym_with] = ACTIONS(3995),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(3993),
  },
  [2825] = {
    [sym_preproc_region] = STATE(2825),
    [sym_preproc_endregion] = STATE(2825),
    [sym_preproc_line] = STATE(2825),
    [sym_preproc_pragma] = STATE(2825),
    [sym_preproc_nullable] = STATE(2825),
    [sym_preproc_error] = STATE(2825),
    [sym_preproc_warning] = STATE(2825),
    [sym_preproc_define] = STATE(2825),
    [sym_preproc_undef] = STATE(2825),
    [sym__identifier_token] = ACTIONS(4122),
    [anon_sym_alias] = ACTIONS(4122),
    [anon_sym_global] = ACTIONS(4122),
    [anon_sym_EQ] = ACTIONS(4122),
    [anon_sym_LBRACK] = ACTIONS(4124),
    [anon_sym_COLON] = ACTIONS(4124),
    [anon_sym_COMMA] = ACTIONS(4124),
    [anon_sym_LPAREN] = ACTIONS(4124),
    [anon_sym_LBRACE] = ACTIONS(4124),
    [anon_sym_file] = ACTIONS(4122),
    [anon_sym_LT] = ACTIONS(4122),
    [anon_sym_GT] = ACTIONS(4122),
    [anon_sym_where] = ACTIONS(4122),
    [anon_sym_QMARK] = ACTIONS(4122),
    [anon_sym_notnull] = ACTIONS(4122),
    [anon_sym_unmanaged] = ACTIONS(4122),
    [anon_sym_BANG] = ACTIONS(4122),
    [anon_sym_PLUS_PLUS] = ACTIONS(4124),
    [anon_sym_DASH_DASH] = ACTIONS(4124),
    [anon_sym_PLUS] = ACTIONS(4122),
    [anon_sym_DASH] = ACTIONS(4122),
    [anon_sym_STAR] = ACTIONS(4122),
    [anon_sym_SLASH] = ACTIONS(4122),
    [anon_sym_PERCENT] = ACTIONS(4122),
    [anon_sym_CARET] = ACTIONS(4122),
    [anon_sym_PIPE] = ACTIONS(4122),
    [anon_sym_AMP] = ACTIONS(4122),
    [anon_sym_LT_LT] = ACTIONS(4122),
    [anon_sym_GT_GT] = ACTIONS(4122),
    [anon_sym_GT_GT_GT] = ACTIONS(4122),
    [anon_sym_EQ_EQ] = ACTIONS(4124),
    [anon_sym_BANG_EQ] = ACTIONS(4124),
    [anon_sym_GT_EQ] = ACTIONS(4124),
    [anon_sym_LT_EQ] = ACTIONS(4124),
    [anon_sym_DOT] = ACTIONS(4122),
    [anon_sym_scoped] = ACTIONS(4122),
    [anon_sym_var] = ACTIONS(4122),
    [anon_sym_yield] = ACTIONS(4122),
    [anon_sym_switch] = ACTIONS(4122),
    [anon_sym_when] = ACTIONS(4122),
    [sym_discard] = ACTIONS(4122),
    [anon_sym_DOT_DOT] = ACTIONS(4124),
    [anon_sym_and] = ACTIONS(4122),
    [anon_sym_or] = ACTIONS(4122),
    [anon_sym_PLUS_EQ] = ACTIONS(4124),
    [anon_sym_DASH_EQ] = ACTIONS(4124),
    [anon_sym_STAR_EQ] = ACTIONS(4124),
    [anon_sym_SLASH_EQ] = ACTIONS(4124),
    [anon_sym_PERCENT_EQ] = ACTIONS(4124),
    [anon_sym_AMP_EQ] = ACTIONS(4124),
    [anon_sym_CARET_EQ] = ACTIONS(4124),
    [anon_sym_PIPE_EQ] = ACTIONS(4124),
    [anon_sym_LT_LT_EQ] = ACTIONS(4124),
    [anon_sym_GT_GT_EQ] = ACTIONS(4124),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4124),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4124),
    [anon_sym_AMP_AMP] = ACTIONS(4124),
    [anon_sym_PIPE_PIPE] = ACTIONS(4124),
    [anon_sym_QMARK_QMARK] = ACTIONS(4122),
    [anon_sym_from] = ACTIONS(4122),
    [anon_sym_into] = ACTIONS(4122),
    [anon_sym_join] = ACTIONS(4122),
    [anon_sym_on] = ACTIONS(4122),
    [anon_sym_equals] = ACTIONS(4122),
    [anon_sym_let] = ACTIONS(4122),
    [anon_sym_orderby] = ACTIONS(4122),
    [anon_sym_ascending] = ACTIONS(4122),
    [anon_sym_descending] = ACTIONS(4122),
    [anon_sym_group] = ACTIONS(4122),
    [anon_sym_by] = ACTIONS(4122),
    [anon_sym_select] = ACTIONS(4122),
    [anon_sym_as] = ACTIONS(4122),
    [anon_sym_is] = ACTIONS(4122),
    [anon_sym_DASH_GT] = ACTIONS(4124),
    [anon_sym_with] = ACTIONS(4122),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4124),
  },
  [2826] = {
    [sym_preproc_region] = STATE(2826),
    [sym_preproc_endregion] = STATE(2826),
    [sym_preproc_line] = STATE(2826),
    [sym_preproc_pragma] = STATE(2826),
    [sym_preproc_nullable] = STATE(2826),
    [sym_preproc_error] = STATE(2826),
    [sym_preproc_warning] = STATE(2826),
    [sym_preproc_define] = STATE(2826),
    [sym_preproc_undef] = STATE(2826),
    [sym__identifier_token] = ACTIONS(4179),
    [anon_sym_alias] = ACTIONS(4179),
    [anon_sym_global] = ACTIONS(4179),
    [anon_sym_EQ] = ACTIONS(4183),
    [anon_sym_LBRACK] = ACTIONS(4185),
    [anon_sym_COLON] = ACTIONS(4185),
    [anon_sym_COMMA] = ACTIONS(4185),
    [anon_sym_LPAREN] = ACTIONS(4185),
    [anon_sym_LBRACE] = ACTIONS(4181),
    [anon_sym_file] = ACTIONS(4179),
    [anon_sym_LT] = ACTIONS(4188),
    [anon_sym_GT] = ACTIONS(4188),
    [anon_sym_where] = ACTIONS(4179),
    [anon_sym_QMARK] = ACTIONS(4188),
    [anon_sym_notnull] = ACTIONS(4179),
    [anon_sym_unmanaged] = ACTIONS(4179),
    [anon_sym_BANG] = ACTIONS(4188),
    [anon_sym_PLUS_PLUS] = ACTIONS(4185),
    [anon_sym_DASH_DASH] = ACTIONS(4185),
    [anon_sym_PLUS] = ACTIONS(4188),
    [anon_sym_DASH] = ACTIONS(4188),
    [anon_sym_STAR] = ACTIONS(4188),
    [anon_sym_SLASH] = ACTIONS(4188),
    [anon_sym_PERCENT] = ACTIONS(4188),
    [anon_sym_CARET] = ACTIONS(4188),
    [anon_sym_PIPE] = ACTIONS(4188),
    [anon_sym_AMP] = ACTIONS(4188),
    [anon_sym_LT_LT] = ACTIONS(4188),
    [anon_sym_GT_GT] = ACTIONS(4188),
    [anon_sym_GT_GT_GT] = ACTIONS(4188),
    [anon_sym_EQ_EQ] = ACTIONS(4185),
    [anon_sym_BANG_EQ] = ACTIONS(4185),
    [anon_sym_GT_EQ] = ACTIONS(4185),
    [anon_sym_LT_EQ] = ACTIONS(4185),
    [anon_sym_DOT] = ACTIONS(4188),
    [anon_sym_scoped] = ACTIONS(4179),
    [anon_sym_var] = ACTIONS(4179),
    [anon_sym_yield] = ACTIONS(4179),
    [anon_sym_switch] = ACTIONS(4188),
    [anon_sym_when] = ACTIONS(4179),
    [sym_discard] = ACTIONS(4179),
    [anon_sym_DOT_DOT] = ACTIONS(4185),
    [anon_sym_and] = ACTIONS(4188),
    [anon_sym_or] = ACTIONS(4188),
    [anon_sym_PLUS_EQ] = ACTIONS(4191),
    [anon_sym_DASH_EQ] = ACTIONS(4191),
    [anon_sym_STAR_EQ] = ACTIONS(4191),
    [anon_sym_SLASH_EQ] = ACTIONS(4191),
    [anon_sym_PERCENT_EQ] = ACTIONS(4191),
    [anon_sym_AMP_EQ] = ACTIONS(4191),
    [anon_sym_CARET_EQ] = ACTIONS(4191),
    [anon_sym_PIPE_EQ] = ACTIONS(4191),
    [anon_sym_LT_LT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4191),
    [anon_sym_AMP_AMP] = ACTIONS(4185),
    [anon_sym_PIPE_PIPE] = ACTIONS(4185),
    [anon_sym_QMARK_QMARK] = ACTIONS(4188),
    [anon_sym_from] = ACTIONS(4179),
    [anon_sym_into] = ACTIONS(4179),
    [anon_sym_join] = ACTIONS(4179),
    [anon_sym_on] = ACTIONS(4179),
    [anon_sym_equals] = ACTIONS(4179),
    [anon_sym_let] = ACTIONS(4179),
    [anon_sym_orderby] = ACTIONS(4179),
    [anon_sym_ascending] = ACTIONS(4179),
    [anon_sym_descending] = ACTIONS(4179),
    [anon_sym_group] = ACTIONS(4179),
    [anon_sym_by] = ACTIONS(4179),
    [anon_sym_select] = ACTIONS(4179),
    [anon_sym_as] = ACTIONS(4188),
    [anon_sym_is] = ACTIONS(4188),
    [anon_sym_DASH_GT] = ACTIONS(4185),
    [anon_sym_with] = ACTIONS(4188),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4185),
  },
  [2827] = {
    [sym_preproc_region] = STATE(2827),
    [sym_preproc_endregion] = STATE(2827),
    [sym_preproc_line] = STATE(2827),
    [sym_preproc_pragma] = STATE(2827),
    [sym_preproc_nullable] = STATE(2827),
    [sym_preproc_error] = STATE(2827),
    [sym_preproc_warning] = STATE(2827),
    [sym_preproc_define] = STATE(2827),
    [sym_preproc_undef] = STATE(2827),
    [sym__identifier_token] = ACTIONS(3995),
    [anon_sym_alias] = ACTIONS(3995),
    [anon_sym_global] = ACTIONS(3995),
    [anon_sym_using] = ACTIONS(4393),
    [anon_sym_EQ] = ACTIONS(3995),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_COLON] = ACTIONS(3995),
    [anon_sym_LPAREN] = ACTIONS(3993),
    [anon_sym_file] = ACTIONS(3995),
    [anon_sym_LT] = ACTIONS(3995),
    [anon_sym_GT] = ACTIONS(3995),
    [anon_sym_where] = ACTIONS(3995),
    [anon_sym_QMARK] = ACTIONS(3995),
    [anon_sym_notnull] = ACTIONS(3995),
    [anon_sym_unmanaged] = ACTIONS(3995),
    [anon_sym_BANG] = ACTIONS(3995),
    [anon_sym_PLUS_PLUS] = ACTIONS(3993),
    [anon_sym_DASH_DASH] = ACTIONS(3993),
    [anon_sym_PLUS] = ACTIONS(3995),
    [anon_sym_DASH] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3995),
    [anon_sym_SLASH] = ACTIONS(3995),
    [anon_sym_PERCENT] = ACTIONS(3995),
    [anon_sym_CARET] = ACTIONS(3995),
    [anon_sym_PIPE] = ACTIONS(3995),
    [anon_sym_AMP] = ACTIONS(3995),
    [anon_sym_LT_LT] = ACTIONS(3995),
    [anon_sym_GT_GT] = ACTIONS(3995),
    [anon_sym_GT_GT_GT] = ACTIONS(3995),
    [anon_sym_EQ_EQ] = ACTIONS(3993),
    [anon_sym_BANG_EQ] = ACTIONS(3993),
    [anon_sym_GT_EQ] = ACTIONS(3993),
    [anon_sym_LT_EQ] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3995),
    [anon_sym_scoped] = ACTIONS(3995),
    [anon_sym_EQ_GT] = ACTIONS(3993),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(3995),
    [anon_sym_yield] = ACTIONS(3995),
    [anon_sym_switch] = ACTIONS(3995),
    [anon_sym_when] = ACTIONS(3995),
    [anon_sym_DOT_DOT] = ACTIONS(3993),
    [anon_sym_PLUS_EQ] = ACTIONS(3993),
    [anon_sym_DASH_EQ] = ACTIONS(3993),
    [anon_sym_STAR_EQ] = ACTIONS(3993),
    [anon_sym_SLASH_EQ] = ACTIONS(3993),
    [anon_sym_PERCENT_EQ] = ACTIONS(3993),
    [anon_sym_AMP_EQ] = ACTIONS(3993),
    [anon_sym_CARET_EQ] = ACTIONS(3993),
    [anon_sym_PIPE_EQ] = ACTIONS(3993),
    [anon_sym_LT_LT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(3993),
    [anon_sym_AMP_AMP] = ACTIONS(3993),
    [anon_sym_PIPE_PIPE] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK] = ACTIONS(3995),
    [anon_sym_from] = ACTIONS(3995),
    [anon_sym_into] = ACTIONS(3995),
    [anon_sym_join] = ACTIONS(3995),
    [anon_sym_on] = ACTIONS(3995),
    [anon_sym_equals] = ACTIONS(3995),
    [anon_sym_let] = ACTIONS(3995),
    [anon_sym_orderby] = ACTIONS(3995),
    [anon_sym_ascending] = ACTIONS(3995),
    [anon_sym_descending] = ACTIONS(3995),
    [anon_sym_group] = ACTIONS(3995),
    [anon_sym_by] = ACTIONS(3995),
    [anon_sym_select] = ACTIONS(3995),
    [anon_sym_as] = ACTIONS(3995),
    [anon_sym_is] = ACTIONS(3995),
    [anon_sym_DASH_GT] = ACTIONS(3993),
    [anon_sym_with] = ACTIONS(3995),
    [aux_sym_preproc_if_token3] = ACTIONS(3993),
    [aux_sym_preproc_else_token1] = ACTIONS(3993),
    [aux_sym_preproc_elif_token1] = ACTIONS(3993),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2828] = {
    [sym_preproc_region] = STATE(2828),
    [sym_preproc_endregion] = STATE(2828),
    [sym_preproc_line] = STATE(2828),
    [sym_preproc_pragma] = STATE(2828),
    [sym_preproc_nullable] = STATE(2828),
    [sym_preproc_error] = STATE(2828),
    [sym_preproc_warning] = STATE(2828),
    [sym_preproc_define] = STATE(2828),
    [sym_preproc_undef] = STATE(2828),
    [sym__identifier_token] = ACTIONS(3995),
    [anon_sym_alias] = ACTIONS(3995),
    [anon_sym_global] = ACTIONS(3995),
    [anon_sym_EQ] = ACTIONS(3995),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_COLON] = ACTIONS(3995),
    [anon_sym_COMMA] = ACTIONS(3993),
    [anon_sym_LPAREN] = ACTIONS(3993),
    [anon_sym_return] = ACTIONS(4395),
    [anon_sym_RBRACE] = ACTIONS(3993),
    [anon_sym_file] = ACTIONS(3995),
    [anon_sym_LT] = ACTIONS(3995),
    [anon_sym_GT] = ACTIONS(3995),
    [anon_sym_where] = ACTIONS(3995),
    [anon_sym_QMARK] = ACTIONS(3995),
    [anon_sym_notnull] = ACTIONS(3995),
    [anon_sym_unmanaged] = ACTIONS(3995),
    [anon_sym_BANG] = ACTIONS(3995),
    [anon_sym_PLUS_PLUS] = ACTIONS(3993),
    [anon_sym_DASH_DASH] = ACTIONS(3993),
    [anon_sym_PLUS] = ACTIONS(3995),
    [anon_sym_DASH] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3995),
    [anon_sym_SLASH] = ACTIONS(3995),
    [anon_sym_PERCENT] = ACTIONS(3995),
    [anon_sym_CARET] = ACTIONS(3995),
    [anon_sym_PIPE] = ACTIONS(3995),
    [anon_sym_AMP] = ACTIONS(3995),
    [anon_sym_LT_LT] = ACTIONS(3995),
    [anon_sym_GT_GT] = ACTIONS(3995),
    [anon_sym_GT_GT_GT] = ACTIONS(3995),
    [anon_sym_EQ_EQ] = ACTIONS(3993),
    [anon_sym_BANG_EQ] = ACTIONS(3993),
    [anon_sym_GT_EQ] = ACTIONS(3993),
    [anon_sym_LT_EQ] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3995),
    [anon_sym_scoped] = ACTIONS(3995),
    [anon_sym_EQ_GT] = ACTIONS(3993),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(3995),
    [anon_sym_break] = ACTIONS(4397),
    [anon_sym_yield] = ACTIONS(3995),
    [anon_sym_switch] = ACTIONS(3995),
    [anon_sym_when] = ACTIONS(3995),
    [anon_sym_DOT_DOT] = ACTIONS(3993),
    [anon_sym_PLUS_EQ] = ACTIONS(3993),
    [anon_sym_DASH_EQ] = ACTIONS(3993),
    [anon_sym_STAR_EQ] = ACTIONS(3993),
    [anon_sym_SLASH_EQ] = ACTIONS(3993),
    [anon_sym_PERCENT_EQ] = ACTIONS(3993),
    [anon_sym_AMP_EQ] = ACTIONS(3993),
    [anon_sym_CARET_EQ] = ACTIONS(3993),
    [anon_sym_PIPE_EQ] = ACTIONS(3993),
    [anon_sym_LT_LT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(3993),
    [anon_sym_AMP_AMP] = ACTIONS(3993),
    [anon_sym_PIPE_PIPE] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK] = ACTIONS(3995),
    [anon_sym_from] = ACTIONS(3995),
    [anon_sym_into] = ACTIONS(3995),
    [anon_sym_join] = ACTIONS(3995),
    [anon_sym_on] = ACTIONS(3995),
    [anon_sym_equals] = ACTIONS(3995),
    [anon_sym_let] = ACTIONS(3995),
    [anon_sym_orderby] = ACTIONS(3995),
    [anon_sym_ascending] = ACTIONS(3995),
    [anon_sym_descending] = ACTIONS(3995),
    [anon_sym_group] = ACTIONS(3995),
    [anon_sym_by] = ACTIONS(3995),
    [anon_sym_select] = ACTIONS(3995),
    [anon_sym_as] = ACTIONS(3995),
    [anon_sym_is] = ACTIONS(3995),
    [anon_sym_DASH_GT] = ACTIONS(3993),
    [anon_sym_with] = ACTIONS(3995),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2829] = {
    [sym_preproc_region] = STATE(2829),
    [sym_preproc_endregion] = STATE(2829),
    [sym_preproc_line] = STATE(2829),
    [sym_preproc_pragma] = STATE(2829),
    [sym_preproc_nullable] = STATE(2829),
    [sym_preproc_error] = STATE(2829),
    [sym_preproc_warning] = STATE(2829),
    [sym_preproc_define] = STATE(2829),
    [sym_preproc_undef] = STATE(2829),
    [sym__identifier_token] = ACTIONS(4157),
    [anon_sym_alias] = ACTIONS(4157),
    [anon_sym_global] = ACTIONS(4157),
    [anon_sym_EQ] = ACTIONS(4162),
    [anon_sym_LBRACK] = ACTIONS(4193),
    [anon_sym_COLON] = ACTIONS(4177),
    [anon_sym_COMMA] = ACTIONS(4168),
    [anon_sym_LPAREN] = ACTIONS(4193),
    [anon_sym_RPAREN] = ACTIONS(4168),
    [anon_sym_LBRACE] = ACTIONS(4168),
    [anon_sym_file] = ACTIONS(4157),
    [anon_sym_LT] = ACTIONS(4162),
    [anon_sym_GT] = ACTIONS(4162),
    [anon_sym_where] = ACTIONS(4157),
    [anon_sym_QMARK] = ACTIONS(4196),
    [anon_sym_notnull] = ACTIONS(4157),
    [anon_sym_unmanaged] = ACTIONS(4157),
    [anon_sym_BANG] = ACTIONS(4162),
    [anon_sym_PLUS_PLUS] = ACTIONS(4177),
    [anon_sym_DASH_DASH] = ACTIONS(4177),
    [anon_sym_PLUS] = ACTIONS(4162),
    [anon_sym_DASH] = ACTIONS(4162),
    [anon_sym_STAR] = ACTIONS(4196),
    [anon_sym_SLASH] = ACTIONS(4162),
    [anon_sym_PERCENT] = ACTIONS(4162),
    [anon_sym_CARET] = ACTIONS(4162),
    [anon_sym_PIPE] = ACTIONS(4162),
    [anon_sym_AMP] = ACTIONS(4162),
    [anon_sym_LT_LT] = ACTIONS(4162),
    [anon_sym_GT_GT] = ACTIONS(4162),
    [anon_sym_GT_GT_GT] = ACTIONS(4162),
    [anon_sym_EQ_EQ] = ACTIONS(4177),
    [anon_sym_BANG_EQ] = ACTIONS(4177),
    [anon_sym_GT_EQ] = ACTIONS(4177),
    [anon_sym_LT_EQ] = ACTIONS(4177),
    [anon_sym_DOT] = ACTIONS(4196),
    [anon_sym_scoped] = ACTIONS(4157),
    [anon_sym_var] = ACTIONS(4157),
    [anon_sym_yield] = ACTIONS(4157),
    [anon_sym_switch] = ACTIONS(4162),
    [anon_sym_when] = ACTIONS(4157),
    [sym_discard] = ACTIONS(4157),
    [anon_sym_DOT_DOT] = ACTIONS(4177),
    [anon_sym_and] = ACTIONS(4157),
    [anon_sym_or] = ACTIONS(4157),
    [anon_sym_PLUS_EQ] = ACTIONS(4177),
    [anon_sym_DASH_EQ] = ACTIONS(4177),
    [anon_sym_STAR_EQ] = ACTIONS(4177),
    [anon_sym_SLASH_EQ] = ACTIONS(4177),
    [anon_sym_PERCENT_EQ] = ACTIONS(4177),
    [anon_sym_AMP_EQ] = ACTIONS(4177),
    [anon_sym_CARET_EQ] = ACTIONS(4177),
    [anon_sym_PIPE_EQ] = ACTIONS(4177),
    [anon_sym_LT_LT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4177),
    [anon_sym_AMP_AMP] = ACTIONS(4177),
    [anon_sym_PIPE_PIPE] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK] = ACTIONS(4162),
    [anon_sym_from] = ACTIONS(4157),
    [anon_sym_into] = ACTIONS(4157),
    [anon_sym_join] = ACTIONS(4157),
    [anon_sym_on] = ACTIONS(4157),
    [anon_sym_equals] = ACTIONS(4157),
    [anon_sym_let] = ACTIONS(4157),
    [anon_sym_orderby] = ACTIONS(4157),
    [anon_sym_ascending] = ACTIONS(4157),
    [anon_sym_descending] = ACTIONS(4157),
    [anon_sym_group] = ACTIONS(4157),
    [anon_sym_by] = ACTIONS(4157),
    [anon_sym_select] = ACTIONS(4157),
    [anon_sym_as] = ACTIONS(4162),
    [anon_sym_is] = ACTIONS(4162),
    [anon_sym_DASH_GT] = ACTIONS(4193),
    [anon_sym_with] = ACTIONS(4162),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2830] = {
    [sym_preproc_region] = STATE(2830),
    [sym_preproc_endregion] = STATE(2830),
    [sym_preproc_line] = STATE(2830),
    [sym_preproc_pragma] = STATE(2830),
    [sym_preproc_nullable] = STATE(2830),
    [sym_preproc_error] = STATE(2830),
    [sym_preproc_warning] = STATE(2830),
    [sym_preproc_define] = STATE(2830),
    [sym_preproc_undef] = STATE(2830),
    [sym__identifier_token] = ACTIONS(4157),
    [anon_sym_alias] = ACTIONS(4157),
    [anon_sym_global] = ACTIONS(4157),
    [anon_sym_EQ] = ACTIONS(4162),
    [anon_sym_LBRACK] = ACTIONS(4164),
    [anon_sym_COLON] = ACTIONS(4159),
    [anon_sym_COMMA] = ACTIONS(4159),
    [anon_sym_LPAREN] = ACTIONS(4164),
    [anon_sym_LBRACE] = ACTIONS(4168),
    [anon_sym_file] = ACTIONS(4157),
    [anon_sym_LT] = ACTIONS(4170),
    [anon_sym_GT] = ACTIONS(4170),
    [anon_sym_where] = ACTIONS(4157),
    [anon_sym_QMARK] = ACTIONS(4170),
    [anon_sym_notnull] = ACTIONS(4157),
    [anon_sym_unmanaged] = ACTIONS(4157),
    [anon_sym_BANG] = ACTIONS(4170),
    [anon_sym_PLUS_PLUS] = ACTIONS(4164),
    [anon_sym_DASH_DASH] = ACTIONS(4164),
    [anon_sym_PLUS] = ACTIONS(4170),
    [anon_sym_DASH] = ACTIONS(4170),
    [anon_sym_STAR] = ACTIONS(4170),
    [anon_sym_SLASH] = ACTIONS(4170),
    [anon_sym_PERCENT] = ACTIONS(4170),
    [anon_sym_CARET] = ACTIONS(4170),
    [anon_sym_PIPE] = ACTIONS(4170),
    [anon_sym_AMP] = ACTIONS(4170),
    [anon_sym_LT_LT] = ACTIONS(4170),
    [anon_sym_GT_GT] = ACTIONS(4170),
    [anon_sym_GT_GT_GT] = ACTIONS(4170),
    [anon_sym_EQ_EQ] = ACTIONS(4164),
    [anon_sym_BANG_EQ] = ACTIONS(4164),
    [anon_sym_GT_EQ] = ACTIONS(4164),
    [anon_sym_LT_EQ] = ACTIONS(4164),
    [anon_sym_DOT] = ACTIONS(4170),
    [anon_sym_scoped] = ACTIONS(4157),
    [anon_sym_var] = ACTIONS(4157),
    [anon_sym_yield] = ACTIONS(4157),
    [anon_sym_switch] = ACTIONS(4170),
    [anon_sym_when] = ACTIONS(4157),
    [sym_discard] = ACTIONS(4157),
    [anon_sym_DOT_DOT] = ACTIONS(4164),
    [anon_sym_and] = ACTIONS(4174),
    [anon_sym_or] = ACTIONS(4174),
    [anon_sym_PLUS_EQ] = ACTIONS(4177),
    [anon_sym_DASH_EQ] = ACTIONS(4177),
    [anon_sym_STAR_EQ] = ACTIONS(4177),
    [anon_sym_SLASH_EQ] = ACTIONS(4177),
    [anon_sym_PERCENT_EQ] = ACTIONS(4177),
    [anon_sym_AMP_EQ] = ACTIONS(4177),
    [anon_sym_CARET_EQ] = ACTIONS(4177),
    [anon_sym_PIPE_EQ] = ACTIONS(4177),
    [anon_sym_LT_LT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4177),
    [anon_sym_AMP_AMP] = ACTIONS(4164),
    [anon_sym_PIPE_PIPE] = ACTIONS(4164),
    [anon_sym_QMARK_QMARK] = ACTIONS(4170),
    [anon_sym_from] = ACTIONS(4157),
    [anon_sym_into] = ACTIONS(4157),
    [anon_sym_join] = ACTIONS(4157),
    [anon_sym_on] = ACTIONS(4157),
    [anon_sym_equals] = ACTIONS(4157),
    [anon_sym_let] = ACTIONS(4157),
    [anon_sym_orderby] = ACTIONS(4157),
    [anon_sym_ascending] = ACTIONS(4157),
    [anon_sym_descending] = ACTIONS(4157),
    [anon_sym_group] = ACTIONS(4157),
    [anon_sym_by] = ACTIONS(4157),
    [anon_sym_select] = ACTIONS(4157),
    [anon_sym_as] = ACTIONS(4170),
    [anon_sym_is] = ACTIONS(4170),
    [anon_sym_DASH_GT] = ACTIONS(4164),
    [anon_sym_with] = ACTIONS(4170),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4159),
  },
  [2831] = {
    [sym_preproc_region] = STATE(2831),
    [sym_preproc_endregion] = STATE(2831),
    [sym_preproc_line] = STATE(2831),
    [sym_preproc_pragma] = STATE(2831),
    [sym_preproc_nullable] = STATE(2831),
    [sym_preproc_error] = STATE(2831),
    [sym_preproc_warning] = STATE(2831),
    [sym_preproc_define] = STATE(2831),
    [sym_preproc_undef] = STATE(2831),
    [sym__identifier_token] = ACTIONS(4157),
    [anon_sym_alias] = ACTIONS(4157),
    [anon_sym_global] = ACTIONS(4157),
    [anon_sym_EQ] = ACTIONS(4162),
    [anon_sym_LBRACK] = ACTIONS(4164),
    [anon_sym_COLON] = ACTIONS(4159),
    [anon_sym_COMMA] = ACTIONS(4159),
    [anon_sym_LPAREN] = ACTIONS(4164),
    [anon_sym_LBRACE] = ACTIONS(4168),
    [anon_sym_file] = ACTIONS(4157),
    [anon_sym_LT] = ACTIONS(4170),
    [anon_sym_GT] = ACTIONS(4170),
    [anon_sym_where] = ACTIONS(4157),
    [anon_sym_QMARK] = ACTIONS(4170),
    [anon_sym_notnull] = ACTIONS(4157),
    [anon_sym_unmanaged] = ACTIONS(4157),
    [anon_sym_BANG] = ACTIONS(4170),
    [anon_sym_PLUS_PLUS] = ACTIONS(4164),
    [anon_sym_DASH_DASH] = ACTIONS(4164),
    [anon_sym_PLUS] = ACTIONS(4170),
    [anon_sym_DASH] = ACTIONS(4170),
    [anon_sym_STAR] = ACTIONS(4170),
    [anon_sym_SLASH] = ACTIONS(4170),
    [anon_sym_PERCENT] = ACTIONS(4170),
    [anon_sym_CARET] = ACTIONS(4170),
    [anon_sym_PIPE] = ACTIONS(4170),
    [anon_sym_AMP] = ACTIONS(4170),
    [anon_sym_LT_LT] = ACTIONS(4170),
    [anon_sym_GT_GT] = ACTIONS(4170),
    [anon_sym_GT_GT_GT] = ACTIONS(4170),
    [anon_sym_EQ_EQ] = ACTIONS(4164),
    [anon_sym_BANG_EQ] = ACTIONS(4164),
    [anon_sym_GT_EQ] = ACTIONS(4164),
    [anon_sym_LT_EQ] = ACTIONS(4164),
    [anon_sym_DOT] = ACTIONS(4170),
    [anon_sym_scoped] = ACTIONS(4157),
    [anon_sym_var] = ACTIONS(4157),
    [anon_sym_yield] = ACTIONS(4157),
    [anon_sym_switch] = ACTIONS(4170),
    [anon_sym_when] = ACTIONS(4157),
    [sym_discard] = ACTIONS(4157),
    [anon_sym_DOT_DOT] = ACTIONS(4164),
    [anon_sym_and] = ACTIONS(4174),
    [anon_sym_or] = ACTIONS(4174),
    [anon_sym_PLUS_EQ] = ACTIONS(4177),
    [anon_sym_DASH_EQ] = ACTIONS(4177),
    [anon_sym_STAR_EQ] = ACTIONS(4177),
    [anon_sym_SLASH_EQ] = ACTIONS(4177),
    [anon_sym_PERCENT_EQ] = ACTIONS(4177),
    [anon_sym_AMP_EQ] = ACTIONS(4177),
    [anon_sym_CARET_EQ] = ACTIONS(4177),
    [anon_sym_PIPE_EQ] = ACTIONS(4177),
    [anon_sym_LT_LT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4177),
    [anon_sym_AMP_AMP] = ACTIONS(4164),
    [anon_sym_PIPE_PIPE] = ACTIONS(4164),
    [anon_sym_QMARK_QMARK] = ACTIONS(4170),
    [anon_sym_from] = ACTIONS(4157),
    [anon_sym_into] = ACTIONS(4174),
    [anon_sym_join] = ACTIONS(4157),
    [anon_sym_on] = ACTIONS(4157),
    [anon_sym_equals] = ACTIONS(4157),
    [anon_sym_let] = ACTIONS(4157),
    [anon_sym_orderby] = ACTIONS(4157),
    [anon_sym_ascending] = ACTIONS(4157),
    [anon_sym_descending] = ACTIONS(4157),
    [anon_sym_group] = ACTIONS(4157),
    [anon_sym_by] = ACTIONS(4157),
    [anon_sym_select] = ACTIONS(4157),
    [anon_sym_as] = ACTIONS(4170),
    [anon_sym_is] = ACTIONS(4170),
    [anon_sym_DASH_GT] = ACTIONS(4164),
    [anon_sym_with] = ACTIONS(4170),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4159),
  },
  [2832] = {
    [sym_preproc_region] = STATE(2832),
    [sym_preproc_endregion] = STATE(2832),
    [sym_preproc_line] = STATE(2832),
    [sym_preproc_pragma] = STATE(2832),
    [sym_preproc_nullable] = STATE(2832),
    [sym_preproc_error] = STATE(2832),
    [sym_preproc_warning] = STATE(2832),
    [sym_preproc_define] = STATE(2832),
    [sym_preproc_undef] = STATE(2832),
    [sym__identifier_token] = ACTIONS(4157),
    [anon_sym_alias] = ACTIONS(4157),
    [anon_sym_global] = ACTIONS(4157),
    [anon_sym_EQ] = ACTIONS(4162),
    [anon_sym_LBRACK] = ACTIONS(4193),
    [anon_sym_COLON] = ACTIONS(4168),
    [anon_sym_COMMA] = ACTIONS(4168),
    [anon_sym_LPAREN] = ACTIONS(4193),
    [anon_sym_LBRACE] = ACTIONS(4168),
    [anon_sym_file] = ACTIONS(4157),
    [anon_sym_LT] = ACTIONS(4196),
    [anon_sym_GT] = ACTIONS(4196),
    [anon_sym_where] = ACTIONS(4157),
    [anon_sym_QMARK] = ACTIONS(4196),
    [anon_sym_notnull] = ACTIONS(4157),
    [anon_sym_unmanaged] = ACTIONS(4157),
    [anon_sym_BANG] = ACTIONS(4196),
    [anon_sym_PLUS_PLUS] = ACTIONS(4193),
    [anon_sym_DASH_DASH] = ACTIONS(4193),
    [anon_sym_PLUS] = ACTIONS(4196),
    [anon_sym_DASH] = ACTIONS(4196),
    [anon_sym_STAR] = ACTIONS(4196),
    [anon_sym_SLASH] = ACTIONS(4196),
    [anon_sym_PERCENT] = ACTIONS(4196),
    [anon_sym_CARET] = ACTIONS(4196),
    [anon_sym_PIPE] = ACTIONS(4196),
    [anon_sym_AMP] = ACTIONS(4196),
    [anon_sym_LT_LT] = ACTIONS(4196),
    [anon_sym_GT_GT] = ACTIONS(4196),
    [anon_sym_GT_GT_GT] = ACTIONS(4196),
    [anon_sym_EQ_EQ] = ACTIONS(4193),
    [anon_sym_BANG_EQ] = ACTIONS(4193),
    [anon_sym_GT_EQ] = ACTIONS(4193),
    [anon_sym_LT_EQ] = ACTIONS(4193),
    [anon_sym_DOT] = ACTIONS(4196),
    [anon_sym_scoped] = ACTIONS(4157),
    [anon_sym_var] = ACTIONS(4157),
    [anon_sym_yield] = ACTIONS(4157),
    [anon_sym_switch] = ACTIONS(4196),
    [anon_sym_when] = ACTIONS(4157),
    [sym_discard] = ACTIONS(4157),
    [anon_sym_DOT_DOT] = ACTIONS(4193),
    [anon_sym_and] = ACTIONS(4157),
    [anon_sym_or] = ACTIONS(4157),
    [anon_sym_PLUS_EQ] = ACTIONS(4177),
    [anon_sym_DASH_EQ] = ACTIONS(4177),
    [anon_sym_STAR_EQ] = ACTIONS(4177),
    [anon_sym_SLASH_EQ] = ACTIONS(4177),
    [anon_sym_PERCENT_EQ] = ACTIONS(4177),
    [anon_sym_AMP_EQ] = ACTIONS(4177),
    [anon_sym_CARET_EQ] = ACTIONS(4177),
    [anon_sym_PIPE_EQ] = ACTIONS(4177),
    [anon_sym_LT_LT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4177),
    [anon_sym_AMP_AMP] = ACTIONS(4193),
    [anon_sym_PIPE_PIPE] = ACTIONS(4193),
    [anon_sym_QMARK_QMARK] = ACTIONS(4196),
    [anon_sym_from] = ACTIONS(4157),
    [anon_sym_into] = ACTIONS(4157),
    [anon_sym_join] = ACTIONS(4157),
    [anon_sym_on] = ACTIONS(4157),
    [anon_sym_equals] = ACTIONS(4157),
    [anon_sym_let] = ACTIONS(4157),
    [anon_sym_orderby] = ACTIONS(4157),
    [anon_sym_ascending] = ACTIONS(4157),
    [anon_sym_descending] = ACTIONS(4157),
    [anon_sym_group] = ACTIONS(4157),
    [anon_sym_by] = ACTIONS(4157),
    [anon_sym_select] = ACTIONS(4157),
    [anon_sym_as] = ACTIONS(4196),
    [anon_sym_is] = ACTIONS(4196),
    [anon_sym_DASH_GT] = ACTIONS(4193),
    [anon_sym_with] = ACTIONS(4196),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4168),
  },
  [2833] = {
    [sym_preproc_region] = STATE(2833),
    [sym_preproc_endregion] = STATE(2833),
    [sym_preproc_line] = STATE(2833),
    [sym_preproc_pragma] = STATE(2833),
    [sym_preproc_nullable] = STATE(2833),
    [sym_preproc_error] = STATE(2833),
    [sym_preproc_warning] = STATE(2833),
    [sym_preproc_define] = STATE(2833),
    [sym_preproc_undef] = STATE(2833),
    [sym__identifier_token] = ACTIONS(4149),
    [anon_sym_alias] = ACTIONS(4149),
    [anon_sym_global] = ACTIONS(4149),
    [anon_sym_EQ] = ACTIONS(4149),
    [anon_sym_LBRACK] = ACTIONS(4151),
    [anon_sym_COLON] = ACTIONS(4151),
    [anon_sym_COMMA] = ACTIONS(4151),
    [anon_sym_LPAREN] = ACTIONS(4151),
    [anon_sym_LBRACE] = ACTIONS(4151),
    [anon_sym_file] = ACTIONS(4149),
    [anon_sym_LT] = ACTIONS(4149),
    [anon_sym_GT] = ACTIONS(4149),
    [anon_sym_where] = ACTIONS(4149),
    [anon_sym_QMARK] = ACTIONS(4149),
    [anon_sym_notnull] = ACTIONS(4149),
    [anon_sym_unmanaged] = ACTIONS(4149),
    [anon_sym_BANG] = ACTIONS(4149),
    [anon_sym_PLUS_PLUS] = ACTIONS(4151),
    [anon_sym_DASH_DASH] = ACTIONS(4151),
    [anon_sym_PLUS] = ACTIONS(4149),
    [anon_sym_DASH] = ACTIONS(4149),
    [anon_sym_STAR] = ACTIONS(4149),
    [anon_sym_SLASH] = ACTIONS(4149),
    [anon_sym_PERCENT] = ACTIONS(4149),
    [anon_sym_CARET] = ACTIONS(4149),
    [anon_sym_PIPE] = ACTIONS(4149),
    [anon_sym_AMP] = ACTIONS(4149),
    [anon_sym_LT_LT] = ACTIONS(4149),
    [anon_sym_GT_GT] = ACTIONS(4149),
    [anon_sym_GT_GT_GT] = ACTIONS(4149),
    [anon_sym_EQ_EQ] = ACTIONS(4151),
    [anon_sym_BANG_EQ] = ACTIONS(4151),
    [anon_sym_GT_EQ] = ACTIONS(4151),
    [anon_sym_LT_EQ] = ACTIONS(4151),
    [anon_sym_DOT] = ACTIONS(4149),
    [anon_sym_scoped] = ACTIONS(4149),
    [anon_sym_var] = ACTIONS(4149),
    [anon_sym_yield] = ACTIONS(4149),
    [anon_sym_switch] = ACTIONS(4149),
    [anon_sym_when] = ACTIONS(4149),
    [sym_discard] = ACTIONS(4149),
    [anon_sym_DOT_DOT] = ACTIONS(4151),
    [anon_sym_and] = ACTIONS(4149),
    [anon_sym_or] = ACTIONS(4149),
    [anon_sym_PLUS_EQ] = ACTIONS(4151),
    [anon_sym_DASH_EQ] = ACTIONS(4151),
    [anon_sym_STAR_EQ] = ACTIONS(4151),
    [anon_sym_SLASH_EQ] = ACTIONS(4151),
    [anon_sym_PERCENT_EQ] = ACTIONS(4151),
    [anon_sym_AMP_EQ] = ACTIONS(4151),
    [anon_sym_CARET_EQ] = ACTIONS(4151),
    [anon_sym_PIPE_EQ] = ACTIONS(4151),
    [anon_sym_LT_LT_EQ] = ACTIONS(4151),
    [anon_sym_GT_GT_EQ] = ACTIONS(4151),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4151),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4151),
    [anon_sym_AMP_AMP] = ACTIONS(4151),
    [anon_sym_PIPE_PIPE] = ACTIONS(4151),
    [anon_sym_QMARK_QMARK] = ACTIONS(4149),
    [anon_sym_from] = ACTIONS(4149),
    [anon_sym_into] = ACTIONS(4149),
    [anon_sym_join] = ACTIONS(4149),
    [anon_sym_on] = ACTIONS(4149),
    [anon_sym_equals] = ACTIONS(4149),
    [anon_sym_let] = ACTIONS(4149),
    [anon_sym_orderby] = ACTIONS(4149),
    [anon_sym_ascending] = ACTIONS(4149),
    [anon_sym_descending] = ACTIONS(4149),
    [anon_sym_group] = ACTIONS(4149),
    [anon_sym_by] = ACTIONS(4149),
    [anon_sym_select] = ACTIONS(4149),
    [anon_sym_as] = ACTIONS(4149),
    [anon_sym_is] = ACTIONS(4149),
    [anon_sym_DASH_GT] = ACTIONS(4151),
    [anon_sym_with] = ACTIONS(4149),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4151),
  },
  [2834] = {
    [sym_preproc_region] = STATE(2834),
    [sym_preproc_endregion] = STATE(2834),
    [sym_preproc_line] = STATE(2834),
    [sym_preproc_pragma] = STATE(2834),
    [sym_preproc_nullable] = STATE(2834),
    [sym_preproc_error] = STATE(2834),
    [sym_preproc_warning] = STATE(2834),
    [sym_preproc_define] = STATE(2834),
    [sym_preproc_undef] = STATE(2834),
    [sym__identifier_token] = ACTIONS(4179),
    [anon_sym_alias] = ACTIONS(4179),
    [anon_sym_global] = ACTIONS(4179),
    [anon_sym_EQ] = ACTIONS(4183),
    [anon_sym_LBRACK] = ACTIONS(4185),
    [anon_sym_COLON] = ACTIONS(4191),
    [anon_sym_COMMA] = ACTIONS(4181),
    [anon_sym_LPAREN] = ACTIONS(4185),
    [anon_sym_RPAREN] = ACTIONS(4181),
    [anon_sym_LBRACE] = ACTIONS(4181),
    [anon_sym_file] = ACTIONS(4179),
    [anon_sym_LT] = ACTIONS(4183),
    [anon_sym_GT] = ACTIONS(4183),
    [anon_sym_where] = ACTIONS(4179),
    [anon_sym_QMARK] = ACTIONS(4188),
    [anon_sym_notnull] = ACTIONS(4179),
    [anon_sym_unmanaged] = ACTIONS(4179),
    [anon_sym_BANG] = ACTIONS(4183),
    [anon_sym_PLUS_PLUS] = ACTIONS(4191),
    [anon_sym_DASH_DASH] = ACTIONS(4191),
    [anon_sym_PLUS] = ACTIONS(4183),
    [anon_sym_DASH] = ACTIONS(4183),
    [anon_sym_STAR] = ACTIONS(4188),
    [anon_sym_SLASH] = ACTIONS(4183),
    [anon_sym_PERCENT] = ACTIONS(4183),
    [anon_sym_CARET] = ACTIONS(4183),
    [anon_sym_PIPE] = ACTIONS(4183),
    [anon_sym_AMP] = ACTIONS(4183),
    [anon_sym_LT_LT] = ACTIONS(4183),
    [anon_sym_GT_GT] = ACTIONS(4183),
    [anon_sym_GT_GT_GT] = ACTIONS(4183),
    [anon_sym_EQ_EQ] = ACTIONS(4191),
    [anon_sym_BANG_EQ] = ACTIONS(4191),
    [anon_sym_GT_EQ] = ACTIONS(4191),
    [anon_sym_LT_EQ] = ACTIONS(4191),
    [anon_sym_DOT] = ACTIONS(4188),
    [anon_sym_scoped] = ACTIONS(4179),
    [anon_sym_var] = ACTIONS(4179),
    [anon_sym_yield] = ACTIONS(4179),
    [anon_sym_switch] = ACTIONS(4183),
    [anon_sym_when] = ACTIONS(4179),
    [sym_discard] = ACTIONS(4179),
    [anon_sym_DOT_DOT] = ACTIONS(4191),
    [anon_sym_and] = ACTIONS(4179),
    [anon_sym_or] = ACTIONS(4179),
    [anon_sym_PLUS_EQ] = ACTIONS(4191),
    [anon_sym_DASH_EQ] = ACTIONS(4191),
    [anon_sym_STAR_EQ] = ACTIONS(4191),
    [anon_sym_SLASH_EQ] = ACTIONS(4191),
    [anon_sym_PERCENT_EQ] = ACTIONS(4191),
    [anon_sym_AMP_EQ] = ACTIONS(4191),
    [anon_sym_CARET_EQ] = ACTIONS(4191),
    [anon_sym_PIPE_EQ] = ACTIONS(4191),
    [anon_sym_LT_LT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4191),
    [anon_sym_AMP_AMP] = ACTIONS(4191),
    [anon_sym_PIPE_PIPE] = ACTIONS(4191),
    [anon_sym_QMARK_QMARK] = ACTIONS(4183),
    [anon_sym_from] = ACTIONS(4179),
    [anon_sym_into] = ACTIONS(4179),
    [anon_sym_join] = ACTIONS(4179),
    [anon_sym_on] = ACTIONS(4179),
    [anon_sym_equals] = ACTIONS(4179),
    [anon_sym_let] = ACTIONS(4179),
    [anon_sym_orderby] = ACTIONS(4179),
    [anon_sym_ascending] = ACTIONS(4179),
    [anon_sym_descending] = ACTIONS(4179),
    [anon_sym_group] = ACTIONS(4179),
    [anon_sym_by] = ACTIONS(4179),
    [anon_sym_select] = ACTIONS(4179),
    [anon_sym_as] = ACTIONS(4183),
    [anon_sym_is] = ACTIONS(4183),
    [anon_sym_DASH_GT] = ACTIONS(4185),
    [anon_sym_with] = ACTIONS(4183),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2835] = {
    [sym_type_argument_list] = STATE(2746),
    [sym_preproc_region] = STATE(2835),
    [sym_preproc_endregion] = STATE(2835),
    [sym_preproc_line] = STATE(2835),
    [sym_preproc_pragma] = STATE(2835),
    [sym_preproc_nullable] = STATE(2835),
    [sym_preproc_error] = STATE(2835),
    [sym_preproc_warning] = STATE(2835),
    [sym_preproc_define] = STATE(2835),
    [sym_preproc_undef] = STATE(2835),
    [sym__identifier_token] = ACTIONS(4138),
    [anon_sym_alias] = ACTIONS(4138),
    [anon_sym_global] = ACTIONS(4138),
    [anon_sym_EQ] = ACTIONS(4138),
    [anon_sym_LBRACK] = ACTIONS(4140),
    [anon_sym_LPAREN] = ACTIONS(4140),
    [anon_sym_LBRACE] = ACTIONS(4140),
    [anon_sym_file] = ACTIONS(4138),
    [anon_sym_LT] = ACTIONS(4142),
    [anon_sym_GT] = ACTIONS(4138),
    [anon_sym_where] = ACTIONS(4138),
    [anon_sym_QMARK] = ACTIONS(4138),
    [anon_sym_notnull] = ACTIONS(4138),
    [anon_sym_unmanaged] = ACTIONS(4138),
    [anon_sym_BANG] = ACTIONS(4138),
    [anon_sym_PLUS_PLUS] = ACTIONS(4140),
    [anon_sym_DASH_DASH] = ACTIONS(4140),
    [anon_sym_PLUS] = ACTIONS(4138),
    [anon_sym_DASH] = ACTIONS(4138),
    [anon_sym_STAR] = ACTIONS(4138),
    [anon_sym_SLASH] = ACTIONS(4138),
    [anon_sym_PERCENT] = ACTIONS(4138),
    [anon_sym_CARET] = ACTIONS(4138),
    [anon_sym_PIPE] = ACTIONS(4138),
    [anon_sym_AMP] = ACTIONS(4138),
    [anon_sym_LT_LT] = ACTIONS(4138),
    [anon_sym_GT_GT] = ACTIONS(4138),
    [anon_sym_GT_GT_GT] = ACTIONS(4138),
    [anon_sym_EQ_EQ] = ACTIONS(4140),
    [anon_sym_BANG_EQ] = ACTIONS(4140),
    [anon_sym_GT_EQ] = ACTIONS(4140),
    [anon_sym_LT_EQ] = ACTIONS(4140),
    [anon_sym_DOT] = ACTIONS(4138),
    [anon_sym_scoped] = ACTIONS(4138),
    [anon_sym_EQ_GT] = ACTIONS(4140),
    [anon_sym_COLON_COLON] = ACTIONS(4155),
    [anon_sym_var] = ACTIONS(4138),
    [anon_sym_yield] = ACTIONS(4138),
    [anon_sym_switch] = ACTIONS(4138),
    [anon_sym_when] = ACTIONS(4138),
    [sym_discard] = ACTIONS(4138),
    [anon_sym_DOT_DOT] = ACTIONS(4140),
    [anon_sym_and] = ACTIONS(4138),
    [anon_sym_or] = ACTIONS(4138),
    [anon_sym_PLUS_EQ] = ACTIONS(4140),
    [anon_sym_DASH_EQ] = ACTIONS(4140),
    [anon_sym_STAR_EQ] = ACTIONS(4140),
    [anon_sym_SLASH_EQ] = ACTIONS(4140),
    [anon_sym_PERCENT_EQ] = ACTIONS(4140),
    [anon_sym_AMP_EQ] = ACTIONS(4140),
    [anon_sym_CARET_EQ] = ACTIONS(4140),
    [anon_sym_PIPE_EQ] = ACTIONS(4140),
    [anon_sym_LT_LT_EQ] = ACTIONS(4140),
    [anon_sym_GT_GT_EQ] = ACTIONS(4140),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4140),
    [anon_sym_AMP_AMP] = ACTIONS(4140),
    [anon_sym_PIPE_PIPE] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK] = ACTIONS(4138),
    [anon_sym_from] = ACTIONS(4138),
    [anon_sym_into] = ACTIONS(4138),
    [anon_sym_join] = ACTIONS(4138),
    [anon_sym_on] = ACTIONS(4138),
    [anon_sym_equals] = ACTIONS(4138),
    [anon_sym_let] = ACTIONS(4138),
    [anon_sym_orderby] = ACTIONS(4138),
    [anon_sym_ascending] = ACTIONS(4138),
    [anon_sym_descending] = ACTIONS(4138),
    [anon_sym_group] = ACTIONS(4138),
    [anon_sym_by] = ACTIONS(4138),
    [anon_sym_select] = ACTIONS(4138),
    [anon_sym_as] = ACTIONS(4138),
    [anon_sym_is] = ACTIONS(4138),
    [anon_sym_DASH_GT] = ACTIONS(4140),
    [anon_sym_with] = ACTIONS(4138),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2836] = {
    [sym_preproc_region] = STATE(2836),
    [sym_preproc_endregion] = STATE(2836),
    [sym_preproc_line] = STATE(2836),
    [sym_preproc_pragma] = STATE(2836),
    [sym_preproc_nullable] = STATE(2836),
    [sym_preproc_error] = STATE(2836),
    [sym_preproc_warning] = STATE(2836),
    [sym_preproc_define] = STATE(2836),
    [sym_preproc_undef] = STATE(2836),
    [sym__identifier_token] = ACTIONS(4179),
    [anon_sym_alias] = ACTIONS(4179),
    [anon_sym_global] = ACTIONS(4179),
    [anon_sym_EQ] = ACTIONS(4183),
    [anon_sym_LBRACK] = ACTIONS(4185),
    [anon_sym_COLON] = ACTIONS(4181),
    [anon_sym_COMMA] = ACTIONS(4181),
    [anon_sym_LPAREN] = ACTIONS(4185),
    [anon_sym_LBRACE] = ACTIONS(4181),
    [anon_sym_file] = ACTIONS(4179),
    [anon_sym_LT] = ACTIONS(4188),
    [anon_sym_GT] = ACTIONS(4188),
    [anon_sym_where] = ACTIONS(4179),
    [anon_sym_QMARK] = ACTIONS(4188),
    [anon_sym_notnull] = ACTIONS(4179),
    [anon_sym_unmanaged] = ACTIONS(4179),
    [anon_sym_BANG] = ACTIONS(4188),
    [anon_sym_PLUS_PLUS] = ACTIONS(4185),
    [anon_sym_DASH_DASH] = ACTIONS(4185),
    [anon_sym_PLUS] = ACTIONS(4188),
    [anon_sym_DASH] = ACTIONS(4188),
    [anon_sym_STAR] = ACTIONS(4188),
    [anon_sym_SLASH] = ACTIONS(4188),
    [anon_sym_PERCENT] = ACTIONS(4188),
    [anon_sym_CARET] = ACTIONS(4188),
    [anon_sym_PIPE] = ACTIONS(4188),
    [anon_sym_AMP] = ACTIONS(4188),
    [anon_sym_LT_LT] = ACTIONS(4188),
    [anon_sym_GT_GT] = ACTIONS(4188),
    [anon_sym_GT_GT_GT] = ACTIONS(4188),
    [anon_sym_EQ_EQ] = ACTIONS(4185),
    [anon_sym_BANG_EQ] = ACTIONS(4185),
    [anon_sym_GT_EQ] = ACTIONS(4185),
    [anon_sym_LT_EQ] = ACTIONS(4185),
    [anon_sym_DOT] = ACTIONS(4188),
    [anon_sym_scoped] = ACTIONS(4179),
    [anon_sym_var] = ACTIONS(4179),
    [anon_sym_yield] = ACTIONS(4179),
    [anon_sym_switch] = ACTIONS(4188),
    [anon_sym_when] = ACTIONS(4179),
    [sym_discard] = ACTIONS(4179),
    [anon_sym_DOT_DOT] = ACTIONS(4185),
    [anon_sym_and] = ACTIONS(4179),
    [anon_sym_or] = ACTIONS(4179),
    [anon_sym_PLUS_EQ] = ACTIONS(4191),
    [anon_sym_DASH_EQ] = ACTIONS(4191),
    [anon_sym_STAR_EQ] = ACTIONS(4191),
    [anon_sym_SLASH_EQ] = ACTIONS(4191),
    [anon_sym_PERCENT_EQ] = ACTIONS(4191),
    [anon_sym_AMP_EQ] = ACTIONS(4191),
    [anon_sym_CARET_EQ] = ACTIONS(4191),
    [anon_sym_PIPE_EQ] = ACTIONS(4191),
    [anon_sym_LT_LT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4191),
    [anon_sym_AMP_AMP] = ACTIONS(4185),
    [anon_sym_PIPE_PIPE] = ACTIONS(4185),
    [anon_sym_QMARK_QMARK] = ACTIONS(4188),
    [anon_sym_from] = ACTIONS(4179),
    [anon_sym_into] = ACTIONS(4179),
    [anon_sym_join] = ACTIONS(4179),
    [anon_sym_on] = ACTIONS(4179),
    [anon_sym_equals] = ACTIONS(4179),
    [anon_sym_let] = ACTIONS(4179),
    [anon_sym_orderby] = ACTIONS(4179),
    [anon_sym_ascending] = ACTIONS(4179),
    [anon_sym_descending] = ACTIONS(4179),
    [anon_sym_group] = ACTIONS(4179),
    [anon_sym_by] = ACTIONS(4179),
    [anon_sym_select] = ACTIONS(4179),
    [anon_sym_as] = ACTIONS(4188),
    [anon_sym_is] = ACTIONS(4188),
    [anon_sym_DASH_GT] = ACTIONS(4185),
    [anon_sym_with] = ACTIONS(4188),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4181),
  },
  [2837] = {
    [sym_preproc_region] = STATE(2837),
    [sym_preproc_endregion] = STATE(2837),
    [sym_preproc_line] = STATE(2837),
    [sym_preproc_pragma] = STATE(2837),
    [sym_preproc_nullable] = STATE(2837),
    [sym_preproc_error] = STATE(2837),
    [sym_preproc_warning] = STATE(2837),
    [sym_preproc_define] = STATE(2837),
    [sym_preproc_undef] = STATE(2837),
    [sym__identifier_token] = ACTIONS(4179),
    [anon_sym_alias] = ACTIONS(4179),
    [anon_sym_global] = ACTIONS(4179),
    [anon_sym_EQ] = ACTIONS(4183),
    [anon_sym_LBRACK] = ACTIONS(4185),
    [anon_sym_COLON] = ACTIONS(4185),
    [anon_sym_COMMA] = ACTIONS(4185),
    [anon_sym_LPAREN] = ACTIONS(4185),
    [anon_sym_LBRACE] = ACTIONS(4181),
    [anon_sym_file] = ACTIONS(4179),
    [anon_sym_LT] = ACTIONS(4188),
    [anon_sym_GT] = ACTIONS(4188),
    [anon_sym_where] = ACTIONS(4179),
    [anon_sym_QMARK] = ACTIONS(4188),
    [anon_sym_notnull] = ACTIONS(4179),
    [anon_sym_unmanaged] = ACTIONS(4179),
    [anon_sym_BANG] = ACTIONS(4188),
    [anon_sym_PLUS_PLUS] = ACTIONS(4185),
    [anon_sym_DASH_DASH] = ACTIONS(4185),
    [anon_sym_PLUS] = ACTIONS(4188),
    [anon_sym_DASH] = ACTIONS(4188),
    [anon_sym_STAR] = ACTIONS(4188),
    [anon_sym_SLASH] = ACTIONS(4188),
    [anon_sym_PERCENT] = ACTIONS(4188),
    [anon_sym_CARET] = ACTIONS(4188),
    [anon_sym_PIPE] = ACTIONS(4188),
    [anon_sym_AMP] = ACTIONS(4188),
    [anon_sym_LT_LT] = ACTIONS(4188),
    [anon_sym_GT_GT] = ACTIONS(4188),
    [anon_sym_GT_GT_GT] = ACTIONS(4188),
    [anon_sym_EQ_EQ] = ACTIONS(4185),
    [anon_sym_BANG_EQ] = ACTIONS(4185),
    [anon_sym_GT_EQ] = ACTIONS(4185),
    [anon_sym_LT_EQ] = ACTIONS(4185),
    [anon_sym_DOT] = ACTIONS(4188),
    [anon_sym_scoped] = ACTIONS(4179),
    [anon_sym_var] = ACTIONS(4179),
    [anon_sym_yield] = ACTIONS(4179),
    [anon_sym_switch] = ACTIONS(4188),
    [anon_sym_when] = ACTIONS(4179),
    [sym_discard] = ACTIONS(4179),
    [anon_sym_DOT_DOT] = ACTIONS(4185),
    [anon_sym_and] = ACTIONS(4188),
    [anon_sym_or] = ACTIONS(4188),
    [anon_sym_PLUS_EQ] = ACTIONS(4191),
    [anon_sym_DASH_EQ] = ACTIONS(4191),
    [anon_sym_STAR_EQ] = ACTIONS(4191),
    [anon_sym_SLASH_EQ] = ACTIONS(4191),
    [anon_sym_PERCENT_EQ] = ACTIONS(4191),
    [anon_sym_AMP_EQ] = ACTIONS(4191),
    [anon_sym_CARET_EQ] = ACTIONS(4191),
    [anon_sym_PIPE_EQ] = ACTIONS(4191),
    [anon_sym_LT_LT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4191),
    [anon_sym_AMP_AMP] = ACTIONS(4185),
    [anon_sym_PIPE_PIPE] = ACTIONS(4185),
    [anon_sym_QMARK_QMARK] = ACTIONS(4188),
    [anon_sym_from] = ACTIONS(4179),
    [anon_sym_into] = ACTIONS(4188),
    [anon_sym_join] = ACTIONS(4179),
    [anon_sym_on] = ACTIONS(4179),
    [anon_sym_equals] = ACTIONS(4179),
    [anon_sym_let] = ACTIONS(4179),
    [anon_sym_orderby] = ACTIONS(4179),
    [anon_sym_ascending] = ACTIONS(4179),
    [anon_sym_descending] = ACTIONS(4179),
    [anon_sym_group] = ACTIONS(4179),
    [anon_sym_by] = ACTIONS(4179),
    [anon_sym_select] = ACTIONS(4179),
    [anon_sym_as] = ACTIONS(4188),
    [anon_sym_is] = ACTIONS(4188),
    [anon_sym_DASH_GT] = ACTIONS(4185),
    [anon_sym_with] = ACTIONS(4188),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4185),
  },
  [2838] = {
    [sym_preproc_region] = STATE(2838),
    [sym_preproc_endregion] = STATE(2838),
    [sym_preproc_line] = STATE(2838),
    [sym_preproc_pragma] = STATE(2838),
    [sym_preproc_nullable] = STATE(2838),
    [sym_preproc_error] = STATE(2838),
    [sym_preproc_warning] = STATE(2838),
    [sym_preproc_define] = STATE(2838),
    [sym_preproc_undef] = STATE(2838),
    [sym__identifier_token] = ACTIONS(4157),
    [anon_sym_alias] = ACTIONS(4157),
    [anon_sym_global] = ACTIONS(4157),
    [anon_sym_EQ] = ACTIONS(4162),
    [anon_sym_LBRACK] = ACTIONS(4193),
    [anon_sym_COLON] = ACTIONS(4177),
    [anon_sym_COMMA] = ACTIONS(4193),
    [anon_sym_LPAREN] = ACTIONS(4193),
    [anon_sym_RPAREN] = ACTIONS(4193),
    [anon_sym_LBRACE] = ACTIONS(4168),
    [anon_sym_file] = ACTIONS(4157),
    [anon_sym_LT] = ACTIONS(4162),
    [anon_sym_GT] = ACTIONS(4162),
    [anon_sym_where] = ACTIONS(4157),
    [anon_sym_QMARK] = ACTIONS(4196),
    [anon_sym_notnull] = ACTIONS(4157),
    [anon_sym_unmanaged] = ACTIONS(4157),
    [anon_sym_BANG] = ACTIONS(4162),
    [anon_sym_PLUS_PLUS] = ACTIONS(4177),
    [anon_sym_DASH_DASH] = ACTIONS(4177),
    [anon_sym_PLUS] = ACTIONS(4162),
    [anon_sym_DASH] = ACTIONS(4162),
    [anon_sym_STAR] = ACTIONS(4196),
    [anon_sym_SLASH] = ACTIONS(4162),
    [anon_sym_PERCENT] = ACTIONS(4162),
    [anon_sym_CARET] = ACTIONS(4162),
    [anon_sym_PIPE] = ACTIONS(4162),
    [anon_sym_AMP] = ACTIONS(4162),
    [anon_sym_LT_LT] = ACTIONS(4162),
    [anon_sym_GT_GT] = ACTIONS(4162),
    [anon_sym_GT_GT_GT] = ACTIONS(4162),
    [anon_sym_EQ_EQ] = ACTIONS(4177),
    [anon_sym_BANG_EQ] = ACTIONS(4177),
    [anon_sym_GT_EQ] = ACTIONS(4177),
    [anon_sym_LT_EQ] = ACTIONS(4177),
    [anon_sym_DOT] = ACTIONS(4196),
    [anon_sym_scoped] = ACTIONS(4157),
    [anon_sym_var] = ACTIONS(4157),
    [anon_sym_yield] = ACTIONS(4157),
    [anon_sym_switch] = ACTIONS(4162),
    [anon_sym_when] = ACTIONS(4157),
    [sym_discard] = ACTIONS(4157),
    [anon_sym_DOT_DOT] = ACTIONS(4177),
    [anon_sym_and] = ACTIONS(4157),
    [anon_sym_or] = ACTIONS(4157),
    [anon_sym_PLUS_EQ] = ACTIONS(4177),
    [anon_sym_DASH_EQ] = ACTIONS(4177),
    [anon_sym_STAR_EQ] = ACTIONS(4177),
    [anon_sym_SLASH_EQ] = ACTIONS(4177),
    [anon_sym_PERCENT_EQ] = ACTIONS(4177),
    [anon_sym_AMP_EQ] = ACTIONS(4177),
    [anon_sym_CARET_EQ] = ACTIONS(4177),
    [anon_sym_PIPE_EQ] = ACTIONS(4177),
    [anon_sym_LT_LT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4177),
    [anon_sym_AMP_AMP] = ACTIONS(4177),
    [anon_sym_PIPE_PIPE] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK] = ACTIONS(4162),
    [anon_sym_from] = ACTIONS(4157),
    [anon_sym_into] = ACTIONS(4157),
    [anon_sym_join] = ACTIONS(4157),
    [anon_sym_on] = ACTIONS(4157),
    [anon_sym_equals] = ACTIONS(4157),
    [anon_sym_let] = ACTIONS(4157),
    [anon_sym_orderby] = ACTIONS(4157),
    [anon_sym_ascending] = ACTIONS(4157),
    [anon_sym_descending] = ACTIONS(4157),
    [anon_sym_group] = ACTIONS(4157),
    [anon_sym_by] = ACTIONS(4157),
    [anon_sym_select] = ACTIONS(4157),
    [anon_sym_as] = ACTIONS(4162),
    [anon_sym_is] = ACTIONS(4162),
    [anon_sym_DASH_GT] = ACTIONS(4193),
    [anon_sym_with] = ACTIONS(4162),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2839] = {
    [sym_preproc_region] = STATE(2839),
    [sym_preproc_endregion] = STATE(2839),
    [sym_preproc_line] = STATE(2839),
    [sym_preproc_pragma] = STATE(2839),
    [sym_preproc_nullable] = STATE(2839),
    [sym_preproc_error] = STATE(2839),
    [sym_preproc_warning] = STATE(2839),
    [sym_preproc_define] = STATE(2839),
    [sym_preproc_undef] = STATE(2839),
    [sym__identifier_token] = ACTIONS(4134),
    [anon_sym_alias] = ACTIONS(4134),
    [anon_sym_global] = ACTIONS(4134),
    [anon_sym_EQ] = ACTIONS(4134),
    [anon_sym_LBRACK] = ACTIONS(4136),
    [anon_sym_COLON] = ACTIONS(4136),
    [anon_sym_COMMA] = ACTIONS(4136),
    [anon_sym_LPAREN] = ACTIONS(4136),
    [anon_sym_LBRACE] = ACTIONS(4136),
    [anon_sym_file] = ACTIONS(4134),
    [anon_sym_LT] = ACTIONS(4134),
    [anon_sym_GT] = ACTIONS(4134),
    [anon_sym_where] = ACTIONS(4134),
    [anon_sym_QMARK] = ACTIONS(4134),
    [anon_sym_notnull] = ACTIONS(4134),
    [anon_sym_unmanaged] = ACTIONS(4134),
    [anon_sym_BANG] = ACTIONS(4134),
    [anon_sym_PLUS_PLUS] = ACTIONS(4136),
    [anon_sym_DASH_DASH] = ACTIONS(4136),
    [anon_sym_PLUS] = ACTIONS(4134),
    [anon_sym_DASH] = ACTIONS(4134),
    [anon_sym_STAR] = ACTIONS(4134),
    [anon_sym_SLASH] = ACTIONS(4134),
    [anon_sym_PERCENT] = ACTIONS(4134),
    [anon_sym_CARET] = ACTIONS(4134),
    [anon_sym_PIPE] = ACTIONS(4134),
    [anon_sym_AMP] = ACTIONS(4134),
    [anon_sym_LT_LT] = ACTIONS(4134),
    [anon_sym_GT_GT] = ACTIONS(4134),
    [anon_sym_GT_GT_GT] = ACTIONS(4134),
    [anon_sym_EQ_EQ] = ACTIONS(4136),
    [anon_sym_BANG_EQ] = ACTIONS(4136),
    [anon_sym_GT_EQ] = ACTIONS(4136),
    [anon_sym_LT_EQ] = ACTIONS(4136),
    [anon_sym_DOT] = ACTIONS(4134),
    [anon_sym_scoped] = ACTIONS(4134),
    [anon_sym_var] = ACTIONS(4134),
    [anon_sym_yield] = ACTIONS(4134),
    [anon_sym_switch] = ACTIONS(4134),
    [anon_sym_when] = ACTIONS(4134),
    [sym_discard] = ACTIONS(4134),
    [anon_sym_DOT_DOT] = ACTIONS(4136),
    [anon_sym_and] = ACTIONS(4134),
    [anon_sym_or] = ACTIONS(4134),
    [anon_sym_PLUS_EQ] = ACTIONS(4136),
    [anon_sym_DASH_EQ] = ACTIONS(4136),
    [anon_sym_STAR_EQ] = ACTIONS(4136),
    [anon_sym_SLASH_EQ] = ACTIONS(4136),
    [anon_sym_PERCENT_EQ] = ACTIONS(4136),
    [anon_sym_AMP_EQ] = ACTIONS(4136),
    [anon_sym_CARET_EQ] = ACTIONS(4136),
    [anon_sym_PIPE_EQ] = ACTIONS(4136),
    [anon_sym_LT_LT_EQ] = ACTIONS(4136),
    [anon_sym_GT_GT_EQ] = ACTIONS(4136),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4136),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4136),
    [anon_sym_AMP_AMP] = ACTIONS(4136),
    [anon_sym_PIPE_PIPE] = ACTIONS(4136),
    [anon_sym_QMARK_QMARK] = ACTIONS(4134),
    [anon_sym_from] = ACTIONS(4134),
    [anon_sym_into] = ACTIONS(4134),
    [anon_sym_join] = ACTIONS(4134),
    [anon_sym_on] = ACTIONS(4134),
    [anon_sym_equals] = ACTIONS(4134),
    [anon_sym_let] = ACTIONS(4134),
    [anon_sym_orderby] = ACTIONS(4134),
    [anon_sym_ascending] = ACTIONS(4134),
    [anon_sym_descending] = ACTIONS(4134),
    [anon_sym_group] = ACTIONS(4134),
    [anon_sym_by] = ACTIONS(4134),
    [anon_sym_select] = ACTIONS(4134),
    [anon_sym_as] = ACTIONS(4134),
    [anon_sym_is] = ACTIONS(4134),
    [anon_sym_DASH_GT] = ACTIONS(4136),
    [anon_sym_with] = ACTIONS(4134),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4136),
  },
  [2840] = {
    [sym_property_pattern_clause] = STATE(2869),
    [sym__variable_designation] = STATE(4035),
    [sym_parenthesized_variable_designation] = STATE(3966),
    [sym_identifier] = STATE(3983),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(2840),
    [sym_preproc_endregion] = STATE(2840),
    [sym_preproc_line] = STATE(2840),
    [sym_preproc_pragma] = STATE(2840),
    [sym_preproc_nullable] = STATE(2840),
    [sym_preproc_error] = STATE(2840),
    [sym_preproc_warning] = STATE(2840),
    [sym_preproc_define] = STATE(2840),
    [sym_preproc_undef] = STATE(2840),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_SEMI] = ACTIONS(4399),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4399),
    [anon_sym_COLON] = ACTIONS(4399),
    [anon_sym_COMMA] = ACTIONS(4399),
    [anon_sym_RBRACK] = ACTIONS(4399),
    [anon_sym_LPAREN] = ACTIONS(4399),
    [anon_sym_RPAREN] = ACTIONS(4399),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_RBRACE] = ACTIONS(4399),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4401),
    [anon_sym_GT] = ACTIONS(4401),
    [anon_sym_in] = ACTIONS(4401),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4401),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4401),
    [anon_sym_PLUS_PLUS] = ACTIONS(4399),
    [anon_sym_DASH_DASH] = ACTIONS(4399),
    [anon_sym_PLUS] = ACTIONS(4401),
    [anon_sym_DASH] = ACTIONS(4401),
    [anon_sym_STAR] = ACTIONS(4399),
    [anon_sym_SLASH] = ACTIONS(4401),
    [anon_sym_PERCENT] = ACTIONS(4399),
    [anon_sym_CARET] = ACTIONS(4399),
    [anon_sym_PIPE] = ACTIONS(4401),
    [anon_sym_AMP] = ACTIONS(4401),
    [anon_sym_LT_LT] = ACTIONS(4399),
    [anon_sym_GT_GT] = ACTIONS(4401),
    [anon_sym_GT_GT_GT] = ACTIONS(4399),
    [anon_sym_EQ_EQ] = ACTIONS(4399),
    [anon_sym_BANG_EQ] = ACTIONS(4399),
    [anon_sym_GT_EQ] = ACTIONS(4399),
    [anon_sym_LT_EQ] = ACTIONS(4399),
    [anon_sym_DOT] = ACTIONS(4401),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_EQ_GT] = ACTIONS(4399),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4401),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4347),
    [anon_sym_DOT_DOT] = ACTIONS(4399),
    [anon_sym_and] = ACTIONS(4401),
    [anon_sym_or] = ACTIONS(4401),
    [anon_sym_AMP_AMP] = ACTIONS(4399),
    [anon_sym_PIPE_PIPE] = ACTIONS(4399),
    [anon_sym_QMARK_QMARK] = ACTIONS(4399),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4401),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4401),
    [anon_sym_is] = ACTIONS(4401),
    [anon_sym_DASH_GT] = ACTIONS(4399),
    [anon_sym_with] = ACTIONS(4401),
    [aux_sym_preproc_if_token3] = ACTIONS(4399),
    [aux_sym_preproc_else_token1] = ACTIONS(4399),
    [aux_sym_preproc_elif_token1] = ACTIONS(4399),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2841] = {
    [sym_type_argument_list] = STATE(2746),
    [sym_preproc_region] = STATE(2841),
    [sym_preproc_endregion] = STATE(2841),
    [sym_preproc_line] = STATE(2841),
    [sym_preproc_pragma] = STATE(2841),
    [sym_preproc_nullable] = STATE(2841),
    [sym_preproc_error] = STATE(2841),
    [sym_preproc_warning] = STATE(2841),
    [sym_preproc_define] = STATE(2841),
    [sym_preproc_undef] = STATE(2841),
    [sym__identifier_token] = ACTIONS(4138),
    [anon_sym_alias] = ACTIONS(4138),
    [anon_sym_global] = ACTIONS(4138),
    [anon_sym_EQ] = ACTIONS(4138),
    [anon_sym_LBRACK] = ACTIONS(4140),
    [anon_sym_COLON] = ACTIONS(4403),
    [anon_sym_LPAREN] = ACTIONS(4140),
    [anon_sym_file] = ACTIONS(4138),
    [anon_sym_LT] = ACTIONS(4142),
    [anon_sym_GT] = ACTIONS(4138),
    [anon_sym_where] = ACTIONS(4138),
    [anon_sym_QMARK] = ACTIONS(4138),
    [anon_sym_notnull] = ACTIONS(4138),
    [anon_sym_unmanaged] = ACTIONS(4138),
    [anon_sym_BANG] = ACTIONS(4138),
    [anon_sym_PLUS_PLUS] = ACTIONS(4140),
    [anon_sym_DASH_DASH] = ACTIONS(4140),
    [anon_sym_PLUS] = ACTIONS(4138),
    [anon_sym_DASH] = ACTIONS(4138),
    [anon_sym_STAR] = ACTIONS(4138),
    [anon_sym_SLASH] = ACTIONS(4138),
    [anon_sym_PERCENT] = ACTIONS(4138),
    [anon_sym_CARET] = ACTIONS(4138),
    [anon_sym_PIPE] = ACTIONS(4138),
    [anon_sym_AMP] = ACTIONS(4138),
    [anon_sym_LT_LT] = ACTIONS(4138),
    [anon_sym_GT_GT] = ACTIONS(4138),
    [anon_sym_GT_GT_GT] = ACTIONS(4138),
    [anon_sym_EQ_EQ] = ACTIONS(4140),
    [anon_sym_BANG_EQ] = ACTIONS(4140),
    [anon_sym_GT_EQ] = ACTIONS(4140),
    [anon_sym_LT_EQ] = ACTIONS(4140),
    [anon_sym_DOT] = ACTIONS(4138),
    [anon_sym_scoped] = ACTIONS(4138),
    [anon_sym_EQ_GT] = ACTIONS(4145),
    [anon_sym_COLON_COLON] = ACTIONS(4147),
    [anon_sym_var] = ACTIONS(4138),
    [anon_sym_yield] = ACTIONS(4138),
    [anon_sym_switch] = ACTIONS(4138),
    [anon_sym_when] = ACTIONS(4138),
    [anon_sym_DOT_DOT] = ACTIONS(4140),
    [anon_sym_PLUS_EQ] = ACTIONS(4140),
    [anon_sym_DASH_EQ] = ACTIONS(4140),
    [anon_sym_STAR_EQ] = ACTIONS(4140),
    [anon_sym_SLASH_EQ] = ACTIONS(4140),
    [anon_sym_PERCENT_EQ] = ACTIONS(4140),
    [anon_sym_AMP_EQ] = ACTIONS(4140),
    [anon_sym_CARET_EQ] = ACTIONS(4140),
    [anon_sym_PIPE_EQ] = ACTIONS(4140),
    [anon_sym_LT_LT_EQ] = ACTIONS(4140),
    [anon_sym_GT_GT_EQ] = ACTIONS(4140),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4140),
    [anon_sym_AMP_AMP] = ACTIONS(4140),
    [anon_sym_PIPE_PIPE] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK] = ACTIONS(4138),
    [anon_sym_from] = ACTIONS(4138),
    [anon_sym_into] = ACTIONS(4138),
    [anon_sym_join] = ACTIONS(4138),
    [anon_sym_on] = ACTIONS(4138),
    [anon_sym_equals] = ACTIONS(4138),
    [anon_sym_let] = ACTIONS(4138),
    [anon_sym_orderby] = ACTIONS(4138),
    [anon_sym_ascending] = ACTIONS(4138),
    [anon_sym_descending] = ACTIONS(4138),
    [anon_sym_group] = ACTIONS(4138),
    [anon_sym_by] = ACTIONS(4138),
    [anon_sym_select] = ACTIONS(4138),
    [anon_sym_as] = ACTIONS(4138),
    [anon_sym_is] = ACTIONS(4138),
    [anon_sym_DASH_GT] = ACTIONS(4140),
    [anon_sym_with] = ACTIONS(4138),
    [aux_sym_preproc_if_token3] = ACTIONS(4140),
    [aux_sym_preproc_else_token1] = ACTIONS(4140),
    [aux_sym_preproc_elif_token1] = ACTIONS(4140),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2842] = {
    [sym_property_pattern_clause] = STATE(2871),
    [sym__variable_designation] = STATE(4088),
    [sym_parenthesized_variable_designation] = STATE(3966),
    [sym_identifier] = STATE(3983),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(2842),
    [sym_preproc_endregion] = STATE(2842),
    [sym_preproc_line] = STATE(2842),
    [sym_preproc_pragma] = STATE(2842),
    [sym_preproc_nullable] = STATE(2842),
    [sym_preproc_error] = STATE(2842),
    [sym_preproc_warning] = STATE(2842),
    [sym_preproc_define] = STATE(2842),
    [sym_preproc_undef] = STATE(2842),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_SEMI] = ACTIONS(4405),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4405),
    [anon_sym_COLON] = ACTIONS(4405),
    [anon_sym_COMMA] = ACTIONS(4405),
    [anon_sym_RBRACK] = ACTIONS(4405),
    [anon_sym_LPAREN] = ACTIONS(4405),
    [anon_sym_RPAREN] = ACTIONS(4405),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_RBRACE] = ACTIONS(4405),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4407),
    [anon_sym_GT] = ACTIONS(4407),
    [anon_sym_in] = ACTIONS(4407),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4407),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4407),
    [anon_sym_PLUS_PLUS] = ACTIONS(4405),
    [anon_sym_DASH_DASH] = ACTIONS(4405),
    [anon_sym_PLUS] = ACTIONS(4407),
    [anon_sym_DASH] = ACTIONS(4407),
    [anon_sym_STAR] = ACTIONS(4405),
    [anon_sym_SLASH] = ACTIONS(4407),
    [anon_sym_PERCENT] = ACTIONS(4405),
    [anon_sym_CARET] = ACTIONS(4405),
    [anon_sym_PIPE] = ACTIONS(4407),
    [anon_sym_AMP] = ACTIONS(4407),
    [anon_sym_LT_LT] = ACTIONS(4405),
    [anon_sym_GT_GT] = ACTIONS(4407),
    [anon_sym_GT_GT_GT] = ACTIONS(4405),
    [anon_sym_EQ_EQ] = ACTIONS(4405),
    [anon_sym_BANG_EQ] = ACTIONS(4405),
    [anon_sym_GT_EQ] = ACTIONS(4405),
    [anon_sym_LT_EQ] = ACTIONS(4405),
    [anon_sym_DOT] = ACTIONS(4407),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_EQ_GT] = ACTIONS(4405),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4407),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4347),
    [anon_sym_DOT_DOT] = ACTIONS(4405),
    [anon_sym_and] = ACTIONS(4407),
    [anon_sym_or] = ACTIONS(4407),
    [anon_sym_AMP_AMP] = ACTIONS(4405),
    [anon_sym_PIPE_PIPE] = ACTIONS(4405),
    [anon_sym_QMARK_QMARK] = ACTIONS(4405),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4407),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4407),
    [anon_sym_is] = ACTIONS(4407),
    [anon_sym_DASH_GT] = ACTIONS(4405),
    [anon_sym_with] = ACTIONS(4407),
    [aux_sym_preproc_if_token3] = ACTIONS(4405),
    [aux_sym_preproc_else_token1] = ACTIONS(4405),
    [aux_sym_preproc_elif_token1] = ACTIONS(4405),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2843] = {
    [sym_type_argument_list] = STATE(2746),
    [sym_preproc_region] = STATE(2843),
    [sym_preproc_endregion] = STATE(2843),
    [sym_preproc_line] = STATE(2843),
    [sym_preproc_pragma] = STATE(2843),
    [sym_preproc_nullable] = STATE(2843),
    [sym_preproc_error] = STATE(2843),
    [sym_preproc_warning] = STATE(2843),
    [sym_preproc_define] = STATE(2843),
    [sym_preproc_undef] = STATE(2843),
    [sym__identifier_token] = ACTIONS(4138),
    [anon_sym_alias] = ACTIONS(4138),
    [anon_sym_global] = ACTIONS(4138),
    [anon_sym_EQ] = ACTIONS(4138),
    [anon_sym_LBRACK] = ACTIONS(4140),
    [anon_sym_COLON] = ACTIONS(4409),
    [anon_sym_COMMA] = ACTIONS(4140),
    [anon_sym_LPAREN] = ACTIONS(4140),
    [anon_sym_RPAREN] = ACTIONS(4140),
    [anon_sym_file] = ACTIONS(4138),
    [anon_sym_LT] = ACTIONS(4142),
    [anon_sym_GT] = ACTIONS(4138),
    [anon_sym_where] = ACTIONS(4138),
    [anon_sym_QMARK] = ACTIONS(4138),
    [anon_sym_notnull] = ACTIONS(4138),
    [anon_sym_unmanaged] = ACTIONS(4138),
    [anon_sym_BANG] = ACTIONS(4138),
    [anon_sym_PLUS_PLUS] = ACTIONS(4140),
    [anon_sym_DASH_DASH] = ACTIONS(4140),
    [anon_sym_PLUS] = ACTIONS(4138),
    [anon_sym_DASH] = ACTIONS(4138),
    [anon_sym_STAR] = ACTIONS(4138),
    [anon_sym_SLASH] = ACTIONS(4138),
    [anon_sym_PERCENT] = ACTIONS(4138),
    [anon_sym_CARET] = ACTIONS(4138),
    [anon_sym_PIPE] = ACTIONS(4138),
    [anon_sym_AMP] = ACTIONS(4138),
    [anon_sym_LT_LT] = ACTIONS(4138),
    [anon_sym_GT_GT] = ACTIONS(4138),
    [anon_sym_GT_GT_GT] = ACTIONS(4138),
    [anon_sym_EQ_EQ] = ACTIONS(4140),
    [anon_sym_BANG_EQ] = ACTIONS(4140),
    [anon_sym_GT_EQ] = ACTIONS(4140),
    [anon_sym_LT_EQ] = ACTIONS(4140),
    [anon_sym_DOT] = ACTIONS(4138),
    [anon_sym_scoped] = ACTIONS(4138),
    [anon_sym_EQ_GT] = ACTIONS(4145),
    [anon_sym_COLON_COLON] = ACTIONS(4147),
    [anon_sym_var] = ACTIONS(4138),
    [anon_sym_yield] = ACTIONS(4138),
    [anon_sym_switch] = ACTIONS(4138),
    [anon_sym_when] = ACTIONS(4138),
    [anon_sym_DOT_DOT] = ACTIONS(4140),
    [anon_sym_PLUS_EQ] = ACTIONS(4140),
    [anon_sym_DASH_EQ] = ACTIONS(4140),
    [anon_sym_STAR_EQ] = ACTIONS(4140),
    [anon_sym_SLASH_EQ] = ACTIONS(4140),
    [anon_sym_PERCENT_EQ] = ACTIONS(4140),
    [anon_sym_AMP_EQ] = ACTIONS(4140),
    [anon_sym_CARET_EQ] = ACTIONS(4140),
    [anon_sym_PIPE_EQ] = ACTIONS(4140),
    [anon_sym_LT_LT_EQ] = ACTIONS(4140),
    [anon_sym_GT_GT_EQ] = ACTIONS(4140),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4140),
    [anon_sym_AMP_AMP] = ACTIONS(4140),
    [anon_sym_PIPE_PIPE] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK] = ACTIONS(4138),
    [anon_sym_from] = ACTIONS(4138),
    [anon_sym_into] = ACTIONS(4138),
    [anon_sym_join] = ACTIONS(4138),
    [anon_sym_on] = ACTIONS(4138),
    [anon_sym_equals] = ACTIONS(4138),
    [anon_sym_let] = ACTIONS(4138),
    [anon_sym_orderby] = ACTIONS(4138),
    [anon_sym_ascending] = ACTIONS(4138),
    [anon_sym_descending] = ACTIONS(4138),
    [anon_sym_group] = ACTIONS(4138),
    [anon_sym_by] = ACTIONS(4138),
    [anon_sym_select] = ACTIONS(4138),
    [anon_sym_as] = ACTIONS(4138),
    [anon_sym_is] = ACTIONS(4138),
    [anon_sym_DASH_GT] = ACTIONS(4140),
    [anon_sym_with] = ACTIONS(4138),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2844] = {
    [sym_preproc_region] = STATE(2844),
    [sym_preproc_endregion] = STATE(2844),
    [sym_preproc_line] = STATE(2844),
    [sym_preproc_pragma] = STATE(2844),
    [sym_preproc_nullable] = STATE(2844),
    [sym_preproc_error] = STATE(2844),
    [sym_preproc_warning] = STATE(2844),
    [sym_preproc_define] = STATE(2844),
    [sym_preproc_undef] = STATE(2844),
    [sym__identifier_token] = ACTIONS(4157),
    [anon_sym_alias] = ACTIONS(4157),
    [anon_sym_global] = ACTIONS(4157),
    [anon_sym_EQ] = ACTIONS(4162),
    [anon_sym_LBRACK] = ACTIONS(4193),
    [anon_sym_COLON] = ACTIONS(4164),
    [anon_sym_LPAREN] = ACTIONS(4193),
    [anon_sym_LBRACE] = ACTIONS(4168),
    [anon_sym_file] = ACTIONS(4157),
    [anon_sym_LT] = ACTIONS(4162),
    [anon_sym_GT] = ACTIONS(4162),
    [anon_sym_where] = ACTIONS(4157),
    [anon_sym_QMARK] = ACTIONS(4196),
    [anon_sym_notnull] = ACTIONS(4157),
    [anon_sym_unmanaged] = ACTIONS(4157),
    [anon_sym_BANG] = ACTIONS(4162),
    [anon_sym_PLUS_PLUS] = ACTIONS(4177),
    [anon_sym_DASH_DASH] = ACTIONS(4177),
    [anon_sym_PLUS] = ACTIONS(4162),
    [anon_sym_DASH] = ACTIONS(4162),
    [anon_sym_STAR] = ACTIONS(4196),
    [anon_sym_SLASH] = ACTIONS(4162),
    [anon_sym_PERCENT] = ACTIONS(4162),
    [anon_sym_CARET] = ACTIONS(4162),
    [anon_sym_PIPE] = ACTIONS(4162),
    [anon_sym_AMP] = ACTIONS(4162),
    [anon_sym_LT_LT] = ACTIONS(4162),
    [anon_sym_GT_GT] = ACTIONS(4162),
    [anon_sym_GT_GT_GT] = ACTIONS(4162),
    [anon_sym_EQ_EQ] = ACTIONS(4177),
    [anon_sym_BANG_EQ] = ACTIONS(4177),
    [anon_sym_GT_EQ] = ACTIONS(4177),
    [anon_sym_LT_EQ] = ACTIONS(4177),
    [anon_sym_DOT] = ACTIONS(4196),
    [anon_sym_scoped] = ACTIONS(4157),
    [anon_sym_EQ_GT] = ACTIONS(4159),
    [anon_sym_var] = ACTIONS(4157),
    [anon_sym_yield] = ACTIONS(4157),
    [anon_sym_switch] = ACTIONS(4162),
    [anon_sym_when] = ACTIONS(4174),
    [sym_discard] = ACTIONS(4157),
    [anon_sym_DOT_DOT] = ACTIONS(4177),
    [anon_sym_and] = ACTIONS(4174),
    [anon_sym_or] = ACTIONS(4174),
    [anon_sym_PLUS_EQ] = ACTIONS(4177),
    [anon_sym_DASH_EQ] = ACTIONS(4177),
    [anon_sym_STAR_EQ] = ACTIONS(4177),
    [anon_sym_SLASH_EQ] = ACTIONS(4177),
    [anon_sym_PERCENT_EQ] = ACTIONS(4177),
    [anon_sym_AMP_EQ] = ACTIONS(4177),
    [anon_sym_CARET_EQ] = ACTIONS(4177),
    [anon_sym_PIPE_EQ] = ACTIONS(4177),
    [anon_sym_LT_LT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4177),
    [anon_sym_AMP_AMP] = ACTIONS(4177),
    [anon_sym_PIPE_PIPE] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK] = ACTIONS(4162),
    [anon_sym_from] = ACTIONS(4157),
    [anon_sym_into] = ACTIONS(4157),
    [anon_sym_join] = ACTIONS(4157),
    [anon_sym_on] = ACTIONS(4157),
    [anon_sym_equals] = ACTIONS(4157),
    [anon_sym_let] = ACTIONS(4157),
    [anon_sym_orderby] = ACTIONS(4157),
    [anon_sym_ascending] = ACTIONS(4157),
    [anon_sym_descending] = ACTIONS(4157),
    [anon_sym_group] = ACTIONS(4157),
    [anon_sym_by] = ACTIONS(4157),
    [anon_sym_select] = ACTIONS(4157),
    [anon_sym_as] = ACTIONS(4162),
    [anon_sym_is] = ACTIONS(4162),
    [anon_sym_DASH_GT] = ACTIONS(4193),
    [anon_sym_with] = ACTIONS(4162),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2845] = {
    [sym_preproc_region] = STATE(2845),
    [sym_preproc_endregion] = STATE(2845),
    [sym_preproc_line] = STATE(2845),
    [sym_preproc_pragma] = STATE(2845),
    [sym_preproc_nullable] = STATE(2845),
    [sym_preproc_error] = STATE(2845),
    [sym_preproc_warning] = STATE(2845),
    [sym_preproc_define] = STATE(2845),
    [sym_preproc_undef] = STATE(2845),
    [sym__identifier_token] = ACTIONS(4091),
    [anon_sym_alias] = ACTIONS(4091),
    [anon_sym_global] = ACTIONS(4091),
    [anon_sym_EQ] = ACTIONS(3995),
    [anon_sym_LBRACK] = ACTIONS(4088),
    [anon_sym_LPAREN] = ACTIONS(4088),
    [anon_sym_LBRACE] = ACTIONS(4088),
    [anon_sym_file] = ACTIONS(4091),
    [anon_sym_LT] = ACTIONS(4091),
    [anon_sym_GT] = ACTIONS(4091),
    [anon_sym_where] = ACTIONS(4091),
    [anon_sym_QMARK] = ACTIONS(4091),
    [anon_sym_notnull] = ACTIONS(4091),
    [anon_sym_unmanaged] = ACTIONS(4091),
    [anon_sym_BANG] = ACTIONS(4091),
    [anon_sym_PLUS_PLUS] = ACTIONS(4088),
    [anon_sym_DASH_DASH] = ACTIONS(4088),
    [anon_sym_PLUS] = ACTIONS(4091),
    [anon_sym_DASH] = ACTIONS(4091),
    [anon_sym_STAR] = ACTIONS(4091),
    [anon_sym_SLASH] = ACTIONS(4091),
    [anon_sym_PERCENT] = ACTIONS(4091),
    [anon_sym_CARET] = ACTIONS(4091),
    [anon_sym_PIPE] = ACTIONS(4091),
    [anon_sym_AMP] = ACTIONS(4091),
    [anon_sym_LT_LT] = ACTIONS(4091),
    [anon_sym_GT_GT] = ACTIONS(4091),
    [anon_sym_GT_GT_GT] = ACTIONS(4091),
    [anon_sym_EQ_EQ] = ACTIONS(4088),
    [anon_sym_BANG_EQ] = ACTIONS(4088),
    [anon_sym_GT_EQ] = ACTIONS(4088),
    [anon_sym_LT_EQ] = ACTIONS(4088),
    [anon_sym_DOT] = ACTIONS(4091),
    [anon_sym_scoped] = ACTIONS(4091),
    [anon_sym_EQ_GT] = ACTIONS(4088),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(4091),
    [anon_sym_yield] = ACTIONS(4091),
    [anon_sym_switch] = ACTIONS(4091),
    [anon_sym_when] = ACTIONS(4091),
    [sym_discard] = ACTIONS(4091),
    [anon_sym_DOT_DOT] = ACTIONS(4088),
    [anon_sym_and] = ACTIONS(4091),
    [anon_sym_or] = ACTIONS(4091),
    [anon_sym_PLUS_EQ] = ACTIONS(3993),
    [anon_sym_DASH_EQ] = ACTIONS(3993),
    [anon_sym_STAR_EQ] = ACTIONS(3993),
    [anon_sym_SLASH_EQ] = ACTIONS(3993),
    [anon_sym_PERCENT_EQ] = ACTIONS(3993),
    [anon_sym_AMP_EQ] = ACTIONS(3993),
    [anon_sym_CARET_EQ] = ACTIONS(3993),
    [anon_sym_PIPE_EQ] = ACTIONS(3993),
    [anon_sym_LT_LT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(3993),
    [anon_sym_AMP_AMP] = ACTIONS(4088),
    [anon_sym_PIPE_PIPE] = ACTIONS(4088),
    [anon_sym_QMARK_QMARK] = ACTIONS(4091),
    [anon_sym_from] = ACTIONS(4091),
    [anon_sym_into] = ACTIONS(4091),
    [anon_sym_join] = ACTIONS(4091),
    [anon_sym_on] = ACTIONS(4091),
    [anon_sym_equals] = ACTIONS(4091),
    [anon_sym_let] = ACTIONS(4091),
    [anon_sym_orderby] = ACTIONS(4091),
    [anon_sym_ascending] = ACTIONS(4091),
    [anon_sym_descending] = ACTIONS(4091),
    [anon_sym_group] = ACTIONS(4091),
    [anon_sym_by] = ACTIONS(4091),
    [anon_sym_select] = ACTIONS(4091),
    [anon_sym_as] = ACTIONS(4091),
    [anon_sym_is] = ACTIONS(4091),
    [anon_sym_DASH_GT] = ACTIONS(4088),
    [anon_sym_with] = ACTIONS(4091),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2846] = {
    [sym_preproc_region] = STATE(2846),
    [sym_preproc_endregion] = STATE(2846),
    [sym_preproc_line] = STATE(2846),
    [sym_preproc_pragma] = STATE(2846),
    [sym_preproc_nullable] = STATE(2846),
    [sym_preproc_error] = STATE(2846),
    [sym_preproc_warning] = STATE(2846),
    [sym_preproc_define] = STATE(2846),
    [sym_preproc_undef] = STATE(2846),
    [sym__identifier_token] = ACTIONS(4157),
    [anon_sym_alias] = ACTIONS(4157),
    [anon_sym_global] = ACTIONS(4157),
    [anon_sym_EQ] = ACTIONS(4162),
    [anon_sym_LBRACK] = ACTIONS(4164),
    [anon_sym_COLON] = ACTIONS(4159),
    [anon_sym_LPAREN] = ACTIONS(4164),
    [anon_sym_LBRACE] = ACTIONS(4168),
    [anon_sym_file] = ACTIONS(4157),
    [anon_sym_LT] = ACTIONS(4170),
    [anon_sym_GT] = ACTIONS(4170),
    [anon_sym_where] = ACTIONS(4157),
    [anon_sym_QMARK] = ACTIONS(4170),
    [anon_sym_notnull] = ACTIONS(4157),
    [anon_sym_unmanaged] = ACTIONS(4157),
    [anon_sym_BANG] = ACTIONS(4170),
    [anon_sym_PLUS_PLUS] = ACTIONS(4164),
    [anon_sym_DASH_DASH] = ACTIONS(4164),
    [anon_sym_PLUS] = ACTIONS(4170),
    [anon_sym_DASH] = ACTIONS(4170),
    [anon_sym_STAR] = ACTIONS(4170),
    [anon_sym_SLASH] = ACTIONS(4170),
    [anon_sym_PERCENT] = ACTIONS(4170),
    [anon_sym_CARET] = ACTIONS(4170),
    [anon_sym_PIPE] = ACTIONS(4170),
    [anon_sym_AMP] = ACTIONS(4170),
    [anon_sym_LT_LT] = ACTIONS(4170),
    [anon_sym_GT_GT] = ACTIONS(4170),
    [anon_sym_GT_GT_GT] = ACTIONS(4170),
    [anon_sym_EQ_EQ] = ACTIONS(4164),
    [anon_sym_BANG_EQ] = ACTIONS(4164),
    [anon_sym_GT_EQ] = ACTIONS(4164),
    [anon_sym_LT_EQ] = ACTIONS(4164),
    [anon_sym_DOT] = ACTIONS(4170),
    [anon_sym_scoped] = ACTIONS(4157),
    [anon_sym_EQ_GT] = ACTIONS(4159),
    [anon_sym_var] = ACTIONS(4157),
    [anon_sym_yield] = ACTIONS(4157),
    [anon_sym_switch] = ACTIONS(4170),
    [anon_sym_when] = ACTIONS(4174),
    [sym_discard] = ACTIONS(4157),
    [anon_sym_DOT_DOT] = ACTIONS(4164),
    [anon_sym_and] = ACTIONS(4174),
    [anon_sym_or] = ACTIONS(4174),
    [anon_sym_PLUS_EQ] = ACTIONS(4177),
    [anon_sym_DASH_EQ] = ACTIONS(4177),
    [anon_sym_STAR_EQ] = ACTIONS(4177),
    [anon_sym_SLASH_EQ] = ACTIONS(4177),
    [anon_sym_PERCENT_EQ] = ACTIONS(4177),
    [anon_sym_AMP_EQ] = ACTIONS(4177),
    [anon_sym_CARET_EQ] = ACTIONS(4177),
    [anon_sym_PIPE_EQ] = ACTIONS(4177),
    [anon_sym_LT_LT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4177),
    [anon_sym_AMP_AMP] = ACTIONS(4164),
    [anon_sym_PIPE_PIPE] = ACTIONS(4164),
    [anon_sym_QMARK_QMARK] = ACTIONS(4170),
    [anon_sym_from] = ACTIONS(4157),
    [anon_sym_into] = ACTIONS(4174),
    [anon_sym_join] = ACTIONS(4157),
    [anon_sym_on] = ACTIONS(4157),
    [anon_sym_equals] = ACTIONS(4157),
    [anon_sym_let] = ACTIONS(4157),
    [anon_sym_orderby] = ACTIONS(4157),
    [anon_sym_ascending] = ACTIONS(4157),
    [anon_sym_descending] = ACTIONS(4157),
    [anon_sym_group] = ACTIONS(4157),
    [anon_sym_by] = ACTIONS(4157),
    [anon_sym_select] = ACTIONS(4157),
    [anon_sym_as] = ACTIONS(4170),
    [anon_sym_is] = ACTIONS(4170),
    [anon_sym_DASH_GT] = ACTIONS(4164),
    [anon_sym_with] = ACTIONS(4170),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2847] = {
    [sym_type_argument_list] = STATE(2746),
    [sym_preproc_region] = STATE(2847),
    [sym_preproc_endregion] = STATE(2847),
    [sym_preproc_line] = STATE(2847),
    [sym_preproc_pragma] = STATE(2847),
    [sym_preproc_nullable] = STATE(2847),
    [sym_preproc_error] = STATE(2847),
    [sym_preproc_warning] = STATE(2847),
    [sym_preproc_define] = STATE(2847),
    [sym_preproc_undef] = STATE(2847),
    [sym__identifier_token] = ACTIONS(4138),
    [anon_sym_alias] = ACTIONS(4138),
    [anon_sym_global] = ACTIONS(4138),
    [anon_sym_EQ] = ACTIONS(4138),
    [anon_sym_LBRACK] = ACTIONS(4140),
    [anon_sym_COLON] = ACTIONS(4411),
    [anon_sym_COMMA] = ACTIONS(4140),
    [anon_sym_LPAREN] = ACTIONS(4140),
    [anon_sym_RBRACE] = ACTIONS(4140),
    [anon_sym_file] = ACTIONS(4138),
    [anon_sym_LT] = ACTIONS(4142),
    [anon_sym_GT] = ACTIONS(4138),
    [anon_sym_where] = ACTIONS(4138),
    [anon_sym_QMARK] = ACTIONS(4138),
    [anon_sym_notnull] = ACTIONS(4138),
    [anon_sym_unmanaged] = ACTIONS(4138),
    [anon_sym_BANG] = ACTIONS(4138),
    [anon_sym_PLUS_PLUS] = ACTIONS(4140),
    [anon_sym_DASH_DASH] = ACTIONS(4140),
    [anon_sym_PLUS] = ACTIONS(4138),
    [anon_sym_DASH] = ACTIONS(4138),
    [anon_sym_STAR] = ACTIONS(4138),
    [anon_sym_SLASH] = ACTIONS(4138),
    [anon_sym_PERCENT] = ACTIONS(4138),
    [anon_sym_CARET] = ACTIONS(4138),
    [anon_sym_PIPE] = ACTIONS(4138),
    [anon_sym_AMP] = ACTIONS(4138),
    [anon_sym_LT_LT] = ACTIONS(4138),
    [anon_sym_GT_GT] = ACTIONS(4138),
    [anon_sym_GT_GT_GT] = ACTIONS(4138),
    [anon_sym_EQ_EQ] = ACTIONS(4140),
    [anon_sym_BANG_EQ] = ACTIONS(4140),
    [anon_sym_GT_EQ] = ACTIONS(4140),
    [anon_sym_LT_EQ] = ACTIONS(4140),
    [anon_sym_DOT] = ACTIONS(4138),
    [anon_sym_scoped] = ACTIONS(4138),
    [anon_sym_EQ_GT] = ACTIONS(4145),
    [anon_sym_COLON_COLON] = ACTIONS(4147),
    [anon_sym_var] = ACTIONS(4138),
    [anon_sym_yield] = ACTIONS(4138),
    [anon_sym_switch] = ACTIONS(4138),
    [anon_sym_when] = ACTIONS(4138),
    [anon_sym_DOT_DOT] = ACTIONS(4140),
    [anon_sym_PLUS_EQ] = ACTIONS(4140),
    [anon_sym_DASH_EQ] = ACTIONS(4140),
    [anon_sym_STAR_EQ] = ACTIONS(4140),
    [anon_sym_SLASH_EQ] = ACTIONS(4140),
    [anon_sym_PERCENT_EQ] = ACTIONS(4140),
    [anon_sym_AMP_EQ] = ACTIONS(4140),
    [anon_sym_CARET_EQ] = ACTIONS(4140),
    [anon_sym_PIPE_EQ] = ACTIONS(4140),
    [anon_sym_LT_LT_EQ] = ACTIONS(4140),
    [anon_sym_GT_GT_EQ] = ACTIONS(4140),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4140),
    [anon_sym_AMP_AMP] = ACTIONS(4140),
    [anon_sym_PIPE_PIPE] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK] = ACTIONS(4138),
    [anon_sym_from] = ACTIONS(4138),
    [anon_sym_into] = ACTIONS(4138),
    [anon_sym_join] = ACTIONS(4138),
    [anon_sym_on] = ACTIONS(4138),
    [anon_sym_equals] = ACTIONS(4138),
    [anon_sym_let] = ACTIONS(4138),
    [anon_sym_orderby] = ACTIONS(4138),
    [anon_sym_ascending] = ACTIONS(4138),
    [anon_sym_descending] = ACTIONS(4138),
    [anon_sym_group] = ACTIONS(4138),
    [anon_sym_by] = ACTIONS(4138),
    [anon_sym_select] = ACTIONS(4138),
    [anon_sym_as] = ACTIONS(4138),
    [anon_sym_is] = ACTIONS(4138),
    [anon_sym_DASH_GT] = ACTIONS(4140),
    [anon_sym_with] = ACTIONS(4138),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2848] = {
    [sym_modifier] = STATE(3807),
    [sym_variable_declaration] = STATE(9548),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(6484),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(6757),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(2848),
    [sym_preproc_endregion] = STATE(2848),
    [sym_preproc_line] = STATE(2848),
    [sym_preproc_pragma] = STATE(2848),
    [sym_preproc_nullable] = STATE(2848),
    [sym_preproc_error] = STATE(2848),
    [sym_preproc_warning] = STATE(2848),
    [sym_preproc_define] = STATE(2848),
    [sym_preproc_undef] = STATE(2848),
    [aux_sym_class_declaration_repeat2] = STATE(3733),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_extern] = ACTIONS(65),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_unsafe] = ACTIONS(65),
    [anon_sym_static] = ACTIONS(65),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_event] = ACTIONS(4413),
    [anon_sym_class] = ACTIONS(4415),
    [anon_sym_ref] = ACTIONS(4417),
    [anon_sym_struct] = ACTIONS(4419),
    [anon_sym_enum] = ACTIONS(4421),
    [anon_sym_interface] = ACTIONS(4423),
    [anon_sym_delegate] = ACTIONS(4425),
    [anon_sym_record] = ACTIONS(4427),
    [anon_sym_abstract] = ACTIONS(65),
    [anon_sym_async] = ACTIONS(65),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_file] = ACTIONS(3225),
    [anon_sym_fixed] = ACTIONS(65),
    [anon_sym_internal] = ACTIONS(65),
    [anon_sym_new] = ACTIONS(65),
    [anon_sym_override] = ACTIONS(65),
    [anon_sym_partial] = ACTIONS(65),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_public] = ACTIONS(65),
    [anon_sym_readonly] = ACTIONS(65),
    [anon_sym_required] = ACTIONS(65),
    [anon_sym_sealed] = ACTIONS(65),
    [anon_sym_virtual] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_implicit] = ACTIONS(4429),
    [anon_sym_explicit] = ACTIONS(4429),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2849] = {
    [sym_preproc_region] = STATE(2849),
    [sym_preproc_endregion] = STATE(2849),
    [sym_preproc_line] = STATE(2849),
    [sym_preproc_pragma] = STATE(2849),
    [sym_preproc_nullable] = STATE(2849),
    [sym_preproc_error] = STATE(2849),
    [sym_preproc_warning] = STATE(2849),
    [sym_preproc_define] = STATE(2849),
    [sym_preproc_undef] = STATE(2849),
    [sym__identifier_token] = ACTIONS(4091),
    [anon_sym_alias] = ACTIONS(4091),
    [anon_sym_global] = ACTIONS(4091),
    [anon_sym_EQ] = ACTIONS(3995),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_LPAREN] = ACTIONS(4088),
    [anon_sym_LBRACE] = ACTIONS(4088),
    [anon_sym_file] = ACTIONS(4091),
    [anon_sym_LT] = ACTIONS(3995),
    [anon_sym_GT] = ACTIONS(3995),
    [anon_sym_where] = ACTIONS(4091),
    [anon_sym_QMARK] = ACTIONS(3995),
    [anon_sym_notnull] = ACTIONS(4091),
    [anon_sym_unmanaged] = ACTIONS(4091),
    [anon_sym_BANG] = ACTIONS(3995),
    [anon_sym_PLUS_PLUS] = ACTIONS(3993),
    [anon_sym_DASH_DASH] = ACTIONS(3993),
    [anon_sym_PLUS] = ACTIONS(3995),
    [anon_sym_DASH] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3995),
    [anon_sym_SLASH] = ACTIONS(3995),
    [anon_sym_PERCENT] = ACTIONS(3995),
    [anon_sym_CARET] = ACTIONS(3995),
    [anon_sym_PIPE] = ACTIONS(3995),
    [anon_sym_AMP] = ACTIONS(3995),
    [anon_sym_LT_LT] = ACTIONS(3995),
    [anon_sym_GT_GT] = ACTIONS(3995),
    [anon_sym_GT_GT_GT] = ACTIONS(3995),
    [anon_sym_EQ_EQ] = ACTIONS(3993),
    [anon_sym_BANG_EQ] = ACTIONS(3993),
    [anon_sym_GT_EQ] = ACTIONS(3993),
    [anon_sym_LT_EQ] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3995),
    [anon_sym_scoped] = ACTIONS(4091),
    [anon_sym_EQ_GT] = ACTIONS(4088),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(4091),
    [anon_sym_yield] = ACTIONS(4091),
    [anon_sym_switch] = ACTIONS(3995),
    [anon_sym_when] = ACTIONS(4091),
    [sym_discard] = ACTIONS(4091),
    [anon_sym_DOT_DOT] = ACTIONS(3993),
    [anon_sym_and] = ACTIONS(4091),
    [anon_sym_or] = ACTIONS(4091),
    [anon_sym_PLUS_EQ] = ACTIONS(3993),
    [anon_sym_DASH_EQ] = ACTIONS(3993),
    [anon_sym_STAR_EQ] = ACTIONS(3993),
    [anon_sym_SLASH_EQ] = ACTIONS(3993),
    [anon_sym_PERCENT_EQ] = ACTIONS(3993),
    [anon_sym_AMP_EQ] = ACTIONS(3993),
    [anon_sym_CARET_EQ] = ACTIONS(3993),
    [anon_sym_PIPE_EQ] = ACTIONS(3993),
    [anon_sym_LT_LT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(3993),
    [anon_sym_AMP_AMP] = ACTIONS(3993),
    [anon_sym_PIPE_PIPE] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK] = ACTIONS(3995),
    [anon_sym_from] = ACTIONS(4091),
    [anon_sym_into] = ACTIONS(4091),
    [anon_sym_join] = ACTIONS(4091),
    [anon_sym_on] = ACTIONS(4091),
    [anon_sym_equals] = ACTIONS(4091),
    [anon_sym_let] = ACTIONS(4091),
    [anon_sym_orderby] = ACTIONS(4091),
    [anon_sym_ascending] = ACTIONS(4091),
    [anon_sym_descending] = ACTIONS(4091),
    [anon_sym_group] = ACTIONS(4091),
    [anon_sym_by] = ACTIONS(4091),
    [anon_sym_select] = ACTIONS(4091),
    [anon_sym_as] = ACTIONS(3995),
    [anon_sym_is] = ACTIONS(3995),
    [anon_sym_DASH_GT] = ACTIONS(3993),
    [anon_sym_with] = ACTIONS(3995),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2850] = {
    [sym_preproc_region] = STATE(2850),
    [sym_preproc_endregion] = STATE(2850),
    [sym_preproc_line] = STATE(2850),
    [sym_preproc_pragma] = STATE(2850),
    [sym_preproc_nullable] = STATE(2850),
    [sym_preproc_error] = STATE(2850),
    [sym_preproc_warning] = STATE(2850),
    [sym_preproc_define] = STATE(2850),
    [sym_preproc_undef] = STATE(2850),
    [sym__identifier_token] = ACTIONS(4179),
    [anon_sym_alias] = ACTIONS(4179),
    [anon_sym_global] = ACTIONS(4179),
    [anon_sym_EQ] = ACTIONS(4183),
    [anon_sym_LBRACK] = ACTIONS(4185),
    [anon_sym_COLON] = ACTIONS(4185),
    [anon_sym_LPAREN] = ACTIONS(4185),
    [anon_sym_LBRACE] = ACTIONS(4181),
    [anon_sym_file] = ACTIONS(4179),
    [anon_sym_LT] = ACTIONS(4183),
    [anon_sym_GT] = ACTIONS(4183),
    [anon_sym_where] = ACTIONS(4179),
    [anon_sym_QMARK] = ACTIONS(4188),
    [anon_sym_notnull] = ACTIONS(4179),
    [anon_sym_unmanaged] = ACTIONS(4179),
    [anon_sym_BANG] = ACTIONS(4183),
    [anon_sym_PLUS_PLUS] = ACTIONS(4191),
    [anon_sym_DASH_DASH] = ACTIONS(4191),
    [anon_sym_PLUS] = ACTIONS(4183),
    [anon_sym_DASH] = ACTIONS(4183),
    [anon_sym_STAR] = ACTIONS(4188),
    [anon_sym_SLASH] = ACTIONS(4183),
    [anon_sym_PERCENT] = ACTIONS(4183),
    [anon_sym_CARET] = ACTIONS(4183),
    [anon_sym_PIPE] = ACTIONS(4183),
    [anon_sym_AMP] = ACTIONS(4183),
    [anon_sym_LT_LT] = ACTIONS(4183),
    [anon_sym_GT_GT] = ACTIONS(4183),
    [anon_sym_GT_GT_GT] = ACTIONS(4183),
    [anon_sym_EQ_EQ] = ACTIONS(4191),
    [anon_sym_BANG_EQ] = ACTIONS(4191),
    [anon_sym_GT_EQ] = ACTIONS(4191),
    [anon_sym_LT_EQ] = ACTIONS(4191),
    [anon_sym_DOT] = ACTIONS(4188),
    [anon_sym_scoped] = ACTIONS(4179),
    [anon_sym_EQ_GT] = ACTIONS(4185),
    [anon_sym_var] = ACTIONS(4179),
    [anon_sym_yield] = ACTIONS(4179),
    [anon_sym_switch] = ACTIONS(4183),
    [anon_sym_when] = ACTIONS(4188),
    [sym_discard] = ACTIONS(4179),
    [anon_sym_DOT_DOT] = ACTIONS(4191),
    [anon_sym_and] = ACTIONS(4188),
    [anon_sym_or] = ACTIONS(4188),
    [anon_sym_PLUS_EQ] = ACTIONS(4191),
    [anon_sym_DASH_EQ] = ACTIONS(4191),
    [anon_sym_STAR_EQ] = ACTIONS(4191),
    [anon_sym_SLASH_EQ] = ACTIONS(4191),
    [anon_sym_PERCENT_EQ] = ACTIONS(4191),
    [anon_sym_AMP_EQ] = ACTIONS(4191),
    [anon_sym_CARET_EQ] = ACTIONS(4191),
    [anon_sym_PIPE_EQ] = ACTIONS(4191),
    [anon_sym_LT_LT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4191),
    [anon_sym_AMP_AMP] = ACTIONS(4191),
    [anon_sym_PIPE_PIPE] = ACTIONS(4191),
    [anon_sym_QMARK_QMARK] = ACTIONS(4183),
    [anon_sym_from] = ACTIONS(4179),
    [anon_sym_into] = ACTIONS(4179),
    [anon_sym_join] = ACTIONS(4179),
    [anon_sym_on] = ACTIONS(4179),
    [anon_sym_equals] = ACTIONS(4179),
    [anon_sym_let] = ACTIONS(4179),
    [anon_sym_orderby] = ACTIONS(4179),
    [anon_sym_ascending] = ACTIONS(4179),
    [anon_sym_descending] = ACTIONS(4179),
    [anon_sym_group] = ACTIONS(4179),
    [anon_sym_by] = ACTIONS(4179),
    [anon_sym_select] = ACTIONS(4179),
    [anon_sym_as] = ACTIONS(4183),
    [anon_sym_is] = ACTIONS(4183),
    [anon_sym_DASH_GT] = ACTIONS(4185),
    [anon_sym_with] = ACTIONS(4183),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2851] = {
    [sym_preproc_region] = STATE(2851),
    [sym_preproc_endregion] = STATE(2851),
    [sym_preproc_line] = STATE(2851),
    [sym_preproc_pragma] = STATE(2851),
    [sym_preproc_nullable] = STATE(2851),
    [sym_preproc_error] = STATE(2851),
    [sym_preproc_warning] = STATE(2851),
    [sym_preproc_define] = STATE(2851),
    [sym_preproc_undef] = STATE(2851),
    [sym__identifier_token] = ACTIONS(4179),
    [anon_sym_alias] = ACTIONS(4179),
    [anon_sym_global] = ACTIONS(4179),
    [anon_sym_EQ] = ACTIONS(4183),
    [anon_sym_LBRACK] = ACTIONS(4185),
    [anon_sym_COLON] = ACTIONS(4185),
    [anon_sym_LPAREN] = ACTIONS(4185),
    [anon_sym_LBRACE] = ACTIONS(4181),
    [anon_sym_file] = ACTIONS(4179),
    [anon_sym_LT] = ACTIONS(4188),
    [anon_sym_GT] = ACTIONS(4188),
    [anon_sym_where] = ACTIONS(4179),
    [anon_sym_QMARK] = ACTIONS(4188),
    [anon_sym_notnull] = ACTIONS(4179),
    [anon_sym_unmanaged] = ACTIONS(4179),
    [anon_sym_BANG] = ACTIONS(4188),
    [anon_sym_PLUS_PLUS] = ACTIONS(4185),
    [anon_sym_DASH_DASH] = ACTIONS(4185),
    [anon_sym_PLUS] = ACTIONS(4188),
    [anon_sym_DASH] = ACTIONS(4188),
    [anon_sym_STAR] = ACTIONS(4188),
    [anon_sym_SLASH] = ACTIONS(4188),
    [anon_sym_PERCENT] = ACTIONS(4188),
    [anon_sym_CARET] = ACTIONS(4188),
    [anon_sym_PIPE] = ACTIONS(4188),
    [anon_sym_AMP] = ACTIONS(4188),
    [anon_sym_LT_LT] = ACTIONS(4188),
    [anon_sym_GT_GT] = ACTIONS(4188),
    [anon_sym_GT_GT_GT] = ACTIONS(4188),
    [anon_sym_EQ_EQ] = ACTIONS(4185),
    [anon_sym_BANG_EQ] = ACTIONS(4185),
    [anon_sym_GT_EQ] = ACTIONS(4185),
    [anon_sym_LT_EQ] = ACTIONS(4185),
    [anon_sym_DOT] = ACTIONS(4188),
    [anon_sym_scoped] = ACTIONS(4179),
    [anon_sym_EQ_GT] = ACTIONS(4185),
    [anon_sym_var] = ACTIONS(4179),
    [anon_sym_yield] = ACTIONS(4179),
    [anon_sym_switch] = ACTIONS(4188),
    [anon_sym_when] = ACTIONS(4188),
    [sym_discard] = ACTIONS(4179),
    [anon_sym_DOT_DOT] = ACTIONS(4185),
    [anon_sym_and] = ACTIONS(4188),
    [anon_sym_or] = ACTIONS(4188),
    [anon_sym_PLUS_EQ] = ACTIONS(4191),
    [anon_sym_DASH_EQ] = ACTIONS(4191),
    [anon_sym_STAR_EQ] = ACTIONS(4191),
    [anon_sym_SLASH_EQ] = ACTIONS(4191),
    [anon_sym_PERCENT_EQ] = ACTIONS(4191),
    [anon_sym_AMP_EQ] = ACTIONS(4191),
    [anon_sym_CARET_EQ] = ACTIONS(4191),
    [anon_sym_PIPE_EQ] = ACTIONS(4191),
    [anon_sym_LT_LT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4191),
    [anon_sym_AMP_AMP] = ACTIONS(4185),
    [anon_sym_PIPE_PIPE] = ACTIONS(4185),
    [anon_sym_QMARK_QMARK] = ACTIONS(4188),
    [anon_sym_from] = ACTIONS(4179),
    [anon_sym_into] = ACTIONS(4188),
    [anon_sym_join] = ACTIONS(4179),
    [anon_sym_on] = ACTIONS(4179),
    [anon_sym_equals] = ACTIONS(4179),
    [anon_sym_let] = ACTIONS(4179),
    [anon_sym_orderby] = ACTIONS(4179),
    [anon_sym_ascending] = ACTIONS(4179),
    [anon_sym_descending] = ACTIONS(4179),
    [anon_sym_group] = ACTIONS(4179),
    [anon_sym_by] = ACTIONS(4179),
    [anon_sym_select] = ACTIONS(4179),
    [anon_sym_as] = ACTIONS(4188),
    [anon_sym_is] = ACTIONS(4188),
    [anon_sym_DASH_GT] = ACTIONS(4185),
    [anon_sym_with] = ACTIONS(4188),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2852] = {
    [sym_preproc_region] = STATE(2852),
    [sym_preproc_endregion] = STATE(2852),
    [sym_preproc_line] = STATE(2852),
    [sym_preproc_pragma] = STATE(2852),
    [sym_preproc_nullable] = STATE(2852),
    [sym_preproc_error] = STATE(2852),
    [sym_preproc_warning] = STATE(2852),
    [sym_preproc_define] = STATE(2852),
    [sym_preproc_undef] = STATE(2852),
    [sym__identifier_token] = ACTIONS(4157),
    [anon_sym_alias] = ACTIONS(4157),
    [anon_sym_global] = ACTIONS(4157),
    [anon_sym_EQ] = ACTIONS(4162),
    [anon_sym_LBRACK] = ACTIONS(4164),
    [anon_sym_COLON] = ACTIONS(4159),
    [anon_sym_LPAREN] = ACTIONS(4164),
    [anon_sym_LBRACE] = ACTIONS(4168),
    [anon_sym_file] = ACTIONS(4157),
    [anon_sym_LT] = ACTIONS(4170),
    [anon_sym_GT] = ACTIONS(4170),
    [anon_sym_where] = ACTIONS(4157),
    [anon_sym_QMARK] = ACTIONS(4170),
    [anon_sym_notnull] = ACTIONS(4157),
    [anon_sym_unmanaged] = ACTIONS(4157),
    [anon_sym_BANG] = ACTIONS(4170),
    [anon_sym_PLUS_PLUS] = ACTIONS(4164),
    [anon_sym_DASH_DASH] = ACTIONS(4164),
    [anon_sym_PLUS] = ACTIONS(4170),
    [anon_sym_DASH] = ACTIONS(4170),
    [anon_sym_STAR] = ACTIONS(4170),
    [anon_sym_SLASH] = ACTIONS(4170),
    [anon_sym_PERCENT] = ACTIONS(4170),
    [anon_sym_CARET] = ACTIONS(4170),
    [anon_sym_PIPE] = ACTIONS(4170),
    [anon_sym_AMP] = ACTIONS(4170),
    [anon_sym_LT_LT] = ACTIONS(4170),
    [anon_sym_GT_GT] = ACTIONS(4170),
    [anon_sym_GT_GT_GT] = ACTIONS(4170),
    [anon_sym_EQ_EQ] = ACTIONS(4164),
    [anon_sym_BANG_EQ] = ACTIONS(4164),
    [anon_sym_GT_EQ] = ACTIONS(4164),
    [anon_sym_LT_EQ] = ACTIONS(4164),
    [anon_sym_DOT] = ACTIONS(4170),
    [anon_sym_scoped] = ACTIONS(4157),
    [anon_sym_EQ_GT] = ACTIONS(4159),
    [anon_sym_var] = ACTIONS(4157),
    [anon_sym_yield] = ACTIONS(4157),
    [anon_sym_switch] = ACTIONS(4170),
    [anon_sym_when] = ACTIONS(4174),
    [sym_discard] = ACTIONS(4157),
    [anon_sym_DOT_DOT] = ACTIONS(4164),
    [anon_sym_and] = ACTIONS(4174),
    [anon_sym_or] = ACTIONS(4174),
    [anon_sym_PLUS_EQ] = ACTIONS(4177),
    [anon_sym_DASH_EQ] = ACTIONS(4177),
    [anon_sym_STAR_EQ] = ACTIONS(4177),
    [anon_sym_SLASH_EQ] = ACTIONS(4177),
    [anon_sym_PERCENT_EQ] = ACTIONS(4177),
    [anon_sym_AMP_EQ] = ACTIONS(4177),
    [anon_sym_CARET_EQ] = ACTIONS(4177),
    [anon_sym_PIPE_EQ] = ACTIONS(4177),
    [anon_sym_LT_LT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4177),
    [anon_sym_AMP_AMP] = ACTIONS(4164),
    [anon_sym_PIPE_PIPE] = ACTIONS(4164),
    [anon_sym_QMARK_QMARK] = ACTIONS(4170),
    [anon_sym_from] = ACTIONS(4157),
    [anon_sym_into] = ACTIONS(4157),
    [anon_sym_join] = ACTIONS(4157),
    [anon_sym_on] = ACTIONS(4157),
    [anon_sym_equals] = ACTIONS(4157),
    [anon_sym_let] = ACTIONS(4157),
    [anon_sym_orderby] = ACTIONS(4157),
    [anon_sym_ascending] = ACTIONS(4157),
    [anon_sym_descending] = ACTIONS(4157),
    [anon_sym_group] = ACTIONS(4157),
    [anon_sym_by] = ACTIONS(4157),
    [anon_sym_select] = ACTIONS(4157),
    [anon_sym_as] = ACTIONS(4170),
    [anon_sym_is] = ACTIONS(4170),
    [anon_sym_DASH_GT] = ACTIONS(4164),
    [anon_sym_with] = ACTIONS(4170),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2853] = {
    [sym_preproc_region] = STATE(2853),
    [sym_preproc_endregion] = STATE(2853),
    [sym_preproc_line] = STATE(2853),
    [sym_preproc_pragma] = STATE(2853),
    [sym_preproc_nullable] = STATE(2853),
    [sym_preproc_error] = STATE(2853),
    [sym_preproc_warning] = STATE(2853),
    [sym_preproc_define] = STATE(2853),
    [sym_preproc_undef] = STATE(2853),
    [sym__identifier_token] = ACTIONS(4179),
    [anon_sym_alias] = ACTIONS(4179),
    [anon_sym_global] = ACTIONS(4179),
    [anon_sym_EQ] = ACTIONS(4183),
    [anon_sym_LBRACK] = ACTIONS(4185),
    [anon_sym_COLON] = ACTIONS(4185),
    [anon_sym_LPAREN] = ACTIONS(4185),
    [anon_sym_LBRACE] = ACTIONS(4181),
    [anon_sym_file] = ACTIONS(4179),
    [anon_sym_LT] = ACTIONS(4188),
    [anon_sym_GT] = ACTIONS(4188),
    [anon_sym_where] = ACTIONS(4179),
    [anon_sym_QMARK] = ACTIONS(4188),
    [anon_sym_notnull] = ACTIONS(4179),
    [anon_sym_unmanaged] = ACTIONS(4179),
    [anon_sym_BANG] = ACTIONS(4188),
    [anon_sym_PLUS_PLUS] = ACTIONS(4185),
    [anon_sym_DASH_DASH] = ACTIONS(4185),
    [anon_sym_PLUS] = ACTIONS(4188),
    [anon_sym_DASH] = ACTIONS(4188),
    [anon_sym_STAR] = ACTIONS(4188),
    [anon_sym_SLASH] = ACTIONS(4188),
    [anon_sym_PERCENT] = ACTIONS(4188),
    [anon_sym_CARET] = ACTIONS(4188),
    [anon_sym_PIPE] = ACTIONS(4188),
    [anon_sym_AMP] = ACTIONS(4188),
    [anon_sym_LT_LT] = ACTIONS(4188),
    [anon_sym_GT_GT] = ACTIONS(4188),
    [anon_sym_GT_GT_GT] = ACTIONS(4188),
    [anon_sym_EQ_EQ] = ACTIONS(4185),
    [anon_sym_BANG_EQ] = ACTIONS(4185),
    [anon_sym_GT_EQ] = ACTIONS(4185),
    [anon_sym_LT_EQ] = ACTIONS(4185),
    [anon_sym_DOT] = ACTIONS(4188),
    [anon_sym_scoped] = ACTIONS(4179),
    [anon_sym_EQ_GT] = ACTIONS(4185),
    [anon_sym_var] = ACTIONS(4179),
    [anon_sym_yield] = ACTIONS(4179),
    [anon_sym_switch] = ACTIONS(4188),
    [anon_sym_when] = ACTIONS(4188),
    [sym_discard] = ACTIONS(4179),
    [anon_sym_DOT_DOT] = ACTIONS(4185),
    [anon_sym_and] = ACTIONS(4188),
    [anon_sym_or] = ACTIONS(4188),
    [anon_sym_PLUS_EQ] = ACTIONS(4191),
    [anon_sym_DASH_EQ] = ACTIONS(4191),
    [anon_sym_STAR_EQ] = ACTIONS(4191),
    [anon_sym_SLASH_EQ] = ACTIONS(4191),
    [anon_sym_PERCENT_EQ] = ACTIONS(4191),
    [anon_sym_AMP_EQ] = ACTIONS(4191),
    [anon_sym_CARET_EQ] = ACTIONS(4191),
    [anon_sym_PIPE_EQ] = ACTIONS(4191),
    [anon_sym_LT_LT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4191),
    [anon_sym_AMP_AMP] = ACTIONS(4185),
    [anon_sym_PIPE_PIPE] = ACTIONS(4185),
    [anon_sym_QMARK_QMARK] = ACTIONS(4188),
    [anon_sym_from] = ACTIONS(4179),
    [anon_sym_into] = ACTIONS(4179),
    [anon_sym_join] = ACTIONS(4179),
    [anon_sym_on] = ACTIONS(4179),
    [anon_sym_equals] = ACTIONS(4179),
    [anon_sym_let] = ACTIONS(4179),
    [anon_sym_orderby] = ACTIONS(4179),
    [anon_sym_ascending] = ACTIONS(4179),
    [anon_sym_descending] = ACTIONS(4179),
    [anon_sym_group] = ACTIONS(4179),
    [anon_sym_by] = ACTIONS(4179),
    [anon_sym_select] = ACTIONS(4179),
    [anon_sym_as] = ACTIONS(4188),
    [anon_sym_is] = ACTIONS(4188),
    [anon_sym_DASH_GT] = ACTIONS(4185),
    [anon_sym_with] = ACTIONS(4188),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2854] = {
    [sym_property_pattern_clause] = STATE(2914),
    [sym__variable_designation] = STATE(4161),
    [sym_parenthesized_variable_designation] = STATE(4153),
    [sym_identifier] = STATE(4156),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(2854),
    [sym_preproc_endregion] = STATE(2854),
    [sym_preproc_line] = STATE(2854),
    [sym_preproc_pragma] = STATE(2854),
    [sym_preproc_nullable] = STATE(2854),
    [sym_preproc_error] = STATE(2854),
    [sym_preproc_warning] = STATE(2854),
    [sym_preproc_define] = STATE(2854),
    [sym_preproc_undef] = STATE(2854),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_SEMI] = ACTIONS(4405),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4405),
    [anon_sym_COLON] = ACTIONS(4405),
    [anon_sym_COMMA] = ACTIONS(4405),
    [anon_sym_RBRACK] = ACTIONS(4405),
    [anon_sym_LPAREN] = ACTIONS(4405),
    [anon_sym_RPAREN] = ACTIONS(4405),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_RBRACE] = ACTIONS(4405),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4407),
    [anon_sym_GT] = ACTIONS(4407),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4407),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4407),
    [anon_sym_PLUS_PLUS] = ACTIONS(4405),
    [anon_sym_DASH_DASH] = ACTIONS(4405),
    [anon_sym_PLUS] = ACTIONS(4407),
    [anon_sym_DASH] = ACTIONS(4407),
    [anon_sym_STAR] = ACTIONS(4405),
    [anon_sym_SLASH] = ACTIONS(4407),
    [anon_sym_PERCENT] = ACTIONS(4405),
    [anon_sym_CARET] = ACTIONS(4405),
    [anon_sym_PIPE] = ACTIONS(4407),
    [anon_sym_AMP] = ACTIONS(4407),
    [anon_sym_LT_LT] = ACTIONS(4405),
    [anon_sym_GT_GT] = ACTIONS(4407),
    [anon_sym_GT_GT_GT] = ACTIONS(4405),
    [anon_sym_EQ_EQ] = ACTIONS(4405),
    [anon_sym_BANG_EQ] = ACTIONS(4405),
    [anon_sym_GT_EQ] = ACTIONS(4405),
    [anon_sym_LT_EQ] = ACTIONS(4405),
    [anon_sym_DOT] = ACTIONS(4407),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_EQ_GT] = ACTIONS(4405),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4407),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4359),
    [anon_sym_DOT_DOT] = ACTIONS(4405),
    [anon_sym_and] = ACTIONS(4407),
    [anon_sym_or] = ACTIONS(4407),
    [anon_sym_AMP_AMP] = ACTIONS(4405),
    [anon_sym_PIPE_PIPE] = ACTIONS(4405),
    [anon_sym_QMARK_QMARK] = ACTIONS(4405),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4339),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4407),
    [anon_sym_is] = ACTIONS(4407),
    [anon_sym_DASH_GT] = ACTIONS(4405),
    [anon_sym_with] = ACTIONS(4407),
    [aux_sym_preproc_if_token3] = ACTIONS(4405),
    [aux_sym_preproc_else_token1] = ACTIONS(4405),
    [aux_sym_preproc_elif_token1] = ACTIONS(4405),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2855] = {
    [sym_parameter_list] = STATE(9685),
    [sym__lambda_parameters] = STATE(9890),
    [sym_identifier] = STATE(9119),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_region] = STATE(2855),
    [sym_preproc_endregion] = STATE(2855),
    [sym_preproc_line] = STATE(2855),
    [sym_preproc_pragma] = STATE(2855),
    [sym_preproc_nullable] = STATE(2855),
    [sym_preproc_error] = STATE(2855),
    [sym_preproc_warning] = STATE(2855),
    [sym_preproc_define] = STATE(2855),
    [sym_preproc_undef] = STATE(2855),
    [sym__identifier_token] = ACTIONS(4431),
    [anon_sym_alias] = ACTIONS(4431),
    [anon_sym_SEMI] = ACTIONS(4433),
    [anon_sym_global] = ACTIONS(4431),
    [anon_sym_LBRACK] = ACTIONS(4433),
    [anon_sym_COLON] = ACTIONS(4433),
    [anon_sym_COMMA] = ACTIONS(4433),
    [anon_sym_RBRACK] = ACTIONS(4433),
    [anon_sym_LPAREN] = ACTIONS(4433),
    [anon_sym_RPAREN] = ACTIONS(4433),
    [anon_sym_LBRACE] = ACTIONS(4433),
    [anon_sym_RBRACE] = ACTIONS(4433),
    [anon_sym_file] = ACTIONS(4431),
    [anon_sym_LT] = ACTIONS(4431),
    [anon_sym_GT] = ACTIONS(4431),
    [anon_sym_in] = ACTIONS(4431),
    [anon_sym_where] = ACTIONS(4431),
    [anon_sym_QMARK] = ACTIONS(4431),
    [anon_sym_notnull] = ACTIONS(4431),
    [anon_sym_unmanaged] = ACTIONS(4431),
    [anon_sym_BANG] = ACTIONS(4431),
    [anon_sym_PLUS_PLUS] = ACTIONS(4433),
    [anon_sym_DASH_DASH] = ACTIONS(4433),
    [anon_sym_PLUS] = ACTIONS(4431),
    [anon_sym_DASH] = ACTIONS(4431),
    [anon_sym_STAR] = ACTIONS(4433),
    [anon_sym_SLASH] = ACTIONS(4431),
    [anon_sym_PERCENT] = ACTIONS(4433),
    [anon_sym_CARET] = ACTIONS(4433),
    [anon_sym_PIPE] = ACTIONS(4431),
    [anon_sym_AMP] = ACTIONS(4431),
    [anon_sym_LT_LT] = ACTIONS(4433),
    [anon_sym_GT_GT] = ACTIONS(4431),
    [anon_sym_GT_GT_GT] = ACTIONS(4433),
    [anon_sym_EQ_EQ] = ACTIONS(4433),
    [anon_sym_BANG_EQ] = ACTIONS(4433),
    [anon_sym_GT_EQ] = ACTIONS(4433),
    [anon_sym_LT_EQ] = ACTIONS(4433),
    [anon_sym_DOT] = ACTIONS(4431),
    [anon_sym_scoped] = ACTIONS(4431),
    [anon_sym_EQ_GT] = ACTIONS(4433),
    [anon_sym_var] = ACTIONS(4431),
    [anon_sym_yield] = ACTIONS(4431),
    [anon_sym_switch] = ACTIONS(4431),
    [anon_sym_when] = ACTIONS(4431),
    [sym_discard] = ACTIONS(4431),
    [anon_sym_DOT_DOT] = ACTIONS(4433),
    [anon_sym_and] = ACTIONS(4431),
    [anon_sym_or] = ACTIONS(4431),
    [anon_sym_AMP_AMP] = ACTIONS(4433),
    [anon_sym_PIPE_PIPE] = ACTIONS(4433),
    [anon_sym_QMARK_QMARK] = ACTIONS(4433),
    [anon_sym_from] = ACTIONS(4431),
    [anon_sym_into] = ACTIONS(4431),
    [anon_sym_join] = ACTIONS(4431),
    [anon_sym_on] = ACTIONS(4431),
    [anon_sym_equals] = ACTIONS(4431),
    [anon_sym_let] = ACTIONS(4431),
    [anon_sym_orderby] = ACTIONS(4431),
    [anon_sym_ascending] = ACTIONS(4431),
    [anon_sym_descending] = ACTIONS(4431),
    [anon_sym_group] = ACTIONS(4431),
    [anon_sym_by] = ACTIONS(4431),
    [anon_sym_select] = ACTIONS(4431),
    [anon_sym_as] = ACTIONS(4431),
    [anon_sym_is] = ACTIONS(4431),
    [anon_sym_DASH_GT] = ACTIONS(4433),
    [anon_sym_with] = ACTIONS(4431),
    [aux_sym_preproc_if_token3] = ACTIONS(4433),
    [aux_sym_preproc_else_token1] = ACTIONS(4433),
    [aux_sym_preproc_elif_token1] = ACTIONS(4433),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2856] = {
    [sym__name] = STATE(3199),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2956),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2944),
    [sym_ref_type] = STATE(2883),
    [sym__scoped_base_type] = STATE(2885),
    [sym_identifier] = STATE(3123),
    [sym__reserved_identifier] = STATE(2928),
    [sym_preproc_region] = STATE(2856),
    [sym_preproc_endregion] = STATE(2856),
    [sym_preproc_line] = STATE(2856),
    [sym_preproc_pragma] = STATE(2856),
    [sym_preproc_nullable] = STATE(2856),
    [sym_preproc_error] = STATE(2856),
    [sym_preproc_warning] = STATE(2856),
    [sym_preproc_define] = STATE(2856),
    [sym_preproc_undef] = STATE(2856),
    [sym__identifier_token] = ACTIONS(4053),
    [anon_sym_alias] = ACTIONS(4056),
    [anon_sym_global] = ACTIONS(4056),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_COLON] = ACTIONS(3995),
    [anon_sym_COMMA] = ACTIONS(3993),
    [anon_sym_LPAREN] = ACTIONS(3993),
    [anon_sym_RPAREN] = ACTIONS(3993),
    [anon_sym_ref] = ACTIONS(4102),
    [anon_sym_LBRACE] = ACTIONS(3993),
    [anon_sym_RBRACE] = ACTIONS(3993),
    [anon_sym_file] = ACTIONS(4056),
    [anon_sym_LT] = ACTIONS(3995),
    [anon_sym_GT] = ACTIONS(3995),
    [anon_sym_where] = ACTIONS(4056),
    [anon_sym_QMARK] = ACTIONS(3995),
    [anon_sym_notnull] = ACTIONS(4056),
    [anon_sym_unmanaged] = ACTIONS(4056),
    [anon_sym_BANG] = ACTIONS(3995),
    [anon_sym_PLUS_PLUS] = ACTIONS(3993),
    [anon_sym_DASH_DASH] = ACTIONS(3993),
    [anon_sym_PLUS] = ACTIONS(3995),
    [anon_sym_DASH] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3993),
    [anon_sym_SLASH] = ACTIONS(3995),
    [anon_sym_PERCENT] = ACTIONS(3993),
    [anon_sym_CARET] = ACTIONS(3993),
    [anon_sym_PIPE] = ACTIONS(3995),
    [anon_sym_AMP] = ACTIONS(3995),
    [anon_sym_LT_LT] = ACTIONS(3993),
    [anon_sym_GT_GT] = ACTIONS(3995),
    [anon_sym_GT_GT_GT] = ACTIONS(3993),
    [anon_sym_EQ_EQ] = ACTIONS(3993),
    [anon_sym_BANG_EQ] = ACTIONS(3993),
    [anon_sym_GT_EQ] = ACTIONS(3993),
    [anon_sym_LT_EQ] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3995),
    [anon_sym_scoped] = ACTIONS(4056),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(4056),
    [anon_sym_yield] = ACTIONS(4056),
    [anon_sym_switch] = ACTIONS(3995),
    [anon_sym_when] = ACTIONS(4056),
    [sym_discard] = ACTIONS(3995),
    [anon_sym_DOT_DOT] = ACTIONS(3993),
    [anon_sym_and] = ACTIONS(3995),
    [anon_sym_or] = ACTIONS(3995),
    [anon_sym_AMP_AMP] = ACTIONS(3993),
    [anon_sym_PIPE_PIPE] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK] = ACTIONS(3993),
    [anon_sym_from] = ACTIONS(4056),
    [anon_sym_into] = ACTIONS(4056),
    [anon_sym_join] = ACTIONS(4056),
    [anon_sym_on] = ACTIONS(4056),
    [anon_sym_equals] = ACTIONS(4056),
    [anon_sym_let] = ACTIONS(4056),
    [anon_sym_orderby] = ACTIONS(4056),
    [anon_sym_ascending] = ACTIONS(4056),
    [anon_sym_descending] = ACTIONS(4056),
    [anon_sym_group] = ACTIONS(4056),
    [anon_sym_by] = ACTIONS(4056),
    [anon_sym_select] = ACTIONS(4056),
    [anon_sym_as] = ACTIONS(3995),
    [anon_sym_is] = ACTIONS(3995),
    [anon_sym_DASH_GT] = ACTIONS(3993),
    [anon_sym_with] = ACTIONS(3995),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2857] = {
    [sym_modifier] = STATE(3807),
    [sym_variable_declaration] = STATE(9113),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(6417),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(6756),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(2857),
    [sym_preproc_endregion] = STATE(2857),
    [sym_preproc_line] = STATE(2857),
    [sym_preproc_pragma] = STATE(2857),
    [sym_preproc_nullable] = STATE(2857),
    [sym_preproc_error] = STATE(2857),
    [sym_preproc_warning] = STATE(2857),
    [sym_preproc_define] = STATE(2857),
    [sym_preproc_undef] = STATE(2857),
    [aux_sym_class_declaration_repeat2] = STATE(3733),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_extern] = ACTIONS(65),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_unsafe] = ACTIONS(65),
    [anon_sym_static] = ACTIONS(65),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_event] = ACTIONS(4274),
    [anon_sym_class] = ACTIONS(4276),
    [anon_sym_ref] = ACTIONS(4278),
    [anon_sym_struct] = ACTIONS(4280),
    [anon_sym_enum] = ACTIONS(4282),
    [anon_sym_interface] = ACTIONS(4284),
    [anon_sym_delegate] = ACTIONS(4286),
    [anon_sym_record] = ACTIONS(4288),
    [anon_sym_abstract] = ACTIONS(65),
    [anon_sym_async] = ACTIONS(65),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_file] = ACTIONS(3225),
    [anon_sym_fixed] = ACTIONS(65),
    [anon_sym_internal] = ACTIONS(65),
    [anon_sym_new] = ACTIONS(65),
    [anon_sym_override] = ACTIONS(65),
    [anon_sym_partial] = ACTIONS(65),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_public] = ACTIONS(65),
    [anon_sym_readonly] = ACTIONS(65),
    [anon_sym_required] = ACTIONS(65),
    [anon_sym_sealed] = ACTIONS(65),
    [anon_sym_virtual] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_implicit] = ACTIONS(4292),
    [anon_sym_explicit] = ACTIONS(4292),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2858] = {
    [sym_property_pattern_clause] = STATE(2888),
    [sym__variable_designation] = STATE(4166),
    [sym_parenthesized_variable_designation] = STATE(4153),
    [sym_identifier] = STATE(4156),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(2858),
    [sym_preproc_endregion] = STATE(2858),
    [sym_preproc_line] = STATE(2858),
    [sym_preproc_pragma] = STATE(2858),
    [sym_preproc_nullable] = STATE(2858),
    [sym_preproc_error] = STATE(2858),
    [sym_preproc_warning] = STATE(2858),
    [sym_preproc_define] = STATE(2858),
    [sym_preproc_undef] = STATE(2858),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_SEMI] = ACTIONS(4399),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4399),
    [anon_sym_COLON] = ACTIONS(4399),
    [anon_sym_COMMA] = ACTIONS(4399),
    [anon_sym_RBRACK] = ACTIONS(4399),
    [anon_sym_LPAREN] = ACTIONS(4399),
    [anon_sym_RPAREN] = ACTIONS(4399),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_RBRACE] = ACTIONS(4399),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4401),
    [anon_sym_GT] = ACTIONS(4401),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4401),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4401),
    [anon_sym_PLUS_PLUS] = ACTIONS(4399),
    [anon_sym_DASH_DASH] = ACTIONS(4399),
    [anon_sym_PLUS] = ACTIONS(4401),
    [anon_sym_DASH] = ACTIONS(4401),
    [anon_sym_STAR] = ACTIONS(4399),
    [anon_sym_SLASH] = ACTIONS(4401),
    [anon_sym_PERCENT] = ACTIONS(4399),
    [anon_sym_CARET] = ACTIONS(4399),
    [anon_sym_PIPE] = ACTIONS(4401),
    [anon_sym_AMP] = ACTIONS(4401),
    [anon_sym_LT_LT] = ACTIONS(4399),
    [anon_sym_GT_GT] = ACTIONS(4401),
    [anon_sym_GT_GT_GT] = ACTIONS(4399),
    [anon_sym_EQ_EQ] = ACTIONS(4399),
    [anon_sym_BANG_EQ] = ACTIONS(4399),
    [anon_sym_GT_EQ] = ACTIONS(4399),
    [anon_sym_LT_EQ] = ACTIONS(4399),
    [anon_sym_DOT] = ACTIONS(4401),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_EQ_GT] = ACTIONS(4399),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4401),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4359),
    [anon_sym_DOT_DOT] = ACTIONS(4399),
    [anon_sym_and] = ACTIONS(4401),
    [anon_sym_or] = ACTIONS(4401),
    [anon_sym_AMP_AMP] = ACTIONS(4399),
    [anon_sym_PIPE_PIPE] = ACTIONS(4399),
    [anon_sym_QMARK_QMARK] = ACTIONS(4399),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4339),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4401),
    [anon_sym_is] = ACTIONS(4401),
    [anon_sym_DASH_GT] = ACTIONS(4399),
    [anon_sym_with] = ACTIONS(4401),
    [aux_sym_preproc_if_token3] = ACTIONS(4399),
    [aux_sym_preproc_else_token1] = ACTIONS(4399),
    [aux_sym_preproc_elif_token1] = ACTIONS(4399),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2859] = {
    [sym_preproc_region] = STATE(2859),
    [sym_preproc_endregion] = STATE(2859),
    [sym_preproc_line] = STATE(2859),
    [sym_preproc_pragma] = STATE(2859),
    [sym_preproc_nullable] = STATE(2859),
    [sym_preproc_error] = STATE(2859),
    [sym_preproc_warning] = STATE(2859),
    [sym_preproc_define] = STATE(2859),
    [sym_preproc_undef] = STATE(2859),
    [sym__identifier_token] = ACTIONS(4157),
    [anon_sym_alias] = ACTIONS(4157),
    [anon_sym_global] = ACTIONS(4157),
    [anon_sym_EQ] = ACTIONS(4162),
    [anon_sym_LBRACK] = ACTIONS(4164),
    [anon_sym_COMMA] = ACTIONS(4159),
    [anon_sym_LPAREN] = ACTIONS(4164),
    [anon_sym_LBRACE] = ACTIONS(4168),
    [anon_sym_file] = ACTIONS(4157),
    [anon_sym_LT] = ACTIONS(4170),
    [anon_sym_GT] = ACTIONS(4170),
    [anon_sym_where] = ACTIONS(4174),
    [anon_sym_QMARK] = ACTIONS(4170),
    [anon_sym_notnull] = ACTIONS(4157),
    [anon_sym_unmanaged] = ACTIONS(4157),
    [anon_sym_BANG] = ACTIONS(4170),
    [anon_sym_PLUS_PLUS] = ACTIONS(4164),
    [anon_sym_DASH_DASH] = ACTIONS(4164),
    [anon_sym_PLUS] = ACTIONS(4170),
    [anon_sym_DASH] = ACTIONS(4170),
    [anon_sym_STAR] = ACTIONS(4170),
    [anon_sym_SLASH] = ACTIONS(4170),
    [anon_sym_PERCENT] = ACTIONS(4170),
    [anon_sym_CARET] = ACTIONS(4170),
    [anon_sym_PIPE] = ACTIONS(4170),
    [anon_sym_AMP] = ACTIONS(4170),
    [anon_sym_LT_LT] = ACTIONS(4170),
    [anon_sym_GT_GT] = ACTIONS(4170),
    [anon_sym_GT_GT_GT] = ACTIONS(4170),
    [anon_sym_EQ_EQ] = ACTIONS(4164),
    [anon_sym_BANG_EQ] = ACTIONS(4164),
    [anon_sym_GT_EQ] = ACTIONS(4164),
    [anon_sym_LT_EQ] = ACTIONS(4164),
    [anon_sym_DOT] = ACTIONS(4170),
    [anon_sym_scoped] = ACTIONS(4157),
    [anon_sym_var] = ACTIONS(4157),
    [anon_sym_yield] = ACTIONS(4157),
    [anon_sym_switch] = ACTIONS(4170),
    [anon_sym_when] = ACTIONS(4157),
    [sym_discard] = ACTIONS(4157),
    [anon_sym_DOT_DOT] = ACTIONS(4164),
    [anon_sym_and] = ACTIONS(4174),
    [anon_sym_or] = ACTIONS(4174),
    [anon_sym_PLUS_EQ] = ACTIONS(4177),
    [anon_sym_DASH_EQ] = ACTIONS(4177),
    [anon_sym_STAR_EQ] = ACTIONS(4177),
    [anon_sym_SLASH_EQ] = ACTIONS(4177),
    [anon_sym_PERCENT_EQ] = ACTIONS(4177),
    [anon_sym_AMP_EQ] = ACTIONS(4177),
    [anon_sym_CARET_EQ] = ACTIONS(4177),
    [anon_sym_PIPE_EQ] = ACTIONS(4177),
    [anon_sym_LT_LT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4177),
    [anon_sym_AMP_AMP] = ACTIONS(4164),
    [anon_sym_PIPE_PIPE] = ACTIONS(4164),
    [anon_sym_QMARK_QMARK] = ACTIONS(4170),
    [anon_sym_from] = ACTIONS(4174),
    [anon_sym_into] = ACTIONS(4174),
    [anon_sym_join] = ACTIONS(4174),
    [anon_sym_on] = ACTIONS(4157),
    [anon_sym_equals] = ACTIONS(4157),
    [anon_sym_let] = ACTIONS(4174),
    [anon_sym_orderby] = ACTIONS(4174),
    [anon_sym_ascending] = ACTIONS(4174),
    [anon_sym_descending] = ACTIONS(4174),
    [anon_sym_group] = ACTIONS(4174),
    [anon_sym_by] = ACTIONS(4157),
    [anon_sym_select] = ACTIONS(4174),
    [anon_sym_as] = ACTIONS(4170),
    [anon_sym_is] = ACTIONS(4170),
    [anon_sym_DASH_GT] = ACTIONS(4164),
    [anon_sym_with] = ACTIONS(4170),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2860] = {
    [sym_preproc_region] = STATE(2860),
    [sym_preproc_endregion] = STATE(2860),
    [sym_preproc_line] = STATE(2860),
    [sym_preproc_pragma] = STATE(2860),
    [sym_preproc_nullable] = STATE(2860),
    [sym_preproc_error] = STATE(2860),
    [sym_preproc_warning] = STATE(2860),
    [sym_preproc_define] = STATE(2860),
    [sym_preproc_undef] = STATE(2860),
    [sym__identifier_token] = ACTIONS(4157),
    [anon_sym_alias] = ACTIONS(4157),
    [anon_sym_global] = ACTIONS(4157),
    [anon_sym_EQ] = ACTIONS(4162),
    [anon_sym_LBRACK] = ACTIONS(4193),
    [anon_sym_COLON] = ACTIONS(4168),
    [anon_sym_LPAREN] = ACTIONS(4193),
    [anon_sym_LBRACE] = ACTIONS(4168),
    [anon_sym_file] = ACTIONS(4157),
    [anon_sym_LT] = ACTIONS(4162),
    [anon_sym_GT] = ACTIONS(4162),
    [anon_sym_where] = ACTIONS(4157),
    [anon_sym_QMARK] = ACTIONS(4196),
    [anon_sym_notnull] = ACTIONS(4157),
    [anon_sym_unmanaged] = ACTIONS(4157),
    [anon_sym_BANG] = ACTIONS(4162),
    [anon_sym_PLUS_PLUS] = ACTIONS(4177),
    [anon_sym_DASH_DASH] = ACTIONS(4177),
    [anon_sym_PLUS] = ACTIONS(4162),
    [anon_sym_DASH] = ACTIONS(4162),
    [anon_sym_STAR] = ACTIONS(4196),
    [anon_sym_SLASH] = ACTIONS(4162),
    [anon_sym_PERCENT] = ACTIONS(4162),
    [anon_sym_CARET] = ACTIONS(4162),
    [anon_sym_PIPE] = ACTIONS(4162),
    [anon_sym_AMP] = ACTIONS(4162),
    [anon_sym_LT_LT] = ACTIONS(4162),
    [anon_sym_GT_GT] = ACTIONS(4162),
    [anon_sym_GT_GT_GT] = ACTIONS(4162),
    [anon_sym_EQ_EQ] = ACTIONS(4177),
    [anon_sym_BANG_EQ] = ACTIONS(4177),
    [anon_sym_GT_EQ] = ACTIONS(4177),
    [anon_sym_LT_EQ] = ACTIONS(4177),
    [anon_sym_DOT] = ACTIONS(4196),
    [anon_sym_scoped] = ACTIONS(4157),
    [anon_sym_var] = ACTIONS(4157),
    [anon_sym_yield] = ACTIONS(4157),
    [anon_sym_switch] = ACTIONS(4162),
    [anon_sym_when] = ACTIONS(4157),
    [sym_discard] = ACTIONS(4157),
    [anon_sym_DOT_DOT] = ACTIONS(4177),
    [anon_sym_and] = ACTIONS(4157),
    [anon_sym_or] = ACTIONS(4157),
    [anon_sym_PLUS_EQ] = ACTIONS(4177),
    [anon_sym_DASH_EQ] = ACTIONS(4177),
    [anon_sym_STAR_EQ] = ACTIONS(4177),
    [anon_sym_SLASH_EQ] = ACTIONS(4177),
    [anon_sym_PERCENT_EQ] = ACTIONS(4177),
    [anon_sym_AMP_EQ] = ACTIONS(4177),
    [anon_sym_CARET_EQ] = ACTIONS(4177),
    [anon_sym_PIPE_EQ] = ACTIONS(4177),
    [anon_sym_LT_LT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4177),
    [anon_sym_AMP_AMP] = ACTIONS(4177),
    [anon_sym_PIPE_PIPE] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK] = ACTIONS(4162),
    [anon_sym_from] = ACTIONS(4157),
    [anon_sym_into] = ACTIONS(4157),
    [anon_sym_join] = ACTIONS(4157),
    [anon_sym_on] = ACTIONS(4157),
    [anon_sym_equals] = ACTIONS(4157),
    [anon_sym_let] = ACTIONS(4157),
    [anon_sym_orderby] = ACTIONS(4157),
    [anon_sym_ascending] = ACTIONS(4157),
    [anon_sym_descending] = ACTIONS(4157),
    [anon_sym_group] = ACTIONS(4157),
    [anon_sym_by] = ACTIONS(4157),
    [anon_sym_select] = ACTIONS(4157),
    [anon_sym_as] = ACTIONS(4162),
    [anon_sym_is] = ACTIONS(4162),
    [anon_sym_DASH_GT] = ACTIONS(4193),
    [anon_sym_with] = ACTIONS(4162),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2861] = {
    [sym_preproc_region] = STATE(2861),
    [sym_preproc_endregion] = STATE(2861),
    [sym_preproc_line] = STATE(2861),
    [sym_preproc_pragma] = STATE(2861),
    [sym_preproc_nullable] = STATE(2861),
    [sym_preproc_error] = STATE(2861),
    [sym_preproc_warning] = STATE(2861),
    [sym_preproc_define] = STATE(2861),
    [sym_preproc_undef] = STATE(2861),
    [sym__identifier_token] = ACTIONS(4157),
    [anon_sym_alias] = ACTIONS(4157),
    [anon_sym_global] = ACTIONS(4157),
    [anon_sym_EQ] = ACTIONS(4162),
    [anon_sym_LBRACK] = ACTIONS(4193),
    [anon_sym_COLON] = ACTIONS(4177),
    [anon_sym_COMMA] = ACTIONS(4177),
    [anon_sym_LPAREN] = ACTIONS(4193),
    [anon_sym_file] = ACTIONS(4157),
    [anon_sym_LT] = ACTIONS(4162),
    [anon_sym_GT] = ACTIONS(4162),
    [anon_sym_where] = ACTIONS(4157),
    [anon_sym_QMARK] = ACTIONS(4196),
    [anon_sym_notnull] = ACTIONS(4157),
    [anon_sym_unmanaged] = ACTIONS(4157),
    [anon_sym_BANG] = ACTIONS(4162),
    [anon_sym_PLUS_PLUS] = ACTIONS(4177),
    [anon_sym_DASH_DASH] = ACTIONS(4177),
    [anon_sym_PLUS] = ACTIONS(4162),
    [anon_sym_DASH] = ACTIONS(4162),
    [anon_sym_STAR] = ACTIONS(4196),
    [anon_sym_SLASH] = ACTIONS(4162),
    [anon_sym_PERCENT] = ACTIONS(4162),
    [anon_sym_CARET] = ACTIONS(4162),
    [anon_sym_PIPE] = ACTIONS(4162),
    [anon_sym_AMP] = ACTIONS(4162),
    [anon_sym_LT_LT] = ACTIONS(4162),
    [anon_sym_GT_GT] = ACTIONS(4162),
    [anon_sym_GT_GT_GT] = ACTIONS(4162),
    [anon_sym_EQ_EQ] = ACTIONS(4177),
    [anon_sym_BANG_EQ] = ACTIONS(4177),
    [anon_sym_GT_EQ] = ACTIONS(4177),
    [anon_sym_LT_EQ] = ACTIONS(4177),
    [anon_sym_DOT] = ACTIONS(4196),
    [anon_sym_scoped] = ACTIONS(4157),
    [anon_sym_var] = ACTIONS(4157),
    [anon_sym_yield] = ACTIONS(4157),
    [anon_sym_switch] = ACTIONS(4162),
    [anon_sym_when] = ACTIONS(4157),
    [anon_sym_DOT_DOT] = ACTIONS(4177),
    [anon_sym_and] = ACTIONS(4162),
    [anon_sym_or] = ACTIONS(4162),
    [anon_sym_PLUS_EQ] = ACTIONS(4177),
    [anon_sym_DASH_EQ] = ACTIONS(4177),
    [anon_sym_STAR_EQ] = ACTIONS(4177),
    [anon_sym_SLASH_EQ] = ACTIONS(4177),
    [anon_sym_PERCENT_EQ] = ACTIONS(4177),
    [anon_sym_AMP_EQ] = ACTIONS(4177),
    [anon_sym_CARET_EQ] = ACTIONS(4177),
    [anon_sym_PIPE_EQ] = ACTIONS(4177),
    [anon_sym_LT_LT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4177),
    [anon_sym_AMP_AMP] = ACTIONS(4177),
    [anon_sym_PIPE_PIPE] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK] = ACTIONS(4162),
    [anon_sym_from] = ACTIONS(4157),
    [anon_sym_into] = ACTIONS(4196),
    [anon_sym_join] = ACTIONS(4157),
    [anon_sym_on] = ACTIONS(4157),
    [anon_sym_equals] = ACTIONS(4157),
    [anon_sym_let] = ACTIONS(4157),
    [anon_sym_orderby] = ACTIONS(4157),
    [anon_sym_ascending] = ACTIONS(4157),
    [anon_sym_descending] = ACTIONS(4157),
    [anon_sym_group] = ACTIONS(4157),
    [anon_sym_by] = ACTIONS(4157),
    [anon_sym_select] = ACTIONS(4157),
    [anon_sym_as] = ACTIONS(4162),
    [anon_sym_is] = ACTIONS(4162),
    [anon_sym_DASH_GT] = ACTIONS(4193),
    [anon_sym_with] = ACTIONS(4162),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4177),
  },
  [2862] = {
    [sym_preproc_region] = STATE(2862),
    [sym_preproc_endregion] = STATE(2862),
    [sym_preproc_line] = STATE(2862),
    [sym_preproc_pragma] = STATE(2862),
    [sym_preproc_nullable] = STATE(2862),
    [sym_preproc_error] = STATE(2862),
    [sym_preproc_warning] = STATE(2862),
    [sym_preproc_define] = STATE(2862),
    [sym_preproc_undef] = STATE(2862),
    [sym__identifier_token] = ACTIONS(4157),
    [anon_sym_alias] = ACTIONS(4157),
    [anon_sym_global] = ACTIONS(4157),
    [anon_sym_EQ] = ACTIONS(4162),
    [anon_sym_LBRACK] = ACTIONS(4193),
    [anon_sym_COLON] = ACTIONS(4159),
    [anon_sym_LPAREN] = ACTIONS(4193),
    [anon_sym_LBRACE] = ACTIONS(4168),
    [anon_sym_file] = ACTIONS(4157),
    [anon_sym_LT] = ACTIONS(4162),
    [anon_sym_GT] = ACTIONS(4162),
    [anon_sym_where] = ACTIONS(4157),
    [anon_sym_QMARK] = ACTIONS(4196),
    [anon_sym_notnull] = ACTIONS(4157),
    [anon_sym_unmanaged] = ACTIONS(4157),
    [anon_sym_BANG] = ACTIONS(4162),
    [anon_sym_PLUS_PLUS] = ACTIONS(4177),
    [anon_sym_DASH_DASH] = ACTIONS(4177),
    [anon_sym_PLUS] = ACTIONS(4162),
    [anon_sym_DASH] = ACTIONS(4162),
    [anon_sym_STAR] = ACTIONS(4196),
    [anon_sym_SLASH] = ACTIONS(4162),
    [anon_sym_PERCENT] = ACTIONS(4162),
    [anon_sym_CARET] = ACTIONS(4162),
    [anon_sym_PIPE] = ACTIONS(4162),
    [anon_sym_AMP] = ACTIONS(4162),
    [anon_sym_LT_LT] = ACTIONS(4162),
    [anon_sym_GT_GT] = ACTIONS(4162),
    [anon_sym_GT_GT_GT] = ACTIONS(4162),
    [anon_sym_EQ_EQ] = ACTIONS(4177),
    [anon_sym_BANG_EQ] = ACTIONS(4177),
    [anon_sym_GT_EQ] = ACTIONS(4177),
    [anon_sym_LT_EQ] = ACTIONS(4177),
    [anon_sym_DOT] = ACTIONS(4196),
    [anon_sym_scoped] = ACTIONS(4157),
    [anon_sym_var] = ACTIONS(4157),
    [anon_sym_yield] = ACTIONS(4157),
    [anon_sym_switch] = ACTIONS(4162),
    [anon_sym_when] = ACTIONS(4174),
    [sym_discard] = ACTIONS(4157),
    [anon_sym_DOT_DOT] = ACTIONS(4177),
    [anon_sym_and] = ACTIONS(4174),
    [anon_sym_or] = ACTIONS(4174),
    [anon_sym_PLUS_EQ] = ACTIONS(4177),
    [anon_sym_DASH_EQ] = ACTIONS(4177),
    [anon_sym_STAR_EQ] = ACTIONS(4177),
    [anon_sym_SLASH_EQ] = ACTIONS(4177),
    [anon_sym_PERCENT_EQ] = ACTIONS(4177),
    [anon_sym_AMP_EQ] = ACTIONS(4177),
    [anon_sym_CARET_EQ] = ACTIONS(4177),
    [anon_sym_PIPE_EQ] = ACTIONS(4177),
    [anon_sym_LT_LT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4177),
    [anon_sym_AMP_AMP] = ACTIONS(4177),
    [anon_sym_PIPE_PIPE] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK] = ACTIONS(4162),
    [anon_sym_from] = ACTIONS(4157),
    [anon_sym_into] = ACTIONS(4157),
    [anon_sym_join] = ACTIONS(4157),
    [anon_sym_on] = ACTIONS(4157),
    [anon_sym_equals] = ACTIONS(4157),
    [anon_sym_let] = ACTIONS(4157),
    [anon_sym_orderby] = ACTIONS(4157),
    [anon_sym_ascending] = ACTIONS(4157),
    [anon_sym_descending] = ACTIONS(4157),
    [anon_sym_group] = ACTIONS(4157),
    [anon_sym_by] = ACTIONS(4157),
    [anon_sym_select] = ACTIONS(4157),
    [anon_sym_as] = ACTIONS(4162),
    [anon_sym_is] = ACTIONS(4162),
    [anon_sym_DASH_GT] = ACTIONS(4193),
    [anon_sym_with] = ACTIONS(4162),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2863] = {
    [sym_preproc_region] = STATE(2863),
    [sym_preproc_endregion] = STATE(2863),
    [sym_preproc_line] = STATE(2863),
    [sym_preproc_pragma] = STATE(2863),
    [sym_preproc_nullable] = STATE(2863),
    [sym_preproc_error] = STATE(2863),
    [sym_preproc_warning] = STATE(2863),
    [sym_preproc_define] = STATE(2863),
    [sym_preproc_undef] = STATE(2863),
    [sym__identifier_token] = ACTIONS(4179),
    [anon_sym_alias] = ACTIONS(4179),
    [anon_sym_global] = ACTIONS(4179),
    [anon_sym_EQ] = ACTIONS(4183),
    [anon_sym_LBRACK] = ACTIONS(4185),
    [anon_sym_COLON] = ACTIONS(4191),
    [anon_sym_COMMA] = ACTIONS(4191),
    [anon_sym_LPAREN] = ACTIONS(4185),
    [anon_sym_file] = ACTIONS(4179),
    [anon_sym_LT] = ACTIONS(4183),
    [anon_sym_GT] = ACTIONS(4183),
    [anon_sym_where] = ACTIONS(4179),
    [anon_sym_QMARK] = ACTIONS(4188),
    [anon_sym_notnull] = ACTIONS(4179),
    [anon_sym_unmanaged] = ACTIONS(4179),
    [anon_sym_BANG] = ACTIONS(4183),
    [anon_sym_PLUS_PLUS] = ACTIONS(4191),
    [anon_sym_DASH_DASH] = ACTIONS(4191),
    [anon_sym_PLUS] = ACTIONS(4183),
    [anon_sym_DASH] = ACTIONS(4183),
    [anon_sym_STAR] = ACTIONS(4188),
    [anon_sym_SLASH] = ACTIONS(4183),
    [anon_sym_PERCENT] = ACTIONS(4183),
    [anon_sym_CARET] = ACTIONS(4183),
    [anon_sym_PIPE] = ACTIONS(4183),
    [anon_sym_AMP] = ACTIONS(4183),
    [anon_sym_LT_LT] = ACTIONS(4183),
    [anon_sym_GT_GT] = ACTIONS(4183),
    [anon_sym_GT_GT_GT] = ACTIONS(4183),
    [anon_sym_EQ_EQ] = ACTIONS(4191),
    [anon_sym_BANG_EQ] = ACTIONS(4191),
    [anon_sym_GT_EQ] = ACTIONS(4191),
    [anon_sym_LT_EQ] = ACTIONS(4191),
    [anon_sym_DOT] = ACTIONS(4188),
    [anon_sym_scoped] = ACTIONS(4179),
    [anon_sym_var] = ACTIONS(4179),
    [anon_sym_yield] = ACTIONS(4179),
    [anon_sym_switch] = ACTIONS(4183),
    [anon_sym_when] = ACTIONS(4179),
    [anon_sym_DOT_DOT] = ACTIONS(4191),
    [anon_sym_and] = ACTIONS(4183),
    [anon_sym_or] = ACTIONS(4183),
    [anon_sym_PLUS_EQ] = ACTIONS(4191),
    [anon_sym_DASH_EQ] = ACTIONS(4191),
    [anon_sym_STAR_EQ] = ACTIONS(4191),
    [anon_sym_SLASH_EQ] = ACTIONS(4191),
    [anon_sym_PERCENT_EQ] = ACTIONS(4191),
    [anon_sym_AMP_EQ] = ACTIONS(4191),
    [anon_sym_CARET_EQ] = ACTIONS(4191),
    [anon_sym_PIPE_EQ] = ACTIONS(4191),
    [anon_sym_LT_LT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4191),
    [anon_sym_AMP_AMP] = ACTIONS(4191),
    [anon_sym_PIPE_PIPE] = ACTIONS(4191),
    [anon_sym_QMARK_QMARK] = ACTIONS(4183),
    [anon_sym_from] = ACTIONS(4179),
    [anon_sym_into] = ACTIONS(4188),
    [anon_sym_join] = ACTIONS(4179),
    [anon_sym_on] = ACTIONS(4179),
    [anon_sym_equals] = ACTIONS(4179),
    [anon_sym_let] = ACTIONS(4179),
    [anon_sym_orderby] = ACTIONS(4179),
    [anon_sym_ascending] = ACTIONS(4179),
    [anon_sym_descending] = ACTIONS(4179),
    [anon_sym_group] = ACTIONS(4179),
    [anon_sym_by] = ACTIONS(4179),
    [anon_sym_select] = ACTIONS(4179),
    [anon_sym_as] = ACTIONS(4183),
    [anon_sym_is] = ACTIONS(4183),
    [anon_sym_DASH_GT] = ACTIONS(4185),
    [anon_sym_with] = ACTIONS(4183),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4191),
  },
  [2864] = {
    [sym_preproc_region] = STATE(2864),
    [sym_preproc_endregion] = STATE(2864),
    [sym_preproc_line] = STATE(2864),
    [sym_preproc_pragma] = STATE(2864),
    [sym_preproc_nullable] = STATE(2864),
    [sym_preproc_error] = STATE(2864),
    [sym_preproc_warning] = STATE(2864),
    [sym_preproc_define] = STATE(2864),
    [sym_preproc_undef] = STATE(2864),
    [sym__identifier_token] = ACTIONS(4179),
    [anon_sym_alias] = ACTIONS(4179),
    [anon_sym_global] = ACTIONS(4179),
    [anon_sym_EQ] = ACTIONS(4183),
    [anon_sym_LBRACK] = ACTIONS(4185),
    [anon_sym_COLON] = ACTIONS(4185),
    [anon_sym_LPAREN] = ACTIONS(4185),
    [anon_sym_LBRACE] = ACTIONS(4181),
    [anon_sym_file] = ACTIONS(4179),
    [anon_sym_LT] = ACTIONS(4183),
    [anon_sym_GT] = ACTIONS(4183),
    [anon_sym_where] = ACTIONS(4179),
    [anon_sym_QMARK] = ACTIONS(4188),
    [anon_sym_notnull] = ACTIONS(4179),
    [anon_sym_unmanaged] = ACTIONS(4179),
    [anon_sym_BANG] = ACTIONS(4183),
    [anon_sym_PLUS_PLUS] = ACTIONS(4191),
    [anon_sym_DASH_DASH] = ACTIONS(4191),
    [anon_sym_PLUS] = ACTIONS(4183),
    [anon_sym_DASH] = ACTIONS(4183),
    [anon_sym_STAR] = ACTIONS(4188),
    [anon_sym_SLASH] = ACTIONS(4183),
    [anon_sym_PERCENT] = ACTIONS(4183),
    [anon_sym_CARET] = ACTIONS(4183),
    [anon_sym_PIPE] = ACTIONS(4183),
    [anon_sym_AMP] = ACTIONS(4183),
    [anon_sym_LT_LT] = ACTIONS(4183),
    [anon_sym_GT_GT] = ACTIONS(4183),
    [anon_sym_GT_GT_GT] = ACTIONS(4183),
    [anon_sym_EQ_EQ] = ACTIONS(4191),
    [anon_sym_BANG_EQ] = ACTIONS(4191),
    [anon_sym_GT_EQ] = ACTIONS(4191),
    [anon_sym_LT_EQ] = ACTIONS(4191),
    [anon_sym_DOT] = ACTIONS(4188),
    [anon_sym_scoped] = ACTIONS(4179),
    [anon_sym_var] = ACTIONS(4179),
    [anon_sym_yield] = ACTIONS(4179),
    [anon_sym_switch] = ACTIONS(4183),
    [anon_sym_when] = ACTIONS(4179),
    [sym_discard] = ACTIONS(4179),
    [anon_sym_DOT_DOT] = ACTIONS(4191),
    [anon_sym_and] = ACTIONS(4179),
    [anon_sym_or] = ACTIONS(4179),
    [anon_sym_PLUS_EQ] = ACTIONS(4191),
    [anon_sym_DASH_EQ] = ACTIONS(4191),
    [anon_sym_STAR_EQ] = ACTIONS(4191),
    [anon_sym_SLASH_EQ] = ACTIONS(4191),
    [anon_sym_PERCENT_EQ] = ACTIONS(4191),
    [anon_sym_AMP_EQ] = ACTIONS(4191),
    [anon_sym_CARET_EQ] = ACTIONS(4191),
    [anon_sym_PIPE_EQ] = ACTIONS(4191),
    [anon_sym_LT_LT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4191),
    [anon_sym_AMP_AMP] = ACTIONS(4191),
    [anon_sym_PIPE_PIPE] = ACTIONS(4191),
    [anon_sym_QMARK_QMARK] = ACTIONS(4183),
    [anon_sym_from] = ACTIONS(4179),
    [anon_sym_into] = ACTIONS(4179),
    [anon_sym_join] = ACTIONS(4179),
    [anon_sym_on] = ACTIONS(4179),
    [anon_sym_equals] = ACTIONS(4179),
    [anon_sym_let] = ACTIONS(4179),
    [anon_sym_orderby] = ACTIONS(4179),
    [anon_sym_ascending] = ACTIONS(4179),
    [anon_sym_descending] = ACTIONS(4179),
    [anon_sym_group] = ACTIONS(4179),
    [anon_sym_by] = ACTIONS(4179),
    [anon_sym_select] = ACTIONS(4179),
    [anon_sym_as] = ACTIONS(4183),
    [anon_sym_is] = ACTIONS(4183),
    [anon_sym_DASH_GT] = ACTIONS(4185),
    [anon_sym_with] = ACTIONS(4183),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2865] = {
    [sym_preproc_region] = STATE(2865),
    [sym_preproc_endregion] = STATE(2865),
    [sym_preproc_line] = STATE(2865),
    [sym_preproc_pragma] = STATE(2865),
    [sym_preproc_nullable] = STATE(2865),
    [sym_preproc_error] = STATE(2865),
    [sym_preproc_warning] = STATE(2865),
    [sym_preproc_define] = STATE(2865),
    [sym_preproc_undef] = STATE(2865),
    [sym__identifier_token] = ACTIONS(4157),
    [anon_sym_alias] = ACTIONS(4157),
    [anon_sym_global] = ACTIONS(4157),
    [anon_sym_EQ] = ACTIONS(4162),
    [anon_sym_LBRACK] = ACTIONS(4193),
    [anon_sym_COLON] = ACTIONS(4193),
    [anon_sym_LPAREN] = ACTIONS(4193),
    [anon_sym_LBRACE] = ACTIONS(4168),
    [anon_sym_file] = ACTIONS(4157),
    [anon_sym_LT] = ACTIONS(4162),
    [anon_sym_GT] = ACTIONS(4162),
    [anon_sym_where] = ACTIONS(4157),
    [anon_sym_QMARK] = ACTIONS(4196),
    [anon_sym_notnull] = ACTIONS(4157),
    [anon_sym_unmanaged] = ACTIONS(4157),
    [anon_sym_BANG] = ACTIONS(4162),
    [anon_sym_PLUS_PLUS] = ACTIONS(4177),
    [anon_sym_DASH_DASH] = ACTIONS(4177),
    [anon_sym_PLUS] = ACTIONS(4162),
    [anon_sym_DASH] = ACTIONS(4162),
    [anon_sym_STAR] = ACTIONS(4196),
    [anon_sym_SLASH] = ACTIONS(4162),
    [anon_sym_PERCENT] = ACTIONS(4162),
    [anon_sym_CARET] = ACTIONS(4162),
    [anon_sym_PIPE] = ACTIONS(4162),
    [anon_sym_AMP] = ACTIONS(4162),
    [anon_sym_LT_LT] = ACTIONS(4162),
    [anon_sym_GT_GT] = ACTIONS(4162),
    [anon_sym_GT_GT_GT] = ACTIONS(4162),
    [anon_sym_EQ_EQ] = ACTIONS(4177),
    [anon_sym_BANG_EQ] = ACTIONS(4177),
    [anon_sym_GT_EQ] = ACTIONS(4177),
    [anon_sym_LT_EQ] = ACTIONS(4177),
    [anon_sym_DOT] = ACTIONS(4196),
    [anon_sym_scoped] = ACTIONS(4157),
    [anon_sym_var] = ACTIONS(4157),
    [anon_sym_yield] = ACTIONS(4157),
    [anon_sym_switch] = ACTIONS(4162),
    [anon_sym_when] = ACTIONS(4157),
    [sym_discard] = ACTIONS(4157),
    [anon_sym_DOT_DOT] = ACTIONS(4177),
    [anon_sym_and] = ACTIONS(4157),
    [anon_sym_or] = ACTIONS(4157),
    [anon_sym_PLUS_EQ] = ACTIONS(4177),
    [anon_sym_DASH_EQ] = ACTIONS(4177),
    [anon_sym_STAR_EQ] = ACTIONS(4177),
    [anon_sym_SLASH_EQ] = ACTIONS(4177),
    [anon_sym_PERCENT_EQ] = ACTIONS(4177),
    [anon_sym_AMP_EQ] = ACTIONS(4177),
    [anon_sym_CARET_EQ] = ACTIONS(4177),
    [anon_sym_PIPE_EQ] = ACTIONS(4177),
    [anon_sym_LT_LT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4177),
    [anon_sym_AMP_AMP] = ACTIONS(4177),
    [anon_sym_PIPE_PIPE] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK] = ACTIONS(4162),
    [anon_sym_from] = ACTIONS(4157),
    [anon_sym_into] = ACTIONS(4157),
    [anon_sym_join] = ACTIONS(4157),
    [anon_sym_on] = ACTIONS(4157),
    [anon_sym_equals] = ACTIONS(4157),
    [anon_sym_let] = ACTIONS(4157),
    [anon_sym_orderby] = ACTIONS(4157),
    [anon_sym_ascending] = ACTIONS(4157),
    [anon_sym_descending] = ACTIONS(4157),
    [anon_sym_group] = ACTIONS(4157),
    [anon_sym_by] = ACTIONS(4157),
    [anon_sym_select] = ACTIONS(4157),
    [anon_sym_as] = ACTIONS(4162),
    [anon_sym_is] = ACTIONS(4162),
    [anon_sym_DASH_GT] = ACTIONS(4193),
    [anon_sym_with] = ACTIONS(4162),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2866] = {
    [sym_preproc_region] = STATE(2866),
    [sym_preproc_endregion] = STATE(2866),
    [sym_preproc_line] = STATE(2866),
    [sym_preproc_pragma] = STATE(2866),
    [sym_preproc_nullable] = STATE(2866),
    [sym_preproc_error] = STATE(2866),
    [sym_preproc_warning] = STATE(2866),
    [sym_preproc_define] = STATE(2866),
    [sym_preproc_undef] = STATE(2866),
    [sym__identifier_token] = ACTIONS(4179),
    [anon_sym_alias] = ACTIONS(4179),
    [anon_sym_global] = ACTIONS(4179),
    [anon_sym_EQ] = ACTIONS(4183),
    [anon_sym_LBRACK] = ACTIONS(4185),
    [anon_sym_COLON] = ACTIONS(4191),
    [anon_sym_COMMA] = ACTIONS(4191),
    [anon_sym_LPAREN] = ACTIONS(4185),
    [anon_sym_file] = ACTIONS(4179),
    [anon_sym_LT] = ACTIONS(4183),
    [anon_sym_GT] = ACTIONS(4183),
    [anon_sym_where] = ACTIONS(4179),
    [anon_sym_QMARK] = ACTIONS(4188),
    [anon_sym_notnull] = ACTIONS(4179),
    [anon_sym_unmanaged] = ACTIONS(4179),
    [anon_sym_BANG] = ACTIONS(4183),
    [anon_sym_PLUS_PLUS] = ACTIONS(4191),
    [anon_sym_DASH_DASH] = ACTIONS(4191),
    [anon_sym_PLUS] = ACTIONS(4183),
    [anon_sym_DASH] = ACTIONS(4183),
    [anon_sym_STAR] = ACTIONS(4188),
    [anon_sym_SLASH] = ACTIONS(4183),
    [anon_sym_PERCENT] = ACTIONS(4183),
    [anon_sym_CARET] = ACTIONS(4183),
    [anon_sym_PIPE] = ACTIONS(4183),
    [anon_sym_AMP] = ACTIONS(4183),
    [anon_sym_LT_LT] = ACTIONS(4183),
    [anon_sym_GT_GT] = ACTIONS(4183),
    [anon_sym_GT_GT_GT] = ACTIONS(4183),
    [anon_sym_EQ_EQ] = ACTIONS(4191),
    [anon_sym_BANG_EQ] = ACTIONS(4191),
    [anon_sym_GT_EQ] = ACTIONS(4191),
    [anon_sym_LT_EQ] = ACTIONS(4191),
    [anon_sym_DOT] = ACTIONS(4188),
    [anon_sym_scoped] = ACTIONS(4179),
    [anon_sym_var] = ACTIONS(4179),
    [anon_sym_yield] = ACTIONS(4179),
    [anon_sym_switch] = ACTIONS(4183),
    [anon_sym_when] = ACTIONS(4179),
    [anon_sym_DOT_DOT] = ACTIONS(4191),
    [anon_sym_and] = ACTIONS(4183),
    [anon_sym_or] = ACTIONS(4183),
    [anon_sym_PLUS_EQ] = ACTIONS(4191),
    [anon_sym_DASH_EQ] = ACTIONS(4191),
    [anon_sym_STAR_EQ] = ACTIONS(4191),
    [anon_sym_SLASH_EQ] = ACTIONS(4191),
    [anon_sym_PERCENT_EQ] = ACTIONS(4191),
    [anon_sym_AMP_EQ] = ACTIONS(4191),
    [anon_sym_CARET_EQ] = ACTIONS(4191),
    [anon_sym_PIPE_EQ] = ACTIONS(4191),
    [anon_sym_LT_LT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4191),
    [anon_sym_AMP_AMP] = ACTIONS(4191),
    [anon_sym_PIPE_PIPE] = ACTIONS(4191),
    [anon_sym_QMARK_QMARK] = ACTIONS(4183),
    [anon_sym_from] = ACTIONS(4179),
    [anon_sym_into] = ACTIONS(4179),
    [anon_sym_join] = ACTIONS(4179),
    [anon_sym_on] = ACTIONS(4179),
    [anon_sym_equals] = ACTIONS(4179),
    [anon_sym_let] = ACTIONS(4179),
    [anon_sym_orderby] = ACTIONS(4179),
    [anon_sym_ascending] = ACTIONS(4179),
    [anon_sym_descending] = ACTIONS(4179),
    [anon_sym_group] = ACTIONS(4179),
    [anon_sym_by] = ACTIONS(4179),
    [anon_sym_select] = ACTIONS(4179),
    [anon_sym_as] = ACTIONS(4183),
    [anon_sym_is] = ACTIONS(4183),
    [anon_sym_DASH_GT] = ACTIONS(4185),
    [anon_sym_with] = ACTIONS(4183),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4191),
  },
  [2867] = {
    [sym_type_argument_list] = STATE(2746),
    [sym_preproc_region] = STATE(2867),
    [sym_preproc_endregion] = STATE(2867),
    [sym_preproc_line] = STATE(2867),
    [sym_preproc_pragma] = STATE(2867),
    [sym_preproc_nullable] = STATE(2867),
    [sym_preproc_error] = STATE(2867),
    [sym_preproc_warning] = STATE(2867),
    [sym_preproc_define] = STATE(2867),
    [sym_preproc_undef] = STATE(2867),
    [sym__identifier_token] = ACTIONS(4138),
    [anon_sym_alias] = ACTIONS(4138),
    [anon_sym_global] = ACTIONS(4138),
    [anon_sym_EQ] = ACTIONS(4435),
    [anon_sym_LBRACK] = ACTIONS(4140),
    [anon_sym_COMMA] = ACTIONS(4140),
    [anon_sym_LPAREN] = ACTIONS(4140),
    [anon_sym_RBRACE] = ACTIONS(4140),
    [anon_sym_file] = ACTIONS(4138),
    [anon_sym_LT] = ACTIONS(4142),
    [anon_sym_GT] = ACTIONS(4138),
    [anon_sym_where] = ACTIONS(4138),
    [anon_sym_QMARK] = ACTIONS(4138),
    [anon_sym_notnull] = ACTIONS(4138),
    [anon_sym_unmanaged] = ACTIONS(4138),
    [anon_sym_BANG] = ACTIONS(4138),
    [anon_sym_PLUS_PLUS] = ACTIONS(4140),
    [anon_sym_DASH_DASH] = ACTIONS(4140),
    [anon_sym_PLUS] = ACTIONS(4138),
    [anon_sym_DASH] = ACTIONS(4138),
    [anon_sym_STAR] = ACTIONS(4138),
    [anon_sym_SLASH] = ACTIONS(4138),
    [anon_sym_PERCENT] = ACTIONS(4138),
    [anon_sym_CARET] = ACTIONS(4138),
    [anon_sym_PIPE] = ACTIONS(4138),
    [anon_sym_AMP] = ACTIONS(4138),
    [anon_sym_LT_LT] = ACTIONS(4138),
    [anon_sym_GT_GT] = ACTIONS(4138),
    [anon_sym_GT_GT_GT] = ACTIONS(4138),
    [anon_sym_EQ_EQ] = ACTIONS(4140),
    [anon_sym_BANG_EQ] = ACTIONS(4140),
    [anon_sym_GT_EQ] = ACTIONS(4140),
    [anon_sym_LT_EQ] = ACTIONS(4140),
    [anon_sym_DOT] = ACTIONS(4138),
    [anon_sym_scoped] = ACTIONS(4138),
    [anon_sym_EQ_GT] = ACTIONS(4145),
    [anon_sym_COLON_COLON] = ACTIONS(4147),
    [anon_sym_var] = ACTIONS(4138),
    [anon_sym_yield] = ACTIONS(4138),
    [anon_sym_switch] = ACTIONS(4138),
    [anon_sym_when] = ACTIONS(4138),
    [anon_sym_DOT_DOT] = ACTIONS(4140),
    [anon_sym_PLUS_EQ] = ACTIONS(4140),
    [anon_sym_DASH_EQ] = ACTIONS(4140),
    [anon_sym_STAR_EQ] = ACTIONS(4140),
    [anon_sym_SLASH_EQ] = ACTIONS(4140),
    [anon_sym_PERCENT_EQ] = ACTIONS(4140),
    [anon_sym_AMP_EQ] = ACTIONS(4140),
    [anon_sym_CARET_EQ] = ACTIONS(4140),
    [anon_sym_PIPE_EQ] = ACTIONS(4140),
    [anon_sym_LT_LT_EQ] = ACTIONS(4140),
    [anon_sym_GT_GT_EQ] = ACTIONS(4140),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4140),
    [anon_sym_AMP_AMP] = ACTIONS(4140),
    [anon_sym_PIPE_PIPE] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK] = ACTIONS(4138),
    [anon_sym_from] = ACTIONS(4138),
    [anon_sym_into] = ACTIONS(4138),
    [anon_sym_join] = ACTIONS(4138),
    [anon_sym_on] = ACTIONS(4138),
    [anon_sym_equals] = ACTIONS(4138),
    [anon_sym_let] = ACTIONS(4138),
    [anon_sym_orderby] = ACTIONS(4138),
    [anon_sym_ascending] = ACTIONS(4138),
    [anon_sym_descending] = ACTIONS(4138),
    [anon_sym_group] = ACTIONS(4138),
    [anon_sym_by] = ACTIONS(4138),
    [anon_sym_select] = ACTIONS(4138),
    [anon_sym_as] = ACTIONS(4138),
    [anon_sym_is] = ACTIONS(4138),
    [anon_sym_DASH_GT] = ACTIONS(4140),
    [anon_sym_with] = ACTIONS(4138),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2868] = {
    [sym_preproc_region] = STATE(2868),
    [sym_preproc_endregion] = STATE(2868),
    [sym_preproc_line] = STATE(2868),
    [sym_preproc_pragma] = STATE(2868),
    [sym_preproc_nullable] = STATE(2868),
    [sym_preproc_error] = STATE(2868),
    [sym_preproc_warning] = STATE(2868),
    [sym_preproc_define] = STATE(2868),
    [sym_preproc_undef] = STATE(2868),
    [sym__identifier_token] = ACTIONS(4179),
    [anon_sym_alias] = ACTIONS(4179),
    [anon_sym_global] = ACTIONS(4179),
    [anon_sym_EQ] = ACTIONS(4183),
    [anon_sym_LBRACK] = ACTIONS(4185),
    [anon_sym_COLON] = ACTIONS(4181),
    [anon_sym_LPAREN] = ACTIONS(4185),
    [anon_sym_LBRACE] = ACTIONS(4181),
    [anon_sym_file] = ACTIONS(4179),
    [anon_sym_LT] = ACTIONS(4183),
    [anon_sym_GT] = ACTIONS(4183),
    [anon_sym_where] = ACTIONS(4179),
    [anon_sym_QMARK] = ACTIONS(4188),
    [anon_sym_notnull] = ACTIONS(4179),
    [anon_sym_unmanaged] = ACTIONS(4179),
    [anon_sym_BANG] = ACTIONS(4183),
    [anon_sym_PLUS_PLUS] = ACTIONS(4191),
    [anon_sym_DASH_DASH] = ACTIONS(4191),
    [anon_sym_PLUS] = ACTIONS(4183),
    [anon_sym_DASH] = ACTIONS(4183),
    [anon_sym_STAR] = ACTIONS(4188),
    [anon_sym_SLASH] = ACTIONS(4183),
    [anon_sym_PERCENT] = ACTIONS(4183),
    [anon_sym_CARET] = ACTIONS(4183),
    [anon_sym_PIPE] = ACTIONS(4183),
    [anon_sym_AMP] = ACTIONS(4183),
    [anon_sym_LT_LT] = ACTIONS(4183),
    [anon_sym_GT_GT] = ACTIONS(4183),
    [anon_sym_GT_GT_GT] = ACTIONS(4183),
    [anon_sym_EQ_EQ] = ACTIONS(4191),
    [anon_sym_BANG_EQ] = ACTIONS(4191),
    [anon_sym_GT_EQ] = ACTIONS(4191),
    [anon_sym_LT_EQ] = ACTIONS(4191),
    [anon_sym_DOT] = ACTIONS(4188),
    [anon_sym_scoped] = ACTIONS(4179),
    [anon_sym_var] = ACTIONS(4179),
    [anon_sym_yield] = ACTIONS(4179),
    [anon_sym_switch] = ACTIONS(4183),
    [anon_sym_when] = ACTIONS(4179),
    [sym_discard] = ACTIONS(4179),
    [anon_sym_DOT_DOT] = ACTIONS(4191),
    [anon_sym_and] = ACTIONS(4179),
    [anon_sym_or] = ACTIONS(4179),
    [anon_sym_PLUS_EQ] = ACTIONS(4191),
    [anon_sym_DASH_EQ] = ACTIONS(4191),
    [anon_sym_STAR_EQ] = ACTIONS(4191),
    [anon_sym_SLASH_EQ] = ACTIONS(4191),
    [anon_sym_PERCENT_EQ] = ACTIONS(4191),
    [anon_sym_AMP_EQ] = ACTIONS(4191),
    [anon_sym_CARET_EQ] = ACTIONS(4191),
    [anon_sym_PIPE_EQ] = ACTIONS(4191),
    [anon_sym_LT_LT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4191),
    [anon_sym_AMP_AMP] = ACTIONS(4191),
    [anon_sym_PIPE_PIPE] = ACTIONS(4191),
    [anon_sym_QMARK_QMARK] = ACTIONS(4183),
    [anon_sym_from] = ACTIONS(4179),
    [anon_sym_into] = ACTIONS(4179),
    [anon_sym_join] = ACTIONS(4179),
    [anon_sym_on] = ACTIONS(4179),
    [anon_sym_equals] = ACTIONS(4179),
    [anon_sym_let] = ACTIONS(4179),
    [anon_sym_orderby] = ACTIONS(4179),
    [anon_sym_ascending] = ACTIONS(4179),
    [anon_sym_descending] = ACTIONS(4179),
    [anon_sym_group] = ACTIONS(4179),
    [anon_sym_by] = ACTIONS(4179),
    [anon_sym_select] = ACTIONS(4179),
    [anon_sym_as] = ACTIONS(4183),
    [anon_sym_is] = ACTIONS(4183),
    [anon_sym_DASH_GT] = ACTIONS(4185),
    [anon_sym_with] = ACTIONS(4183),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2869] = {
    [sym__variable_designation] = STATE(4065),
    [sym_parenthesized_variable_designation] = STATE(3966),
    [sym_identifier] = STATE(3983),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(2869),
    [sym_preproc_endregion] = STATE(2869),
    [sym_preproc_line] = STATE(2869),
    [sym_preproc_pragma] = STATE(2869),
    [sym_preproc_nullable] = STATE(2869),
    [sym_preproc_error] = STATE(2869),
    [sym_preproc_warning] = STATE(2869),
    [sym_preproc_define] = STATE(2869),
    [sym_preproc_undef] = STATE(2869),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_SEMI] = ACTIONS(4437),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4437),
    [anon_sym_COLON] = ACTIONS(4437),
    [anon_sym_COMMA] = ACTIONS(4437),
    [anon_sym_RBRACK] = ACTIONS(4437),
    [anon_sym_LPAREN] = ACTIONS(4437),
    [anon_sym_RPAREN] = ACTIONS(4437),
    [anon_sym_RBRACE] = ACTIONS(4437),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4439),
    [anon_sym_GT] = ACTIONS(4439),
    [anon_sym_in] = ACTIONS(4439),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4439),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4439),
    [anon_sym_PLUS_PLUS] = ACTIONS(4437),
    [anon_sym_DASH_DASH] = ACTIONS(4437),
    [anon_sym_PLUS] = ACTIONS(4439),
    [anon_sym_DASH] = ACTIONS(4439),
    [anon_sym_STAR] = ACTIONS(4437),
    [anon_sym_SLASH] = ACTIONS(4439),
    [anon_sym_PERCENT] = ACTIONS(4437),
    [anon_sym_CARET] = ACTIONS(4437),
    [anon_sym_PIPE] = ACTIONS(4439),
    [anon_sym_AMP] = ACTIONS(4439),
    [anon_sym_LT_LT] = ACTIONS(4437),
    [anon_sym_GT_GT] = ACTIONS(4439),
    [anon_sym_GT_GT_GT] = ACTIONS(4437),
    [anon_sym_EQ_EQ] = ACTIONS(4437),
    [anon_sym_BANG_EQ] = ACTIONS(4437),
    [anon_sym_GT_EQ] = ACTIONS(4437),
    [anon_sym_LT_EQ] = ACTIONS(4437),
    [anon_sym_DOT] = ACTIONS(4439),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_EQ_GT] = ACTIONS(4437),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4439),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4347),
    [anon_sym_DOT_DOT] = ACTIONS(4437),
    [anon_sym_and] = ACTIONS(4439),
    [anon_sym_or] = ACTIONS(4439),
    [anon_sym_AMP_AMP] = ACTIONS(4437),
    [anon_sym_PIPE_PIPE] = ACTIONS(4437),
    [anon_sym_QMARK_QMARK] = ACTIONS(4437),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4439),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4439),
    [anon_sym_is] = ACTIONS(4439),
    [anon_sym_DASH_GT] = ACTIONS(4437),
    [anon_sym_with] = ACTIONS(4439),
    [aux_sym_preproc_if_token3] = ACTIONS(4437),
    [aux_sym_preproc_else_token1] = ACTIONS(4437),
    [aux_sym_preproc_elif_token1] = ACTIONS(4437),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2870] = {
    [sym__name] = STATE(3365),
    [sym_alias_qualified_name] = STATE(3486),
    [sym__simple_name] = STATE(3486),
    [sym_qualified_name] = STATE(3486),
    [sym_generic_name] = STATE(3326),
    [sym_ref_type] = STATE(3368),
    [sym__scoped_base_type] = STATE(3369),
    [sym_identifier] = STATE(3158),
    [sym__reserved_identifier] = STATE(3178),
    [sym_preproc_region] = STATE(2870),
    [sym_preproc_endregion] = STATE(2870),
    [sym_preproc_line] = STATE(2870),
    [sym_preproc_pragma] = STATE(2870),
    [sym_preproc_nullable] = STATE(2870),
    [sym_preproc_error] = STATE(2870),
    [sym_preproc_warning] = STATE(2870),
    [sym_preproc_define] = STATE(2870),
    [sym_preproc_undef] = STATE(2870),
    [sym__identifier_token] = ACTIONS(4104),
    [anon_sym_alias] = ACTIONS(4107),
    [anon_sym_global] = ACTIONS(4107),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_COLON] = ACTIONS(3995),
    [anon_sym_COMMA] = ACTIONS(3993),
    [anon_sym_LPAREN] = ACTIONS(3993),
    [anon_sym_ref] = ACTIONS(4110),
    [anon_sym_LBRACE] = ACTIONS(3993),
    [anon_sym_file] = ACTIONS(4107),
    [anon_sym_LT] = ACTIONS(3995),
    [anon_sym_GT] = ACTIONS(3995),
    [anon_sym_where] = ACTIONS(4107),
    [anon_sym_QMARK] = ACTIONS(3995),
    [anon_sym_notnull] = ACTIONS(4107),
    [anon_sym_unmanaged] = ACTIONS(4107),
    [anon_sym_BANG] = ACTIONS(3995),
    [anon_sym_PLUS_PLUS] = ACTIONS(3993),
    [anon_sym_DASH_DASH] = ACTIONS(3993),
    [anon_sym_PLUS] = ACTIONS(3995),
    [anon_sym_DASH] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3993),
    [anon_sym_SLASH] = ACTIONS(3995),
    [anon_sym_PERCENT] = ACTIONS(3993),
    [anon_sym_CARET] = ACTIONS(3993),
    [anon_sym_PIPE] = ACTIONS(3995),
    [anon_sym_AMP] = ACTIONS(3995),
    [anon_sym_LT_LT] = ACTIONS(3993),
    [anon_sym_GT_GT] = ACTIONS(3995),
    [anon_sym_GT_GT_GT] = ACTIONS(3993),
    [anon_sym_EQ_EQ] = ACTIONS(3993),
    [anon_sym_BANG_EQ] = ACTIONS(3993),
    [anon_sym_GT_EQ] = ACTIONS(3993),
    [anon_sym_LT_EQ] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3995),
    [anon_sym_scoped] = ACTIONS(4107),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(4107),
    [anon_sym_yield] = ACTIONS(4107),
    [anon_sym_switch] = ACTIONS(3995),
    [anon_sym_when] = ACTIONS(4107),
    [sym_discard] = ACTIONS(3995),
    [anon_sym_DOT_DOT] = ACTIONS(3993),
    [anon_sym_and] = ACTIONS(3995),
    [anon_sym_or] = ACTIONS(3995),
    [anon_sym_AMP_AMP] = ACTIONS(3993),
    [anon_sym_PIPE_PIPE] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK] = ACTIONS(3993),
    [anon_sym_from] = ACTIONS(4107),
    [anon_sym_into] = ACTIONS(4107),
    [anon_sym_join] = ACTIONS(4107),
    [anon_sym_on] = ACTIONS(4107),
    [anon_sym_equals] = ACTIONS(4107),
    [anon_sym_let] = ACTIONS(4107),
    [anon_sym_orderby] = ACTIONS(4107),
    [anon_sym_ascending] = ACTIONS(4107),
    [anon_sym_descending] = ACTIONS(4107),
    [anon_sym_group] = ACTIONS(4107),
    [anon_sym_by] = ACTIONS(4107),
    [anon_sym_select] = ACTIONS(4107),
    [anon_sym_as] = ACTIONS(3995),
    [anon_sym_is] = ACTIONS(3995),
    [anon_sym_DASH_GT] = ACTIONS(3993),
    [anon_sym_with] = ACTIONS(3995),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(3993),
  },
  [2871] = {
    [sym__variable_designation] = STATE(3957),
    [sym_parenthesized_variable_designation] = STATE(3966),
    [sym_identifier] = STATE(3983),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(2871),
    [sym_preproc_endregion] = STATE(2871),
    [sym_preproc_line] = STATE(2871),
    [sym_preproc_pragma] = STATE(2871),
    [sym_preproc_nullable] = STATE(2871),
    [sym_preproc_error] = STATE(2871),
    [sym_preproc_warning] = STATE(2871),
    [sym_preproc_define] = STATE(2871),
    [sym_preproc_undef] = STATE(2871),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_SEMI] = ACTIONS(4441),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4441),
    [anon_sym_COLON] = ACTIONS(4441),
    [anon_sym_COMMA] = ACTIONS(4441),
    [anon_sym_RBRACK] = ACTIONS(4441),
    [anon_sym_LPAREN] = ACTIONS(4441),
    [anon_sym_RPAREN] = ACTIONS(4441),
    [anon_sym_RBRACE] = ACTIONS(4441),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4443),
    [anon_sym_GT] = ACTIONS(4443),
    [anon_sym_in] = ACTIONS(4443),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4443),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4443),
    [anon_sym_PLUS_PLUS] = ACTIONS(4441),
    [anon_sym_DASH_DASH] = ACTIONS(4441),
    [anon_sym_PLUS] = ACTIONS(4443),
    [anon_sym_DASH] = ACTIONS(4443),
    [anon_sym_STAR] = ACTIONS(4441),
    [anon_sym_SLASH] = ACTIONS(4443),
    [anon_sym_PERCENT] = ACTIONS(4441),
    [anon_sym_CARET] = ACTIONS(4441),
    [anon_sym_PIPE] = ACTIONS(4443),
    [anon_sym_AMP] = ACTIONS(4443),
    [anon_sym_LT_LT] = ACTIONS(4441),
    [anon_sym_GT_GT] = ACTIONS(4443),
    [anon_sym_GT_GT_GT] = ACTIONS(4441),
    [anon_sym_EQ_EQ] = ACTIONS(4441),
    [anon_sym_BANG_EQ] = ACTIONS(4441),
    [anon_sym_GT_EQ] = ACTIONS(4441),
    [anon_sym_LT_EQ] = ACTIONS(4441),
    [anon_sym_DOT] = ACTIONS(4443),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_EQ_GT] = ACTIONS(4441),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4443),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4347),
    [anon_sym_DOT_DOT] = ACTIONS(4441),
    [anon_sym_and] = ACTIONS(4443),
    [anon_sym_or] = ACTIONS(4443),
    [anon_sym_AMP_AMP] = ACTIONS(4441),
    [anon_sym_PIPE_PIPE] = ACTIONS(4441),
    [anon_sym_QMARK_QMARK] = ACTIONS(4441),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4443),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4443),
    [anon_sym_is] = ACTIONS(4443),
    [anon_sym_DASH_GT] = ACTIONS(4441),
    [anon_sym_with] = ACTIONS(4443),
    [aux_sym_preproc_if_token3] = ACTIONS(4441),
    [aux_sym_preproc_else_token1] = ACTIONS(4441),
    [aux_sym_preproc_elif_token1] = ACTIONS(4441),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2872] = {
    [sym_preproc_region] = STATE(2872),
    [sym_preproc_endregion] = STATE(2872),
    [sym_preproc_line] = STATE(2872),
    [sym_preproc_pragma] = STATE(2872),
    [sym_preproc_nullable] = STATE(2872),
    [sym_preproc_error] = STATE(2872),
    [sym_preproc_warning] = STATE(2872),
    [sym_preproc_define] = STATE(2872),
    [sym_preproc_undef] = STATE(2872),
    [sym__identifier_token] = ACTIONS(4179),
    [anon_sym_alias] = ACTIONS(4179),
    [anon_sym_global] = ACTIONS(4179),
    [anon_sym_EQ] = ACTIONS(4183),
    [anon_sym_LBRACK] = ACTIONS(4185),
    [anon_sym_COMMA] = ACTIONS(4185),
    [anon_sym_LPAREN] = ACTIONS(4185),
    [anon_sym_LBRACE] = ACTIONS(4181),
    [anon_sym_file] = ACTIONS(4179),
    [anon_sym_LT] = ACTIONS(4188),
    [anon_sym_GT] = ACTIONS(4188),
    [anon_sym_where] = ACTIONS(4188),
    [anon_sym_QMARK] = ACTIONS(4188),
    [anon_sym_notnull] = ACTIONS(4179),
    [anon_sym_unmanaged] = ACTIONS(4179),
    [anon_sym_BANG] = ACTIONS(4188),
    [anon_sym_PLUS_PLUS] = ACTIONS(4185),
    [anon_sym_DASH_DASH] = ACTIONS(4185),
    [anon_sym_PLUS] = ACTIONS(4188),
    [anon_sym_DASH] = ACTIONS(4188),
    [anon_sym_STAR] = ACTIONS(4188),
    [anon_sym_SLASH] = ACTIONS(4188),
    [anon_sym_PERCENT] = ACTIONS(4188),
    [anon_sym_CARET] = ACTIONS(4188),
    [anon_sym_PIPE] = ACTIONS(4188),
    [anon_sym_AMP] = ACTIONS(4188),
    [anon_sym_LT_LT] = ACTIONS(4188),
    [anon_sym_GT_GT] = ACTIONS(4188),
    [anon_sym_GT_GT_GT] = ACTIONS(4188),
    [anon_sym_EQ_EQ] = ACTIONS(4185),
    [anon_sym_BANG_EQ] = ACTIONS(4185),
    [anon_sym_GT_EQ] = ACTIONS(4185),
    [anon_sym_LT_EQ] = ACTIONS(4185),
    [anon_sym_DOT] = ACTIONS(4188),
    [anon_sym_scoped] = ACTIONS(4179),
    [anon_sym_var] = ACTIONS(4179),
    [anon_sym_yield] = ACTIONS(4179),
    [anon_sym_switch] = ACTIONS(4188),
    [anon_sym_when] = ACTIONS(4179),
    [sym_discard] = ACTIONS(4179),
    [anon_sym_DOT_DOT] = ACTIONS(4185),
    [anon_sym_and] = ACTIONS(4188),
    [anon_sym_or] = ACTIONS(4188),
    [anon_sym_PLUS_EQ] = ACTIONS(4191),
    [anon_sym_DASH_EQ] = ACTIONS(4191),
    [anon_sym_STAR_EQ] = ACTIONS(4191),
    [anon_sym_SLASH_EQ] = ACTIONS(4191),
    [anon_sym_PERCENT_EQ] = ACTIONS(4191),
    [anon_sym_AMP_EQ] = ACTIONS(4191),
    [anon_sym_CARET_EQ] = ACTIONS(4191),
    [anon_sym_PIPE_EQ] = ACTIONS(4191),
    [anon_sym_LT_LT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4191),
    [anon_sym_AMP_AMP] = ACTIONS(4185),
    [anon_sym_PIPE_PIPE] = ACTIONS(4185),
    [anon_sym_QMARK_QMARK] = ACTIONS(4188),
    [anon_sym_from] = ACTIONS(4188),
    [anon_sym_into] = ACTIONS(4188),
    [anon_sym_join] = ACTIONS(4188),
    [anon_sym_on] = ACTIONS(4179),
    [anon_sym_equals] = ACTIONS(4179),
    [anon_sym_let] = ACTIONS(4188),
    [anon_sym_orderby] = ACTIONS(4188),
    [anon_sym_ascending] = ACTIONS(4188),
    [anon_sym_descending] = ACTIONS(4188),
    [anon_sym_group] = ACTIONS(4188),
    [anon_sym_by] = ACTIONS(4179),
    [anon_sym_select] = ACTIONS(4188),
    [anon_sym_as] = ACTIONS(4188),
    [anon_sym_is] = ACTIONS(4188),
    [anon_sym_DASH_GT] = ACTIONS(4185),
    [anon_sym_with] = ACTIONS(4188),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2873] = {
    [sym_preproc_region] = STATE(2873),
    [sym_preproc_endregion] = STATE(2873),
    [sym_preproc_line] = STATE(2873),
    [sym_preproc_pragma] = STATE(2873),
    [sym_preproc_nullable] = STATE(2873),
    [sym_preproc_error] = STATE(2873),
    [sym_preproc_warning] = STATE(2873),
    [sym_preproc_define] = STATE(2873),
    [sym_preproc_undef] = STATE(2873),
    [sym__identifier_token] = ACTIONS(4157),
    [anon_sym_alias] = ACTIONS(4157),
    [anon_sym_global] = ACTIONS(4157),
    [anon_sym_EQ] = ACTIONS(4162),
    [anon_sym_LBRACK] = ACTIONS(4193),
    [anon_sym_COLON] = ACTIONS(4177),
    [anon_sym_COMMA] = ACTIONS(4177),
    [anon_sym_LPAREN] = ACTIONS(4193),
    [anon_sym_file] = ACTIONS(4157),
    [anon_sym_LT] = ACTIONS(4162),
    [anon_sym_GT] = ACTIONS(4162),
    [anon_sym_where] = ACTIONS(4157),
    [anon_sym_QMARK] = ACTIONS(4196),
    [anon_sym_notnull] = ACTIONS(4157),
    [anon_sym_unmanaged] = ACTIONS(4157),
    [anon_sym_BANG] = ACTIONS(4162),
    [anon_sym_PLUS_PLUS] = ACTIONS(4177),
    [anon_sym_DASH_DASH] = ACTIONS(4177),
    [anon_sym_PLUS] = ACTIONS(4162),
    [anon_sym_DASH] = ACTIONS(4162),
    [anon_sym_STAR] = ACTIONS(4196),
    [anon_sym_SLASH] = ACTIONS(4162),
    [anon_sym_PERCENT] = ACTIONS(4162),
    [anon_sym_CARET] = ACTIONS(4162),
    [anon_sym_PIPE] = ACTIONS(4162),
    [anon_sym_AMP] = ACTIONS(4162),
    [anon_sym_LT_LT] = ACTIONS(4162),
    [anon_sym_GT_GT] = ACTIONS(4162),
    [anon_sym_GT_GT_GT] = ACTIONS(4162),
    [anon_sym_EQ_EQ] = ACTIONS(4177),
    [anon_sym_BANG_EQ] = ACTIONS(4177),
    [anon_sym_GT_EQ] = ACTIONS(4177),
    [anon_sym_LT_EQ] = ACTIONS(4177),
    [anon_sym_DOT] = ACTIONS(4196),
    [anon_sym_scoped] = ACTIONS(4157),
    [anon_sym_var] = ACTIONS(4157),
    [anon_sym_yield] = ACTIONS(4157),
    [anon_sym_switch] = ACTIONS(4162),
    [anon_sym_when] = ACTIONS(4157),
    [anon_sym_DOT_DOT] = ACTIONS(4177),
    [anon_sym_and] = ACTIONS(4162),
    [anon_sym_or] = ACTIONS(4162),
    [anon_sym_PLUS_EQ] = ACTIONS(4177),
    [anon_sym_DASH_EQ] = ACTIONS(4177),
    [anon_sym_STAR_EQ] = ACTIONS(4177),
    [anon_sym_SLASH_EQ] = ACTIONS(4177),
    [anon_sym_PERCENT_EQ] = ACTIONS(4177),
    [anon_sym_AMP_EQ] = ACTIONS(4177),
    [anon_sym_CARET_EQ] = ACTIONS(4177),
    [anon_sym_PIPE_EQ] = ACTIONS(4177),
    [anon_sym_LT_LT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4177),
    [anon_sym_AMP_AMP] = ACTIONS(4177),
    [anon_sym_PIPE_PIPE] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK] = ACTIONS(4162),
    [anon_sym_from] = ACTIONS(4157),
    [anon_sym_into] = ACTIONS(4157),
    [anon_sym_join] = ACTIONS(4157),
    [anon_sym_on] = ACTIONS(4157),
    [anon_sym_equals] = ACTIONS(4157),
    [anon_sym_let] = ACTIONS(4157),
    [anon_sym_orderby] = ACTIONS(4157),
    [anon_sym_ascending] = ACTIONS(4157),
    [anon_sym_descending] = ACTIONS(4157),
    [anon_sym_group] = ACTIONS(4157),
    [anon_sym_by] = ACTIONS(4157),
    [anon_sym_select] = ACTIONS(4157),
    [anon_sym_as] = ACTIONS(4162),
    [anon_sym_is] = ACTIONS(4162),
    [anon_sym_DASH_GT] = ACTIONS(4193),
    [anon_sym_with] = ACTIONS(4162),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4177),
  },
  [2874] = {
    [sym__variable_designation] = STATE(4040),
    [sym_parenthesized_variable_designation] = STATE(3966),
    [sym_identifier] = STATE(3983),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(2874),
    [sym_preproc_endregion] = STATE(2874),
    [sym_preproc_line] = STATE(2874),
    [sym_preproc_pragma] = STATE(2874),
    [sym_preproc_nullable] = STATE(2874),
    [sym_preproc_error] = STATE(2874),
    [sym_preproc_warning] = STATE(2874),
    [sym_preproc_define] = STATE(2874),
    [sym_preproc_undef] = STATE(2874),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_SEMI] = ACTIONS(4399),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4399),
    [anon_sym_COLON] = ACTIONS(4399),
    [anon_sym_COMMA] = ACTIONS(4399),
    [anon_sym_RBRACK] = ACTIONS(4399),
    [anon_sym_LPAREN] = ACTIONS(4399),
    [anon_sym_RPAREN] = ACTIONS(4399),
    [anon_sym_RBRACE] = ACTIONS(4399),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4401),
    [anon_sym_GT] = ACTIONS(4401),
    [anon_sym_in] = ACTIONS(4401),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4401),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4401),
    [anon_sym_PLUS_PLUS] = ACTIONS(4399),
    [anon_sym_DASH_DASH] = ACTIONS(4399),
    [anon_sym_PLUS] = ACTIONS(4401),
    [anon_sym_DASH] = ACTIONS(4401),
    [anon_sym_STAR] = ACTIONS(4399),
    [anon_sym_SLASH] = ACTIONS(4401),
    [anon_sym_PERCENT] = ACTIONS(4399),
    [anon_sym_CARET] = ACTIONS(4399),
    [anon_sym_PIPE] = ACTIONS(4401),
    [anon_sym_AMP] = ACTIONS(4401),
    [anon_sym_LT_LT] = ACTIONS(4399),
    [anon_sym_GT_GT] = ACTIONS(4401),
    [anon_sym_GT_GT_GT] = ACTIONS(4399),
    [anon_sym_EQ_EQ] = ACTIONS(4399),
    [anon_sym_BANG_EQ] = ACTIONS(4399),
    [anon_sym_GT_EQ] = ACTIONS(4399),
    [anon_sym_LT_EQ] = ACTIONS(4399),
    [anon_sym_DOT] = ACTIONS(4401),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_EQ_GT] = ACTIONS(4399),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4401),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4347),
    [anon_sym_DOT_DOT] = ACTIONS(4399),
    [anon_sym_and] = ACTIONS(4401),
    [anon_sym_or] = ACTIONS(4401),
    [anon_sym_AMP_AMP] = ACTIONS(4399),
    [anon_sym_PIPE_PIPE] = ACTIONS(4399),
    [anon_sym_QMARK_QMARK] = ACTIONS(4399),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4401),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4401),
    [anon_sym_is] = ACTIONS(4401),
    [anon_sym_DASH_GT] = ACTIONS(4399),
    [anon_sym_with] = ACTIONS(4401),
    [aux_sym_preproc_if_token3] = ACTIONS(4399),
    [aux_sym_preproc_else_token1] = ACTIONS(4399),
    [aux_sym_preproc_elif_token1] = ACTIONS(4399),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2875] = {
    [sym_preproc_region] = STATE(2875),
    [sym_preproc_endregion] = STATE(2875),
    [sym_preproc_line] = STATE(2875),
    [sym_preproc_pragma] = STATE(2875),
    [sym_preproc_nullable] = STATE(2875),
    [sym_preproc_error] = STATE(2875),
    [sym_preproc_warning] = STATE(2875),
    [sym_preproc_define] = STATE(2875),
    [sym_preproc_undef] = STATE(2875),
    [sym__identifier_token] = ACTIONS(3995),
    [anon_sym_alias] = ACTIONS(3995),
    [anon_sym_global] = ACTIONS(3995),
    [anon_sym_EQ] = ACTIONS(3995),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_COLON] = ACTIONS(3995),
    [anon_sym_LPAREN] = ACTIONS(3993),
    [anon_sym_return] = ACTIONS(4445),
    [anon_sym_file] = ACTIONS(3995),
    [anon_sym_LT] = ACTIONS(3995),
    [anon_sym_GT] = ACTIONS(3995),
    [anon_sym_where] = ACTIONS(3995),
    [anon_sym_QMARK] = ACTIONS(3995),
    [anon_sym_notnull] = ACTIONS(3995),
    [anon_sym_unmanaged] = ACTIONS(3995),
    [anon_sym_BANG] = ACTIONS(3995),
    [anon_sym_PLUS_PLUS] = ACTIONS(3993),
    [anon_sym_DASH_DASH] = ACTIONS(3993),
    [anon_sym_PLUS] = ACTIONS(3995),
    [anon_sym_DASH] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3995),
    [anon_sym_SLASH] = ACTIONS(3995),
    [anon_sym_PERCENT] = ACTIONS(3995),
    [anon_sym_CARET] = ACTIONS(3995),
    [anon_sym_PIPE] = ACTIONS(3995),
    [anon_sym_AMP] = ACTIONS(3995),
    [anon_sym_LT_LT] = ACTIONS(3995),
    [anon_sym_GT_GT] = ACTIONS(3995),
    [anon_sym_GT_GT_GT] = ACTIONS(3995),
    [anon_sym_EQ_EQ] = ACTIONS(3993),
    [anon_sym_BANG_EQ] = ACTIONS(3993),
    [anon_sym_GT_EQ] = ACTIONS(3993),
    [anon_sym_LT_EQ] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3995),
    [anon_sym_scoped] = ACTIONS(3995),
    [anon_sym_EQ_GT] = ACTIONS(3993),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(3995),
    [anon_sym_break] = ACTIONS(4447),
    [anon_sym_yield] = ACTIONS(3995),
    [anon_sym_switch] = ACTIONS(3995),
    [anon_sym_when] = ACTIONS(3995),
    [anon_sym_DOT_DOT] = ACTIONS(3993),
    [anon_sym_PLUS_EQ] = ACTIONS(3993),
    [anon_sym_DASH_EQ] = ACTIONS(3993),
    [anon_sym_STAR_EQ] = ACTIONS(3993),
    [anon_sym_SLASH_EQ] = ACTIONS(3993),
    [anon_sym_PERCENT_EQ] = ACTIONS(3993),
    [anon_sym_AMP_EQ] = ACTIONS(3993),
    [anon_sym_CARET_EQ] = ACTIONS(3993),
    [anon_sym_PIPE_EQ] = ACTIONS(3993),
    [anon_sym_LT_LT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(3993),
    [anon_sym_AMP_AMP] = ACTIONS(3993),
    [anon_sym_PIPE_PIPE] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK] = ACTIONS(3995),
    [anon_sym_from] = ACTIONS(3995),
    [anon_sym_into] = ACTIONS(3995),
    [anon_sym_join] = ACTIONS(3995),
    [anon_sym_on] = ACTIONS(3995),
    [anon_sym_equals] = ACTIONS(3995),
    [anon_sym_let] = ACTIONS(3995),
    [anon_sym_orderby] = ACTIONS(3995),
    [anon_sym_ascending] = ACTIONS(3995),
    [anon_sym_descending] = ACTIONS(3995),
    [anon_sym_group] = ACTIONS(3995),
    [anon_sym_by] = ACTIONS(3995),
    [anon_sym_select] = ACTIONS(3995),
    [anon_sym_as] = ACTIONS(3995),
    [anon_sym_is] = ACTIONS(3995),
    [anon_sym_DASH_GT] = ACTIONS(3993),
    [anon_sym_with] = ACTIONS(3995),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2876] = {
    [sym_preproc_region] = STATE(2876),
    [sym_preproc_endregion] = STATE(2876),
    [sym_preproc_line] = STATE(2876),
    [sym_preproc_pragma] = STATE(2876),
    [sym_preproc_nullable] = STATE(2876),
    [sym_preproc_error] = STATE(2876),
    [sym_preproc_warning] = STATE(2876),
    [sym_preproc_define] = STATE(2876),
    [sym_preproc_undef] = STATE(2876),
    [sym__identifier_token] = ACTIONS(4157),
    [anon_sym_alias] = ACTIONS(4157),
    [anon_sym_global] = ACTIONS(4157),
    [anon_sym_EQ] = ACTIONS(4162),
    [anon_sym_LBRACK] = ACTIONS(4164),
    [anon_sym_COMMA] = ACTIONS(4159),
    [anon_sym_LPAREN] = ACTIONS(4164),
    [anon_sym_LBRACE] = ACTIONS(4168),
    [anon_sym_file] = ACTIONS(4157),
    [anon_sym_LT] = ACTIONS(4170),
    [anon_sym_GT] = ACTIONS(4170),
    [anon_sym_where] = ACTIONS(4174),
    [anon_sym_QMARK] = ACTIONS(4170),
    [anon_sym_notnull] = ACTIONS(4157),
    [anon_sym_unmanaged] = ACTIONS(4157),
    [anon_sym_BANG] = ACTIONS(4170),
    [anon_sym_PLUS_PLUS] = ACTIONS(4164),
    [anon_sym_DASH_DASH] = ACTIONS(4164),
    [anon_sym_PLUS] = ACTIONS(4170),
    [anon_sym_DASH] = ACTIONS(4170),
    [anon_sym_STAR] = ACTIONS(4170),
    [anon_sym_SLASH] = ACTIONS(4170),
    [anon_sym_PERCENT] = ACTIONS(4170),
    [anon_sym_CARET] = ACTIONS(4170),
    [anon_sym_PIPE] = ACTIONS(4170),
    [anon_sym_AMP] = ACTIONS(4170),
    [anon_sym_LT_LT] = ACTIONS(4170),
    [anon_sym_GT_GT] = ACTIONS(4170),
    [anon_sym_GT_GT_GT] = ACTIONS(4170),
    [anon_sym_EQ_EQ] = ACTIONS(4164),
    [anon_sym_BANG_EQ] = ACTIONS(4164),
    [anon_sym_GT_EQ] = ACTIONS(4164),
    [anon_sym_LT_EQ] = ACTIONS(4164),
    [anon_sym_DOT] = ACTIONS(4170),
    [anon_sym_scoped] = ACTIONS(4157),
    [anon_sym_var] = ACTIONS(4157),
    [anon_sym_yield] = ACTIONS(4157),
    [anon_sym_switch] = ACTIONS(4170),
    [anon_sym_when] = ACTIONS(4157),
    [sym_discard] = ACTIONS(4157),
    [anon_sym_DOT_DOT] = ACTIONS(4164),
    [anon_sym_and] = ACTIONS(4174),
    [anon_sym_or] = ACTIONS(4174),
    [anon_sym_PLUS_EQ] = ACTIONS(4177),
    [anon_sym_DASH_EQ] = ACTIONS(4177),
    [anon_sym_STAR_EQ] = ACTIONS(4177),
    [anon_sym_SLASH_EQ] = ACTIONS(4177),
    [anon_sym_PERCENT_EQ] = ACTIONS(4177),
    [anon_sym_AMP_EQ] = ACTIONS(4177),
    [anon_sym_CARET_EQ] = ACTIONS(4177),
    [anon_sym_PIPE_EQ] = ACTIONS(4177),
    [anon_sym_LT_LT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4177),
    [anon_sym_AMP_AMP] = ACTIONS(4164),
    [anon_sym_PIPE_PIPE] = ACTIONS(4164),
    [anon_sym_QMARK_QMARK] = ACTIONS(4170),
    [anon_sym_from] = ACTIONS(4174),
    [anon_sym_into] = ACTIONS(4157),
    [anon_sym_join] = ACTIONS(4174),
    [anon_sym_on] = ACTIONS(4157),
    [anon_sym_equals] = ACTIONS(4157),
    [anon_sym_let] = ACTIONS(4174),
    [anon_sym_orderby] = ACTIONS(4174),
    [anon_sym_ascending] = ACTIONS(4174),
    [anon_sym_descending] = ACTIONS(4174),
    [anon_sym_group] = ACTIONS(4174),
    [anon_sym_by] = ACTIONS(4157),
    [anon_sym_select] = ACTIONS(4174),
    [anon_sym_as] = ACTIONS(4170),
    [anon_sym_is] = ACTIONS(4170),
    [anon_sym_DASH_GT] = ACTIONS(4164),
    [anon_sym_with] = ACTIONS(4170),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2877] = {
    [sym_preproc_region] = STATE(2877),
    [sym_preproc_endregion] = STATE(2877),
    [sym_preproc_line] = STATE(2877),
    [sym_preproc_pragma] = STATE(2877),
    [sym_preproc_nullable] = STATE(2877),
    [sym_preproc_error] = STATE(2877),
    [sym_preproc_warning] = STATE(2877),
    [sym_preproc_define] = STATE(2877),
    [sym_preproc_undef] = STATE(2877),
    [sym__identifier_token] = ACTIONS(3995),
    [anon_sym_alias] = ACTIONS(3995),
    [anon_sym_global] = ACTIONS(3995),
    [anon_sym_EQ] = ACTIONS(3995),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_COLON] = ACTIONS(3995),
    [anon_sym_LPAREN] = ACTIONS(3993),
    [anon_sym_return] = ACTIONS(4449),
    [anon_sym_file] = ACTIONS(3995),
    [anon_sym_LT] = ACTIONS(3995),
    [anon_sym_GT] = ACTIONS(3995),
    [anon_sym_where] = ACTIONS(3995),
    [anon_sym_QMARK] = ACTIONS(3995),
    [anon_sym_notnull] = ACTIONS(3995),
    [anon_sym_unmanaged] = ACTIONS(3995),
    [anon_sym_BANG] = ACTIONS(3995),
    [anon_sym_PLUS_PLUS] = ACTIONS(3993),
    [anon_sym_DASH_DASH] = ACTIONS(3993),
    [anon_sym_PLUS] = ACTIONS(3995),
    [anon_sym_DASH] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3995),
    [anon_sym_SLASH] = ACTIONS(3995),
    [anon_sym_PERCENT] = ACTIONS(3995),
    [anon_sym_CARET] = ACTIONS(3995),
    [anon_sym_PIPE] = ACTIONS(3995),
    [anon_sym_AMP] = ACTIONS(3995),
    [anon_sym_LT_LT] = ACTIONS(3995),
    [anon_sym_GT_GT] = ACTIONS(3995),
    [anon_sym_GT_GT_GT] = ACTIONS(3995),
    [anon_sym_EQ_EQ] = ACTIONS(3993),
    [anon_sym_BANG_EQ] = ACTIONS(3993),
    [anon_sym_GT_EQ] = ACTIONS(3993),
    [anon_sym_LT_EQ] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3995),
    [anon_sym_scoped] = ACTIONS(3995),
    [anon_sym_EQ_GT] = ACTIONS(3993),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(3995),
    [anon_sym_break] = ACTIONS(4451),
    [anon_sym_yield] = ACTIONS(3995),
    [anon_sym_switch] = ACTIONS(3995),
    [anon_sym_when] = ACTIONS(3995),
    [anon_sym_DOT_DOT] = ACTIONS(3993),
    [anon_sym_PLUS_EQ] = ACTIONS(3993),
    [anon_sym_DASH_EQ] = ACTIONS(3993),
    [anon_sym_STAR_EQ] = ACTIONS(3993),
    [anon_sym_SLASH_EQ] = ACTIONS(3993),
    [anon_sym_PERCENT_EQ] = ACTIONS(3993),
    [anon_sym_AMP_EQ] = ACTIONS(3993),
    [anon_sym_CARET_EQ] = ACTIONS(3993),
    [anon_sym_PIPE_EQ] = ACTIONS(3993),
    [anon_sym_LT_LT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(3993),
    [anon_sym_AMP_AMP] = ACTIONS(3993),
    [anon_sym_PIPE_PIPE] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK] = ACTIONS(3995),
    [anon_sym_from] = ACTIONS(3995),
    [anon_sym_into] = ACTIONS(3995),
    [anon_sym_join] = ACTIONS(3995),
    [anon_sym_on] = ACTIONS(3995),
    [anon_sym_equals] = ACTIONS(3995),
    [anon_sym_let] = ACTIONS(3995),
    [anon_sym_orderby] = ACTIONS(3995),
    [anon_sym_ascending] = ACTIONS(3995),
    [anon_sym_descending] = ACTIONS(3995),
    [anon_sym_group] = ACTIONS(3995),
    [anon_sym_by] = ACTIONS(3995),
    [anon_sym_select] = ACTIONS(3995),
    [anon_sym_as] = ACTIONS(3995),
    [anon_sym_is] = ACTIONS(3995),
    [anon_sym_DASH_GT] = ACTIONS(3993),
    [anon_sym_with] = ACTIONS(3995),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2878] = {
    [sym_preproc_region] = STATE(2878),
    [sym_preproc_endregion] = STATE(2878),
    [sym_preproc_line] = STATE(2878),
    [sym_preproc_pragma] = STATE(2878),
    [sym_preproc_nullable] = STATE(2878),
    [sym_preproc_error] = STATE(2878),
    [sym_preproc_warning] = STATE(2878),
    [sym_preproc_define] = STATE(2878),
    [sym_preproc_undef] = STATE(2878),
    [sym__identifier_token] = ACTIONS(4179),
    [anon_sym_alias] = ACTIONS(4179),
    [anon_sym_global] = ACTIONS(4179),
    [anon_sym_EQ] = ACTIONS(4183),
    [anon_sym_LBRACK] = ACTIONS(4185),
    [anon_sym_COMMA] = ACTIONS(4185),
    [anon_sym_LPAREN] = ACTIONS(4185),
    [anon_sym_LBRACE] = ACTIONS(4181),
    [anon_sym_file] = ACTIONS(4179),
    [anon_sym_LT] = ACTIONS(4188),
    [anon_sym_GT] = ACTIONS(4188),
    [anon_sym_where] = ACTIONS(4188),
    [anon_sym_QMARK] = ACTIONS(4188),
    [anon_sym_notnull] = ACTIONS(4179),
    [anon_sym_unmanaged] = ACTIONS(4179),
    [anon_sym_BANG] = ACTIONS(4188),
    [anon_sym_PLUS_PLUS] = ACTIONS(4185),
    [anon_sym_DASH_DASH] = ACTIONS(4185),
    [anon_sym_PLUS] = ACTIONS(4188),
    [anon_sym_DASH] = ACTIONS(4188),
    [anon_sym_STAR] = ACTIONS(4188),
    [anon_sym_SLASH] = ACTIONS(4188),
    [anon_sym_PERCENT] = ACTIONS(4188),
    [anon_sym_CARET] = ACTIONS(4188),
    [anon_sym_PIPE] = ACTIONS(4188),
    [anon_sym_AMP] = ACTIONS(4188),
    [anon_sym_LT_LT] = ACTIONS(4188),
    [anon_sym_GT_GT] = ACTIONS(4188),
    [anon_sym_GT_GT_GT] = ACTIONS(4188),
    [anon_sym_EQ_EQ] = ACTIONS(4185),
    [anon_sym_BANG_EQ] = ACTIONS(4185),
    [anon_sym_GT_EQ] = ACTIONS(4185),
    [anon_sym_LT_EQ] = ACTIONS(4185),
    [anon_sym_DOT] = ACTIONS(4188),
    [anon_sym_scoped] = ACTIONS(4179),
    [anon_sym_var] = ACTIONS(4179),
    [anon_sym_yield] = ACTIONS(4179),
    [anon_sym_switch] = ACTIONS(4188),
    [anon_sym_when] = ACTIONS(4179),
    [sym_discard] = ACTIONS(4179),
    [anon_sym_DOT_DOT] = ACTIONS(4185),
    [anon_sym_and] = ACTIONS(4188),
    [anon_sym_or] = ACTIONS(4188),
    [anon_sym_PLUS_EQ] = ACTIONS(4191),
    [anon_sym_DASH_EQ] = ACTIONS(4191),
    [anon_sym_STAR_EQ] = ACTIONS(4191),
    [anon_sym_SLASH_EQ] = ACTIONS(4191),
    [anon_sym_PERCENT_EQ] = ACTIONS(4191),
    [anon_sym_AMP_EQ] = ACTIONS(4191),
    [anon_sym_CARET_EQ] = ACTIONS(4191),
    [anon_sym_PIPE_EQ] = ACTIONS(4191),
    [anon_sym_LT_LT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4191),
    [anon_sym_AMP_AMP] = ACTIONS(4185),
    [anon_sym_PIPE_PIPE] = ACTIONS(4185),
    [anon_sym_QMARK_QMARK] = ACTIONS(4188),
    [anon_sym_from] = ACTIONS(4188),
    [anon_sym_into] = ACTIONS(4179),
    [anon_sym_join] = ACTIONS(4188),
    [anon_sym_on] = ACTIONS(4179),
    [anon_sym_equals] = ACTIONS(4179),
    [anon_sym_let] = ACTIONS(4188),
    [anon_sym_orderby] = ACTIONS(4188),
    [anon_sym_ascending] = ACTIONS(4188),
    [anon_sym_descending] = ACTIONS(4188),
    [anon_sym_group] = ACTIONS(4188),
    [anon_sym_by] = ACTIONS(4179),
    [anon_sym_select] = ACTIONS(4188),
    [anon_sym_as] = ACTIONS(4188),
    [anon_sym_is] = ACTIONS(4188),
    [anon_sym_DASH_GT] = ACTIONS(4185),
    [anon_sym_with] = ACTIONS(4188),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2879] = {
    [sym__variable_designation] = STATE(4043),
    [sym_parenthesized_variable_designation] = STATE(3966),
    [sym_identifier] = STATE(3983),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(2879),
    [sym_preproc_endregion] = STATE(2879),
    [sym_preproc_line] = STATE(2879),
    [sym_preproc_pragma] = STATE(2879),
    [sym_preproc_nullable] = STATE(2879),
    [sym_preproc_error] = STATE(2879),
    [sym_preproc_warning] = STATE(2879),
    [sym_preproc_define] = STATE(2879),
    [sym_preproc_undef] = STATE(2879),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_SEMI] = ACTIONS(4405),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4405),
    [anon_sym_COLON] = ACTIONS(4405),
    [anon_sym_COMMA] = ACTIONS(4405),
    [anon_sym_RBRACK] = ACTIONS(4405),
    [anon_sym_LPAREN] = ACTIONS(4405),
    [anon_sym_RPAREN] = ACTIONS(4405),
    [anon_sym_RBRACE] = ACTIONS(4405),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4407),
    [anon_sym_GT] = ACTIONS(4407),
    [anon_sym_in] = ACTIONS(4407),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4407),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4407),
    [anon_sym_PLUS_PLUS] = ACTIONS(4405),
    [anon_sym_DASH_DASH] = ACTIONS(4405),
    [anon_sym_PLUS] = ACTIONS(4407),
    [anon_sym_DASH] = ACTIONS(4407),
    [anon_sym_STAR] = ACTIONS(4405),
    [anon_sym_SLASH] = ACTIONS(4407),
    [anon_sym_PERCENT] = ACTIONS(4405),
    [anon_sym_CARET] = ACTIONS(4405),
    [anon_sym_PIPE] = ACTIONS(4407),
    [anon_sym_AMP] = ACTIONS(4407),
    [anon_sym_LT_LT] = ACTIONS(4405),
    [anon_sym_GT_GT] = ACTIONS(4407),
    [anon_sym_GT_GT_GT] = ACTIONS(4405),
    [anon_sym_EQ_EQ] = ACTIONS(4405),
    [anon_sym_BANG_EQ] = ACTIONS(4405),
    [anon_sym_GT_EQ] = ACTIONS(4405),
    [anon_sym_LT_EQ] = ACTIONS(4405),
    [anon_sym_DOT] = ACTIONS(4407),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_EQ_GT] = ACTIONS(4405),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4407),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4347),
    [anon_sym_DOT_DOT] = ACTIONS(4405),
    [anon_sym_and] = ACTIONS(4407),
    [anon_sym_or] = ACTIONS(4407),
    [anon_sym_AMP_AMP] = ACTIONS(4405),
    [anon_sym_PIPE_PIPE] = ACTIONS(4405),
    [anon_sym_QMARK_QMARK] = ACTIONS(4405),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4407),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4407),
    [anon_sym_is] = ACTIONS(4407),
    [anon_sym_DASH_GT] = ACTIONS(4405),
    [anon_sym_with] = ACTIONS(4407),
    [aux_sym_preproc_if_token3] = ACTIONS(4405),
    [aux_sym_preproc_else_token1] = ACTIONS(4405),
    [aux_sym_preproc_elif_token1] = ACTIONS(4405),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2880] = {
    [sym_preproc_region] = STATE(2880),
    [sym_preproc_endregion] = STATE(2880),
    [sym_preproc_line] = STATE(2880),
    [sym_preproc_pragma] = STATE(2880),
    [sym_preproc_nullable] = STATE(2880),
    [sym_preproc_error] = STATE(2880),
    [sym_preproc_warning] = STATE(2880),
    [sym_preproc_define] = STATE(2880),
    [sym_preproc_undef] = STATE(2880),
    [sym__identifier_token] = ACTIONS(4091),
    [anon_sym_alias] = ACTIONS(4091),
    [anon_sym_global] = ACTIONS(4091),
    [anon_sym_EQ] = ACTIONS(3995),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_COLON] = ACTIONS(3995),
    [anon_sym_COMMA] = ACTIONS(4088),
    [anon_sym_LPAREN] = ACTIONS(4088),
    [anon_sym_RPAREN] = ACTIONS(3993),
    [anon_sym_file] = ACTIONS(4091),
    [anon_sym_LT] = ACTIONS(3995),
    [anon_sym_GT] = ACTIONS(3995),
    [anon_sym_where] = ACTIONS(4091),
    [anon_sym_QMARK] = ACTIONS(3995),
    [anon_sym_notnull] = ACTIONS(4091),
    [anon_sym_unmanaged] = ACTIONS(4091),
    [anon_sym_BANG] = ACTIONS(3995),
    [anon_sym_PLUS_PLUS] = ACTIONS(3993),
    [anon_sym_DASH_DASH] = ACTIONS(3993),
    [anon_sym_PLUS] = ACTIONS(3995),
    [anon_sym_DASH] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3995),
    [anon_sym_SLASH] = ACTIONS(3995),
    [anon_sym_PERCENT] = ACTIONS(3995),
    [anon_sym_CARET] = ACTIONS(3995),
    [anon_sym_PIPE] = ACTIONS(3995),
    [anon_sym_AMP] = ACTIONS(3995),
    [anon_sym_LT_LT] = ACTIONS(3995),
    [anon_sym_GT_GT] = ACTIONS(3995),
    [anon_sym_GT_GT_GT] = ACTIONS(3995),
    [anon_sym_EQ_EQ] = ACTIONS(3993),
    [anon_sym_BANG_EQ] = ACTIONS(3993),
    [anon_sym_GT_EQ] = ACTIONS(3993),
    [anon_sym_LT_EQ] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3995),
    [anon_sym_scoped] = ACTIONS(4091),
    [anon_sym_EQ_GT] = ACTIONS(3993),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(4091),
    [anon_sym_yield] = ACTIONS(4091),
    [anon_sym_switch] = ACTIONS(3995),
    [anon_sym_when] = ACTIONS(4091),
    [anon_sym_DOT_DOT] = ACTIONS(3993),
    [anon_sym_PLUS_EQ] = ACTIONS(3993),
    [anon_sym_DASH_EQ] = ACTIONS(3993),
    [anon_sym_STAR_EQ] = ACTIONS(3993),
    [anon_sym_SLASH_EQ] = ACTIONS(3993),
    [anon_sym_PERCENT_EQ] = ACTIONS(3993),
    [anon_sym_AMP_EQ] = ACTIONS(3993),
    [anon_sym_CARET_EQ] = ACTIONS(3993),
    [anon_sym_PIPE_EQ] = ACTIONS(3993),
    [anon_sym_LT_LT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(3993),
    [anon_sym_AMP_AMP] = ACTIONS(3993),
    [anon_sym_PIPE_PIPE] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK] = ACTIONS(3995),
    [anon_sym_from] = ACTIONS(4091),
    [anon_sym_into] = ACTIONS(4091),
    [anon_sym_join] = ACTIONS(4091),
    [anon_sym_on] = ACTIONS(4091),
    [anon_sym_equals] = ACTIONS(4091),
    [anon_sym_let] = ACTIONS(4091),
    [anon_sym_orderby] = ACTIONS(4091),
    [anon_sym_ascending] = ACTIONS(4091),
    [anon_sym_descending] = ACTIONS(4091),
    [anon_sym_group] = ACTIONS(4091),
    [anon_sym_by] = ACTIONS(4091),
    [anon_sym_select] = ACTIONS(4091),
    [anon_sym_as] = ACTIONS(3995),
    [anon_sym_is] = ACTIONS(3995),
    [anon_sym_DASH_GT] = ACTIONS(3993),
    [anon_sym_with] = ACTIONS(3995),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2881] = {
    [sym__variable_designation] = STATE(4167),
    [sym_parenthesized_variable_designation] = STATE(4153),
    [sym_identifier] = STATE(4156),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(2881),
    [sym_preproc_endregion] = STATE(2881),
    [sym_preproc_line] = STATE(2881),
    [sym_preproc_pragma] = STATE(2881),
    [sym_preproc_nullable] = STATE(2881),
    [sym_preproc_error] = STATE(2881),
    [sym_preproc_warning] = STATE(2881),
    [sym_preproc_define] = STATE(2881),
    [sym_preproc_undef] = STATE(2881),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_SEMI] = ACTIONS(4399),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4399),
    [anon_sym_COLON] = ACTIONS(4399),
    [anon_sym_COMMA] = ACTIONS(4399),
    [anon_sym_RBRACK] = ACTIONS(4399),
    [anon_sym_LPAREN] = ACTIONS(4399),
    [anon_sym_RPAREN] = ACTIONS(4399),
    [anon_sym_RBRACE] = ACTIONS(4399),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4401),
    [anon_sym_GT] = ACTIONS(4401),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4401),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4401),
    [anon_sym_PLUS_PLUS] = ACTIONS(4399),
    [anon_sym_DASH_DASH] = ACTIONS(4399),
    [anon_sym_PLUS] = ACTIONS(4401),
    [anon_sym_DASH] = ACTIONS(4401),
    [anon_sym_STAR] = ACTIONS(4399),
    [anon_sym_SLASH] = ACTIONS(4401),
    [anon_sym_PERCENT] = ACTIONS(4399),
    [anon_sym_CARET] = ACTIONS(4399),
    [anon_sym_PIPE] = ACTIONS(4401),
    [anon_sym_AMP] = ACTIONS(4401),
    [anon_sym_LT_LT] = ACTIONS(4399),
    [anon_sym_GT_GT] = ACTIONS(4401),
    [anon_sym_GT_GT_GT] = ACTIONS(4399),
    [anon_sym_EQ_EQ] = ACTIONS(4399),
    [anon_sym_BANG_EQ] = ACTIONS(4399),
    [anon_sym_GT_EQ] = ACTIONS(4399),
    [anon_sym_LT_EQ] = ACTIONS(4399),
    [anon_sym_DOT] = ACTIONS(4401),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_EQ_GT] = ACTIONS(4399),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4401),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4359),
    [anon_sym_DOT_DOT] = ACTIONS(4399),
    [anon_sym_and] = ACTIONS(4401),
    [anon_sym_or] = ACTIONS(4401),
    [anon_sym_AMP_AMP] = ACTIONS(4399),
    [anon_sym_PIPE_PIPE] = ACTIONS(4399),
    [anon_sym_QMARK_QMARK] = ACTIONS(4399),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4339),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4401),
    [anon_sym_is] = ACTIONS(4401),
    [anon_sym_DASH_GT] = ACTIONS(4399),
    [anon_sym_with] = ACTIONS(4401),
    [aux_sym_preproc_if_token3] = ACTIONS(4399),
    [aux_sym_preproc_else_token1] = ACTIONS(4399),
    [aux_sym_preproc_elif_token1] = ACTIONS(4399),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2882] = {
    [sym_preproc_region] = STATE(2882),
    [sym_preproc_endregion] = STATE(2882),
    [sym_preproc_line] = STATE(2882),
    [sym_preproc_pragma] = STATE(2882),
    [sym_preproc_nullable] = STATE(2882),
    [sym_preproc_error] = STATE(2882),
    [sym_preproc_warning] = STATE(2882),
    [sym_preproc_define] = STATE(2882),
    [sym_preproc_undef] = STATE(2882),
    [sym__identifier_token] = ACTIONS(4157),
    [anon_sym_alias] = ACTIONS(4157),
    [anon_sym_global] = ACTIONS(4157),
    [anon_sym_EQ] = ACTIONS(4162),
    [anon_sym_LBRACK] = ACTIONS(4164),
    [anon_sym_LPAREN] = ACTIONS(4164),
    [anon_sym_LBRACE] = ACTIONS(4168),
    [anon_sym_file] = ACTIONS(4157),
    [anon_sym_LT] = ACTIONS(4170),
    [anon_sym_GT] = ACTIONS(4170),
    [anon_sym_where] = ACTIONS(4174),
    [anon_sym_QMARK] = ACTIONS(4170),
    [anon_sym_notnull] = ACTIONS(4157),
    [anon_sym_unmanaged] = ACTIONS(4157),
    [anon_sym_BANG] = ACTIONS(4170),
    [anon_sym_PLUS_PLUS] = ACTIONS(4164),
    [anon_sym_DASH_DASH] = ACTIONS(4164),
    [anon_sym_PLUS] = ACTIONS(4170),
    [anon_sym_DASH] = ACTIONS(4170),
    [anon_sym_STAR] = ACTIONS(4170),
    [anon_sym_SLASH] = ACTIONS(4170),
    [anon_sym_PERCENT] = ACTIONS(4170),
    [anon_sym_CARET] = ACTIONS(4170),
    [anon_sym_PIPE] = ACTIONS(4170),
    [anon_sym_AMP] = ACTIONS(4170),
    [anon_sym_LT_LT] = ACTIONS(4170),
    [anon_sym_GT_GT] = ACTIONS(4170),
    [anon_sym_GT_GT_GT] = ACTIONS(4170),
    [anon_sym_EQ_EQ] = ACTIONS(4164),
    [anon_sym_BANG_EQ] = ACTIONS(4164),
    [anon_sym_GT_EQ] = ACTIONS(4164),
    [anon_sym_LT_EQ] = ACTIONS(4164),
    [anon_sym_DOT] = ACTIONS(4170),
    [anon_sym_scoped] = ACTIONS(4157),
    [anon_sym_var] = ACTIONS(4157),
    [anon_sym_yield] = ACTIONS(4157),
    [anon_sym_switch] = ACTIONS(4170),
    [anon_sym_when] = ACTIONS(4157),
    [sym_discard] = ACTIONS(4157),
    [anon_sym_DOT_DOT] = ACTIONS(4164),
    [anon_sym_and] = ACTIONS(4174),
    [anon_sym_or] = ACTIONS(4174),
    [anon_sym_PLUS_EQ] = ACTIONS(4177),
    [anon_sym_DASH_EQ] = ACTIONS(4177),
    [anon_sym_STAR_EQ] = ACTIONS(4177),
    [anon_sym_SLASH_EQ] = ACTIONS(4177),
    [anon_sym_PERCENT_EQ] = ACTIONS(4177),
    [anon_sym_AMP_EQ] = ACTIONS(4177),
    [anon_sym_CARET_EQ] = ACTIONS(4177),
    [anon_sym_PIPE_EQ] = ACTIONS(4177),
    [anon_sym_LT_LT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4177),
    [anon_sym_AMP_AMP] = ACTIONS(4164),
    [anon_sym_PIPE_PIPE] = ACTIONS(4164),
    [anon_sym_QMARK_QMARK] = ACTIONS(4170),
    [anon_sym_from] = ACTIONS(4174),
    [anon_sym_into] = ACTIONS(4157),
    [anon_sym_join] = ACTIONS(4174),
    [anon_sym_on] = ACTIONS(4157),
    [anon_sym_equals] = ACTIONS(4157),
    [anon_sym_let] = ACTIONS(4174),
    [anon_sym_orderby] = ACTIONS(4174),
    [anon_sym_ascending] = ACTIONS(4157),
    [anon_sym_descending] = ACTIONS(4157),
    [anon_sym_group] = ACTIONS(4174),
    [anon_sym_by] = ACTIONS(4157),
    [anon_sym_select] = ACTIONS(4174),
    [anon_sym_as] = ACTIONS(4170),
    [anon_sym_is] = ACTIONS(4170),
    [anon_sym_DASH_GT] = ACTIONS(4164),
    [anon_sym_with] = ACTIONS(4170),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2883] = {
    [sym_preproc_region] = STATE(2883),
    [sym_preproc_endregion] = STATE(2883),
    [sym_preproc_line] = STATE(2883),
    [sym_preproc_pragma] = STATE(2883),
    [sym_preproc_nullable] = STATE(2883),
    [sym_preproc_error] = STATE(2883),
    [sym_preproc_warning] = STATE(2883),
    [sym_preproc_define] = STATE(2883),
    [sym_preproc_undef] = STATE(2883),
    [sym__identifier_token] = ACTIONS(4453),
    [anon_sym_alias] = ACTIONS(4453),
    [anon_sym_SEMI] = ACTIONS(4455),
    [anon_sym_global] = ACTIONS(4453),
    [anon_sym_LBRACK] = ACTIONS(4455),
    [anon_sym_COLON] = ACTIONS(4455),
    [anon_sym_COMMA] = ACTIONS(4455),
    [anon_sym_RBRACK] = ACTIONS(4455),
    [anon_sym_LPAREN] = ACTIONS(4455),
    [anon_sym_RPAREN] = ACTIONS(4455),
    [anon_sym_LBRACE] = ACTIONS(4455),
    [anon_sym_RBRACE] = ACTIONS(4455),
    [anon_sym_file] = ACTIONS(4453),
    [anon_sym_LT] = ACTIONS(4453),
    [anon_sym_GT] = ACTIONS(4453),
    [anon_sym_in] = ACTIONS(4453),
    [anon_sym_where] = ACTIONS(4453),
    [anon_sym_QMARK] = ACTIONS(4453),
    [anon_sym_notnull] = ACTIONS(4453),
    [anon_sym_unmanaged] = ACTIONS(4453),
    [anon_sym_operator] = ACTIONS(4453),
    [anon_sym_BANG] = ACTIONS(4453),
    [anon_sym_PLUS_PLUS] = ACTIONS(4455),
    [anon_sym_DASH_DASH] = ACTIONS(4455),
    [anon_sym_PLUS] = ACTIONS(4453),
    [anon_sym_DASH] = ACTIONS(4453),
    [anon_sym_STAR] = ACTIONS(4455),
    [anon_sym_SLASH] = ACTIONS(4453),
    [anon_sym_PERCENT] = ACTIONS(4455),
    [anon_sym_CARET] = ACTIONS(4455),
    [anon_sym_PIPE] = ACTIONS(4453),
    [anon_sym_AMP] = ACTIONS(4453),
    [anon_sym_LT_LT] = ACTIONS(4455),
    [anon_sym_GT_GT] = ACTIONS(4453),
    [anon_sym_GT_GT_GT] = ACTIONS(4455),
    [anon_sym_EQ_EQ] = ACTIONS(4455),
    [anon_sym_BANG_EQ] = ACTIONS(4455),
    [anon_sym_GT_EQ] = ACTIONS(4455),
    [anon_sym_LT_EQ] = ACTIONS(4455),
    [anon_sym_this] = ACTIONS(4453),
    [anon_sym_DOT] = ACTIONS(4453),
    [anon_sym_scoped] = ACTIONS(4453),
    [anon_sym_EQ_GT] = ACTIONS(4455),
    [anon_sym_var] = ACTIONS(4453),
    [anon_sym_yield] = ACTIONS(4453),
    [anon_sym_switch] = ACTIONS(4453),
    [anon_sym_when] = ACTIONS(4453),
    [sym_discard] = ACTIONS(4453),
    [anon_sym_DOT_DOT] = ACTIONS(4455),
    [anon_sym_and] = ACTIONS(4453),
    [anon_sym_or] = ACTIONS(4453),
    [anon_sym_AMP_AMP] = ACTIONS(4455),
    [anon_sym_PIPE_PIPE] = ACTIONS(4455),
    [anon_sym_QMARK_QMARK] = ACTIONS(4455),
    [anon_sym_from] = ACTIONS(4453),
    [anon_sym_into] = ACTIONS(4453),
    [anon_sym_join] = ACTIONS(4453),
    [anon_sym_on] = ACTIONS(4453),
    [anon_sym_equals] = ACTIONS(4453),
    [anon_sym_let] = ACTIONS(4453),
    [anon_sym_orderby] = ACTIONS(4453),
    [anon_sym_ascending] = ACTIONS(4453),
    [anon_sym_descending] = ACTIONS(4453),
    [anon_sym_group] = ACTIONS(4453),
    [anon_sym_by] = ACTIONS(4453),
    [anon_sym_select] = ACTIONS(4453),
    [anon_sym_as] = ACTIONS(4453),
    [anon_sym_is] = ACTIONS(4453),
    [anon_sym_DASH_GT] = ACTIONS(4455),
    [anon_sym_with] = ACTIONS(4453),
    [aux_sym_preproc_if_token3] = ACTIONS(4455),
    [aux_sym_preproc_else_token1] = ACTIONS(4455),
    [aux_sym_preproc_elif_token1] = ACTIONS(4455),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2884] = {
    [sym__name] = STATE(5379),
    [sym_alias_qualified_name] = STATE(5341),
    [sym__simple_name] = STATE(5341),
    [sym_qualified_name] = STATE(5341),
    [sym_generic_name] = STATE(5408),
    [sym_ref_type] = STATE(5290),
    [sym__scoped_base_type] = STATE(5345),
    [sym_identifier] = STATE(5076),
    [sym__reserved_identifier] = STATE(5173),
    [sym_preproc_region] = STATE(2884),
    [sym_preproc_endregion] = STATE(2884),
    [sym_preproc_line] = STATE(2884),
    [sym_preproc_pragma] = STATE(2884),
    [sym_preproc_nullable] = STATE(2884),
    [sym_preproc_error] = STATE(2884),
    [sym_preproc_warning] = STATE(2884),
    [sym_preproc_define] = STATE(2884),
    [sym_preproc_undef] = STATE(2884),
    [sym__identifier_token] = ACTIONS(4457),
    [anon_sym_alias] = ACTIONS(4459),
    [anon_sym_global] = ACTIONS(4459),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_COLON] = ACTIONS(3995),
    [anon_sym_COMMA] = ACTIONS(3993),
    [anon_sym_LPAREN] = ACTIONS(3993),
    [anon_sym_ref] = ACTIONS(4461),
    [anon_sym_LBRACE] = ACTIONS(3993),
    [anon_sym_file] = ACTIONS(4459),
    [anon_sym_LT] = ACTIONS(3995),
    [anon_sym_GT] = ACTIONS(3995),
    [anon_sym_where] = ACTIONS(4459),
    [anon_sym_QMARK] = ACTIONS(3995),
    [anon_sym_notnull] = ACTIONS(4459),
    [anon_sym_unmanaged] = ACTIONS(4459),
    [anon_sym_BANG] = ACTIONS(3995),
    [anon_sym_PLUS_PLUS] = ACTIONS(3993),
    [anon_sym_DASH_DASH] = ACTIONS(3993),
    [anon_sym_PLUS] = ACTIONS(3995),
    [anon_sym_DASH] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3993),
    [anon_sym_SLASH] = ACTIONS(3995),
    [anon_sym_PERCENT] = ACTIONS(3993),
    [anon_sym_CARET] = ACTIONS(3993),
    [anon_sym_PIPE] = ACTIONS(3995),
    [anon_sym_AMP] = ACTIONS(3995),
    [anon_sym_LT_LT] = ACTIONS(3993),
    [anon_sym_GT_GT] = ACTIONS(3995),
    [anon_sym_GT_GT_GT] = ACTIONS(3993),
    [anon_sym_EQ_EQ] = ACTIONS(3993),
    [anon_sym_BANG_EQ] = ACTIONS(3993),
    [anon_sym_GT_EQ] = ACTIONS(3993),
    [anon_sym_LT_EQ] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3995),
    [anon_sym_scoped] = ACTIONS(4459),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(4459),
    [anon_sym_yield] = ACTIONS(4459),
    [anon_sym_switch] = ACTIONS(3995),
    [anon_sym_when] = ACTIONS(4459),
    [anon_sym_DOT_DOT] = ACTIONS(3993),
    [anon_sym_and] = ACTIONS(3995),
    [anon_sym_or] = ACTIONS(3995),
    [anon_sym_AMP_AMP] = ACTIONS(3993),
    [anon_sym_PIPE_PIPE] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK] = ACTIONS(3993),
    [anon_sym_from] = ACTIONS(4459),
    [anon_sym_into] = ACTIONS(4463),
    [anon_sym_join] = ACTIONS(4459),
    [anon_sym_on] = ACTIONS(4459),
    [anon_sym_equals] = ACTIONS(4459),
    [anon_sym_let] = ACTIONS(4459),
    [anon_sym_orderby] = ACTIONS(4459),
    [anon_sym_ascending] = ACTIONS(4459),
    [anon_sym_descending] = ACTIONS(4459),
    [anon_sym_group] = ACTIONS(4459),
    [anon_sym_by] = ACTIONS(4459),
    [anon_sym_select] = ACTIONS(4459),
    [anon_sym_as] = ACTIONS(3995),
    [anon_sym_is] = ACTIONS(3995),
    [anon_sym_DASH_GT] = ACTIONS(3993),
    [anon_sym_with] = ACTIONS(3995),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(3993),
  },
  [2885] = {
    [sym_preproc_region] = STATE(2885),
    [sym_preproc_endregion] = STATE(2885),
    [sym_preproc_line] = STATE(2885),
    [sym_preproc_pragma] = STATE(2885),
    [sym_preproc_nullable] = STATE(2885),
    [sym_preproc_error] = STATE(2885),
    [sym_preproc_warning] = STATE(2885),
    [sym_preproc_define] = STATE(2885),
    [sym_preproc_undef] = STATE(2885),
    [sym__identifier_token] = ACTIONS(4466),
    [anon_sym_alias] = ACTIONS(4466),
    [anon_sym_SEMI] = ACTIONS(4468),
    [anon_sym_global] = ACTIONS(4466),
    [anon_sym_LBRACK] = ACTIONS(4468),
    [anon_sym_COLON] = ACTIONS(4468),
    [anon_sym_COMMA] = ACTIONS(4468),
    [anon_sym_RBRACK] = ACTIONS(4468),
    [anon_sym_LPAREN] = ACTIONS(4468),
    [anon_sym_RPAREN] = ACTIONS(4468),
    [anon_sym_LBRACE] = ACTIONS(4468),
    [anon_sym_RBRACE] = ACTIONS(4468),
    [anon_sym_file] = ACTIONS(4466),
    [anon_sym_LT] = ACTIONS(4466),
    [anon_sym_GT] = ACTIONS(4466),
    [anon_sym_in] = ACTIONS(4466),
    [anon_sym_where] = ACTIONS(4466),
    [anon_sym_QMARK] = ACTIONS(4466),
    [anon_sym_notnull] = ACTIONS(4466),
    [anon_sym_unmanaged] = ACTIONS(4466),
    [anon_sym_operator] = ACTIONS(4466),
    [anon_sym_BANG] = ACTIONS(4466),
    [anon_sym_PLUS_PLUS] = ACTIONS(4468),
    [anon_sym_DASH_DASH] = ACTIONS(4468),
    [anon_sym_PLUS] = ACTIONS(4466),
    [anon_sym_DASH] = ACTIONS(4466),
    [anon_sym_STAR] = ACTIONS(4468),
    [anon_sym_SLASH] = ACTIONS(4466),
    [anon_sym_PERCENT] = ACTIONS(4468),
    [anon_sym_CARET] = ACTIONS(4468),
    [anon_sym_PIPE] = ACTIONS(4466),
    [anon_sym_AMP] = ACTIONS(4466),
    [anon_sym_LT_LT] = ACTIONS(4468),
    [anon_sym_GT_GT] = ACTIONS(4466),
    [anon_sym_GT_GT_GT] = ACTIONS(4468),
    [anon_sym_EQ_EQ] = ACTIONS(4468),
    [anon_sym_BANG_EQ] = ACTIONS(4468),
    [anon_sym_GT_EQ] = ACTIONS(4468),
    [anon_sym_LT_EQ] = ACTIONS(4468),
    [anon_sym_this] = ACTIONS(4466),
    [anon_sym_DOT] = ACTIONS(4466),
    [anon_sym_scoped] = ACTIONS(4466),
    [anon_sym_EQ_GT] = ACTIONS(4468),
    [anon_sym_var] = ACTIONS(4466),
    [anon_sym_yield] = ACTIONS(4466),
    [anon_sym_switch] = ACTIONS(4466),
    [anon_sym_when] = ACTIONS(4466),
    [sym_discard] = ACTIONS(4466),
    [anon_sym_DOT_DOT] = ACTIONS(4468),
    [anon_sym_and] = ACTIONS(4466),
    [anon_sym_or] = ACTIONS(4466),
    [anon_sym_AMP_AMP] = ACTIONS(4468),
    [anon_sym_PIPE_PIPE] = ACTIONS(4468),
    [anon_sym_QMARK_QMARK] = ACTIONS(4468),
    [anon_sym_from] = ACTIONS(4466),
    [anon_sym_into] = ACTIONS(4466),
    [anon_sym_join] = ACTIONS(4466),
    [anon_sym_on] = ACTIONS(4466),
    [anon_sym_equals] = ACTIONS(4466),
    [anon_sym_let] = ACTIONS(4466),
    [anon_sym_orderby] = ACTIONS(4466),
    [anon_sym_ascending] = ACTIONS(4466),
    [anon_sym_descending] = ACTIONS(4466),
    [anon_sym_group] = ACTIONS(4466),
    [anon_sym_by] = ACTIONS(4466),
    [anon_sym_select] = ACTIONS(4466),
    [anon_sym_as] = ACTIONS(4466),
    [anon_sym_is] = ACTIONS(4466),
    [anon_sym_DASH_GT] = ACTIONS(4468),
    [anon_sym_with] = ACTIONS(4466),
    [aux_sym_preproc_if_token3] = ACTIONS(4468),
    [aux_sym_preproc_else_token1] = ACTIONS(4468),
    [aux_sym_preproc_elif_token1] = ACTIONS(4468),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2886] = {
    [sym__variable_designation] = STATE(4182),
    [sym_parenthesized_variable_designation] = STATE(4153),
    [sym_identifier] = STATE(4156),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(2886),
    [sym_preproc_endregion] = STATE(2886),
    [sym_preproc_line] = STATE(2886),
    [sym_preproc_pragma] = STATE(2886),
    [sym_preproc_nullable] = STATE(2886),
    [sym_preproc_error] = STATE(2886),
    [sym_preproc_warning] = STATE(2886),
    [sym_preproc_define] = STATE(2886),
    [sym_preproc_undef] = STATE(2886),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_SEMI] = ACTIONS(4405),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4405),
    [anon_sym_COLON] = ACTIONS(4405),
    [anon_sym_COMMA] = ACTIONS(4405),
    [anon_sym_RBRACK] = ACTIONS(4405),
    [anon_sym_LPAREN] = ACTIONS(4405),
    [anon_sym_RPAREN] = ACTIONS(4405),
    [anon_sym_RBRACE] = ACTIONS(4405),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4407),
    [anon_sym_GT] = ACTIONS(4407),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4407),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4407),
    [anon_sym_PLUS_PLUS] = ACTIONS(4405),
    [anon_sym_DASH_DASH] = ACTIONS(4405),
    [anon_sym_PLUS] = ACTIONS(4407),
    [anon_sym_DASH] = ACTIONS(4407),
    [anon_sym_STAR] = ACTIONS(4405),
    [anon_sym_SLASH] = ACTIONS(4407),
    [anon_sym_PERCENT] = ACTIONS(4405),
    [anon_sym_CARET] = ACTIONS(4405),
    [anon_sym_PIPE] = ACTIONS(4407),
    [anon_sym_AMP] = ACTIONS(4407),
    [anon_sym_LT_LT] = ACTIONS(4405),
    [anon_sym_GT_GT] = ACTIONS(4407),
    [anon_sym_GT_GT_GT] = ACTIONS(4405),
    [anon_sym_EQ_EQ] = ACTIONS(4405),
    [anon_sym_BANG_EQ] = ACTIONS(4405),
    [anon_sym_GT_EQ] = ACTIONS(4405),
    [anon_sym_LT_EQ] = ACTIONS(4405),
    [anon_sym_DOT] = ACTIONS(4407),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_EQ_GT] = ACTIONS(4405),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4407),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4359),
    [anon_sym_DOT_DOT] = ACTIONS(4405),
    [anon_sym_and] = ACTIONS(4407),
    [anon_sym_or] = ACTIONS(4407),
    [anon_sym_AMP_AMP] = ACTIONS(4405),
    [anon_sym_PIPE_PIPE] = ACTIONS(4405),
    [anon_sym_QMARK_QMARK] = ACTIONS(4405),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4339),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4407),
    [anon_sym_is] = ACTIONS(4407),
    [anon_sym_DASH_GT] = ACTIONS(4405),
    [anon_sym_with] = ACTIONS(4407),
    [aux_sym_preproc_if_token3] = ACTIONS(4405),
    [aux_sym_preproc_else_token1] = ACTIONS(4405),
    [aux_sym_preproc_elif_token1] = ACTIONS(4405),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2887] = {
    [sym_preproc_region] = STATE(2887),
    [sym_preproc_endregion] = STATE(2887),
    [sym_preproc_line] = STATE(2887),
    [sym_preproc_pragma] = STATE(2887),
    [sym_preproc_nullable] = STATE(2887),
    [sym_preproc_error] = STATE(2887),
    [sym_preproc_warning] = STATE(2887),
    [sym_preproc_define] = STATE(2887),
    [sym_preproc_undef] = STATE(2887),
    [sym__identifier_token] = ACTIONS(4470),
    [anon_sym_alias] = ACTIONS(4470),
    [anon_sym_SEMI] = ACTIONS(4472),
    [anon_sym_global] = ACTIONS(4470),
    [anon_sym_LBRACK] = ACTIONS(4472),
    [anon_sym_COLON] = ACTIONS(4472),
    [anon_sym_COMMA] = ACTIONS(4472),
    [anon_sym_RBRACK] = ACTIONS(4472),
    [anon_sym_LPAREN] = ACTIONS(4472),
    [anon_sym_RPAREN] = ACTIONS(4472),
    [anon_sym_LBRACE] = ACTIONS(4472),
    [anon_sym_RBRACE] = ACTIONS(4472),
    [anon_sym_file] = ACTIONS(4470),
    [anon_sym_LT] = ACTIONS(4470),
    [anon_sym_GT] = ACTIONS(4470),
    [anon_sym_in] = ACTIONS(4470),
    [anon_sym_where] = ACTIONS(4470),
    [anon_sym_QMARK] = ACTIONS(4470),
    [anon_sym_notnull] = ACTIONS(4470),
    [anon_sym_unmanaged] = ACTIONS(4470),
    [anon_sym_operator] = ACTIONS(4470),
    [anon_sym_BANG] = ACTIONS(4470),
    [anon_sym_PLUS_PLUS] = ACTIONS(4472),
    [anon_sym_DASH_DASH] = ACTIONS(4472),
    [anon_sym_PLUS] = ACTIONS(4470),
    [anon_sym_DASH] = ACTIONS(4470),
    [anon_sym_STAR] = ACTIONS(4472),
    [anon_sym_SLASH] = ACTIONS(4470),
    [anon_sym_PERCENT] = ACTIONS(4472),
    [anon_sym_CARET] = ACTIONS(4472),
    [anon_sym_PIPE] = ACTIONS(4470),
    [anon_sym_AMP] = ACTIONS(4470),
    [anon_sym_LT_LT] = ACTIONS(4472),
    [anon_sym_GT_GT] = ACTIONS(4470),
    [anon_sym_GT_GT_GT] = ACTIONS(4472),
    [anon_sym_EQ_EQ] = ACTIONS(4472),
    [anon_sym_BANG_EQ] = ACTIONS(4472),
    [anon_sym_GT_EQ] = ACTIONS(4472),
    [anon_sym_LT_EQ] = ACTIONS(4472),
    [anon_sym_this] = ACTIONS(4470),
    [anon_sym_DOT] = ACTIONS(4470),
    [anon_sym_scoped] = ACTIONS(4470),
    [anon_sym_EQ_GT] = ACTIONS(4472),
    [anon_sym_var] = ACTIONS(4470),
    [anon_sym_yield] = ACTIONS(4470),
    [anon_sym_switch] = ACTIONS(4470),
    [anon_sym_when] = ACTIONS(4470),
    [sym_discard] = ACTIONS(4470),
    [anon_sym_DOT_DOT] = ACTIONS(4472),
    [anon_sym_and] = ACTIONS(4470),
    [anon_sym_or] = ACTIONS(4470),
    [anon_sym_AMP_AMP] = ACTIONS(4472),
    [anon_sym_PIPE_PIPE] = ACTIONS(4472),
    [anon_sym_QMARK_QMARK] = ACTIONS(4472),
    [anon_sym_from] = ACTIONS(4470),
    [anon_sym_into] = ACTIONS(4470),
    [anon_sym_join] = ACTIONS(4470),
    [anon_sym_on] = ACTIONS(4470),
    [anon_sym_equals] = ACTIONS(4470),
    [anon_sym_let] = ACTIONS(4470),
    [anon_sym_orderby] = ACTIONS(4470),
    [anon_sym_ascending] = ACTIONS(4470),
    [anon_sym_descending] = ACTIONS(4470),
    [anon_sym_group] = ACTIONS(4470),
    [anon_sym_by] = ACTIONS(4470),
    [anon_sym_select] = ACTIONS(4470),
    [anon_sym_as] = ACTIONS(4470),
    [anon_sym_is] = ACTIONS(4470),
    [anon_sym_DASH_GT] = ACTIONS(4472),
    [anon_sym_with] = ACTIONS(4470),
    [aux_sym_preproc_if_token3] = ACTIONS(4472),
    [aux_sym_preproc_else_token1] = ACTIONS(4472),
    [aux_sym_preproc_elif_token1] = ACTIONS(4472),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2888] = {
    [sym__variable_designation] = STATE(4207),
    [sym_parenthesized_variable_designation] = STATE(4153),
    [sym_identifier] = STATE(4156),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(2888),
    [sym_preproc_endregion] = STATE(2888),
    [sym_preproc_line] = STATE(2888),
    [sym_preproc_pragma] = STATE(2888),
    [sym_preproc_nullable] = STATE(2888),
    [sym_preproc_error] = STATE(2888),
    [sym_preproc_warning] = STATE(2888),
    [sym_preproc_define] = STATE(2888),
    [sym_preproc_undef] = STATE(2888),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_SEMI] = ACTIONS(4437),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4437),
    [anon_sym_COLON] = ACTIONS(4437),
    [anon_sym_COMMA] = ACTIONS(4437),
    [anon_sym_RBRACK] = ACTIONS(4437),
    [anon_sym_LPAREN] = ACTIONS(4437),
    [anon_sym_RPAREN] = ACTIONS(4437),
    [anon_sym_RBRACE] = ACTIONS(4437),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4439),
    [anon_sym_GT] = ACTIONS(4439),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4439),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4439),
    [anon_sym_PLUS_PLUS] = ACTIONS(4437),
    [anon_sym_DASH_DASH] = ACTIONS(4437),
    [anon_sym_PLUS] = ACTIONS(4439),
    [anon_sym_DASH] = ACTIONS(4439),
    [anon_sym_STAR] = ACTIONS(4437),
    [anon_sym_SLASH] = ACTIONS(4439),
    [anon_sym_PERCENT] = ACTIONS(4437),
    [anon_sym_CARET] = ACTIONS(4437),
    [anon_sym_PIPE] = ACTIONS(4439),
    [anon_sym_AMP] = ACTIONS(4439),
    [anon_sym_LT_LT] = ACTIONS(4437),
    [anon_sym_GT_GT] = ACTIONS(4439),
    [anon_sym_GT_GT_GT] = ACTIONS(4437),
    [anon_sym_EQ_EQ] = ACTIONS(4437),
    [anon_sym_BANG_EQ] = ACTIONS(4437),
    [anon_sym_GT_EQ] = ACTIONS(4437),
    [anon_sym_LT_EQ] = ACTIONS(4437),
    [anon_sym_DOT] = ACTIONS(4439),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_EQ_GT] = ACTIONS(4437),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4439),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4359),
    [anon_sym_DOT_DOT] = ACTIONS(4437),
    [anon_sym_and] = ACTIONS(4439),
    [anon_sym_or] = ACTIONS(4439),
    [anon_sym_AMP_AMP] = ACTIONS(4437),
    [anon_sym_PIPE_PIPE] = ACTIONS(4437),
    [anon_sym_QMARK_QMARK] = ACTIONS(4437),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4339),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4439),
    [anon_sym_is] = ACTIONS(4439),
    [anon_sym_DASH_GT] = ACTIONS(4437),
    [anon_sym_with] = ACTIONS(4439),
    [aux_sym_preproc_if_token3] = ACTIONS(4437),
    [aux_sym_preproc_else_token1] = ACTIONS(4437),
    [aux_sym_preproc_elif_token1] = ACTIONS(4437),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2889] = {
    [sym_preproc_region] = STATE(2889),
    [sym_preproc_endregion] = STATE(2889),
    [sym_preproc_line] = STATE(2889),
    [sym_preproc_pragma] = STATE(2889),
    [sym_preproc_nullable] = STATE(2889),
    [sym_preproc_error] = STATE(2889),
    [sym_preproc_warning] = STATE(2889),
    [sym_preproc_define] = STATE(2889),
    [sym_preproc_undef] = STATE(2889),
    [sym__identifier_token] = ACTIONS(4179),
    [anon_sym_alias] = ACTIONS(4179),
    [anon_sym_global] = ACTIONS(4179),
    [anon_sym_EQ] = ACTIONS(4183),
    [anon_sym_LBRACK] = ACTIONS(4185),
    [anon_sym_COLON] = ACTIONS(4191),
    [anon_sym_LPAREN] = ACTIONS(4185),
    [anon_sym_file] = ACTIONS(4179),
    [anon_sym_LT] = ACTIONS(4183),
    [anon_sym_GT] = ACTIONS(4183),
    [anon_sym_where] = ACTIONS(4179),
    [anon_sym_QMARK] = ACTIONS(4188),
    [anon_sym_notnull] = ACTIONS(4179),
    [anon_sym_unmanaged] = ACTIONS(4179),
    [anon_sym_BANG] = ACTIONS(4183),
    [anon_sym_PLUS_PLUS] = ACTIONS(4191),
    [anon_sym_DASH_DASH] = ACTIONS(4191),
    [anon_sym_PLUS] = ACTIONS(4183),
    [anon_sym_DASH] = ACTIONS(4183),
    [anon_sym_STAR] = ACTIONS(4188),
    [anon_sym_SLASH] = ACTIONS(4183),
    [anon_sym_PERCENT] = ACTIONS(4183),
    [anon_sym_CARET] = ACTIONS(4183),
    [anon_sym_PIPE] = ACTIONS(4183),
    [anon_sym_AMP] = ACTIONS(4183),
    [anon_sym_LT_LT] = ACTIONS(4183),
    [anon_sym_GT_GT] = ACTIONS(4183),
    [anon_sym_GT_GT_GT] = ACTIONS(4183),
    [anon_sym_EQ_EQ] = ACTIONS(4191),
    [anon_sym_BANG_EQ] = ACTIONS(4191),
    [anon_sym_GT_EQ] = ACTIONS(4191),
    [anon_sym_LT_EQ] = ACTIONS(4191),
    [anon_sym_DOT] = ACTIONS(4188),
    [anon_sym_scoped] = ACTIONS(4179),
    [anon_sym_EQ_GT] = ACTIONS(4191),
    [anon_sym_var] = ACTIONS(4179),
    [anon_sym_yield] = ACTIONS(4179),
    [anon_sym_switch] = ACTIONS(4183),
    [anon_sym_when] = ACTIONS(4188),
    [anon_sym_DOT_DOT] = ACTIONS(4191),
    [anon_sym_and] = ACTIONS(4183),
    [anon_sym_or] = ACTIONS(4183),
    [anon_sym_PLUS_EQ] = ACTIONS(4191),
    [anon_sym_DASH_EQ] = ACTIONS(4191),
    [anon_sym_STAR_EQ] = ACTIONS(4191),
    [anon_sym_SLASH_EQ] = ACTIONS(4191),
    [anon_sym_PERCENT_EQ] = ACTIONS(4191),
    [anon_sym_AMP_EQ] = ACTIONS(4191),
    [anon_sym_CARET_EQ] = ACTIONS(4191),
    [anon_sym_PIPE_EQ] = ACTIONS(4191),
    [anon_sym_LT_LT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4191),
    [anon_sym_AMP_AMP] = ACTIONS(4191),
    [anon_sym_PIPE_PIPE] = ACTIONS(4191),
    [anon_sym_QMARK_QMARK] = ACTIONS(4183),
    [anon_sym_from] = ACTIONS(4179),
    [anon_sym_into] = ACTIONS(4188),
    [anon_sym_join] = ACTIONS(4179),
    [anon_sym_on] = ACTIONS(4179),
    [anon_sym_equals] = ACTIONS(4179),
    [anon_sym_let] = ACTIONS(4179),
    [anon_sym_orderby] = ACTIONS(4179),
    [anon_sym_ascending] = ACTIONS(4179),
    [anon_sym_descending] = ACTIONS(4179),
    [anon_sym_group] = ACTIONS(4179),
    [anon_sym_by] = ACTIONS(4179),
    [anon_sym_select] = ACTIONS(4179),
    [anon_sym_as] = ACTIONS(4183),
    [anon_sym_is] = ACTIONS(4183),
    [anon_sym_DASH_GT] = ACTIONS(4185),
    [anon_sym_with] = ACTIONS(4183),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2890] = {
    [sym_preproc_region] = STATE(2890),
    [sym_preproc_endregion] = STATE(2890),
    [sym_preproc_line] = STATE(2890),
    [sym_preproc_pragma] = STATE(2890),
    [sym_preproc_nullable] = STATE(2890),
    [sym_preproc_error] = STATE(2890),
    [sym_preproc_warning] = STATE(2890),
    [sym_preproc_define] = STATE(2890),
    [sym_preproc_undef] = STATE(2890),
    [sym__identifier_token] = ACTIONS(4179),
    [anon_sym_alias] = ACTIONS(4179),
    [anon_sym_global] = ACTIONS(4179),
    [anon_sym_EQ] = ACTIONS(4183),
    [anon_sym_LBRACK] = ACTIONS(4185),
    [anon_sym_LPAREN] = ACTIONS(4185),
    [anon_sym_LBRACE] = ACTIONS(4181),
    [anon_sym_file] = ACTIONS(4179),
    [anon_sym_LT] = ACTIONS(4188),
    [anon_sym_GT] = ACTIONS(4188),
    [anon_sym_where] = ACTIONS(4188),
    [anon_sym_QMARK] = ACTIONS(4188),
    [anon_sym_notnull] = ACTIONS(4179),
    [anon_sym_unmanaged] = ACTIONS(4179),
    [anon_sym_BANG] = ACTIONS(4188),
    [anon_sym_PLUS_PLUS] = ACTIONS(4185),
    [anon_sym_DASH_DASH] = ACTIONS(4185),
    [anon_sym_PLUS] = ACTIONS(4188),
    [anon_sym_DASH] = ACTIONS(4188),
    [anon_sym_STAR] = ACTIONS(4188),
    [anon_sym_SLASH] = ACTIONS(4188),
    [anon_sym_PERCENT] = ACTIONS(4188),
    [anon_sym_CARET] = ACTIONS(4188),
    [anon_sym_PIPE] = ACTIONS(4188),
    [anon_sym_AMP] = ACTIONS(4188),
    [anon_sym_LT_LT] = ACTIONS(4188),
    [anon_sym_GT_GT] = ACTIONS(4188),
    [anon_sym_GT_GT_GT] = ACTIONS(4188),
    [anon_sym_EQ_EQ] = ACTIONS(4185),
    [anon_sym_BANG_EQ] = ACTIONS(4185),
    [anon_sym_GT_EQ] = ACTIONS(4185),
    [anon_sym_LT_EQ] = ACTIONS(4185),
    [anon_sym_DOT] = ACTIONS(4188),
    [anon_sym_scoped] = ACTIONS(4179),
    [anon_sym_var] = ACTIONS(4179),
    [anon_sym_yield] = ACTIONS(4179),
    [anon_sym_switch] = ACTIONS(4188),
    [anon_sym_when] = ACTIONS(4179),
    [sym_discard] = ACTIONS(4179),
    [anon_sym_DOT_DOT] = ACTIONS(4185),
    [anon_sym_and] = ACTIONS(4188),
    [anon_sym_or] = ACTIONS(4188),
    [anon_sym_PLUS_EQ] = ACTIONS(4191),
    [anon_sym_DASH_EQ] = ACTIONS(4191),
    [anon_sym_STAR_EQ] = ACTIONS(4191),
    [anon_sym_SLASH_EQ] = ACTIONS(4191),
    [anon_sym_PERCENT_EQ] = ACTIONS(4191),
    [anon_sym_AMP_EQ] = ACTIONS(4191),
    [anon_sym_CARET_EQ] = ACTIONS(4191),
    [anon_sym_PIPE_EQ] = ACTIONS(4191),
    [anon_sym_LT_LT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4191),
    [anon_sym_AMP_AMP] = ACTIONS(4185),
    [anon_sym_PIPE_PIPE] = ACTIONS(4185),
    [anon_sym_QMARK_QMARK] = ACTIONS(4188),
    [anon_sym_from] = ACTIONS(4188),
    [anon_sym_into] = ACTIONS(4188),
    [anon_sym_join] = ACTIONS(4188),
    [anon_sym_on] = ACTIONS(4179),
    [anon_sym_equals] = ACTIONS(4179),
    [anon_sym_let] = ACTIONS(4188),
    [anon_sym_orderby] = ACTIONS(4188),
    [anon_sym_ascending] = ACTIONS(4179),
    [anon_sym_descending] = ACTIONS(4179),
    [anon_sym_group] = ACTIONS(4188),
    [anon_sym_by] = ACTIONS(4179),
    [anon_sym_select] = ACTIONS(4188),
    [anon_sym_as] = ACTIONS(4188),
    [anon_sym_is] = ACTIONS(4188),
    [anon_sym_DASH_GT] = ACTIONS(4185),
    [anon_sym_with] = ACTIONS(4188),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2891] = {
    [sym_preproc_region] = STATE(2891),
    [sym_preproc_endregion] = STATE(2891),
    [sym_preproc_line] = STATE(2891),
    [sym_preproc_pragma] = STATE(2891),
    [sym_preproc_nullable] = STATE(2891),
    [sym_preproc_error] = STATE(2891),
    [sym_preproc_warning] = STATE(2891),
    [sym_preproc_define] = STATE(2891),
    [sym_preproc_undef] = STATE(2891),
    [sym__identifier_token] = ACTIONS(4179),
    [anon_sym_alias] = ACTIONS(4179),
    [anon_sym_global] = ACTIONS(4179),
    [anon_sym_EQ] = ACTIONS(4183),
    [anon_sym_LBRACK] = ACTIONS(4185),
    [anon_sym_LPAREN] = ACTIONS(4185),
    [anon_sym_LBRACE] = ACTIONS(4181),
    [anon_sym_file] = ACTIONS(4179),
    [anon_sym_LT] = ACTIONS(4188),
    [anon_sym_GT] = ACTIONS(4188),
    [anon_sym_where] = ACTIONS(4179),
    [anon_sym_QMARK] = ACTIONS(4188),
    [anon_sym_notnull] = ACTIONS(4179),
    [anon_sym_unmanaged] = ACTIONS(4179),
    [anon_sym_BANG] = ACTIONS(4188),
    [anon_sym_PLUS_PLUS] = ACTIONS(4185),
    [anon_sym_DASH_DASH] = ACTIONS(4185),
    [anon_sym_PLUS] = ACTIONS(4188),
    [anon_sym_DASH] = ACTIONS(4188),
    [anon_sym_STAR] = ACTIONS(4188),
    [anon_sym_SLASH] = ACTIONS(4188),
    [anon_sym_PERCENT] = ACTIONS(4188),
    [anon_sym_CARET] = ACTIONS(4188),
    [anon_sym_PIPE] = ACTIONS(4188),
    [anon_sym_AMP] = ACTIONS(4188),
    [anon_sym_LT_LT] = ACTIONS(4188),
    [anon_sym_GT_GT] = ACTIONS(4188),
    [anon_sym_GT_GT_GT] = ACTIONS(4188),
    [anon_sym_EQ_EQ] = ACTIONS(4185),
    [anon_sym_BANG_EQ] = ACTIONS(4185),
    [anon_sym_GT_EQ] = ACTIONS(4185),
    [anon_sym_LT_EQ] = ACTIONS(4185),
    [anon_sym_DOT] = ACTIONS(4188),
    [anon_sym_scoped] = ACTIONS(4179),
    [anon_sym_var] = ACTIONS(4179),
    [anon_sym_yield] = ACTIONS(4179),
    [anon_sym_switch] = ACTIONS(4188),
    [anon_sym_when] = ACTIONS(4179),
    [sym_discard] = ACTIONS(4179),
    [anon_sym_DOT_DOT] = ACTIONS(4185),
    [anon_sym_and] = ACTIONS(4188),
    [anon_sym_or] = ACTIONS(4188),
    [anon_sym_PLUS_EQ] = ACTIONS(4191),
    [anon_sym_DASH_EQ] = ACTIONS(4191),
    [anon_sym_STAR_EQ] = ACTIONS(4191),
    [anon_sym_SLASH_EQ] = ACTIONS(4191),
    [anon_sym_PERCENT_EQ] = ACTIONS(4191),
    [anon_sym_AMP_EQ] = ACTIONS(4191),
    [anon_sym_CARET_EQ] = ACTIONS(4191),
    [anon_sym_PIPE_EQ] = ACTIONS(4191),
    [anon_sym_LT_LT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4191),
    [anon_sym_AMP_AMP] = ACTIONS(4185),
    [anon_sym_PIPE_PIPE] = ACTIONS(4185),
    [anon_sym_QMARK_QMARK] = ACTIONS(4188),
    [anon_sym_from] = ACTIONS(4179),
    [anon_sym_into] = ACTIONS(4179),
    [anon_sym_join] = ACTIONS(4179),
    [anon_sym_on] = ACTIONS(4179),
    [anon_sym_equals] = ACTIONS(4188),
    [anon_sym_let] = ACTIONS(4179),
    [anon_sym_orderby] = ACTIONS(4179),
    [anon_sym_ascending] = ACTIONS(4179),
    [anon_sym_descending] = ACTIONS(4179),
    [anon_sym_group] = ACTIONS(4179),
    [anon_sym_by] = ACTIONS(4179),
    [anon_sym_select] = ACTIONS(4179),
    [anon_sym_as] = ACTIONS(4188),
    [anon_sym_is] = ACTIONS(4188),
    [anon_sym_DASH_GT] = ACTIONS(4185),
    [anon_sym_with] = ACTIONS(4188),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2892] = {
    [sym_preproc_region] = STATE(2892),
    [sym_preproc_endregion] = STATE(2892),
    [sym_preproc_line] = STATE(2892),
    [sym_preproc_pragma] = STATE(2892),
    [sym_preproc_nullable] = STATE(2892),
    [sym_preproc_error] = STATE(2892),
    [sym_preproc_warning] = STATE(2892),
    [sym_preproc_define] = STATE(2892),
    [sym_preproc_undef] = STATE(2892),
    [sym__identifier_token] = ACTIONS(4179),
    [anon_sym_alias] = ACTIONS(4179),
    [anon_sym_global] = ACTIONS(4179),
    [anon_sym_EQ] = ACTIONS(4183),
    [anon_sym_LBRACK] = ACTIONS(4185),
    [anon_sym_LPAREN] = ACTIONS(4185),
    [anon_sym_LBRACE] = ACTIONS(4181),
    [anon_sym_file] = ACTIONS(4179),
    [anon_sym_LT] = ACTIONS(4188),
    [anon_sym_GT] = ACTIONS(4188),
    [anon_sym_where] = ACTIONS(4179),
    [anon_sym_QMARK] = ACTIONS(4188),
    [anon_sym_notnull] = ACTIONS(4179),
    [anon_sym_unmanaged] = ACTIONS(4179),
    [anon_sym_BANG] = ACTIONS(4188),
    [anon_sym_PLUS_PLUS] = ACTIONS(4185),
    [anon_sym_DASH_DASH] = ACTIONS(4185),
    [anon_sym_PLUS] = ACTIONS(4188),
    [anon_sym_DASH] = ACTIONS(4188),
    [anon_sym_STAR] = ACTIONS(4188),
    [anon_sym_SLASH] = ACTIONS(4188),
    [anon_sym_PERCENT] = ACTIONS(4188),
    [anon_sym_CARET] = ACTIONS(4188),
    [anon_sym_PIPE] = ACTIONS(4188),
    [anon_sym_AMP] = ACTIONS(4188),
    [anon_sym_LT_LT] = ACTIONS(4188),
    [anon_sym_GT_GT] = ACTIONS(4188),
    [anon_sym_GT_GT_GT] = ACTIONS(4188),
    [anon_sym_EQ_EQ] = ACTIONS(4185),
    [anon_sym_BANG_EQ] = ACTIONS(4185),
    [anon_sym_GT_EQ] = ACTIONS(4185),
    [anon_sym_LT_EQ] = ACTIONS(4185),
    [anon_sym_DOT] = ACTIONS(4188),
    [anon_sym_scoped] = ACTIONS(4179),
    [anon_sym_var] = ACTIONS(4179),
    [anon_sym_yield] = ACTIONS(4179),
    [anon_sym_switch] = ACTIONS(4188),
    [anon_sym_when] = ACTIONS(4179),
    [sym_discard] = ACTIONS(4179),
    [anon_sym_DOT_DOT] = ACTIONS(4185),
    [anon_sym_and] = ACTIONS(4188),
    [anon_sym_or] = ACTIONS(4188),
    [anon_sym_PLUS_EQ] = ACTIONS(4191),
    [anon_sym_DASH_EQ] = ACTIONS(4191),
    [anon_sym_STAR_EQ] = ACTIONS(4191),
    [anon_sym_SLASH_EQ] = ACTIONS(4191),
    [anon_sym_PERCENT_EQ] = ACTIONS(4191),
    [anon_sym_AMP_EQ] = ACTIONS(4191),
    [anon_sym_CARET_EQ] = ACTIONS(4191),
    [anon_sym_PIPE_EQ] = ACTIONS(4191),
    [anon_sym_LT_LT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4191),
    [anon_sym_AMP_AMP] = ACTIONS(4185),
    [anon_sym_PIPE_PIPE] = ACTIONS(4185),
    [anon_sym_QMARK_QMARK] = ACTIONS(4188),
    [anon_sym_from] = ACTIONS(4179),
    [anon_sym_into] = ACTIONS(4179),
    [anon_sym_join] = ACTIONS(4179),
    [anon_sym_on] = ACTIONS(4188),
    [anon_sym_equals] = ACTIONS(4179),
    [anon_sym_let] = ACTIONS(4179),
    [anon_sym_orderby] = ACTIONS(4179),
    [anon_sym_ascending] = ACTIONS(4179),
    [anon_sym_descending] = ACTIONS(4179),
    [anon_sym_group] = ACTIONS(4179),
    [anon_sym_by] = ACTIONS(4179),
    [anon_sym_select] = ACTIONS(4179),
    [anon_sym_as] = ACTIONS(4188),
    [anon_sym_is] = ACTIONS(4188),
    [anon_sym_DASH_GT] = ACTIONS(4185),
    [anon_sym_with] = ACTIONS(4188),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2893] = {
    [sym_preproc_region] = STATE(2893),
    [sym_preproc_endregion] = STATE(2893),
    [sym_preproc_line] = STATE(2893),
    [sym_preproc_pragma] = STATE(2893),
    [sym_preproc_nullable] = STATE(2893),
    [sym_preproc_error] = STATE(2893),
    [sym_preproc_warning] = STATE(2893),
    [sym_preproc_define] = STATE(2893),
    [sym_preproc_undef] = STATE(2893),
    [sym__identifier_token] = ACTIONS(4157),
    [anon_sym_alias] = ACTIONS(4157),
    [anon_sym_global] = ACTIONS(4157),
    [anon_sym_EQ] = ACTIONS(4162),
    [anon_sym_LBRACK] = ACTIONS(4164),
    [anon_sym_LPAREN] = ACTIONS(4164),
    [anon_sym_LBRACE] = ACTIONS(4168),
    [anon_sym_file] = ACTIONS(4157),
    [anon_sym_LT] = ACTIONS(4170),
    [anon_sym_GT] = ACTIONS(4170),
    [anon_sym_where] = ACTIONS(4157),
    [anon_sym_QMARK] = ACTIONS(4170),
    [anon_sym_notnull] = ACTIONS(4157),
    [anon_sym_unmanaged] = ACTIONS(4157),
    [anon_sym_BANG] = ACTIONS(4170),
    [anon_sym_PLUS_PLUS] = ACTIONS(4164),
    [anon_sym_DASH_DASH] = ACTIONS(4164),
    [anon_sym_PLUS] = ACTIONS(4170),
    [anon_sym_DASH] = ACTIONS(4170),
    [anon_sym_STAR] = ACTIONS(4170),
    [anon_sym_SLASH] = ACTIONS(4170),
    [anon_sym_PERCENT] = ACTIONS(4170),
    [anon_sym_CARET] = ACTIONS(4170),
    [anon_sym_PIPE] = ACTIONS(4170),
    [anon_sym_AMP] = ACTIONS(4170),
    [anon_sym_LT_LT] = ACTIONS(4170),
    [anon_sym_GT_GT] = ACTIONS(4170),
    [anon_sym_GT_GT_GT] = ACTIONS(4170),
    [anon_sym_EQ_EQ] = ACTIONS(4164),
    [anon_sym_BANG_EQ] = ACTIONS(4164),
    [anon_sym_GT_EQ] = ACTIONS(4164),
    [anon_sym_LT_EQ] = ACTIONS(4164),
    [anon_sym_DOT] = ACTIONS(4170),
    [anon_sym_scoped] = ACTIONS(4157),
    [anon_sym_var] = ACTIONS(4157),
    [anon_sym_yield] = ACTIONS(4157),
    [anon_sym_switch] = ACTIONS(4170),
    [anon_sym_when] = ACTIONS(4157),
    [sym_discard] = ACTIONS(4157),
    [anon_sym_DOT_DOT] = ACTIONS(4164),
    [anon_sym_and] = ACTIONS(4174),
    [anon_sym_or] = ACTIONS(4174),
    [anon_sym_PLUS_EQ] = ACTIONS(4177),
    [anon_sym_DASH_EQ] = ACTIONS(4177),
    [anon_sym_STAR_EQ] = ACTIONS(4177),
    [anon_sym_SLASH_EQ] = ACTIONS(4177),
    [anon_sym_PERCENT_EQ] = ACTIONS(4177),
    [anon_sym_AMP_EQ] = ACTIONS(4177),
    [anon_sym_CARET_EQ] = ACTIONS(4177),
    [anon_sym_PIPE_EQ] = ACTIONS(4177),
    [anon_sym_LT_LT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4177),
    [anon_sym_AMP_AMP] = ACTIONS(4164),
    [anon_sym_PIPE_PIPE] = ACTIONS(4164),
    [anon_sym_QMARK_QMARK] = ACTIONS(4170),
    [anon_sym_from] = ACTIONS(4157),
    [anon_sym_into] = ACTIONS(4157),
    [anon_sym_join] = ACTIONS(4157),
    [anon_sym_on] = ACTIONS(4157),
    [anon_sym_equals] = ACTIONS(4174),
    [anon_sym_let] = ACTIONS(4157),
    [anon_sym_orderby] = ACTIONS(4157),
    [anon_sym_ascending] = ACTIONS(4157),
    [anon_sym_descending] = ACTIONS(4157),
    [anon_sym_group] = ACTIONS(4157),
    [anon_sym_by] = ACTIONS(4157),
    [anon_sym_select] = ACTIONS(4157),
    [anon_sym_as] = ACTIONS(4170),
    [anon_sym_is] = ACTIONS(4170),
    [anon_sym_DASH_GT] = ACTIONS(4164),
    [anon_sym_with] = ACTIONS(4170),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2894] = {
    [sym_preproc_region] = STATE(2894),
    [sym_preproc_endregion] = STATE(2894),
    [sym_preproc_line] = STATE(2894),
    [sym_preproc_pragma] = STATE(2894),
    [sym_preproc_nullable] = STATE(2894),
    [sym_preproc_error] = STATE(2894),
    [sym_preproc_warning] = STATE(2894),
    [sym_preproc_define] = STATE(2894),
    [sym_preproc_undef] = STATE(2894),
    [sym__identifier_token] = ACTIONS(4179),
    [anon_sym_alias] = ACTIONS(4179),
    [anon_sym_global] = ACTIONS(4179),
    [anon_sym_EQ] = ACTIONS(4183),
    [anon_sym_LBRACK] = ACTIONS(4185),
    [anon_sym_LPAREN] = ACTIONS(4185),
    [anon_sym_LBRACE] = ACTIONS(4181),
    [anon_sym_file] = ACTIONS(4179),
    [anon_sym_LT] = ACTIONS(4188),
    [anon_sym_GT] = ACTIONS(4188),
    [anon_sym_where] = ACTIONS(4179),
    [anon_sym_QMARK] = ACTIONS(4188),
    [anon_sym_notnull] = ACTIONS(4179),
    [anon_sym_unmanaged] = ACTIONS(4179),
    [anon_sym_BANG] = ACTIONS(4188),
    [anon_sym_PLUS_PLUS] = ACTIONS(4185),
    [anon_sym_DASH_DASH] = ACTIONS(4185),
    [anon_sym_PLUS] = ACTIONS(4188),
    [anon_sym_DASH] = ACTIONS(4188),
    [anon_sym_STAR] = ACTIONS(4188),
    [anon_sym_SLASH] = ACTIONS(4188),
    [anon_sym_PERCENT] = ACTIONS(4188),
    [anon_sym_CARET] = ACTIONS(4188),
    [anon_sym_PIPE] = ACTIONS(4188),
    [anon_sym_AMP] = ACTIONS(4188),
    [anon_sym_LT_LT] = ACTIONS(4188),
    [anon_sym_GT_GT] = ACTIONS(4188),
    [anon_sym_GT_GT_GT] = ACTIONS(4188),
    [anon_sym_EQ_EQ] = ACTIONS(4185),
    [anon_sym_BANG_EQ] = ACTIONS(4185),
    [anon_sym_GT_EQ] = ACTIONS(4185),
    [anon_sym_LT_EQ] = ACTIONS(4185),
    [anon_sym_DOT] = ACTIONS(4188),
    [anon_sym_scoped] = ACTIONS(4179),
    [anon_sym_var] = ACTIONS(4179),
    [anon_sym_yield] = ACTIONS(4179),
    [anon_sym_switch] = ACTIONS(4188),
    [anon_sym_when] = ACTIONS(4179),
    [sym_discard] = ACTIONS(4179),
    [anon_sym_DOT_DOT] = ACTIONS(4185),
    [anon_sym_and] = ACTIONS(4188),
    [anon_sym_or] = ACTIONS(4188),
    [anon_sym_PLUS_EQ] = ACTIONS(4191),
    [anon_sym_DASH_EQ] = ACTIONS(4191),
    [anon_sym_STAR_EQ] = ACTIONS(4191),
    [anon_sym_SLASH_EQ] = ACTIONS(4191),
    [anon_sym_PERCENT_EQ] = ACTIONS(4191),
    [anon_sym_AMP_EQ] = ACTIONS(4191),
    [anon_sym_CARET_EQ] = ACTIONS(4191),
    [anon_sym_PIPE_EQ] = ACTIONS(4191),
    [anon_sym_LT_LT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4191),
    [anon_sym_AMP_AMP] = ACTIONS(4185),
    [anon_sym_PIPE_PIPE] = ACTIONS(4185),
    [anon_sym_QMARK_QMARK] = ACTIONS(4188),
    [anon_sym_from] = ACTIONS(4179),
    [anon_sym_into] = ACTIONS(4179),
    [anon_sym_join] = ACTIONS(4179),
    [anon_sym_on] = ACTIONS(4179),
    [anon_sym_equals] = ACTIONS(4179),
    [anon_sym_let] = ACTIONS(4179),
    [anon_sym_orderby] = ACTIONS(4179),
    [anon_sym_ascending] = ACTIONS(4179),
    [anon_sym_descending] = ACTIONS(4179),
    [anon_sym_group] = ACTIONS(4179),
    [anon_sym_by] = ACTIONS(4188),
    [anon_sym_select] = ACTIONS(4179),
    [anon_sym_as] = ACTIONS(4188),
    [anon_sym_is] = ACTIONS(4188),
    [anon_sym_DASH_GT] = ACTIONS(4185),
    [anon_sym_with] = ACTIONS(4188),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2895] = {
    [sym_preproc_region] = STATE(2895),
    [sym_preproc_endregion] = STATE(2895),
    [sym_preproc_line] = STATE(2895),
    [sym_preproc_pragma] = STATE(2895),
    [sym_preproc_nullable] = STATE(2895),
    [sym_preproc_error] = STATE(2895),
    [sym_preproc_warning] = STATE(2895),
    [sym_preproc_define] = STATE(2895),
    [sym_preproc_undef] = STATE(2895),
    [sym__identifier_token] = ACTIONS(4179),
    [anon_sym_alias] = ACTIONS(4179),
    [anon_sym_global] = ACTIONS(4179),
    [anon_sym_EQ] = ACTIONS(4183),
    [anon_sym_LBRACK] = ACTIONS(4185),
    [anon_sym_LPAREN] = ACTIONS(4185),
    [anon_sym_LBRACE] = ACTIONS(4181),
    [anon_sym_file] = ACTIONS(4179),
    [anon_sym_LT] = ACTIONS(4188),
    [anon_sym_GT] = ACTIONS(4188),
    [anon_sym_where] = ACTIONS(4179),
    [anon_sym_QMARK] = ACTIONS(4188),
    [anon_sym_notnull] = ACTIONS(4179),
    [anon_sym_unmanaged] = ACTIONS(4179),
    [anon_sym_BANG] = ACTIONS(4188),
    [anon_sym_PLUS_PLUS] = ACTIONS(4185),
    [anon_sym_DASH_DASH] = ACTIONS(4185),
    [anon_sym_PLUS] = ACTIONS(4188),
    [anon_sym_DASH] = ACTIONS(4188),
    [anon_sym_STAR] = ACTIONS(4188),
    [anon_sym_SLASH] = ACTIONS(4188),
    [anon_sym_PERCENT] = ACTIONS(4188),
    [anon_sym_CARET] = ACTIONS(4188),
    [anon_sym_PIPE] = ACTIONS(4188),
    [anon_sym_AMP] = ACTIONS(4188),
    [anon_sym_LT_LT] = ACTIONS(4188),
    [anon_sym_GT_GT] = ACTIONS(4188),
    [anon_sym_GT_GT_GT] = ACTIONS(4188),
    [anon_sym_EQ_EQ] = ACTIONS(4185),
    [anon_sym_BANG_EQ] = ACTIONS(4185),
    [anon_sym_GT_EQ] = ACTIONS(4185),
    [anon_sym_LT_EQ] = ACTIONS(4185),
    [anon_sym_DOT] = ACTIONS(4188),
    [anon_sym_scoped] = ACTIONS(4179),
    [anon_sym_var] = ACTIONS(4179),
    [anon_sym_yield] = ACTIONS(4179),
    [anon_sym_switch] = ACTIONS(4188),
    [anon_sym_when] = ACTIONS(4179),
    [sym_discard] = ACTIONS(4179),
    [anon_sym_DOT_DOT] = ACTIONS(4185),
    [anon_sym_and] = ACTIONS(4188),
    [anon_sym_or] = ACTIONS(4188),
    [anon_sym_PLUS_EQ] = ACTIONS(4191),
    [anon_sym_DASH_EQ] = ACTIONS(4191),
    [anon_sym_STAR_EQ] = ACTIONS(4191),
    [anon_sym_SLASH_EQ] = ACTIONS(4191),
    [anon_sym_PERCENT_EQ] = ACTIONS(4191),
    [anon_sym_AMP_EQ] = ACTIONS(4191),
    [anon_sym_CARET_EQ] = ACTIONS(4191),
    [anon_sym_PIPE_EQ] = ACTIONS(4191),
    [anon_sym_LT_LT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4191),
    [anon_sym_AMP_AMP] = ACTIONS(4185),
    [anon_sym_PIPE_PIPE] = ACTIONS(4185),
    [anon_sym_QMARK_QMARK] = ACTIONS(4188),
    [anon_sym_from] = ACTIONS(4179),
    [anon_sym_into] = ACTIONS(4188),
    [anon_sym_join] = ACTIONS(4179),
    [anon_sym_on] = ACTIONS(4179),
    [anon_sym_equals] = ACTIONS(4179),
    [anon_sym_let] = ACTIONS(4179),
    [anon_sym_orderby] = ACTIONS(4179),
    [anon_sym_ascending] = ACTIONS(4179),
    [anon_sym_descending] = ACTIONS(4179),
    [anon_sym_group] = ACTIONS(4179),
    [anon_sym_by] = ACTIONS(4188),
    [anon_sym_select] = ACTIONS(4179),
    [anon_sym_as] = ACTIONS(4188),
    [anon_sym_is] = ACTIONS(4188),
    [anon_sym_DASH_GT] = ACTIONS(4185),
    [anon_sym_with] = ACTIONS(4188),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2896] = {
    [sym__name] = STATE(5379),
    [sym_alias_qualified_name] = STATE(5341),
    [sym__simple_name] = STATE(5341),
    [sym_qualified_name] = STATE(5341),
    [sym_generic_name] = STATE(5408),
    [sym_ref_type] = STATE(5290),
    [sym__scoped_base_type] = STATE(5345),
    [sym_identifier] = STATE(5076),
    [sym__reserved_identifier] = STATE(5173),
    [sym_preproc_region] = STATE(2896),
    [sym_preproc_endregion] = STATE(2896),
    [sym_preproc_line] = STATE(2896),
    [sym_preproc_pragma] = STATE(2896),
    [sym_preproc_nullable] = STATE(2896),
    [sym_preproc_error] = STATE(2896),
    [sym_preproc_warning] = STATE(2896),
    [sym_preproc_define] = STATE(2896),
    [sym_preproc_undef] = STATE(2896),
    [sym__identifier_token] = ACTIONS(4457),
    [anon_sym_alias] = ACTIONS(4459),
    [anon_sym_global] = ACTIONS(4459),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_COLON] = ACTIONS(3995),
    [anon_sym_COMMA] = ACTIONS(3993),
    [anon_sym_LPAREN] = ACTIONS(3993),
    [anon_sym_ref] = ACTIONS(4474),
    [anon_sym_LBRACE] = ACTIONS(3993),
    [anon_sym_file] = ACTIONS(4459),
    [anon_sym_LT] = ACTIONS(3995),
    [anon_sym_GT] = ACTIONS(3995),
    [anon_sym_where] = ACTIONS(4459),
    [anon_sym_QMARK] = ACTIONS(3995),
    [anon_sym_notnull] = ACTIONS(4459),
    [anon_sym_unmanaged] = ACTIONS(4459),
    [anon_sym_BANG] = ACTIONS(3995),
    [anon_sym_PLUS_PLUS] = ACTIONS(3993),
    [anon_sym_DASH_DASH] = ACTIONS(3993),
    [anon_sym_PLUS] = ACTIONS(3995),
    [anon_sym_DASH] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3993),
    [anon_sym_SLASH] = ACTIONS(3995),
    [anon_sym_PERCENT] = ACTIONS(3993),
    [anon_sym_CARET] = ACTIONS(3993),
    [anon_sym_PIPE] = ACTIONS(3995),
    [anon_sym_AMP] = ACTIONS(3995),
    [anon_sym_LT_LT] = ACTIONS(3993),
    [anon_sym_GT_GT] = ACTIONS(3995),
    [anon_sym_GT_GT_GT] = ACTIONS(3993),
    [anon_sym_EQ_EQ] = ACTIONS(3993),
    [anon_sym_BANG_EQ] = ACTIONS(3993),
    [anon_sym_GT_EQ] = ACTIONS(3993),
    [anon_sym_LT_EQ] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3995),
    [anon_sym_scoped] = ACTIONS(4459),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(4459),
    [anon_sym_yield] = ACTIONS(4459),
    [anon_sym_switch] = ACTIONS(3995),
    [anon_sym_when] = ACTIONS(4459),
    [anon_sym_DOT_DOT] = ACTIONS(3993),
    [anon_sym_and] = ACTIONS(3995),
    [anon_sym_or] = ACTIONS(3995),
    [anon_sym_AMP_AMP] = ACTIONS(3993),
    [anon_sym_PIPE_PIPE] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK] = ACTIONS(3993),
    [anon_sym_from] = ACTIONS(4459),
    [anon_sym_into] = ACTIONS(4459),
    [anon_sym_join] = ACTIONS(4459),
    [anon_sym_on] = ACTIONS(4459),
    [anon_sym_equals] = ACTIONS(4459),
    [anon_sym_let] = ACTIONS(4459),
    [anon_sym_orderby] = ACTIONS(4459),
    [anon_sym_ascending] = ACTIONS(4459),
    [anon_sym_descending] = ACTIONS(4459),
    [anon_sym_group] = ACTIONS(4459),
    [anon_sym_by] = ACTIONS(4459),
    [anon_sym_select] = ACTIONS(4459),
    [anon_sym_as] = ACTIONS(3995),
    [anon_sym_is] = ACTIONS(3995),
    [anon_sym_DASH_GT] = ACTIONS(3993),
    [anon_sym_with] = ACTIONS(3995),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(3993),
  },
  [2897] = {
    [sym_preproc_region] = STATE(2897),
    [sym_preproc_endregion] = STATE(2897),
    [sym_preproc_line] = STATE(2897),
    [sym_preproc_pragma] = STATE(2897),
    [sym_preproc_nullable] = STATE(2897),
    [sym_preproc_error] = STATE(2897),
    [sym_preproc_warning] = STATE(2897),
    [sym_preproc_define] = STATE(2897),
    [sym_preproc_undef] = STATE(2897),
    [sym__identifier_token] = ACTIONS(3995),
    [anon_sym_alias] = ACTIONS(3995),
    [anon_sym_global] = ACTIONS(3995),
    [anon_sym_using] = ACTIONS(4476),
    [anon_sym_EQ] = ACTIONS(3995),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_COLON] = ACTIONS(3995),
    [anon_sym_LPAREN] = ACTIONS(3993),
    [anon_sym_file] = ACTIONS(3995),
    [anon_sym_LT] = ACTIONS(3995),
    [anon_sym_GT] = ACTIONS(3995),
    [anon_sym_where] = ACTIONS(3995),
    [anon_sym_QMARK] = ACTIONS(3995),
    [anon_sym_notnull] = ACTIONS(3995),
    [anon_sym_unmanaged] = ACTIONS(3995),
    [anon_sym_BANG] = ACTIONS(3995),
    [anon_sym_PLUS_PLUS] = ACTIONS(3993),
    [anon_sym_DASH_DASH] = ACTIONS(3993),
    [anon_sym_PLUS] = ACTIONS(3995),
    [anon_sym_DASH] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3995),
    [anon_sym_SLASH] = ACTIONS(3995),
    [anon_sym_PERCENT] = ACTIONS(3995),
    [anon_sym_CARET] = ACTIONS(3995),
    [anon_sym_PIPE] = ACTIONS(3995),
    [anon_sym_AMP] = ACTIONS(3995),
    [anon_sym_LT_LT] = ACTIONS(3995),
    [anon_sym_GT_GT] = ACTIONS(3995),
    [anon_sym_GT_GT_GT] = ACTIONS(3995),
    [anon_sym_EQ_EQ] = ACTIONS(3993),
    [anon_sym_BANG_EQ] = ACTIONS(3993),
    [anon_sym_GT_EQ] = ACTIONS(3993),
    [anon_sym_LT_EQ] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3995),
    [anon_sym_scoped] = ACTIONS(3995),
    [anon_sym_EQ_GT] = ACTIONS(3993),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(3995),
    [anon_sym_yield] = ACTIONS(3995),
    [anon_sym_switch] = ACTIONS(3995),
    [anon_sym_when] = ACTIONS(3995),
    [anon_sym_DOT_DOT] = ACTIONS(3993),
    [anon_sym_PLUS_EQ] = ACTIONS(3993),
    [anon_sym_DASH_EQ] = ACTIONS(3993),
    [anon_sym_STAR_EQ] = ACTIONS(3993),
    [anon_sym_SLASH_EQ] = ACTIONS(3993),
    [anon_sym_PERCENT_EQ] = ACTIONS(3993),
    [anon_sym_AMP_EQ] = ACTIONS(3993),
    [anon_sym_CARET_EQ] = ACTIONS(3993),
    [anon_sym_PIPE_EQ] = ACTIONS(3993),
    [anon_sym_LT_LT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(3993),
    [anon_sym_AMP_AMP] = ACTIONS(3993),
    [anon_sym_PIPE_PIPE] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK] = ACTIONS(3995),
    [anon_sym_from] = ACTIONS(3995),
    [anon_sym_into] = ACTIONS(3995),
    [anon_sym_join] = ACTIONS(3995),
    [anon_sym_on] = ACTIONS(3995),
    [anon_sym_equals] = ACTIONS(3995),
    [anon_sym_let] = ACTIONS(3995),
    [anon_sym_orderby] = ACTIONS(3995),
    [anon_sym_ascending] = ACTIONS(3995),
    [anon_sym_descending] = ACTIONS(3995),
    [anon_sym_group] = ACTIONS(3995),
    [anon_sym_by] = ACTIONS(3995),
    [anon_sym_select] = ACTIONS(3995),
    [anon_sym_as] = ACTIONS(3995),
    [anon_sym_is] = ACTIONS(3995),
    [anon_sym_DASH_GT] = ACTIONS(3993),
    [anon_sym_with] = ACTIONS(3995),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2898] = {
    [sym_preproc_region] = STATE(2898),
    [sym_preproc_endregion] = STATE(2898),
    [sym_preproc_line] = STATE(2898),
    [sym_preproc_pragma] = STATE(2898),
    [sym_preproc_nullable] = STATE(2898),
    [sym_preproc_error] = STATE(2898),
    [sym_preproc_warning] = STATE(2898),
    [sym_preproc_define] = STATE(2898),
    [sym_preproc_undef] = STATE(2898),
    [sym__identifier_token] = ACTIONS(4478),
    [anon_sym_alias] = ACTIONS(4478),
    [anon_sym_SEMI] = ACTIONS(4480),
    [anon_sym_global] = ACTIONS(4478),
    [anon_sym_LBRACK] = ACTIONS(4480),
    [anon_sym_COLON] = ACTIONS(4480),
    [anon_sym_COMMA] = ACTIONS(4480),
    [anon_sym_RBRACK] = ACTIONS(4480),
    [anon_sym_LPAREN] = ACTIONS(4480),
    [anon_sym_RPAREN] = ACTIONS(4480),
    [anon_sym_LBRACE] = ACTIONS(4480),
    [anon_sym_RBRACE] = ACTIONS(4480),
    [anon_sym_file] = ACTIONS(4478),
    [anon_sym_LT] = ACTIONS(4478),
    [anon_sym_GT] = ACTIONS(4478),
    [anon_sym_in] = ACTIONS(4478),
    [anon_sym_where] = ACTIONS(4478),
    [anon_sym_QMARK] = ACTIONS(4478),
    [anon_sym_notnull] = ACTIONS(4478),
    [anon_sym_unmanaged] = ACTIONS(4478),
    [anon_sym_operator] = ACTIONS(4478),
    [anon_sym_BANG] = ACTIONS(4478),
    [anon_sym_PLUS_PLUS] = ACTIONS(4480),
    [anon_sym_DASH_DASH] = ACTIONS(4480),
    [anon_sym_PLUS] = ACTIONS(4478),
    [anon_sym_DASH] = ACTIONS(4478),
    [anon_sym_STAR] = ACTIONS(4480),
    [anon_sym_SLASH] = ACTIONS(4478),
    [anon_sym_PERCENT] = ACTIONS(4480),
    [anon_sym_CARET] = ACTIONS(4480),
    [anon_sym_PIPE] = ACTIONS(4478),
    [anon_sym_AMP] = ACTIONS(4478),
    [anon_sym_LT_LT] = ACTIONS(4480),
    [anon_sym_GT_GT] = ACTIONS(4478),
    [anon_sym_GT_GT_GT] = ACTIONS(4480),
    [anon_sym_EQ_EQ] = ACTIONS(4480),
    [anon_sym_BANG_EQ] = ACTIONS(4480),
    [anon_sym_GT_EQ] = ACTIONS(4480),
    [anon_sym_LT_EQ] = ACTIONS(4480),
    [anon_sym_this] = ACTIONS(4478),
    [anon_sym_DOT] = ACTIONS(4478),
    [anon_sym_scoped] = ACTIONS(4478),
    [anon_sym_EQ_GT] = ACTIONS(4480),
    [anon_sym_var] = ACTIONS(4478),
    [anon_sym_yield] = ACTIONS(4478),
    [anon_sym_switch] = ACTIONS(4478),
    [anon_sym_when] = ACTIONS(4478),
    [sym_discard] = ACTIONS(4478),
    [anon_sym_DOT_DOT] = ACTIONS(4480),
    [anon_sym_and] = ACTIONS(4478),
    [anon_sym_or] = ACTIONS(4478),
    [anon_sym_AMP_AMP] = ACTIONS(4480),
    [anon_sym_PIPE_PIPE] = ACTIONS(4480),
    [anon_sym_QMARK_QMARK] = ACTIONS(4480),
    [anon_sym_from] = ACTIONS(4478),
    [anon_sym_into] = ACTIONS(4478),
    [anon_sym_join] = ACTIONS(4478),
    [anon_sym_on] = ACTIONS(4478),
    [anon_sym_equals] = ACTIONS(4478),
    [anon_sym_let] = ACTIONS(4478),
    [anon_sym_orderby] = ACTIONS(4478),
    [anon_sym_ascending] = ACTIONS(4478),
    [anon_sym_descending] = ACTIONS(4478),
    [anon_sym_group] = ACTIONS(4478),
    [anon_sym_by] = ACTIONS(4478),
    [anon_sym_select] = ACTIONS(4478),
    [anon_sym_as] = ACTIONS(4478),
    [anon_sym_is] = ACTIONS(4478),
    [anon_sym_DASH_GT] = ACTIONS(4480),
    [anon_sym_with] = ACTIONS(4478),
    [aux_sym_preproc_if_token3] = ACTIONS(4480),
    [aux_sym_preproc_else_token1] = ACTIONS(4480),
    [aux_sym_preproc_elif_token1] = ACTIONS(4480),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2899] = {
    [sym_preproc_region] = STATE(2899),
    [sym_preproc_endregion] = STATE(2899),
    [sym_preproc_line] = STATE(2899),
    [sym_preproc_pragma] = STATE(2899),
    [sym_preproc_nullable] = STATE(2899),
    [sym_preproc_error] = STATE(2899),
    [sym_preproc_warning] = STATE(2899),
    [sym_preproc_define] = STATE(2899),
    [sym_preproc_undef] = STATE(2899),
    [sym__identifier_token] = ACTIONS(4179),
    [anon_sym_alias] = ACTIONS(4179),
    [anon_sym_global] = ACTIONS(4179),
    [anon_sym_EQ] = ACTIONS(4183),
    [anon_sym_LBRACK] = ACTIONS(4185),
    [anon_sym_LPAREN] = ACTIONS(4185),
    [anon_sym_LBRACE] = ACTIONS(4181),
    [anon_sym_file] = ACTIONS(4179),
    [anon_sym_LT] = ACTIONS(4188),
    [anon_sym_GT] = ACTIONS(4188),
    [anon_sym_where] = ACTIONS(4179),
    [anon_sym_QMARK] = ACTIONS(4188),
    [anon_sym_notnull] = ACTIONS(4179),
    [anon_sym_unmanaged] = ACTIONS(4179),
    [anon_sym_BANG] = ACTIONS(4188),
    [anon_sym_PLUS_PLUS] = ACTIONS(4185),
    [anon_sym_DASH_DASH] = ACTIONS(4185),
    [anon_sym_PLUS] = ACTIONS(4188),
    [anon_sym_DASH] = ACTIONS(4188),
    [anon_sym_STAR] = ACTIONS(4188),
    [anon_sym_SLASH] = ACTIONS(4188),
    [anon_sym_PERCENT] = ACTIONS(4188),
    [anon_sym_CARET] = ACTIONS(4188),
    [anon_sym_PIPE] = ACTIONS(4188),
    [anon_sym_AMP] = ACTIONS(4188),
    [anon_sym_LT_LT] = ACTIONS(4188),
    [anon_sym_GT_GT] = ACTIONS(4188),
    [anon_sym_GT_GT_GT] = ACTIONS(4188),
    [anon_sym_EQ_EQ] = ACTIONS(4185),
    [anon_sym_BANG_EQ] = ACTIONS(4185),
    [anon_sym_GT_EQ] = ACTIONS(4185),
    [anon_sym_LT_EQ] = ACTIONS(4185),
    [anon_sym_DOT] = ACTIONS(4188),
    [anon_sym_scoped] = ACTIONS(4179),
    [anon_sym_var] = ACTIONS(4179),
    [anon_sym_yield] = ACTIONS(4179),
    [anon_sym_switch] = ACTIONS(4188),
    [anon_sym_when] = ACTIONS(4179),
    [sym_discard] = ACTIONS(4179),
    [anon_sym_DOT_DOT] = ACTIONS(4185),
    [anon_sym_and] = ACTIONS(4188),
    [anon_sym_or] = ACTIONS(4188),
    [anon_sym_PLUS_EQ] = ACTIONS(4191),
    [anon_sym_DASH_EQ] = ACTIONS(4191),
    [anon_sym_STAR_EQ] = ACTIONS(4191),
    [anon_sym_SLASH_EQ] = ACTIONS(4191),
    [anon_sym_PERCENT_EQ] = ACTIONS(4191),
    [anon_sym_AMP_EQ] = ACTIONS(4191),
    [anon_sym_CARET_EQ] = ACTIONS(4191),
    [anon_sym_PIPE_EQ] = ACTIONS(4191),
    [anon_sym_LT_LT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4191),
    [anon_sym_AMP_AMP] = ACTIONS(4185),
    [anon_sym_PIPE_PIPE] = ACTIONS(4185),
    [anon_sym_QMARK_QMARK] = ACTIONS(4188),
    [anon_sym_from] = ACTIONS(4179),
    [anon_sym_into] = ACTIONS(4188),
    [anon_sym_join] = ACTIONS(4179),
    [anon_sym_on] = ACTIONS(4179),
    [anon_sym_equals] = ACTIONS(4188),
    [anon_sym_let] = ACTIONS(4179),
    [anon_sym_orderby] = ACTIONS(4179),
    [anon_sym_ascending] = ACTIONS(4179),
    [anon_sym_descending] = ACTIONS(4179),
    [anon_sym_group] = ACTIONS(4179),
    [anon_sym_by] = ACTIONS(4179),
    [anon_sym_select] = ACTIONS(4179),
    [anon_sym_as] = ACTIONS(4188),
    [anon_sym_is] = ACTIONS(4188),
    [anon_sym_DASH_GT] = ACTIONS(4185),
    [anon_sym_with] = ACTIONS(4188),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2900] = {
    [sym_preproc_region] = STATE(2900),
    [sym_preproc_endregion] = STATE(2900),
    [sym_preproc_line] = STATE(2900),
    [sym_preproc_pragma] = STATE(2900),
    [sym_preproc_nullable] = STATE(2900),
    [sym_preproc_error] = STATE(2900),
    [sym_preproc_warning] = STATE(2900),
    [sym_preproc_define] = STATE(2900),
    [sym_preproc_undef] = STATE(2900),
    [sym__identifier_token] = ACTIONS(4179),
    [anon_sym_alias] = ACTIONS(4179),
    [anon_sym_global] = ACTIONS(4179),
    [anon_sym_EQ] = ACTIONS(4183),
    [anon_sym_LBRACK] = ACTIONS(4185),
    [anon_sym_LPAREN] = ACTIONS(4185),
    [anon_sym_LBRACE] = ACTIONS(4181),
    [anon_sym_file] = ACTIONS(4179),
    [anon_sym_LT] = ACTIONS(4188),
    [anon_sym_GT] = ACTIONS(4188),
    [anon_sym_where] = ACTIONS(4179),
    [anon_sym_QMARK] = ACTIONS(4188),
    [anon_sym_notnull] = ACTIONS(4179),
    [anon_sym_unmanaged] = ACTIONS(4179),
    [anon_sym_BANG] = ACTIONS(4188),
    [anon_sym_PLUS_PLUS] = ACTIONS(4185),
    [anon_sym_DASH_DASH] = ACTIONS(4185),
    [anon_sym_PLUS] = ACTIONS(4188),
    [anon_sym_DASH] = ACTIONS(4188),
    [anon_sym_STAR] = ACTIONS(4188),
    [anon_sym_SLASH] = ACTIONS(4188),
    [anon_sym_PERCENT] = ACTIONS(4188),
    [anon_sym_CARET] = ACTIONS(4188),
    [anon_sym_PIPE] = ACTIONS(4188),
    [anon_sym_AMP] = ACTIONS(4188),
    [anon_sym_LT_LT] = ACTIONS(4188),
    [anon_sym_GT_GT] = ACTIONS(4188),
    [anon_sym_GT_GT_GT] = ACTIONS(4188),
    [anon_sym_EQ_EQ] = ACTIONS(4185),
    [anon_sym_BANG_EQ] = ACTIONS(4185),
    [anon_sym_GT_EQ] = ACTIONS(4185),
    [anon_sym_LT_EQ] = ACTIONS(4185),
    [anon_sym_DOT] = ACTIONS(4188),
    [anon_sym_scoped] = ACTIONS(4179),
    [anon_sym_var] = ACTIONS(4179),
    [anon_sym_yield] = ACTIONS(4179),
    [anon_sym_switch] = ACTIONS(4188),
    [anon_sym_when] = ACTIONS(4179),
    [sym_discard] = ACTIONS(4179),
    [anon_sym_DOT_DOT] = ACTIONS(4185),
    [anon_sym_and] = ACTIONS(4188),
    [anon_sym_or] = ACTIONS(4188),
    [anon_sym_PLUS_EQ] = ACTIONS(4191),
    [anon_sym_DASH_EQ] = ACTIONS(4191),
    [anon_sym_STAR_EQ] = ACTIONS(4191),
    [anon_sym_SLASH_EQ] = ACTIONS(4191),
    [anon_sym_PERCENT_EQ] = ACTIONS(4191),
    [anon_sym_AMP_EQ] = ACTIONS(4191),
    [anon_sym_CARET_EQ] = ACTIONS(4191),
    [anon_sym_PIPE_EQ] = ACTIONS(4191),
    [anon_sym_LT_LT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4191),
    [anon_sym_AMP_AMP] = ACTIONS(4185),
    [anon_sym_PIPE_PIPE] = ACTIONS(4185),
    [anon_sym_QMARK_QMARK] = ACTIONS(4188),
    [anon_sym_from] = ACTIONS(4179),
    [anon_sym_into] = ACTIONS(4188),
    [anon_sym_join] = ACTIONS(4179),
    [anon_sym_on] = ACTIONS(4188),
    [anon_sym_equals] = ACTIONS(4179),
    [anon_sym_let] = ACTIONS(4179),
    [anon_sym_orderby] = ACTIONS(4179),
    [anon_sym_ascending] = ACTIONS(4179),
    [anon_sym_descending] = ACTIONS(4179),
    [anon_sym_group] = ACTIONS(4179),
    [anon_sym_by] = ACTIONS(4179),
    [anon_sym_select] = ACTIONS(4179),
    [anon_sym_as] = ACTIONS(4188),
    [anon_sym_is] = ACTIONS(4188),
    [anon_sym_DASH_GT] = ACTIONS(4185),
    [anon_sym_with] = ACTIONS(4188),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2901] = {
    [sym_preproc_region] = STATE(2901),
    [sym_preproc_endregion] = STATE(2901),
    [sym_preproc_line] = STATE(2901),
    [sym_preproc_pragma] = STATE(2901),
    [sym_preproc_nullable] = STATE(2901),
    [sym_preproc_error] = STATE(2901),
    [sym_preproc_warning] = STATE(2901),
    [sym_preproc_define] = STATE(2901),
    [sym_preproc_undef] = STATE(2901),
    [sym__identifier_token] = ACTIONS(4157),
    [anon_sym_alias] = ACTIONS(4157),
    [anon_sym_global] = ACTIONS(4157),
    [anon_sym_EQ] = ACTIONS(4162),
    [anon_sym_LBRACK] = ACTIONS(4164),
    [anon_sym_LPAREN] = ACTIONS(4164),
    [anon_sym_LBRACE] = ACTIONS(4168),
    [anon_sym_file] = ACTIONS(4157),
    [anon_sym_LT] = ACTIONS(4170),
    [anon_sym_GT] = ACTIONS(4170),
    [anon_sym_where] = ACTIONS(4157),
    [anon_sym_QMARK] = ACTIONS(4170),
    [anon_sym_notnull] = ACTIONS(4157),
    [anon_sym_unmanaged] = ACTIONS(4157),
    [anon_sym_BANG] = ACTIONS(4170),
    [anon_sym_PLUS_PLUS] = ACTIONS(4164),
    [anon_sym_DASH_DASH] = ACTIONS(4164),
    [anon_sym_PLUS] = ACTIONS(4170),
    [anon_sym_DASH] = ACTIONS(4170),
    [anon_sym_STAR] = ACTIONS(4170),
    [anon_sym_SLASH] = ACTIONS(4170),
    [anon_sym_PERCENT] = ACTIONS(4170),
    [anon_sym_CARET] = ACTIONS(4170),
    [anon_sym_PIPE] = ACTIONS(4170),
    [anon_sym_AMP] = ACTIONS(4170),
    [anon_sym_LT_LT] = ACTIONS(4170),
    [anon_sym_GT_GT] = ACTIONS(4170),
    [anon_sym_GT_GT_GT] = ACTIONS(4170),
    [anon_sym_EQ_EQ] = ACTIONS(4164),
    [anon_sym_BANG_EQ] = ACTIONS(4164),
    [anon_sym_GT_EQ] = ACTIONS(4164),
    [anon_sym_LT_EQ] = ACTIONS(4164),
    [anon_sym_DOT] = ACTIONS(4170),
    [anon_sym_scoped] = ACTIONS(4157),
    [anon_sym_var] = ACTIONS(4157),
    [anon_sym_yield] = ACTIONS(4157),
    [anon_sym_switch] = ACTIONS(4170),
    [anon_sym_when] = ACTIONS(4157),
    [sym_discard] = ACTIONS(4157),
    [anon_sym_DOT_DOT] = ACTIONS(4164),
    [anon_sym_and] = ACTIONS(4174),
    [anon_sym_or] = ACTIONS(4174),
    [anon_sym_PLUS_EQ] = ACTIONS(4177),
    [anon_sym_DASH_EQ] = ACTIONS(4177),
    [anon_sym_STAR_EQ] = ACTIONS(4177),
    [anon_sym_SLASH_EQ] = ACTIONS(4177),
    [anon_sym_PERCENT_EQ] = ACTIONS(4177),
    [anon_sym_AMP_EQ] = ACTIONS(4177),
    [anon_sym_CARET_EQ] = ACTIONS(4177),
    [anon_sym_PIPE_EQ] = ACTIONS(4177),
    [anon_sym_LT_LT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4177),
    [anon_sym_AMP_AMP] = ACTIONS(4164),
    [anon_sym_PIPE_PIPE] = ACTIONS(4164),
    [anon_sym_QMARK_QMARK] = ACTIONS(4170),
    [anon_sym_from] = ACTIONS(4157),
    [anon_sym_into] = ACTIONS(4157),
    [anon_sym_join] = ACTIONS(4157),
    [anon_sym_on] = ACTIONS(4174),
    [anon_sym_equals] = ACTIONS(4157),
    [anon_sym_let] = ACTIONS(4157),
    [anon_sym_orderby] = ACTIONS(4157),
    [anon_sym_ascending] = ACTIONS(4157),
    [anon_sym_descending] = ACTIONS(4157),
    [anon_sym_group] = ACTIONS(4157),
    [anon_sym_by] = ACTIONS(4157),
    [anon_sym_select] = ACTIONS(4157),
    [anon_sym_as] = ACTIONS(4170),
    [anon_sym_is] = ACTIONS(4170),
    [anon_sym_DASH_GT] = ACTIONS(4164),
    [anon_sym_with] = ACTIONS(4170),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2902] = {
    [sym_preproc_region] = STATE(2902),
    [sym_preproc_endregion] = STATE(2902),
    [sym_preproc_line] = STATE(2902),
    [sym_preproc_pragma] = STATE(2902),
    [sym_preproc_nullable] = STATE(2902),
    [sym_preproc_error] = STATE(2902),
    [sym_preproc_warning] = STATE(2902),
    [sym_preproc_define] = STATE(2902),
    [sym_preproc_undef] = STATE(2902),
    [sym__identifier_token] = ACTIONS(4482),
    [anon_sym_alias] = ACTIONS(4482),
    [anon_sym_SEMI] = ACTIONS(4484),
    [anon_sym_global] = ACTIONS(4482),
    [anon_sym_LBRACK] = ACTIONS(4484),
    [anon_sym_COLON] = ACTIONS(4484),
    [anon_sym_COMMA] = ACTIONS(4484),
    [anon_sym_RBRACK] = ACTIONS(4484),
    [anon_sym_LPAREN] = ACTIONS(4484),
    [anon_sym_RPAREN] = ACTIONS(4484),
    [anon_sym_LBRACE] = ACTIONS(4484),
    [anon_sym_RBRACE] = ACTIONS(4484),
    [anon_sym_file] = ACTIONS(4482),
    [anon_sym_LT] = ACTIONS(4482),
    [anon_sym_GT] = ACTIONS(4482),
    [anon_sym_in] = ACTIONS(4482),
    [anon_sym_where] = ACTIONS(4482),
    [anon_sym_QMARK] = ACTIONS(4482),
    [anon_sym_notnull] = ACTIONS(4482),
    [anon_sym_unmanaged] = ACTIONS(4482),
    [anon_sym_operator] = ACTIONS(4482),
    [anon_sym_BANG] = ACTIONS(4482),
    [anon_sym_PLUS_PLUS] = ACTIONS(4484),
    [anon_sym_DASH_DASH] = ACTIONS(4484),
    [anon_sym_PLUS] = ACTIONS(4482),
    [anon_sym_DASH] = ACTIONS(4482),
    [anon_sym_STAR] = ACTIONS(4484),
    [anon_sym_SLASH] = ACTIONS(4482),
    [anon_sym_PERCENT] = ACTIONS(4484),
    [anon_sym_CARET] = ACTIONS(4484),
    [anon_sym_PIPE] = ACTIONS(4482),
    [anon_sym_AMP] = ACTIONS(4482),
    [anon_sym_LT_LT] = ACTIONS(4484),
    [anon_sym_GT_GT] = ACTIONS(4482),
    [anon_sym_GT_GT_GT] = ACTIONS(4484),
    [anon_sym_EQ_EQ] = ACTIONS(4484),
    [anon_sym_BANG_EQ] = ACTIONS(4484),
    [anon_sym_GT_EQ] = ACTIONS(4484),
    [anon_sym_LT_EQ] = ACTIONS(4484),
    [anon_sym_this] = ACTIONS(4482),
    [anon_sym_DOT] = ACTIONS(4482),
    [anon_sym_scoped] = ACTIONS(4482),
    [anon_sym_EQ_GT] = ACTIONS(4484),
    [anon_sym_var] = ACTIONS(4482),
    [anon_sym_yield] = ACTIONS(4482),
    [anon_sym_switch] = ACTIONS(4482),
    [anon_sym_when] = ACTIONS(4482),
    [sym_discard] = ACTIONS(4482),
    [anon_sym_DOT_DOT] = ACTIONS(4484),
    [anon_sym_and] = ACTIONS(4482),
    [anon_sym_or] = ACTIONS(4482),
    [anon_sym_AMP_AMP] = ACTIONS(4484),
    [anon_sym_PIPE_PIPE] = ACTIONS(4484),
    [anon_sym_QMARK_QMARK] = ACTIONS(4484),
    [anon_sym_from] = ACTIONS(4482),
    [anon_sym_into] = ACTIONS(4482),
    [anon_sym_join] = ACTIONS(4482),
    [anon_sym_on] = ACTIONS(4482),
    [anon_sym_equals] = ACTIONS(4482),
    [anon_sym_let] = ACTIONS(4482),
    [anon_sym_orderby] = ACTIONS(4482),
    [anon_sym_ascending] = ACTIONS(4482),
    [anon_sym_descending] = ACTIONS(4482),
    [anon_sym_group] = ACTIONS(4482),
    [anon_sym_by] = ACTIONS(4482),
    [anon_sym_select] = ACTIONS(4482),
    [anon_sym_as] = ACTIONS(4482),
    [anon_sym_is] = ACTIONS(4482),
    [anon_sym_DASH_GT] = ACTIONS(4484),
    [anon_sym_with] = ACTIONS(4482),
    [aux_sym_preproc_if_token3] = ACTIONS(4484),
    [aux_sym_preproc_else_token1] = ACTIONS(4484),
    [aux_sym_preproc_elif_token1] = ACTIONS(4484),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2903] = {
    [sym_preproc_region] = STATE(2903),
    [sym_preproc_endregion] = STATE(2903),
    [sym_preproc_line] = STATE(2903),
    [sym_preproc_pragma] = STATE(2903),
    [sym_preproc_nullable] = STATE(2903),
    [sym_preproc_error] = STATE(2903),
    [sym_preproc_warning] = STATE(2903),
    [sym_preproc_define] = STATE(2903),
    [sym_preproc_undef] = STATE(2903),
    [sym__identifier_token] = ACTIONS(4486),
    [anon_sym_alias] = ACTIONS(4486),
    [anon_sym_SEMI] = ACTIONS(4488),
    [anon_sym_global] = ACTIONS(4486),
    [anon_sym_LBRACK] = ACTIONS(4488),
    [anon_sym_COLON] = ACTIONS(4488),
    [anon_sym_COMMA] = ACTIONS(4488),
    [anon_sym_RBRACK] = ACTIONS(4488),
    [anon_sym_LPAREN] = ACTIONS(4488),
    [anon_sym_RPAREN] = ACTIONS(4488),
    [anon_sym_LBRACE] = ACTIONS(4488),
    [anon_sym_RBRACE] = ACTIONS(4488),
    [anon_sym_file] = ACTIONS(4486),
    [anon_sym_LT] = ACTIONS(4486),
    [anon_sym_GT] = ACTIONS(4486),
    [anon_sym_in] = ACTIONS(4486),
    [anon_sym_where] = ACTIONS(4486),
    [anon_sym_QMARK] = ACTIONS(4486),
    [anon_sym_notnull] = ACTIONS(4486),
    [anon_sym_unmanaged] = ACTIONS(4486),
    [anon_sym_operator] = ACTIONS(4486),
    [anon_sym_BANG] = ACTIONS(4486),
    [anon_sym_PLUS_PLUS] = ACTIONS(4488),
    [anon_sym_DASH_DASH] = ACTIONS(4488),
    [anon_sym_PLUS] = ACTIONS(4486),
    [anon_sym_DASH] = ACTIONS(4486),
    [anon_sym_STAR] = ACTIONS(4488),
    [anon_sym_SLASH] = ACTIONS(4486),
    [anon_sym_PERCENT] = ACTIONS(4488),
    [anon_sym_CARET] = ACTIONS(4488),
    [anon_sym_PIPE] = ACTIONS(4486),
    [anon_sym_AMP] = ACTIONS(4486),
    [anon_sym_LT_LT] = ACTIONS(4488),
    [anon_sym_GT_GT] = ACTIONS(4486),
    [anon_sym_GT_GT_GT] = ACTIONS(4488),
    [anon_sym_EQ_EQ] = ACTIONS(4488),
    [anon_sym_BANG_EQ] = ACTIONS(4488),
    [anon_sym_GT_EQ] = ACTIONS(4488),
    [anon_sym_LT_EQ] = ACTIONS(4488),
    [anon_sym_this] = ACTIONS(4486),
    [anon_sym_DOT] = ACTIONS(4486),
    [anon_sym_scoped] = ACTIONS(4486),
    [anon_sym_EQ_GT] = ACTIONS(4488),
    [anon_sym_var] = ACTIONS(4486),
    [anon_sym_yield] = ACTIONS(4486),
    [anon_sym_switch] = ACTIONS(4486),
    [anon_sym_when] = ACTIONS(4486),
    [sym_discard] = ACTIONS(4486),
    [anon_sym_DOT_DOT] = ACTIONS(4488),
    [anon_sym_and] = ACTIONS(4486),
    [anon_sym_or] = ACTIONS(4486),
    [anon_sym_AMP_AMP] = ACTIONS(4488),
    [anon_sym_PIPE_PIPE] = ACTIONS(4488),
    [anon_sym_QMARK_QMARK] = ACTIONS(4488),
    [anon_sym_from] = ACTIONS(4486),
    [anon_sym_into] = ACTIONS(4486),
    [anon_sym_join] = ACTIONS(4486),
    [anon_sym_on] = ACTIONS(4486),
    [anon_sym_equals] = ACTIONS(4486),
    [anon_sym_let] = ACTIONS(4486),
    [anon_sym_orderby] = ACTIONS(4486),
    [anon_sym_ascending] = ACTIONS(4486),
    [anon_sym_descending] = ACTIONS(4486),
    [anon_sym_group] = ACTIONS(4486),
    [anon_sym_by] = ACTIONS(4486),
    [anon_sym_select] = ACTIONS(4486),
    [anon_sym_as] = ACTIONS(4486),
    [anon_sym_is] = ACTIONS(4486),
    [anon_sym_DASH_GT] = ACTIONS(4488),
    [anon_sym_with] = ACTIONS(4486),
    [aux_sym_preproc_if_token3] = ACTIONS(4488),
    [aux_sym_preproc_else_token1] = ACTIONS(4488),
    [aux_sym_preproc_elif_token1] = ACTIONS(4488),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2904] = {
    [sym_type_argument_list] = STATE(2746),
    [sym_preproc_region] = STATE(2904),
    [sym_preproc_endregion] = STATE(2904),
    [sym_preproc_line] = STATE(2904),
    [sym_preproc_pragma] = STATE(2904),
    [sym_preproc_nullable] = STATE(2904),
    [sym_preproc_error] = STATE(2904),
    [sym_preproc_warning] = STATE(2904),
    [sym_preproc_define] = STATE(2904),
    [sym_preproc_undef] = STATE(2904),
    [sym__identifier_token] = ACTIONS(4138),
    [anon_sym_alias] = ACTIONS(4138),
    [anon_sym_global] = ACTIONS(4138),
    [anon_sym_EQ] = ACTIONS(4138),
    [anon_sym_LBRACK] = ACTIONS(4140),
    [anon_sym_COLON] = ACTIONS(4490),
    [anon_sym_LPAREN] = ACTIONS(4140),
    [anon_sym_file] = ACTIONS(4138),
    [anon_sym_LT] = ACTIONS(4142),
    [anon_sym_GT] = ACTIONS(4138),
    [anon_sym_where] = ACTIONS(4138),
    [anon_sym_QMARK] = ACTIONS(4138),
    [anon_sym_notnull] = ACTIONS(4138),
    [anon_sym_unmanaged] = ACTIONS(4138),
    [anon_sym_BANG] = ACTIONS(4138),
    [anon_sym_PLUS_PLUS] = ACTIONS(4140),
    [anon_sym_DASH_DASH] = ACTIONS(4140),
    [anon_sym_PLUS] = ACTIONS(4138),
    [anon_sym_DASH] = ACTIONS(4138),
    [anon_sym_STAR] = ACTIONS(4138),
    [anon_sym_SLASH] = ACTIONS(4138),
    [anon_sym_PERCENT] = ACTIONS(4138),
    [anon_sym_CARET] = ACTIONS(4138),
    [anon_sym_PIPE] = ACTIONS(4138),
    [anon_sym_AMP] = ACTIONS(4138),
    [anon_sym_LT_LT] = ACTIONS(4138),
    [anon_sym_GT_GT] = ACTIONS(4138),
    [anon_sym_GT_GT_GT] = ACTIONS(4138),
    [anon_sym_EQ_EQ] = ACTIONS(4140),
    [anon_sym_BANG_EQ] = ACTIONS(4140),
    [anon_sym_GT_EQ] = ACTIONS(4140),
    [anon_sym_LT_EQ] = ACTIONS(4140),
    [anon_sym_DOT] = ACTIONS(4138),
    [anon_sym_scoped] = ACTIONS(4138),
    [anon_sym_EQ_GT] = ACTIONS(4145),
    [anon_sym_COLON_COLON] = ACTIONS(4147),
    [anon_sym_var] = ACTIONS(4138),
    [anon_sym_yield] = ACTIONS(4138),
    [anon_sym_switch] = ACTIONS(4138),
    [anon_sym_when] = ACTIONS(4138),
    [anon_sym_DOT_DOT] = ACTIONS(4140),
    [anon_sym_PLUS_EQ] = ACTIONS(4140),
    [anon_sym_DASH_EQ] = ACTIONS(4140),
    [anon_sym_STAR_EQ] = ACTIONS(4140),
    [anon_sym_SLASH_EQ] = ACTIONS(4140),
    [anon_sym_PERCENT_EQ] = ACTIONS(4140),
    [anon_sym_AMP_EQ] = ACTIONS(4140),
    [anon_sym_CARET_EQ] = ACTIONS(4140),
    [anon_sym_PIPE_EQ] = ACTIONS(4140),
    [anon_sym_LT_LT_EQ] = ACTIONS(4140),
    [anon_sym_GT_GT_EQ] = ACTIONS(4140),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4140),
    [anon_sym_AMP_AMP] = ACTIONS(4140),
    [anon_sym_PIPE_PIPE] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK] = ACTIONS(4138),
    [anon_sym_from] = ACTIONS(4138),
    [anon_sym_into] = ACTIONS(4138),
    [anon_sym_join] = ACTIONS(4138),
    [anon_sym_on] = ACTIONS(4138),
    [anon_sym_equals] = ACTIONS(4138),
    [anon_sym_let] = ACTIONS(4138),
    [anon_sym_orderby] = ACTIONS(4138),
    [anon_sym_ascending] = ACTIONS(4138),
    [anon_sym_descending] = ACTIONS(4138),
    [anon_sym_group] = ACTIONS(4138),
    [anon_sym_by] = ACTIONS(4138),
    [anon_sym_select] = ACTIONS(4138),
    [anon_sym_as] = ACTIONS(4138),
    [anon_sym_is] = ACTIONS(4138),
    [anon_sym_DASH_GT] = ACTIONS(4140),
    [anon_sym_with] = ACTIONS(4138),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2905] = {
    [sym_preproc_region] = STATE(2905),
    [sym_preproc_endregion] = STATE(2905),
    [sym_preproc_line] = STATE(2905),
    [sym_preproc_pragma] = STATE(2905),
    [sym_preproc_nullable] = STATE(2905),
    [sym_preproc_error] = STATE(2905),
    [sym_preproc_warning] = STATE(2905),
    [sym_preproc_define] = STATE(2905),
    [sym_preproc_undef] = STATE(2905),
    [sym__identifier_token] = ACTIONS(4157),
    [anon_sym_alias] = ACTIONS(4157),
    [anon_sym_global] = ACTIONS(4157),
    [anon_sym_EQ] = ACTIONS(4162),
    [anon_sym_LBRACK] = ACTIONS(4193),
    [anon_sym_COLON] = ACTIONS(4177),
    [anon_sym_LPAREN] = ACTIONS(4193),
    [anon_sym_file] = ACTIONS(4157),
    [anon_sym_LT] = ACTIONS(4162),
    [anon_sym_GT] = ACTIONS(4162),
    [anon_sym_where] = ACTIONS(4157),
    [anon_sym_QMARK] = ACTIONS(4196),
    [anon_sym_notnull] = ACTIONS(4157),
    [anon_sym_unmanaged] = ACTIONS(4157),
    [anon_sym_BANG] = ACTIONS(4162),
    [anon_sym_PLUS_PLUS] = ACTIONS(4177),
    [anon_sym_DASH_DASH] = ACTIONS(4177),
    [anon_sym_PLUS] = ACTIONS(4162),
    [anon_sym_DASH] = ACTIONS(4162),
    [anon_sym_STAR] = ACTIONS(4196),
    [anon_sym_SLASH] = ACTIONS(4162),
    [anon_sym_PERCENT] = ACTIONS(4162),
    [anon_sym_CARET] = ACTIONS(4162),
    [anon_sym_PIPE] = ACTIONS(4162),
    [anon_sym_AMP] = ACTIONS(4162),
    [anon_sym_LT_LT] = ACTIONS(4162),
    [anon_sym_GT_GT] = ACTIONS(4162),
    [anon_sym_GT_GT_GT] = ACTIONS(4162),
    [anon_sym_EQ_EQ] = ACTIONS(4177),
    [anon_sym_BANG_EQ] = ACTIONS(4177),
    [anon_sym_GT_EQ] = ACTIONS(4177),
    [anon_sym_LT_EQ] = ACTIONS(4177),
    [anon_sym_DOT] = ACTIONS(4196),
    [anon_sym_scoped] = ACTIONS(4157),
    [anon_sym_EQ_GT] = ACTIONS(4177),
    [anon_sym_var] = ACTIONS(4157),
    [anon_sym_yield] = ACTIONS(4157),
    [anon_sym_switch] = ACTIONS(4162),
    [anon_sym_when] = ACTIONS(4196),
    [anon_sym_DOT_DOT] = ACTIONS(4177),
    [anon_sym_and] = ACTIONS(4162),
    [anon_sym_or] = ACTIONS(4162),
    [anon_sym_PLUS_EQ] = ACTIONS(4177),
    [anon_sym_DASH_EQ] = ACTIONS(4177),
    [anon_sym_STAR_EQ] = ACTIONS(4177),
    [anon_sym_SLASH_EQ] = ACTIONS(4177),
    [anon_sym_PERCENT_EQ] = ACTIONS(4177),
    [anon_sym_AMP_EQ] = ACTIONS(4177),
    [anon_sym_CARET_EQ] = ACTIONS(4177),
    [anon_sym_PIPE_EQ] = ACTIONS(4177),
    [anon_sym_LT_LT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4177),
    [anon_sym_AMP_AMP] = ACTIONS(4177),
    [anon_sym_PIPE_PIPE] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK] = ACTIONS(4162),
    [anon_sym_from] = ACTIONS(4157),
    [anon_sym_into] = ACTIONS(4157),
    [anon_sym_join] = ACTIONS(4157),
    [anon_sym_on] = ACTIONS(4157),
    [anon_sym_equals] = ACTIONS(4157),
    [anon_sym_let] = ACTIONS(4157),
    [anon_sym_orderby] = ACTIONS(4157),
    [anon_sym_ascending] = ACTIONS(4157),
    [anon_sym_descending] = ACTIONS(4157),
    [anon_sym_group] = ACTIONS(4157),
    [anon_sym_by] = ACTIONS(4157),
    [anon_sym_select] = ACTIONS(4157),
    [anon_sym_as] = ACTIONS(4162),
    [anon_sym_is] = ACTIONS(4162),
    [anon_sym_DASH_GT] = ACTIONS(4193),
    [anon_sym_with] = ACTIONS(4162),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2906] = {
    [sym_preproc_region] = STATE(2906),
    [sym_preproc_endregion] = STATE(2906),
    [sym_preproc_line] = STATE(2906),
    [sym_preproc_pragma] = STATE(2906),
    [sym_preproc_nullable] = STATE(2906),
    [sym_preproc_error] = STATE(2906),
    [sym_preproc_warning] = STATE(2906),
    [sym_preproc_define] = STATE(2906),
    [sym_preproc_undef] = STATE(2906),
    [sym__identifier_token] = ACTIONS(4492),
    [anon_sym_alias] = ACTIONS(4492),
    [anon_sym_SEMI] = ACTIONS(4494),
    [anon_sym_global] = ACTIONS(4492),
    [anon_sym_LBRACK] = ACTIONS(4494),
    [anon_sym_COLON] = ACTIONS(4494),
    [anon_sym_COMMA] = ACTIONS(4494),
    [anon_sym_RBRACK] = ACTIONS(4494),
    [anon_sym_LPAREN] = ACTIONS(4494),
    [anon_sym_RPAREN] = ACTIONS(4494),
    [anon_sym_LBRACE] = ACTIONS(4494),
    [anon_sym_RBRACE] = ACTIONS(4494),
    [anon_sym_file] = ACTIONS(4492),
    [anon_sym_LT] = ACTIONS(4492),
    [anon_sym_GT] = ACTIONS(4492),
    [anon_sym_in] = ACTIONS(4492),
    [anon_sym_where] = ACTIONS(4492),
    [anon_sym_QMARK] = ACTIONS(4492),
    [anon_sym_notnull] = ACTIONS(4492),
    [anon_sym_unmanaged] = ACTIONS(4492),
    [anon_sym_operator] = ACTIONS(4492),
    [anon_sym_BANG] = ACTIONS(4492),
    [anon_sym_PLUS_PLUS] = ACTIONS(4494),
    [anon_sym_DASH_DASH] = ACTIONS(4494),
    [anon_sym_PLUS] = ACTIONS(4492),
    [anon_sym_DASH] = ACTIONS(4492),
    [anon_sym_STAR] = ACTIONS(4494),
    [anon_sym_SLASH] = ACTIONS(4492),
    [anon_sym_PERCENT] = ACTIONS(4494),
    [anon_sym_CARET] = ACTIONS(4494),
    [anon_sym_PIPE] = ACTIONS(4492),
    [anon_sym_AMP] = ACTIONS(4492),
    [anon_sym_LT_LT] = ACTIONS(4494),
    [anon_sym_GT_GT] = ACTIONS(4492),
    [anon_sym_GT_GT_GT] = ACTIONS(4494),
    [anon_sym_EQ_EQ] = ACTIONS(4494),
    [anon_sym_BANG_EQ] = ACTIONS(4494),
    [anon_sym_GT_EQ] = ACTIONS(4494),
    [anon_sym_LT_EQ] = ACTIONS(4494),
    [anon_sym_this] = ACTIONS(4492),
    [anon_sym_DOT] = ACTIONS(4492),
    [anon_sym_scoped] = ACTIONS(4492),
    [anon_sym_EQ_GT] = ACTIONS(4494),
    [anon_sym_var] = ACTIONS(4492),
    [anon_sym_yield] = ACTIONS(4492),
    [anon_sym_switch] = ACTIONS(4492),
    [anon_sym_when] = ACTIONS(4492),
    [sym_discard] = ACTIONS(4492),
    [anon_sym_DOT_DOT] = ACTIONS(4494),
    [anon_sym_and] = ACTIONS(4492),
    [anon_sym_or] = ACTIONS(4492),
    [anon_sym_AMP_AMP] = ACTIONS(4494),
    [anon_sym_PIPE_PIPE] = ACTIONS(4494),
    [anon_sym_QMARK_QMARK] = ACTIONS(4494),
    [anon_sym_from] = ACTIONS(4492),
    [anon_sym_into] = ACTIONS(4492),
    [anon_sym_join] = ACTIONS(4492),
    [anon_sym_on] = ACTIONS(4492),
    [anon_sym_equals] = ACTIONS(4492),
    [anon_sym_let] = ACTIONS(4492),
    [anon_sym_orderby] = ACTIONS(4492),
    [anon_sym_ascending] = ACTIONS(4492),
    [anon_sym_descending] = ACTIONS(4492),
    [anon_sym_group] = ACTIONS(4492),
    [anon_sym_by] = ACTIONS(4492),
    [anon_sym_select] = ACTIONS(4492),
    [anon_sym_as] = ACTIONS(4492),
    [anon_sym_is] = ACTIONS(4492),
    [anon_sym_DASH_GT] = ACTIONS(4494),
    [anon_sym_with] = ACTIONS(4492),
    [aux_sym_preproc_if_token3] = ACTIONS(4494),
    [aux_sym_preproc_else_token1] = ACTIONS(4494),
    [aux_sym_preproc_elif_token1] = ACTIONS(4494),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2907] = {
    [sym_type_argument_list] = STATE(2746),
    [sym_preproc_region] = STATE(2907),
    [sym_preproc_endregion] = STATE(2907),
    [sym_preproc_line] = STATE(2907),
    [sym_preproc_pragma] = STATE(2907),
    [sym_preproc_nullable] = STATE(2907),
    [sym_preproc_error] = STATE(2907),
    [sym_preproc_warning] = STATE(2907),
    [sym_preproc_define] = STATE(2907),
    [sym_preproc_undef] = STATE(2907),
    [sym__identifier_token] = ACTIONS(4138),
    [anon_sym_alias] = ACTIONS(4138),
    [anon_sym_global] = ACTIONS(4138),
    [anon_sym_EQ] = ACTIONS(4138),
    [anon_sym_LBRACK] = ACTIONS(4140),
    [anon_sym_COLON] = ACTIONS(4496),
    [anon_sym_LPAREN] = ACTIONS(4140),
    [anon_sym_file] = ACTIONS(4138),
    [anon_sym_LT] = ACTIONS(4142),
    [anon_sym_GT] = ACTIONS(4138),
    [anon_sym_where] = ACTIONS(4138),
    [anon_sym_QMARK] = ACTIONS(4138),
    [anon_sym_notnull] = ACTIONS(4138),
    [anon_sym_unmanaged] = ACTIONS(4138),
    [anon_sym_BANG] = ACTIONS(4138),
    [anon_sym_PLUS_PLUS] = ACTIONS(4140),
    [anon_sym_DASH_DASH] = ACTIONS(4140),
    [anon_sym_PLUS] = ACTIONS(4138),
    [anon_sym_DASH] = ACTIONS(4138),
    [anon_sym_STAR] = ACTIONS(4138),
    [anon_sym_SLASH] = ACTIONS(4138),
    [anon_sym_PERCENT] = ACTIONS(4138),
    [anon_sym_CARET] = ACTIONS(4138),
    [anon_sym_PIPE] = ACTIONS(4138),
    [anon_sym_AMP] = ACTIONS(4138),
    [anon_sym_LT_LT] = ACTIONS(4138),
    [anon_sym_GT_GT] = ACTIONS(4138),
    [anon_sym_GT_GT_GT] = ACTIONS(4138),
    [anon_sym_EQ_EQ] = ACTIONS(4140),
    [anon_sym_BANG_EQ] = ACTIONS(4140),
    [anon_sym_GT_EQ] = ACTIONS(4140),
    [anon_sym_LT_EQ] = ACTIONS(4140),
    [anon_sym_DOT] = ACTIONS(4138),
    [anon_sym_scoped] = ACTIONS(4138),
    [anon_sym_EQ_GT] = ACTIONS(4145),
    [anon_sym_COLON_COLON] = ACTIONS(4147),
    [anon_sym_var] = ACTIONS(4138),
    [anon_sym_yield] = ACTIONS(4138),
    [anon_sym_switch] = ACTIONS(4138),
    [anon_sym_when] = ACTIONS(4138),
    [anon_sym_DOT_DOT] = ACTIONS(4140),
    [anon_sym_PLUS_EQ] = ACTIONS(4140),
    [anon_sym_DASH_EQ] = ACTIONS(4140),
    [anon_sym_STAR_EQ] = ACTIONS(4140),
    [anon_sym_SLASH_EQ] = ACTIONS(4140),
    [anon_sym_PERCENT_EQ] = ACTIONS(4140),
    [anon_sym_AMP_EQ] = ACTIONS(4140),
    [anon_sym_CARET_EQ] = ACTIONS(4140),
    [anon_sym_PIPE_EQ] = ACTIONS(4140),
    [anon_sym_LT_LT_EQ] = ACTIONS(4140),
    [anon_sym_GT_GT_EQ] = ACTIONS(4140),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4140),
    [anon_sym_AMP_AMP] = ACTIONS(4140),
    [anon_sym_PIPE_PIPE] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK] = ACTIONS(4138),
    [anon_sym_from] = ACTIONS(4138),
    [anon_sym_into] = ACTIONS(4138),
    [anon_sym_join] = ACTIONS(4138),
    [anon_sym_on] = ACTIONS(4138),
    [anon_sym_equals] = ACTIONS(4138),
    [anon_sym_let] = ACTIONS(4138),
    [anon_sym_orderby] = ACTIONS(4138),
    [anon_sym_ascending] = ACTIONS(4138),
    [anon_sym_descending] = ACTIONS(4138),
    [anon_sym_group] = ACTIONS(4138),
    [anon_sym_by] = ACTIONS(4138),
    [anon_sym_select] = ACTIONS(4138),
    [anon_sym_as] = ACTIONS(4138),
    [anon_sym_is] = ACTIONS(4138),
    [anon_sym_DASH_GT] = ACTIONS(4140),
    [anon_sym_with] = ACTIONS(4138),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2908] = {
    [sym_preproc_region] = STATE(2908),
    [sym_preproc_endregion] = STATE(2908),
    [sym_preproc_line] = STATE(2908),
    [sym_preproc_pragma] = STATE(2908),
    [sym_preproc_nullable] = STATE(2908),
    [sym_preproc_error] = STATE(2908),
    [sym_preproc_warning] = STATE(2908),
    [sym_preproc_define] = STATE(2908),
    [sym_preproc_undef] = STATE(2908),
    [sym__identifier_token] = ACTIONS(4157),
    [anon_sym_alias] = ACTIONS(4157),
    [anon_sym_global] = ACTIONS(4157),
    [anon_sym_EQ] = ACTIONS(4162),
    [anon_sym_LBRACK] = ACTIONS(4164),
    [anon_sym_LPAREN] = ACTIONS(4164),
    [anon_sym_LBRACE] = ACTIONS(4168),
    [anon_sym_file] = ACTIONS(4157),
    [anon_sym_LT] = ACTIONS(4170),
    [anon_sym_GT] = ACTIONS(4170),
    [anon_sym_where] = ACTIONS(4157),
    [anon_sym_QMARK] = ACTIONS(4170),
    [anon_sym_notnull] = ACTIONS(4157),
    [anon_sym_unmanaged] = ACTIONS(4157),
    [anon_sym_BANG] = ACTIONS(4170),
    [anon_sym_PLUS_PLUS] = ACTIONS(4164),
    [anon_sym_DASH_DASH] = ACTIONS(4164),
    [anon_sym_PLUS] = ACTIONS(4170),
    [anon_sym_DASH] = ACTIONS(4170),
    [anon_sym_STAR] = ACTIONS(4170),
    [anon_sym_SLASH] = ACTIONS(4170),
    [anon_sym_PERCENT] = ACTIONS(4170),
    [anon_sym_CARET] = ACTIONS(4170),
    [anon_sym_PIPE] = ACTIONS(4170),
    [anon_sym_AMP] = ACTIONS(4170),
    [anon_sym_LT_LT] = ACTIONS(4170),
    [anon_sym_GT_GT] = ACTIONS(4170),
    [anon_sym_GT_GT_GT] = ACTIONS(4170),
    [anon_sym_EQ_EQ] = ACTIONS(4164),
    [anon_sym_BANG_EQ] = ACTIONS(4164),
    [anon_sym_GT_EQ] = ACTIONS(4164),
    [anon_sym_LT_EQ] = ACTIONS(4164),
    [anon_sym_DOT] = ACTIONS(4170),
    [anon_sym_scoped] = ACTIONS(4157),
    [anon_sym_var] = ACTIONS(4157),
    [anon_sym_yield] = ACTIONS(4157),
    [anon_sym_switch] = ACTIONS(4170),
    [anon_sym_when] = ACTIONS(4157),
    [sym_discard] = ACTIONS(4157),
    [anon_sym_DOT_DOT] = ACTIONS(4164),
    [anon_sym_and] = ACTIONS(4174),
    [anon_sym_or] = ACTIONS(4174),
    [anon_sym_PLUS_EQ] = ACTIONS(4177),
    [anon_sym_DASH_EQ] = ACTIONS(4177),
    [anon_sym_STAR_EQ] = ACTIONS(4177),
    [anon_sym_SLASH_EQ] = ACTIONS(4177),
    [anon_sym_PERCENT_EQ] = ACTIONS(4177),
    [anon_sym_AMP_EQ] = ACTIONS(4177),
    [anon_sym_CARET_EQ] = ACTIONS(4177),
    [anon_sym_PIPE_EQ] = ACTIONS(4177),
    [anon_sym_LT_LT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4177),
    [anon_sym_AMP_AMP] = ACTIONS(4164),
    [anon_sym_PIPE_PIPE] = ACTIONS(4164),
    [anon_sym_QMARK_QMARK] = ACTIONS(4170),
    [anon_sym_from] = ACTIONS(4157),
    [anon_sym_into] = ACTIONS(4174),
    [anon_sym_join] = ACTIONS(4157),
    [anon_sym_on] = ACTIONS(4157),
    [anon_sym_equals] = ACTIONS(4174),
    [anon_sym_let] = ACTIONS(4157),
    [anon_sym_orderby] = ACTIONS(4157),
    [anon_sym_ascending] = ACTIONS(4157),
    [anon_sym_descending] = ACTIONS(4157),
    [anon_sym_group] = ACTIONS(4157),
    [anon_sym_by] = ACTIONS(4157),
    [anon_sym_select] = ACTIONS(4157),
    [anon_sym_as] = ACTIONS(4170),
    [anon_sym_is] = ACTIONS(4170),
    [anon_sym_DASH_GT] = ACTIONS(4164),
    [anon_sym_with] = ACTIONS(4170),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2909] = {
    [sym_preproc_region] = STATE(2909),
    [sym_preproc_endregion] = STATE(2909),
    [sym_preproc_line] = STATE(2909),
    [sym_preproc_pragma] = STATE(2909),
    [sym_preproc_nullable] = STATE(2909),
    [sym_preproc_error] = STATE(2909),
    [sym_preproc_warning] = STATE(2909),
    [sym_preproc_define] = STATE(2909),
    [sym_preproc_undef] = STATE(2909),
    [sym__identifier_token] = ACTIONS(4498),
    [anon_sym_alias] = ACTIONS(4498),
    [anon_sym_SEMI] = ACTIONS(4500),
    [anon_sym_global] = ACTIONS(4498),
    [anon_sym_LBRACK] = ACTIONS(4500),
    [anon_sym_COLON] = ACTIONS(4500),
    [anon_sym_COMMA] = ACTIONS(4500),
    [anon_sym_RBRACK] = ACTIONS(4500),
    [anon_sym_LPAREN] = ACTIONS(4500),
    [anon_sym_RPAREN] = ACTIONS(4500),
    [anon_sym_LBRACE] = ACTIONS(4500),
    [anon_sym_RBRACE] = ACTIONS(4500),
    [anon_sym_file] = ACTIONS(4498),
    [anon_sym_LT] = ACTIONS(4498),
    [anon_sym_GT] = ACTIONS(4498),
    [anon_sym_in] = ACTIONS(4498),
    [anon_sym_where] = ACTIONS(4498),
    [anon_sym_QMARK] = ACTIONS(4498),
    [anon_sym_notnull] = ACTIONS(4498),
    [anon_sym_unmanaged] = ACTIONS(4498),
    [anon_sym_operator] = ACTIONS(4498),
    [anon_sym_BANG] = ACTIONS(4498),
    [anon_sym_PLUS_PLUS] = ACTIONS(4500),
    [anon_sym_DASH_DASH] = ACTIONS(4500),
    [anon_sym_PLUS] = ACTIONS(4498),
    [anon_sym_DASH] = ACTIONS(4498),
    [anon_sym_STAR] = ACTIONS(4500),
    [anon_sym_SLASH] = ACTIONS(4498),
    [anon_sym_PERCENT] = ACTIONS(4500),
    [anon_sym_CARET] = ACTIONS(4500),
    [anon_sym_PIPE] = ACTIONS(4498),
    [anon_sym_AMP] = ACTIONS(4498),
    [anon_sym_LT_LT] = ACTIONS(4500),
    [anon_sym_GT_GT] = ACTIONS(4498),
    [anon_sym_GT_GT_GT] = ACTIONS(4500),
    [anon_sym_EQ_EQ] = ACTIONS(4500),
    [anon_sym_BANG_EQ] = ACTIONS(4500),
    [anon_sym_GT_EQ] = ACTIONS(4500),
    [anon_sym_LT_EQ] = ACTIONS(4500),
    [anon_sym_this] = ACTIONS(4498),
    [anon_sym_DOT] = ACTIONS(4498),
    [anon_sym_scoped] = ACTIONS(4498),
    [anon_sym_EQ_GT] = ACTIONS(4500),
    [anon_sym_var] = ACTIONS(4498),
    [anon_sym_yield] = ACTIONS(4498),
    [anon_sym_switch] = ACTIONS(4498),
    [anon_sym_when] = ACTIONS(4498),
    [sym_discard] = ACTIONS(4498),
    [anon_sym_DOT_DOT] = ACTIONS(4500),
    [anon_sym_and] = ACTIONS(4498),
    [anon_sym_or] = ACTIONS(4498),
    [anon_sym_AMP_AMP] = ACTIONS(4500),
    [anon_sym_PIPE_PIPE] = ACTIONS(4500),
    [anon_sym_QMARK_QMARK] = ACTIONS(4500),
    [anon_sym_from] = ACTIONS(4498),
    [anon_sym_into] = ACTIONS(4498),
    [anon_sym_join] = ACTIONS(4498),
    [anon_sym_on] = ACTIONS(4498),
    [anon_sym_equals] = ACTIONS(4498),
    [anon_sym_let] = ACTIONS(4498),
    [anon_sym_orderby] = ACTIONS(4498),
    [anon_sym_ascending] = ACTIONS(4498),
    [anon_sym_descending] = ACTIONS(4498),
    [anon_sym_group] = ACTIONS(4498),
    [anon_sym_by] = ACTIONS(4498),
    [anon_sym_select] = ACTIONS(4498),
    [anon_sym_as] = ACTIONS(4498),
    [anon_sym_is] = ACTIONS(4498),
    [anon_sym_DASH_GT] = ACTIONS(4500),
    [anon_sym_with] = ACTIONS(4498),
    [aux_sym_preproc_if_token3] = ACTIONS(4500),
    [aux_sym_preproc_else_token1] = ACTIONS(4500),
    [aux_sym_preproc_elif_token1] = ACTIONS(4500),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2910] = {
    [sym_preproc_region] = STATE(2910),
    [sym_preproc_endregion] = STATE(2910),
    [sym_preproc_line] = STATE(2910),
    [sym_preproc_pragma] = STATE(2910),
    [sym_preproc_nullable] = STATE(2910),
    [sym_preproc_error] = STATE(2910),
    [sym_preproc_warning] = STATE(2910),
    [sym_preproc_define] = STATE(2910),
    [sym_preproc_undef] = STATE(2910),
    [sym__identifier_token] = ACTIONS(4179),
    [anon_sym_alias] = ACTIONS(4179),
    [anon_sym_global] = ACTIONS(4179),
    [anon_sym_EQ] = ACTIONS(4183),
    [anon_sym_LBRACK] = ACTIONS(4185),
    [anon_sym_COLON] = ACTIONS(4191),
    [anon_sym_LPAREN] = ACTIONS(4185),
    [anon_sym_file] = ACTIONS(4179),
    [anon_sym_LT] = ACTIONS(4183),
    [anon_sym_GT] = ACTIONS(4183),
    [anon_sym_where] = ACTIONS(4179),
    [anon_sym_QMARK] = ACTIONS(4188),
    [anon_sym_notnull] = ACTIONS(4179),
    [anon_sym_unmanaged] = ACTIONS(4179),
    [anon_sym_BANG] = ACTIONS(4183),
    [anon_sym_PLUS_PLUS] = ACTIONS(4191),
    [anon_sym_DASH_DASH] = ACTIONS(4191),
    [anon_sym_PLUS] = ACTIONS(4183),
    [anon_sym_DASH] = ACTIONS(4183),
    [anon_sym_STAR] = ACTIONS(4188),
    [anon_sym_SLASH] = ACTIONS(4183),
    [anon_sym_PERCENT] = ACTIONS(4183),
    [anon_sym_CARET] = ACTIONS(4183),
    [anon_sym_PIPE] = ACTIONS(4183),
    [anon_sym_AMP] = ACTIONS(4183),
    [anon_sym_LT_LT] = ACTIONS(4183),
    [anon_sym_GT_GT] = ACTIONS(4183),
    [anon_sym_GT_GT_GT] = ACTIONS(4183),
    [anon_sym_EQ_EQ] = ACTIONS(4191),
    [anon_sym_BANG_EQ] = ACTIONS(4191),
    [anon_sym_GT_EQ] = ACTIONS(4191),
    [anon_sym_LT_EQ] = ACTIONS(4191),
    [anon_sym_DOT] = ACTIONS(4188),
    [anon_sym_scoped] = ACTIONS(4179),
    [anon_sym_EQ_GT] = ACTIONS(4191),
    [anon_sym_var] = ACTIONS(4179),
    [anon_sym_yield] = ACTIONS(4179),
    [anon_sym_switch] = ACTIONS(4183),
    [anon_sym_when] = ACTIONS(4188),
    [anon_sym_DOT_DOT] = ACTIONS(4191),
    [anon_sym_and] = ACTIONS(4183),
    [anon_sym_or] = ACTIONS(4183),
    [anon_sym_PLUS_EQ] = ACTIONS(4191),
    [anon_sym_DASH_EQ] = ACTIONS(4191),
    [anon_sym_STAR_EQ] = ACTIONS(4191),
    [anon_sym_SLASH_EQ] = ACTIONS(4191),
    [anon_sym_PERCENT_EQ] = ACTIONS(4191),
    [anon_sym_AMP_EQ] = ACTIONS(4191),
    [anon_sym_CARET_EQ] = ACTIONS(4191),
    [anon_sym_PIPE_EQ] = ACTIONS(4191),
    [anon_sym_LT_LT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4191),
    [anon_sym_AMP_AMP] = ACTIONS(4191),
    [anon_sym_PIPE_PIPE] = ACTIONS(4191),
    [anon_sym_QMARK_QMARK] = ACTIONS(4183),
    [anon_sym_from] = ACTIONS(4179),
    [anon_sym_into] = ACTIONS(4179),
    [anon_sym_join] = ACTIONS(4179),
    [anon_sym_on] = ACTIONS(4179),
    [anon_sym_equals] = ACTIONS(4179),
    [anon_sym_let] = ACTIONS(4179),
    [anon_sym_orderby] = ACTIONS(4179),
    [anon_sym_ascending] = ACTIONS(4179),
    [anon_sym_descending] = ACTIONS(4179),
    [anon_sym_group] = ACTIONS(4179),
    [anon_sym_by] = ACTIONS(4179),
    [anon_sym_select] = ACTIONS(4179),
    [anon_sym_as] = ACTIONS(4183),
    [anon_sym_is] = ACTIONS(4183),
    [anon_sym_DASH_GT] = ACTIONS(4185),
    [anon_sym_with] = ACTIONS(4183),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2911] = {
    [sym_preproc_region] = STATE(2911),
    [sym_preproc_endregion] = STATE(2911),
    [sym_preproc_line] = STATE(2911),
    [sym_preproc_pragma] = STATE(2911),
    [sym_preproc_nullable] = STATE(2911),
    [sym_preproc_error] = STATE(2911),
    [sym_preproc_warning] = STATE(2911),
    [sym_preproc_define] = STATE(2911),
    [sym_preproc_undef] = STATE(2911),
    [sym__identifier_token] = ACTIONS(4157),
    [anon_sym_alias] = ACTIONS(4157),
    [anon_sym_global] = ACTIONS(4157),
    [anon_sym_EQ] = ACTIONS(4162),
    [anon_sym_LBRACK] = ACTIONS(4164),
    [anon_sym_LPAREN] = ACTIONS(4164),
    [anon_sym_LBRACE] = ACTIONS(4168),
    [anon_sym_file] = ACTIONS(4157),
    [anon_sym_LT] = ACTIONS(4170),
    [anon_sym_GT] = ACTIONS(4170),
    [anon_sym_where] = ACTIONS(4157),
    [anon_sym_QMARK] = ACTIONS(4170),
    [anon_sym_notnull] = ACTIONS(4157),
    [anon_sym_unmanaged] = ACTIONS(4157),
    [anon_sym_BANG] = ACTIONS(4170),
    [anon_sym_PLUS_PLUS] = ACTIONS(4164),
    [anon_sym_DASH_DASH] = ACTIONS(4164),
    [anon_sym_PLUS] = ACTIONS(4170),
    [anon_sym_DASH] = ACTIONS(4170),
    [anon_sym_STAR] = ACTIONS(4170),
    [anon_sym_SLASH] = ACTIONS(4170),
    [anon_sym_PERCENT] = ACTIONS(4170),
    [anon_sym_CARET] = ACTIONS(4170),
    [anon_sym_PIPE] = ACTIONS(4170),
    [anon_sym_AMP] = ACTIONS(4170),
    [anon_sym_LT_LT] = ACTIONS(4170),
    [anon_sym_GT_GT] = ACTIONS(4170),
    [anon_sym_GT_GT_GT] = ACTIONS(4170),
    [anon_sym_EQ_EQ] = ACTIONS(4164),
    [anon_sym_BANG_EQ] = ACTIONS(4164),
    [anon_sym_GT_EQ] = ACTIONS(4164),
    [anon_sym_LT_EQ] = ACTIONS(4164),
    [anon_sym_DOT] = ACTIONS(4170),
    [anon_sym_scoped] = ACTIONS(4157),
    [anon_sym_var] = ACTIONS(4157),
    [anon_sym_yield] = ACTIONS(4157),
    [anon_sym_switch] = ACTIONS(4170),
    [anon_sym_when] = ACTIONS(4157),
    [sym_discard] = ACTIONS(4157),
    [anon_sym_DOT_DOT] = ACTIONS(4164),
    [anon_sym_and] = ACTIONS(4174),
    [anon_sym_or] = ACTIONS(4174),
    [anon_sym_PLUS_EQ] = ACTIONS(4177),
    [anon_sym_DASH_EQ] = ACTIONS(4177),
    [anon_sym_STAR_EQ] = ACTIONS(4177),
    [anon_sym_SLASH_EQ] = ACTIONS(4177),
    [anon_sym_PERCENT_EQ] = ACTIONS(4177),
    [anon_sym_AMP_EQ] = ACTIONS(4177),
    [anon_sym_CARET_EQ] = ACTIONS(4177),
    [anon_sym_PIPE_EQ] = ACTIONS(4177),
    [anon_sym_LT_LT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4177),
    [anon_sym_AMP_AMP] = ACTIONS(4164),
    [anon_sym_PIPE_PIPE] = ACTIONS(4164),
    [anon_sym_QMARK_QMARK] = ACTIONS(4170),
    [anon_sym_from] = ACTIONS(4157),
    [anon_sym_into] = ACTIONS(4174),
    [anon_sym_join] = ACTIONS(4157),
    [anon_sym_on] = ACTIONS(4174),
    [anon_sym_equals] = ACTIONS(4157),
    [anon_sym_let] = ACTIONS(4157),
    [anon_sym_orderby] = ACTIONS(4157),
    [anon_sym_ascending] = ACTIONS(4157),
    [anon_sym_descending] = ACTIONS(4157),
    [anon_sym_group] = ACTIONS(4157),
    [anon_sym_by] = ACTIONS(4157),
    [anon_sym_select] = ACTIONS(4157),
    [anon_sym_as] = ACTIONS(4170),
    [anon_sym_is] = ACTIONS(4170),
    [anon_sym_DASH_GT] = ACTIONS(4164),
    [anon_sym_with] = ACTIONS(4170),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2912] = {
    [sym_preproc_region] = STATE(2912),
    [sym_preproc_endregion] = STATE(2912),
    [sym_preproc_line] = STATE(2912),
    [sym_preproc_pragma] = STATE(2912),
    [sym_preproc_nullable] = STATE(2912),
    [sym_preproc_error] = STATE(2912),
    [sym_preproc_warning] = STATE(2912),
    [sym_preproc_define] = STATE(2912),
    [sym_preproc_undef] = STATE(2912),
    [sym__identifier_token] = ACTIONS(4157),
    [anon_sym_alias] = ACTIONS(4157),
    [anon_sym_global] = ACTIONS(4157),
    [anon_sym_EQ] = ACTIONS(4162),
    [anon_sym_LBRACK] = ACTIONS(4193),
    [anon_sym_COLON] = ACTIONS(4177),
    [anon_sym_LPAREN] = ACTIONS(4193),
    [anon_sym_file] = ACTIONS(4157),
    [anon_sym_LT] = ACTIONS(4162),
    [anon_sym_GT] = ACTIONS(4162),
    [anon_sym_where] = ACTIONS(4157),
    [anon_sym_QMARK] = ACTIONS(4196),
    [anon_sym_notnull] = ACTIONS(4157),
    [anon_sym_unmanaged] = ACTIONS(4157),
    [anon_sym_BANG] = ACTIONS(4162),
    [anon_sym_PLUS_PLUS] = ACTIONS(4177),
    [anon_sym_DASH_DASH] = ACTIONS(4177),
    [anon_sym_PLUS] = ACTIONS(4162),
    [anon_sym_DASH] = ACTIONS(4162),
    [anon_sym_STAR] = ACTIONS(4196),
    [anon_sym_SLASH] = ACTIONS(4162),
    [anon_sym_PERCENT] = ACTIONS(4162),
    [anon_sym_CARET] = ACTIONS(4162),
    [anon_sym_PIPE] = ACTIONS(4162),
    [anon_sym_AMP] = ACTIONS(4162),
    [anon_sym_LT_LT] = ACTIONS(4162),
    [anon_sym_GT_GT] = ACTIONS(4162),
    [anon_sym_GT_GT_GT] = ACTIONS(4162),
    [anon_sym_EQ_EQ] = ACTIONS(4177),
    [anon_sym_BANG_EQ] = ACTIONS(4177),
    [anon_sym_GT_EQ] = ACTIONS(4177),
    [anon_sym_LT_EQ] = ACTIONS(4177),
    [anon_sym_DOT] = ACTIONS(4196),
    [anon_sym_scoped] = ACTIONS(4157),
    [anon_sym_EQ_GT] = ACTIONS(4177),
    [anon_sym_var] = ACTIONS(4157),
    [anon_sym_yield] = ACTIONS(4157),
    [anon_sym_switch] = ACTIONS(4162),
    [anon_sym_when] = ACTIONS(4196),
    [anon_sym_DOT_DOT] = ACTIONS(4177),
    [anon_sym_and] = ACTIONS(4162),
    [anon_sym_or] = ACTIONS(4162),
    [anon_sym_PLUS_EQ] = ACTIONS(4177),
    [anon_sym_DASH_EQ] = ACTIONS(4177),
    [anon_sym_STAR_EQ] = ACTIONS(4177),
    [anon_sym_SLASH_EQ] = ACTIONS(4177),
    [anon_sym_PERCENT_EQ] = ACTIONS(4177),
    [anon_sym_AMP_EQ] = ACTIONS(4177),
    [anon_sym_CARET_EQ] = ACTIONS(4177),
    [anon_sym_PIPE_EQ] = ACTIONS(4177),
    [anon_sym_LT_LT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4177),
    [anon_sym_AMP_AMP] = ACTIONS(4177),
    [anon_sym_PIPE_PIPE] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK] = ACTIONS(4162),
    [anon_sym_from] = ACTIONS(4157),
    [anon_sym_into] = ACTIONS(4196),
    [anon_sym_join] = ACTIONS(4157),
    [anon_sym_on] = ACTIONS(4157),
    [anon_sym_equals] = ACTIONS(4157),
    [anon_sym_let] = ACTIONS(4157),
    [anon_sym_orderby] = ACTIONS(4157),
    [anon_sym_ascending] = ACTIONS(4157),
    [anon_sym_descending] = ACTIONS(4157),
    [anon_sym_group] = ACTIONS(4157),
    [anon_sym_by] = ACTIONS(4157),
    [anon_sym_select] = ACTIONS(4157),
    [anon_sym_as] = ACTIONS(4162),
    [anon_sym_is] = ACTIONS(4162),
    [anon_sym_DASH_GT] = ACTIONS(4193),
    [anon_sym_with] = ACTIONS(4162),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2913] = {
    [sym_preproc_region] = STATE(2913),
    [sym_preproc_endregion] = STATE(2913),
    [sym_preproc_line] = STATE(2913),
    [sym_preproc_pragma] = STATE(2913),
    [sym_preproc_nullable] = STATE(2913),
    [sym_preproc_error] = STATE(2913),
    [sym_preproc_warning] = STATE(2913),
    [sym_preproc_define] = STATE(2913),
    [sym_preproc_undef] = STATE(2913),
    [sym__identifier_token] = ACTIONS(4502),
    [anon_sym_alias] = ACTIONS(4502),
    [anon_sym_SEMI] = ACTIONS(4504),
    [anon_sym_global] = ACTIONS(4502),
    [anon_sym_LBRACK] = ACTIONS(4504),
    [anon_sym_COLON] = ACTIONS(4504),
    [anon_sym_COMMA] = ACTIONS(4504),
    [anon_sym_RBRACK] = ACTIONS(4504),
    [anon_sym_LPAREN] = ACTIONS(4504),
    [anon_sym_RPAREN] = ACTIONS(4504),
    [anon_sym_LBRACE] = ACTIONS(4504),
    [anon_sym_RBRACE] = ACTIONS(4504),
    [anon_sym_file] = ACTIONS(4502),
    [anon_sym_LT] = ACTIONS(4502),
    [anon_sym_GT] = ACTIONS(4502),
    [anon_sym_in] = ACTIONS(4502),
    [anon_sym_where] = ACTIONS(4502),
    [anon_sym_QMARK] = ACTIONS(4502),
    [anon_sym_notnull] = ACTIONS(4502),
    [anon_sym_unmanaged] = ACTIONS(4502),
    [anon_sym_operator] = ACTIONS(4502),
    [anon_sym_BANG] = ACTIONS(4502),
    [anon_sym_PLUS_PLUS] = ACTIONS(4504),
    [anon_sym_DASH_DASH] = ACTIONS(4504),
    [anon_sym_PLUS] = ACTIONS(4502),
    [anon_sym_DASH] = ACTIONS(4502),
    [anon_sym_STAR] = ACTIONS(4504),
    [anon_sym_SLASH] = ACTIONS(4502),
    [anon_sym_PERCENT] = ACTIONS(4504),
    [anon_sym_CARET] = ACTIONS(4504),
    [anon_sym_PIPE] = ACTIONS(4502),
    [anon_sym_AMP] = ACTIONS(4502),
    [anon_sym_LT_LT] = ACTIONS(4504),
    [anon_sym_GT_GT] = ACTIONS(4502),
    [anon_sym_GT_GT_GT] = ACTIONS(4504),
    [anon_sym_EQ_EQ] = ACTIONS(4504),
    [anon_sym_BANG_EQ] = ACTIONS(4504),
    [anon_sym_GT_EQ] = ACTIONS(4504),
    [anon_sym_LT_EQ] = ACTIONS(4504),
    [anon_sym_this] = ACTIONS(4502),
    [anon_sym_DOT] = ACTIONS(4502),
    [anon_sym_scoped] = ACTIONS(4502),
    [anon_sym_EQ_GT] = ACTIONS(4504),
    [anon_sym_var] = ACTIONS(4502),
    [anon_sym_yield] = ACTIONS(4502),
    [anon_sym_switch] = ACTIONS(4502),
    [anon_sym_when] = ACTIONS(4502),
    [sym_discard] = ACTIONS(4502),
    [anon_sym_DOT_DOT] = ACTIONS(4504),
    [anon_sym_and] = ACTIONS(4502),
    [anon_sym_or] = ACTIONS(4502),
    [anon_sym_AMP_AMP] = ACTIONS(4504),
    [anon_sym_PIPE_PIPE] = ACTIONS(4504),
    [anon_sym_QMARK_QMARK] = ACTIONS(4504),
    [anon_sym_from] = ACTIONS(4502),
    [anon_sym_into] = ACTIONS(4502),
    [anon_sym_join] = ACTIONS(4502),
    [anon_sym_on] = ACTIONS(4502),
    [anon_sym_equals] = ACTIONS(4502),
    [anon_sym_let] = ACTIONS(4502),
    [anon_sym_orderby] = ACTIONS(4502),
    [anon_sym_ascending] = ACTIONS(4502),
    [anon_sym_descending] = ACTIONS(4502),
    [anon_sym_group] = ACTIONS(4502),
    [anon_sym_by] = ACTIONS(4502),
    [anon_sym_select] = ACTIONS(4502),
    [anon_sym_as] = ACTIONS(4502),
    [anon_sym_is] = ACTIONS(4502),
    [anon_sym_DASH_GT] = ACTIONS(4504),
    [anon_sym_with] = ACTIONS(4502),
    [aux_sym_preproc_if_token3] = ACTIONS(4504),
    [aux_sym_preproc_else_token1] = ACTIONS(4504),
    [aux_sym_preproc_elif_token1] = ACTIONS(4504),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2914] = {
    [sym__variable_designation] = STATE(4190),
    [sym_parenthesized_variable_designation] = STATE(4153),
    [sym_identifier] = STATE(4156),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(2914),
    [sym_preproc_endregion] = STATE(2914),
    [sym_preproc_line] = STATE(2914),
    [sym_preproc_pragma] = STATE(2914),
    [sym_preproc_nullable] = STATE(2914),
    [sym_preproc_error] = STATE(2914),
    [sym_preproc_warning] = STATE(2914),
    [sym_preproc_define] = STATE(2914),
    [sym_preproc_undef] = STATE(2914),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_SEMI] = ACTIONS(4441),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4441),
    [anon_sym_COLON] = ACTIONS(4441),
    [anon_sym_COMMA] = ACTIONS(4441),
    [anon_sym_RBRACK] = ACTIONS(4441),
    [anon_sym_LPAREN] = ACTIONS(4441),
    [anon_sym_RPAREN] = ACTIONS(4441),
    [anon_sym_RBRACE] = ACTIONS(4441),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4443),
    [anon_sym_GT] = ACTIONS(4443),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4443),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4443),
    [anon_sym_PLUS_PLUS] = ACTIONS(4441),
    [anon_sym_DASH_DASH] = ACTIONS(4441),
    [anon_sym_PLUS] = ACTIONS(4443),
    [anon_sym_DASH] = ACTIONS(4443),
    [anon_sym_STAR] = ACTIONS(4441),
    [anon_sym_SLASH] = ACTIONS(4443),
    [anon_sym_PERCENT] = ACTIONS(4441),
    [anon_sym_CARET] = ACTIONS(4441),
    [anon_sym_PIPE] = ACTIONS(4443),
    [anon_sym_AMP] = ACTIONS(4443),
    [anon_sym_LT_LT] = ACTIONS(4441),
    [anon_sym_GT_GT] = ACTIONS(4443),
    [anon_sym_GT_GT_GT] = ACTIONS(4441),
    [anon_sym_EQ_EQ] = ACTIONS(4441),
    [anon_sym_BANG_EQ] = ACTIONS(4441),
    [anon_sym_GT_EQ] = ACTIONS(4441),
    [anon_sym_LT_EQ] = ACTIONS(4441),
    [anon_sym_DOT] = ACTIONS(4443),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_EQ_GT] = ACTIONS(4441),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4443),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4359),
    [anon_sym_DOT_DOT] = ACTIONS(4441),
    [anon_sym_and] = ACTIONS(4443),
    [anon_sym_or] = ACTIONS(4443),
    [anon_sym_AMP_AMP] = ACTIONS(4441),
    [anon_sym_PIPE_PIPE] = ACTIONS(4441),
    [anon_sym_QMARK_QMARK] = ACTIONS(4441),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4339),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4443),
    [anon_sym_is] = ACTIONS(4443),
    [anon_sym_DASH_GT] = ACTIONS(4441),
    [anon_sym_with] = ACTIONS(4443),
    [aux_sym_preproc_if_token3] = ACTIONS(4441),
    [aux_sym_preproc_else_token1] = ACTIONS(4441),
    [aux_sym_preproc_elif_token1] = ACTIONS(4441),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2915] = {
    [sym_preproc_region] = STATE(2915),
    [sym_preproc_endregion] = STATE(2915),
    [sym_preproc_line] = STATE(2915),
    [sym_preproc_pragma] = STATE(2915),
    [sym_preproc_nullable] = STATE(2915),
    [sym_preproc_error] = STATE(2915),
    [sym_preproc_warning] = STATE(2915),
    [sym_preproc_define] = STATE(2915),
    [sym_preproc_undef] = STATE(2915),
    [sym__identifier_token] = ACTIONS(4157),
    [anon_sym_alias] = ACTIONS(4157),
    [anon_sym_global] = ACTIONS(4157),
    [anon_sym_EQ] = ACTIONS(4162),
    [anon_sym_LBRACK] = ACTIONS(4164),
    [anon_sym_LPAREN] = ACTIONS(4164),
    [anon_sym_LBRACE] = ACTIONS(4168),
    [anon_sym_file] = ACTIONS(4157),
    [anon_sym_LT] = ACTIONS(4170),
    [anon_sym_GT] = ACTIONS(4170),
    [anon_sym_where] = ACTIONS(4157),
    [anon_sym_QMARK] = ACTIONS(4170),
    [anon_sym_notnull] = ACTIONS(4157),
    [anon_sym_unmanaged] = ACTIONS(4157),
    [anon_sym_BANG] = ACTIONS(4170),
    [anon_sym_PLUS_PLUS] = ACTIONS(4164),
    [anon_sym_DASH_DASH] = ACTIONS(4164),
    [anon_sym_PLUS] = ACTIONS(4170),
    [anon_sym_DASH] = ACTIONS(4170),
    [anon_sym_STAR] = ACTIONS(4170),
    [anon_sym_SLASH] = ACTIONS(4170),
    [anon_sym_PERCENT] = ACTIONS(4170),
    [anon_sym_CARET] = ACTIONS(4170),
    [anon_sym_PIPE] = ACTIONS(4170),
    [anon_sym_AMP] = ACTIONS(4170),
    [anon_sym_LT_LT] = ACTIONS(4170),
    [anon_sym_GT_GT] = ACTIONS(4170),
    [anon_sym_GT_GT_GT] = ACTIONS(4170),
    [anon_sym_EQ_EQ] = ACTIONS(4164),
    [anon_sym_BANG_EQ] = ACTIONS(4164),
    [anon_sym_GT_EQ] = ACTIONS(4164),
    [anon_sym_LT_EQ] = ACTIONS(4164),
    [anon_sym_DOT] = ACTIONS(4170),
    [anon_sym_scoped] = ACTIONS(4157),
    [anon_sym_var] = ACTIONS(4157),
    [anon_sym_yield] = ACTIONS(4157),
    [anon_sym_switch] = ACTIONS(4170),
    [anon_sym_when] = ACTIONS(4157),
    [sym_discard] = ACTIONS(4157),
    [anon_sym_DOT_DOT] = ACTIONS(4164),
    [anon_sym_and] = ACTIONS(4174),
    [anon_sym_or] = ACTIONS(4174),
    [anon_sym_PLUS_EQ] = ACTIONS(4177),
    [anon_sym_DASH_EQ] = ACTIONS(4177),
    [anon_sym_STAR_EQ] = ACTIONS(4177),
    [anon_sym_SLASH_EQ] = ACTIONS(4177),
    [anon_sym_PERCENT_EQ] = ACTIONS(4177),
    [anon_sym_AMP_EQ] = ACTIONS(4177),
    [anon_sym_CARET_EQ] = ACTIONS(4177),
    [anon_sym_PIPE_EQ] = ACTIONS(4177),
    [anon_sym_LT_LT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4177),
    [anon_sym_AMP_AMP] = ACTIONS(4164),
    [anon_sym_PIPE_PIPE] = ACTIONS(4164),
    [anon_sym_QMARK_QMARK] = ACTIONS(4170),
    [anon_sym_from] = ACTIONS(4157),
    [anon_sym_into] = ACTIONS(4157),
    [anon_sym_join] = ACTIONS(4157),
    [anon_sym_on] = ACTIONS(4157),
    [anon_sym_equals] = ACTIONS(4157),
    [anon_sym_let] = ACTIONS(4157),
    [anon_sym_orderby] = ACTIONS(4157),
    [anon_sym_ascending] = ACTIONS(4157),
    [anon_sym_descending] = ACTIONS(4157),
    [anon_sym_group] = ACTIONS(4157),
    [anon_sym_by] = ACTIONS(4174),
    [anon_sym_select] = ACTIONS(4157),
    [anon_sym_as] = ACTIONS(4170),
    [anon_sym_is] = ACTIONS(4170),
    [anon_sym_DASH_GT] = ACTIONS(4164),
    [anon_sym_with] = ACTIONS(4170),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2916] = {
    [sym_preproc_region] = STATE(2916),
    [sym_preproc_endregion] = STATE(2916),
    [sym_preproc_line] = STATE(2916),
    [sym_preproc_pragma] = STATE(2916),
    [sym_preproc_nullable] = STATE(2916),
    [sym_preproc_error] = STATE(2916),
    [sym_preproc_warning] = STATE(2916),
    [sym_preproc_define] = STATE(2916),
    [sym_preproc_undef] = STATE(2916),
    [sym__identifier_token] = ACTIONS(4179),
    [anon_sym_alias] = ACTIONS(4179),
    [anon_sym_global] = ACTIONS(4179),
    [anon_sym_EQ] = ACTIONS(4183),
    [anon_sym_LBRACK] = ACTIONS(4185),
    [anon_sym_LPAREN] = ACTIONS(4185),
    [anon_sym_LBRACE] = ACTIONS(4181),
    [anon_sym_file] = ACTIONS(4179),
    [anon_sym_LT] = ACTIONS(4188),
    [anon_sym_GT] = ACTIONS(4188),
    [anon_sym_where] = ACTIONS(4188),
    [anon_sym_QMARK] = ACTIONS(4188),
    [anon_sym_notnull] = ACTIONS(4179),
    [anon_sym_unmanaged] = ACTIONS(4179),
    [anon_sym_BANG] = ACTIONS(4188),
    [anon_sym_PLUS_PLUS] = ACTIONS(4185),
    [anon_sym_DASH_DASH] = ACTIONS(4185),
    [anon_sym_PLUS] = ACTIONS(4188),
    [anon_sym_DASH] = ACTIONS(4188),
    [anon_sym_STAR] = ACTIONS(4188),
    [anon_sym_SLASH] = ACTIONS(4188),
    [anon_sym_PERCENT] = ACTIONS(4188),
    [anon_sym_CARET] = ACTIONS(4188),
    [anon_sym_PIPE] = ACTIONS(4188),
    [anon_sym_AMP] = ACTIONS(4188),
    [anon_sym_LT_LT] = ACTIONS(4188),
    [anon_sym_GT_GT] = ACTIONS(4188),
    [anon_sym_GT_GT_GT] = ACTIONS(4188),
    [anon_sym_EQ_EQ] = ACTIONS(4185),
    [anon_sym_BANG_EQ] = ACTIONS(4185),
    [anon_sym_GT_EQ] = ACTIONS(4185),
    [anon_sym_LT_EQ] = ACTIONS(4185),
    [anon_sym_DOT] = ACTIONS(4188),
    [anon_sym_scoped] = ACTIONS(4179),
    [anon_sym_var] = ACTIONS(4179),
    [anon_sym_yield] = ACTIONS(4179),
    [anon_sym_switch] = ACTIONS(4188),
    [anon_sym_when] = ACTIONS(4179),
    [sym_discard] = ACTIONS(4179),
    [anon_sym_DOT_DOT] = ACTIONS(4185),
    [anon_sym_and] = ACTIONS(4188),
    [anon_sym_or] = ACTIONS(4188),
    [anon_sym_PLUS_EQ] = ACTIONS(4191),
    [anon_sym_DASH_EQ] = ACTIONS(4191),
    [anon_sym_STAR_EQ] = ACTIONS(4191),
    [anon_sym_SLASH_EQ] = ACTIONS(4191),
    [anon_sym_PERCENT_EQ] = ACTIONS(4191),
    [anon_sym_AMP_EQ] = ACTIONS(4191),
    [anon_sym_CARET_EQ] = ACTIONS(4191),
    [anon_sym_PIPE_EQ] = ACTIONS(4191),
    [anon_sym_LT_LT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4191),
    [anon_sym_AMP_AMP] = ACTIONS(4185),
    [anon_sym_PIPE_PIPE] = ACTIONS(4185),
    [anon_sym_QMARK_QMARK] = ACTIONS(4188),
    [anon_sym_from] = ACTIONS(4188),
    [anon_sym_into] = ACTIONS(4179),
    [anon_sym_join] = ACTIONS(4188),
    [anon_sym_on] = ACTIONS(4179),
    [anon_sym_equals] = ACTIONS(4179),
    [anon_sym_let] = ACTIONS(4188),
    [anon_sym_orderby] = ACTIONS(4188),
    [anon_sym_ascending] = ACTIONS(4179),
    [anon_sym_descending] = ACTIONS(4179),
    [anon_sym_group] = ACTIONS(4188),
    [anon_sym_by] = ACTIONS(4179),
    [anon_sym_select] = ACTIONS(4188),
    [anon_sym_as] = ACTIONS(4188),
    [anon_sym_is] = ACTIONS(4188),
    [anon_sym_DASH_GT] = ACTIONS(4185),
    [anon_sym_with] = ACTIONS(4188),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2917] = {
    [sym_preproc_region] = STATE(2917),
    [sym_preproc_endregion] = STATE(2917),
    [sym_preproc_line] = STATE(2917),
    [sym_preproc_pragma] = STATE(2917),
    [sym_preproc_nullable] = STATE(2917),
    [sym_preproc_error] = STATE(2917),
    [sym_preproc_warning] = STATE(2917),
    [sym_preproc_define] = STATE(2917),
    [sym_preproc_undef] = STATE(2917),
    [sym__identifier_token] = ACTIONS(4157),
    [anon_sym_alias] = ACTIONS(4157),
    [anon_sym_global] = ACTIONS(4157),
    [anon_sym_EQ] = ACTIONS(4162),
    [anon_sym_LBRACK] = ACTIONS(4164),
    [anon_sym_LPAREN] = ACTIONS(4164),
    [anon_sym_LBRACE] = ACTIONS(4168),
    [anon_sym_file] = ACTIONS(4157),
    [anon_sym_LT] = ACTIONS(4170),
    [anon_sym_GT] = ACTIONS(4170),
    [anon_sym_where] = ACTIONS(4174),
    [anon_sym_QMARK] = ACTIONS(4170),
    [anon_sym_notnull] = ACTIONS(4157),
    [anon_sym_unmanaged] = ACTIONS(4157),
    [anon_sym_BANG] = ACTIONS(4170),
    [anon_sym_PLUS_PLUS] = ACTIONS(4164),
    [anon_sym_DASH_DASH] = ACTIONS(4164),
    [anon_sym_PLUS] = ACTIONS(4170),
    [anon_sym_DASH] = ACTIONS(4170),
    [anon_sym_STAR] = ACTIONS(4170),
    [anon_sym_SLASH] = ACTIONS(4170),
    [anon_sym_PERCENT] = ACTIONS(4170),
    [anon_sym_CARET] = ACTIONS(4170),
    [anon_sym_PIPE] = ACTIONS(4170),
    [anon_sym_AMP] = ACTIONS(4170),
    [anon_sym_LT_LT] = ACTIONS(4170),
    [anon_sym_GT_GT] = ACTIONS(4170),
    [anon_sym_GT_GT_GT] = ACTIONS(4170),
    [anon_sym_EQ_EQ] = ACTIONS(4164),
    [anon_sym_BANG_EQ] = ACTIONS(4164),
    [anon_sym_GT_EQ] = ACTIONS(4164),
    [anon_sym_LT_EQ] = ACTIONS(4164),
    [anon_sym_DOT] = ACTIONS(4170),
    [anon_sym_scoped] = ACTIONS(4157),
    [anon_sym_var] = ACTIONS(4157),
    [anon_sym_yield] = ACTIONS(4157),
    [anon_sym_switch] = ACTIONS(4170),
    [anon_sym_when] = ACTIONS(4157),
    [sym_discard] = ACTIONS(4157),
    [anon_sym_DOT_DOT] = ACTIONS(4164),
    [anon_sym_and] = ACTIONS(4174),
    [anon_sym_or] = ACTIONS(4174),
    [anon_sym_PLUS_EQ] = ACTIONS(4177),
    [anon_sym_DASH_EQ] = ACTIONS(4177),
    [anon_sym_STAR_EQ] = ACTIONS(4177),
    [anon_sym_SLASH_EQ] = ACTIONS(4177),
    [anon_sym_PERCENT_EQ] = ACTIONS(4177),
    [anon_sym_AMP_EQ] = ACTIONS(4177),
    [anon_sym_CARET_EQ] = ACTIONS(4177),
    [anon_sym_PIPE_EQ] = ACTIONS(4177),
    [anon_sym_LT_LT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4177),
    [anon_sym_AMP_AMP] = ACTIONS(4164),
    [anon_sym_PIPE_PIPE] = ACTIONS(4164),
    [anon_sym_QMARK_QMARK] = ACTIONS(4170),
    [anon_sym_from] = ACTIONS(4174),
    [anon_sym_into] = ACTIONS(4174),
    [anon_sym_join] = ACTIONS(4174),
    [anon_sym_on] = ACTIONS(4157),
    [anon_sym_equals] = ACTIONS(4157),
    [anon_sym_let] = ACTIONS(4174),
    [anon_sym_orderby] = ACTIONS(4174),
    [anon_sym_ascending] = ACTIONS(4157),
    [anon_sym_descending] = ACTIONS(4157),
    [anon_sym_group] = ACTIONS(4174),
    [anon_sym_by] = ACTIONS(4157),
    [anon_sym_select] = ACTIONS(4174),
    [anon_sym_as] = ACTIONS(4170),
    [anon_sym_is] = ACTIONS(4170),
    [anon_sym_DASH_GT] = ACTIONS(4164),
    [anon_sym_with] = ACTIONS(4170),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2918] = {
    [sym_preproc_region] = STATE(2918),
    [sym_preproc_endregion] = STATE(2918),
    [sym_preproc_line] = STATE(2918),
    [sym_preproc_pragma] = STATE(2918),
    [sym_preproc_nullable] = STATE(2918),
    [sym_preproc_error] = STATE(2918),
    [sym_preproc_warning] = STATE(2918),
    [sym_preproc_define] = STATE(2918),
    [sym_preproc_undef] = STATE(2918),
    [sym__identifier_token] = ACTIONS(4157),
    [anon_sym_alias] = ACTIONS(4157),
    [anon_sym_global] = ACTIONS(4157),
    [anon_sym_EQ] = ACTIONS(4162),
    [anon_sym_LBRACK] = ACTIONS(4164),
    [anon_sym_LPAREN] = ACTIONS(4164),
    [anon_sym_LBRACE] = ACTIONS(4168),
    [anon_sym_file] = ACTIONS(4157),
    [anon_sym_LT] = ACTIONS(4170),
    [anon_sym_GT] = ACTIONS(4170),
    [anon_sym_where] = ACTIONS(4157),
    [anon_sym_QMARK] = ACTIONS(4170),
    [anon_sym_notnull] = ACTIONS(4157),
    [anon_sym_unmanaged] = ACTIONS(4157),
    [anon_sym_BANG] = ACTIONS(4170),
    [anon_sym_PLUS_PLUS] = ACTIONS(4164),
    [anon_sym_DASH_DASH] = ACTIONS(4164),
    [anon_sym_PLUS] = ACTIONS(4170),
    [anon_sym_DASH] = ACTIONS(4170),
    [anon_sym_STAR] = ACTIONS(4170),
    [anon_sym_SLASH] = ACTIONS(4170),
    [anon_sym_PERCENT] = ACTIONS(4170),
    [anon_sym_CARET] = ACTIONS(4170),
    [anon_sym_PIPE] = ACTIONS(4170),
    [anon_sym_AMP] = ACTIONS(4170),
    [anon_sym_LT_LT] = ACTIONS(4170),
    [anon_sym_GT_GT] = ACTIONS(4170),
    [anon_sym_GT_GT_GT] = ACTIONS(4170),
    [anon_sym_EQ_EQ] = ACTIONS(4164),
    [anon_sym_BANG_EQ] = ACTIONS(4164),
    [anon_sym_GT_EQ] = ACTIONS(4164),
    [anon_sym_LT_EQ] = ACTIONS(4164),
    [anon_sym_DOT] = ACTIONS(4170),
    [anon_sym_scoped] = ACTIONS(4157),
    [anon_sym_var] = ACTIONS(4157),
    [anon_sym_yield] = ACTIONS(4157),
    [anon_sym_switch] = ACTIONS(4170),
    [anon_sym_when] = ACTIONS(4157),
    [sym_discard] = ACTIONS(4157),
    [anon_sym_DOT_DOT] = ACTIONS(4164),
    [anon_sym_and] = ACTIONS(4174),
    [anon_sym_or] = ACTIONS(4174),
    [anon_sym_PLUS_EQ] = ACTIONS(4177),
    [anon_sym_DASH_EQ] = ACTIONS(4177),
    [anon_sym_STAR_EQ] = ACTIONS(4177),
    [anon_sym_SLASH_EQ] = ACTIONS(4177),
    [anon_sym_PERCENT_EQ] = ACTIONS(4177),
    [anon_sym_AMP_EQ] = ACTIONS(4177),
    [anon_sym_CARET_EQ] = ACTIONS(4177),
    [anon_sym_PIPE_EQ] = ACTIONS(4177),
    [anon_sym_LT_LT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4177),
    [anon_sym_AMP_AMP] = ACTIONS(4164),
    [anon_sym_PIPE_PIPE] = ACTIONS(4164),
    [anon_sym_QMARK_QMARK] = ACTIONS(4170),
    [anon_sym_from] = ACTIONS(4157),
    [anon_sym_into] = ACTIONS(4174),
    [anon_sym_join] = ACTIONS(4157),
    [anon_sym_on] = ACTIONS(4157),
    [anon_sym_equals] = ACTIONS(4157),
    [anon_sym_let] = ACTIONS(4157),
    [anon_sym_orderby] = ACTIONS(4157),
    [anon_sym_ascending] = ACTIONS(4157),
    [anon_sym_descending] = ACTIONS(4157),
    [anon_sym_group] = ACTIONS(4157),
    [anon_sym_by] = ACTIONS(4174),
    [anon_sym_select] = ACTIONS(4157),
    [anon_sym_as] = ACTIONS(4170),
    [anon_sym_is] = ACTIONS(4170),
    [anon_sym_DASH_GT] = ACTIONS(4164),
    [anon_sym_with] = ACTIONS(4170),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2919] = {
    [sym_argument_list] = STATE(3594),
    [sym__name] = STATE(3744),
    [sym_alias_qualified_name] = STATE(3680),
    [sym__simple_name] = STATE(3680),
    [sym_qualified_name] = STATE(3680),
    [sym_generic_name] = STATE(3648),
    [sym_type] = STATE(4138),
    [sym_implicit_type] = STATE(3707),
    [sym_array_type] = STATE(3586),
    [sym__array_base_type] = STATE(8829),
    [sym_nullable_type] = STATE(3681),
    [sym_pointer_type] = STATE(3681),
    [sym__pointer_base_type] = STATE(9538),
    [sym_function_pointer_type] = STATE(3681),
    [sym_ref_type] = STATE(3707),
    [sym_scoped_type] = STATE(3707),
    [sym_tuple_type] = STATE(3631),
    [sym_identifier] = STATE(3590),
    [sym__reserved_identifier] = STATE(3625),
    [sym_preproc_region] = STATE(2919),
    [sym_preproc_endregion] = STATE(2919),
    [sym_preproc_line] = STATE(2919),
    [sym_preproc_pragma] = STATE(2919),
    [sym_preproc_nullable] = STATE(2919),
    [sym_preproc_error] = STATE(2919),
    [sym_preproc_warning] = STATE(2919),
    [sym_preproc_define] = STATE(2919),
    [sym_preproc_undef] = STATE(2919),
    [sym__identifier_token] = ACTIONS(4349),
    [anon_sym_extern] = ACTIONS(4042),
    [anon_sym_alias] = ACTIONS(4351),
    [anon_sym_global] = ACTIONS(4351),
    [anon_sym_unsafe] = ACTIONS(4042),
    [anon_sym_static] = ACTIONS(4042),
    [anon_sym_LBRACK] = ACTIONS(4506),
    [anon_sym_LPAREN] = ACTIONS(4508),
    [anon_sym_class] = ACTIONS(4042),
    [anon_sym_ref] = ACTIONS(4353),
    [anon_sym_struct] = ACTIONS(4042),
    [anon_sym_enum] = ACTIONS(4042),
    [anon_sym_LBRACE] = ACTIONS(4510),
    [anon_sym_interface] = ACTIONS(4042),
    [anon_sym_delegate] = ACTIONS(4512),
    [anon_sym_record] = ACTIONS(4042),
    [anon_sym_abstract] = ACTIONS(4042),
    [anon_sym_async] = ACTIONS(4042),
    [anon_sym_const] = ACTIONS(4042),
    [anon_sym_file] = ACTIONS(4351),
    [anon_sym_fixed] = ACTIONS(4042),
    [anon_sym_internal] = ACTIONS(4042),
    [anon_sym_new] = ACTIONS(4042),
    [anon_sym_override] = ACTIONS(4042),
    [anon_sym_partial] = ACTIONS(4042),
    [anon_sym_private] = ACTIONS(4042),
    [anon_sym_protected] = ACTIONS(4042),
    [anon_sym_public] = ACTIONS(4042),
    [anon_sym_readonly] = ACTIONS(4042),
    [anon_sym_required] = ACTIONS(4042),
    [anon_sym_sealed] = ACTIONS(4042),
    [anon_sym_virtual] = ACTIONS(4042),
    [anon_sym_volatile] = ACTIONS(4042),
    [anon_sym_where] = ACTIONS(4351),
    [anon_sym_notnull] = ACTIONS(4351),
    [anon_sym_unmanaged] = ACTIONS(4351),
    [anon_sym_scoped] = ACTIONS(4514),
    [anon_sym_var] = ACTIONS(4516),
    [sym_predefined_type] = ACTIONS(4518),
    [anon_sym_yield] = ACTIONS(4351),
    [anon_sym_when] = ACTIONS(4351),
    [anon_sym_from] = ACTIONS(4351),
    [anon_sym_into] = ACTIONS(4351),
    [anon_sym_join] = ACTIONS(4351),
    [anon_sym_on] = ACTIONS(4351),
    [anon_sym_equals] = ACTIONS(4351),
    [anon_sym_let] = ACTIONS(4351),
    [anon_sym_orderby] = ACTIONS(4351),
    [anon_sym_ascending] = ACTIONS(4351),
    [anon_sym_descending] = ACTIONS(4351),
    [anon_sym_group] = ACTIONS(4351),
    [anon_sym_by] = ACTIONS(4351),
    [anon_sym_select] = ACTIONS(4351),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2920] = {
    [sym_type_argument_list] = STATE(2945),
    [sym_preproc_region] = STATE(2920),
    [sym_preproc_endregion] = STATE(2920),
    [sym_preproc_line] = STATE(2920),
    [sym_preproc_pragma] = STATE(2920),
    [sym_preproc_nullable] = STATE(2920),
    [sym_preproc_error] = STATE(2920),
    [sym_preproc_warning] = STATE(2920),
    [sym_preproc_define] = STATE(2920),
    [sym_preproc_undef] = STATE(2920),
    [sym__identifier_token] = ACTIONS(4138),
    [anon_sym_alias] = ACTIONS(4138),
    [anon_sym_SEMI] = ACTIONS(4140),
    [anon_sym_global] = ACTIONS(4138),
    [anon_sym_LBRACK] = ACTIONS(4140),
    [anon_sym_COMMA] = ACTIONS(4140),
    [anon_sym_RBRACK] = ACTIONS(4140),
    [anon_sym_LPAREN] = ACTIONS(4140),
    [anon_sym_RPAREN] = ACTIONS(4140),
    [anon_sym_LBRACE] = ACTIONS(4140),
    [anon_sym_RBRACE] = ACTIONS(4140),
    [anon_sym_file] = ACTIONS(4138),
    [anon_sym_LT] = ACTIONS(4520),
    [anon_sym_GT] = ACTIONS(4138),
    [anon_sym_in] = ACTIONS(4138),
    [anon_sym_where] = ACTIONS(4138),
    [anon_sym_QMARK] = ACTIONS(4138),
    [anon_sym_notnull] = ACTIONS(4138),
    [anon_sym_unmanaged] = ACTIONS(4138),
    [anon_sym_BANG] = ACTIONS(4138),
    [anon_sym_PLUS_PLUS] = ACTIONS(4140),
    [anon_sym_DASH_DASH] = ACTIONS(4140),
    [anon_sym_PLUS] = ACTIONS(4138),
    [anon_sym_DASH] = ACTIONS(4138),
    [anon_sym_STAR] = ACTIONS(4140),
    [anon_sym_SLASH] = ACTIONS(4138),
    [anon_sym_PERCENT] = ACTIONS(4140),
    [anon_sym_CARET] = ACTIONS(4140),
    [anon_sym_PIPE] = ACTIONS(4138),
    [anon_sym_AMP] = ACTIONS(4138),
    [anon_sym_LT_LT] = ACTIONS(4140),
    [anon_sym_GT_GT] = ACTIONS(4138),
    [anon_sym_GT_GT_GT] = ACTIONS(4140),
    [anon_sym_EQ_EQ] = ACTIONS(4140),
    [anon_sym_BANG_EQ] = ACTIONS(4140),
    [anon_sym_GT_EQ] = ACTIONS(4140),
    [anon_sym_LT_EQ] = ACTIONS(4140),
    [anon_sym_DOT] = ACTIONS(4138),
    [anon_sym_scoped] = ACTIONS(4138),
    [anon_sym_EQ_GT] = ACTIONS(4140),
    [anon_sym_COLON_COLON] = ACTIONS(4155),
    [anon_sym_var] = ACTIONS(4138),
    [anon_sym_yield] = ACTIONS(4138),
    [anon_sym_switch] = ACTIONS(4138),
    [anon_sym_when] = ACTIONS(4138),
    [sym_discard] = ACTIONS(4138),
    [anon_sym_DOT_DOT] = ACTIONS(4140),
    [anon_sym_and] = ACTIONS(4138),
    [anon_sym_or] = ACTIONS(4138),
    [anon_sym_AMP_AMP] = ACTIONS(4140),
    [anon_sym_PIPE_PIPE] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK] = ACTIONS(4140),
    [anon_sym_from] = ACTIONS(4138),
    [anon_sym_into] = ACTIONS(4138),
    [anon_sym_join] = ACTIONS(4138),
    [anon_sym_on] = ACTIONS(4138),
    [anon_sym_equals] = ACTIONS(4138),
    [anon_sym_let] = ACTIONS(4138),
    [anon_sym_orderby] = ACTIONS(4138),
    [anon_sym_ascending] = ACTIONS(4138),
    [anon_sym_descending] = ACTIONS(4138),
    [anon_sym_group] = ACTIONS(4138),
    [anon_sym_by] = ACTIONS(4138),
    [anon_sym_select] = ACTIONS(4138),
    [anon_sym_as] = ACTIONS(4138),
    [anon_sym_is] = ACTIONS(4138),
    [anon_sym_DASH_GT] = ACTIONS(4140),
    [anon_sym_with] = ACTIONS(4138),
    [aux_sym_preproc_if_token3] = ACTIONS(4140),
    [aux_sym_preproc_else_token1] = ACTIONS(4140),
    [aux_sym_preproc_elif_token1] = ACTIONS(4140),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2921] = {
    [sym_modifier] = STATE(3807),
    [sym_variable_declaration] = STATE(9117),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7136),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(2921),
    [sym_preproc_endregion] = STATE(2921),
    [sym_preproc_line] = STATE(2921),
    [sym_preproc_pragma] = STATE(2921),
    [sym_preproc_nullable] = STATE(2921),
    [sym_preproc_error] = STATE(2921),
    [sym_preproc_warning] = STATE(2921),
    [sym_preproc_define] = STATE(2921),
    [sym_preproc_undef] = STATE(2921),
    [aux_sym_class_declaration_repeat2] = STATE(3733),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_extern] = ACTIONS(65),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_unsafe] = ACTIONS(65),
    [anon_sym_static] = ACTIONS(65),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_class] = ACTIONS(4369),
    [anon_sym_ref] = ACTIONS(4371),
    [anon_sym_struct] = ACTIONS(2821),
    [anon_sym_enum] = ACTIONS(4373),
    [anon_sym_interface] = ACTIONS(4375),
    [anon_sym_delegate] = ACTIONS(4377),
    [anon_sym_record] = ACTIONS(4379),
    [anon_sym_abstract] = ACTIONS(65),
    [anon_sym_async] = ACTIONS(65),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_file] = ACTIONS(3225),
    [anon_sym_fixed] = ACTIONS(65),
    [anon_sym_internal] = ACTIONS(65),
    [anon_sym_new] = ACTIONS(65),
    [anon_sym_override] = ACTIONS(65),
    [anon_sym_partial] = ACTIONS(65),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_public] = ACTIONS(65),
    [anon_sym_readonly] = ACTIONS(65),
    [anon_sym_required] = ACTIONS(65),
    [anon_sym_sealed] = ACTIONS(65),
    [anon_sym_virtual] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2922] = {
    [sym__name] = STATE(4159),
    [sym_alias_qualified_name] = STATE(4085),
    [sym__simple_name] = STATE(4085),
    [sym_qualified_name] = STATE(4085),
    [sym_generic_name] = STATE(3959),
    [sym_ref_type] = STATE(3971),
    [sym__scoped_base_type] = STATE(3973),
    [sym_identifier] = STATE(3889),
    [sym__reserved_identifier] = STATE(3911),
    [sym_preproc_region] = STATE(2922),
    [sym_preproc_endregion] = STATE(2922),
    [sym_preproc_line] = STATE(2922),
    [sym_preproc_pragma] = STATE(2922),
    [sym_preproc_nullable] = STATE(2922),
    [sym_preproc_error] = STATE(2922),
    [sym_preproc_warning] = STATE(2922),
    [sym_preproc_define] = STATE(2922),
    [sym_preproc_undef] = STATE(2922),
    [sym__identifier_token] = ACTIONS(4248),
    [anon_sym_alias] = ACTIONS(4250),
    [anon_sym_global] = ACTIONS(4250),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_COLON] = ACTIONS(3995),
    [anon_sym_LPAREN] = ACTIONS(3993),
    [anon_sym_ref] = ACTIONS(4523),
    [anon_sym_LBRACE] = ACTIONS(3993),
    [anon_sym_file] = ACTIONS(4250),
    [anon_sym_LT] = ACTIONS(3995),
    [anon_sym_GT] = ACTIONS(3995),
    [anon_sym_where] = ACTIONS(4250),
    [anon_sym_QMARK] = ACTIONS(3995),
    [anon_sym_notnull] = ACTIONS(4250),
    [anon_sym_unmanaged] = ACTIONS(4250),
    [anon_sym_BANG] = ACTIONS(3995),
    [anon_sym_PLUS_PLUS] = ACTIONS(3993),
    [anon_sym_DASH_DASH] = ACTIONS(3993),
    [anon_sym_PLUS] = ACTIONS(3995),
    [anon_sym_DASH] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3993),
    [anon_sym_SLASH] = ACTIONS(3995),
    [anon_sym_PERCENT] = ACTIONS(3993),
    [anon_sym_CARET] = ACTIONS(3993),
    [anon_sym_PIPE] = ACTIONS(3995),
    [anon_sym_AMP] = ACTIONS(3995),
    [anon_sym_LT_LT] = ACTIONS(3993),
    [anon_sym_GT_GT] = ACTIONS(3995),
    [anon_sym_GT_GT_GT] = ACTIONS(3993),
    [anon_sym_EQ_EQ] = ACTIONS(3993),
    [anon_sym_BANG_EQ] = ACTIONS(3993),
    [anon_sym_GT_EQ] = ACTIONS(3993),
    [anon_sym_LT_EQ] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3995),
    [anon_sym_scoped] = ACTIONS(4250),
    [anon_sym_EQ_GT] = ACTIONS(3993),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(4250),
    [anon_sym_yield] = ACTIONS(4250),
    [anon_sym_switch] = ACTIONS(3995),
    [anon_sym_when] = ACTIONS(4525),
    [anon_sym_DOT_DOT] = ACTIONS(3993),
    [anon_sym_and] = ACTIONS(3995),
    [anon_sym_or] = ACTIONS(3995),
    [anon_sym_AMP_AMP] = ACTIONS(3993),
    [anon_sym_PIPE_PIPE] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK] = ACTIONS(3993),
    [anon_sym_from] = ACTIONS(4250),
    [anon_sym_into] = ACTIONS(4250),
    [anon_sym_join] = ACTIONS(4250),
    [anon_sym_on] = ACTIONS(4250),
    [anon_sym_equals] = ACTIONS(4250),
    [anon_sym_let] = ACTIONS(4250),
    [anon_sym_orderby] = ACTIONS(4250),
    [anon_sym_ascending] = ACTIONS(4250),
    [anon_sym_descending] = ACTIONS(4250),
    [anon_sym_group] = ACTIONS(4250),
    [anon_sym_by] = ACTIONS(4250),
    [anon_sym_select] = ACTIONS(4250),
    [anon_sym_as] = ACTIONS(3995),
    [anon_sym_is] = ACTIONS(3995),
    [anon_sym_DASH_GT] = ACTIONS(3993),
    [anon_sym_with] = ACTIONS(3995),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2923] = {
    [sym_modifier] = STATE(3807),
    [sym_variable_declaration] = STATE(9401),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(6978),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(2923),
    [sym_preproc_endregion] = STATE(2923),
    [sym_preproc_line] = STATE(2923),
    [sym_preproc_pragma] = STATE(2923),
    [sym_preproc_nullable] = STATE(2923),
    [sym_preproc_error] = STATE(2923),
    [sym_preproc_warning] = STATE(2923),
    [sym_preproc_define] = STATE(2923),
    [sym_preproc_undef] = STATE(2923),
    [aux_sym_class_declaration_repeat2] = STATE(3733),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_extern] = ACTIONS(65),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_unsafe] = ACTIONS(65),
    [anon_sym_static] = ACTIONS(65),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_class] = ACTIONS(4381),
    [anon_sym_ref] = ACTIONS(4383),
    [anon_sym_struct] = ACTIONS(2823),
    [anon_sym_enum] = ACTIONS(4385),
    [anon_sym_interface] = ACTIONS(4387),
    [anon_sym_delegate] = ACTIONS(4389),
    [anon_sym_record] = ACTIONS(4391),
    [anon_sym_abstract] = ACTIONS(65),
    [anon_sym_async] = ACTIONS(65),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_file] = ACTIONS(3225),
    [anon_sym_fixed] = ACTIONS(65),
    [anon_sym_internal] = ACTIONS(65),
    [anon_sym_new] = ACTIONS(65),
    [anon_sym_override] = ACTIONS(65),
    [anon_sym_partial] = ACTIONS(65),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_public] = ACTIONS(65),
    [anon_sym_readonly] = ACTIONS(65),
    [anon_sym_required] = ACTIONS(65),
    [anon_sym_sealed] = ACTIONS(65),
    [anon_sym_virtual] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2924] = {
    [sym__name] = STATE(5937),
    [sym_alias_qualified_name] = STATE(3680),
    [sym__simple_name] = STATE(3680),
    [sym_qualified_name] = STATE(3680),
    [sym_generic_name] = STATE(3648),
    [sym_ref_type] = STATE(3643),
    [sym__scoped_base_type] = STATE(3647),
    [sym_identifier] = STATE(5255),
    [sym__reserved_identifier] = STATE(3625),
    [sym_preproc_region] = STATE(2924),
    [sym_preproc_endregion] = STATE(2924),
    [sym_preproc_line] = STATE(2924),
    [sym_preproc_pragma] = STATE(2924),
    [sym_preproc_nullable] = STATE(2924),
    [sym_preproc_error] = STATE(2924),
    [sym_preproc_warning] = STATE(2924),
    [sym_preproc_define] = STATE(2924),
    [sym_preproc_undef] = STATE(2924),
    [sym__identifier_token] = ACTIONS(4349),
    [anon_sym_alias] = ACTIONS(4351),
    [anon_sym_global] = ACTIONS(4351),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_COLON] = ACTIONS(3995),
    [anon_sym_COMMA] = ACTIONS(3993),
    [anon_sym_LPAREN] = ACTIONS(3993),
    [anon_sym_RPAREN] = ACTIONS(3993),
    [anon_sym_ref] = ACTIONS(4528),
    [anon_sym_LBRACE] = ACTIONS(3993),
    [anon_sym_RBRACE] = ACTIONS(3993),
    [anon_sym_file] = ACTIONS(4351),
    [anon_sym_LT] = ACTIONS(3995),
    [anon_sym_GT] = ACTIONS(3995),
    [anon_sym_where] = ACTIONS(4351),
    [anon_sym_QMARK] = ACTIONS(3995),
    [anon_sym_notnull] = ACTIONS(4351),
    [anon_sym_unmanaged] = ACTIONS(4351),
    [anon_sym_BANG] = ACTIONS(3995),
    [anon_sym_PLUS_PLUS] = ACTIONS(3993),
    [anon_sym_DASH_DASH] = ACTIONS(3993),
    [anon_sym_PLUS] = ACTIONS(3995),
    [anon_sym_DASH] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3993),
    [anon_sym_SLASH] = ACTIONS(3995),
    [anon_sym_PERCENT] = ACTIONS(3993),
    [anon_sym_CARET] = ACTIONS(3993),
    [anon_sym_PIPE] = ACTIONS(3995),
    [anon_sym_AMP] = ACTIONS(3995),
    [anon_sym_LT_LT] = ACTIONS(3993),
    [anon_sym_GT_GT] = ACTIONS(3995),
    [anon_sym_GT_GT_GT] = ACTIONS(3993),
    [anon_sym_EQ_EQ] = ACTIONS(3993),
    [anon_sym_BANG_EQ] = ACTIONS(3993),
    [anon_sym_GT_EQ] = ACTIONS(3993),
    [anon_sym_LT_EQ] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3995),
    [anon_sym_scoped] = ACTIONS(4351),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(4351),
    [anon_sym_yield] = ACTIONS(4351),
    [anon_sym_switch] = ACTIONS(3995),
    [anon_sym_when] = ACTIONS(4351),
    [anon_sym_DOT_DOT] = ACTIONS(3993),
    [anon_sym_AMP_AMP] = ACTIONS(3993),
    [anon_sym_PIPE_PIPE] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK] = ACTIONS(3993),
    [anon_sym_from] = ACTIONS(4351),
    [anon_sym_into] = ACTIONS(4351),
    [anon_sym_join] = ACTIONS(4351),
    [anon_sym_on] = ACTIONS(4351),
    [anon_sym_equals] = ACTIONS(4351),
    [anon_sym_let] = ACTIONS(4351),
    [anon_sym_orderby] = ACTIONS(4351),
    [anon_sym_ascending] = ACTIONS(4351),
    [anon_sym_descending] = ACTIONS(4351),
    [anon_sym_group] = ACTIONS(4351),
    [anon_sym_by] = ACTIONS(4351),
    [anon_sym_select] = ACTIONS(4351),
    [anon_sym_as] = ACTIONS(3995),
    [anon_sym_is] = ACTIONS(3995),
    [anon_sym_DASH_GT] = ACTIONS(3993),
    [anon_sym_with] = ACTIONS(3995),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2925] = {
    [sym__name] = STATE(3912),
    [sym_alias_qualified_name] = STATE(3924),
    [sym__simple_name] = STATE(3924),
    [sym_qualified_name] = STATE(3924),
    [sym_generic_name] = STATE(3900),
    [sym_ref_type] = STATE(3954),
    [sym__scoped_base_type] = STATE(3916),
    [sym_identifier] = STATE(3808),
    [sym__reserved_identifier] = STATE(3871),
    [sym_preproc_region] = STATE(2925),
    [sym_preproc_endregion] = STATE(2925),
    [sym_preproc_line] = STATE(2925),
    [sym_preproc_pragma] = STATE(2925),
    [sym_preproc_nullable] = STATE(2925),
    [sym_preproc_error] = STATE(2925),
    [sym_preproc_warning] = STATE(2925),
    [sym_preproc_define] = STATE(2925),
    [sym_preproc_undef] = STATE(2925),
    [sym__identifier_token] = ACTIONS(4223),
    [anon_sym_alias] = ACTIONS(4225),
    [anon_sym_global] = ACTIONS(4225),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_COLON] = ACTIONS(3995),
    [anon_sym_LPAREN] = ACTIONS(3993),
    [anon_sym_ref] = ACTIONS(4530),
    [anon_sym_LBRACE] = ACTIONS(3993),
    [anon_sym_file] = ACTIONS(4225),
    [anon_sym_LT] = ACTIONS(3995),
    [anon_sym_GT] = ACTIONS(3995),
    [anon_sym_where] = ACTIONS(4225),
    [anon_sym_QMARK] = ACTIONS(3995),
    [anon_sym_notnull] = ACTIONS(4225),
    [anon_sym_unmanaged] = ACTIONS(4225),
    [anon_sym_BANG] = ACTIONS(3995),
    [anon_sym_PLUS_PLUS] = ACTIONS(3993),
    [anon_sym_DASH_DASH] = ACTIONS(3993),
    [anon_sym_PLUS] = ACTIONS(3995),
    [anon_sym_DASH] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3993),
    [anon_sym_SLASH] = ACTIONS(3995),
    [anon_sym_PERCENT] = ACTIONS(3993),
    [anon_sym_CARET] = ACTIONS(3993),
    [anon_sym_PIPE] = ACTIONS(3995),
    [anon_sym_AMP] = ACTIONS(3995),
    [anon_sym_LT_LT] = ACTIONS(3993),
    [anon_sym_GT_GT] = ACTIONS(3995),
    [anon_sym_GT_GT_GT] = ACTIONS(3993),
    [anon_sym_EQ_EQ] = ACTIONS(3993),
    [anon_sym_BANG_EQ] = ACTIONS(3993),
    [anon_sym_GT_EQ] = ACTIONS(3993),
    [anon_sym_LT_EQ] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3995),
    [anon_sym_scoped] = ACTIONS(4225),
    [anon_sym_EQ_GT] = ACTIONS(3993),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(4225),
    [anon_sym_yield] = ACTIONS(4225),
    [anon_sym_switch] = ACTIONS(3995),
    [anon_sym_when] = ACTIONS(4229),
    [anon_sym_DOT_DOT] = ACTIONS(3993),
    [anon_sym_and] = ACTIONS(3995),
    [anon_sym_or] = ACTIONS(3995),
    [anon_sym_AMP_AMP] = ACTIONS(3993),
    [anon_sym_PIPE_PIPE] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK] = ACTIONS(3993),
    [anon_sym_from] = ACTIONS(4225),
    [anon_sym_into] = ACTIONS(4229),
    [anon_sym_join] = ACTIONS(4225),
    [anon_sym_on] = ACTIONS(4225),
    [anon_sym_equals] = ACTIONS(4225),
    [anon_sym_let] = ACTIONS(4225),
    [anon_sym_orderby] = ACTIONS(4225),
    [anon_sym_ascending] = ACTIONS(4225),
    [anon_sym_descending] = ACTIONS(4225),
    [anon_sym_group] = ACTIONS(4225),
    [anon_sym_by] = ACTIONS(4225),
    [anon_sym_select] = ACTIONS(4225),
    [anon_sym_as] = ACTIONS(3995),
    [anon_sym_is] = ACTIONS(3995),
    [anon_sym_DASH_GT] = ACTIONS(3993),
    [anon_sym_with] = ACTIONS(3995),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2926] = {
    [sym_preproc_region] = STATE(2926),
    [sym_preproc_endregion] = STATE(2926),
    [sym_preproc_line] = STATE(2926),
    [sym_preproc_pragma] = STATE(2926),
    [sym_preproc_nullable] = STATE(2926),
    [sym_preproc_error] = STATE(2926),
    [sym_preproc_warning] = STATE(2926),
    [sym_preproc_define] = STATE(2926),
    [sym_preproc_undef] = STATE(2926),
    [sym__identifier_token] = ACTIONS(3995),
    [anon_sym_alias] = ACTIONS(3995),
    [anon_sym_SEMI] = ACTIONS(3993),
    [anon_sym_global] = ACTIONS(3995),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_COLON] = ACTIONS(3995),
    [anon_sym_COMMA] = ACTIONS(3993),
    [anon_sym_RBRACK] = ACTIONS(3993),
    [anon_sym_LPAREN] = ACTIONS(3993),
    [anon_sym_RPAREN] = ACTIONS(3993),
    [anon_sym_LBRACE] = ACTIONS(3993),
    [anon_sym_RBRACE] = ACTIONS(3993),
    [anon_sym_file] = ACTIONS(3995),
    [anon_sym_LT] = ACTIONS(3995),
    [anon_sym_GT] = ACTIONS(3995),
    [anon_sym_in] = ACTIONS(3995),
    [anon_sym_where] = ACTIONS(3995),
    [anon_sym_QMARK] = ACTIONS(3995),
    [anon_sym_notnull] = ACTIONS(3995),
    [anon_sym_unmanaged] = ACTIONS(3995),
    [anon_sym_BANG] = ACTIONS(3995),
    [anon_sym_PLUS_PLUS] = ACTIONS(3993),
    [anon_sym_DASH_DASH] = ACTIONS(3993),
    [anon_sym_PLUS] = ACTIONS(3995),
    [anon_sym_DASH] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3993),
    [anon_sym_SLASH] = ACTIONS(3995),
    [anon_sym_PERCENT] = ACTIONS(3993),
    [anon_sym_CARET] = ACTIONS(3993),
    [anon_sym_PIPE] = ACTIONS(3995),
    [anon_sym_AMP] = ACTIONS(3995),
    [anon_sym_LT_LT] = ACTIONS(3993),
    [anon_sym_GT_GT] = ACTIONS(3995),
    [anon_sym_GT_GT_GT] = ACTIONS(3993),
    [anon_sym_EQ_EQ] = ACTIONS(3993),
    [anon_sym_BANG_EQ] = ACTIONS(3993),
    [anon_sym_GT_EQ] = ACTIONS(3993),
    [anon_sym_LT_EQ] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3995),
    [anon_sym_scoped] = ACTIONS(3995),
    [anon_sym_EQ_GT] = ACTIONS(3993),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(3995),
    [anon_sym_yield] = ACTIONS(3995),
    [anon_sym_switch] = ACTIONS(3995),
    [anon_sym_when] = ACTIONS(3995),
    [sym_discard] = ACTIONS(3995),
    [anon_sym_DOT_DOT] = ACTIONS(3993),
    [anon_sym_and] = ACTIONS(3995),
    [anon_sym_or] = ACTIONS(3995),
    [anon_sym_AMP_AMP] = ACTIONS(3993),
    [anon_sym_PIPE_PIPE] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK] = ACTIONS(3993),
    [anon_sym_from] = ACTIONS(3995),
    [anon_sym_into] = ACTIONS(3995),
    [anon_sym_join] = ACTIONS(3995),
    [anon_sym_on] = ACTIONS(3995),
    [anon_sym_equals] = ACTIONS(3995),
    [anon_sym_let] = ACTIONS(3995),
    [anon_sym_orderby] = ACTIONS(3995),
    [anon_sym_ascending] = ACTIONS(3995),
    [anon_sym_descending] = ACTIONS(3995),
    [anon_sym_group] = ACTIONS(3995),
    [anon_sym_by] = ACTIONS(3995),
    [anon_sym_select] = ACTIONS(3995),
    [anon_sym_as] = ACTIONS(3995),
    [anon_sym_is] = ACTIONS(3995),
    [anon_sym_DASH_GT] = ACTIONS(3993),
    [anon_sym_with] = ACTIONS(3995),
    [aux_sym_preproc_if_token3] = ACTIONS(3993),
    [aux_sym_preproc_else_token1] = ACTIONS(3993),
    [aux_sym_preproc_elif_token1] = ACTIONS(3993),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2927] = {
    [sym_preproc_region] = STATE(2927),
    [sym_preproc_endregion] = STATE(2927),
    [sym_preproc_line] = STATE(2927),
    [sym_preproc_pragma] = STATE(2927),
    [sym_preproc_nullable] = STATE(2927),
    [sym_preproc_error] = STATE(2927),
    [sym_preproc_warning] = STATE(2927),
    [sym_preproc_define] = STATE(2927),
    [sym_preproc_undef] = STATE(2927),
    [sym__identifier_token] = ACTIONS(4091),
    [anon_sym_alias] = ACTIONS(4091),
    [anon_sym_SEMI] = ACTIONS(4088),
    [anon_sym_global] = ACTIONS(4091),
    [anon_sym_LBRACK] = ACTIONS(4088),
    [anon_sym_COLON] = ACTIONS(4091),
    [anon_sym_COMMA] = ACTIONS(4088),
    [anon_sym_RBRACK] = ACTIONS(4088),
    [anon_sym_LPAREN] = ACTIONS(4088),
    [anon_sym_RPAREN] = ACTIONS(4088),
    [anon_sym_LBRACE] = ACTIONS(4088),
    [anon_sym_RBRACE] = ACTIONS(4088),
    [anon_sym_file] = ACTIONS(4091),
    [anon_sym_LT] = ACTIONS(4091),
    [anon_sym_GT] = ACTIONS(4091),
    [anon_sym_in] = ACTIONS(4091),
    [anon_sym_where] = ACTIONS(4091),
    [anon_sym_QMARK] = ACTIONS(4091),
    [anon_sym_notnull] = ACTIONS(4091),
    [anon_sym_unmanaged] = ACTIONS(4091),
    [anon_sym_BANG] = ACTIONS(4091),
    [anon_sym_PLUS_PLUS] = ACTIONS(4088),
    [anon_sym_DASH_DASH] = ACTIONS(4088),
    [anon_sym_PLUS] = ACTIONS(4091),
    [anon_sym_DASH] = ACTIONS(4091),
    [anon_sym_STAR] = ACTIONS(4088),
    [anon_sym_SLASH] = ACTIONS(4091),
    [anon_sym_PERCENT] = ACTIONS(4088),
    [anon_sym_CARET] = ACTIONS(4088),
    [anon_sym_PIPE] = ACTIONS(4091),
    [anon_sym_AMP] = ACTIONS(4091),
    [anon_sym_LT_LT] = ACTIONS(4088),
    [anon_sym_GT_GT] = ACTIONS(4091),
    [anon_sym_GT_GT_GT] = ACTIONS(4088),
    [anon_sym_EQ_EQ] = ACTIONS(4088),
    [anon_sym_BANG_EQ] = ACTIONS(4088),
    [anon_sym_GT_EQ] = ACTIONS(4088),
    [anon_sym_LT_EQ] = ACTIONS(4088),
    [anon_sym_DOT] = ACTIONS(4091),
    [anon_sym_scoped] = ACTIONS(4091),
    [anon_sym_EQ_GT] = ACTIONS(4088),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(4091),
    [anon_sym_yield] = ACTIONS(4091),
    [anon_sym_switch] = ACTIONS(4091),
    [anon_sym_when] = ACTIONS(4091),
    [sym_discard] = ACTIONS(4091),
    [anon_sym_DOT_DOT] = ACTIONS(4088),
    [anon_sym_and] = ACTIONS(4091),
    [anon_sym_or] = ACTIONS(4091),
    [anon_sym_AMP_AMP] = ACTIONS(4088),
    [anon_sym_PIPE_PIPE] = ACTIONS(4088),
    [anon_sym_QMARK_QMARK] = ACTIONS(4088),
    [anon_sym_from] = ACTIONS(4091),
    [anon_sym_into] = ACTIONS(4091),
    [anon_sym_join] = ACTIONS(4091),
    [anon_sym_on] = ACTIONS(4091),
    [anon_sym_equals] = ACTIONS(4091),
    [anon_sym_let] = ACTIONS(4091),
    [anon_sym_orderby] = ACTIONS(4091),
    [anon_sym_ascending] = ACTIONS(4091),
    [anon_sym_descending] = ACTIONS(4091),
    [anon_sym_group] = ACTIONS(4091),
    [anon_sym_by] = ACTIONS(4091),
    [anon_sym_select] = ACTIONS(4091),
    [anon_sym_as] = ACTIONS(4091),
    [anon_sym_is] = ACTIONS(4091),
    [anon_sym_DASH_GT] = ACTIONS(4088),
    [anon_sym_with] = ACTIONS(4091),
    [aux_sym_preproc_if_token3] = ACTIONS(4088),
    [aux_sym_preproc_else_token1] = ACTIONS(4088),
    [aux_sym_preproc_elif_token1] = ACTIONS(4088),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2928] = {
    [sym_preproc_region] = STATE(2928),
    [sym_preproc_endregion] = STATE(2928),
    [sym_preproc_line] = STATE(2928),
    [sym_preproc_pragma] = STATE(2928),
    [sym_preproc_nullable] = STATE(2928),
    [sym_preproc_error] = STATE(2928),
    [sym_preproc_warning] = STATE(2928),
    [sym_preproc_define] = STATE(2928),
    [sym_preproc_undef] = STATE(2928),
    [sym__identifier_token] = ACTIONS(4122),
    [anon_sym_alias] = ACTIONS(4122),
    [anon_sym_SEMI] = ACTIONS(4124),
    [anon_sym_global] = ACTIONS(4122),
    [anon_sym_LBRACK] = ACTIONS(4124),
    [anon_sym_COLON] = ACTIONS(4122),
    [anon_sym_COMMA] = ACTIONS(4124),
    [anon_sym_RBRACK] = ACTIONS(4124),
    [anon_sym_LPAREN] = ACTIONS(4124),
    [anon_sym_RPAREN] = ACTIONS(4124),
    [anon_sym_LBRACE] = ACTIONS(4124),
    [anon_sym_RBRACE] = ACTIONS(4124),
    [anon_sym_file] = ACTIONS(4122),
    [anon_sym_LT] = ACTIONS(4122),
    [anon_sym_GT] = ACTIONS(4122),
    [anon_sym_in] = ACTIONS(4122),
    [anon_sym_where] = ACTIONS(4122),
    [anon_sym_QMARK] = ACTIONS(4122),
    [anon_sym_notnull] = ACTIONS(4122),
    [anon_sym_unmanaged] = ACTIONS(4122),
    [anon_sym_BANG] = ACTIONS(4122),
    [anon_sym_PLUS_PLUS] = ACTIONS(4124),
    [anon_sym_DASH_DASH] = ACTIONS(4124),
    [anon_sym_PLUS] = ACTIONS(4122),
    [anon_sym_DASH] = ACTIONS(4122),
    [anon_sym_STAR] = ACTIONS(4124),
    [anon_sym_SLASH] = ACTIONS(4122),
    [anon_sym_PERCENT] = ACTIONS(4124),
    [anon_sym_CARET] = ACTIONS(4124),
    [anon_sym_PIPE] = ACTIONS(4122),
    [anon_sym_AMP] = ACTIONS(4122),
    [anon_sym_LT_LT] = ACTIONS(4124),
    [anon_sym_GT_GT] = ACTIONS(4122),
    [anon_sym_GT_GT_GT] = ACTIONS(4124),
    [anon_sym_EQ_EQ] = ACTIONS(4124),
    [anon_sym_BANG_EQ] = ACTIONS(4124),
    [anon_sym_GT_EQ] = ACTIONS(4124),
    [anon_sym_LT_EQ] = ACTIONS(4124),
    [anon_sym_DOT] = ACTIONS(4122),
    [anon_sym_scoped] = ACTIONS(4122),
    [anon_sym_EQ_GT] = ACTIONS(4124),
    [anon_sym_COLON_COLON] = ACTIONS(4124),
    [anon_sym_var] = ACTIONS(4122),
    [anon_sym_yield] = ACTIONS(4122),
    [anon_sym_switch] = ACTIONS(4122),
    [anon_sym_when] = ACTIONS(4122),
    [sym_discard] = ACTIONS(4122),
    [anon_sym_DOT_DOT] = ACTIONS(4124),
    [anon_sym_and] = ACTIONS(4122),
    [anon_sym_or] = ACTIONS(4122),
    [anon_sym_AMP_AMP] = ACTIONS(4124),
    [anon_sym_PIPE_PIPE] = ACTIONS(4124),
    [anon_sym_QMARK_QMARK] = ACTIONS(4124),
    [anon_sym_from] = ACTIONS(4122),
    [anon_sym_into] = ACTIONS(4122),
    [anon_sym_join] = ACTIONS(4122),
    [anon_sym_on] = ACTIONS(4122),
    [anon_sym_equals] = ACTIONS(4122),
    [anon_sym_let] = ACTIONS(4122),
    [anon_sym_orderby] = ACTIONS(4122),
    [anon_sym_ascending] = ACTIONS(4122),
    [anon_sym_descending] = ACTIONS(4122),
    [anon_sym_group] = ACTIONS(4122),
    [anon_sym_by] = ACTIONS(4122),
    [anon_sym_select] = ACTIONS(4122),
    [anon_sym_as] = ACTIONS(4122),
    [anon_sym_is] = ACTIONS(4122),
    [anon_sym_DASH_GT] = ACTIONS(4124),
    [anon_sym_with] = ACTIONS(4122),
    [aux_sym_preproc_if_token3] = ACTIONS(4124),
    [aux_sym_preproc_else_token1] = ACTIONS(4124),
    [aux_sym_preproc_elif_token1] = ACTIONS(4124),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2929] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7107),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9821),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(2929),
    [sym_preproc_endregion] = STATE(2929),
    [sym_preproc_line] = STATE(2929),
    [sym_preproc_pragma] = STATE(2929),
    [sym_preproc_nullable] = STATE(2929),
    [sym_preproc_error] = STATE(2929),
    [sym_preproc_warning] = STATE(2929),
    [sym_preproc_define] = STATE(2929),
    [sym_preproc_undef] = STATE(2929),
    [aux_sym_class_declaration_repeat1] = STATE(4341),
    [aux_sym_class_declaration_repeat2] = STATE(3125),
    [aux_sym_lambda_expression_repeat1] = STATE(4289),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_unsafe] = ACTIONS(661),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(4532),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(4534),
    [anon_sym_fixed] = ACTIONS(661),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(661),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2930] = {
    [sym_preproc_region] = STATE(2930),
    [sym_preproc_endregion] = STATE(2930),
    [sym_preproc_line] = STATE(2930),
    [sym_preproc_pragma] = STATE(2930),
    [sym_preproc_nullable] = STATE(2930),
    [sym_preproc_error] = STATE(2930),
    [sym_preproc_warning] = STATE(2930),
    [sym_preproc_define] = STATE(2930),
    [sym_preproc_undef] = STATE(2930),
    [sym__identifier_token] = ACTIONS(4157),
    [anon_sym_alias] = ACTIONS(4157),
    [anon_sym_global] = ACTIONS(4157),
    [anon_sym_EQ] = ACTIONS(4162),
    [anon_sym_LBRACK] = ACTIONS(4193),
    [anon_sym_COMMA] = ACTIONS(4177),
    [anon_sym_LPAREN] = ACTIONS(4193),
    [anon_sym_file] = ACTIONS(4157),
    [anon_sym_LT] = ACTIONS(4162),
    [anon_sym_GT] = ACTIONS(4162),
    [anon_sym_where] = ACTIONS(4196),
    [anon_sym_QMARK] = ACTIONS(4196),
    [anon_sym_notnull] = ACTIONS(4157),
    [anon_sym_unmanaged] = ACTIONS(4157),
    [anon_sym_BANG] = ACTIONS(4162),
    [anon_sym_PLUS_PLUS] = ACTIONS(4177),
    [anon_sym_DASH_DASH] = ACTIONS(4177),
    [anon_sym_PLUS] = ACTIONS(4162),
    [anon_sym_DASH] = ACTIONS(4162),
    [anon_sym_STAR] = ACTIONS(4196),
    [anon_sym_SLASH] = ACTIONS(4162),
    [anon_sym_PERCENT] = ACTIONS(4162),
    [anon_sym_CARET] = ACTIONS(4162),
    [anon_sym_PIPE] = ACTIONS(4162),
    [anon_sym_AMP] = ACTIONS(4162),
    [anon_sym_LT_LT] = ACTIONS(4162),
    [anon_sym_GT_GT] = ACTIONS(4162),
    [anon_sym_GT_GT_GT] = ACTIONS(4162),
    [anon_sym_EQ_EQ] = ACTIONS(4177),
    [anon_sym_BANG_EQ] = ACTIONS(4177),
    [anon_sym_GT_EQ] = ACTIONS(4177),
    [anon_sym_LT_EQ] = ACTIONS(4177),
    [anon_sym_DOT] = ACTIONS(4196),
    [anon_sym_scoped] = ACTIONS(4157),
    [anon_sym_var] = ACTIONS(4157),
    [anon_sym_yield] = ACTIONS(4157),
    [anon_sym_switch] = ACTIONS(4162),
    [anon_sym_when] = ACTIONS(4157),
    [anon_sym_DOT_DOT] = ACTIONS(4177),
    [anon_sym_and] = ACTIONS(4162),
    [anon_sym_or] = ACTIONS(4162),
    [anon_sym_PLUS_EQ] = ACTIONS(4177),
    [anon_sym_DASH_EQ] = ACTIONS(4177),
    [anon_sym_STAR_EQ] = ACTIONS(4177),
    [anon_sym_SLASH_EQ] = ACTIONS(4177),
    [anon_sym_PERCENT_EQ] = ACTIONS(4177),
    [anon_sym_AMP_EQ] = ACTIONS(4177),
    [anon_sym_CARET_EQ] = ACTIONS(4177),
    [anon_sym_PIPE_EQ] = ACTIONS(4177),
    [anon_sym_LT_LT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4177),
    [anon_sym_AMP_AMP] = ACTIONS(4177),
    [anon_sym_PIPE_PIPE] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK] = ACTIONS(4162),
    [anon_sym_from] = ACTIONS(4196),
    [anon_sym_into] = ACTIONS(4157),
    [anon_sym_join] = ACTIONS(4196),
    [anon_sym_on] = ACTIONS(4157),
    [anon_sym_equals] = ACTIONS(4157),
    [anon_sym_let] = ACTIONS(4196),
    [anon_sym_orderby] = ACTIONS(4196),
    [anon_sym_ascending] = ACTIONS(4196),
    [anon_sym_descending] = ACTIONS(4196),
    [anon_sym_group] = ACTIONS(4196),
    [anon_sym_by] = ACTIONS(4157),
    [anon_sym_select] = ACTIONS(4196),
    [anon_sym_as] = ACTIONS(4162),
    [anon_sym_is] = ACTIONS(4162),
    [anon_sym_DASH_GT] = ACTIONS(4193),
    [anon_sym_with] = ACTIONS(4162),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2931] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7089),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9876),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(2931),
    [sym_preproc_endregion] = STATE(2931),
    [sym_preproc_line] = STATE(2931),
    [sym_preproc_pragma] = STATE(2931),
    [sym_preproc_nullable] = STATE(2931),
    [sym_preproc_error] = STATE(2931),
    [sym_preproc_warning] = STATE(2931),
    [sym_preproc_define] = STATE(2931),
    [sym_preproc_undef] = STATE(2931),
    [aux_sym_class_declaration_repeat1] = STATE(4341),
    [aux_sym_class_declaration_repeat2] = STATE(3126),
    [aux_sym_lambda_expression_repeat1] = STATE(4288),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_unsafe] = ACTIONS(661),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(4532),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(4534),
    [anon_sym_fixed] = ACTIONS(661),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(661),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2932] = {
    [sym_preproc_region] = STATE(2932),
    [sym_preproc_endregion] = STATE(2932),
    [sym_preproc_line] = STATE(2932),
    [sym_preproc_pragma] = STATE(2932),
    [sym_preproc_nullable] = STATE(2932),
    [sym_preproc_error] = STATE(2932),
    [sym_preproc_warning] = STATE(2932),
    [sym_preproc_define] = STATE(2932),
    [sym_preproc_undef] = STATE(2932),
    [sym__identifier_token] = ACTIONS(4157),
    [anon_sym_alias] = ACTIONS(4157),
    [anon_sym_global] = ACTIONS(4157),
    [anon_sym_EQ] = ACTIONS(4162),
    [anon_sym_LBRACK] = ACTIONS(4193),
    [anon_sym_COMMA] = ACTIONS(4177),
    [anon_sym_LPAREN] = ACTIONS(4193),
    [anon_sym_file] = ACTIONS(4157),
    [anon_sym_LT] = ACTIONS(4162),
    [anon_sym_GT] = ACTIONS(4162),
    [anon_sym_where] = ACTIONS(4196),
    [anon_sym_QMARK] = ACTIONS(4196),
    [anon_sym_notnull] = ACTIONS(4157),
    [anon_sym_unmanaged] = ACTIONS(4157),
    [anon_sym_BANG] = ACTIONS(4162),
    [anon_sym_PLUS_PLUS] = ACTIONS(4177),
    [anon_sym_DASH_DASH] = ACTIONS(4177),
    [anon_sym_PLUS] = ACTIONS(4162),
    [anon_sym_DASH] = ACTIONS(4162),
    [anon_sym_STAR] = ACTIONS(4196),
    [anon_sym_SLASH] = ACTIONS(4162),
    [anon_sym_PERCENT] = ACTIONS(4162),
    [anon_sym_CARET] = ACTIONS(4162),
    [anon_sym_PIPE] = ACTIONS(4162),
    [anon_sym_AMP] = ACTIONS(4162),
    [anon_sym_LT_LT] = ACTIONS(4162),
    [anon_sym_GT_GT] = ACTIONS(4162),
    [anon_sym_GT_GT_GT] = ACTIONS(4162),
    [anon_sym_EQ_EQ] = ACTIONS(4177),
    [anon_sym_BANG_EQ] = ACTIONS(4177),
    [anon_sym_GT_EQ] = ACTIONS(4177),
    [anon_sym_LT_EQ] = ACTIONS(4177),
    [anon_sym_DOT] = ACTIONS(4196),
    [anon_sym_scoped] = ACTIONS(4157),
    [anon_sym_var] = ACTIONS(4157),
    [anon_sym_yield] = ACTIONS(4157),
    [anon_sym_switch] = ACTIONS(4162),
    [anon_sym_when] = ACTIONS(4157),
    [anon_sym_DOT_DOT] = ACTIONS(4177),
    [anon_sym_and] = ACTIONS(4162),
    [anon_sym_or] = ACTIONS(4162),
    [anon_sym_PLUS_EQ] = ACTIONS(4177),
    [anon_sym_DASH_EQ] = ACTIONS(4177),
    [anon_sym_STAR_EQ] = ACTIONS(4177),
    [anon_sym_SLASH_EQ] = ACTIONS(4177),
    [anon_sym_PERCENT_EQ] = ACTIONS(4177),
    [anon_sym_AMP_EQ] = ACTIONS(4177),
    [anon_sym_CARET_EQ] = ACTIONS(4177),
    [anon_sym_PIPE_EQ] = ACTIONS(4177),
    [anon_sym_LT_LT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4177),
    [anon_sym_AMP_AMP] = ACTIONS(4177),
    [anon_sym_PIPE_PIPE] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK] = ACTIONS(4162),
    [anon_sym_from] = ACTIONS(4196),
    [anon_sym_into] = ACTIONS(4196),
    [anon_sym_join] = ACTIONS(4196),
    [anon_sym_on] = ACTIONS(4157),
    [anon_sym_equals] = ACTIONS(4157),
    [anon_sym_let] = ACTIONS(4196),
    [anon_sym_orderby] = ACTIONS(4196),
    [anon_sym_ascending] = ACTIONS(4196),
    [anon_sym_descending] = ACTIONS(4196),
    [anon_sym_group] = ACTIONS(4196),
    [anon_sym_by] = ACTIONS(4157),
    [anon_sym_select] = ACTIONS(4196),
    [anon_sym_as] = ACTIONS(4162),
    [anon_sym_is] = ACTIONS(4162),
    [anon_sym_DASH_GT] = ACTIONS(4193),
    [anon_sym_with] = ACTIONS(4162),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2933] = {
    [sym_preproc_region] = STATE(2933),
    [sym_preproc_endregion] = STATE(2933),
    [sym_preproc_line] = STATE(2933),
    [sym_preproc_pragma] = STATE(2933),
    [sym_preproc_nullable] = STATE(2933),
    [sym_preproc_error] = STATE(2933),
    [sym_preproc_warning] = STATE(2933),
    [sym_preproc_define] = STATE(2933),
    [sym_preproc_undef] = STATE(2933),
    [sym__identifier_token] = ACTIONS(4179),
    [anon_sym_alias] = ACTIONS(4179),
    [anon_sym_global] = ACTIONS(4179),
    [anon_sym_EQ] = ACTIONS(4183),
    [anon_sym_LBRACK] = ACTIONS(4185),
    [anon_sym_COMMA] = ACTIONS(4191),
    [anon_sym_LPAREN] = ACTIONS(4185),
    [anon_sym_file] = ACTIONS(4179),
    [anon_sym_LT] = ACTIONS(4183),
    [anon_sym_GT] = ACTIONS(4183),
    [anon_sym_where] = ACTIONS(4188),
    [anon_sym_QMARK] = ACTIONS(4188),
    [anon_sym_notnull] = ACTIONS(4179),
    [anon_sym_unmanaged] = ACTIONS(4179),
    [anon_sym_BANG] = ACTIONS(4183),
    [anon_sym_PLUS_PLUS] = ACTIONS(4191),
    [anon_sym_DASH_DASH] = ACTIONS(4191),
    [anon_sym_PLUS] = ACTIONS(4183),
    [anon_sym_DASH] = ACTIONS(4183),
    [anon_sym_STAR] = ACTIONS(4188),
    [anon_sym_SLASH] = ACTIONS(4183),
    [anon_sym_PERCENT] = ACTIONS(4183),
    [anon_sym_CARET] = ACTIONS(4183),
    [anon_sym_PIPE] = ACTIONS(4183),
    [anon_sym_AMP] = ACTIONS(4183),
    [anon_sym_LT_LT] = ACTIONS(4183),
    [anon_sym_GT_GT] = ACTIONS(4183),
    [anon_sym_GT_GT_GT] = ACTIONS(4183),
    [anon_sym_EQ_EQ] = ACTIONS(4191),
    [anon_sym_BANG_EQ] = ACTIONS(4191),
    [anon_sym_GT_EQ] = ACTIONS(4191),
    [anon_sym_LT_EQ] = ACTIONS(4191),
    [anon_sym_DOT] = ACTIONS(4188),
    [anon_sym_scoped] = ACTIONS(4179),
    [anon_sym_var] = ACTIONS(4179),
    [anon_sym_yield] = ACTIONS(4179),
    [anon_sym_switch] = ACTIONS(4183),
    [anon_sym_when] = ACTIONS(4179),
    [anon_sym_DOT_DOT] = ACTIONS(4191),
    [anon_sym_and] = ACTIONS(4183),
    [anon_sym_or] = ACTIONS(4183),
    [anon_sym_PLUS_EQ] = ACTIONS(4191),
    [anon_sym_DASH_EQ] = ACTIONS(4191),
    [anon_sym_STAR_EQ] = ACTIONS(4191),
    [anon_sym_SLASH_EQ] = ACTIONS(4191),
    [anon_sym_PERCENT_EQ] = ACTIONS(4191),
    [anon_sym_AMP_EQ] = ACTIONS(4191),
    [anon_sym_CARET_EQ] = ACTIONS(4191),
    [anon_sym_PIPE_EQ] = ACTIONS(4191),
    [anon_sym_LT_LT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4191),
    [anon_sym_AMP_AMP] = ACTIONS(4191),
    [anon_sym_PIPE_PIPE] = ACTIONS(4191),
    [anon_sym_QMARK_QMARK] = ACTIONS(4183),
    [anon_sym_from] = ACTIONS(4188),
    [anon_sym_into] = ACTIONS(4188),
    [anon_sym_join] = ACTIONS(4188),
    [anon_sym_on] = ACTIONS(4179),
    [anon_sym_equals] = ACTIONS(4179),
    [anon_sym_let] = ACTIONS(4188),
    [anon_sym_orderby] = ACTIONS(4188),
    [anon_sym_ascending] = ACTIONS(4188),
    [anon_sym_descending] = ACTIONS(4188),
    [anon_sym_group] = ACTIONS(4188),
    [anon_sym_by] = ACTIONS(4179),
    [anon_sym_select] = ACTIONS(4188),
    [anon_sym_as] = ACTIONS(4183),
    [anon_sym_is] = ACTIONS(4183),
    [anon_sym_DASH_GT] = ACTIONS(4185),
    [anon_sym_with] = ACTIONS(4183),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2934] = {
    [sym_preproc_region] = STATE(2934),
    [sym_preproc_endregion] = STATE(2934),
    [sym_preproc_line] = STATE(2934),
    [sym_preproc_pragma] = STATE(2934),
    [sym_preproc_nullable] = STATE(2934),
    [sym_preproc_error] = STATE(2934),
    [sym_preproc_warning] = STATE(2934),
    [sym_preproc_define] = STATE(2934),
    [sym_preproc_undef] = STATE(2934),
    [sym__identifier_token] = ACTIONS(4179),
    [anon_sym_alias] = ACTIONS(4179),
    [anon_sym_global] = ACTIONS(4179),
    [anon_sym_EQ] = ACTIONS(4183),
    [anon_sym_LBRACK] = ACTIONS(4185),
    [anon_sym_COMMA] = ACTIONS(4191),
    [anon_sym_LPAREN] = ACTIONS(4185),
    [anon_sym_file] = ACTIONS(4179),
    [anon_sym_LT] = ACTIONS(4183),
    [anon_sym_GT] = ACTIONS(4183),
    [anon_sym_where] = ACTIONS(4188),
    [anon_sym_QMARK] = ACTIONS(4188),
    [anon_sym_notnull] = ACTIONS(4179),
    [anon_sym_unmanaged] = ACTIONS(4179),
    [anon_sym_BANG] = ACTIONS(4183),
    [anon_sym_PLUS_PLUS] = ACTIONS(4191),
    [anon_sym_DASH_DASH] = ACTIONS(4191),
    [anon_sym_PLUS] = ACTIONS(4183),
    [anon_sym_DASH] = ACTIONS(4183),
    [anon_sym_STAR] = ACTIONS(4188),
    [anon_sym_SLASH] = ACTIONS(4183),
    [anon_sym_PERCENT] = ACTIONS(4183),
    [anon_sym_CARET] = ACTIONS(4183),
    [anon_sym_PIPE] = ACTIONS(4183),
    [anon_sym_AMP] = ACTIONS(4183),
    [anon_sym_LT_LT] = ACTIONS(4183),
    [anon_sym_GT_GT] = ACTIONS(4183),
    [anon_sym_GT_GT_GT] = ACTIONS(4183),
    [anon_sym_EQ_EQ] = ACTIONS(4191),
    [anon_sym_BANG_EQ] = ACTIONS(4191),
    [anon_sym_GT_EQ] = ACTIONS(4191),
    [anon_sym_LT_EQ] = ACTIONS(4191),
    [anon_sym_DOT] = ACTIONS(4188),
    [anon_sym_scoped] = ACTIONS(4179),
    [anon_sym_var] = ACTIONS(4179),
    [anon_sym_yield] = ACTIONS(4179),
    [anon_sym_switch] = ACTIONS(4183),
    [anon_sym_when] = ACTIONS(4179),
    [anon_sym_DOT_DOT] = ACTIONS(4191),
    [anon_sym_and] = ACTIONS(4183),
    [anon_sym_or] = ACTIONS(4183),
    [anon_sym_PLUS_EQ] = ACTIONS(4191),
    [anon_sym_DASH_EQ] = ACTIONS(4191),
    [anon_sym_STAR_EQ] = ACTIONS(4191),
    [anon_sym_SLASH_EQ] = ACTIONS(4191),
    [anon_sym_PERCENT_EQ] = ACTIONS(4191),
    [anon_sym_AMP_EQ] = ACTIONS(4191),
    [anon_sym_CARET_EQ] = ACTIONS(4191),
    [anon_sym_PIPE_EQ] = ACTIONS(4191),
    [anon_sym_LT_LT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4191),
    [anon_sym_AMP_AMP] = ACTIONS(4191),
    [anon_sym_PIPE_PIPE] = ACTIONS(4191),
    [anon_sym_QMARK_QMARK] = ACTIONS(4183),
    [anon_sym_from] = ACTIONS(4188),
    [anon_sym_into] = ACTIONS(4179),
    [anon_sym_join] = ACTIONS(4188),
    [anon_sym_on] = ACTIONS(4179),
    [anon_sym_equals] = ACTIONS(4179),
    [anon_sym_let] = ACTIONS(4188),
    [anon_sym_orderby] = ACTIONS(4188),
    [anon_sym_ascending] = ACTIONS(4188),
    [anon_sym_descending] = ACTIONS(4188),
    [anon_sym_group] = ACTIONS(4188),
    [anon_sym_by] = ACTIONS(4179),
    [anon_sym_select] = ACTIONS(4188),
    [anon_sym_as] = ACTIONS(4183),
    [anon_sym_is] = ACTIONS(4183),
    [anon_sym_DASH_GT] = ACTIONS(4185),
    [anon_sym_with] = ACTIONS(4183),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2935] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7134),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9876),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(2935),
    [sym_preproc_endregion] = STATE(2935),
    [sym_preproc_line] = STATE(2935),
    [sym_preproc_pragma] = STATE(2935),
    [sym_preproc_nullable] = STATE(2935),
    [sym_preproc_error] = STATE(2935),
    [sym_preproc_warning] = STATE(2935),
    [sym_preproc_define] = STATE(2935),
    [sym_preproc_undef] = STATE(2935),
    [aux_sym_class_declaration_repeat1] = STATE(4341),
    [aux_sym_class_declaration_repeat2] = STATE(3125),
    [aux_sym_lambda_expression_repeat1] = STATE(4288),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_unsafe] = ACTIONS(661),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(4532),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(4534),
    [anon_sym_fixed] = ACTIONS(661),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(661),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2936] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7119),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9876),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(2936),
    [sym_preproc_endregion] = STATE(2936),
    [sym_preproc_line] = STATE(2936),
    [sym_preproc_pragma] = STATE(2936),
    [sym_preproc_nullable] = STATE(2936),
    [sym_preproc_error] = STATE(2936),
    [sym_preproc_warning] = STATE(2936),
    [sym_preproc_define] = STATE(2936),
    [sym_preproc_undef] = STATE(2936),
    [aux_sym_class_declaration_repeat1] = STATE(4341),
    [aux_sym_class_declaration_repeat2] = STATE(3133),
    [aux_sym_lambda_expression_repeat1] = STATE(4288),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_unsafe] = ACTIONS(661),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(4532),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(4534),
    [anon_sym_fixed] = ACTIONS(661),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(661),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2937] = {
    [sym_attribute_list] = STATE(4528),
    [sym_modifier] = STATE(4634),
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(6959),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9876),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(2937),
    [sym_preproc_endregion] = STATE(2937),
    [sym_preproc_line] = STATE(2937),
    [sym_preproc_pragma] = STATE(2937),
    [sym_preproc_nullable] = STATE(2937),
    [sym_preproc_error] = STATE(2937),
    [sym_preproc_warning] = STATE(2937),
    [sym_preproc_define] = STATE(2937),
    [sym_preproc_undef] = STATE(2937),
    [aux_sym_class_declaration_repeat1] = STATE(4341),
    [aux_sym_class_declaration_repeat2] = STATE(3134),
    [aux_sym_lambda_expression_repeat1] = STATE(4288),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_unsafe] = ACTIONS(661),
    [anon_sym_static] = ACTIONS(669),
    [anon_sym_LBRACK] = ACTIONS(4532),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(669),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(4534),
    [anon_sym_fixed] = ACTIONS(661),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(661),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2938] = {
    [sym_type_argument_list] = STATE(2945),
    [sym_preproc_region] = STATE(2938),
    [sym_preproc_endregion] = STATE(2938),
    [sym_preproc_line] = STATE(2938),
    [sym_preproc_pragma] = STATE(2938),
    [sym_preproc_nullable] = STATE(2938),
    [sym_preproc_error] = STATE(2938),
    [sym_preproc_warning] = STATE(2938),
    [sym_preproc_define] = STATE(2938),
    [sym_preproc_undef] = STATE(2938),
    [sym__identifier_token] = ACTIONS(4138),
    [anon_sym_alias] = ACTIONS(4138),
    [anon_sym_SEMI] = ACTIONS(4140),
    [anon_sym_global] = ACTIONS(4138),
    [anon_sym_LBRACK] = ACTIONS(4140),
    [anon_sym_COLON] = ACTIONS(4140),
    [anon_sym_COMMA] = ACTIONS(4140),
    [anon_sym_RBRACK] = ACTIONS(4140),
    [anon_sym_LPAREN] = ACTIONS(4140),
    [anon_sym_RPAREN] = ACTIONS(4140),
    [anon_sym_LBRACE] = ACTIONS(4140),
    [anon_sym_RBRACE] = ACTIONS(4140),
    [anon_sym_file] = ACTIONS(4138),
    [anon_sym_LT] = ACTIONS(4520),
    [anon_sym_GT] = ACTIONS(4138),
    [anon_sym_in] = ACTIONS(4138),
    [anon_sym_where] = ACTIONS(4138),
    [anon_sym_QMARK] = ACTIONS(4138),
    [anon_sym_notnull] = ACTIONS(4138),
    [anon_sym_unmanaged] = ACTIONS(4138),
    [anon_sym_BANG] = ACTIONS(4138),
    [anon_sym_PLUS_PLUS] = ACTIONS(4140),
    [anon_sym_DASH_DASH] = ACTIONS(4140),
    [anon_sym_PLUS] = ACTIONS(4138),
    [anon_sym_DASH] = ACTIONS(4138),
    [anon_sym_STAR] = ACTIONS(4140),
    [anon_sym_SLASH] = ACTIONS(4138),
    [anon_sym_PERCENT] = ACTIONS(4140),
    [anon_sym_CARET] = ACTIONS(4140),
    [anon_sym_PIPE] = ACTIONS(4138),
    [anon_sym_AMP] = ACTIONS(4138),
    [anon_sym_LT_LT] = ACTIONS(4140),
    [anon_sym_GT_GT] = ACTIONS(4138),
    [anon_sym_GT_GT_GT] = ACTIONS(4140),
    [anon_sym_EQ_EQ] = ACTIONS(4140),
    [anon_sym_BANG_EQ] = ACTIONS(4140),
    [anon_sym_GT_EQ] = ACTIONS(4140),
    [anon_sym_LT_EQ] = ACTIONS(4140),
    [anon_sym_DOT] = ACTIONS(4138),
    [anon_sym_scoped] = ACTIONS(4138),
    [anon_sym_EQ_GT] = ACTIONS(4140),
    [anon_sym_var] = ACTIONS(4138),
    [anon_sym_yield] = ACTIONS(4138),
    [anon_sym_switch] = ACTIONS(4138),
    [anon_sym_when] = ACTIONS(4138),
    [sym_discard] = ACTIONS(4138),
    [anon_sym_DOT_DOT] = ACTIONS(4140),
    [anon_sym_and] = ACTIONS(4138),
    [anon_sym_or] = ACTIONS(4138),
    [anon_sym_AMP_AMP] = ACTIONS(4140),
    [anon_sym_PIPE_PIPE] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK] = ACTIONS(4140),
    [anon_sym_from] = ACTIONS(4138),
    [anon_sym_into] = ACTIONS(4138),
    [anon_sym_join] = ACTIONS(4138),
    [anon_sym_on] = ACTIONS(4138),
    [anon_sym_equals] = ACTIONS(4138),
    [anon_sym_let] = ACTIONS(4138),
    [anon_sym_orderby] = ACTIONS(4138),
    [anon_sym_ascending] = ACTIONS(4138),
    [anon_sym_descending] = ACTIONS(4138),
    [anon_sym_group] = ACTIONS(4138),
    [anon_sym_by] = ACTIONS(4138),
    [anon_sym_select] = ACTIONS(4138),
    [anon_sym_as] = ACTIONS(4138),
    [anon_sym_is] = ACTIONS(4138),
    [anon_sym_DASH_GT] = ACTIONS(4140),
    [anon_sym_with] = ACTIONS(4138),
    [aux_sym_preproc_if_token3] = ACTIONS(4140),
    [aux_sym_preproc_else_token1] = ACTIONS(4140),
    [aux_sym_preproc_elif_token1] = ACTIONS(4140),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2939] = {
    [sym_preproc_region] = STATE(2939),
    [sym_preproc_endregion] = STATE(2939),
    [sym_preproc_line] = STATE(2939),
    [sym_preproc_pragma] = STATE(2939),
    [sym_preproc_nullable] = STATE(2939),
    [sym_preproc_error] = STATE(2939),
    [sym_preproc_warning] = STATE(2939),
    [sym_preproc_define] = STATE(2939),
    [sym_preproc_undef] = STATE(2939),
    [sym__identifier_token] = ACTIONS(4179),
    [anon_sym_alias] = ACTIONS(4179),
    [anon_sym_global] = ACTIONS(4179),
    [anon_sym_EQ] = ACTIONS(4183),
    [anon_sym_LBRACK] = ACTIONS(4185),
    [anon_sym_LPAREN] = ACTIONS(4185),
    [anon_sym_file] = ACTIONS(4179),
    [anon_sym_LT] = ACTIONS(4183),
    [anon_sym_GT] = ACTIONS(4183),
    [anon_sym_where] = ACTIONS(4179),
    [anon_sym_QMARK] = ACTIONS(4188),
    [anon_sym_notnull] = ACTIONS(4179),
    [anon_sym_unmanaged] = ACTIONS(4179),
    [anon_sym_BANG] = ACTIONS(4183),
    [anon_sym_PLUS_PLUS] = ACTIONS(4191),
    [anon_sym_DASH_DASH] = ACTIONS(4191),
    [anon_sym_PLUS] = ACTIONS(4183),
    [anon_sym_DASH] = ACTIONS(4183),
    [anon_sym_STAR] = ACTIONS(4188),
    [anon_sym_SLASH] = ACTIONS(4183),
    [anon_sym_PERCENT] = ACTIONS(4183),
    [anon_sym_CARET] = ACTIONS(4183),
    [anon_sym_PIPE] = ACTIONS(4183),
    [anon_sym_AMP] = ACTIONS(4183),
    [anon_sym_LT_LT] = ACTIONS(4183),
    [anon_sym_GT_GT] = ACTIONS(4183),
    [anon_sym_GT_GT_GT] = ACTIONS(4183),
    [anon_sym_EQ_EQ] = ACTIONS(4191),
    [anon_sym_BANG_EQ] = ACTIONS(4191),
    [anon_sym_GT_EQ] = ACTIONS(4191),
    [anon_sym_LT_EQ] = ACTIONS(4191),
    [anon_sym_DOT] = ACTIONS(4188),
    [anon_sym_scoped] = ACTIONS(4179),
    [anon_sym_var] = ACTIONS(4179),
    [anon_sym_yield] = ACTIONS(4179),
    [anon_sym_switch] = ACTIONS(4183),
    [anon_sym_when] = ACTIONS(4179),
    [anon_sym_DOT_DOT] = ACTIONS(4191),
    [anon_sym_and] = ACTIONS(4183),
    [anon_sym_or] = ACTIONS(4183),
    [anon_sym_PLUS_EQ] = ACTIONS(4191),
    [anon_sym_DASH_EQ] = ACTIONS(4191),
    [anon_sym_STAR_EQ] = ACTIONS(4191),
    [anon_sym_SLASH_EQ] = ACTIONS(4191),
    [anon_sym_PERCENT_EQ] = ACTIONS(4191),
    [anon_sym_AMP_EQ] = ACTIONS(4191),
    [anon_sym_CARET_EQ] = ACTIONS(4191),
    [anon_sym_PIPE_EQ] = ACTIONS(4191),
    [anon_sym_LT_LT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4191),
    [anon_sym_AMP_AMP] = ACTIONS(4191),
    [anon_sym_PIPE_PIPE] = ACTIONS(4191),
    [anon_sym_QMARK_QMARK] = ACTIONS(4183),
    [anon_sym_from] = ACTIONS(4179),
    [anon_sym_into] = ACTIONS(4188),
    [anon_sym_join] = ACTIONS(4179),
    [anon_sym_on] = ACTIONS(4179),
    [anon_sym_equals] = ACTIONS(4188),
    [anon_sym_let] = ACTIONS(4179),
    [anon_sym_orderby] = ACTIONS(4179),
    [anon_sym_ascending] = ACTIONS(4179),
    [anon_sym_descending] = ACTIONS(4179),
    [anon_sym_group] = ACTIONS(4179),
    [anon_sym_by] = ACTIONS(4179),
    [anon_sym_select] = ACTIONS(4179),
    [anon_sym_as] = ACTIONS(4183),
    [anon_sym_is] = ACTIONS(4183),
    [anon_sym_DASH_GT] = ACTIONS(4185),
    [anon_sym_with] = ACTIONS(4183),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2940] = {
    [sym_preproc_region] = STATE(2940),
    [sym_preproc_endregion] = STATE(2940),
    [sym_preproc_line] = STATE(2940),
    [sym_preproc_pragma] = STATE(2940),
    [sym_preproc_nullable] = STATE(2940),
    [sym_preproc_error] = STATE(2940),
    [sym_preproc_warning] = STATE(2940),
    [sym_preproc_define] = STATE(2940),
    [sym_preproc_undef] = STATE(2940),
    [sym__identifier_token] = ACTIONS(4157),
    [anon_sym_alias] = ACTIONS(4157),
    [anon_sym_global] = ACTIONS(4157),
    [anon_sym_EQ] = ACTIONS(4162),
    [anon_sym_LBRACK] = ACTIONS(4193),
    [anon_sym_LPAREN] = ACTIONS(4193),
    [anon_sym_file] = ACTIONS(4157),
    [anon_sym_LT] = ACTIONS(4162),
    [anon_sym_GT] = ACTIONS(4162),
    [anon_sym_where] = ACTIONS(4196),
    [anon_sym_QMARK] = ACTIONS(4196),
    [anon_sym_notnull] = ACTIONS(4157),
    [anon_sym_unmanaged] = ACTIONS(4157),
    [anon_sym_BANG] = ACTIONS(4162),
    [anon_sym_PLUS_PLUS] = ACTIONS(4177),
    [anon_sym_DASH_DASH] = ACTIONS(4177),
    [anon_sym_PLUS] = ACTIONS(4162),
    [anon_sym_DASH] = ACTIONS(4162),
    [anon_sym_STAR] = ACTIONS(4196),
    [anon_sym_SLASH] = ACTIONS(4162),
    [anon_sym_PERCENT] = ACTIONS(4162),
    [anon_sym_CARET] = ACTIONS(4162),
    [anon_sym_PIPE] = ACTIONS(4162),
    [anon_sym_AMP] = ACTIONS(4162),
    [anon_sym_LT_LT] = ACTIONS(4162),
    [anon_sym_GT_GT] = ACTIONS(4162),
    [anon_sym_GT_GT_GT] = ACTIONS(4162),
    [anon_sym_EQ_EQ] = ACTIONS(4177),
    [anon_sym_BANG_EQ] = ACTIONS(4177),
    [anon_sym_GT_EQ] = ACTIONS(4177),
    [anon_sym_LT_EQ] = ACTIONS(4177),
    [anon_sym_DOT] = ACTIONS(4196),
    [anon_sym_scoped] = ACTIONS(4157),
    [anon_sym_var] = ACTIONS(4157),
    [anon_sym_yield] = ACTIONS(4157),
    [anon_sym_switch] = ACTIONS(4162),
    [anon_sym_when] = ACTIONS(4157),
    [anon_sym_DOT_DOT] = ACTIONS(4177),
    [anon_sym_and] = ACTIONS(4162),
    [anon_sym_or] = ACTIONS(4162),
    [anon_sym_PLUS_EQ] = ACTIONS(4177),
    [anon_sym_DASH_EQ] = ACTIONS(4177),
    [anon_sym_STAR_EQ] = ACTIONS(4177),
    [anon_sym_SLASH_EQ] = ACTIONS(4177),
    [anon_sym_PERCENT_EQ] = ACTIONS(4177),
    [anon_sym_AMP_EQ] = ACTIONS(4177),
    [anon_sym_CARET_EQ] = ACTIONS(4177),
    [anon_sym_PIPE_EQ] = ACTIONS(4177),
    [anon_sym_LT_LT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4177),
    [anon_sym_AMP_AMP] = ACTIONS(4177),
    [anon_sym_PIPE_PIPE] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK] = ACTIONS(4162),
    [anon_sym_from] = ACTIONS(4196),
    [anon_sym_into] = ACTIONS(4157),
    [anon_sym_join] = ACTIONS(4196),
    [anon_sym_on] = ACTIONS(4157),
    [anon_sym_equals] = ACTIONS(4157),
    [anon_sym_let] = ACTIONS(4196),
    [anon_sym_orderby] = ACTIONS(4196),
    [anon_sym_ascending] = ACTIONS(4157),
    [anon_sym_descending] = ACTIONS(4157),
    [anon_sym_group] = ACTIONS(4196),
    [anon_sym_by] = ACTIONS(4157),
    [anon_sym_select] = ACTIONS(4196),
    [anon_sym_as] = ACTIONS(4162),
    [anon_sym_is] = ACTIONS(4162),
    [anon_sym_DASH_GT] = ACTIONS(4193),
    [anon_sym_with] = ACTIONS(4162),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2941] = {
    [sym_preproc_region] = STATE(2941),
    [sym_preproc_endregion] = STATE(2941),
    [sym_preproc_line] = STATE(2941),
    [sym_preproc_pragma] = STATE(2941),
    [sym_preproc_nullable] = STATE(2941),
    [sym_preproc_error] = STATE(2941),
    [sym_preproc_warning] = STATE(2941),
    [sym_preproc_define] = STATE(2941),
    [sym_preproc_undef] = STATE(2941),
    [sym__identifier_token] = ACTIONS(4134),
    [anon_sym_alias] = ACTIONS(4134),
    [anon_sym_SEMI] = ACTIONS(4136),
    [anon_sym_global] = ACTIONS(4134),
    [anon_sym_LBRACK] = ACTIONS(4136),
    [anon_sym_COLON] = ACTIONS(4136),
    [anon_sym_COMMA] = ACTIONS(4136),
    [anon_sym_RBRACK] = ACTIONS(4136),
    [anon_sym_LPAREN] = ACTIONS(4136),
    [anon_sym_RPAREN] = ACTIONS(4136),
    [anon_sym_LBRACE] = ACTIONS(4136),
    [anon_sym_RBRACE] = ACTIONS(4136),
    [anon_sym_file] = ACTIONS(4134),
    [anon_sym_LT] = ACTIONS(4134),
    [anon_sym_GT] = ACTIONS(4134),
    [anon_sym_in] = ACTIONS(4134),
    [anon_sym_where] = ACTIONS(4134),
    [anon_sym_QMARK] = ACTIONS(4134),
    [anon_sym_notnull] = ACTIONS(4134),
    [anon_sym_unmanaged] = ACTIONS(4134),
    [anon_sym_BANG] = ACTIONS(4134),
    [anon_sym_PLUS_PLUS] = ACTIONS(4136),
    [anon_sym_DASH_DASH] = ACTIONS(4136),
    [anon_sym_PLUS] = ACTIONS(4134),
    [anon_sym_DASH] = ACTIONS(4134),
    [anon_sym_STAR] = ACTIONS(4136),
    [anon_sym_SLASH] = ACTIONS(4134),
    [anon_sym_PERCENT] = ACTIONS(4136),
    [anon_sym_CARET] = ACTIONS(4136),
    [anon_sym_PIPE] = ACTIONS(4134),
    [anon_sym_AMP] = ACTIONS(4134),
    [anon_sym_LT_LT] = ACTIONS(4136),
    [anon_sym_GT_GT] = ACTIONS(4134),
    [anon_sym_GT_GT_GT] = ACTIONS(4136),
    [anon_sym_EQ_EQ] = ACTIONS(4136),
    [anon_sym_BANG_EQ] = ACTIONS(4136),
    [anon_sym_GT_EQ] = ACTIONS(4136),
    [anon_sym_LT_EQ] = ACTIONS(4136),
    [anon_sym_DOT] = ACTIONS(4134),
    [anon_sym_scoped] = ACTIONS(4134),
    [anon_sym_EQ_GT] = ACTIONS(4136),
    [anon_sym_var] = ACTIONS(4134),
    [anon_sym_yield] = ACTIONS(4134),
    [anon_sym_switch] = ACTIONS(4134),
    [anon_sym_when] = ACTIONS(4134),
    [sym_discard] = ACTIONS(4134),
    [anon_sym_DOT_DOT] = ACTIONS(4136),
    [anon_sym_and] = ACTIONS(4134),
    [anon_sym_or] = ACTIONS(4134),
    [anon_sym_AMP_AMP] = ACTIONS(4136),
    [anon_sym_PIPE_PIPE] = ACTIONS(4136),
    [anon_sym_QMARK_QMARK] = ACTIONS(4136),
    [anon_sym_from] = ACTIONS(4134),
    [anon_sym_into] = ACTIONS(4134),
    [anon_sym_join] = ACTIONS(4134),
    [anon_sym_on] = ACTIONS(4134),
    [anon_sym_equals] = ACTIONS(4134),
    [anon_sym_let] = ACTIONS(4134),
    [anon_sym_orderby] = ACTIONS(4134),
    [anon_sym_ascending] = ACTIONS(4134),
    [anon_sym_descending] = ACTIONS(4134),
    [anon_sym_group] = ACTIONS(4134),
    [anon_sym_by] = ACTIONS(4134),
    [anon_sym_select] = ACTIONS(4134),
    [anon_sym_as] = ACTIONS(4134),
    [anon_sym_is] = ACTIONS(4134),
    [anon_sym_DASH_GT] = ACTIONS(4136),
    [anon_sym_with] = ACTIONS(4134),
    [aux_sym_preproc_if_token3] = ACTIONS(4136),
    [aux_sym_preproc_else_token1] = ACTIONS(4136),
    [aux_sym_preproc_elif_token1] = ACTIONS(4136),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2942] = {
    [sym_preproc_region] = STATE(2942),
    [sym_preproc_endregion] = STATE(2942),
    [sym_preproc_line] = STATE(2942),
    [sym_preproc_pragma] = STATE(2942),
    [sym_preproc_nullable] = STATE(2942),
    [sym_preproc_error] = STATE(2942),
    [sym_preproc_warning] = STATE(2942),
    [sym_preproc_define] = STATE(2942),
    [sym_preproc_undef] = STATE(2942),
    [sym__identifier_token] = ACTIONS(4157),
    [anon_sym_alias] = ACTIONS(4157),
    [anon_sym_global] = ACTIONS(4157),
    [anon_sym_EQ] = ACTIONS(4162),
    [anon_sym_LBRACK] = ACTIONS(4193),
    [anon_sym_LPAREN] = ACTIONS(4193),
    [anon_sym_file] = ACTIONS(4157),
    [anon_sym_LT] = ACTIONS(4162),
    [anon_sym_GT] = ACTIONS(4162),
    [anon_sym_where] = ACTIONS(4157),
    [anon_sym_QMARK] = ACTIONS(4196),
    [anon_sym_notnull] = ACTIONS(4157),
    [anon_sym_unmanaged] = ACTIONS(4157),
    [anon_sym_BANG] = ACTIONS(4162),
    [anon_sym_PLUS_PLUS] = ACTIONS(4177),
    [anon_sym_DASH_DASH] = ACTIONS(4177),
    [anon_sym_PLUS] = ACTIONS(4162),
    [anon_sym_DASH] = ACTIONS(4162),
    [anon_sym_STAR] = ACTIONS(4196),
    [anon_sym_SLASH] = ACTIONS(4162),
    [anon_sym_PERCENT] = ACTIONS(4162),
    [anon_sym_CARET] = ACTIONS(4162),
    [anon_sym_PIPE] = ACTIONS(4162),
    [anon_sym_AMP] = ACTIONS(4162),
    [anon_sym_LT_LT] = ACTIONS(4162),
    [anon_sym_GT_GT] = ACTIONS(4162),
    [anon_sym_GT_GT_GT] = ACTIONS(4162),
    [anon_sym_EQ_EQ] = ACTIONS(4177),
    [anon_sym_BANG_EQ] = ACTIONS(4177),
    [anon_sym_GT_EQ] = ACTIONS(4177),
    [anon_sym_LT_EQ] = ACTIONS(4177),
    [anon_sym_DOT] = ACTIONS(4196),
    [anon_sym_scoped] = ACTIONS(4157),
    [anon_sym_var] = ACTIONS(4157),
    [anon_sym_yield] = ACTIONS(4157),
    [anon_sym_switch] = ACTIONS(4162),
    [anon_sym_when] = ACTIONS(4157),
    [anon_sym_DOT_DOT] = ACTIONS(4177),
    [anon_sym_and] = ACTIONS(4162),
    [anon_sym_or] = ACTIONS(4162),
    [anon_sym_PLUS_EQ] = ACTIONS(4177),
    [anon_sym_DASH_EQ] = ACTIONS(4177),
    [anon_sym_STAR_EQ] = ACTIONS(4177),
    [anon_sym_SLASH_EQ] = ACTIONS(4177),
    [anon_sym_PERCENT_EQ] = ACTIONS(4177),
    [anon_sym_AMP_EQ] = ACTIONS(4177),
    [anon_sym_CARET_EQ] = ACTIONS(4177),
    [anon_sym_PIPE_EQ] = ACTIONS(4177),
    [anon_sym_LT_LT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4177),
    [anon_sym_AMP_AMP] = ACTIONS(4177),
    [anon_sym_PIPE_PIPE] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK] = ACTIONS(4162),
    [anon_sym_from] = ACTIONS(4157),
    [anon_sym_into] = ACTIONS(4157),
    [anon_sym_join] = ACTIONS(4157),
    [anon_sym_on] = ACTIONS(4157),
    [anon_sym_equals] = ACTIONS(4157),
    [anon_sym_let] = ACTIONS(4157),
    [anon_sym_orderby] = ACTIONS(4157),
    [anon_sym_ascending] = ACTIONS(4157),
    [anon_sym_descending] = ACTIONS(4157),
    [anon_sym_group] = ACTIONS(4157),
    [anon_sym_by] = ACTIONS(4196),
    [anon_sym_select] = ACTIONS(4157),
    [anon_sym_as] = ACTIONS(4162),
    [anon_sym_is] = ACTIONS(4162),
    [anon_sym_DASH_GT] = ACTIONS(4193),
    [anon_sym_with] = ACTIONS(4162),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2943] = {
    [sym__name] = STATE(3015),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2956),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2944),
    [sym_ref_type] = STATE(2883),
    [sym__scoped_base_type] = STATE(2885),
    [sym_identifier] = STATE(2920),
    [sym__reserved_identifier] = STATE(2928),
    [sym_preproc_region] = STATE(2943),
    [sym_preproc_endregion] = STATE(2943),
    [sym_preproc_line] = STATE(2943),
    [sym_preproc_pragma] = STATE(2943),
    [sym_preproc_nullable] = STATE(2943),
    [sym_preproc_error] = STATE(2943),
    [sym_preproc_warning] = STATE(2943),
    [sym_preproc_define] = STATE(2943),
    [sym_preproc_undef] = STATE(2943),
    [sym__identifier_token] = ACTIONS(4536),
    [anon_sym_alias] = ACTIONS(4538),
    [anon_sym_global] = ACTIONS(4538),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_COMMA] = ACTIONS(3993),
    [anon_sym_LPAREN] = ACTIONS(3993),
    [anon_sym_ref] = ACTIONS(4540),
    [anon_sym_LBRACE] = ACTIONS(3993),
    [anon_sym_file] = ACTIONS(4538),
    [anon_sym_LT] = ACTIONS(3995),
    [anon_sym_GT] = ACTIONS(3995),
    [anon_sym_where] = ACTIONS(4056),
    [anon_sym_QMARK] = ACTIONS(3995),
    [anon_sym_notnull] = ACTIONS(4538),
    [anon_sym_unmanaged] = ACTIONS(4538),
    [anon_sym_BANG] = ACTIONS(3995),
    [anon_sym_PLUS_PLUS] = ACTIONS(3993),
    [anon_sym_DASH_DASH] = ACTIONS(3993),
    [anon_sym_PLUS] = ACTIONS(3995),
    [anon_sym_DASH] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3993),
    [anon_sym_SLASH] = ACTIONS(3995),
    [anon_sym_PERCENT] = ACTIONS(3993),
    [anon_sym_CARET] = ACTIONS(3993),
    [anon_sym_PIPE] = ACTIONS(3995),
    [anon_sym_AMP] = ACTIONS(3995),
    [anon_sym_LT_LT] = ACTIONS(3993),
    [anon_sym_GT_GT] = ACTIONS(3995),
    [anon_sym_GT_GT_GT] = ACTIONS(3993),
    [anon_sym_EQ_EQ] = ACTIONS(3993),
    [anon_sym_BANG_EQ] = ACTIONS(3993),
    [anon_sym_GT_EQ] = ACTIONS(3993),
    [anon_sym_LT_EQ] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3995),
    [anon_sym_scoped] = ACTIONS(4538),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(4538),
    [anon_sym_yield] = ACTIONS(4538),
    [anon_sym_switch] = ACTIONS(3995),
    [anon_sym_when] = ACTIONS(4538),
    [anon_sym_DOT_DOT] = ACTIONS(3993),
    [anon_sym_and] = ACTIONS(3995),
    [anon_sym_or] = ACTIONS(3995),
    [anon_sym_AMP_AMP] = ACTIONS(3993),
    [anon_sym_PIPE_PIPE] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK] = ACTIONS(3993),
    [anon_sym_from] = ACTIONS(4056),
    [anon_sym_into] = ACTIONS(4056),
    [anon_sym_join] = ACTIONS(4056),
    [anon_sym_on] = ACTIONS(4538),
    [anon_sym_equals] = ACTIONS(4538),
    [anon_sym_let] = ACTIONS(4056),
    [anon_sym_orderby] = ACTIONS(4056),
    [anon_sym_ascending] = ACTIONS(4056),
    [anon_sym_descending] = ACTIONS(4056),
    [anon_sym_group] = ACTIONS(4056),
    [anon_sym_by] = ACTIONS(4538),
    [anon_sym_select] = ACTIONS(4056),
    [anon_sym_as] = ACTIONS(3995),
    [anon_sym_is] = ACTIONS(3995),
    [anon_sym_DASH_GT] = ACTIONS(3993),
    [anon_sym_with] = ACTIONS(3995),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2944] = {
    [sym_preproc_region] = STATE(2944),
    [sym_preproc_endregion] = STATE(2944),
    [sym_preproc_line] = STATE(2944),
    [sym_preproc_pragma] = STATE(2944),
    [sym_preproc_nullable] = STATE(2944),
    [sym_preproc_error] = STATE(2944),
    [sym_preproc_warning] = STATE(2944),
    [sym_preproc_define] = STATE(2944),
    [sym_preproc_undef] = STATE(2944),
    [sym__identifier_token] = ACTIONS(4138),
    [anon_sym_alias] = ACTIONS(4138),
    [anon_sym_SEMI] = ACTIONS(4140),
    [anon_sym_global] = ACTIONS(4138),
    [anon_sym_LBRACK] = ACTIONS(4140),
    [anon_sym_COLON] = ACTIONS(4140),
    [anon_sym_COMMA] = ACTIONS(4140),
    [anon_sym_RBRACK] = ACTIONS(4140),
    [anon_sym_LPAREN] = ACTIONS(4140),
    [anon_sym_RPAREN] = ACTIONS(4140),
    [anon_sym_LBRACE] = ACTIONS(4140),
    [anon_sym_RBRACE] = ACTIONS(4140),
    [anon_sym_file] = ACTIONS(4138),
    [anon_sym_LT] = ACTIONS(4138),
    [anon_sym_GT] = ACTIONS(4138),
    [anon_sym_in] = ACTIONS(4138),
    [anon_sym_where] = ACTIONS(4138),
    [anon_sym_QMARK] = ACTIONS(4138),
    [anon_sym_notnull] = ACTIONS(4138),
    [anon_sym_unmanaged] = ACTIONS(4138),
    [anon_sym_BANG] = ACTIONS(4138),
    [anon_sym_PLUS_PLUS] = ACTIONS(4140),
    [anon_sym_DASH_DASH] = ACTIONS(4140),
    [anon_sym_PLUS] = ACTIONS(4138),
    [anon_sym_DASH] = ACTIONS(4138),
    [anon_sym_STAR] = ACTIONS(4140),
    [anon_sym_SLASH] = ACTIONS(4138),
    [anon_sym_PERCENT] = ACTIONS(4140),
    [anon_sym_CARET] = ACTIONS(4140),
    [anon_sym_PIPE] = ACTIONS(4138),
    [anon_sym_AMP] = ACTIONS(4138),
    [anon_sym_LT_LT] = ACTIONS(4140),
    [anon_sym_GT_GT] = ACTIONS(4138),
    [anon_sym_GT_GT_GT] = ACTIONS(4140),
    [anon_sym_EQ_EQ] = ACTIONS(4140),
    [anon_sym_BANG_EQ] = ACTIONS(4140),
    [anon_sym_GT_EQ] = ACTIONS(4140),
    [anon_sym_LT_EQ] = ACTIONS(4140),
    [anon_sym_DOT] = ACTIONS(4138),
    [anon_sym_scoped] = ACTIONS(4138),
    [anon_sym_EQ_GT] = ACTIONS(4140),
    [anon_sym_var] = ACTIONS(4138),
    [anon_sym_yield] = ACTIONS(4138),
    [anon_sym_switch] = ACTIONS(4138),
    [anon_sym_when] = ACTIONS(4138),
    [sym_discard] = ACTIONS(4138),
    [anon_sym_DOT_DOT] = ACTIONS(4140),
    [anon_sym_and] = ACTIONS(4138),
    [anon_sym_or] = ACTIONS(4138),
    [anon_sym_AMP_AMP] = ACTIONS(4140),
    [anon_sym_PIPE_PIPE] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK] = ACTIONS(4140),
    [anon_sym_from] = ACTIONS(4138),
    [anon_sym_into] = ACTIONS(4138),
    [anon_sym_join] = ACTIONS(4138),
    [anon_sym_on] = ACTIONS(4138),
    [anon_sym_equals] = ACTIONS(4138),
    [anon_sym_let] = ACTIONS(4138),
    [anon_sym_orderby] = ACTIONS(4138),
    [anon_sym_ascending] = ACTIONS(4138),
    [anon_sym_descending] = ACTIONS(4138),
    [anon_sym_group] = ACTIONS(4138),
    [anon_sym_by] = ACTIONS(4138),
    [anon_sym_select] = ACTIONS(4138),
    [anon_sym_as] = ACTIONS(4138),
    [anon_sym_is] = ACTIONS(4138),
    [anon_sym_DASH_GT] = ACTIONS(4140),
    [anon_sym_with] = ACTIONS(4138),
    [aux_sym_preproc_if_token3] = ACTIONS(4140),
    [aux_sym_preproc_else_token1] = ACTIONS(4140),
    [aux_sym_preproc_elif_token1] = ACTIONS(4140),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2945] = {
    [sym_preproc_region] = STATE(2945),
    [sym_preproc_endregion] = STATE(2945),
    [sym_preproc_line] = STATE(2945),
    [sym_preproc_pragma] = STATE(2945),
    [sym_preproc_nullable] = STATE(2945),
    [sym_preproc_error] = STATE(2945),
    [sym_preproc_warning] = STATE(2945),
    [sym_preproc_define] = STATE(2945),
    [sym_preproc_undef] = STATE(2945),
    [sym__identifier_token] = ACTIONS(4130),
    [anon_sym_alias] = ACTIONS(4130),
    [anon_sym_SEMI] = ACTIONS(4132),
    [anon_sym_global] = ACTIONS(4130),
    [anon_sym_LBRACK] = ACTIONS(4132),
    [anon_sym_COLON] = ACTIONS(4132),
    [anon_sym_COMMA] = ACTIONS(4132),
    [anon_sym_RBRACK] = ACTIONS(4132),
    [anon_sym_LPAREN] = ACTIONS(4132),
    [anon_sym_RPAREN] = ACTIONS(4132),
    [anon_sym_LBRACE] = ACTIONS(4132),
    [anon_sym_RBRACE] = ACTIONS(4132),
    [anon_sym_file] = ACTIONS(4130),
    [anon_sym_LT] = ACTIONS(4130),
    [anon_sym_GT] = ACTIONS(4130),
    [anon_sym_in] = ACTIONS(4130),
    [anon_sym_where] = ACTIONS(4130),
    [anon_sym_QMARK] = ACTIONS(4130),
    [anon_sym_notnull] = ACTIONS(4130),
    [anon_sym_unmanaged] = ACTIONS(4130),
    [anon_sym_BANG] = ACTIONS(4130),
    [anon_sym_PLUS_PLUS] = ACTIONS(4132),
    [anon_sym_DASH_DASH] = ACTIONS(4132),
    [anon_sym_PLUS] = ACTIONS(4130),
    [anon_sym_DASH] = ACTIONS(4130),
    [anon_sym_STAR] = ACTIONS(4132),
    [anon_sym_SLASH] = ACTIONS(4130),
    [anon_sym_PERCENT] = ACTIONS(4132),
    [anon_sym_CARET] = ACTIONS(4132),
    [anon_sym_PIPE] = ACTIONS(4130),
    [anon_sym_AMP] = ACTIONS(4130),
    [anon_sym_LT_LT] = ACTIONS(4132),
    [anon_sym_GT_GT] = ACTIONS(4130),
    [anon_sym_GT_GT_GT] = ACTIONS(4132),
    [anon_sym_EQ_EQ] = ACTIONS(4132),
    [anon_sym_BANG_EQ] = ACTIONS(4132),
    [anon_sym_GT_EQ] = ACTIONS(4132),
    [anon_sym_LT_EQ] = ACTIONS(4132),
    [anon_sym_DOT] = ACTIONS(4130),
    [anon_sym_scoped] = ACTIONS(4130),
    [anon_sym_EQ_GT] = ACTIONS(4132),
    [anon_sym_var] = ACTIONS(4130),
    [anon_sym_yield] = ACTIONS(4130),
    [anon_sym_switch] = ACTIONS(4130),
    [anon_sym_when] = ACTIONS(4130),
    [sym_discard] = ACTIONS(4130),
    [anon_sym_DOT_DOT] = ACTIONS(4132),
    [anon_sym_and] = ACTIONS(4130),
    [anon_sym_or] = ACTIONS(4130),
    [anon_sym_AMP_AMP] = ACTIONS(4132),
    [anon_sym_PIPE_PIPE] = ACTIONS(4132),
    [anon_sym_QMARK_QMARK] = ACTIONS(4132),
    [anon_sym_from] = ACTIONS(4130),
    [anon_sym_into] = ACTIONS(4130),
    [anon_sym_join] = ACTIONS(4130),
    [anon_sym_on] = ACTIONS(4130),
    [anon_sym_equals] = ACTIONS(4130),
    [anon_sym_let] = ACTIONS(4130),
    [anon_sym_orderby] = ACTIONS(4130),
    [anon_sym_ascending] = ACTIONS(4130),
    [anon_sym_descending] = ACTIONS(4130),
    [anon_sym_group] = ACTIONS(4130),
    [anon_sym_by] = ACTIONS(4130),
    [anon_sym_select] = ACTIONS(4130),
    [anon_sym_as] = ACTIONS(4130),
    [anon_sym_is] = ACTIONS(4130),
    [anon_sym_DASH_GT] = ACTIONS(4132),
    [anon_sym_with] = ACTIONS(4130),
    [aux_sym_preproc_if_token3] = ACTIONS(4132),
    [aux_sym_preproc_else_token1] = ACTIONS(4132),
    [aux_sym_preproc_elif_token1] = ACTIONS(4132),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2946] = {
    [sym__name] = STATE(6206),
    [sym_alias_qualified_name] = STATE(4085),
    [sym__simple_name] = STATE(4085),
    [sym_qualified_name] = STATE(4085),
    [sym_generic_name] = STATE(3959),
    [sym_ref_type] = STATE(3971),
    [sym__scoped_base_type] = STATE(3973),
    [sym_identifier] = STATE(5502),
    [sym__reserved_identifier] = STATE(3911),
    [sym_preproc_region] = STATE(2946),
    [sym_preproc_endregion] = STATE(2946),
    [sym_preproc_line] = STATE(2946),
    [sym_preproc_pragma] = STATE(2946),
    [sym_preproc_nullable] = STATE(2946),
    [sym_preproc_error] = STATE(2946),
    [sym_preproc_warning] = STATE(2946),
    [sym_preproc_define] = STATE(2946),
    [sym_preproc_undef] = STATE(2946),
    [sym__identifier_token] = ACTIONS(4248),
    [anon_sym_alias] = ACTIONS(4250),
    [anon_sym_global] = ACTIONS(4250),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_LPAREN] = ACTIONS(3993),
    [anon_sym_ref] = ACTIONS(4542),
    [anon_sym_LBRACE] = ACTIONS(3993),
    [anon_sym_file] = ACTIONS(4250),
    [anon_sym_LT] = ACTIONS(3995),
    [anon_sym_GT] = ACTIONS(3995),
    [anon_sym_in] = ACTIONS(3995),
    [anon_sym_where] = ACTIONS(4250),
    [anon_sym_QMARK] = ACTIONS(3995),
    [anon_sym_notnull] = ACTIONS(4250),
    [anon_sym_unmanaged] = ACTIONS(4250),
    [anon_sym_BANG] = ACTIONS(3995),
    [anon_sym_PLUS_PLUS] = ACTIONS(3993),
    [anon_sym_DASH_DASH] = ACTIONS(3993),
    [anon_sym_PLUS] = ACTIONS(3995),
    [anon_sym_DASH] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3993),
    [anon_sym_SLASH] = ACTIONS(3995),
    [anon_sym_PERCENT] = ACTIONS(3993),
    [anon_sym_CARET] = ACTIONS(3993),
    [anon_sym_PIPE] = ACTIONS(3995),
    [anon_sym_AMP] = ACTIONS(3995),
    [anon_sym_LT_LT] = ACTIONS(3993),
    [anon_sym_GT_GT] = ACTIONS(3995),
    [anon_sym_GT_GT_GT] = ACTIONS(3993),
    [anon_sym_EQ_EQ] = ACTIONS(3993),
    [anon_sym_BANG_EQ] = ACTIONS(3993),
    [anon_sym_GT_EQ] = ACTIONS(3993),
    [anon_sym_LT_EQ] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3995),
    [anon_sym_scoped] = ACTIONS(4250),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(4250),
    [anon_sym_yield] = ACTIONS(4250),
    [anon_sym_switch] = ACTIONS(3995),
    [anon_sym_when] = ACTIONS(4250),
    [anon_sym_DOT_DOT] = ACTIONS(3993),
    [anon_sym_and] = ACTIONS(3995),
    [anon_sym_or] = ACTIONS(3995),
    [anon_sym_AMP_AMP] = ACTIONS(3993),
    [anon_sym_PIPE_PIPE] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK] = ACTIONS(3993),
    [anon_sym_from] = ACTIONS(4250),
    [anon_sym_into] = ACTIONS(4250),
    [anon_sym_join] = ACTIONS(4250),
    [anon_sym_on] = ACTIONS(4250),
    [anon_sym_equals] = ACTIONS(4250),
    [anon_sym_let] = ACTIONS(4250),
    [anon_sym_orderby] = ACTIONS(4250),
    [anon_sym_ascending] = ACTIONS(4250),
    [anon_sym_descending] = ACTIONS(4250),
    [anon_sym_group] = ACTIONS(4250),
    [anon_sym_by] = ACTIONS(4250),
    [anon_sym_select] = ACTIONS(4250),
    [anon_sym_as] = ACTIONS(3995),
    [anon_sym_is] = ACTIONS(3995),
    [anon_sym_DASH_GT] = ACTIONS(3993),
    [anon_sym_with] = ACTIONS(3995),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2947] = {
    [sym_preproc_region] = STATE(2947),
    [sym_preproc_endregion] = STATE(2947),
    [sym_preproc_line] = STATE(2947),
    [sym_preproc_pragma] = STATE(2947),
    [sym_preproc_nullable] = STATE(2947),
    [sym_preproc_error] = STATE(2947),
    [sym_preproc_warning] = STATE(2947),
    [sym_preproc_define] = STATE(2947),
    [sym_preproc_undef] = STATE(2947),
    [sym__identifier_token] = ACTIONS(4544),
    [anon_sym_alias] = ACTIONS(4544),
    [anon_sym_SEMI] = ACTIONS(4546),
    [anon_sym_global] = ACTIONS(4544),
    [anon_sym_LBRACK] = ACTIONS(4546),
    [anon_sym_COLON] = ACTIONS(4546),
    [anon_sym_COMMA] = ACTIONS(4546),
    [anon_sym_RBRACK] = ACTIONS(4546),
    [anon_sym_LPAREN] = ACTIONS(4546),
    [anon_sym_RPAREN] = ACTIONS(4546),
    [anon_sym_LBRACE] = ACTIONS(4546),
    [anon_sym_RBRACE] = ACTIONS(4546),
    [anon_sym_file] = ACTIONS(4544),
    [anon_sym_LT] = ACTIONS(4544),
    [anon_sym_GT] = ACTIONS(4544),
    [anon_sym_in] = ACTIONS(4544),
    [anon_sym_where] = ACTIONS(4544),
    [anon_sym_QMARK] = ACTIONS(4544),
    [anon_sym_notnull] = ACTIONS(4544),
    [anon_sym_unmanaged] = ACTIONS(4544),
    [anon_sym_BANG] = ACTIONS(4544),
    [anon_sym_PLUS_PLUS] = ACTIONS(4546),
    [anon_sym_DASH_DASH] = ACTIONS(4546),
    [anon_sym_PLUS] = ACTIONS(4544),
    [anon_sym_DASH] = ACTIONS(4544),
    [anon_sym_STAR] = ACTIONS(4546),
    [anon_sym_SLASH] = ACTIONS(4544),
    [anon_sym_PERCENT] = ACTIONS(4546),
    [anon_sym_CARET] = ACTIONS(4546),
    [anon_sym_PIPE] = ACTIONS(4544),
    [anon_sym_AMP] = ACTIONS(4544),
    [anon_sym_LT_LT] = ACTIONS(4546),
    [anon_sym_GT_GT] = ACTIONS(4544),
    [anon_sym_GT_GT_GT] = ACTIONS(4546),
    [anon_sym_EQ_EQ] = ACTIONS(4546),
    [anon_sym_BANG_EQ] = ACTIONS(4546),
    [anon_sym_GT_EQ] = ACTIONS(4546),
    [anon_sym_LT_EQ] = ACTIONS(4546),
    [anon_sym_DOT] = ACTIONS(4544),
    [anon_sym_scoped] = ACTIONS(4544),
    [anon_sym_EQ_GT] = ACTIONS(4546),
    [anon_sym_var] = ACTIONS(4544),
    [anon_sym_yield] = ACTIONS(4544),
    [anon_sym_switch] = ACTIONS(4544),
    [anon_sym_when] = ACTIONS(4544),
    [sym_discard] = ACTIONS(4544),
    [anon_sym_DOT_DOT] = ACTIONS(4546),
    [anon_sym_and] = ACTIONS(4544),
    [anon_sym_or] = ACTIONS(4544),
    [anon_sym_AMP_AMP] = ACTIONS(4546),
    [anon_sym_PIPE_PIPE] = ACTIONS(4546),
    [anon_sym_QMARK_QMARK] = ACTIONS(4546),
    [anon_sym_from] = ACTIONS(4544),
    [anon_sym_into] = ACTIONS(4544),
    [anon_sym_join] = ACTIONS(4544),
    [anon_sym_on] = ACTIONS(4544),
    [anon_sym_equals] = ACTIONS(4544),
    [anon_sym_let] = ACTIONS(4544),
    [anon_sym_orderby] = ACTIONS(4544),
    [anon_sym_ascending] = ACTIONS(4544),
    [anon_sym_descending] = ACTIONS(4544),
    [anon_sym_group] = ACTIONS(4544),
    [anon_sym_by] = ACTIONS(4544),
    [anon_sym_select] = ACTIONS(4544),
    [anon_sym_as] = ACTIONS(4544),
    [anon_sym_is] = ACTIONS(4544),
    [anon_sym_DASH_GT] = ACTIONS(4546),
    [anon_sym_with] = ACTIONS(4544),
    [aux_sym_preproc_if_token3] = ACTIONS(4546),
    [aux_sym_preproc_else_token1] = ACTIONS(4546),
    [aux_sym_preproc_elif_token1] = ACTIONS(4546),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2948] = {
    [sym_preproc_region] = STATE(2948),
    [sym_preproc_endregion] = STATE(2948),
    [sym_preproc_line] = STATE(2948),
    [sym_preproc_pragma] = STATE(2948),
    [sym_preproc_nullable] = STATE(2948),
    [sym_preproc_error] = STATE(2948),
    [sym_preproc_warning] = STATE(2948),
    [sym_preproc_define] = STATE(2948),
    [sym_preproc_undef] = STATE(2948),
    [sym__identifier_token] = ACTIONS(4548),
    [anon_sym_alias] = ACTIONS(4548),
    [anon_sym_SEMI] = ACTIONS(4550),
    [anon_sym_global] = ACTIONS(4548),
    [anon_sym_LBRACK] = ACTIONS(4550),
    [anon_sym_COLON] = ACTIONS(4550),
    [anon_sym_COMMA] = ACTIONS(4550),
    [anon_sym_RBRACK] = ACTIONS(4550),
    [anon_sym_LPAREN] = ACTIONS(4550),
    [anon_sym_RPAREN] = ACTIONS(4550),
    [anon_sym_LBRACE] = ACTIONS(4550),
    [anon_sym_RBRACE] = ACTIONS(4550),
    [anon_sym_file] = ACTIONS(4548),
    [anon_sym_LT] = ACTIONS(4548),
    [anon_sym_GT] = ACTIONS(4548),
    [anon_sym_in] = ACTIONS(4548),
    [anon_sym_where] = ACTIONS(4548),
    [anon_sym_QMARK] = ACTIONS(4548),
    [anon_sym_notnull] = ACTIONS(4548),
    [anon_sym_unmanaged] = ACTIONS(4548),
    [anon_sym_BANG] = ACTIONS(4548),
    [anon_sym_PLUS_PLUS] = ACTIONS(4550),
    [anon_sym_DASH_DASH] = ACTIONS(4550),
    [anon_sym_PLUS] = ACTIONS(4548),
    [anon_sym_DASH] = ACTIONS(4548),
    [anon_sym_STAR] = ACTIONS(4550),
    [anon_sym_SLASH] = ACTIONS(4548),
    [anon_sym_PERCENT] = ACTIONS(4550),
    [anon_sym_CARET] = ACTIONS(4550),
    [anon_sym_PIPE] = ACTIONS(4548),
    [anon_sym_AMP] = ACTIONS(4548),
    [anon_sym_LT_LT] = ACTIONS(4550),
    [anon_sym_GT_GT] = ACTIONS(4548),
    [anon_sym_GT_GT_GT] = ACTIONS(4550),
    [anon_sym_EQ_EQ] = ACTIONS(4550),
    [anon_sym_BANG_EQ] = ACTIONS(4550),
    [anon_sym_GT_EQ] = ACTIONS(4550),
    [anon_sym_LT_EQ] = ACTIONS(4550),
    [anon_sym_DOT] = ACTIONS(4548),
    [anon_sym_scoped] = ACTIONS(4548),
    [anon_sym_EQ_GT] = ACTIONS(4550),
    [anon_sym_var] = ACTIONS(4548),
    [anon_sym_yield] = ACTIONS(4548),
    [anon_sym_switch] = ACTIONS(4548),
    [anon_sym_when] = ACTIONS(4548),
    [sym_discard] = ACTIONS(4548),
    [anon_sym_DOT_DOT] = ACTIONS(4550),
    [anon_sym_and] = ACTIONS(4548),
    [anon_sym_or] = ACTIONS(4548),
    [anon_sym_AMP_AMP] = ACTIONS(4550),
    [anon_sym_PIPE_PIPE] = ACTIONS(4550),
    [anon_sym_QMARK_QMARK] = ACTIONS(4550),
    [anon_sym_from] = ACTIONS(4548),
    [anon_sym_into] = ACTIONS(4548),
    [anon_sym_join] = ACTIONS(4548),
    [anon_sym_on] = ACTIONS(4548),
    [anon_sym_equals] = ACTIONS(4548),
    [anon_sym_let] = ACTIONS(4548),
    [anon_sym_orderby] = ACTIONS(4548),
    [anon_sym_ascending] = ACTIONS(4548),
    [anon_sym_descending] = ACTIONS(4548),
    [anon_sym_group] = ACTIONS(4548),
    [anon_sym_by] = ACTIONS(4548),
    [anon_sym_select] = ACTIONS(4548),
    [anon_sym_as] = ACTIONS(4548),
    [anon_sym_is] = ACTIONS(4548),
    [anon_sym_DASH_GT] = ACTIONS(4550),
    [anon_sym_with] = ACTIONS(4548),
    [aux_sym_preproc_if_token3] = ACTIONS(4550),
    [aux_sym_preproc_else_token1] = ACTIONS(4550),
    [aux_sym_preproc_elif_token1] = ACTIONS(4550),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2949] = {
    [sym_preproc_region] = STATE(2949),
    [sym_preproc_endregion] = STATE(2949),
    [sym_preproc_line] = STATE(2949),
    [sym_preproc_pragma] = STATE(2949),
    [sym_preproc_nullable] = STATE(2949),
    [sym_preproc_error] = STATE(2949),
    [sym_preproc_warning] = STATE(2949),
    [sym_preproc_define] = STATE(2949),
    [sym_preproc_undef] = STATE(2949),
    [sym__identifier_token] = ACTIONS(4179),
    [anon_sym_alias] = ACTIONS(4179),
    [anon_sym_global] = ACTIONS(4179),
    [anon_sym_EQ] = ACTIONS(4183),
    [anon_sym_LBRACK] = ACTIONS(4185),
    [anon_sym_LPAREN] = ACTIONS(4185),
    [anon_sym_file] = ACTIONS(4179),
    [anon_sym_LT] = ACTIONS(4183),
    [anon_sym_GT] = ACTIONS(4183),
    [anon_sym_where] = ACTIONS(4188),
    [anon_sym_QMARK] = ACTIONS(4188),
    [anon_sym_notnull] = ACTIONS(4179),
    [anon_sym_unmanaged] = ACTIONS(4179),
    [anon_sym_BANG] = ACTIONS(4183),
    [anon_sym_PLUS_PLUS] = ACTIONS(4191),
    [anon_sym_DASH_DASH] = ACTIONS(4191),
    [anon_sym_PLUS] = ACTIONS(4183),
    [anon_sym_DASH] = ACTIONS(4183),
    [anon_sym_STAR] = ACTIONS(4188),
    [anon_sym_SLASH] = ACTIONS(4183),
    [anon_sym_PERCENT] = ACTIONS(4183),
    [anon_sym_CARET] = ACTIONS(4183),
    [anon_sym_PIPE] = ACTIONS(4183),
    [anon_sym_AMP] = ACTIONS(4183),
    [anon_sym_LT_LT] = ACTIONS(4183),
    [anon_sym_GT_GT] = ACTIONS(4183),
    [anon_sym_GT_GT_GT] = ACTIONS(4183),
    [anon_sym_EQ_EQ] = ACTIONS(4191),
    [anon_sym_BANG_EQ] = ACTIONS(4191),
    [anon_sym_GT_EQ] = ACTIONS(4191),
    [anon_sym_LT_EQ] = ACTIONS(4191),
    [anon_sym_DOT] = ACTIONS(4188),
    [anon_sym_scoped] = ACTIONS(4179),
    [anon_sym_var] = ACTIONS(4179),
    [anon_sym_yield] = ACTIONS(4179),
    [anon_sym_switch] = ACTIONS(4183),
    [anon_sym_when] = ACTIONS(4179),
    [anon_sym_DOT_DOT] = ACTIONS(4191),
    [anon_sym_and] = ACTIONS(4183),
    [anon_sym_or] = ACTIONS(4183),
    [anon_sym_PLUS_EQ] = ACTIONS(4191),
    [anon_sym_DASH_EQ] = ACTIONS(4191),
    [anon_sym_STAR_EQ] = ACTIONS(4191),
    [anon_sym_SLASH_EQ] = ACTIONS(4191),
    [anon_sym_PERCENT_EQ] = ACTIONS(4191),
    [anon_sym_AMP_EQ] = ACTIONS(4191),
    [anon_sym_CARET_EQ] = ACTIONS(4191),
    [anon_sym_PIPE_EQ] = ACTIONS(4191),
    [anon_sym_LT_LT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4191),
    [anon_sym_AMP_AMP] = ACTIONS(4191),
    [anon_sym_PIPE_PIPE] = ACTIONS(4191),
    [anon_sym_QMARK_QMARK] = ACTIONS(4183),
    [anon_sym_from] = ACTIONS(4188),
    [anon_sym_into] = ACTIONS(4179),
    [anon_sym_join] = ACTIONS(4188),
    [anon_sym_on] = ACTIONS(4179),
    [anon_sym_equals] = ACTIONS(4179),
    [anon_sym_let] = ACTIONS(4188),
    [anon_sym_orderby] = ACTIONS(4188),
    [anon_sym_ascending] = ACTIONS(4179),
    [anon_sym_descending] = ACTIONS(4179),
    [anon_sym_group] = ACTIONS(4188),
    [anon_sym_by] = ACTIONS(4179),
    [anon_sym_select] = ACTIONS(4188),
    [anon_sym_as] = ACTIONS(4183),
    [anon_sym_is] = ACTIONS(4183),
    [anon_sym_DASH_GT] = ACTIONS(4185),
    [anon_sym_with] = ACTIONS(4183),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2950] = {
    [sym_preproc_region] = STATE(2950),
    [sym_preproc_endregion] = STATE(2950),
    [sym_preproc_line] = STATE(2950),
    [sym_preproc_pragma] = STATE(2950),
    [sym_preproc_nullable] = STATE(2950),
    [sym_preproc_error] = STATE(2950),
    [sym_preproc_warning] = STATE(2950),
    [sym_preproc_define] = STATE(2950),
    [sym_preproc_undef] = STATE(2950),
    [sym__identifier_token] = ACTIONS(4157),
    [anon_sym_alias] = ACTIONS(4157),
    [anon_sym_global] = ACTIONS(4157),
    [anon_sym_EQ] = ACTIONS(4162),
    [anon_sym_LBRACK] = ACTIONS(4193),
    [anon_sym_LPAREN] = ACTIONS(4193),
    [anon_sym_file] = ACTIONS(4157),
    [anon_sym_LT] = ACTIONS(4162),
    [anon_sym_GT] = ACTIONS(4162),
    [anon_sym_where] = ACTIONS(4157),
    [anon_sym_QMARK] = ACTIONS(4196),
    [anon_sym_notnull] = ACTIONS(4157),
    [anon_sym_unmanaged] = ACTIONS(4157),
    [anon_sym_BANG] = ACTIONS(4162),
    [anon_sym_PLUS_PLUS] = ACTIONS(4177),
    [anon_sym_DASH_DASH] = ACTIONS(4177),
    [anon_sym_PLUS] = ACTIONS(4162),
    [anon_sym_DASH] = ACTIONS(4162),
    [anon_sym_STAR] = ACTIONS(4196),
    [anon_sym_SLASH] = ACTIONS(4162),
    [anon_sym_PERCENT] = ACTIONS(4162),
    [anon_sym_CARET] = ACTIONS(4162),
    [anon_sym_PIPE] = ACTIONS(4162),
    [anon_sym_AMP] = ACTIONS(4162),
    [anon_sym_LT_LT] = ACTIONS(4162),
    [anon_sym_GT_GT] = ACTIONS(4162),
    [anon_sym_GT_GT_GT] = ACTIONS(4162),
    [anon_sym_EQ_EQ] = ACTIONS(4177),
    [anon_sym_BANG_EQ] = ACTIONS(4177),
    [anon_sym_GT_EQ] = ACTIONS(4177),
    [anon_sym_LT_EQ] = ACTIONS(4177),
    [anon_sym_DOT] = ACTIONS(4196),
    [anon_sym_scoped] = ACTIONS(4157),
    [anon_sym_var] = ACTIONS(4157),
    [anon_sym_yield] = ACTIONS(4157),
    [anon_sym_switch] = ACTIONS(4162),
    [anon_sym_when] = ACTIONS(4157),
    [anon_sym_DOT_DOT] = ACTIONS(4177),
    [anon_sym_and] = ACTIONS(4162),
    [anon_sym_or] = ACTIONS(4162),
    [anon_sym_PLUS_EQ] = ACTIONS(4177),
    [anon_sym_DASH_EQ] = ACTIONS(4177),
    [anon_sym_STAR_EQ] = ACTIONS(4177),
    [anon_sym_SLASH_EQ] = ACTIONS(4177),
    [anon_sym_PERCENT_EQ] = ACTIONS(4177),
    [anon_sym_AMP_EQ] = ACTIONS(4177),
    [anon_sym_CARET_EQ] = ACTIONS(4177),
    [anon_sym_PIPE_EQ] = ACTIONS(4177),
    [anon_sym_LT_LT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4177),
    [anon_sym_AMP_AMP] = ACTIONS(4177),
    [anon_sym_PIPE_PIPE] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK] = ACTIONS(4162),
    [anon_sym_from] = ACTIONS(4157),
    [anon_sym_into] = ACTIONS(4196),
    [anon_sym_join] = ACTIONS(4157),
    [anon_sym_on] = ACTIONS(4196),
    [anon_sym_equals] = ACTIONS(4157),
    [anon_sym_let] = ACTIONS(4157),
    [anon_sym_orderby] = ACTIONS(4157),
    [anon_sym_ascending] = ACTIONS(4157),
    [anon_sym_descending] = ACTIONS(4157),
    [anon_sym_group] = ACTIONS(4157),
    [anon_sym_by] = ACTIONS(4157),
    [anon_sym_select] = ACTIONS(4157),
    [anon_sym_as] = ACTIONS(4162),
    [anon_sym_is] = ACTIONS(4162),
    [anon_sym_DASH_GT] = ACTIONS(4193),
    [anon_sym_with] = ACTIONS(4162),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2951] = {
    [sym_preproc_region] = STATE(2951),
    [sym_preproc_endregion] = STATE(2951),
    [sym_preproc_line] = STATE(2951),
    [sym_preproc_pragma] = STATE(2951),
    [sym_preproc_nullable] = STATE(2951),
    [sym_preproc_error] = STATE(2951),
    [sym_preproc_warning] = STATE(2951),
    [sym_preproc_define] = STATE(2951),
    [sym_preproc_undef] = STATE(2951),
    [sym__identifier_token] = ACTIONS(4179),
    [anon_sym_alias] = ACTIONS(4179),
    [anon_sym_global] = ACTIONS(4179),
    [anon_sym_EQ] = ACTIONS(4183),
    [anon_sym_LBRACK] = ACTIONS(4185),
    [anon_sym_LPAREN] = ACTIONS(4185),
    [anon_sym_file] = ACTIONS(4179),
    [anon_sym_LT] = ACTIONS(4183),
    [anon_sym_GT] = ACTIONS(4183),
    [anon_sym_where] = ACTIONS(4179),
    [anon_sym_QMARK] = ACTIONS(4188),
    [anon_sym_notnull] = ACTIONS(4179),
    [anon_sym_unmanaged] = ACTIONS(4179),
    [anon_sym_BANG] = ACTIONS(4183),
    [anon_sym_PLUS_PLUS] = ACTIONS(4191),
    [anon_sym_DASH_DASH] = ACTIONS(4191),
    [anon_sym_PLUS] = ACTIONS(4183),
    [anon_sym_DASH] = ACTIONS(4183),
    [anon_sym_STAR] = ACTIONS(4188),
    [anon_sym_SLASH] = ACTIONS(4183),
    [anon_sym_PERCENT] = ACTIONS(4183),
    [anon_sym_CARET] = ACTIONS(4183),
    [anon_sym_PIPE] = ACTIONS(4183),
    [anon_sym_AMP] = ACTIONS(4183),
    [anon_sym_LT_LT] = ACTIONS(4183),
    [anon_sym_GT_GT] = ACTIONS(4183),
    [anon_sym_GT_GT_GT] = ACTIONS(4183),
    [anon_sym_EQ_EQ] = ACTIONS(4191),
    [anon_sym_BANG_EQ] = ACTIONS(4191),
    [anon_sym_GT_EQ] = ACTIONS(4191),
    [anon_sym_LT_EQ] = ACTIONS(4191),
    [anon_sym_DOT] = ACTIONS(4188),
    [anon_sym_scoped] = ACTIONS(4179),
    [anon_sym_var] = ACTIONS(4179),
    [anon_sym_yield] = ACTIONS(4179),
    [anon_sym_switch] = ACTIONS(4183),
    [anon_sym_when] = ACTIONS(4179),
    [anon_sym_DOT_DOT] = ACTIONS(4191),
    [anon_sym_and] = ACTIONS(4183),
    [anon_sym_or] = ACTIONS(4183),
    [anon_sym_PLUS_EQ] = ACTIONS(4191),
    [anon_sym_DASH_EQ] = ACTIONS(4191),
    [anon_sym_STAR_EQ] = ACTIONS(4191),
    [anon_sym_SLASH_EQ] = ACTIONS(4191),
    [anon_sym_PERCENT_EQ] = ACTIONS(4191),
    [anon_sym_AMP_EQ] = ACTIONS(4191),
    [anon_sym_CARET_EQ] = ACTIONS(4191),
    [anon_sym_PIPE_EQ] = ACTIONS(4191),
    [anon_sym_LT_LT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4191),
    [anon_sym_AMP_AMP] = ACTIONS(4191),
    [anon_sym_PIPE_PIPE] = ACTIONS(4191),
    [anon_sym_QMARK_QMARK] = ACTIONS(4183),
    [anon_sym_from] = ACTIONS(4179),
    [anon_sym_into] = ACTIONS(4188),
    [anon_sym_join] = ACTIONS(4179),
    [anon_sym_on] = ACTIONS(4179),
    [anon_sym_equals] = ACTIONS(4179),
    [anon_sym_let] = ACTIONS(4179),
    [anon_sym_orderby] = ACTIONS(4179),
    [anon_sym_ascending] = ACTIONS(4179),
    [anon_sym_descending] = ACTIONS(4179),
    [anon_sym_group] = ACTIONS(4179),
    [anon_sym_by] = ACTIONS(4188),
    [anon_sym_select] = ACTIONS(4179),
    [anon_sym_as] = ACTIONS(4183),
    [anon_sym_is] = ACTIONS(4183),
    [anon_sym_DASH_GT] = ACTIONS(4185),
    [anon_sym_with] = ACTIONS(4183),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2952] = {
    [sym_preproc_region] = STATE(2952),
    [sym_preproc_endregion] = STATE(2952),
    [sym_preproc_line] = STATE(2952),
    [sym_preproc_pragma] = STATE(2952),
    [sym_preproc_nullable] = STATE(2952),
    [sym_preproc_error] = STATE(2952),
    [sym_preproc_warning] = STATE(2952),
    [sym_preproc_define] = STATE(2952),
    [sym_preproc_undef] = STATE(2952),
    [sym__identifier_token] = ACTIONS(4552),
    [anon_sym_alias] = ACTIONS(4552),
    [anon_sym_SEMI] = ACTIONS(4554),
    [anon_sym_global] = ACTIONS(4552),
    [anon_sym_LBRACK] = ACTIONS(4554),
    [anon_sym_COLON] = ACTIONS(4554),
    [anon_sym_COMMA] = ACTIONS(4554),
    [anon_sym_RBRACK] = ACTIONS(4554),
    [anon_sym_LPAREN] = ACTIONS(4554),
    [anon_sym_RPAREN] = ACTIONS(4554),
    [anon_sym_LBRACE] = ACTIONS(4554),
    [anon_sym_RBRACE] = ACTIONS(4554),
    [anon_sym_file] = ACTIONS(4552),
    [anon_sym_LT] = ACTIONS(4552),
    [anon_sym_GT] = ACTIONS(4552),
    [anon_sym_in] = ACTIONS(4552),
    [anon_sym_where] = ACTIONS(4552),
    [anon_sym_QMARK] = ACTIONS(4552),
    [anon_sym_notnull] = ACTIONS(4552),
    [anon_sym_unmanaged] = ACTIONS(4552),
    [anon_sym_BANG] = ACTIONS(4552),
    [anon_sym_PLUS_PLUS] = ACTIONS(4554),
    [anon_sym_DASH_DASH] = ACTIONS(4554),
    [anon_sym_PLUS] = ACTIONS(4552),
    [anon_sym_DASH] = ACTIONS(4552),
    [anon_sym_STAR] = ACTIONS(4554),
    [anon_sym_SLASH] = ACTIONS(4552),
    [anon_sym_PERCENT] = ACTIONS(4554),
    [anon_sym_CARET] = ACTIONS(4554),
    [anon_sym_PIPE] = ACTIONS(4552),
    [anon_sym_AMP] = ACTIONS(4552),
    [anon_sym_LT_LT] = ACTIONS(4554),
    [anon_sym_GT_GT] = ACTIONS(4552),
    [anon_sym_GT_GT_GT] = ACTIONS(4554),
    [anon_sym_EQ_EQ] = ACTIONS(4554),
    [anon_sym_BANG_EQ] = ACTIONS(4554),
    [anon_sym_GT_EQ] = ACTIONS(4554),
    [anon_sym_LT_EQ] = ACTIONS(4554),
    [anon_sym_DOT] = ACTIONS(4552),
    [anon_sym_scoped] = ACTIONS(4552),
    [anon_sym_EQ_GT] = ACTIONS(4554),
    [anon_sym_var] = ACTIONS(4552),
    [anon_sym_yield] = ACTIONS(4552),
    [anon_sym_switch] = ACTIONS(4552),
    [anon_sym_when] = ACTIONS(4552),
    [sym_discard] = ACTIONS(4552),
    [anon_sym_DOT_DOT] = ACTIONS(4554),
    [anon_sym_and] = ACTIONS(4552),
    [anon_sym_or] = ACTIONS(4552),
    [anon_sym_AMP_AMP] = ACTIONS(4554),
    [anon_sym_PIPE_PIPE] = ACTIONS(4554),
    [anon_sym_QMARK_QMARK] = ACTIONS(4554),
    [anon_sym_from] = ACTIONS(4552),
    [anon_sym_into] = ACTIONS(4552),
    [anon_sym_join] = ACTIONS(4552),
    [anon_sym_on] = ACTIONS(4552),
    [anon_sym_equals] = ACTIONS(4552),
    [anon_sym_let] = ACTIONS(4552),
    [anon_sym_orderby] = ACTIONS(4552),
    [anon_sym_ascending] = ACTIONS(4552),
    [anon_sym_descending] = ACTIONS(4552),
    [anon_sym_group] = ACTIONS(4552),
    [anon_sym_by] = ACTIONS(4552),
    [anon_sym_select] = ACTIONS(4552),
    [anon_sym_as] = ACTIONS(4552),
    [anon_sym_is] = ACTIONS(4552),
    [anon_sym_DASH_GT] = ACTIONS(4554),
    [anon_sym_with] = ACTIONS(4552),
    [aux_sym_preproc_if_token3] = ACTIONS(4554),
    [aux_sym_preproc_else_token1] = ACTIONS(4554),
    [aux_sym_preproc_elif_token1] = ACTIONS(4554),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2953] = {
    [sym_type_argument_list] = STATE(3005),
    [sym_preproc_region] = STATE(2953),
    [sym_preproc_endregion] = STATE(2953),
    [sym_preproc_line] = STATE(2953),
    [sym_preproc_pragma] = STATE(2953),
    [sym_preproc_nullable] = STATE(2953),
    [sym_preproc_error] = STATE(2953),
    [sym_preproc_warning] = STATE(2953),
    [sym_preproc_define] = STATE(2953),
    [sym_preproc_undef] = STATE(2953),
    [anon_sym_SEMI] = ACTIONS(4140),
    [anon_sym_EQ] = ACTIONS(4138),
    [anon_sym_LBRACK] = ACTIONS(4140),
    [anon_sym_COLON] = ACTIONS(4140),
    [anon_sym_COMMA] = ACTIONS(4140),
    [anon_sym_RBRACK] = ACTIONS(4140),
    [anon_sym_LPAREN] = ACTIONS(4140),
    [anon_sym_RPAREN] = ACTIONS(4140),
    [anon_sym_RBRACE] = ACTIONS(4140),
    [anon_sym_LT] = ACTIONS(4556),
    [anon_sym_GT] = ACTIONS(4138),
    [anon_sym_in] = ACTIONS(4138),
    [anon_sym_where] = ACTIONS(4140),
    [anon_sym_QMARK] = ACTIONS(4138),
    [anon_sym_BANG] = ACTIONS(4138),
    [anon_sym_PLUS_PLUS] = ACTIONS(4140),
    [anon_sym_DASH_DASH] = ACTIONS(4140),
    [anon_sym_PLUS] = ACTIONS(4138),
    [anon_sym_DASH] = ACTIONS(4138),
    [anon_sym_STAR] = ACTIONS(4138),
    [anon_sym_SLASH] = ACTIONS(4138),
    [anon_sym_PERCENT] = ACTIONS(4138),
    [anon_sym_CARET] = ACTIONS(4138),
    [anon_sym_PIPE] = ACTIONS(4138),
    [anon_sym_AMP] = ACTIONS(4138),
    [anon_sym_LT_LT] = ACTIONS(4138),
    [anon_sym_GT_GT] = ACTIONS(4138),
    [anon_sym_GT_GT_GT] = ACTIONS(4138),
    [anon_sym_EQ_EQ] = ACTIONS(4140),
    [anon_sym_BANG_EQ] = ACTIONS(4140),
    [anon_sym_GT_EQ] = ACTIONS(4140),
    [anon_sym_LT_EQ] = ACTIONS(4140),
    [anon_sym_DOT] = ACTIONS(4138),
    [anon_sym_EQ_GT] = ACTIONS(4140),
    [anon_sym_switch] = ACTIONS(4140),
    [anon_sym_DOT_DOT] = ACTIONS(4140),
    [anon_sym_and] = ACTIONS(4140),
    [anon_sym_or] = ACTIONS(4138),
    [anon_sym_PLUS_EQ] = ACTIONS(4140),
    [anon_sym_DASH_EQ] = ACTIONS(4140),
    [anon_sym_STAR_EQ] = ACTIONS(4140),
    [anon_sym_SLASH_EQ] = ACTIONS(4140),
    [anon_sym_PERCENT_EQ] = ACTIONS(4140),
    [anon_sym_AMP_EQ] = ACTIONS(4140),
    [anon_sym_CARET_EQ] = ACTIONS(4140),
    [anon_sym_PIPE_EQ] = ACTIONS(4140),
    [anon_sym_LT_LT_EQ] = ACTIONS(4140),
    [anon_sym_GT_GT_EQ] = ACTIONS(4140),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4140),
    [anon_sym_AMP_AMP] = ACTIONS(4140),
    [anon_sym_PIPE_PIPE] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK] = ACTIONS(4138),
    [anon_sym_from] = ACTIONS(4140),
    [anon_sym_into] = ACTIONS(4140),
    [anon_sym_join] = ACTIONS(4140),
    [anon_sym_on] = ACTIONS(4140),
    [anon_sym_equals] = ACTIONS(4140),
    [anon_sym_let] = ACTIONS(4140),
    [anon_sym_orderby] = ACTIONS(4140),
    [anon_sym_group] = ACTIONS(4140),
    [anon_sym_by] = ACTIONS(4140),
    [anon_sym_select] = ACTIONS(4140),
    [anon_sym_as] = ACTIONS(4140),
    [anon_sym_is] = ACTIONS(4140),
    [anon_sym_DASH_GT] = ACTIONS(4140),
    [anon_sym_with] = ACTIONS(4140),
    [aux_sym_preproc_if_token3] = ACTIONS(4140),
    [aux_sym_preproc_else_token1] = ACTIONS(4140),
    [aux_sym_preproc_elif_token1] = ACTIONS(4140),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2954] = {
    [sym_preproc_region] = STATE(2954),
    [sym_preproc_endregion] = STATE(2954),
    [sym_preproc_line] = STATE(2954),
    [sym_preproc_pragma] = STATE(2954),
    [sym_preproc_nullable] = STATE(2954),
    [sym_preproc_error] = STATE(2954),
    [sym_preproc_warning] = STATE(2954),
    [sym_preproc_define] = STATE(2954),
    [sym_preproc_undef] = STATE(2954),
    [sym__identifier_token] = ACTIONS(4179),
    [anon_sym_alias] = ACTIONS(4179),
    [anon_sym_global] = ACTIONS(4179),
    [anon_sym_EQ] = ACTIONS(4183),
    [anon_sym_LBRACK] = ACTIONS(4185),
    [anon_sym_LPAREN] = ACTIONS(4185),
    [anon_sym_file] = ACTIONS(4179),
    [anon_sym_LT] = ACTIONS(4183),
    [anon_sym_GT] = ACTIONS(4183),
    [anon_sym_where] = ACTIONS(4179),
    [anon_sym_QMARK] = ACTIONS(4188),
    [anon_sym_notnull] = ACTIONS(4179),
    [anon_sym_unmanaged] = ACTIONS(4179),
    [anon_sym_BANG] = ACTIONS(4183),
    [anon_sym_PLUS_PLUS] = ACTIONS(4191),
    [anon_sym_DASH_DASH] = ACTIONS(4191),
    [anon_sym_PLUS] = ACTIONS(4183),
    [anon_sym_DASH] = ACTIONS(4183),
    [anon_sym_STAR] = ACTIONS(4188),
    [anon_sym_SLASH] = ACTIONS(4183),
    [anon_sym_PERCENT] = ACTIONS(4183),
    [anon_sym_CARET] = ACTIONS(4183),
    [anon_sym_PIPE] = ACTIONS(4183),
    [anon_sym_AMP] = ACTIONS(4183),
    [anon_sym_LT_LT] = ACTIONS(4183),
    [anon_sym_GT_GT] = ACTIONS(4183),
    [anon_sym_GT_GT_GT] = ACTIONS(4183),
    [anon_sym_EQ_EQ] = ACTIONS(4191),
    [anon_sym_BANG_EQ] = ACTIONS(4191),
    [anon_sym_GT_EQ] = ACTIONS(4191),
    [anon_sym_LT_EQ] = ACTIONS(4191),
    [anon_sym_DOT] = ACTIONS(4188),
    [anon_sym_scoped] = ACTIONS(4179),
    [anon_sym_var] = ACTIONS(4179),
    [anon_sym_yield] = ACTIONS(4179),
    [anon_sym_switch] = ACTIONS(4183),
    [anon_sym_when] = ACTIONS(4179),
    [anon_sym_DOT_DOT] = ACTIONS(4191),
    [anon_sym_and] = ACTIONS(4183),
    [anon_sym_or] = ACTIONS(4183),
    [anon_sym_PLUS_EQ] = ACTIONS(4191),
    [anon_sym_DASH_EQ] = ACTIONS(4191),
    [anon_sym_STAR_EQ] = ACTIONS(4191),
    [anon_sym_SLASH_EQ] = ACTIONS(4191),
    [anon_sym_PERCENT_EQ] = ACTIONS(4191),
    [anon_sym_AMP_EQ] = ACTIONS(4191),
    [anon_sym_CARET_EQ] = ACTIONS(4191),
    [anon_sym_PIPE_EQ] = ACTIONS(4191),
    [anon_sym_LT_LT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4191),
    [anon_sym_AMP_AMP] = ACTIONS(4191),
    [anon_sym_PIPE_PIPE] = ACTIONS(4191),
    [anon_sym_QMARK_QMARK] = ACTIONS(4183),
    [anon_sym_from] = ACTIONS(4179),
    [anon_sym_into] = ACTIONS(4179),
    [anon_sym_join] = ACTIONS(4179),
    [anon_sym_on] = ACTIONS(4179),
    [anon_sym_equals] = ACTIONS(4188),
    [anon_sym_let] = ACTIONS(4179),
    [anon_sym_orderby] = ACTIONS(4179),
    [anon_sym_ascending] = ACTIONS(4179),
    [anon_sym_descending] = ACTIONS(4179),
    [anon_sym_group] = ACTIONS(4179),
    [anon_sym_by] = ACTIONS(4179),
    [anon_sym_select] = ACTIONS(4179),
    [anon_sym_as] = ACTIONS(4183),
    [anon_sym_is] = ACTIONS(4183),
    [anon_sym_DASH_GT] = ACTIONS(4185),
    [anon_sym_with] = ACTIONS(4183),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2955] = {
    [sym_preproc_region] = STATE(2955),
    [sym_preproc_endregion] = STATE(2955),
    [sym_preproc_line] = STATE(2955),
    [sym_preproc_pragma] = STATE(2955),
    [sym_preproc_nullable] = STATE(2955),
    [sym_preproc_error] = STATE(2955),
    [sym_preproc_warning] = STATE(2955),
    [sym_preproc_define] = STATE(2955),
    [sym_preproc_undef] = STATE(2955),
    [sym__identifier_token] = ACTIONS(4179),
    [anon_sym_alias] = ACTIONS(4179),
    [anon_sym_global] = ACTIONS(4179),
    [anon_sym_EQ] = ACTIONS(4183),
    [anon_sym_LBRACK] = ACTIONS(4185),
    [anon_sym_LPAREN] = ACTIONS(4185),
    [anon_sym_file] = ACTIONS(4179),
    [anon_sym_LT] = ACTIONS(4183),
    [anon_sym_GT] = ACTIONS(4183),
    [anon_sym_where] = ACTIONS(4188),
    [anon_sym_QMARK] = ACTIONS(4188),
    [anon_sym_notnull] = ACTIONS(4179),
    [anon_sym_unmanaged] = ACTIONS(4179),
    [anon_sym_BANG] = ACTIONS(4183),
    [anon_sym_PLUS_PLUS] = ACTIONS(4191),
    [anon_sym_DASH_DASH] = ACTIONS(4191),
    [anon_sym_PLUS] = ACTIONS(4183),
    [anon_sym_DASH] = ACTIONS(4183),
    [anon_sym_STAR] = ACTIONS(4188),
    [anon_sym_SLASH] = ACTIONS(4183),
    [anon_sym_PERCENT] = ACTIONS(4183),
    [anon_sym_CARET] = ACTIONS(4183),
    [anon_sym_PIPE] = ACTIONS(4183),
    [anon_sym_AMP] = ACTIONS(4183),
    [anon_sym_LT_LT] = ACTIONS(4183),
    [anon_sym_GT_GT] = ACTIONS(4183),
    [anon_sym_GT_GT_GT] = ACTIONS(4183),
    [anon_sym_EQ_EQ] = ACTIONS(4191),
    [anon_sym_BANG_EQ] = ACTIONS(4191),
    [anon_sym_GT_EQ] = ACTIONS(4191),
    [anon_sym_LT_EQ] = ACTIONS(4191),
    [anon_sym_DOT] = ACTIONS(4188),
    [anon_sym_scoped] = ACTIONS(4179),
    [anon_sym_var] = ACTIONS(4179),
    [anon_sym_yield] = ACTIONS(4179),
    [anon_sym_switch] = ACTIONS(4183),
    [anon_sym_when] = ACTIONS(4179),
    [anon_sym_DOT_DOT] = ACTIONS(4191),
    [anon_sym_and] = ACTIONS(4183),
    [anon_sym_or] = ACTIONS(4183),
    [anon_sym_PLUS_EQ] = ACTIONS(4191),
    [anon_sym_DASH_EQ] = ACTIONS(4191),
    [anon_sym_STAR_EQ] = ACTIONS(4191),
    [anon_sym_SLASH_EQ] = ACTIONS(4191),
    [anon_sym_PERCENT_EQ] = ACTIONS(4191),
    [anon_sym_AMP_EQ] = ACTIONS(4191),
    [anon_sym_CARET_EQ] = ACTIONS(4191),
    [anon_sym_PIPE_EQ] = ACTIONS(4191),
    [anon_sym_LT_LT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4191),
    [anon_sym_AMP_AMP] = ACTIONS(4191),
    [anon_sym_PIPE_PIPE] = ACTIONS(4191),
    [anon_sym_QMARK_QMARK] = ACTIONS(4183),
    [anon_sym_from] = ACTIONS(4188),
    [anon_sym_into] = ACTIONS(4188),
    [anon_sym_join] = ACTIONS(4188),
    [anon_sym_on] = ACTIONS(4179),
    [anon_sym_equals] = ACTIONS(4179),
    [anon_sym_let] = ACTIONS(4188),
    [anon_sym_orderby] = ACTIONS(4188),
    [anon_sym_ascending] = ACTIONS(4179),
    [anon_sym_descending] = ACTIONS(4179),
    [anon_sym_group] = ACTIONS(4188),
    [anon_sym_by] = ACTIONS(4179),
    [anon_sym_select] = ACTIONS(4188),
    [anon_sym_as] = ACTIONS(4183),
    [anon_sym_is] = ACTIONS(4183),
    [anon_sym_DASH_GT] = ACTIONS(4185),
    [anon_sym_with] = ACTIONS(4183),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2956] = {
    [sym_preproc_region] = STATE(2956),
    [sym_preproc_endregion] = STATE(2956),
    [sym_preproc_line] = STATE(2956),
    [sym_preproc_pragma] = STATE(2956),
    [sym_preproc_nullable] = STATE(2956),
    [sym_preproc_error] = STATE(2956),
    [sym_preproc_warning] = STATE(2956),
    [sym_preproc_define] = STATE(2956),
    [sym_preproc_undef] = STATE(2956),
    [sym__identifier_token] = ACTIONS(4157),
    [anon_sym_alias] = ACTIONS(4157),
    [anon_sym_SEMI] = ACTIONS(4168),
    [anon_sym_global] = ACTIONS(4157),
    [anon_sym_LBRACK] = ACTIONS(4168),
    [anon_sym_COLON] = ACTIONS(4168),
    [anon_sym_COMMA] = ACTIONS(4168),
    [anon_sym_RBRACK] = ACTIONS(4168),
    [anon_sym_LPAREN] = ACTIONS(4168),
    [anon_sym_RPAREN] = ACTIONS(4168),
    [anon_sym_LBRACE] = ACTIONS(4168),
    [anon_sym_RBRACE] = ACTIONS(4168),
    [anon_sym_file] = ACTIONS(4157),
    [anon_sym_LT] = ACTIONS(4157),
    [anon_sym_GT] = ACTIONS(4157),
    [anon_sym_in] = ACTIONS(4157),
    [anon_sym_where] = ACTIONS(4157),
    [anon_sym_QMARK] = ACTIONS(4157),
    [anon_sym_notnull] = ACTIONS(4157),
    [anon_sym_unmanaged] = ACTIONS(4157),
    [anon_sym_BANG] = ACTIONS(4157),
    [anon_sym_PLUS_PLUS] = ACTIONS(4168),
    [anon_sym_DASH_DASH] = ACTIONS(4168),
    [anon_sym_PLUS] = ACTIONS(4157),
    [anon_sym_DASH] = ACTIONS(4157),
    [anon_sym_STAR] = ACTIONS(4168),
    [anon_sym_SLASH] = ACTIONS(4157),
    [anon_sym_PERCENT] = ACTIONS(4168),
    [anon_sym_CARET] = ACTIONS(4168),
    [anon_sym_PIPE] = ACTIONS(4157),
    [anon_sym_AMP] = ACTIONS(4157),
    [anon_sym_LT_LT] = ACTIONS(4168),
    [anon_sym_GT_GT] = ACTIONS(4157),
    [anon_sym_GT_GT_GT] = ACTIONS(4168),
    [anon_sym_EQ_EQ] = ACTIONS(4168),
    [anon_sym_BANG_EQ] = ACTIONS(4168),
    [anon_sym_GT_EQ] = ACTIONS(4168),
    [anon_sym_LT_EQ] = ACTIONS(4168),
    [anon_sym_DOT] = ACTIONS(4157),
    [anon_sym_scoped] = ACTIONS(4157),
    [anon_sym_EQ_GT] = ACTIONS(4168),
    [anon_sym_var] = ACTIONS(4157),
    [anon_sym_yield] = ACTIONS(4157),
    [anon_sym_switch] = ACTIONS(4157),
    [anon_sym_when] = ACTIONS(4157),
    [sym_discard] = ACTIONS(4157),
    [anon_sym_DOT_DOT] = ACTIONS(4168),
    [anon_sym_and] = ACTIONS(4157),
    [anon_sym_or] = ACTIONS(4157),
    [anon_sym_AMP_AMP] = ACTIONS(4168),
    [anon_sym_PIPE_PIPE] = ACTIONS(4168),
    [anon_sym_QMARK_QMARK] = ACTIONS(4168),
    [anon_sym_from] = ACTIONS(4157),
    [anon_sym_into] = ACTIONS(4157),
    [anon_sym_join] = ACTIONS(4157),
    [anon_sym_on] = ACTIONS(4157),
    [anon_sym_equals] = ACTIONS(4157),
    [anon_sym_let] = ACTIONS(4157),
    [anon_sym_orderby] = ACTIONS(4157),
    [anon_sym_ascending] = ACTIONS(4157),
    [anon_sym_descending] = ACTIONS(4157),
    [anon_sym_group] = ACTIONS(4157),
    [anon_sym_by] = ACTIONS(4157),
    [anon_sym_select] = ACTIONS(4157),
    [anon_sym_as] = ACTIONS(4157),
    [anon_sym_is] = ACTIONS(4157),
    [anon_sym_DASH_GT] = ACTIONS(4168),
    [anon_sym_with] = ACTIONS(4157),
    [aux_sym_preproc_if_token3] = ACTIONS(4168),
    [aux_sym_preproc_else_token1] = ACTIONS(4168),
    [aux_sym_preproc_elif_token1] = ACTIONS(4168),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2957] = {
    [sym_preproc_region] = STATE(2957),
    [sym_preproc_endregion] = STATE(2957),
    [sym_preproc_line] = STATE(2957),
    [sym_preproc_pragma] = STATE(2957),
    [sym_preproc_nullable] = STATE(2957),
    [sym_preproc_error] = STATE(2957),
    [sym_preproc_warning] = STATE(2957),
    [sym_preproc_define] = STATE(2957),
    [sym_preproc_undef] = STATE(2957),
    [sym__identifier_token] = ACTIONS(4149),
    [anon_sym_alias] = ACTIONS(4149),
    [anon_sym_SEMI] = ACTIONS(4151),
    [anon_sym_global] = ACTIONS(4149),
    [anon_sym_LBRACK] = ACTIONS(4151),
    [anon_sym_COLON] = ACTIONS(4151),
    [anon_sym_COMMA] = ACTIONS(4151),
    [anon_sym_RBRACK] = ACTIONS(4151),
    [anon_sym_LPAREN] = ACTIONS(4151),
    [anon_sym_RPAREN] = ACTIONS(4151),
    [anon_sym_LBRACE] = ACTIONS(4151),
    [anon_sym_RBRACE] = ACTIONS(4151),
    [anon_sym_file] = ACTIONS(4149),
    [anon_sym_LT] = ACTIONS(4149),
    [anon_sym_GT] = ACTIONS(4149),
    [anon_sym_in] = ACTIONS(4149),
    [anon_sym_where] = ACTIONS(4149),
    [anon_sym_QMARK] = ACTIONS(4149),
    [anon_sym_notnull] = ACTIONS(4149),
    [anon_sym_unmanaged] = ACTIONS(4149),
    [anon_sym_BANG] = ACTIONS(4149),
    [anon_sym_PLUS_PLUS] = ACTIONS(4151),
    [anon_sym_DASH_DASH] = ACTIONS(4151),
    [anon_sym_PLUS] = ACTIONS(4149),
    [anon_sym_DASH] = ACTIONS(4149),
    [anon_sym_STAR] = ACTIONS(4151),
    [anon_sym_SLASH] = ACTIONS(4149),
    [anon_sym_PERCENT] = ACTIONS(4151),
    [anon_sym_CARET] = ACTIONS(4151),
    [anon_sym_PIPE] = ACTIONS(4149),
    [anon_sym_AMP] = ACTIONS(4149),
    [anon_sym_LT_LT] = ACTIONS(4151),
    [anon_sym_GT_GT] = ACTIONS(4149),
    [anon_sym_GT_GT_GT] = ACTIONS(4151),
    [anon_sym_EQ_EQ] = ACTIONS(4151),
    [anon_sym_BANG_EQ] = ACTIONS(4151),
    [anon_sym_GT_EQ] = ACTIONS(4151),
    [anon_sym_LT_EQ] = ACTIONS(4151),
    [anon_sym_DOT] = ACTIONS(4149),
    [anon_sym_scoped] = ACTIONS(4149),
    [anon_sym_EQ_GT] = ACTIONS(4151),
    [anon_sym_var] = ACTIONS(4149),
    [anon_sym_yield] = ACTIONS(4149),
    [anon_sym_switch] = ACTIONS(4149),
    [anon_sym_when] = ACTIONS(4149),
    [sym_discard] = ACTIONS(4149),
    [anon_sym_DOT_DOT] = ACTIONS(4151),
    [anon_sym_and] = ACTIONS(4149),
    [anon_sym_or] = ACTIONS(4149),
    [anon_sym_AMP_AMP] = ACTIONS(4151),
    [anon_sym_PIPE_PIPE] = ACTIONS(4151),
    [anon_sym_QMARK_QMARK] = ACTIONS(4151),
    [anon_sym_from] = ACTIONS(4149),
    [anon_sym_into] = ACTIONS(4149),
    [anon_sym_join] = ACTIONS(4149),
    [anon_sym_on] = ACTIONS(4149),
    [anon_sym_equals] = ACTIONS(4149),
    [anon_sym_let] = ACTIONS(4149),
    [anon_sym_orderby] = ACTIONS(4149),
    [anon_sym_ascending] = ACTIONS(4149),
    [anon_sym_descending] = ACTIONS(4149),
    [anon_sym_group] = ACTIONS(4149),
    [anon_sym_by] = ACTIONS(4149),
    [anon_sym_select] = ACTIONS(4149),
    [anon_sym_as] = ACTIONS(4149),
    [anon_sym_is] = ACTIONS(4149),
    [anon_sym_DASH_GT] = ACTIONS(4151),
    [anon_sym_with] = ACTIONS(4149),
    [aux_sym_preproc_if_token3] = ACTIONS(4151),
    [aux_sym_preproc_else_token1] = ACTIONS(4151),
    [aux_sym_preproc_elif_token1] = ACTIONS(4151),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2958] = {
    [sym_modifier] = STATE(3807),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7332),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(2958),
    [sym_preproc_endregion] = STATE(2958),
    [sym_preproc_line] = STATE(2958),
    [sym_preproc_pragma] = STATE(2958),
    [sym_preproc_nullable] = STATE(2958),
    [sym_preproc_error] = STATE(2958),
    [sym_preproc_warning] = STATE(2958),
    [sym_preproc_define] = STATE(2958),
    [sym_preproc_undef] = STATE(2958),
    [aux_sym_class_declaration_repeat2] = STATE(3733),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_extern] = ACTIONS(65),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_unsafe] = ACTIONS(65),
    [anon_sym_static] = ACTIONS(65),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_class] = ACTIONS(4559),
    [anon_sym_ref] = ACTIONS(4561),
    [anon_sym_struct] = ACTIONS(4563),
    [anon_sym_enum] = ACTIONS(4565),
    [anon_sym_interface] = ACTIONS(4567),
    [anon_sym_delegate] = ACTIONS(4569),
    [anon_sym_record] = ACTIONS(4571),
    [anon_sym_abstract] = ACTIONS(65),
    [anon_sym_async] = ACTIONS(65),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_file] = ACTIONS(4573),
    [anon_sym_fixed] = ACTIONS(65),
    [anon_sym_internal] = ACTIONS(65),
    [anon_sym_new] = ACTIONS(65),
    [anon_sym_override] = ACTIONS(65),
    [anon_sym_partial] = ACTIONS(65),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_public] = ACTIONS(65),
    [anon_sym_readonly] = ACTIONS(65),
    [anon_sym_required] = ACTIONS(65),
    [anon_sym_sealed] = ACTIONS(65),
    [anon_sym_virtual] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2959] = {
    [sym_parameter_list] = STATE(9685),
    [sym_positional_pattern_clause] = STATE(3081),
    [sym_property_pattern_clause] = STATE(3135),
    [sym__variable_designation] = STATE(5777),
    [sym_parenthesized_variable_designation] = STATE(5773),
    [sym__lambda_parameters] = STATE(9890),
    [sym_identifier] = STATE(5348),
    [sym__reserved_identifier] = STATE(5200),
    [sym_preproc_region] = STATE(2959),
    [sym_preproc_endregion] = STATE(2959),
    [sym_preproc_line] = STATE(2959),
    [sym_preproc_pragma] = STATE(2959),
    [sym_preproc_nullable] = STATE(2959),
    [sym_preproc_error] = STATE(2959),
    [sym_preproc_warning] = STATE(2959),
    [sym_preproc_define] = STATE(2959),
    [sym_preproc_undef] = STATE(2959),
    [sym__identifier_token] = ACTIONS(4575),
    [anon_sym_alias] = ACTIONS(4577),
    [anon_sym_global] = ACTIONS(4577),
    [anon_sym_LBRACK] = ACTIONS(4341),
    [anon_sym_COLON] = ACTIONS(4341),
    [anon_sym_COMMA] = ACTIONS(4341),
    [anon_sym_LPAREN] = ACTIONS(4341),
    [anon_sym_LBRACE] = ACTIONS(4579),
    [anon_sym_file] = ACTIONS(4577),
    [anon_sym_LT] = ACTIONS(4345),
    [anon_sym_GT] = ACTIONS(4345),
    [anon_sym_where] = ACTIONS(4577),
    [anon_sym_QMARK] = ACTIONS(4345),
    [anon_sym_notnull] = ACTIONS(4577),
    [anon_sym_unmanaged] = ACTIONS(4577),
    [anon_sym_BANG] = ACTIONS(4345),
    [anon_sym_PLUS_PLUS] = ACTIONS(4341),
    [anon_sym_DASH_DASH] = ACTIONS(4341),
    [anon_sym_PLUS] = ACTIONS(4345),
    [anon_sym_DASH] = ACTIONS(4345),
    [anon_sym_STAR] = ACTIONS(4341),
    [anon_sym_SLASH] = ACTIONS(4345),
    [anon_sym_PERCENT] = ACTIONS(4341),
    [anon_sym_CARET] = ACTIONS(4341),
    [anon_sym_PIPE] = ACTIONS(4345),
    [anon_sym_AMP] = ACTIONS(4345),
    [anon_sym_LT_LT] = ACTIONS(4341),
    [anon_sym_GT_GT] = ACTIONS(4345),
    [anon_sym_GT_GT_GT] = ACTIONS(4341),
    [anon_sym_EQ_EQ] = ACTIONS(4341),
    [anon_sym_BANG_EQ] = ACTIONS(4341),
    [anon_sym_GT_EQ] = ACTIONS(4341),
    [anon_sym_LT_EQ] = ACTIONS(4341),
    [anon_sym_DOT] = ACTIONS(4345),
    [anon_sym_scoped] = ACTIONS(4577),
    [anon_sym_var] = ACTIONS(4577),
    [anon_sym_yield] = ACTIONS(4577),
    [anon_sym_switch] = ACTIONS(4345),
    [anon_sym_when] = ACTIONS(4577),
    [sym_discard] = ACTIONS(4581),
    [anon_sym_DOT_DOT] = ACTIONS(4341),
    [anon_sym_and] = ACTIONS(4345),
    [anon_sym_or] = ACTIONS(4345),
    [anon_sym_AMP_AMP] = ACTIONS(4341),
    [anon_sym_PIPE_PIPE] = ACTIONS(4341),
    [anon_sym_QMARK_QMARK] = ACTIONS(4341),
    [anon_sym_from] = ACTIONS(4577),
    [anon_sym_into] = ACTIONS(4345),
    [anon_sym_join] = ACTIONS(4577),
    [anon_sym_on] = ACTIONS(4577),
    [anon_sym_equals] = ACTIONS(4577),
    [anon_sym_let] = ACTIONS(4577),
    [anon_sym_orderby] = ACTIONS(4577),
    [anon_sym_ascending] = ACTIONS(4577),
    [anon_sym_descending] = ACTIONS(4577),
    [anon_sym_group] = ACTIONS(4577),
    [anon_sym_by] = ACTIONS(4577),
    [anon_sym_select] = ACTIONS(4577),
    [anon_sym_as] = ACTIONS(4345),
    [anon_sym_is] = ACTIONS(4345),
    [anon_sym_DASH_GT] = ACTIONS(4341),
    [anon_sym_with] = ACTIONS(4345),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4341),
  },
  [2960] = {
    [sym_preproc_region] = STATE(2960),
    [sym_preproc_endregion] = STATE(2960),
    [sym_preproc_line] = STATE(2960),
    [sym_preproc_pragma] = STATE(2960),
    [sym_preproc_nullable] = STATE(2960),
    [sym_preproc_error] = STATE(2960),
    [sym_preproc_warning] = STATE(2960),
    [sym_preproc_define] = STATE(2960),
    [sym_preproc_undef] = STATE(2960),
    [sym__identifier_token] = ACTIONS(4157),
    [anon_sym_alias] = ACTIONS(4157),
    [anon_sym_global] = ACTIONS(4157),
    [anon_sym_EQ] = ACTIONS(4162),
    [anon_sym_LBRACK] = ACTIONS(4193),
    [anon_sym_LPAREN] = ACTIONS(4193),
    [anon_sym_file] = ACTIONS(4157),
    [anon_sym_LT] = ACTIONS(4162),
    [anon_sym_GT] = ACTIONS(4162),
    [anon_sym_where] = ACTIONS(4157),
    [anon_sym_QMARK] = ACTIONS(4196),
    [anon_sym_notnull] = ACTIONS(4157),
    [anon_sym_unmanaged] = ACTIONS(4157),
    [anon_sym_BANG] = ACTIONS(4162),
    [anon_sym_PLUS_PLUS] = ACTIONS(4177),
    [anon_sym_DASH_DASH] = ACTIONS(4177),
    [anon_sym_PLUS] = ACTIONS(4162),
    [anon_sym_DASH] = ACTIONS(4162),
    [anon_sym_STAR] = ACTIONS(4196),
    [anon_sym_SLASH] = ACTIONS(4162),
    [anon_sym_PERCENT] = ACTIONS(4162),
    [anon_sym_CARET] = ACTIONS(4162),
    [anon_sym_PIPE] = ACTIONS(4162),
    [anon_sym_AMP] = ACTIONS(4162),
    [anon_sym_LT_LT] = ACTIONS(4162),
    [anon_sym_GT_GT] = ACTIONS(4162),
    [anon_sym_GT_GT_GT] = ACTIONS(4162),
    [anon_sym_EQ_EQ] = ACTIONS(4177),
    [anon_sym_BANG_EQ] = ACTIONS(4177),
    [anon_sym_GT_EQ] = ACTIONS(4177),
    [anon_sym_LT_EQ] = ACTIONS(4177),
    [anon_sym_DOT] = ACTIONS(4196),
    [anon_sym_scoped] = ACTIONS(4157),
    [anon_sym_var] = ACTIONS(4157),
    [anon_sym_yield] = ACTIONS(4157),
    [anon_sym_switch] = ACTIONS(4162),
    [anon_sym_when] = ACTIONS(4157),
    [anon_sym_DOT_DOT] = ACTIONS(4177),
    [anon_sym_and] = ACTIONS(4162),
    [anon_sym_or] = ACTIONS(4162),
    [anon_sym_PLUS_EQ] = ACTIONS(4177),
    [anon_sym_DASH_EQ] = ACTIONS(4177),
    [anon_sym_STAR_EQ] = ACTIONS(4177),
    [anon_sym_SLASH_EQ] = ACTIONS(4177),
    [anon_sym_PERCENT_EQ] = ACTIONS(4177),
    [anon_sym_AMP_EQ] = ACTIONS(4177),
    [anon_sym_CARET_EQ] = ACTIONS(4177),
    [anon_sym_PIPE_EQ] = ACTIONS(4177),
    [anon_sym_LT_LT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4177),
    [anon_sym_AMP_AMP] = ACTIONS(4177),
    [anon_sym_PIPE_PIPE] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK] = ACTIONS(4162),
    [anon_sym_from] = ACTIONS(4157),
    [anon_sym_into] = ACTIONS(4196),
    [anon_sym_join] = ACTIONS(4157),
    [anon_sym_on] = ACTIONS(4157),
    [anon_sym_equals] = ACTIONS(4196),
    [anon_sym_let] = ACTIONS(4157),
    [anon_sym_orderby] = ACTIONS(4157),
    [anon_sym_ascending] = ACTIONS(4157),
    [anon_sym_descending] = ACTIONS(4157),
    [anon_sym_group] = ACTIONS(4157),
    [anon_sym_by] = ACTIONS(4157),
    [anon_sym_select] = ACTIONS(4157),
    [anon_sym_as] = ACTIONS(4162),
    [anon_sym_is] = ACTIONS(4162),
    [anon_sym_DASH_GT] = ACTIONS(4193),
    [anon_sym_with] = ACTIONS(4162),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2961] = {
    [sym_preproc_region] = STATE(2961),
    [sym_preproc_endregion] = STATE(2961),
    [sym_preproc_line] = STATE(2961),
    [sym_preproc_pragma] = STATE(2961),
    [sym_preproc_nullable] = STATE(2961),
    [sym_preproc_error] = STATE(2961),
    [sym_preproc_warning] = STATE(2961),
    [sym_preproc_define] = STATE(2961),
    [sym_preproc_undef] = STATE(2961),
    [sym__identifier_token] = ACTIONS(4583),
    [anon_sym_alias] = ACTIONS(4583),
    [anon_sym_SEMI] = ACTIONS(4585),
    [anon_sym_global] = ACTIONS(4583),
    [anon_sym_LBRACK] = ACTIONS(4585),
    [anon_sym_COLON] = ACTIONS(4585),
    [anon_sym_COMMA] = ACTIONS(4585),
    [anon_sym_RBRACK] = ACTIONS(4585),
    [anon_sym_LPAREN] = ACTIONS(4585),
    [anon_sym_RPAREN] = ACTIONS(4585),
    [anon_sym_LBRACE] = ACTIONS(4585),
    [anon_sym_RBRACE] = ACTIONS(4585),
    [anon_sym_file] = ACTIONS(4583),
    [anon_sym_LT] = ACTIONS(4583),
    [anon_sym_GT] = ACTIONS(4583),
    [anon_sym_in] = ACTIONS(4583),
    [anon_sym_where] = ACTIONS(4583),
    [anon_sym_QMARK] = ACTIONS(4583),
    [anon_sym_notnull] = ACTIONS(4583),
    [anon_sym_unmanaged] = ACTIONS(4583),
    [anon_sym_BANG] = ACTIONS(4583),
    [anon_sym_PLUS_PLUS] = ACTIONS(4585),
    [anon_sym_DASH_DASH] = ACTIONS(4585),
    [anon_sym_PLUS] = ACTIONS(4583),
    [anon_sym_DASH] = ACTIONS(4583),
    [anon_sym_STAR] = ACTIONS(4585),
    [anon_sym_SLASH] = ACTIONS(4583),
    [anon_sym_PERCENT] = ACTIONS(4585),
    [anon_sym_CARET] = ACTIONS(4585),
    [anon_sym_PIPE] = ACTIONS(4583),
    [anon_sym_AMP] = ACTIONS(4583),
    [anon_sym_LT_LT] = ACTIONS(4585),
    [anon_sym_GT_GT] = ACTIONS(4583),
    [anon_sym_GT_GT_GT] = ACTIONS(4585),
    [anon_sym_EQ_EQ] = ACTIONS(4585),
    [anon_sym_BANG_EQ] = ACTIONS(4585),
    [anon_sym_GT_EQ] = ACTIONS(4585),
    [anon_sym_LT_EQ] = ACTIONS(4585),
    [anon_sym_DOT] = ACTIONS(4583),
    [anon_sym_scoped] = ACTIONS(4583),
    [anon_sym_EQ_GT] = ACTIONS(4585),
    [anon_sym_var] = ACTIONS(4583),
    [anon_sym_yield] = ACTIONS(4583),
    [anon_sym_switch] = ACTIONS(4583),
    [anon_sym_when] = ACTIONS(4583),
    [sym_discard] = ACTIONS(4583),
    [anon_sym_DOT_DOT] = ACTIONS(4585),
    [anon_sym_and] = ACTIONS(4583),
    [anon_sym_or] = ACTIONS(4583),
    [anon_sym_AMP_AMP] = ACTIONS(4585),
    [anon_sym_PIPE_PIPE] = ACTIONS(4585),
    [anon_sym_QMARK_QMARK] = ACTIONS(4585),
    [anon_sym_from] = ACTIONS(4583),
    [anon_sym_into] = ACTIONS(4583),
    [anon_sym_join] = ACTIONS(4583),
    [anon_sym_on] = ACTIONS(4583),
    [anon_sym_equals] = ACTIONS(4583),
    [anon_sym_let] = ACTIONS(4583),
    [anon_sym_orderby] = ACTIONS(4583),
    [anon_sym_ascending] = ACTIONS(4583),
    [anon_sym_descending] = ACTIONS(4583),
    [anon_sym_group] = ACTIONS(4583),
    [anon_sym_by] = ACTIONS(4583),
    [anon_sym_select] = ACTIONS(4583),
    [anon_sym_as] = ACTIONS(4583),
    [anon_sym_is] = ACTIONS(4583),
    [anon_sym_DASH_GT] = ACTIONS(4585),
    [anon_sym_with] = ACTIONS(4583),
    [aux_sym_preproc_if_token3] = ACTIONS(4585),
    [aux_sym_preproc_else_token1] = ACTIONS(4585),
    [aux_sym_preproc_elif_token1] = ACTIONS(4585),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2962] = {
    [sym_preproc_region] = STATE(2962),
    [sym_preproc_endregion] = STATE(2962),
    [sym_preproc_line] = STATE(2962),
    [sym_preproc_pragma] = STATE(2962),
    [sym_preproc_nullable] = STATE(2962),
    [sym_preproc_error] = STATE(2962),
    [sym_preproc_warning] = STATE(2962),
    [sym_preproc_define] = STATE(2962),
    [sym_preproc_undef] = STATE(2962),
    [sym__identifier_token] = ACTIONS(4587),
    [anon_sym_alias] = ACTIONS(4587),
    [anon_sym_SEMI] = ACTIONS(4589),
    [anon_sym_global] = ACTIONS(4587),
    [anon_sym_LBRACK] = ACTIONS(4589),
    [anon_sym_COLON] = ACTIONS(4589),
    [anon_sym_COMMA] = ACTIONS(4589),
    [anon_sym_RBRACK] = ACTIONS(4589),
    [anon_sym_LPAREN] = ACTIONS(4589),
    [anon_sym_RPAREN] = ACTIONS(4589),
    [anon_sym_LBRACE] = ACTIONS(4589),
    [anon_sym_RBRACE] = ACTIONS(4589),
    [anon_sym_file] = ACTIONS(4587),
    [anon_sym_LT] = ACTIONS(4587),
    [anon_sym_GT] = ACTIONS(4587),
    [anon_sym_in] = ACTIONS(4587),
    [anon_sym_where] = ACTIONS(4587),
    [anon_sym_QMARK] = ACTIONS(4587),
    [anon_sym_notnull] = ACTIONS(4587),
    [anon_sym_unmanaged] = ACTIONS(4587),
    [anon_sym_BANG] = ACTIONS(4587),
    [anon_sym_PLUS_PLUS] = ACTIONS(4589),
    [anon_sym_DASH_DASH] = ACTIONS(4589),
    [anon_sym_PLUS] = ACTIONS(4587),
    [anon_sym_DASH] = ACTIONS(4587),
    [anon_sym_STAR] = ACTIONS(4589),
    [anon_sym_SLASH] = ACTIONS(4587),
    [anon_sym_PERCENT] = ACTIONS(4589),
    [anon_sym_CARET] = ACTIONS(4589),
    [anon_sym_PIPE] = ACTIONS(4587),
    [anon_sym_AMP] = ACTIONS(4587),
    [anon_sym_LT_LT] = ACTIONS(4589),
    [anon_sym_GT_GT] = ACTIONS(4587),
    [anon_sym_GT_GT_GT] = ACTIONS(4589),
    [anon_sym_EQ_EQ] = ACTIONS(4589),
    [anon_sym_BANG_EQ] = ACTIONS(4589),
    [anon_sym_GT_EQ] = ACTIONS(4589),
    [anon_sym_LT_EQ] = ACTIONS(4589),
    [anon_sym_DOT] = ACTIONS(4587),
    [anon_sym_scoped] = ACTIONS(4587),
    [anon_sym_EQ_GT] = ACTIONS(4591),
    [anon_sym_var] = ACTIONS(4587),
    [anon_sym_yield] = ACTIONS(4587),
    [anon_sym_switch] = ACTIONS(4587),
    [anon_sym_when] = ACTIONS(4587),
    [sym_discard] = ACTIONS(4587),
    [anon_sym_DOT_DOT] = ACTIONS(4589),
    [anon_sym_and] = ACTIONS(4587),
    [anon_sym_or] = ACTIONS(4587),
    [anon_sym_AMP_AMP] = ACTIONS(4589),
    [anon_sym_PIPE_PIPE] = ACTIONS(4589),
    [anon_sym_QMARK_QMARK] = ACTIONS(4589),
    [anon_sym_from] = ACTIONS(4587),
    [anon_sym_into] = ACTIONS(4587),
    [anon_sym_join] = ACTIONS(4587),
    [anon_sym_on] = ACTIONS(4587),
    [anon_sym_equals] = ACTIONS(4587),
    [anon_sym_let] = ACTIONS(4587),
    [anon_sym_orderby] = ACTIONS(4587),
    [anon_sym_ascending] = ACTIONS(4587),
    [anon_sym_descending] = ACTIONS(4587),
    [anon_sym_group] = ACTIONS(4587),
    [anon_sym_by] = ACTIONS(4587),
    [anon_sym_select] = ACTIONS(4587),
    [anon_sym_as] = ACTIONS(4587),
    [anon_sym_is] = ACTIONS(4587),
    [anon_sym_DASH_GT] = ACTIONS(4589),
    [anon_sym_with] = ACTIONS(4587),
    [aux_sym_preproc_if_token3] = ACTIONS(4589),
    [aux_sym_preproc_else_token1] = ACTIONS(4589),
    [aux_sym_preproc_elif_token1] = ACTIONS(4589),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2963] = {
    [sym_preproc_region] = STATE(2963),
    [sym_preproc_endregion] = STATE(2963),
    [sym_preproc_line] = STATE(2963),
    [sym_preproc_pragma] = STATE(2963),
    [sym_preproc_nullable] = STATE(2963),
    [sym_preproc_error] = STATE(2963),
    [sym_preproc_warning] = STATE(2963),
    [sym_preproc_define] = STATE(2963),
    [sym_preproc_undef] = STATE(2963),
    [sym__identifier_token] = ACTIONS(4492),
    [anon_sym_alias] = ACTIONS(4492),
    [anon_sym_SEMI] = ACTIONS(4494),
    [anon_sym_global] = ACTIONS(4492),
    [anon_sym_LBRACK] = ACTIONS(4593),
    [anon_sym_COLON] = ACTIONS(4494),
    [anon_sym_COMMA] = ACTIONS(4494),
    [anon_sym_RBRACK] = ACTIONS(4494),
    [anon_sym_LPAREN] = ACTIONS(4494),
    [anon_sym_RPAREN] = ACTIONS(4494),
    [anon_sym_LBRACE] = ACTIONS(4494),
    [anon_sym_RBRACE] = ACTIONS(4494),
    [anon_sym_file] = ACTIONS(4492),
    [anon_sym_LT] = ACTIONS(4492),
    [anon_sym_GT] = ACTIONS(4492),
    [anon_sym_in] = ACTIONS(4492),
    [anon_sym_where] = ACTIONS(4492),
    [anon_sym_QMARK] = ACTIONS(4596),
    [anon_sym_notnull] = ACTIONS(4492),
    [anon_sym_unmanaged] = ACTIONS(4492),
    [anon_sym_BANG] = ACTIONS(4492),
    [anon_sym_PLUS_PLUS] = ACTIONS(4494),
    [anon_sym_DASH_DASH] = ACTIONS(4494),
    [anon_sym_PLUS] = ACTIONS(4492),
    [anon_sym_DASH] = ACTIONS(4492),
    [anon_sym_STAR] = ACTIONS(4599),
    [anon_sym_SLASH] = ACTIONS(4492),
    [anon_sym_PERCENT] = ACTIONS(4494),
    [anon_sym_CARET] = ACTIONS(4494),
    [anon_sym_PIPE] = ACTIONS(4492),
    [anon_sym_AMP] = ACTIONS(4492),
    [anon_sym_LT_LT] = ACTIONS(4494),
    [anon_sym_GT_GT] = ACTIONS(4492),
    [anon_sym_GT_GT_GT] = ACTIONS(4494),
    [anon_sym_EQ_EQ] = ACTIONS(4494),
    [anon_sym_BANG_EQ] = ACTIONS(4494),
    [anon_sym_GT_EQ] = ACTIONS(4494),
    [anon_sym_LT_EQ] = ACTIONS(4494),
    [anon_sym_DOT] = ACTIONS(4602),
    [anon_sym_scoped] = ACTIONS(4492),
    [anon_sym_EQ_GT] = ACTIONS(4494),
    [anon_sym_var] = ACTIONS(4492),
    [anon_sym_yield] = ACTIONS(4492),
    [anon_sym_switch] = ACTIONS(4492),
    [anon_sym_when] = ACTIONS(4492),
    [sym_discard] = ACTIONS(4492),
    [anon_sym_DOT_DOT] = ACTIONS(4494),
    [anon_sym_and] = ACTIONS(4492),
    [anon_sym_or] = ACTIONS(4492),
    [anon_sym_AMP_AMP] = ACTIONS(4494),
    [anon_sym_PIPE_PIPE] = ACTIONS(4494),
    [anon_sym_QMARK_QMARK] = ACTIONS(4494),
    [anon_sym_from] = ACTIONS(4492),
    [anon_sym_into] = ACTIONS(4492),
    [anon_sym_join] = ACTIONS(4492),
    [anon_sym_on] = ACTIONS(4492),
    [anon_sym_equals] = ACTIONS(4492),
    [anon_sym_let] = ACTIONS(4492),
    [anon_sym_orderby] = ACTIONS(4492),
    [anon_sym_ascending] = ACTIONS(4492),
    [anon_sym_descending] = ACTIONS(4492),
    [anon_sym_group] = ACTIONS(4492),
    [anon_sym_by] = ACTIONS(4492),
    [anon_sym_select] = ACTIONS(4492),
    [anon_sym_as] = ACTIONS(4492),
    [anon_sym_is] = ACTIONS(4492),
    [anon_sym_DASH_GT] = ACTIONS(4604),
    [anon_sym_with] = ACTIONS(4492),
    [aux_sym_preproc_if_token3] = ACTIONS(4494),
    [aux_sym_preproc_else_token1] = ACTIONS(4494),
    [aux_sym_preproc_elif_token1] = ACTIONS(4494),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2964] = {
    [sym_parameter_list] = STATE(9685),
    [sym_positional_pattern_clause] = STATE(3085),
    [sym_property_pattern_clause] = STATE(3122),
    [sym__variable_designation] = STATE(5777),
    [sym_parenthesized_variable_designation] = STATE(5773),
    [sym__lambda_parameters] = STATE(9890),
    [sym_identifier] = STATE(5348),
    [sym__reserved_identifier] = STATE(5200),
    [sym_preproc_region] = STATE(2964),
    [sym_preproc_endregion] = STATE(2964),
    [sym_preproc_line] = STATE(2964),
    [sym_preproc_pragma] = STATE(2964),
    [sym_preproc_nullable] = STATE(2964),
    [sym_preproc_error] = STATE(2964),
    [sym_preproc_warning] = STATE(2964),
    [sym_preproc_define] = STATE(2964),
    [sym_preproc_undef] = STATE(2964),
    [sym__identifier_token] = ACTIONS(4575),
    [anon_sym_alias] = ACTIONS(4577),
    [anon_sym_global] = ACTIONS(4577),
    [anon_sym_LBRACK] = ACTIONS(4341),
    [anon_sym_COLON] = ACTIONS(4341),
    [anon_sym_COMMA] = ACTIONS(4341),
    [anon_sym_LPAREN] = ACTIONS(4341),
    [anon_sym_LBRACE] = ACTIONS(4579),
    [anon_sym_file] = ACTIONS(4577),
    [anon_sym_LT] = ACTIONS(4345),
    [anon_sym_GT] = ACTIONS(4345),
    [anon_sym_where] = ACTIONS(4577),
    [anon_sym_QMARK] = ACTIONS(4345),
    [anon_sym_notnull] = ACTIONS(4577),
    [anon_sym_unmanaged] = ACTIONS(4577),
    [anon_sym_BANG] = ACTIONS(4345),
    [anon_sym_PLUS_PLUS] = ACTIONS(4341),
    [anon_sym_DASH_DASH] = ACTIONS(4341),
    [anon_sym_PLUS] = ACTIONS(4345),
    [anon_sym_DASH] = ACTIONS(4345),
    [anon_sym_STAR] = ACTIONS(4341),
    [anon_sym_SLASH] = ACTIONS(4345),
    [anon_sym_PERCENT] = ACTIONS(4341),
    [anon_sym_CARET] = ACTIONS(4341),
    [anon_sym_PIPE] = ACTIONS(4345),
    [anon_sym_AMP] = ACTIONS(4345),
    [anon_sym_LT_LT] = ACTIONS(4341),
    [anon_sym_GT_GT] = ACTIONS(4345),
    [anon_sym_GT_GT_GT] = ACTIONS(4341),
    [anon_sym_EQ_EQ] = ACTIONS(4341),
    [anon_sym_BANG_EQ] = ACTIONS(4341),
    [anon_sym_GT_EQ] = ACTIONS(4341),
    [anon_sym_LT_EQ] = ACTIONS(4341),
    [anon_sym_DOT] = ACTIONS(4345),
    [anon_sym_scoped] = ACTIONS(4577),
    [anon_sym_var] = ACTIONS(4577),
    [anon_sym_yield] = ACTIONS(4577),
    [anon_sym_switch] = ACTIONS(4345),
    [anon_sym_when] = ACTIONS(4577),
    [sym_discard] = ACTIONS(4581),
    [anon_sym_DOT_DOT] = ACTIONS(4341),
    [anon_sym_and] = ACTIONS(4345),
    [anon_sym_or] = ACTIONS(4345),
    [anon_sym_AMP_AMP] = ACTIONS(4341),
    [anon_sym_PIPE_PIPE] = ACTIONS(4341),
    [anon_sym_QMARK_QMARK] = ACTIONS(4341),
    [anon_sym_from] = ACTIONS(4577),
    [anon_sym_into] = ACTIONS(4577),
    [anon_sym_join] = ACTIONS(4577),
    [anon_sym_on] = ACTIONS(4577),
    [anon_sym_equals] = ACTIONS(4577),
    [anon_sym_let] = ACTIONS(4577),
    [anon_sym_orderby] = ACTIONS(4577),
    [anon_sym_ascending] = ACTIONS(4577),
    [anon_sym_descending] = ACTIONS(4577),
    [anon_sym_group] = ACTIONS(4577),
    [anon_sym_by] = ACTIONS(4577),
    [anon_sym_select] = ACTIONS(4577),
    [anon_sym_as] = ACTIONS(4345),
    [anon_sym_is] = ACTIONS(4345),
    [anon_sym_DASH_GT] = ACTIONS(4341),
    [anon_sym_with] = ACTIONS(4345),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4341),
  },
  [2965] = {
    [sym_modifier] = STATE(3807),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7380),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(2965),
    [sym_preproc_endregion] = STATE(2965),
    [sym_preproc_line] = STATE(2965),
    [sym_preproc_pragma] = STATE(2965),
    [sym_preproc_nullable] = STATE(2965),
    [sym_preproc_error] = STATE(2965),
    [sym_preproc_warning] = STATE(2965),
    [sym_preproc_define] = STATE(2965),
    [sym_preproc_undef] = STATE(2965),
    [aux_sym_class_declaration_repeat2] = STATE(3733),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_extern] = ACTIONS(65),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_unsafe] = ACTIONS(65),
    [anon_sym_static] = ACTIONS(65),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_class] = ACTIONS(4606),
    [anon_sym_ref] = ACTIONS(4608),
    [anon_sym_struct] = ACTIONS(4610),
    [anon_sym_enum] = ACTIONS(4612),
    [anon_sym_interface] = ACTIONS(4614),
    [anon_sym_delegate] = ACTIONS(4616),
    [anon_sym_record] = ACTIONS(4618),
    [anon_sym_abstract] = ACTIONS(65),
    [anon_sym_async] = ACTIONS(65),
    [anon_sym_const] = ACTIONS(65),
    [anon_sym_file] = ACTIONS(4573),
    [anon_sym_fixed] = ACTIONS(65),
    [anon_sym_internal] = ACTIONS(65),
    [anon_sym_new] = ACTIONS(65),
    [anon_sym_override] = ACTIONS(65),
    [anon_sym_partial] = ACTIONS(65),
    [anon_sym_private] = ACTIONS(65),
    [anon_sym_protected] = ACTIONS(65),
    [anon_sym_public] = ACTIONS(65),
    [anon_sym_readonly] = ACTIONS(65),
    [anon_sym_required] = ACTIONS(65),
    [anon_sym_sealed] = ACTIONS(65),
    [anon_sym_virtual] = ACTIONS(65),
    [anon_sym_volatile] = ACTIONS(65),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2966] = {
    [sym_preproc_region] = STATE(2966),
    [sym_preproc_endregion] = STATE(2966),
    [sym_preproc_line] = STATE(2966),
    [sym_preproc_pragma] = STATE(2966),
    [sym_preproc_nullable] = STATE(2966),
    [sym_preproc_error] = STATE(2966),
    [sym_preproc_warning] = STATE(2966),
    [sym_preproc_define] = STATE(2966),
    [sym_preproc_undef] = STATE(2966),
    [sym__identifier_token] = ACTIONS(4492),
    [anon_sym_alias] = ACTIONS(4492),
    [anon_sym_SEMI] = ACTIONS(4494),
    [anon_sym_global] = ACTIONS(4492),
    [anon_sym_LBRACK] = ACTIONS(4593),
    [anon_sym_COLON] = ACTIONS(4494),
    [anon_sym_COMMA] = ACTIONS(4494),
    [anon_sym_RBRACK] = ACTIONS(4494),
    [anon_sym_LPAREN] = ACTIONS(4494),
    [anon_sym_RPAREN] = ACTIONS(4494),
    [anon_sym_LBRACE] = ACTIONS(4494),
    [anon_sym_RBRACE] = ACTIONS(4494),
    [anon_sym_file] = ACTIONS(4492),
    [anon_sym_LT] = ACTIONS(4492),
    [anon_sym_GT] = ACTIONS(4492),
    [anon_sym_in] = ACTIONS(4492),
    [anon_sym_where] = ACTIONS(4492),
    [anon_sym_QMARK] = ACTIONS(4596),
    [anon_sym_notnull] = ACTIONS(4492),
    [anon_sym_unmanaged] = ACTIONS(4492),
    [anon_sym_BANG] = ACTIONS(4492),
    [anon_sym_PLUS_PLUS] = ACTIONS(4494),
    [anon_sym_DASH_DASH] = ACTIONS(4494),
    [anon_sym_PLUS] = ACTIONS(4492),
    [anon_sym_DASH] = ACTIONS(4492),
    [anon_sym_STAR] = ACTIONS(4494),
    [anon_sym_SLASH] = ACTIONS(4492),
    [anon_sym_PERCENT] = ACTIONS(4494),
    [anon_sym_CARET] = ACTIONS(4494),
    [anon_sym_PIPE] = ACTIONS(4492),
    [anon_sym_AMP] = ACTIONS(4492),
    [anon_sym_LT_LT] = ACTIONS(4494),
    [anon_sym_GT_GT] = ACTIONS(4492),
    [anon_sym_GT_GT_GT] = ACTIONS(4494),
    [anon_sym_EQ_EQ] = ACTIONS(4494),
    [anon_sym_BANG_EQ] = ACTIONS(4494),
    [anon_sym_GT_EQ] = ACTIONS(4494),
    [anon_sym_LT_EQ] = ACTIONS(4494),
    [anon_sym_DOT] = ACTIONS(4492),
    [anon_sym_scoped] = ACTIONS(4492),
    [anon_sym_EQ_GT] = ACTIONS(4494),
    [anon_sym_var] = ACTIONS(4492),
    [anon_sym_yield] = ACTIONS(4492),
    [anon_sym_switch] = ACTIONS(4492),
    [anon_sym_when] = ACTIONS(4492),
    [sym_discard] = ACTIONS(4492),
    [anon_sym_DOT_DOT] = ACTIONS(4494),
    [anon_sym_and] = ACTIONS(4492),
    [anon_sym_or] = ACTIONS(4492),
    [anon_sym_AMP_AMP] = ACTIONS(4494),
    [anon_sym_PIPE_PIPE] = ACTIONS(4494),
    [anon_sym_QMARK_QMARK] = ACTIONS(4494),
    [anon_sym_from] = ACTIONS(4492),
    [anon_sym_into] = ACTIONS(4492),
    [anon_sym_join] = ACTIONS(4492),
    [anon_sym_on] = ACTIONS(4492),
    [anon_sym_equals] = ACTIONS(4492),
    [anon_sym_let] = ACTIONS(4492),
    [anon_sym_orderby] = ACTIONS(4492),
    [anon_sym_ascending] = ACTIONS(4492),
    [anon_sym_descending] = ACTIONS(4492),
    [anon_sym_group] = ACTIONS(4492),
    [anon_sym_by] = ACTIONS(4492),
    [anon_sym_select] = ACTIONS(4492),
    [anon_sym_as] = ACTIONS(4492),
    [anon_sym_is] = ACTIONS(4492),
    [anon_sym_DASH_GT] = ACTIONS(4494),
    [anon_sym_with] = ACTIONS(4492),
    [aux_sym_preproc_if_token3] = ACTIONS(4494),
    [aux_sym_preproc_else_token1] = ACTIONS(4494),
    [aux_sym_preproc_elif_token1] = ACTIONS(4494),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2967] = {
    [sym_preproc_region] = STATE(2967),
    [sym_preproc_endregion] = STATE(2967),
    [sym_preproc_line] = STATE(2967),
    [sym_preproc_pragma] = STATE(2967),
    [sym_preproc_nullable] = STATE(2967),
    [sym_preproc_error] = STATE(2967),
    [sym_preproc_warning] = STATE(2967),
    [sym_preproc_define] = STATE(2967),
    [sym_preproc_undef] = STATE(2967),
    [sym__identifier_token] = ACTIONS(4179),
    [anon_sym_alias] = ACTIONS(4179),
    [anon_sym_global] = ACTIONS(4179),
    [anon_sym_EQ] = ACTIONS(4183),
    [anon_sym_LBRACK] = ACTIONS(4185),
    [anon_sym_LPAREN] = ACTIONS(4185),
    [anon_sym_file] = ACTIONS(4179),
    [anon_sym_LT] = ACTIONS(4183),
    [anon_sym_GT] = ACTIONS(4183),
    [anon_sym_where] = ACTIONS(4179),
    [anon_sym_QMARK] = ACTIONS(4188),
    [anon_sym_notnull] = ACTIONS(4179),
    [anon_sym_unmanaged] = ACTIONS(4179),
    [anon_sym_BANG] = ACTIONS(4183),
    [anon_sym_PLUS_PLUS] = ACTIONS(4191),
    [anon_sym_DASH_DASH] = ACTIONS(4191),
    [anon_sym_PLUS] = ACTIONS(4183),
    [anon_sym_DASH] = ACTIONS(4183),
    [anon_sym_STAR] = ACTIONS(4188),
    [anon_sym_SLASH] = ACTIONS(4183),
    [anon_sym_PERCENT] = ACTIONS(4183),
    [anon_sym_CARET] = ACTIONS(4183),
    [anon_sym_PIPE] = ACTIONS(4183),
    [anon_sym_AMP] = ACTIONS(4183),
    [anon_sym_LT_LT] = ACTIONS(4183),
    [anon_sym_GT_GT] = ACTIONS(4183),
    [anon_sym_GT_GT_GT] = ACTIONS(4183),
    [anon_sym_EQ_EQ] = ACTIONS(4191),
    [anon_sym_BANG_EQ] = ACTIONS(4191),
    [anon_sym_GT_EQ] = ACTIONS(4191),
    [anon_sym_LT_EQ] = ACTIONS(4191),
    [anon_sym_DOT] = ACTIONS(4188),
    [anon_sym_scoped] = ACTIONS(4179),
    [anon_sym_var] = ACTIONS(4179),
    [anon_sym_yield] = ACTIONS(4179),
    [anon_sym_switch] = ACTIONS(4183),
    [anon_sym_when] = ACTIONS(4179),
    [anon_sym_DOT_DOT] = ACTIONS(4191),
    [anon_sym_and] = ACTIONS(4183),
    [anon_sym_or] = ACTIONS(4183),
    [anon_sym_PLUS_EQ] = ACTIONS(4191),
    [anon_sym_DASH_EQ] = ACTIONS(4191),
    [anon_sym_STAR_EQ] = ACTIONS(4191),
    [anon_sym_SLASH_EQ] = ACTIONS(4191),
    [anon_sym_PERCENT_EQ] = ACTIONS(4191),
    [anon_sym_AMP_EQ] = ACTIONS(4191),
    [anon_sym_CARET_EQ] = ACTIONS(4191),
    [anon_sym_PIPE_EQ] = ACTIONS(4191),
    [anon_sym_LT_LT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4191),
    [anon_sym_AMP_AMP] = ACTIONS(4191),
    [anon_sym_PIPE_PIPE] = ACTIONS(4191),
    [anon_sym_QMARK_QMARK] = ACTIONS(4183),
    [anon_sym_from] = ACTIONS(4179),
    [anon_sym_into] = ACTIONS(4179),
    [anon_sym_join] = ACTIONS(4179),
    [anon_sym_on] = ACTIONS(4188),
    [anon_sym_equals] = ACTIONS(4179),
    [anon_sym_let] = ACTIONS(4179),
    [anon_sym_orderby] = ACTIONS(4179),
    [anon_sym_ascending] = ACTIONS(4179),
    [anon_sym_descending] = ACTIONS(4179),
    [anon_sym_group] = ACTIONS(4179),
    [anon_sym_by] = ACTIONS(4179),
    [anon_sym_select] = ACTIONS(4179),
    [anon_sym_as] = ACTIONS(4183),
    [anon_sym_is] = ACTIONS(4183),
    [anon_sym_DASH_GT] = ACTIONS(4185),
    [anon_sym_with] = ACTIONS(4183),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2968] = {
    [sym_preproc_region] = STATE(2968),
    [sym_preproc_endregion] = STATE(2968),
    [sym_preproc_line] = STATE(2968),
    [sym_preproc_pragma] = STATE(2968),
    [sym_preproc_nullable] = STATE(2968),
    [sym_preproc_error] = STATE(2968),
    [sym_preproc_warning] = STATE(2968),
    [sym_preproc_define] = STATE(2968),
    [sym_preproc_undef] = STATE(2968),
    [sym__identifier_token] = ACTIONS(4620),
    [anon_sym_alias] = ACTIONS(4620),
    [anon_sym_SEMI] = ACTIONS(4622),
    [anon_sym_global] = ACTIONS(4620),
    [anon_sym_LBRACK] = ACTIONS(4622),
    [anon_sym_COLON] = ACTIONS(4622),
    [anon_sym_COMMA] = ACTIONS(4622),
    [anon_sym_RBRACK] = ACTIONS(4622),
    [anon_sym_LPAREN] = ACTIONS(4622),
    [anon_sym_RPAREN] = ACTIONS(4622),
    [anon_sym_LBRACE] = ACTIONS(4622),
    [anon_sym_RBRACE] = ACTIONS(4622),
    [anon_sym_file] = ACTIONS(4620),
    [anon_sym_LT] = ACTIONS(4620),
    [anon_sym_GT] = ACTIONS(4620),
    [anon_sym_in] = ACTIONS(4620),
    [anon_sym_where] = ACTIONS(4620),
    [anon_sym_QMARK] = ACTIONS(4620),
    [anon_sym_notnull] = ACTIONS(4620),
    [anon_sym_unmanaged] = ACTIONS(4620),
    [anon_sym_BANG] = ACTIONS(4620),
    [anon_sym_PLUS_PLUS] = ACTIONS(4622),
    [anon_sym_DASH_DASH] = ACTIONS(4622),
    [anon_sym_PLUS] = ACTIONS(4620),
    [anon_sym_DASH] = ACTIONS(4620),
    [anon_sym_STAR] = ACTIONS(4622),
    [anon_sym_SLASH] = ACTIONS(4620),
    [anon_sym_PERCENT] = ACTIONS(4622),
    [anon_sym_CARET] = ACTIONS(4622),
    [anon_sym_PIPE] = ACTIONS(4620),
    [anon_sym_AMP] = ACTIONS(4620),
    [anon_sym_LT_LT] = ACTIONS(4622),
    [anon_sym_GT_GT] = ACTIONS(4620),
    [anon_sym_GT_GT_GT] = ACTIONS(4622),
    [anon_sym_EQ_EQ] = ACTIONS(4622),
    [anon_sym_BANG_EQ] = ACTIONS(4622),
    [anon_sym_GT_EQ] = ACTIONS(4622),
    [anon_sym_LT_EQ] = ACTIONS(4622),
    [anon_sym_DOT] = ACTIONS(4620),
    [anon_sym_scoped] = ACTIONS(4620),
    [anon_sym_EQ_GT] = ACTIONS(4622),
    [anon_sym_var] = ACTIONS(4620),
    [anon_sym_yield] = ACTIONS(4620),
    [anon_sym_switch] = ACTIONS(4620),
    [anon_sym_when] = ACTIONS(4620),
    [sym_discard] = ACTIONS(4620),
    [anon_sym_DOT_DOT] = ACTIONS(4622),
    [anon_sym_and] = ACTIONS(4620),
    [anon_sym_or] = ACTIONS(4620),
    [anon_sym_AMP_AMP] = ACTIONS(4622),
    [anon_sym_PIPE_PIPE] = ACTIONS(4622),
    [anon_sym_QMARK_QMARK] = ACTIONS(4622),
    [anon_sym_from] = ACTIONS(4620),
    [anon_sym_into] = ACTIONS(4620),
    [anon_sym_join] = ACTIONS(4620),
    [anon_sym_on] = ACTIONS(4620),
    [anon_sym_equals] = ACTIONS(4620),
    [anon_sym_let] = ACTIONS(4620),
    [anon_sym_orderby] = ACTIONS(4620),
    [anon_sym_ascending] = ACTIONS(4620),
    [anon_sym_descending] = ACTIONS(4620),
    [anon_sym_group] = ACTIONS(4620),
    [anon_sym_by] = ACTIONS(4620),
    [anon_sym_select] = ACTIONS(4620),
    [anon_sym_as] = ACTIONS(4620),
    [anon_sym_is] = ACTIONS(4620),
    [anon_sym_DASH_GT] = ACTIONS(4622),
    [anon_sym_with] = ACTIONS(4620),
    [aux_sym_preproc_if_token3] = ACTIONS(4622),
    [aux_sym_preproc_else_token1] = ACTIONS(4622),
    [aux_sym_preproc_elif_token1] = ACTIONS(4622),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2969] = {
    [sym_preproc_region] = STATE(2969),
    [sym_preproc_endregion] = STATE(2969),
    [sym_preproc_line] = STATE(2969),
    [sym_preproc_pragma] = STATE(2969),
    [sym_preproc_nullable] = STATE(2969),
    [sym_preproc_error] = STATE(2969),
    [sym_preproc_warning] = STATE(2969),
    [sym_preproc_define] = STATE(2969),
    [sym_preproc_undef] = STATE(2969),
    [sym__identifier_token] = ACTIONS(4624),
    [anon_sym_alias] = ACTIONS(4624),
    [anon_sym_SEMI] = ACTIONS(4626),
    [anon_sym_global] = ACTIONS(4624),
    [anon_sym_LBRACK] = ACTIONS(4626),
    [anon_sym_COLON] = ACTIONS(4626),
    [anon_sym_COMMA] = ACTIONS(4626),
    [anon_sym_RBRACK] = ACTIONS(4626),
    [anon_sym_LPAREN] = ACTIONS(4626),
    [anon_sym_RPAREN] = ACTIONS(4626),
    [anon_sym_LBRACE] = ACTIONS(4626),
    [anon_sym_RBRACE] = ACTIONS(4626),
    [anon_sym_file] = ACTIONS(4624),
    [anon_sym_LT] = ACTIONS(4624),
    [anon_sym_GT] = ACTIONS(4624),
    [anon_sym_in] = ACTIONS(4624),
    [anon_sym_where] = ACTIONS(4624),
    [anon_sym_QMARK] = ACTIONS(4624),
    [anon_sym_notnull] = ACTIONS(4624),
    [anon_sym_unmanaged] = ACTIONS(4624),
    [anon_sym_BANG] = ACTIONS(4624),
    [anon_sym_PLUS_PLUS] = ACTIONS(4626),
    [anon_sym_DASH_DASH] = ACTIONS(4626),
    [anon_sym_PLUS] = ACTIONS(4624),
    [anon_sym_DASH] = ACTIONS(4624),
    [anon_sym_STAR] = ACTIONS(4626),
    [anon_sym_SLASH] = ACTIONS(4624),
    [anon_sym_PERCENT] = ACTIONS(4626),
    [anon_sym_CARET] = ACTIONS(4626),
    [anon_sym_PIPE] = ACTIONS(4624),
    [anon_sym_AMP] = ACTIONS(4624),
    [anon_sym_LT_LT] = ACTIONS(4626),
    [anon_sym_GT_GT] = ACTIONS(4624),
    [anon_sym_GT_GT_GT] = ACTIONS(4626),
    [anon_sym_EQ_EQ] = ACTIONS(4626),
    [anon_sym_BANG_EQ] = ACTIONS(4626),
    [anon_sym_GT_EQ] = ACTIONS(4626),
    [anon_sym_LT_EQ] = ACTIONS(4626),
    [anon_sym_DOT] = ACTIONS(4624),
    [anon_sym_scoped] = ACTIONS(4624),
    [anon_sym_EQ_GT] = ACTIONS(4626),
    [anon_sym_var] = ACTIONS(4624),
    [anon_sym_yield] = ACTIONS(4624),
    [anon_sym_switch] = ACTIONS(4624),
    [anon_sym_when] = ACTIONS(4624),
    [sym_discard] = ACTIONS(4624),
    [anon_sym_DOT_DOT] = ACTIONS(4626),
    [anon_sym_and] = ACTIONS(4624),
    [anon_sym_or] = ACTIONS(4624),
    [anon_sym_AMP_AMP] = ACTIONS(4626),
    [anon_sym_PIPE_PIPE] = ACTIONS(4626),
    [anon_sym_QMARK_QMARK] = ACTIONS(4626),
    [anon_sym_from] = ACTIONS(4624),
    [anon_sym_into] = ACTIONS(4624),
    [anon_sym_join] = ACTIONS(4624),
    [anon_sym_on] = ACTIONS(4624),
    [anon_sym_equals] = ACTIONS(4624),
    [anon_sym_let] = ACTIONS(4624),
    [anon_sym_orderby] = ACTIONS(4624),
    [anon_sym_ascending] = ACTIONS(4624),
    [anon_sym_descending] = ACTIONS(4624),
    [anon_sym_group] = ACTIONS(4624),
    [anon_sym_by] = ACTIONS(4624),
    [anon_sym_select] = ACTIONS(4624),
    [anon_sym_as] = ACTIONS(4624),
    [anon_sym_is] = ACTIONS(4624),
    [anon_sym_DASH_GT] = ACTIONS(4626),
    [anon_sym_with] = ACTIONS(4624),
    [aux_sym_preproc_if_token3] = ACTIONS(4626),
    [aux_sym_preproc_else_token1] = ACTIONS(4626),
    [aux_sym_preproc_elif_token1] = ACTIONS(4626),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2970] = {
    [sym_preproc_region] = STATE(2970),
    [sym_preproc_endregion] = STATE(2970),
    [sym_preproc_line] = STATE(2970),
    [sym_preproc_pragma] = STATE(2970),
    [sym_preproc_nullable] = STATE(2970),
    [sym_preproc_error] = STATE(2970),
    [sym_preproc_warning] = STATE(2970),
    [sym_preproc_define] = STATE(2970),
    [sym_preproc_undef] = STATE(2970),
    [sym__identifier_token] = ACTIONS(4492),
    [anon_sym_alias] = ACTIONS(4492),
    [anon_sym_SEMI] = ACTIONS(4494),
    [anon_sym_global] = ACTIONS(4492),
    [anon_sym_LBRACK] = ACTIONS(4593),
    [anon_sym_COLON] = ACTIONS(4494),
    [anon_sym_COMMA] = ACTIONS(4494),
    [anon_sym_RBRACK] = ACTIONS(4494),
    [anon_sym_LPAREN] = ACTIONS(4494),
    [anon_sym_RPAREN] = ACTIONS(4494),
    [anon_sym_LBRACE] = ACTIONS(4494),
    [anon_sym_RBRACE] = ACTIONS(4494),
    [anon_sym_file] = ACTIONS(4492),
    [anon_sym_LT] = ACTIONS(4492),
    [anon_sym_GT] = ACTIONS(4492),
    [anon_sym_in] = ACTIONS(4492),
    [anon_sym_where] = ACTIONS(4492),
    [anon_sym_QMARK] = ACTIONS(4492),
    [anon_sym_notnull] = ACTIONS(4492),
    [anon_sym_unmanaged] = ACTIONS(4492),
    [anon_sym_BANG] = ACTIONS(4492),
    [anon_sym_PLUS_PLUS] = ACTIONS(4494),
    [anon_sym_DASH_DASH] = ACTIONS(4494),
    [anon_sym_PLUS] = ACTIONS(4492),
    [anon_sym_DASH] = ACTIONS(4492),
    [anon_sym_STAR] = ACTIONS(4599),
    [anon_sym_SLASH] = ACTIONS(4492),
    [anon_sym_PERCENT] = ACTIONS(4494),
    [anon_sym_CARET] = ACTIONS(4494),
    [anon_sym_PIPE] = ACTIONS(4492),
    [anon_sym_AMP] = ACTIONS(4492),
    [anon_sym_LT_LT] = ACTIONS(4494),
    [anon_sym_GT_GT] = ACTIONS(4492),
    [anon_sym_GT_GT_GT] = ACTIONS(4494),
    [anon_sym_EQ_EQ] = ACTIONS(4494),
    [anon_sym_BANG_EQ] = ACTIONS(4494),
    [anon_sym_GT_EQ] = ACTIONS(4494),
    [anon_sym_LT_EQ] = ACTIONS(4494),
    [anon_sym_DOT] = ACTIONS(4492),
    [anon_sym_scoped] = ACTIONS(4492),
    [anon_sym_EQ_GT] = ACTIONS(4494),
    [anon_sym_var] = ACTIONS(4492),
    [anon_sym_yield] = ACTIONS(4492),
    [anon_sym_switch] = ACTIONS(4492),
    [anon_sym_when] = ACTIONS(4492),
    [sym_discard] = ACTIONS(4492),
    [anon_sym_DOT_DOT] = ACTIONS(4494),
    [anon_sym_and] = ACTIONS(4492),
    [anon_sym_or] = ACTIONS(4492),
    [anon_sym_AMP_AMP] = ACTIONS(4494),
    [anon_sym_PIPE_PIPE] = ACTIONS(4494),
    [anon_sym_QMARK_QMARK] = ACTIONS(4494),
    [anon_sym_from] = ACTIONS(4492),
    [anon_sym_into] = ACTIONS(4492),
    [anon_sym_join] = ACTIONS(4492),
    [anon_sym_on] = ACTIONS(4492),
    [anon_sym_equals] = ACTIONS(4492),
    [anon_sym_let] = ACTIONS(4492),
    [anon_sym_orderby] = ACTIONS(4492),
    [anon_sym_ascending] = ACTIONS(4492),
    [anon_sym_descending] = ACTIONS(4492),
    [anon_sym_group] = ACTIONS(4492),
    [anon_sym_by] = ACTIONS(4492),
    [anon_sym_select] = ACTIONS(4492),
    [anon_sym_as] = ACTIONS(4492),
    [anon_sym_is] = ACTIONS(4492),
    [anon_sym_DASH_GT] = ACTIONS(4494),
    [anon_sym_with] = ACTIONS(4492),
    [aux_sym_preproc_if_token3] = ACTIONS(4494),
    [aux_sym_preproc_else_token1] = ACTIONS(4494),
    [aux_sym_preproc_elif_token1] = ACTIONS(4494),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2971] = {
    [sym_preproc_region] = STATE(2971),
    [sym_preproc_endregion] = STATE(2971),
    [sym_preproc_line] = STATE(2971),
    [sym_preproc_pragma] = STATE(2971),
    [sym_preproc_nullable] = STATE(2971),
    [sym_preproc_error] = STATE(2971),
    [sym_preproc_warning] = STATE(2971),
    [sym_preproc_define] = STATE(2971),
    [sym_preproc_undef] = STATE(2971),
    [sym__identifier_token] = ACTIONS(4492),
    [anon_sym_alias] = ACTIONS(4492),
    [anon_sym_SEMI] = ACTIONS(4494),
    [anon_sym_global] = ACTIONS(4492),
    [anon_sym_LBRACK] = ACTIONS(4593),
    [anon_sym_COLON] = ACTIONS(4494),
    [anon_sym_COMMA] = ACTIONS(4494),
    [anon_sym_RBRACK] = ACTIONS(4494),
    [anon_sym_LPAREN] = ACTIONS(4494),
    [anon_sym_RPAREN] = ACTIONS(4494),
    [anon_sym_LBRACE] = ACTIONS(4494),
    [anon_sym_RBRACE] = ACTIONS(4494),
    [anon_sym_file] = ACTIONS(4492),
    [anon_sym_LT] = ACTIONS(4492),
    [anon_sym_GT] = ACTIONS(4492),
    [anon_sym_in] = ACTIONS(4492),
    [anon_sym_where] = ACTIONS(4492),
    [anon_sym_QMARK] = ACTIONS(4596),
    [anon_sym_notnull] = ACTIONS(4492),
    [anon_sym_unmanaged] = ACTIONS(4492),
    [anon_sym_BANG] = ACTIONS(4492),
    [anon_sym_PLUS_PLUS] = ACTIONS(4494),
    [anon_sym_DASH_DASH] = ACTIONS(4494),
    [anon_sym_PLUS] = ACTIONS(4492),
    [anon_sym_DASH] = ACTIONS(4492),
    [anon_sym_STAR] = ACTIONS(4599),
    [anon_sym_SLASH] = ACTIONS(4492),
    [anon_sym_PERCENT] = ACTIONS(4494),
    [anon_sym_CARET] = ACTIONS(4494),
    [anon_sym_PIPE] = ACTIONS(4492),
    [anon_sym_AMP] = ACTIONS(4492),
    [anon_sym_LT_LT] = ACTIONS(4494),
    [anon_sym_GT_GT] = ACTIONS(4492),
    [anon_sym_GT_GT_GT] = ACTIONS(4494),
    [anon_sym_EQ_EQ] = ACTIONS(4494),
    [anon_sym_BANG_EQ] = ACTIONS(4494),
    [anon_sym_GT_EQ] = ACTIONS(4494),
    [anon_sym_LT_EQ] = ACTIONS(4494),
    [anon_sym_DOT] = ACTIONS(4492),
    [anon_sym_scoped] = ACTIONS(4492),
    [anon_sym_EQ_GT] = ACTIONS(4494),
    [anon_sym_var] = ACTIONS(4492),
    [anon_sym_yield] = ACTIONS(4492),
    [anon_sym_switch] = ACTIONS(4492),
    [anon_sym_when] = ACTIONS(4492),
    [sym_discard] = ACTIONS(4492),
    [anon_sym_DOT_DOT] = ACTIONS(4494),
    [anon_sym_and] = ACTIONS(4492),
    [anon_sym_or] = ACTIONS(4492),
    [anon_sym_AMP_AMP] = ACTIONS(4494),
    [anon_sym_PIPE_PIPE] = ACTIONS(4494),
    [anon_sym_QMARK_QMARK] = ACTIONS(4494),
    [anon_sym_from] = ACTIONS(4492),
    [anon_sym_into] = ACTIONS(4492),
    [anon_sym_join] = ACTIONS(4492),
    [anon_sym_on] = ACTIONS(4492),
    [anon_sym_equals] = ACTIONS(4492),
    [anon_sym_let] = ACTIONS(4492),
    [anon_sym_orderby] = ACTIONS(4492),
    [anon_sym_ascending] = ACTIONS(4492),
    [anon_sym_descending] = ACTIONS(4492),
    [anon_sym_group] = ACTIONS(4492),
    [anon_sym_by] = ACTIONS(4492),
    [anon_sym_select] = ACTIONS(4492),
    [anon_sym_as] = ACTIONS(4492),
    [anon_sym_is] = ACTIONS(4492),
    [anon_sym_DASH_GT] = ACTIONS(4494),
    [anon_sym_with] = ACTIONS(4492),
    [aux_sym_preproc_if_token3] = ACTIONS(4494),
    [aux_sym_preproc_else_token1] = ACTIONS(4494),
    [aux_sym_preproc_elif_token1] = ACTIONS(4494),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2972] = {
    [sym_preproc_region] = STATE(2972),
    [sym_preproc_endregion] = STATE(2972),
    [sym_preproc_line] = STATE(2972),
    [sym_preproc_pragma] = STATE(2972),
    [sym_preproc_nullable] = STATE(2972),
    [sym_preproc_error] = STATE(2972),
    [sym_preproc_warning] = STATE(2972),
    [sym_preproc_define] = STATE(2972),
    [sym_preproc_undef] = STATE(2972),
    [sym__identifier_token] = ACTIONS(4179),
    [anon_sym_alias] = ACTIONS(4179),
    [anon_sym_SEMI] = ACTIONS(4181),
    [anon_sym_global] = ACTIONS(4179),
    [anon_sym_LBRACK] = ACTIONS(4181),
    [anon_sym_COLON] = ACTIONS(4181),
    [anon_sym_COMMA] = ACTIONS(4181),
    [anon_sym_RBRACK] = ACTIONS(4181),
    [anon_sym_LPAREN] = ACTIONS(4181),
    [anon_sym_RPAREN] = ACTIONS(4181),
    [anon_sym_LBRACE] = ACTIONS(4181),
    [anon_sym_RBRACE] = ACTIONS(4181),
    [anon_sym_file] = ACTIONS(4179),
    [anon_sym_LT] = ACTIONS(4179),
    [anon_sym_GT] = ACTIONS(4179),
    [anon_sym_in] = ACTIONS(4179),
    [anon_sym_where] = ACTIONS(4179),
    [anon_sym_QMARK] = ACTIONS(4179),
    [anon_sym_notnull] = ACTIONS(4179),
    [anon_sym_unmanaged] = ACTIONS(4179),
    [anon_sym_BANG] = ACTIONS(4179),
    [anon_sym_PLUS_PLUS] = ACTIONS(4181),
    [anon_sym_DASH_DASH] = ACTIONS(4181),
    [anon_sym_PLUS] = ACTIONS(4179),
    [anon_sym_DASH] = ACTIONS(4179),
    [anon_sym_STAR] = ACTIONS(4181),
    [anon_sym_SLASH] = ACTIONS(4179),
    [anon_sym_PERCENT] = ACTIONS(4181),
    [anon_sym_CARET] = ACTIONS(4181),
    [anon_sym_PIPE] = ACTIONS(4179),
    [anon_sym_AMP] = ACTIONS(4179),
    [anon_sym_LT_LT] = ACTIONS(4181),
    [anon_sym_GT_GT] = ACTIONS(4179),
    [anon_sym_GT_GT_GT] = ACTIONS(4181),
    [anon_sym_EQ_EQ] = ACTIONS(4181),
    [anon_sym_BANG_EQ] = ACTIONS(4181),
    [anon_sym_GT_EQ] = ACTIONS(4181),
    [anon_sym_LT_EQ] = ACTIONS(4181),
    [anon_sym_DOT] = ACTIONS(4179),
    [anon_sym_scoped] = ACTIONS(4179),
    [anon_sym_EQ_GT] = ACTIONS(4181),
    [anon_sym_var] = ACTIONS(4179),
    [anon_sym_yield] = ACTIONS(4179),
    [anon_sym_switch] = ACTIONS(4179),
    [anon_sym_when] = ACTIONS(4179),
    [sym_discard] = ACTIONS(4179),
    [anon_sym_DOT_DOT] = ACTIONS(4181),
    [anon_sym_and] = ACTIONS(4179),
    [anon_sym_or] = ACTIONS(4179),
    [anon_sym_AMP_AMP] = ACTIONS(4181),
    [anon_sym_PIPE_PIPE] = ACTIONS(4181),
    [anon_sym_QMARK_QMARK] = ACTIONS(4181),
    [anon_sym_from] = ACTIONS(4179),
    [anon_sym_into] = ACTIONS(4179),
    [anon_sym_join] = ACTIONS(4179),
    [anon_sym_on] = ACTIONS(4179),
    [anon_sym_equals] = ACTIONS(4179),
    [anon_sym_let] = ACTIONS(4179),
    [anon_sym_orderby] = ACTIONS(4179),
    [anon_sym_ascending] = ACTIONS(4179),
    [anon_sym_descending] = ACTIONS(4179),
    [anon_sym_group] = ACTIONS(4179),
    [anon_sym_by] = ACTIONS(4179),
    [anon_sym_select] = ACTIONS(4179),
    [anon_sym_as] = ACTIONS(4179),
    [anon_sym_is] = ACTIONS(4179),
    [anon_sym_DASH_GT] = ACTIONS(4181),
    [anon_sym_with] = ACTIONS(4179),
    [aux_sym_preproc_if_token3] = ACTIONS(4181),
    [aux_sym_preproc_else_token1] = ACTIONS(4181),
    [aux_sym_preproc_elif_token1] = ACTIONS(4181),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2973] = {
    [sym_preproc_region] = STATE(2973),
    [sym_preproc_endregion] = STATE(2973),
    [sym_preproc_line] = STATE(2973),
    [sym_preproc_pragma] = STATE(2973),
    [sym_preproc_nullable] = STATE(2973),
    [sym_preproc_error] = STATE(2973),
    [sym_preproc_warning] = STATE(2973),
    [sym_preproc_define] = STATE(2973),
    [sym_preproc_undef] = STATE(2973),
    [sym__identifier_token] = ACTIONS(4628),
    [anon_sym_alias] = ACTIONS(4628),
    [anon_sym_SEMI] = ACTIONS(4630),
    [anon_sym_global] = ACTIONS(4628),
    [anon_sym_LBRACK] = ACTIONS(4630),
    [anon_sym_COLON] = ACTIONS(4630),
    [anon_sym_COMMA] = ACTIONS(4630),
    [anon_sym_RBRACK] = ACTIONS(4630),
    [anon_sym_LPAREN] = ACTIONS(4630),
    [anon_sym_RPAREN] = ACTIONS(4630),
    [anon_sym_LBRACE] = ACTIONS(4630),
    [anon_sym_RBRACE] = ACTIONS(4630),
    [anon_sym_file] = ACTIONS(4628),
    [anon_sym_LT] = ACTIONS(4628),
    [anon_sym_GT] = ACTIONS(4628),
    [anon_sym_in] = ACTIONS(4628),
    [anon_sym_where] = ACTIONS(4628),
    [anon_sym_QMARK] = ACTIONS(4628),
    [anon_sym_notnull] = ACTIONS(4628),
    [anon_sym_unmanaged] = ACTIONS(4628),
    [anon_sym_BANG] = ACTIONS(4628),
    [anon_sym_PLUS_PLUS] = ACTIONS(4630),
    [anon_sym_DASH_DASH] = ACTIONS(4630),
    [anon_sym_PLUS] = ACTIONS(4628),
    [anon_sym_DASH] = ACTIONS(4628),
    [anon_sym_STAR] = ACTIONS(4630),
    [anon_sym_SLASH] = ACTIONS(4628),
    [anon_sym_PERCENT] = ACTIONS(4630),
    [anon_sym_CARET] = ACTIONS(4630),
    [anon_sym_PIPE] = ACTIONS(4628),
    [anon_sym_AMP] = ACTIONS(4628),
    [anon_sym_LT_LT] = ACTIONS(4630),
    [anon_sym_GT_GT] = ACTIONS(4628),
    [anon_sym_GT_GT_GT] = ACTIONS(4630),
    [anon_sym_EQ_EQ] = ACTIONS(4630),
    [anon_sym_BANG_EQ] = ACTIONS(4630),
    [anon_sym_GT_EQ] = ACTIONS(4630),
    [anon_sym_LT_EQ] = ACTIONS(4630),
    [anon_sym_DOT] = ACTIONS(4628),
    [anon_sym_scoped] = ACTIONS(4628),
    [anon_sym_EQ_GT] = ACTIONS(4630),
    [anon_sym_var] = ACTIONS(4628),
    [anon_sym_yield] = ACTIONS(4628),
    [anon_sym_switch] = ACTIONS(4628),
    [anon_sym_when] = ACTIONS(4628),
    [sym_discard] = ACTIONS(4628),
    [anon_sym_DOT_DOT] = ACTIONS(4630),
    [anon_sym_and] = ACTIONS(4628),
    [anon_sym_or] = ACTIONS(4628),
    [anon_sym_AMP_AMP] = ACTIONS(4630),
    [anon_sym_PIPE_PIPE] = ACTIONS(4630),
    [anon_sym_QMARK_QMARK] = ACTIONS(4630),
    [anon_sym_from] = ACTIONS(4628),
    [anon_sym_into] = ACTIONS(4628),
    [anon_sym_join] = ACTIONS(4628),
    [anon_sym_on] = ACTIONS(4628),
    [anon_sym_equals] = ACTIONS(4628),
    [anon_sym_let] = ACTIONS(4628),
    [anon_sym_orderby] = ACTIONS(4628),
    [anon_sym_ascending] = ACTIONS(4628),
    [anon_sym_descending] = ACTIONS(4628),
    [anon_sym_group] = ACTIONS(4628),
    [anon_sym_by] = ACTIONS(4628),
    [anon_sym_select] = ACTIONS(4628),
    [anon_sym_as] = ACTIONS(4628),
    [anon_sym_is] = ACTIONS(4628),
    [anon_sym_DASH_GT] = ACTIONS(4630),
    [anon_sym_with] = ACTIONS(4628),
    [aux_sym_preproc_if_token3] = ACTIONS(4630),
    [aux_sym_preproc_else_token1] = ACTIONS(4630),
    [aux_sym_preproc_elif_token1] = ACTIONS(4630),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2974] = {
    [sym_parameter_list] = STATE(9685),
    [sym_positional_pattern_clause] = STATE(3081),
    [sym_property_pattern_clause] = STATE(3135),
    [sym__variable_designation] = STATE(5777),
    [sym_parenthesized_variable_designation] = STATE(5773),
    [sym__lambda_parameters] = STATE(9890),
    [sym_identifier] = STATE(5348),
    [sym__reserved_identifier] = STATE(5200),
    [sym_preproc_region] = STATE(2974),
    [sym_preproc_endregion] = STATE(2974),
    [sym_preproc_line] = STATE(2974),
    [sym_preproc_pragma] = STATE(2974),
    [sym_preproc_nullable] = STATE(2974),
    [sym_preproc_error] = STATE(2974),
    [sym_preproc_warning] = STATE(2974),
    [sym_preproc_define] = STATE(2974),
    [sym_preproc_undef] = STATE(2974),
    [sym__identifier_token] = ACTIONS(4575),
    [anon_sym_alias] = ACTIONS(4577),
    [anon_sym_global] = ACTIONS(4577),
    [anon_sym_LBRACK] = ACTIONS(4341),
    [anon_sym_COLON] = ACTIONS(4341),
    [anon_sym_COMMA] = ACTIONS(4341),
    [anon_sym_LPAREN] = ACTIONS(4341),
    [anon_sym_LBRACE] = ACTIONS(4579),
    [anon_sym_file] = ACTIONS(4577),
    [anon_sym_LT] = ACTIONS(4345),
    [anon_sym_GT] = ACTIONS(4345),
    [anon_sym_where] = ACTIONS(4577),
    [anon_sym_QMARK] = ACTIONS(4345),
    [anon_sym_notnull] = ACTIONS(4577),
    [anon_sym_unmanaged] = ACTIONS(4577),
    [anon_sym_BANG] = ACTIONS(4345),
    [anon_sym_PLUS_PLUS] = ACTIONS(4341),
    [anon_sym_DASH_DASH] = ACTIONS(4341),
    [anon_sym_PLUS] = ACTIONS(4345),
    [anon_sym_DASH] = ACTIONS(4345),
    [anon_sym_STAR] = ACTIONS(4341),
    [anon_sym_SLASH] = ACTIONS(4345),
    [anon_sym_PERCENT] = ACTIONS(4341),
    [anon_sym_CARET] = ACTIONS(4341),
    [anon_sym_PIPE] = ACTIONS(4345),
    [anon_sym_AMP] = ACTIONS(4345),
    [anon_sym_LT_LT] = ACTIONS(4341),
    [anon_sym_GT_GT] = ACTIONS(4345),
    [anon_sym_GT_GT_GT] = ACTIONS(4341),
    [anon_sym_EQ_EQ] = ACTIONS(4341),
    [anon_sym_BANG_EQ] = ACTIONS(4341),
    [anon_sym_GT_EQ] = ACTIONS(4341),
    [anon_sym_LT_EQ] = ACTIONS(4341),
    [anon_sym_DOT] = ACTIONS(4345),
    [anon_sym_scoped] = ACTIONS(4577),
    [anon_sym_var] = ACTIONS(4577),
    [anon_sym_yield] = ACTIONS(4577),
    [anon_sym_switch] = ACTIONS(4345),
    [anon_sym_when] = ACTIONS(4577),
    [sym_discard] = ACTIONS(4581),
    [anon_sym_DOT_DOT] = ACTIONS(4341),
    [anon_sym_and] = ACTIONS(4355),
    [anon_sym_or] = ACTIONS(4355),
    [anon_sym_AMP_AMP] = ACTIONS(4341),
    [anon_sym_PIPE_PIPE] = ACTIONS(4341),
    [anon_sym_QMARK_QMARK] = ACTIONS(4341),
    [anon_sym_from] = ACTIONS(4577),
    [anon_sym_into] = ACTIONS(4345),
    [anon_sym_join] = ACTIONS(4577),
    [anon_sym_on] = ACTIONS(4577),
    [anon_sym_equals] = ACTIONS(4577),
    [anon_sym_let] = ACTIONS(4577),
    [anon_sym_orderby] = ACTIONS(4577),
    [anon_sym_ascending] = ACTIONS(4577),
    [anon_sym_descending] = ACTIONS(4577),
    [anon_sym_group] = ACTIONS(4577),
    [anon_sym_by] = ACTIONS(4577),
    [anon_sym_select] = ACTIONS(4577),
    [anon_sym_as] = ACTIONS(4345),
    [anon_sym_is] = ACTIONS(4345),
    [anon_sym_DASH_GT] = ACTIONS(4341),
    [anon_sym_with] = ACTIONS(4345),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4341),
  },
  [2975] = {
    [sym_preproc_region] = STATE(2975),
    [sym_preproc_endregion] = STATE(2975),
    [sym_preproc_line] = STATE(2975),
    [sym_preproc_pragma] = STATE(2975),
    [sym_preproc_nullable] = STATE(2975),
    [sym_preproc_error] = STATE(2975),
    [sym_preproc_warning] = STATE(2975),
    [sym_preproc_define] = STATE(2975),
    [sym_preproc_undef] = STATE(2975),
    [sym__identifier_token] = ACTIONS(4157),
    [anon_sym_alias] = ACTIONS(4157),
    [anon_sym_global] = ACTIONS(4157),
    [anon_sym_EQ] = ACTIONS(4162),
    [anon_sym_LBRACK] = ACTIONS(4193),
    [anon_sym_LPAREN] = ACTIONS(4193),
    [anon_sym_file] = ACTIONS(4157),
    [anon_sym_LT] = ACTIONS(4162),
    [anon_sym_GT] = ACTIONS(4162),
    [anon_sym_where] = ACTIONS(4196),
    [anon_sym_QMARK] = ACTIONS(4196),
    [anon_sym_notnull] = ACTIONS(4157),
    [anon_sym_unmanaged] = ACTIONS(4157),
    [anon_sym_BANG] = ACTIONS(4162),
    [anon_sym_PLUS_PLUS] = ACTIONS(4177),
    [anon_sym_DASH_DASH] = ACTIONS(4177),
    [anon_sym_PLUS] = ACTIONS(4162),
    [anon_sym_DASH] = ACTIONS(4162),
    [anon_sym_STAR] = ACTIONS(4196),
    [anon_sym_SLASH] = ACTIONS(4162),
    [anon_sym_PERCENT] = ACTIONS(4162),
    [anon_sym_CARET] = ACTIONS(4162),
    [anon_sym_PIPE] = ACTIONS(4162),
    [anon_sym_AMP] = ACTIONS(4162),
    [anon_sym_LT_LT] = ACTIONS(4162),
    [anon_sym_GT_GT] = ACTIONS(4162),
    [anon_sym_GT_GT_GT] = ACTIONS(4162),
    [anon_sym_EQ_EQ] = ACTIONS(4177),
    [anon_sym_BANG_EQ] = ACTIONS(4177),
    [anon_sym_GT_EQ] = ACTIONS(4177),
    [anon_sym_LT_EQ] = ACTIONS(4177),
    [anon_sym_DOT] = ACTIONS(4196),
    [anon_sym_scoped] = ACTIONS(4157),
    [anon_sym_var] = ACTIONS(4157),
    [anon_sym_yield] = ACTIONS(4157),
    [anon_sym_switch] = ACTIONS(4162),
    [anon_sym_when] = ACTIONS(4157),
    [anon_sym_DOT_DOT] = ACTIONS(4177),
    [anon_sym_and] = ACTIONS(4162),
    [anon_sym_or] = ACTIONS(4162),
    [anon_sym_PLUS_EQ] = ACTIONS(4177),
    [anon_sym_DASH_EQ] = ACTIONS(4177),
    [anon_sym_STAR_EQ] = ACTIONS(4177),
    [anon_sym_SLASH_EQ] = ACTIONS(4177),
    [anon_sym_PERCENT_EQ] = ACTIONS(4177),
    [anon_sym_AMP_EQ] = ACTIONS(4177),
    [anon_sym_CARET_EQ] = ACTIONS(4177),
    [anon_sym_PIPE_EQ] = ACTIONS(4177),
    [anon_sym_LT_LT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4177),
    [anon_sym_AMP_AMP] = ACTIONS(4177),
    [anon_sym_PIPE_PIPE] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK] = ACTIONS(4162),
    [anon_sym_from] = ACTIONS(4196),
    [anon_sym_into] = ACTIONS(4196),
    [anon_sym_join] = ACTIONS(4196),
    [anon_sym_on] = ACTIONS(4157),
    [anon_sym_equals] = ACTIONS(4157),
    [anon_sym_let] = ACTIONS(4196),
    [anon_sym_orderby] = ACTIONS(4196),
    [anon_sym_ascending] = ACTIONS(4157),
    [anon_sym_descending] = ACTIONS(4157),
    [anon_sym_group] = ACTIONS(4196),
    [anon_sym_by] = ACTIONS(4157),
    [anon_sym_select] = ACTIONS(4196),
    [anon_sym_as] = ACTIONS(4162),
    [anon_sym_is] = ACTIONS(4162),
    [anon_sym_DASH_GT] = ACTIONS(4193),
    [anon_sym_with] = ACTIONS(4162),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2976] = {
    [sym_parameter_list] = STATE(9685),
    [sym_positional_pattern_clause] = STATE(3081),
    [sym_property_pattern_clause] = STATE(3135),
    [sym__variable_designation] = STATE(5777),
    [sym_parenthesized_variable_designation] = STATE(5773),
    [sym__lambda_parameters] = STATE(9890),
    [sym_identifier] = STATE(5348),
    [sym__reserved_identifier] = STATE(5200),
    [sym_preproc_region] = STATE(2976),
    [sym_preproc_endregion] = STATE(2976),
    [sym_preproc_line] = STATE(2976),
    [sym_preproc_pragma] = STATE(2976),
    [sym_preproc_nullable] = STATE(2976),
    [sym_preproc_error] = STATE(2976),
    [sym_preproc_warning] = STATE(2976),
    [sym_preproc_define] = STATE(2976),
    [sym_preproc_undef] = STATE(2976),
    [sym__identifier_token] = ACTIONS(4575),
    [anon_sym_alias] = ACTIONS(4577),
    [anon_sym_global] = ACTIONS(4577),
    [anon_sym_LBRACK] = ACTIONS(4357),
    [anon_sym_COLON] = ACTIONS(4357),
    [anon_sym_COMMA] = ACTIONS(4357),
    [anon_sym_LPAREN] = ACTIONS(4357),
    [anon_sym_LBRACE] = ACTIONS(4579),
    [anon_sym_file] = ACTIONS(4577),
    [anon_sym_LT] = ACTIONS(4355),
    [anon_sym_GT] = ACTIONS(4355),
    [anon_sym_where] = ACTIONS(4577),
    [anon_sym_QMARK] = ACTIONS(4355),
    [anon_sym_notnull] = ACTIONS(4577),
    [anon_sym_unmanaged] = ACTIONS(4577),
    [anon_sym_BANG] = ACTIONS(4355),
    [anon_sym_PLUS_PLUS] = ACTIONS(4357),
    [anon_sym_DASH_DASH] = ACTIONS(4357),
    [anon_sym_PLUS] = ACTIONS(4355),
    [anon_sym_DASH] = ACTIONS(4355),
    [anon_sym_STAR] = ACTIONS(4357),
    [anon_sym_SLASH] = ACTIONS(4355),
    [anon_sym_PERCENT] = ACTIONS(4357),
    [anon_sym_CARET] = ACTIONS(4357),
    [anon_sym_PIPE] = ACTIONS(4355),
    [anon_sym_AMP] = ACTIONS(4355),
    [anon_sym_LT_LT] = ACTIONS(4357),
    [anon_sym_GT_GT] = ACTIONS(4355),
    [anon_sym_GT_GT_GT] = ACTIONS(4357),
    [anon_sym_EQ_EQ] = ACTIONS(4357),
    [anon_sym_BANG_EQ] = ACTIONS(4357),
    [anon_sym_GT_EQ] = ACTIONS(4357),
    [anon_sym_LT_EQ] = ACTIONS(4357),
    [anon_sym_DOT] = ACTIONS(4355),
    [anon_sym_scoped] = ACTIONS(4577),
    [anon_sym_var] = ACTIONS(4577),
    [anon_sym_yield] = ACTIONS(4577),
    [anon_sym_switch] = ACTIONS(4355),
    [anon_sym_when] = ACTIONS(4577),
    [sym_discard] = ACTIONS(4581),
    [anon_sym_DOT_DOT] = ACTIONS(4357),
    [anon_sym_and] = ACTIONS(4355),
    [anon_sym_or] = ACTIONS(4355),
    [anon_sym_AMP_AMP] = ACTIONS(4357),
    [anon_sym_PIPE_PIPE] = ACTIONS(4357),
    [anon_sym_QMARK_QMARK] = ACTIONS(4357),
    [anon_sym_from] = ACTIONS(4577),
    [anon_sym_into] = ACTIONS(4355),
    [anon_sym_join] = ACTIONS(4577),
    [anon_sym_on] = ACTIONS(4577),
    [anon_sym_equals] = ACTIONS(4577),
    [anon_sym_let] = ACTIONS(4577),
    [anon_sym_orderby] = ACTIONS(4577),
    [anon_sym_ascending] = ACTIONS(4577),
    [anon_sym_descending] = ACTIONS(4577),
    [anon_sym_group] = ACTIONS(4577),
    [anon_sym_by] = ACTIONS(4577),
    [anon_sym_select] = ACTIONS(4577),
    [anon_sym_as] = ACTIONS(4355),
    [anon_sym_is] = ACTIONS(4355),
    [anon_sym_DASH_GT] = ACTIONS(4357),
    [anon_sym_with] = ACTIONS(4355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4357),
  },
  [2977] = {
    [sym_preproc_region] = STATE(2977),
    [sym_preproc_endregion] = STATE(2977),
    [sym_preproc_line] = STATE(2977),
    [sym_preproc_pragma] = STATE(2977),
    [sym_preproc_nullable] = STATE(2977),
    [sym_preproc_error] = STATE(2977),
    [sym_preproc_warning] = STATE(2977),
    [sym_preproc_define] = STATE(2977),
    [sym_preproc_undef] = STATE(2977),
    [sym__identifier_token] = ACTIONS(4157),
    [anon_sym_alias] = ACTIONS(4157),
    [anon_sym_global] = ACTIONS(4157),
    [anon_sym_EQ] = ACTIONS(4162),
    [anon_sym_LBRACK] = ACTIONS(4193),
    [anon_sym_LPAREN] = ACTIONS(4193),
    [anon_sym_file] = ACTIONS(4157),
    [anon_sym_LT] = ACTIONS(4162),
    [anon_sym_GT] = ACTIONS(4162),
    [anon_sym_where] = ACTIONS(4157),
    [anon_sym_QMARK] = ACTIONS(4196),
    [anon_sym_notnull] = ACTIONS(4157),
    [anon_sym_unmanaged] = ACTIONS(4157),
    [anon_sym_BANG] = ACTIONS(4162),
    [anon_sym_PLUS_PLUS] = ACTIONS(4177),
    [anon_sym_DASH_DASH] = ACTIONS(4177),
    [anon_sym_PLUS] = ACTIONS(4162),
    [anon_sym_DASH] = ACTIONS(4162),
    [anon_sym_STAR] = ACTIONS(4196),
    [anon_sym_SLASH] = ACTIONS(4162),
    [anon_sym_PERCENT] = ACTIONS(4162),
    [anon_sym_CARET] = ACTIONS(4162),
    [anon_sym_PIPE] = ACTIONS(4162),
    [anon_sym_AMP] = ACTIONS(4162),
    [anon_sym_LT_LT] = ACTIONS(4162),
    [anon_sym_GT_GT] = ACTIONS(4162),
    [anon_sym_GT_GT_GT] = ACTIONS(4162),
    [anon_sym_EQ_EQ] = ACTIONS(4177),
    [anon_sym_BANG_EQ] = ACTIONS(4177),
    [anon_sym_GT_EQ] = ACTIONS(4177),
    [anon_sym_LT_EQ] = ACTIONS(4177),
    [anon_sym_DOT] = ACTIONS(4196),
    [anon_sym_scoped] = ACTIONS(4157),
    [anon_sym_var] = ACTIONS(4157),
    [anon_sym_yield] = ACTIONS(4157),
    [anon_sym_switch] = ACTIONS(4162),
    [anon_sym_when] = ACTIONS(4157),
    [anon_sym_DOT_DOT] = ACTIONS(4177),
    [anon_sym_and] = ACTIONS(4162),
    [anon_sym_or] = ACTIONS(4162),
    [anon_sym_PLUS_EQ] = ACTIONS(4177),
    [anon_sym_DASH_EQ] = ACTIONS(4177),
    [anon_sym_STAR_EQ] = ACTIONS(4177),
    [anon_sym_SLASH_EQ] = ACTIONS(4177),
    [anon_sym_PERCENT_EQ] = ACTIONS(4177),
    [anon_sym_AMP_EQ] = ACTIONS(4177),
    [anon_sym_CARET_EQ] = ACTIONS(4177),
    [anon_sym_PIPE_EQ] = ACTIONS(4177),
    [anon_sym_LT_LT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4177),
    [anon_sym_AMP_AMP] = ACTIONS(4177),
    [anon_sym_PIPE_PIPE] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK] = ACTIONS(4162),
    [anon_sym_from] = ACTIONS(4157),
    [anon_sym_into] = ACTIONS(4196),
    [anon_sym_join] = ACTIONS(4157),
    [anon_sym_on] = ACTIONS(4157),
    [anon_sym_equals] = ACTIONS(4157),
    [anon_sym_let] = ACTIONS(4157),
    [anon_sym_orderby] = ACTIONS(4157),
    [anon_sym_ascending] = ACTIONS(4157),
    [anon_sym_descending] = ACTIONS(4157),
    [anon_sym_group] = ACTIONS(4157),
    [anon_sym_by] = ACTIONS(4196),
    [anon_sym_select] = ACTIONS(4157),
    [anon_sym_as] = ACTIONS(4162),
    [anon_sym_is] = ACTIONS(4162),
    [anon_sym_DASH_GT] = ACTIONS(4193),
    [anon_sym_with] = ACTIONS(4162),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2978] = {
    [sym_preproc_region] = STATE(2978),
    [sym_preproc_endregion] = STATE(2978),
    [sym_preproc_line] = STATE(2978),
    [sym_preproc_pragma] = STATE(2978),
    [sym_preproc_nullable] = STATE(2978),
    [sym_preproc_error] = STATE(2978),
    [sym_preproc_warning] = STATE(2978),
    [sym_preproc_define] = STATE(2978),
    [sym_preproc_undef] = STATE(2978),
    [sym__identifier_token] = ACTIONS(4431),
    [anon_sym_alias] = ACTIONS(4431),
    [anon_sym_SEMI] = ACTIONS(4433),
    [anon_sym_global] = ACTIONS(4431),
    [anon_sym_LBRACK] = ACTIONS(4433),
    [anon_sym_COLON] = ACTIONS(4433),
    [anon_sym_COMMA] = ACTIONS(4433),
    [anon_sym_RBRACK] = ACTIONS(4433),
    [anon_sym_LPAREN] = ACTIONS(4433),
    [anon_sym_RPAREN] = ACTIONS(4433),
    [anon_sym_LBRACE] = ACTIONS(4433),
    [anon_sym_RBRACE] = ACTIONS(4433),
    [anon_sym_file] = ACTIONS(4431),
    [anon_sym_LT] = ACTIONS(4431),
    [anon_sym_GT] = ACTIONS(4431),
    [anon_sym_in] = ACTIONS(4431),
    [anon_sym_where] = ACTIONS(4431),
    [anon_sym_QMARK] = ACTIONS(4431),
    [anon_sym_notnull] = ACTIONS(4431),
    [anon_sym_unmanaged] = ACTIONS(4431),
    [anon_sym_BANG] = ACTIONS(4431),
    [anon_sym_PLUS_PLUS] = ACTIONS(4433),
    [anon_sym_DASH_DASH] = ACTIONS(4433),
    [anon_sym_PLUS] = ACTIONS(4431),
    [anon_sym_DASH] = ACTIONS(4431),
    [anon_sym_STAR] = ACTIONS(4433),
    [anon_sym_SLASH] = ACTIONS(4431),
    [anon_sym_PERCENT] = ACTIONS(4433),
    [anon_sym_CARET] = ACTIONS(4433),
    [anon_sym_PIPE] = ACTIONS(4431),
    [anon_sym_AMP] = ACTIONS(4431),
    [anon_sym_LT_LT] = ACTIONS(4433),
    [anon_sym_GT_GT] = ACTIONS(4431),
    [anon_sym_GT_GT_GT] = ACTIONS(4433),
    [anon_sym_EQ_EQ] = ACTIONS(4433),
    [anon_sym_BANG_EQ] = ACTIONS(4433),
    [anon_sym_GT_EQ] = ACTIONS(4433),
    [anon_sym_LT_EQ] = ACTIONS(4433),
    [anon_sym_DOT] = ACTIONS(4431),
    [anon_sym_scoped] = ACTIONS(4431),
    [anon_sym_EQ_GT] = ACTIONS(4433),
    [anon_sym_var] = ACTIONS(4431),
    [anon_sym_yield] = ACTIONS(4431),
    [anon_sym_switch] = ACTIONS(4431),
    [anon_sym_when] = ACTIONS(4431),
    [sym_discard] = ACTIONS(4431),
    [anon_sym_DOT_DOT] = ACTIONS(4433),
    [anon_sym_and] = ACTIONS(4431),
    [anon_sym_or] = ACTIONS(4431),
    [anon_sym_AMP_AMP] = ACTIONS(4433),
    [anon_sym_PIPE_PIPE] = ACTIONS(4433),
    [anon_sym_QMARK_QMARK] = ACTIONS(4433),
    [anon_sym_from] = ACTIONS(4431),
    [anon_sym_into] = ACTIONS(4431),
    [anon_sym_join] = ACTIONS(4431),
    [anon_sym_on] = ACTIONS(4431),
    [anon_sym_equals] = ACTIONS(4431),
    [anon_sym_let] = ACTIONS(4431),
    [anon_sym_orderby] = ACTIONS(4431),
    [anon_sym_ascending] = ACTIONS(4431),
    [anon_sym_descending] = ACTIONS(4431),
    [anon_sym_group] = ACTIONS(4431),
    [anon_sym_by] = ACTIONS(4431),
    [anon_sym_select] = ACTIONS(4431),
    [anon_sym_as] = ACTIONS(4431),
    [anon_sym_is] = ACTIONS(4431),
    [anon_sym_DASH_GT] = ACTIONS(4433),
    [anon_sym_with] = ACTIONS(4431),
    [aux_sym_preproc_if_token3] = ACTIONS(4433),
    [aux_sym_preproc_else_token1] = ACTIONS(4433),
    [aux_sym_preproc_elif_token1] = ACTIONS(4433),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2979] = {
    [sym__name] = STATE(3015),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2956),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2944),
    [sym_ref_type] = STATE(2883),
    [sym__scoped_base_type] = STATE(2885),
    [sym_identifier] = STATE(2920),
    [sym__reserved_identifier] = STATE(2928),
    [sym_preproc_region] = STATE(2979),
    [sym_preproc_endregion] = STATE(2979),
    [sym_preproc_line] = STATE(2979),
    [sym_preproc_pragma] = STATE(2979),
    [sym_preproc_nullable] = STATE(2979),
    [sym_preproc_error] = STATE(2979),
    [sym_preproc_warning] = STATE(2979),
    [sym_preproc_define] = STATE(2979),
    [sym_preproc_undef] = STATE(2979),
    [sym__identifier_token] = ACTIONS(4536),
    [anon_sym_alias] = ACTIONS(4538),
    [anon_sym_global] = ACTIONS(4538),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_COMMA] = ACTIONS(3993),
    [anon_sym_LPAREN] = ACTIONS(3993),
    [anon_sym_ref] = ACTIONS(4632),
    [anon_sym_LBRACE] = ACTIONS(3993),
    [anon_sym_file] = ACTIONS(4538),
    [anon_sym_LT] = ACTIONS(3995),
    [anon_sym_GT] = ACTIONS(3995),
    [anon_sym_where] = ACTIONS(4056),
    [anon_sym_QMARK] = ACTIONS(3995),
    [anon_sym_notnull] = ACTIONS(4538),
    [anon_sym_unmanaged] = ACTIONS(4538),
    [anon_sym_BANG] = ACTIONS(3995),
    [anon_sym_PLUS_PLUS] = ACTIONS(3993),
    [anon_sym_DASH_DASH] = ACTIONS(3993),
    [anon_sym_PLUS] = ACTIONS(3995),
    [anon_sym_DASH] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3993),
    [anon_sym_SLASH] = ACTIONS(3995),
    [anon_sym_PERCENT] = ACTIONS(3993),
    [anon_sym_CARET] = ACTIONS(3993),
    [anon_sym_PIPE] = ACTIONS(3995),
    [anon_sym_AMP] = ACTIONS(3995),
    [anon_sym_LT_LT] = ACTIONS(3993),
    [anon_sym_GT_GT] = ACTIONS(3995),
    [anon_sym_GT_GT_GT] = ACTIONS(3993),
    [anon_sym_EQ_EQ] = ACTIONS(3993),
    [anon_sym_BANG_EQ] = ACTIONS(3993),
    [anon_sym_GT_EQ] = ACTIONS(3993),
    [anon_sym_LT_EQ] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3995),
    [anon_sym_scoped] = ACTIONS(4538),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(4538),
    [anon_sym_yield] = ACTIONS(4538),
    [anon_sym_switch] = ACTIONS(3995),
    [anon_sym_when] = ACTIONS(4538),
    [anon_sym_DOT_DOT] = ACTIONS(3993),
    [anon_sym_and] = ACTIONS(3995),
    [anon_sym_or] = ACTIONS(3995),
    [anon_sym_AMP_AMP] = ACTIONS(3993),
    [anon_sym_PIPE_PIPE] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK] = ACTIONS(3993),
    [anon_sym_from] = ACTIONS(4056),
    [anon_sym_into] = ACTIONS(4538),
    [anon_sym_join] = ACTIONS(4056),
    [anon_sym_on] = ACTIONS(4538),
    [anon_sym_equals] = ACTIONS(4538),
    [anon_sym_let] = ACTIONS(4056),
    [anon_sym_orderby] = ACTIONS(4056),
    [anon_sym_ascending] = ACTIONS(4056),
    [anon_sym_descending] = ACTIONS(4056),
    [anon_sym_group] = ACTIONS(4056),
    [anon_sym_by] = ACTIONS(4538),
    [anon_sym_select] = ACTIONS(4056),
    [anon_sym_as] = ACTIONS(3995),
    [anon_sym_is] = ACTIONS(3995),
    [anon_sym_DASH_GT] = ACTIONS(3993),
    [anon_sym_with] = ACTIONS(3995),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2980] = {
    [sym_parameter_list] = STATE(9685),
    [sym_positional_pattern_clause] = STATE(3085),
    [sym_property_pattern_clause] = STATE(3122),
    [sym__variable_designation] = STATE(5777),
    [sym_parenthesized_variable_designation] = STATE(5773),
    [sym__lambda_parameters] = STATE(9890),
    [sym_identifier] = STATE(5348),
    [sym__reserved_identifier] = STATE(5200),
    [sym_preproc_region] = STATE(2980),
    [sym_preproc_endregion] = STATE(2980),
    [sym_preproc_line] = STATE(2980),
    [sym_preproc_pragma] = STATE(2980),
    [sym_preproc_nullable] = STATE(2980),
    [sym_preproc_error] = STATE(2980),
    [sym_preproc_warning] = STATE(2980),
    [sym_preproc_define] = STATE(2980),
    [sym_preproc_undef] = STATE(2980),
    [sym__identifier_token] = ACTIONS(4575),
    [anon_sym_alias] = ACTIONS(4577),
    [anon_sym_global] = ACTIONS(4577),
    [anon_sym_LBRACK] = ACTIONS(4341),
    [anon_sym_COLON] = ACTIONS(4341),
    [anon_sym_COMMA] = ACTIONS(4341),
    [anon_sym_LPAREN] = ACTIONS(4341),
    [anon_sym_LBRACE] = ACTIONS(4579),
    [anon_sym_file] = ACTIONS(4577),
    [anon_sym_LT] = ACTIONS(4345),
    [anon_sym_GT] = ACTIONS(4345),
    [anon_sym_where] = ACTIONS(4577),
    [anon_sym_QMARK] = ACTIONS(4345),
    [anon_sym_notnull] = ACTIONS(4577),
    [anon_sym_unmanaged] = ACTIONS(4577),
    [anon_sym_BANG] = ACTIONS(4345),
    [anon_sym_PLUS_PLUS] = ACTIONS(4341),
    [anon_sym_DASH_DASH] = ACTIONS(4341),
    [anon_sym_PLUS] = ACTIONS(4345),
    [anon_sym_DASH] = ACTIONS(4345),
    [anon_sym_STAR] = ACTIONS(4341),
    [anon_sym_SLASH] = ACTIONS(4345),
    [anon_sym_PERCENT] = ACTIONS(4341),
    [anon_sym_CARET] = ACTIONS(4341),
    [anon_sym_PIPE] = ACTIONS(4345),
    [anon_sym_AMP] = ACTIONS(4345),
    [anon_sym_LT_LT] = ACTIONS(4341),
    [anon_sym_GT_GT] = ACTIONS(4345),
    [anon_sym_GT_GT_GT] = ACTIONS(4341),
    [anon_sym_EQ_EQ] = ACTIONS(4341),
    [anon_sym_BANG_EQ] = ACTIONS(4341),
    [anon_sym_GT_EQ] = ACTIONS(4341),
    [anon_sym_LT_EQ] = ACTIONS(4341),
    [anon_sym_DOT] = ACTIONS(4345),
    [anon_sym_scoped] = ACTIONS(4577),
    [anon_sym_var] = ACTIONS(4577),
    [anon_sym_yield] = ACTIONS(4577),
    [anon_sym_switch] = ACTIONS(4345),
    [anon_sym_when] = ACTIONS(4577),
    [sym_discard] = ACTIONS(4581),
    [anon_sym_DOT_DOT] = ACTIONS(4341),
    [anon_sym_and] = ACTIONS(4355),
    [anon_sym_or] = ACTIONS(4355),
    [anon_sym_AMP_AMP] = ACTIONS(4341),
    [anon_sym_PIPE_PIPE] = ACTIONS(4341),
    [anon_sym_QMARK_QMARK] = ACTIONS(4341),
    [anon_sym_from] = ACTIONS(4577),
    [anon_sym_into] = ACTIONS(4577),
    [anon_sym_join] = ACTIONS(4577),
    [anon_sym_on] = ACTIONS(4577),
    [anon_sym_equals] = ACTIONS(4577),
    [anon_sym_let] = ACTIONS(4577),
    [anon_sym_orderby] = ACTIONS(4577),
    [anon_sym_ascending] = ACTIONS(4577),
    [anon_sym_descending] = ACTIONS(4577),
    [anon_sym_group] = ACTIONS(4577),
    [anon_sym_by] = ACTIONS(4577),
    [anon_sym_select] = ACTIONS(4577),
    [anon_sym_as] = ACTIONS(4345),
    [anon_sym_is] = ACTIONS(4345),
    [anon_sym_DASH_GT] = ACTIONS(4341),
    [anon_sym_with] = ACTIONS(4345),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4341),
  },
  [2981] = {
    [sym_preproc_region] = STATE(2981),
    [sym_preproc_endregion] = STATE(2981),
    [sym_preproc_line] = STATE(2981),
    [sym_preproc_pragma] = STATE(2981),
    [sym_preproc_nullable] = STATE(2981),
    [sym_preproc_error] = STATE(2981),
    [sym_preproc_warning] = STATE(2981),
    [sym_preproc_define] = STATE(2981),
    [sym_preproc_undef] = STATE(2981),
    [sym__identifier_token] = ACTIONS(4126),
    [anon_sym_alias] = ACTIONS(4126),
    [anon_sym_SEMI] = ACTIONS(4128),
    [anon_sym_global] = ACTIONS(4126),
    [anon_sym_LBRACK] = ACTIONS(4128),
    [anon_sym_COLON] = ACTIONS(4128),
    [anon_sym_COMMA] = ACTIONS(4128),
    [anon_sym_RBRACK] = ACTIONS(4128),
    [anon_sym_LPAREN] = ACTIONS(4128),
    [anon_sym_RPAREN] = ACTIONS(4128),
    [anon_sym_LBRACE] = ACTIONS(4128),
    [anon_sym_RBRACE] = ACTIONS(4128),
    [anon_sym_file] = ACTIONS(4126),
    [anon_sym_LT] = ACTIONS(4126),
    [anon_sym_GT] = ACTIONS(4126),
    [anon_sym_in] = ACTIONS(4126),
    [anon_sym_where] = ACTIONS(4126),
    [anon_sym_QMARK] = ACTIONS(4126),
    [anon_sym_notnull] = ACTIONS(4126),
    [anon_sym_unmanaged] = ACTIONS(4126),
    [anon_sym_BANG] = ACTIONS(4126),
    [anon_sym_PLUS_PLUS] = ACTIONS(4128),
    [anon_sym_DASH_DASH] = ACTIONS(4128),
    [anon_sym_PLUS] = ACTIONS(4126),
    [anon_sym_DASH] = ACTIONS(4126),
    [anon_sym_STAR] = ACTIONS(4128),
    [anon_sym_SLASH] = ACTIONS(4126),
    [anon_sym_PERCENT] = ACTIONS(4128),
    [anon_sym_CARET] = ACTIONS(4128),
    [anon_sym_PIPE] = ACTIONS(4126),
    [anon_sym_AMP] = ACTIONS(4126),
    [anon_sym_LT_LT] = ACTIONS(4128),
    [anon_sym_GT_GT] = ACTIONS(4126),
    [anon_sym_GT_GT_GT] = ACTIONS(4128),
    [anon_sym_EQ_EQ] = ACTIONS(4128),
    [anon_sym_BANG_EQ] = ACTIONS(4128),
    [anon_sym_GT_EQ] = ACTIONS(4128),
    [anon_sym_LT_EQ] = ACTIONS(4128),
    [anon_sym_DOT] = ACTIONS(4126),
    [anon_sym_scoped] = ACTIONS(4126),
    [anon_sym_EQ_GT] = ACTIONS(4128),
    [anon_sym_var] = ACTIONS(4126),
    [anon_sym_yield] = ACTIONS(4126),
    [anon_sym_switch] = ACTIONS(4126),
    [anon_sym_when] = ACTIONS(4126),
    [sym_discard] = ACTIONS(4126),
    [anon_sym_DOT_DOT] = ACTIONS(4128),
    [anon_sym_and] = ACTIONS(4126),
    [anon_sym_or] = ACTIONS(4126),
    [anon_sym_AMP_AMP] = ACTIONS(4128),
    [anon_sym_PIPE_PIPE] = ACTIONS(4128),
    [anon_sym_QMARK_QMARK] = ACTIONS(4128),
    [anon_sym_from] = ACTIONS(4126),
    [anon_sym_into] = ACTIONS(4126),
    [anon_sym_join] = ACTIONS(4126),
    [anon_sym_on] = ACTIONS(4126),
    [anon_sym_equals] = ACTIONS(4126),
    [anon_sym_let] = ACTIONS(4126),
    [anon_sym_orderby] = ACTIONS(4126),
    [anon_sym_ascending] = ACTIONS(4126),
    [anon_sym_descending] = ACTIONS(4126),
    [anon_sym_group] = ACTIONS(4126),
    [anon_sym_by] = ACTIONS(4126),
    [anon_sym_select] = ACTIONS(4126),
    [anon_sym_as] = ACTIONS(4126),
    [anon_sym_is] = ACTIONS(4126),
    [anon_sym_DASH_GT] = ACTIONS(4128),
    [anon_sym_with] = ACTIONS(4126),
    [aux_sym_preproc_if_token3] = ACTIONS(4128),
    [aux_sym_preproc_else_token1] = ACTIONS(4128),
    [aux_sym_preproc_elif_token1] = ACTIONS(4128),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2982] = {
    [sym_preproc_region] = STATE(2982),
    [sym_preproc_endregion] = STATE(2982),
    [sym_preproc_line] = STATE(2982),
    [sym_preproc_pragma] = STATE(2982),
    [sym_preproc_nullable] = STATE(2982),
    [sym_preproc_error] = STATE(2982),
    [sym_preproc_warning] = STATE(2982),
    [sym_preproc_define] = STATE(2982),
    [sym_preproc_undef] = STATE(2982),
    [sym__identifier_token] = ACTIONS(4179),
    [anon_sym_alias] = ACTIONS(4179),
    [anon_sym_global] = ACTIONS(4179),
    [anon_sym_EQ] = ACTIONS(4183),
    [anon_sym_LBRACK] = ACTIONS(4185),
    [anon_sym_LPAREN] = ACTIONS(4185),
    [anon_sym_file] = ACTIONS(4179),
    [anon_sym_LT] = ACTIONS(4183),
    [anon_sym_GT] = ACTIONS(4183),
    [anon_sym_where] = ACTIONS(4179),
    [anon_sym_QMARK] = ACTIONS(4188),
    [anon_sym_notnull] = ACTIONS(4179),
    [anon_sym_unmanaged] = ACTIONS(4179),
    [anon_sym_BANG] = ACTIONS(4183),
    [anon_sym_PLUS_PLUS] = ACTIONS(4191),
    [anon_sym_DASH_DASH] = ACTIONS(4191),
    [anon_sym_PLUS] = ACTIONS(4183),
    [anon_sym_DASH] = ACTIONS(4183),
    [anon_sym_STAR] = ACTIONS(4188),
    [anon_sym_SLASH] = ACTIONS(4183),
    [anon_sym_PERCENT] = ACTIONS(4183),
    [anon_sym_CARET] = ACTIONS(4183),
    [anon_sym_PIPE] = ACTIONS(4183),
    [anon_sym_AMP] = ACTIONS(4183),
    [anon_sym_LT_LT] = ACTIONS(4183),
    [anon_sym_GT_GT] = ACTIONS(4183),
    [anon_sym_GT_GT_GT] = ACTIONS(4183),
    [anon_sym_EQ_EQ] = ACTIONS(4191),
    [anon_sym_BANG_EQ] = ACTIONS(4191),
    [anon_sym_GT_EQ] = ACTIONS(4191),
    [anon_sym_LT_EQ] = ACTIONS(4191),
    [anon_sym_DOT] = ACTIONS(4188),
    [anon_sym_scoped] = ACTIONS(4179),
    [anon_sym_var] = ACTIONS(4179),
    [anon_sym_yield] = ACTIONS(4179),
    [anon_sym_switch] = ACTIONS(4183),
    [anon_sym_when] = ACTIONS(4179),
    [anon_sym_DOT_DOT] = ACTIONS(4191),
    [anon_sym_and] = ACTIONS(4183),
    [anon_sym_or] = ACTIONS(4183),
    [anon_sym_PLUS_EQ] = ACTIONS(4191),
    [anon_sym_DASH_EQ] = ACTIONS(4191),
    [anon_sym_STAR_EQ] = ACTIONS(4191),
    [anon_sym_SLASH_EQ] = ACTIONS(4191),
    [anon_sym_PERCENT_EQ] = ACTIONS(4191),
    [anon_sym_AMP_EQ] = ACTIONS(4191),
    [anon_sym_CARET_EQ] = ACTIONS(4191),
    [anon_sym_PIPE_EQ] = ACTIONS(4191),
    [anon_sym_LT_LT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4191),
    [anon_sym_AMP_AMP] = ACTIONS(4191),
    [anon_sym_PIPE_PIPE] = ACTIONS(4191),
    [anon_sym_QMARK_QMARK] = ACTIONS(4183),
    [anon_sym_from] = ACTIONS(4179),
    [anon_sym_into] = ACTIONS(4188),
    [anon_sym_join] = ACTIONS(4179),
    [anon_sym_on] = ACTIONS(4188),
    [anon_sym_equals] = ACTIONS(4179),
    [anon_sym_let] = ACTIONS(4179),
    [anon_sym_orderby] = ACTIONS(4179),
    [anon_sym_ascending] = ACTIONS(4179),
    [anon_sym_descending] = ACTIONS(4179),
    [anon_sym_group] = ACTIONS(4179),
    [anon_sym_by] = ACTIONS(4179),
    [anon_sym_select] = ACTIONS(4179),
    [anon_sym_as] = ACTIONS(4183),
    [anon_sym_is] = ACTIONS(4183),
    [anon_sym_DASH_GT] = ACTIONS(4185),
    [anon_sym_with] = ACTIONS(4183),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2983] = {
    [sym_preproc_region] = STATE(2983),
    [sym_preproc_endregion] = STATE(2983),
    [sym_preproc_line] = STATE(2983),
    [sym_preproc_pragma] = STATE(2983),
    [sym_preproc_nullable] = STATE(2983),
    [sym_preproc_error] = STATE(2983),
    [sym_preproc_warning] = STATE(2983),
    [sym_preproc_define] = STATE(2983),
    [sym_preproc_undef] = STATE(2983),
    [sym__identifier_token] = ACTIONS(4179),
    [anon_sym_alias] = ACTIONS(4179),
    [anon_sym_global] = ACTIONS(4179),
    [anon_sym_EQ] = ACTIONS(4183),
    [anon_sym_LBRACK] = ACTIONS(4185),
    [anon_sym_LPAREN] = ACTIONS(4185),
    [anon_sym_file] = ACTIONS(4179),
    [anon_sym_LT] = ACTIONS(4183),
    [anon_sym_GT] = ACTIONS(4183),
    [anon_sym_where] = ACTIONS(4179),
    [anon_sym_QMARK] = ACTIONS(4188),
    [anon_sym_notnull] = ACTIONS(4179),
    [anon_sym_unmanaged] = ACTIONS(4179),
    [anon_sym_BANG] = ACTIONS(4183),
    [anon_sym_PLUS_PLUS] = ACTIONS(4191),
    [anon_sym_DASH_DASH] = ACTIONS(4191),
    [anon_sym_PLUS] = ACTIONS(4183),
    [anon_sym_DASH] = ACTIONS(4183),
    [anon_sym_STAR] = ACTIONS(4188),
    [anon_sym_SLASH] = ACTIONS(4183),
    [anon_sym_PERCENT] = ACTIONS(4183),
    [anon_sym_CARET] = ACTIONS(4183),
    [anon_sym_PIPE] = ACTIONS(4183),
    [anon_sym_AMP] = ACTIONS(4183),
    [anon_sym_LT_LT] = ACTIONS(4183),
    [anon_sym_GT_GT] = ACTIONS(4183),
    [anon_sym_GT_GT_GT] = ACTIONS(4183),
    [anon_sym_EQ_EQ] = ACTIONS(4191),
    [anon_sym_BANG_EQ] = ACTIONS(4191),
    [anon_sym_GT_EQ] = ACTIONS(4191),
    [anon_sym_LT_EQ] = ACTIONS(4191),
    [anon_sym_DOT] = ACTIONS(4188),
    [anon_sym_scoped] = ACTIONS(4179),
    [anon_sym_var] = ACTIONS(4179),
    [anon_sym_yield] = ACTIONS(4179),
    [anon_sym_switch] = ACTIONS(4183),
    [anon_sym_when] = ACTIONS(4179),
    [anon_sym_DOT_DOT] = ACTIONS(4191),
    [anon_sym_and] = ACTIONS(4183),
    [anon_sym_or] = ACTIONS(4183),
    [anon_sym_PLUS_EQ] = ACTIONS(4191),
    [anon_sym_DASH_EQ] = ACTIONS(4191),
    [anon_sym_STAR_EQ] = ACTIONS(4191),
    [anon_sym_SLASH_EQ] = ACTIONS(4191),
    [anon_sym_PERCENT_EQ] = ACTIONS(4191),
    [anon_sym_AMP_EQ] = ACTIONS(4191),
    [anon_sym_CARET_EQ] = ACTIONS(4191),
    [anon_sym_PIPE_EQ] = ACTIONS(4191),
    [anon_sym_LT_LT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4191),
    [anon_sym_AMP_AMP] = ACTIONS(4191),
    [anon_sym_PIPE_PIPE] = ACTIONS(4191),
    [anon_sym_QMARK_QMARK] = ACTIONS(4183),
    [anon_sym_from] = ACTIONS(4179),
    [anon_sym_into] = ACTIONS(4179),
    [anon_sym_join] = ACTIONS(4179),
    [anon_sym_on] = ACTIONS(4179),
    [anon_sym_equals] = ACTIONS(4179),
    [anon_sym_let] = ACTIONS(4179),
    [anon_sym_orderby] = ACTIONS(4179),
    [anon_sym_ascending] = ACTIONS(4179),
    [anon_sym_descending] = ACTIONS(4179),
    [anon_sym_group] = ACTIONS(4179),
    [anon_sym_by] = ACTIONS(4188),
    [anon_sym_select] = ACTIONS(4179),
    [anon_sym_as] = ACTIONS(4183),
    [anon_sym_is] = ACTIONS(4183),
    [anon_sym_DASH_GT] = ACTIONS(4185),
    [anon_sym_with] = ACTIONS(4183),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2984] = {
    [sym_preproc_region] = STATE(2984),
    [sym_preproc_endregion] = STATE(2984),
    [sym_preproc_line] = STATE(2984),
    [sym_preproc_pragma] = STATE(2984),
    [sym_preproc_nullable] = STATE(2984),
    [sym_preproc_error] = STATE(2984),
    [sym_preproc_warning] = STATE(2984),
    [sym_preproc_define] = STATE(2984),
    [sym_preproc_undef] = STATE(2984),
    [sym__identifier_token] = ACTIONS(4157),
    [anon_sym_alias] = ACTIONS(4157),
    [anon_sym_global] = ACTIONS(4157),
    [anon_sym_EQ] = ACTIONS(4162),
    [anon_sym_LBRACK] = ACTIONS(4193),
    [anon_sym_LPAREN] = ACTIONS(4193),
    [anon_sym_file] = ACTIONS(4157),
    [anon_sym_LT] = ACTIONS(4162),
    [anon_sym_GT] = ACTIONS(4162),
    [anon_sym_where] = ACTIONS(4157),
    [anon_sym_QMARK] = ACTIONS(4196),
    [anon_sym_notnull] = ACTIONS(4157),
    [anon_sym_unmanaged] = ACTIONS(4157),
    [anon_sym_BANG] = ACTIONS(4162),
    [anon_sym_PLUS_PLUS] = ACTIONS(4177),
    [anon_sym_DASH_DASH] = ACTIONS(4177),
    [anon_sym_PLUS] = ACTIONS(4162),
    [anon_sym_DASH] = ACTIONS(4162),
    [anon_sym_STAR] = ACTIONS(4196),
    [anon_sym_SLASH] = ACTIONS(4162),
    [anon_sym_PERCENT] = ACTIONS(4162),
    [anon_sym_CARET] = ACTIONS(4162),
    [anon_sym_PIPE] = ACTIONS(4162),
    [anon_sym_AMP] = ACTIONS(4162),
    [anon_sym_LT_LT] = ACTIONS(4162),
    [anon_sym_GT_GT] = ACTIONS(4162),
    [anon_sym_GT_GT_GT] = ACTIONS(4162),
    [anon_sym_EQ_EQ] = ACTIONS(4177),
    [anon_sym_BANG_EQ] = ACTIONS(4177),
    [anon_sym_GT_EQ] = ACTIONS(4177),
    [anon_sym_LT_EQ] = ACTIONS(4177),
    [anon_sym_DOT] = ACTIONS(4196),
    [anon_sym_scoped] = ACTIONS(4157),
    [anon_sym_var] = ACTIONS(4157),
    [anon_sym_yield] = ACTIONS(4157),
    [anon_sym_switch] = ACTIONS(4162),
    [anon_sym_when] = ACTIONS(4157),
    [anon_sym_DOT_DOT] = ACTIONS(4177),
    [anon_sym_and] = ACTIONS(4162),
    [anon_sym_or] = ACTIONS(4162),
    [anon_sym_PLUS_EQ] = ACTIONS(4177),
    [anon_sym_DASH_EQ] = ACTIONS(4177),
    [anon_sym_STAR_EQ] = ACTIONS(4177),
    [anon_sym_SLASH_EQ] = ACTIONS(4177),
    [anon_sym_PERCENT_EQ] = ACTIONS(4177),
    [anon_sym_AMP_EQ] = ACTIONS(4177),
    [anon_sym_CARET_EQ] = ACTIONS(4177),
    [anon_sym_PIPE_EQ] = ACTIONS(4177),
    [anon_sym_LT_LT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4177),
    [anon_sym_AMP_AMP] = ACTIONS(4177),
    [anon_sym_PIPE_PIPE] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK] = ACTIONS(4162),
    [anon_sym_from] = ACTIONS(4157),
    [anon_sym_into] = ACTIONS(4157),
    [anon_sym_join] = ACTIONS(4157),
    [anon_sym_on] = ACTIONS(4196),
    [anon_sym_equals] = ACTIONS(4157),
    [anon_sym_let] = ACTIONS(4157),
    [anon_sym_orderby] = ACTIONS(4157),
    [anon_sym_ascending] = ACTIONS(4157),
    [anon_sym_descending] = ACTIONS(4157),
    [anon_sym_group] = ACTIONS(4157),
    [anon_sym_by] = ACTIONS(4157),
    [anon_sym_select] = ACTIONS(4157),
    [anon_sym_as] = ACTIONS(4162),
    [anon_sym_is] = ACTIONS(4162),
    [anon_sym_DASH_GT] = ACTIONS(4193),
    [anon_sym_with] = ACTIONS(4162),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2985] = {
    [sym_parameter_list] = STATE(9685),
    [sym_positional_pattern_clause] = STATE(3085),
    [sym_property_pattern_clause] = STATE(3122),
    [sym__variable_designation] = STATE(5777),
    [sym_parenthesized_variable_designation] = STATE(5773),
    [sym__lambda_parameters] = STATE(9890),
    [sym_identifier] = STATE(5348),
    [sym__reserved_identifier] = STATE(5200),
    [sym_preproc_region] = STATE(2985),
    [sym_preproc_endregion] = STATE(2985),
    [sym_preproc_line] = STATE(2985),
    [sym_preproc_pragma] = STATE(2985),
    [sym_preproc_nullable] = STATE(2985),
    [sym_preproc_error] = STATE(2985),
    [sym_preproc_warning] = STATE(2985),
    [sym_preproc_define] = STATE(2985),
    [sym_preproc_undef] = STATE(2985),
    [sym__identifier_token] = ACTIONS(4575),
    [anon_sym_alias] = ACTIONS(4577),
    [anon_sym_global] = ACTIONS(4577),
    [anon_sym_LBRACK] = ACTIONS(4357),
    [anon_sym_COLON] = ACTIONS(4357),
    [anon_sym_COMMA] = ACTIONS(4357),
    [anon_sym_LPAREN] = ACTIONS(4357),
    [anon_sym_LBRACE] = ACTIONS(4579),
    [anon_sym_file] = ACTIONS(4577),
    [anon_sym_LT] = ACTIONS(4355),
    [anon_sym_GT] = ACTIONS(4355),
    [anon_sym_where] = ACTIONS(4577),
    [anon_sym_QMARK] = ACTIONS(4355),
    [anon_sym_notnull] = ACTIONS(4577),
    [anon_sym_unmanaged] = ACTIONS(4577),
    [anon_sym_BANG] = ACTIONS(4355),
    [anon_sym_PLUS_PLUS] = ACTIONS(4357),
    [anon_sym_DASH_DASH] = ACTIONS(4357),
    [anon_sym_PLUS] = ACTIONS(4355),
    [anon_sym_DASH] = ACTIONS(4355),
    [anon_sym_STAR] = ACTIONS(4357),
    [anon_sym_SLASH] = ACTIONS(4355),
    [anon_sym_PERCENT] = ACTIONS(4357),
    [anon_sym_CARET] = ACTIONS(4357),
    [anon_sym_PIPE] = ACTIONS(4355),
    [anon_sym_AMP] = ACTIONS(4355),
    [anon_sym_LT_LT] = ACTIONS(4357),
    [anon_sym_GT_GT] = ACTIONS(4355),
    [anon_sym_GT_GT_GT] = ACTIONS(4357),
    [anon_sym_EQ_EQ] = ACTIONS(4357),
    [anon_sym_BANG_EQ] = ACTIONS(4357),
    [anon_sym_GT_EQ] = ACTIONS(4357),
    [anon_sym_LT_EQ] = ACTIONS(4357),
    [anon_sym_DOT] = ACTIONS(4355),
    [anon_sym_scoped] = ACTIONS(4577),
    [anon_sym_var] = ACTIONS(4577),
    [anon_sym_yield] = ACTIONS(4577),
    [anon_sym_switch] = ACTIONS(4355),
    [anon_sym_when] = ACTIONS(4577),
    [sym_discard] = ACTIONS(4581),
    [anon_sym_DOT_DOT] = ACTIONS(4357),
    [anon_sym_and] = ACTIONS(4355),
    [anon_sym_or] = ACTIONS(4355),
    [anon_sym_AMP_AMP] = ACTIONS(4357),
    [anon_sym_PIPE_PIPE] = ACTIONS(4357),
    [anon_sym_QMARK_QMARK] = ACTIONS(4357),
    [anon_sym_from] = ACTIONS(4577),
    [anon_sym_into] = ACTIONS(4577),
    [anon_sym_join] = ACTIONS(4577),
    [anon_sym_on] = ACTIONS(4577),
    [anon_sym_equals] = ACTIONS(4577),
    [anon_sym_let] = ACTIONS(4577),
    [anon_sym_orderby] = ACTIONS(4577),
    [anon_sym_ascending] = ACTIONS(4577),
    [anon_sym_descending] = ACTIONS(4577),
    [anon_sym_group] = ACTIONS(4577),
    [anon_sym_by] = ACTIONS(4577),
    [anon_sym_select] = ACTIONS(4577),
    [anon_sym_as] = ACTIONS(4355),
    [anon_sym_is] = ACTIONS(4355),
    [anon_sym_DASH_GT] = ACTIONS(4357),
    [anon_sym_with] = ACTIONS(4355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4357),
  },
  [2986] = {
    [sym_preproc_region] = STATE(2986),
    [sym_preproc_endregion] = STATE(2986),
    [sym_preproc_line] = STATE(2986),
    [sym_preproc_pragma] = STATE(2986),
    [sym_preproc_nullable] = STATE(2986),
    [sym_preproc_error] = STATE(2986),
    [sym_preproc_warning] = STATE(2986),
    [sym_preproc_define] = STATE(2986),
    [sym_preproc_undef] = STATE(2986),
    [sym__identifier_token] = ACTIONS(4157),
    [anon_sym_alias] = ACTIONS(4157),
    [anon_sym_global] = ACTIONS(4157),
    [anon_sym_EQ] = ACTIONS(4162),
    [anon_sym_LBRACK] = ACTIONS(4193),
    [anon_sym_LPAREN] = ACTIONS(4193),
    [anon_sym_file] = ACTIONS(4157),
    [anon_sym_LT] = ACTIONS(4162),
    [anon_sym_GT] = ACTIONS(4162),
    [anon_sym_where] = ACTIONS(4157),
    [anon_sym_QMARK] = ACTIONS(4196),
    [anon_sym_notnull] = ACTIONS(4157),
    [anon_sym_unmanaged] = ACTIONS(4157),
    [anon_sym_BANG] = ACTIONS(4162),
    [anon_sym_PLUS_PLUS] = ACTIONS(4177),
    [anon_sym_DASH_DASH] = ACTIONS(4177),
    [anon_sym_PLUS] = ACTIONS(4162),
    [anon_sym_DASH] = ACTIONS(4162),
    [anon_sym_STAR] = ACTIONS(4196),
    [anon_sym_SLASH] = ACTIONS(4162),
    [anon_sym_PERCENT] = ACTIONS(4162),
    [anon_sym_CARET] = ACTIONS(4162),
    [anon_sym_PIPE] = ACTIONS(4162),
    [anon_sym_AMP] = ACTIONS(4162),
    [anon_sym_LT_LT] = ACTIONS(4162),
    [anon_sym_GT_GT] = ACTIONS(4162),
    [anon_sym_GT_GT_GT] = ACTIONS(4162),
    [anon_sym_EQ_EQ] = ACTIONS(4177),
    [anon_sym_BANG_EQ] = ACTIONS(4177),
    [anon_sym_GT_EQ] = ACTIONS(4177),
    [anon_sym_LT_EQ] = ACTIONS(4177),
    [anon_sym_DOT] = ACTIONS(4196),
    [anon_sym_scoped] = ACTIONS(4157),
    [anon_sym_var] = ACTIONS(4157),
    [anon_sym_yield] = ACTIONS(4157),
    [anon_sym_switch] = ACTIONS(4162),
    [anon_sym_when] = ACTIONS(4157),
    [anon_sym_DOT_DOT] = ACTIONS(4177),
    [anon_sym_and] = ACTIONS(4162),
    [anon_sym_or] = ACTIONS(4162),
    [anon_sym_PLUS_EQ] = ACTIONS(4177),
    [anon_sym_DASH_EQ] = ACTIONS(4177),
    [anon_sym_STAR_EQ] = ACTIONS(4177),
    [anon_sym_SLASH_EQ] = ACTIONS(4177),
    [anon_sym_PERCENT_EQ] = ACTIONS(4177),
    [anon_sym_AMP_EQ] = ACTIONS(4177),
    [anon_sym_CARET_EQ] = ACTIONS(4177),
    [anon_sym_PIPE_EQ] = ACTIONS(4177),
    [anon_sym_LT_LT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4177),
    [anon_sym_AMP_AMP] = ACTIONS(4177),
    [anon_sym_PIPE_PIPE] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK] = ACTIONS(4162),
    [anon_sym_from] = ACTIONS(4157),
    [anon_sym_into] = ACTIONS(4157),
    [anon_sym_join] = ACTIONS(4157),
    [anon_sym_on] = ACTIONS(4157),
    [anon_sym_equals] = ACTIONS(4196),
    [anon_sym_let] = ACTIONS(4157),
    [anon_sym_orderby] = ACTIONS(4157),
    [anon_sym_ascending] = ACTIONS(4157),
    [anon_sym_descending] = ACTIONS(4157),
    [anon_sym_group] = ACTIONS(4157),
    [anon_sym_by] = ACTIONS(4157),
    [anon_sym_select] = ACTIONS(4157),
    [anon_sym_as] = ACTIONS(4162),
    [anon_sym_is] = ACTIONS(4162),
    [anon_sym_DASH_GT] = ACTIONS(4193),
    [anon_sym_with] = ACTIONS(4162),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2987] = {
    [sym_preproc_region] = STATE(2987),
    [sym_preproc_endregion] = STATE(2987),
    [sym_preproc_line] = STATE(2987),
    [sym_preproc_pragma] = STATE(2987),
    [sym_preproc_nullable] = STATE(2987),
    [sym_preproc_error] = STATE(2987),
    [sym_preproc_warning] = STATE(2987),
    [sym_preproc_define] = STATE(2987),
    [sym_preproc_undef] = STATE(2987),
    [sym__identifier_token] = ACTIONS(4587),
    [anon_sym_alias] = ACTIONS(4587),
    [anon_sym_SEMI] = ACTIONS(4589),
    [anon_sym_global] = ACTIONS(4587),
    [anon_sym_LBRACK] = ACTIONS(4589),
    [anon_sym_COLON] = ACTIONS(4589),
    [anon_sym_COMMA] = ACTIONS(4589),
    [anon_sym_RBRACK] = ACTIONS(4589),
    [anon_sym_LPAREN] = ACTIONS(4589),
    [anon_sym_RPAREN] = ACTIONS(4589),
    [anon_sym_LBRACE] = ACTIONS(4589),
    [anon_sym_RBRACE] = ACTIONS(4589),
    [anon_sym_file] = ACTIONS(4587),
    [anon_sym_LT] = ACTIONS(4587),
    [anon_sym_GT] = ACTIONS(4587),
    [anon_sym_in] = ACTIONS(4587),
    [anon_sym_where] = ACTIONS(4587),
    [anon_sym_QMARK] = ACTIONS(4587),
    [anon_sym_notnull] = ACTIONS(4587),
    [anon_sym_unmanaged] = ACTIONS(4587),
    [anon_sym_BANG] = ACTIONS(4587),
    [anon_sym_PLUS_PLUS] = ACTIONS(4589),
    [anon_sym_DASH_DASH] = ACTIONS(4589),
    [anon_sym_PLUS] = ACTIONS(4587),
    [anon_sym_DASH] = ACTIONS(4587),
    [anon_sym_STAR] = ACTIONS(4589),
    [anon_sym_SLASH] = ACTIONS(4587),
    [anon_sym_PERCENT] = ACTIONS(4589),
    [anon_sym_CARET] = ACTIONS(4589),
    [anon_sym_PIPE] = ACTIONS(4587),
    [anon_sym_AMP] = ACTIONS(4587),
    [anon_sym_LT_LT] = ACTIONS(4589),
    [anon_sym_GT_GT] = ACTIONS(4587),
    [anon_sym_GT_GT_GT] = ACTIONS(4589),
    [anon_sym_EQ_EQ] = ACTIONS(4589),
    [anon_sym_BANG_EQ] = ACTIONS(4589),
    [anon_sym_GT_EQ] = ACTIONS(4589),
    [anon_sym_LT_EQ] = ACTIONS(4589),
    [anon_sym_DOT] = ACTIONS(4587),
    [anon_sym_scoped] = ACTIONS(4587),
    [anon_sym_EQ_GT] = ACTIONS(4591),
    [anon_sym_var] = ACTIONS(4587),
    [anon_sym_yield] = ACTIONS(4587),
    [anon_sym_switch] = ACTIONS(4587),
    [anon_sym_when] = ACTIONS(4587),
    [sym_discard] = ACTIONS(4587),
    [anon_sym_DOT_DOT] = ACTIONS(4589),
    [anon_sym_and] = ACTIONS(4587),
    [anon_sym_or] = ACTIONS(4587),
    [anon_sym_AMP_AMP] = ACTIONS(4589),
    [anon_sym_PIPE_PIPE] = ACTIONS(4589),
    [anon_sym_QMARK_QMARK] = ACTIONS(4589),
    [anon_sym_from] = ACTIONS(4587),
    [anon_sym_into] = ACTIONS(4587),
    [anon_sym_join] = ACTIONS(4587),
    [anon_sym_on] = ACTIONS(4587),
    [anon_sym_equals] = ACTIONS(4587),
    [anon_sym_let] = ACTIONS(4587),
    [anon_sym_orderby] = ACTIONS(4587),
    [anon_sym_ascending] = ACTIONS(4587),
    [anon_sym_descending] = ACTIONS(4587),
    [anon_sym_group] = ACTIONS(4587),
    [anon_sym_by] = ACTIONS(4587),
    [anon_sym_select] = ACTIONS(4587),
    [anon_sym_as] = ACTIONS(4587),
    [anon_sym_is] = ACTIONS(4587),
    [anon_sym_DASH_GT] = ACTIONS(4589),
    [anon_sym_with] = ACTIONS(4587),
    [aux_sym_preproc_if_token3] = ACTIONS(4589),
    [aux_sym_preproc_else_token1] = ACTIONS(4589),
    [aux_sym_preproc_elif_token1] = ACTIONS(4589),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2988] = {
    [sym_preproc_region] = STATE(2988),
    [sym_preproc_endregion] = STATE(2988),
    [sym_preproc_line] = STATE(2988),
    [sym_preproc_pragma] = STATE(2988),
    [sym_preproc_nullable] = STATE(2988),
    [sym_preproc_error] = STATE(2988),
    [sym_preproc_warning] = STATE(2988),
    [sym_preproc_define] = STATE(2988),
    [sym_preproc_undef] = STATE(2988),
    [sym__identifier_token] = ACTIONS(4492),
    [anon_sym_alias] = ACTIONS(4492),
    [anon_sym_SEMI] = ACTIONS(4494),
    [anon_sym_global] = ACTIONS(4492),
    [anon_sym_LBRACK] = ACTIONS(4593),
    [anon_sym_COLON] = ACTIONS(4494),
    [anon_sym_COMMA] = ACTIONS(4494),
    [anon_sym_RBRACK] = ACTIONS(4494),
    [anon_sym_LPAREN] = ACTIONS(4494),
    [anon_sym_RPAREN] = ACTIONS(4494),
    [anon_sym_LBRACE] = ACTIONS(4494),
    [anon_sym_RBRACE] = ACTIONS(4494),
    [anon_sym_file] = ACTIONS(4492),
    [anon_sym_LT] = ACTIONS(4492),
    [anon_sym_GT] = ACTIONS(4492),
    [anon_sym_in] = ACTIONS(4492),
    [anon_sym_where] = ACTIONS(4492),
    [anon_sym_QMARK] = ACTIONS(4596),
    [anon_sym_notnull] = ACTIONS(4492),
    [anon_sym_unmanaged] = ACTIONS(4492),
    [anon_sym_BANG] = ACTIONS(4492),
    [anon_sym_PLUS_PLUS] = ACTIONS(4494),
    [anon_sym_DASH_DASH] = ACTIONS(4494),
    [anon_sym_PLUS] = ACTIONS(4492),
    [anon_sym_DASH] = ACTIONS(4492),
    [anon_sym_STAR] = ACTIONS(4599),
    [anon_sym_SLASH] = ACTIONS(4492),
    [anon_sym_PERCENT] = ACTIONS(4494),
    [anon_sym_CARET] = ACTIONS(4494),
    [anon_sym_PIPE] = ACTIONS(4492),
    [anon_sym_AMP] = ACTIONS(4492),
    [anon_sym_LT_LT] = ACTIONS(4494),
    [anon_sym_GT_GT] = ACTIONS(4492),
    [anon_sym_GT_GT_GT] = ACTIONS(4494),
    [anon_sym_EQ_EQ] = ACTIONS(4494),
    [anon_sym_BANG_EQ] = ACTIONS(4494),
    [anon_sym_GT_EQ] = ACTIONS(4494),
    [anon_sym_LT_EQ] = ACTIONS(4494),
    [anon_sym_DOT] = ACTIONS(4634),
    [anon_sym_scoped] = ACTIONS(4492),
    [anon_sym_EQ_GT] = ACTIONS(4494),
    [anon_sym_var] = ACTIONS(4492),
    [anon_sym_yield] = ACTIONS(4492),
    [anon_sym_switch] = ACTIONS(4492),
    [anon_sym_when] = ACTIONS(4492),
    [sym_discard] = ACTIONS(4492),
    [anon_sym_DOT_DOT] = ACTIONS(4494),
    [anon_sym_and] = ACTIONS(4492),
    [anon_sym_or] = ACTIONS(4492),
    [anon_sym_AMP_AMP] = ACTIONS(4494),
    [anon_sym_PIPE_PIPE] = ACTIONS(4494),
    [anon_sym_QMARK_QMARK] = ACTIONS(4494),
    [anon_sym_from] = ACTIONS(4492),
    [anon_sym_into] = ACTIONS(4492),
    [anon_sym_join] = ACTIONS(4492),
    [anon_sym_on] = ACTIONS(4492),
    [anon_sym_equals] = ACTIONS(4492),
    [anon_sym_let] = ACTIONS(4492),
    [anon_sym_orderby] = ACTIONS(4492),
    [anon_sym_ascending] = ACTIONS(4492),
    [anon_sym_descending] = ACTIONS(4492),
    [anon_sym_group] = ACTIONS(4492),
    [anon_sym_by] = ACTIONS(4492),
    [anon_sym_select] = ACTIONS(4492),
    [anon_sym_as] = ACTIONS(4492),
    [anon_sym_is] = ACTIONS(4492),
    [anon_sym_DASH_GT] = ACTIONS(4636),
    [anon_sym_with] = ACTIONS(4492),
    [aux_sym_preproc_if_token3] = ACTIONS(4494),
    [aux_sym_preproc_else_token1] = ACTIONS(4494),
    [aux_sym_preproc_elif_token1] = ACTIONS(4494),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2989] = {
    [sym__name] = STATE(3912),
    [sym_alias_qualified_name] = STATE(3924),
    [sym__simple_name] = STATE(3924),
    [sym_qualified_name] = STATE(3924),
    [sym_generic_name] = STATE(3900),
    [sym_ref_type] = STATE(3954),
    [sym__scoped_base_type] = STATE(3916),
    [sym_identifier] = STATE(3808),
    [sym__reserved_identifier] = STATE(3871),
    [sym_preproc_region] = STATE(2989),
    [sym_preproc_endregion] = STATE(2989),
    [sym_preproc_line] = STATE(2989),
    [sym_preproc_pragma] = STATE(2989),
    [sym_preproc_nullable] = STATE(2989),
    [sym_preproc_error] = STATE(2989),
    [sym_preproc_warning] = STATE(2989),
    [sym_preproc_define] = STATE(2989),
    [sym_preproc_undef] = STATE(2989),
    [sym__identifier_token] = ACTIONS(4223),
    [anon_sym_alias] = ACTIONS(4225),
    [anon_sym_global] = ACTIONS(4225),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_LPAREN] = ACTIONS(3993),
    [anon_sym_ref] = ACTIONS(4638),
    [anon_sym_LBRACE] = ACTIONS(3993),
    [anon_sym_file] = ACTIONS(4225),
    [anon_sym_LT] = ACTIONS(3995),
    [anon_sym_GT] = ACTIONS(3995),
    [anon_sym_where] = ACTIONS(4225),
    [anon_sym_QMARK] = ACTIONS(3995),
    [anon_sym_notnull] = ACTIONS(4225),
    [anon_sym_unmanaged] = ACTIONS(4225),
    [anon_sym_BANG] = ACTIONS(3995),
    [anon_sym_PLUS_PLUS] = ACTIONS(3993),
    [anon_sym_DASH_DASH] = ACTIONS(3993),
    [anon_sym_PLUS] = ACTIONS(3995),
    [anon_sym_DASH] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3993),
    [anon_sym_SLASH] = ACTIONS(3995),
    [anon_sym_PERCENT] = ACTIONS(3993),
    [anon_sym_CARET] = ACTIONS(3993),
    [anon_sym_PIPE] = ACTIONS(3995),
    [anon_sym_AMP] = ACTIONS(3995),
    [anon_sym_LT_LT] = ACTIONS(3993),
    [anon_sym_GT_GT] = ACTIONS(3995),
    [anon_sym_GT_GT_GT] = ACTIONS(3993),
    [anon_sym_EQ_EQ] = ACTIONS(3993),
    [anon_sym_BANG_EQ] = ACTIONS(3993),
    [anon_sym_GT_EQ] = ACTIONS(3993),
    [anon_sym_LT_EQ] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3995),
    [anon_sym_scoped] = ACTIONS(4225),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(4225),
    [anon_sym_yield] = ACTIONS(4225),
    [anon_sym_switch] = ACTIONS(3995),
    [anon_sym_when] = ACTIONS(4225),
    [anon_sym_DOT_DOT] = ACTIONS(3993),
    [anon_sym_and] = ACTIONS(3995),
    [anon_sym_or] = ACTIONS(3995),
    [anon_sym_AMP_AMP] = ACTIONS(3993),
    [anon_sym_PIPE_PIPE] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK] = ACTIONS(3993),
    [anon_sym_from] = ACTIONS(4225),
    [anon_sym_into] = ACTIONS(4229),
    [anon_sym_join] = ACTIONS(4225),
    [anon_sym_on] = ACTIONS(4225),
    [anon_sym_equals] = ACTIONS(4225),
    [anon_sym_let] = ACTIONS(4225),
    [anon_sym_orderby] = ACTIONS(4225),
    [anon_sym_ascending] = ACTIONS(4225),
    [anon_sym_descending] = ACTIONS(4225),
    [anon_sym_group] = ACTIONS(4225),
    [anon_sym_by] = ACTIONS(4229),
    [anon_sym_select] = ACTIONS(4225),
    [anon_sym_as] = ACTIONS(3995),
    [anon_sym_is] = ACTIONS(3995),
    [anon_sym_DASH_GT] = ACTIONS(3993),
    [anon_sym_with] = ACTIONS(3995),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2990] = {
    [sym_preproc_region] = STATE(2990),
    [sym_preproc_endregion] = STATE(2990),
    [sym_preproc_line] = STATE(2990),
    [sym_preproc_pragma] = STATE(2990),
    [sym_preproc_nullable] = STATE(2990),
    [sym_preproc_error] = STATE(2990),
    [sym_preproc_warning] = STATE(2990),
    [sym_preproc_define] = STATE(2990),
    [sym_preproc_undef] = STATE(2990),
    [anon_sym_SEMI] = ACTIONS(4640),
    [anon_sym_EQ] = ACTIONS(4642),
    [anon_sym_LBRACK] = ACTIONS(4640),
    [anon_sym_COLON] = ACTIONS(4640),
    [anon_sym_COMMA] = ACTIONS(4640),
    [anon_sym_RBRACK] = ACTIONS(4640),
    [anon_sym_LPAREN] = ACTIONS(4640),
    [anon_sym_RPAREN] = ACTIONS(4640),
    [anon_sym_RBRACE] = ACTIONS(4640),
    [anon_sym_LT] = ACTIONS(4642),
    [anon_sym_GT] = ACTIONS(4642),
    [anon_sym_in] = ACTIONS(4642),
    [anon_sym_where] = ACTIONS(4640),
    [anon_sym_QMARK] = ACTIONS(4642),
    [anon_sym_BANG] = ACTIONS(4642),
    [anon_sym_PLUS_PLUS] = ACTIONS(4640),
    [anon_sym_DASH_DASH] = ACTIONS(4640),
    [anon_sym_PLUS] = ACTIONS(4642),
    [anon_sym_DASH] = ACTIONS(4642),
    [anon_sym_STAR] = ACTIONS(4642),
    [anon_sym_SLASH] = ACTIONS(4642),
    [anon_sym_PERCENT] = ACTIONS(4642),
    [anon_sym_CARET] = ACTIONS(4642),
    [anon_sym_PIPE] = ACTIONS(4642),
    [anon_sym_AMP] = ACTIONS(4642),
    [anon_sym_LT_LT] = ACTIONS(4642),
    [anon_sym_GT_GT] = ACTIONS(4642),
    [anon_sym_GT_GT_GT] = ACTIONS(4642),
    [anon_sym_EQ_EQ] = ACTIONS(4640),
    [anon_sym_BANG_EQ] = ACTIONS(4640),
    [anon_sym_GT_EQ] = ACTIONS(4640),
    [anon_sym_LT_EQ] = ACTIONS(4640),
    [anon_sym_DOT] = ACTIONS(4642),
    [anon_sym_EQ_GT] = ACTIONS(4640),
    [anon_sym_switch] = ACTIONS(4640),
    [anon_sym_DOT_DOT] = ACTIONS(4640),
    [anon_sym_and] = ACTIONS(4640),
    [anon_sym_or] = ACTIONS(4642),
    [anon_sym_PLUS_EQ] = ACTIONS(4640),
    [anon_sym_DASH_EQ] = ACTIONS(4640),
    [anon_sym_STAR_EQ] = ACTIONS(4640),
    [anon_sym_SLASH_EQ] = ACTIONS(4640),
    [anon_sym_PERCENT_EQ] = ACTIONS(4640),
    [anon_sym_AMP_EQ] = ACTIONS(4640),
    [anon_sym_CARET_EQ] = ACTIONS(4640),
    [anon_sym_PIPE_EQ] = ACTIONS(4640),
    [anon_sym_LT_LT_EQ] = ACTIONS(4640),
    [anon_sym_GT_GT_EQ] = ACTIONS(4640),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4640),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4640),
    [anon_sym_AMP_AMP] = ACTIONS(4640),
    [anon_sym_PIPE_PIPE] = ACTIONS(4640),
    [anon_sym_QMARK_QMARK] = ACTIONS(4642),
    [anon_sym_from] = ACTIONS(4640),
    [anon_sym_into] = ACTIONS(4640),
    [anon_sym_join] = ACTIONS(4640),
    [anon_sym_on] = ACTIONS(4640),
    [anon_sym_equals] = ACTIONS(4640),
    [anon_sym_let] = ACTIONS(4640),
    [anon_sym_orderby] = ACTIONS(4640),
    [anon_sym_group] = ACTIONS(4640),
    [anon_sym_by] = ACTIONS(4640),
    [anon_sym_select] = ACTIONS(4640),
    [anon_sym_as] = ACTIONS(4640),
    [anon_sym_is] = ACTIONS(4640),
    [anon_sym_DASH_GT] = ACTIONS(4640),
    [anon_sym_with] = ACTIONS(4640),
    [aux_sym_preproc_if_token3] = ACTIONS(4640),
    [aux_sym_preproc_else_token1] = ACTIONS(4640),
    [aux_sym_preproc_elif_token1] = ACTIONS(4640),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2991] = {
    [sym__name] = STATE(3912),
    [sym_alias_qualified_name] = STATE(3924),
    [sym__simple_name] = STATE(3924),
    [sym_qualified_name] = STATE(3924),
    [sym_generic_name] = STATE(3900),
    [sym_ref_type] = STATE(3954),
    [sym__scoped_base_type] = STATE(3916),
    [sym_identifier] = STATE(3808),
    [sym__reserved_identifier] = STATE(3871),
    [sym_preproc_region] = STATE(2991),
    [sym_preproc_endregion] = STATE(2991),
    [sym_preproc_line] = STATE(2991),
    [sym_preproc_pragma] = STATE(2991),
    [sym_preproc_nullable] = STATE(2991),
    [sym_preproc_error] = STATE(2991),
    [sym_preproc_warning] = STATE(2991),
    [sym_preproc_define] = STATE(2991),
    [sym_preproc_undef] = STATE(2991),
    [sym__identifier_token] = ACTIONS(4223),
    [anon_sym_alias] = ACTIONS(4225),
    [anon_sym_global] = ACTIONS(4225),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_LPAREN] = ACTIONS(3993),
    [anon_sym_ref] = ACTIONS(4644),
    [anon_sym_LBRACE] = ACTIONS(3993),
    [anon_sym_file] = ACTIONS(4225),
    [anon_sym_LT] = ACTIONS(3995),
    [anon_sym_GT] = ACTIONS(3995),
    [anon_sym_where] = ACTIONS(4225),
    [anon_sym_QMARK] = ACTIONS(3995),
    [anon_sym_notnull] = ACTIONS(4225),
    [anon_sym_unmanaged] = ACTIONS(4225),
    [anon_sym_BANG] = ACTIONS(3995),
    [anon_sym_PLUS_PLUS] = ACTIONS(3993),
    [anon_sym_DASH_DASH] = ACTIONS(3993),
    [anon_sym_PLUS] = ACTIONS(3995),
    [anon_sym_DASH] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3993),
    [anon_sym_SLASH] = ACTIONS(3995),
    [anon_sym_PERCENT] = ACTIONS(3993),
    [anon_sym_CARET] = ACTIONS(3993),
    [anon_sym_PIPE] = ACTIONS(3995),
    [anon_sym_AMP] = ACTIONS(3995),
    [anon_sym_LT_LT] = ACTIONS(3993),
    [anon_sym_GT_GT] = ACTIONS(3995),
    [anon_sym_GT_GT_GT] = ACTIONS(3993),
    [anon_sym_EQ_EQ] = ACTIONS(3993),
    [anon_sym_BANG_EQ] = ACTIONS(3993),
    [anon_sym_GT_EQ] = ACTIONS(3993),
    [anon_sym_LT_EQ] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3995),
    [anon_sym_scoped] = ACTIONS(4225),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(4225),
    [anon_sym_yield] = ACTIONS(4225),
    [anon_sym_switch] = ACTIONS(3995),
    [anon_sym_when] = ACTIONS(4225),
    [anon_sym_DOT_DOT] = ACTIONS(3993),
    [anon_sym_and] = ACTIONS(3995),
    [anon_sym_or] = ACTIONS(3995),
    [anon_sym_AMP_AMP] = ACTIONS(3993),
    [anon_sym_PIPE_PIPE] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK] = ACTIONS(3993),
    [anon_sym_from] = ACTIONS(4225),
    [anon_sym_into] = ACTIONS(4229),
    [anon_sym_join] = ACTIONS(4225),
    [anon_sym_on] = ACTIONS(4225),
    [anon_sym_equals] = ACTIONS(4229),
    [anon_sym_let] = ACTIONS(4225),
    [anon_sym_orderby] = ACTIONS(4225),
    [anon_sym_ascending] = ACTIONS(4225),
    [anon_sym_descending] = ACTIONS(4225),
    [anon_sym_group] = ACTIONS(4225),
    [anon_sym_by] = ACTIONS(4225),
    [anon_sym_select] = ACTIONS(4225),
    [anon_sym_as] = ACTIONS(3995),
    [anon_sym_is] = ACTIONS(3995),
    [anon_sym_DASH_GT] = ACTIONS(3993),
    [anon_sym_with] = ACTIONS(3995),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2992] = {
    [sym_preproc_region] = STATE(2992),
    [sym_preproc_endregion] = STATE(2992),
    [sym_preproc_line] = STATE(2992),
    [sym_preproc_pragma] = STATE(2992),
    [sym_preproc_nullable] = STATE(2992),
    [sym_preproc_error] = STATE(2992),
    [sym_preproc_warning] = STATE(2992),
    [sym_preproc_define] = STATE(2992),
    [sym_preproc_undef] = STATE(2992),
    [sym__identifier_token] = ACTIONS(4492),
    [anon_sym_alias] = ACTIONS(4492),
    [anon_sym_SEMI] = ACTIONS(4494),
    [anon_sym_global] = ACTIONS(4492),
    [anon_sym_LBRACK] = ACTIONS(4593),
    [anon_sym_COMMA] = ACTIONS(4494),
    [anon_sym_RBRACK] = ACTIONS(4494),
    [anon_sym_LPAREN] = ACTIONS(4494),
    [anon_sym_RPAREN] = ACTIONS(4494),
    [anon_sym_LBRACE] = ACTIONS(4494),
    [anon_sym_RBRACE] = ACTIONS(4494),
    [anon_sym_file] = ACTIONS(4492),
    [anon_sym_LT] = ACTIONS(4492),
    [anon_sym_GT] = ACTIONS(4492),
    [anon_sym_in] = ACTIONS(4492),
    [anon_sym_where] = ACTIONS(4492),
    [anon_sym_QMARK] = ACTIONS(4596),
    [anon_sym_notnull] = ACTIONS(4492),
    [anon_sym_unmanaged] = ACTIONS(4492),
    [anon_sym_BANG] = ACTIONS(4492),
    [anon_sym_PLUS_PLUS] = ACTIONS(4494),
    [anon_sym_DASH_DASH] = ACTIONS(4494),
    [anon_sym_PLUS] = ACTIONS(4492),
    [anon_sym_DASH] = ACTIONS(4492),
    [anon_sym_STAR] = ACTIONS(4599),
    [anon_sym_SLASH] = ACTIONS(4492),
    [anon_sym_PERCENT] = ACTIONS(4494),
    [anon_sym_CARET] = ACTIONS(4494),
    [anon_sym_PIPE] = ACTIONS(4492),
    [anon_sym_AMP] = ACTIONS(4492),
    [anon_sym_LT_LT] = ACTIONS(4494),
    [anon_sym_GT_GT] = ACTIONS(4492),
    [anon_sym_GT_GT_GT] = ACTIONS(4494),
    [anon_sym_EQ_EQ] = ACTIONS(4494),
    [anon_sym_BANG_EQ] = ACTIONS(4494),
    [anon_sym_GT_EQ] = ACTIONS(4494),
    [anon_sym_LT_EQ] = ACTIONS(4494),
    [anon_sym_DOT] = ACTIONS(4646),
    [anon_sym_scoped] = ACTIONS(4492),
    [anon_sym_EQ_GT] = ACTIONS(4494),
    [anon_sym_var] = ACTIONS(4492),
    [anon_sym_yield] = ACTIONS(4492),
    [anon_sym_switch] = ACTIONS(4492),
    [anon_sym_when] = ACTIONS(4492),
    [sym_discard] = ACTIONS(4492),
    [anon_sym_DOT_DOT] = ACTIONS(4494),
    [anon_sym_and] = ACTIONS(4492),
    [anon_sym_or] = ACTIONS(4492),
    [anon_sym_AMP_AMP] = ACTIONS(4494),
    [anon_sym_PIPE_PIPE] = ACTIONS(4494),
    [anon_sym_QMARK_QMARK] = ACTIONS(4494),
    [anon_sym_from] = ACTIONS(4492),
    [anon_sym_into] = ACTIONS(4492),
    [anon_sym_join] = ACTIONS(4492),
    [anon_sym_on] = ACTIONS(4492),
    [anon_sym_equals] = ACTIONS(4492),
    [anon_sym_let] = ACTIONS(4492),
    [anon_sym_orderby] = ACTIONS(4492),
    [anon_sym_ascending] = ACTIONS(4492),
    [anon_sym_descending] = ACTIONS(4492),
    [anon_sym_group] = ACTIONS(4492),
    [anon_sym_by] = ACTIONS(4492),
    [anon_sym_select] = ACTIONS(4492),
    [anon_sym_as] = ACTIONS(4492),
    [anon_sym_is] = ACTIONS(4492),
    [anon_sym_DASH_GT] = ACTIONS(4494),
    [anon_sym_with] = ACTIONS(4492),
    [aux_sym_preproc_if_token3] = ACTIONS(4494),
    [aux_sym_preproc_else_token1] = ACTIONS(4494),
    [aux_sym_preproc_elif_token1] = ACTIONS(4494),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2993] = {
    [sym__name] = STATE(4159),
    [sym_alias_qualified_name] = STATE(4085),
    [sym__simple_name] = STATE(4085),
    [sym_qualified_name] = STATE(4085),
    [sym_generic_name] = STATE(3959),
    [sym_ref_type] = STATE(3971),
    [sym__scoped_base_type] = STATE(3973),
    [sym_identifier] = STATE(3889),
    [sym__reserved_identifier] = STATE(3911),
    [sym_preproc_region] = STATE(2993),
    [sym_preproc_endregion] = STATE(2993),
    [sym_preproc_line] = STATE(2993),
    [sym_preproc_pragma] = STATE(2993),
    [sym_preproc_nullable] = STATE(2993),
    [sym_preproc_error] = STATE(2993),
    [sym_preproc_warning] = STATE(2993),
    [sym_preproc_define] = STATE(2993),
    [sym_preproc_undef] = STATE(2993),
    [sym__identifier_token] = ACTIONS(4248),
    [anon_sym_alias] = ACTIONS(4250),
    [anon_sym_global] = ACTIONS(4250),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_LPAREN] = ACTIONS(3993),
    [anon_sym_ref] = ACTIONS(4648),
    [anon_sym_LBRACE] = ACTIONS(3993),
    [anon_sym_file] = ACTIONS(4250),
    [anon_sym_LT] = ACTIONS(3995),
    [anon_sym_GT] = ACTIONS(3995),
    [anon_sym_where] = ACTIONS(4250),
    [anon_sym_QMARK] = ACTIONS(3995),
    [anon_sym_notnull] = ACTIONS(4250),
    [anon_sym_unmanaged] = ACTIONS(4250),
    [anon_sym_BANG] = ACTIONS(3995),
    [anon_sym_PLUS_PLUS] = ACTIONS(3993),
    [anon_sym_DASH_DASH] = ACTIONS(3993),
    [anon_sym_PLUS] = ACTIONS(3995),
    [anon_sym_DASH] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3993),
    [anon_sym_SLASH] = ACTIONS(3995),
    [anon_sym_PERCENT] = ACTIONS(3993),
    [anon_sym_CARET] = ACTIONS(3993),
    [anon_sym_PIPE] = ACTIONS(3995),
    [anon_sym_AMP] = ACTIONS(3995),
    [anon_sym_LT_LT] = ACTIONS(3993),
    [anon_sym_GT_GT] = ACTIONS(3995),
    [anon_sym_GT_GT_GT] = ACTIONS(3993),
    [anon_sym_EQ_EQ] = ACTIONS(3993),
    [anon_sym_BANG_EQ] = ACTIONS(3993),
    [anon_sym_GT_EQ] = ACTIONS(3993),
    [anon_sym_LT_EQ] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3995),
    [anon_sym_scoped] = ACTIONS(4250),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(4250),
    [anon_sym_yield] = ACTIONS(4250),
    [anon_sym_switch] = ACTIONS(3995),
    [anon_sym_when] = ACTIONS(4250),
    [anon_sym_DOT_DOT] = ACTIONS(3993),
    [anon_sym_and] = ACTIONS(3995),
    [anon_sym_or] = ACTIONS(3995),
    [anon_sym_AMP_AMP] = ACTIONS(3993),
    [anon_sym_PIPE_PIPE] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK] = ACTIONS(3993),
    [anon_sym_from] = ACTIONS(4250),
    [anon_sym_into] = ACTIONS(4250),
    [anon_sym_join] = ACTIONS(4250),
    [anon_sym_on] = ACTIONS(4250),
    [anon_sym_equals] = ACTIONS(4525),
    [anon_sym_let] = ACTIONS(4250),
    [anon_sym_orderby] = ACTIONS(4250),
    [anon_sym_ascending] = ACTIONS(4250),
    [anon_sym_descending] = ACTIONS(4250),
    [anon_sym_group] = ACTIONS(4250),
    [anon_sym_by] = ACTIONS(4250),
    [anon_sym_select] = ACTIONS(4250),
    [anon_sym_as] = ACTIONS(3995),
    [anon_sym_is] = ACTIONS(3995),
    [anon_sym_DASH_GT] = ACTIONS(3993),
    [anon_sym_with] = ACTIONS(3995),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2994] = {
    [sym_preproc_region] = STATE(2994),
    [sym_preproc_endregion] = STATE(2994),
    [sym_preproc_line] = STATE(2994),
    [sym_preproc_pragma] = STATE(2994),
    [sym_preproc_nullable] = STATE(2994),
    [sym_preproc_error] = STATE(2994),
    [sym_preproc_warning] = STATE(2994),
    [sym_preproc_define] = STATE(2994),
    [sym_preproc_undef] = STATE(2994),
    [sym__identifier_token] = ACTIONS(4650),
    [anon_sym_alias] = ACTIONS(4650),
    [anon_sym_SEMI] = ACTIONS(4652),
    [anon_sym_global] = ACTIONS(4650),
    [anon_sym_LBRACK] = ACTIONS(4652),
    [anon_sym_COLON] = ACTIONS(4652),
    [anon_sym_COMMA] = ACTIONS(4652),
    [anon_sym_RBRACK] = ACTIONS(4652),
    [anon_sym_LPAREN] = ACTIONS(4652),
    [anon_sym_RPAREN] = ACTIONS(4652),
    [anon_sym_RBRACE] = ACTIONS(4652),
    [anon_sym_file] = ACTIONS(4650),
    [anon_sym_LT] = ACTIONS(4650),
    [anon_sym_GT] = ACTIONS(4650),
    [anon_sym_in] = ACTIONS(4650),
    [anon_sym_where] = ACTIONS(4650),
    [anon_sym_QMARK] = ACTIONS(4650),
    [anon_sym_notnull] = ACTIONS(4650),
    [anon_sym_unmanaged] = ACTIONS(4650),
    [anon_sym_BANG] = ACTIONS(4650),
    [anon_sym_PLUS_PLUS] = ACTIONS(4652),
    [anon_sym_DASH_DASH] = ACTIONS(4652),
    [anon_sym_PLUS] = ACTIONS(4650),
    [anon_sym_DASH] = ACTIONS(4650),
    [anon_sym_STAR] = ACTIONS(4652),
    [anon_sym_SLASH] = ACTIONS(4650),
    [anon_sym_PERCENT] = ACTIONS(4652),
    [anon_sym_CARET] = ACTIONS(4652),
    [anon_sym_PIPE] = ACTIONS(4650),
    [anon_sym_AMP] = ACTIONS(4650),
    [anon_sym_LT_LT] = ACTIONS(4652),
    [anon_sym_GT_GT] = ACTIONS(4650),
    [anon_sym_GT_GT_GT] = ACTIONS(4652),
    [anon_sym_EQ_EQ] = ACTIONS(4652),
    [anon_sym_BANG_EQ] = ACTIONS(4652),
    [anon_sym_GT_EQ] = ACTIONS(4652),
    [anon_sym_LT_EQ] = ACTIONS(4652),
    [anon_sym_DOT] = ACTIONS(4650),
    [anon_sym_scoped] = ACTIONS(4650),
    [anon_sym_EQ_GT] = ACTIONS(4652),
    [anon_sym_var] = ACTIONS(4650),
    [anon_sym_yield] = ACTIONS(4650),
    [anon_sym_switch] = ACTIONS(4650),
    [anon_sym_when] = ACTIONS(4650),
    [sym_discard] = ACTIONS(4650),
    [anon_sym_DOT_DOT] = ACTIONS(4652),
    [anon_sym_and] = ACTIONS(4650),
    [anon_sym_or] = ACTIONS(4650),
    [anon_sym_AMP_AMP] = ACTIONS(4652),
    [anon_sym_PIPE_PIPE] = ACTIONS(4652),
    [anon_sym_QMARK_QMARK] = ACTIONS(4652),
    [anon_sym_from] = ACTIONS(4650),
    [anon_sym_into] = ACTIONS(4650),
    [anon_sym_join] = ACTIONS(4650),
    [anon_sym_on] = ACTIONS(4650),
    [anon_sym_equals] = ACTIONS(4650),
    [anon_sym_let] = ACTIONS(4650),
    [anon_sym_orderby] = ACTIONS(4650),
    [anon_sym_ascending] = ACTIONS(4650),
    [anon_sym_descending] = ACTIONS(4650),
    [anon_sym_group] = ACTIONS(4650),
    [anon_sym_by] = ACTIONS(4650),
    [anon_sym_select] = ACTIONS(4650),
    [anon_sym_as] = ACTIONS(4650),
    [anon_sym_is] = ACTIONS(4650),
    [anon_sym_DASH_GT] = ACTIONS(4652),
    [anon_sym_with] = ACTIONS(4650),
    [aux_sym_preproc_if_token3] = ACTIONS(4652),
    [aux_sym_preproc_else_token1] = ACTIONS(4652),
    [aux_sym_preproc_elif_token1] = ACTIONS(4652),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2995] = {
    [sym_preproc_region] = STATE(2995),
    [sym_preproc_endregion] = STATE(2995),
    [sym_preproc_line] = STATE(2995),
    [sym_preproc_pragma] = STATE(2995),
    [sym_preproc_nullable] = STATE(2995),
    [sym_preproc_error] = STATE(2995),
    [sym_preproc_warning] = STATE(2995),
    [sym_preproc_define] = STATE(2995),
    [sym_preproc_undef] = STATE(2995),
    [sym__identifier_token] = ACTIONS(4650),
    [anon_sym_alias] = ACTIONS(4650),
    [anon_sym_SEMI] = ACTIONS(4652),
    [anon_sym_global] = ACTIONS(4650),
    [anon_sym_LBRACK] = ACTIONS(4652),
    [anon_sym_COLON] = ACTIONS(4652),
    [anon_sym_COMMA] = ACTIONS(4652),
    [anon_sym_RBRACK] = ACTIONS(4652),
    [anon_sym_LPAREN] = ACTIONS(4652),
    [anon_sym_RPAREN] = ACTIONS(4652),
    [anon_sym_RBRACE] = ACTIONS(4652),
    [anon_sym_file] = ACTIONS(4650),
    [anon_sym_LT] = ACTIONS(4650),
    [anon_sym_GT] = ACTIONS(4650),
    [anon_sym_in] = ACTIONS(4650),
    [anon_sym_where] = ACTIONS(4650),
    [anon_sym_QMARK] = ACTIONS(4650),
    [anon_sym_notnull] = ACTIONS(4650),
    [anon_sym_unmanaged] = ACTIONS(4650),
    [anon_sym_BANG] = ACTIONS(4650),
    [anon_sym_PLUS_PLUS] = ACTIONS(4652),
    [anon_sym_DASH_DASH] = ACTIONS(4652),
    [anon_sym_PLUS] = ACTIONS(4650),
    [anon_sym_DASH] = ACTIONS(4650),
    [anon_sym_STAR] = ACTIONS(4652),
    [anon_sym_SLASH] = ACTIONS(4650),
    [anon_sym_PERCENT] = ACTIONS(4652),
    [anon_sym_CARET] = ACTIONS(4652),
    [anon_sym_PIPE] = ACTIONS(4650),
    [anon_sym_AMP] = ACTIONS(4650),
    [anon_sym_LT_LT] = ACTIONS(4652),
    [anon_sym_GT_GT] = ACTIONS(4650),
    [anon_sym_GT_GT_GT] = ACTIONS(4652),
    [anon_sym_EQ_EQ] = ACTIONS(4652),
    [anon_sym_BANG_EQ] = ACTIONS(4652),
    [anon_sym_GT_EQ] = ACTIONS(4652),
    [anon_sym_LT_EQ] = ACTIONS(4652),
    [anon_sym_DOT] = ACTIONS(4650),
    [anon_sym_scoped] = ACTIONS(4650),
    [anon_sym_EQ_GT] = ACTIONS(4652),
    [anon_sym_var] = ACTIONS(4650),
    [anon_sym_yield] = ACTIONS(4650),
    [anon_sym_switch] = ACTIONS(4650),
    [anon_sym_when] = ACTIONS(4650),
    [sym_discard] = ACTIONS(4650),
    [anon_sym_DOT_DOT] = ACTIONS(4652),
    [anon_sym_and] = ACTIONS(4650),
    [anon_sym_or] = ACTIONS(4650),
    [anon_sym_AMP_AMP] = ACTIONS(4652),
    [anon_sym_PIPE_PIPE] = ACTIONS(4652),
    [anon_sym_QMARK_QMARK] = ACTIONS(4652),
    [anon_sym_from] = ACTIONS(4650),
    [anon_sym_into] = ACTIONS(4650),
    [anon_sym_join] = ACTIONS(4650),
    [anon_sym_on] = ACTIONS(4650),
    [anon_sym_equals] = ACTIONS(4650),
    [anon_sym_let] = ACTIONS(4650),
    [anon_sym_orderby] = ACTIONS(4650),
    [anon_sym_ascending] = ACTIONS(4650),
    [anon_sym_descending] = ACTIONS(4650),
    [anon_sym_group] = ACTIONS(4650),
    [anon_sym_by] = ACTIONS(4650),
    [anon_sym_select] = ACTIONS(4650),
    [anon_sym_as] = ACTIONS(4650),
    [anon_sym_is] = ACTIONS(4650),
    [anon_sym_DASH_GT] = ACTIONS(4652),
    [anon_sym_with] = ACTIONS(4650),
    [aux_sym_preproc_if_token3] = ACTIONS(4652),
    [aux_sym_preproc_else_token1] = ACTIONS(4652),
    [aux_sym_preproc_elif_token1] = ACTIONS(4652),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2996] = {
    [sym_preproc_region] = STATE(2996),
    [sym_preproc_endregion] = STATE(2996),
    [sym_preproc_line] = STATE(2996),
    [sym_preproc_pragma] = STATE(2996),
    [sym_preproc_nullable] = STATE(2996),
    [sym_preproc_error] = STATE(2996),
    [sym_preproc_warning] = STATE(2996),
    [sym_preproc_define] = STATE(2996),
    [sym_preproc_undef] = STATE(2996),
    [sym__identifier_token] = ACTIONS(4654),
    [anon_sym_alias] = ACTIONS(4654),
    [anon_sym_SEMI] = ACTIONS(4656),
    [anon_sym_global] = ACTIONS(4654),
    [anon_sym_LBRACK] = ACTIONS(4656),
    [anon_sym_COLON] = ACTIONS(4656),
    [anon_sym_COMMA] = ACTIONS(4656),
    [anon_sym_RBRACK] = ACTIONS(4656),
    [anon_sym_LPAREN] = ACTIONS(4656),
    [anon_sym_RPAREN] = ACTIONS(4656),
    [anon_sym_RBRACE] = ACTIONS(4656),
    [anon_sym_file] = ACTIONS(4654),
    [anon_sym_LT] = ACTIONS(4654),
    [anon_sym_GT] = ACTIONS(4654),
    [anon_sym_in] = ACTIONS(4654),
    [anon_sym_where] = ACTIONS(4654),
    [anon_sym_QMARK] = ACTIONS(4654),
    [anon_sym_notnull] = ACTIONS(4654),
    [anon_sym_unmanaged] = ACTIONS(4654),
    [anon_sym_BANG] = ACTIONS(4654),
    [anon_sym_PLUS_PLUS] = ACTIONS(4656),
    [anon_sym_DASH_DASH] = ACTIONS(4656),
    [anon_sym_PLUS] = ACTIONS(4654),
    [anon_sym_DASH] = ACTIONS(4654),
    [anon_sym_STAR] = ACTIONS(4656),
    [anon_sym_SLASH] = ACTIONS(4654),
    [anon_sym_PERCENT] = ACTIONS(4656),
    [anon_sym_CARET] = ACTIONS(4656),
    [anon_sym_PIPE] = ACTIONS(4654),
    [anon_sym_AMP] = ACTIONS(4654),
    [anon_sym_LT_LT] = ACTIONS(4656),
    [anon_sym_GT_GT] = ACTIONS(4654),
    [anon_sym_GT_GT_GT] = ACTIONS(4656),
    [anon_sym_EQ_EQ] = ACTIONS(4656),
    [anon_sym_BANG_EQ] = ACTIONS(4656),
    [anon_sym_GT_EQ] = ACTIONS(4656),
    [anon_sym_LT_EQ] = ACTIONS(4656),
    [anon_sym_DOT] = ACTIONS(4654),
    [anon_sym_scoped] = ACTIONS(4654),
    [anon_sym_EQ_GT] = ACTIONS(4656),
    [anon_sym_var] = ACTIONS(4654),
    [anon_sym_yield] = ACTIONS(4654),
    [anon_sym_switch] = ACTIONS(4654),
    [anon_sym_when] = ACTIONS(4654),
    [sym_discard] = ACTIONS(4654),
    [anon_sym_DOT_DOT] = ACTIONS(4656),
    [anon_sym_and] = ACTIONS(4654),
    [anon_sym_or] = ACTIONS(4654),
    [anon_sym_AMP_AMP] = ACTIONS(4656),
    [anon_sym_PIPE_PIPE] = ACTIONS(4656),
    [anon_sym_QMARK_QMARK] = ACTIONS(4656),
    [anon_sym_from] = ACTIONS(4654),
    [anon_sym_into] = ACTIONS(4654),
    [anon_sym_join] = ACTIONS(4654),
    [anon_sym_on] = ACTIONS(4654),
    [anon_sym_equals] = ACTIONS(4654),
    [anon_sym_let] = ACTIONS(4654),
    [anon_sym_orderby] = ACTIONS(4654),
    [anon_sym_ascending] = ACTIONS(4654),
    [anon_sym_descending] = ACTIONS(4654),
    [anon_sym_group] = ACTIONS(4654),
    [anon_sym_by] = ACTIONS(4654),
    [anon_sym_select] = ACTIONS(4654),
    [anon_sym_as] = ACTIONS(4654),
    [anon_sym_is] = ACTIONS(4654),
    [anon_sym_DASH_GT] = ACTIONS(4656),
    [anon_sym_with] = ACTIONS(4654),
    [aux_sym_preproc_if_token3] = ACTIONS(4656),
    [aux_sym_preproc_else_token1] = ACTIONS(4656),
    [aux_sym_preproc_elif_token1] = ACTIONS(4656),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2997] = {
    [sym__name] = STATE(4159),
    [sym_alias_qualified_name] = STATE(4085),
    [sym__simple_name] = STATE(4085),
    [sym_qualified_name] = STATE(4085),
    [sym_generic_name] = STATE(3959),
    [sym_ref_type] = STATE(3971),
    [sym__scoped_base_type] = STATE(3973),
    [sym_identifier] = STATE(3889),
    [sym__reserved_identifier] = STATE(3911),
    [sym_preproc_region] = STATE(2997),
    [sym_preproc_endregion] = STATE(2997),
    [sym_preproc_line] = STATE(2997),
    [sym_preproc_pragma] = STATE(2997),
    [sym_preproc_nullable] = STATE(2997),
    [sym_preproc_error] = STATE(2997),
    [sym_preproc_warning] = STATE(2997),
    [sym_preproc_define] = STATE(2997),
    [sym_preproc_undef] = STATE(2997),
    [sym__identifier_token] = ACTIONS(4248),
    [anon_sym_alias] = ACTIONS(4250),
    [anon_sym_global] = ACTIONS(4250),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_LPAREN] = ACTIONS(3993),
    [anon_sym_ref] = ACTIONS(4658),
    [anon_sym_LBRACE] = ACTIONS(3993),
    [anon_sym_file] = ACTIONS(4250),
    [anon_sym_LT] = ACTIONS(3995),
    [anon_sym_GT] = ACTIONS(3995),
    [anon_sym_where] = ACTIONS(4250),
    [anon_sym_QMARK] = ACTIONS(3995),
    [anon_sym_notnull] = ACTIONS(4250),
    [anon_sym_unmanaged] = ACTIONS(4250),
    [anon_sym_BANG] = ACTIONS(3995),
    [anon_sym_PLUS_PLUS] = ACTIONS(3993),
    [anon_sym_DASH_DASH] = ACTIONS(3993),
    [anon_sym_PLUS] = ACTIONS(3995),
    [anon_sym_DASH] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3993),
    [anon_sym_SLASH] = ACTIONS(3995),
    [anon_sym_PERCENT] = ACTIONS(3993),
    [anon_sym_CARET] = ACTIONS(3993),
    [anon_sym_PIPE] = ACTIONS(3995),
    [anon_sym_AMP] = ACTIONS(3995),
    [anon_sym_LT_LT] = ACTIONS(3993),
    [anon_sym_GT_GT] = ACTIONS(3995),
    [anon_sym_GT_GT_GT] = ACTIONS(3993),
    [anon_sym_EQ_EQ] = ACTIONS(3993),
    [anon_sym_BANG_EQ] = ACTIONS(3993),
    [anon_sym_GT_EQ] = ACTIONS(3993),
    [anon_sym_LT_EQ] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3995),
    [anon_sym_scoped] = ACTIONS(4250),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(4250),
    [anon_sym_yield] = ACTIONS(4250),
    [anon_sym_switch] = ACTIONS(3995),
    [anon_sym_when] = ACTIONS(4250),
    [anon_sym_DOT_DOT] = ACTIONS(3993),
    [anon_sym_and] = ACTIONS(3995),
    [anon_sym_or] = ACTIONS(3995),
    [anon_sym_AMP_AMP] = ACTIONS(3993),
    [anon_sym_PIPE_PIPE] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK] = ACTIONS(3993),
    [anon_sym_from] = ACTIONS(4250),
    [anon_sym_into] = ACTIONS(4250),
    [anon_sym_join] = ACTIONS(4250),
    [anon_sym_on] = ACTIONS(4250),
    [anon_sym_equals] = ACTIONS(4250),
    [anon_sym_let] = ACTIONS(4250),
    [anon_sym_orderby] = ACTIONS(4250),
    [anon_sym_ascending] = ACTIONS(4250),
    [anon_sym_descending] = ACTIONS(4250),
    [anon_sym_group] = ACTIONS(4250),
    [anon_sym_by] = ACTIONS(4525),
    [anon_sym_select] = ACTIONS(4250),
    [anon_sym_as] = ACTIONS(3995),
    [anon_sym_is] = ACTIONS(3995),
    [anon_sym_DASH_GT] = ACTIONS(3993),
    [anon_sym_with] = ACTIONS(3995),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2998] = {
    [sym__name] = STATE(3912),
    [sym_alias_qualified_name] = STATE(3924),
    [sym__simple_name] = STATE(3924),
    [sym_qualified_name] = STATE(3924),
    [sym_generic_name] = STATE(3900),
    [sym_ref_type] = STATE(3954),
    [sym__scoped_base_type] = STATE(3916),
    [sym_identifier] = STATE(3808),
    [sym__reserved_identifier] = STATE(3871),
    [sym_preproc_region] = STATE(2998),
    [sym_preproc_endregion] = STATE(2998),
    [sym_preproc_line] = STATE(2998),
    [sym_preproc_pragma] = STATE(2998),
    [sym_preproc_nullable] = STATE(2998),
    [sym_preproc_error] = STATE(2998),
    [sym_preproc_warning] = STATE(2998),
    [sym_preproc_define] = STATE(2998),
    [sym_preproc_undef] = STATE(2998),
    [sym__identifier_token] = ACTIONS(4223),
    [anon_sym_alias] = ACTIONS(4225),
    [anon_sym_global] = ACTIONS(4225),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_LPAREN] = ACTIONS(3993),
    [anon_sym_ref] = ACTIONS(4660),
    [anon_sym_LBRACE] = ACTIONS(3993),
    [anon_sym_file] = ACTIONS(4225),
    [anon_sym_LT] = ACTIONS(3995),
    [anon_sym_GT] = ACTIONS(3995),
    [anon_sym_where] = ACTIONS(4225),
    [anon_sym_QMARK] = ACTIONS(3995),
    [anon_sym_notnull] = ACTIONS(4225),
    [anon_sym_unmanaged] = ACTIONS(4225),
    [anon_sym_BANG] = ACTIONS(3995),
    [anon_sym_PLUS_PLUS] = ACTIONS(3993),
    [anon_sym_DASH_DASH] = ACTIONS(3993),
    [anon_sym_PLUS] = ACTIONS(3995),
    [anon_sym_DASH] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3993),
    [anon_sym_SLASH] = ACTIONS(3995),
    [anon_sym_PERCENT] = ACTIONS(3993),
    [anon_sym_CARET] = ACTIONS(3993),
    [anon_sym_PIPE] = ACTIONS(3995),
    [anon_sym_AMP] = ACTIONS(3995),
    [anon_sym_LT_LT] = ACTIONS(3993),
    [anon_sym_GT_GT] = ACTIONS(3995),
    [anon_sym_GT_GT_GT] = ACTIONS(3993),
    [anon_sym_EQ_EQ] = ACTIONS(3993),
    [anon_sym_BANG_EQ] = ACTIONS(3993),
    [anon_sym_GT_EQ] = ACTIONS(3993),
    [anon_sym_LT_EQ] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3995),
    [anon_sym_scoped] = ACTIONS(4225),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(4225),
    [anon_sym_yield] = ACTIONS(4225),
    [anon_sym_switch] = ACTIONS(3995),
    [anon_sym_when] = ACTIONS(4225),
    [anon_sym_DOT_DOT] = ACTIONS(3993),
    [anon_sym_and] = ACTIONS(3995),
    [anon_sym_or] = ACTIONS(3995),
    [anon_sym_AMP_AMP] = ACTIONS(3993),
    [anon_sym_PIPE_PIPE] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK] = ACTIONS(3993),
    [anon_sym_from] = ACTIONS(4225),
    [anon_sym_into] = ACTIONS(4229),
    [anon_sym_join] = ACTIONS(4225),
    [anon_sym_on] = ACTIONS(4229),
    [anon_sym_equals] = ACTIONS(4225),
    [anon_sym_let] = ACTIONS(4225),
    [anon_sym_orderby] = ACTIONS(4225),
    [anon_sym_ascending] = ACTIONS(4225),
    [anon_sym_descending] = ACTIONS(4225),
    [anon_sym_group] = ACTIONS(4225),
    [anon_sym_by] = ACTIONS(4225),
    [anon_sym_select] = ACTIONS(4225),
    [anon_sym_as] = ACTIONS(3995),
    [anon_sym_is] = ACTIONS(3995),
    [anon_sym_DASH_GT] = ACTIONS(3993),
    [anon_sym_with] = ACTIONS(3995),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [2999] = {
    [sym_preproc_region] = STATE(2999),
    [sym_preproc_endregion] = STATE(2999),
    [sym_preproc_line] = STATE(2999),
    [sym_preproc_pragma] = STATE(2999),
    [sym_preproc_nullable] = STATE(2999),
    [sym_preproc_error] = STATE(2999),
    [sym_preproc_warning] = STATE(2999),
    [sym_preproc_define] = STATE(2999),
    [sym_preproc_undef] = STATE(2999),
    [sym__identifier_token] = ACTIONS(4492),
    [anon_sym_alias] = ACTIONS(4492),
    [anon_sym_SEMI] = ACTIONS(4494),
    [anon_sym_global] = ACTIONS(4492),
    [anon_sym_LBRACK] = ACTIONS(4593),
    [anon_sym_COMMA] = ACTIONS(4494),
    [anon_sym_RBRACK] = ACTIONS(4494),
    [anon_sym_LPAREN] = ACTIONS(4494),
    [anon_sym_RPAREN] = ACTIONS(4494),
    [anon_sym_LBRACE] = ACTIONS(4494),
    [anon_sym_RBRACE] = ACTIONS(4494),
    [anon_sym_file] = ACTIONS(4492),
    [anon_sym_LT] = ACTIONS(4492),
    [anon_sym_GT] = ACTIONS(4492),
    [anon_sym_in] = ACTIONS(4492),
    [anon_sym_where] = ACTIONS(4492),
    [anon_sym_QMARK] = ACTIONS(4596),
    [anon_sym_notnull] = ACTIONS(4492),
    [anon_sym_unmanaged] = ACTIONS(4492),
    [anon_sym_BANG] = ACTIONS(4492),
    [anon_sym_PLUS_PLUS] = ACTIONS(4494),
    [anon_sym_DASH_DASH] = ACTIONS(4494),
    [anon_sym_PLUS] = ACTIONS(4492),
    [anon_sym_DASH] = ACTIONS(4492),
    [anon_sym_STAR] = ACTIONS(4599),
    [anon_sym_SLASH] = ACTIONS(4492),
    [anon_sym_PERCENT] = ACTIONS(4494),
    [anon_sym_CARET] = ACTIONS(4494),
    [anon_sym_PIPE] = ACTIONS(4492),
    [anon_sym_AMP] = ACTIONS(4492),
    [anon_sym_LT_LT] = ACTIONS(4494),
    [anon_sym_GT_GT] = ACTIONS(4492),
    [anon_sym_GT_GT_GT] = ACTIONS(4494),
    [anon_sym_EQ_EQ] = ACTIONS(4494),
    [anon_sym_BANG_EQ] = ACTIONS(4494),
    [anon_sym_GT_EQ] = ACTIONS(4494),
    [anon_sym_LT_EQ] = ACTIONS(4494),
    [anon_sym_DOT] = ACTIONS(4662),
    [anon_sym_scoped] = ACTIONS(4492),
    [anon_sym_EQ_GT] = ACTIONS(4494),
    [anon_sym_var] = ACTIONS(4492),
    [anon_sym_yield] = ACTIONS(4492),
    [anon_sym_switch] = ACTIONS(4492),
    [anon_sym_when] = ACTIONS(4492),
    [sym_discard] = ACTIONS(4492),
    [anon_sym_DOT_DOT] = ACTIONS(4494),
    [anon_sym_and] = ACTIONS(4492),
    [anon_sym_or] = ACTIONS(4492),
    [anon_sym_AMP_AMP] = ACTIONS(4494),
    [anon_sym_PIPE_PIPE] = ACTIONS(4494),
    [anon_sym_QMARK_QMARK] = ACTIONS(4494),
    [anon_sym_from] = ACTIONS(4492),
    [anon_sym_into] = ACTIONS(4492),
    [anon_sym_join] = ACTIONS(4492),
    [anon_sym_on] = ACTIONS(4492),
    [anon_sym_equals] = ACTIONS(4492),
    [anon_sym_let] = ACTIONS(4492),
    [anon_sym_orderby] = ACTIONS(4492),
    [anon_sym_ascending] = ACTIONS(4492),
    [anon_sym_descending] = ACTIONS(4492),
    [anon_sym_group] = ACTIONS(4492),
    [anon_sym_by] = ACTIONS(4492),
    [anon_sym_select] = ACTIONS(4492),
    [anon_sym_as] = ACTIONS(4492),
    [anon_sym_is] = ACTIONS(4492),
    [anon_sym_DASH_GT] = ACTIONS(4636),
    [anon_sym_with] = ACTIONS(4492),
    [aux_sym_preproc_if_token3] = ACTIONS(4494),
    [aux_sym_preproc_else_token1] = ACTIONS(4494),
    [aux_sym_preproc_elif_token1] = ACTIONS(4494),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3000] = {
    [sym_preproc_region] = STATE(3000),
    [sym_preproc_endregion] = STATE(3000),
    [sym_preproc_line] = STATE(3000),
    [sym_preproc_pragma] = STATE(3000),
    [sym_preproc_nullable] = STATE(3000),
    [sym_preproc_error] = STATE(3000),
    [sym_preproc_warning] = STATE(3000),
    [sym_preproc_define] = STATE(3000),
    [sym_preproc_undef] = STATE(3000),
    [sym__identifier_token] = ACTIONS(4492),
    [anon_sym_alias] = ACTIONS(4492),
    [anon_sym_SEMI] = ACTIONS(4494),
    [anon_sym_global] = ACTIONS(4492),
    [anon_sym_LBRACK] = ACTIONS(4593),
    [anon_sym_COMMA] = ACTIONS(4494),
    [anon_sym_RBRACK] = ACTIONS(4494),
    [anon_sym_LPAREN] = ACTIONS(4494),
    [anon_sym_RPAREN] = ACTIONS(4494),
    [anon_sym_LBRACE] = ACTIONS(4494),
    [anon_sym_RBRACE] = ACTIONS(4494),
    [anon_sym_file] = ACTIONS(4492),
    [anon_sym_LT] = ACTIONS(4492),
    [anon_sym_GT] = ACTIONS(4492),
    [anon_sym_in] = ACTIONS(4492),
    [anon_sym_where] = ACTIONS(4492),
    [anon_sym_QMARK] = ACTIONS(4596),
    [anon_sym_notnull] = ACTIONS(4492),
    [anon_sym_unmanaged] = ACTIONS(4492),
    [anon_sym_BANG] = ACTIONS(4492),
    [anon_sym_PLUS_PLUS] = ACTIONS(4494),
    [anon_sym_DASH_DASH] = ACTIONS(4494),
    [anon_sym_PLUS] = ACTIONS(4492),
    [anon_sym_DASH] = ACTIONS(4492),
    [anon_sym_STAR] = ACTIONS(4599),
    [anon_sym_SLASH] = ACTIONS(4492),
    [anon_sym_PERCENT] = ACTIONS(4494),
    [anon_sym_CARET] = ACTIONS(4494),
    [anon_sym_PIPE] = ACTIONS(4492),
    [anon_sym_AMP] = ACTIONS(4492),
    [anon_sym_LT_LT] = ACTIONS(4494),
    [anon_sym_GT_GT] = ACTIONS(4492),
    [anon_sym_GT_GT_GT] = ACTIONS(4494),
    [anon_sym_EQ_EQ] = ACTIONS(4494),
    [anon_sym_BANG_EQ] = ACTIONS(4494),
    [anon_sym_GT_EQ] = ACTIONS(4494),
    [anon_sym_LT_EQ] = ACTIONS(4494),
    [anon_sym_DOT] = ACTIONS(4664),
    [anon_sym_scoped] = ACTIONS(4492),
    [anon_sym_EQ_GT] = ACTIONS(4494),
    [anon_sym_var] = ACTIONS(4492),
    [anon_sym_yield] = ACTIONS(4492),
    [anon_sym_switch] = ACTIONS(4492),
    [anon_sym_when] = ACTIONS(4492),
    [sym_discard] = ACTIONS(4492),
    [anon_sym_DOT_DOT] = ACTIONS(4494),
    [anon_sym_and] = ACTIONS(4492),
    [anon_sym_or] = ACTIONS(4492),
    [anon_sym_AMP_AMP] = ACTIONS(4494),
    [anon_sym_PIPE_PIPE] = ACTIONS(4494),
    [anon_sym_QMARK_QMARK] = ACTIONS(4494),
    [anon_sym_from] = ACTIONS(4492),
    [anon_sym_into] = ACTIONS(4492),
    [anon_sym_join] = ACTIONS(4492),
    [anon_sym_on] = ACTIONS(4492),
    [anon_sym_equals] = ACTIONS(4492),
    [anon_sym_let] = ACTIONS(4492),
    [anon_sym_orderby] = ACTIONS(4492),
    [anon_sym_ascending] = ACTIONS(4492),
    [anon_sym_descending] = ACTIONS(4492),
    [anon_sym_group] = ACTIONS(4492),
    [anon_sym_by] = ACTIONS(4492),
    [anon_sym_select] = ACTIONS(4492),
    [anon_sym_as] = ACTIONS(4492),
    [anon_sym_is] = ACTIONS(4492),
    [anon_sym_DASH_GT] = ACTIONS(4604),
    [anon_sym_with] = ACTIONS(4492),
    [aux_sym_preproc_if_token3] = ACTIONS(4494),
    [aux_sym_preproc_else_token1] = ACTIONS(4494),
    [aux_sym_preproc_elif_token1] = ACTIONS(4494),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3001] = {
    [sym_preproc_region] = STATE(3001),
    [sym_preproc_endregion] = STATE(3001),
    [sym_preproc_line] = STATE(3001),
    [sym_preproc_pragma] = STATE(3001),
    [sym_preproc_nullable] = STATE(3001),
    [sym_preproc_error] = STATE(3001),
    [sym_preproc_warning] = STATE(3001),
    [sym_preproc_define] = STATE(3001),
    [sym_preproc_undef] = STATE(3001),
    [anon_sym_SEMI] = ACTIONS(4666),
    [anon_sym_EQ] = ACTIONS(4668),
    [anon_sym_LBRACK] = ACTIONS(4666),
    [anon_sym_COLON] = ACTIONS(4666),
    [anon_sym_COMMA] = ACTIONS(4666),
    [anon_sym_RBRACK] = ACTIONS(4666),
    [anon_sym_LPAREN] = ACTIONS(4666),
    [anon_sym_RPAREN] = ACTIONS(4666),
    [anon_sym_RBRACE] = ACTIONS(4666),
    [anon_sym_LT] = ACTIONS(4668),
    [anon_sym_GT] = ACTIONS(4668),
    [anon_sym_in] = ACTIONS(4668),
    [anon_sym_where] = ACTIONS(4666),
    [anon_sym_QMARK] = ACTIONS(4668),
    [anon_sym_BANG] = ACTIONS(4668),
    [anon_sym_PLUS_PLUS] = ACTIONS(4666),
    [anon_sym_DASH_DASH] = ACTIONS(4666),
    [anon_sym_PLUS] = ACTIONS(4668),
    [anon_sym_DASH] = ACTIONS(4668),
    [anon_sym_STAR] = ACTIONS(4668),
    [anon_sym_SLASH] = ACTIONS(4668),
    [anon_sym_PERCENT] = ACTIONS(4668),
    [anon_sym_CARET] = ACTIONS(4668),
    [anon_sym_PIPE] = ACTIONS(4668),
    [anon_sym_AMP] = ACTIONS(4668),
    [anon_sym_LT_LT] = ACTIONS(4668),
    [anon_sym_GT_GT] = ACTIONS(4668),
    [anon_sym_GT_GT_GT] = ACTIONS(4668),
    [anon_sym_EQ_EQ] = ACTIONS(4666),
    [anon_sym_BANG_EQ] = ACTIONS(4666),
    [anon_sym_GT_EQ] = ACTIONS(4666),
    [anon_sym_LT_EQ] = ACTIONS(4666),
    [anon_sym_DOT] = ACTIONS(4668),
    [anon_sym_EQ_GT] = ACTIONS(4666),
    [anon_sym_switch] = ACTIONS(4666),
    [anon_sym_DOT_DOT] = ACTIONS(4666),
    [anon_sym_and] = ACTIONS(4666),
    [anon_sym_or] = ACTIONS(4668),
    [anon_sym_PLUS_EQ] = ACTIONS(4666),
    [anon_sym_DASH_EQ] = ACTIONS(4666),
    [anon_sym_STAR_EQ] = ACTIONS(4666),
    [anon_sym_SLASH_EQ] = ACTIONS(4666),
    [anon_sym_PERCENT_EQ] = ACTIONS(4666),
    [anon_sym_AMP_EQ] = ACTIONS(4666),
    [anon_sym_CARET_EQ] = ACTIONS(4666),
    [anon_sym_PIPE_EQ] = ACTIONS(4666),
    [anon_sym_LT_LT_EQ] = ACTIONS(4666),
    [anon_sym_GT_GT_EQ] = ACTIONS(4666),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4666),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4666),
    [anon_sym_AMP_AMP] = ACTIONS(4666),
    [anon_sym_PIPE_PIPE] = ACTIONS(4666),
    [anon_sym_QMARK_QMARK] = ACTIONS(4668),
    [anon_sym_from] = ACTIONS(4666),
    [anon_sym_into] = ACTIONS(4666),
    [anon_sym_join] = ACTIONS(4666),
    [anon_sym_on] = ACTIONS(4666),
    [anon_sym_equals] = ACTIONS(4666),
    [anon_sym_let] = ACTIONS(4666),
    [anon_sym_orderby] = ACTIONS(4666),
    [anon_sym_group] = ACTIONS(4666),
    [anon_sym_by] = ACTIONS(4666),
    [anon_sym_select] = ACTIONS(4666),
    [anon_sym_as] = ACTIONS(4666),
    [anon_sym_is] = ACTIONS(4666),
    [anon_sym_DASH_GT] = ACTIONS(4666),
    [anon_sym_with] = ACTIONS(4666),
    [aux_sym_preproc_if_token3] = ACTIONS(4666),
    [aux_sym_preproc_else_token1] = ACTIONS(4666),
    [aux_sym_preproc_elif_token1] = ACTIONS(4666),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3002] = {
    [sym_preproc_region] = STATE(3002),
    [sym_preproc_endregion] = STATE(3002),
    [sym_preproc_line] = STATE(3002),
    [sym_preproc_pragma] = STATE(3002),
    [sym_preproc_nullable] = STATE(3002),
    [sym_preproc_error] = STATE(3002),
    [sym_preproc_warning] = STATE(3002),
    [sym_preproc_define] = STATE(3002),
    [sym_preproc_undef] = STATE(3002),
    [anon_sym_SEMI] = ACTIONS(4670),
    [anon_sym_EQ] = ACTIONS(4672),
    [anon_sym_LBRACK] = ACTIONS(4670),
    [anon_sym_COLON] = ACTIONS(4670),
    [anon_sym_COMMA] = ACTIONS(4670),
    [anon_sym_RBRACK] = ACTIONS(4670),
    [anon_sym_LPAREN] = ACTIONS(4670),
    [anon_sym_RPAREN] = ACTIONS(4670),
    [anon_sym_RBRACE] = ACTIONS(4670),
    [anon_sym_LT] = ACTIONS(4672),
    [anon_sym_GT] = ACTIONS(4672),
    [anon_sym_in] = ACTIONS(4672),
    [anon_sym_where] = ACTIONS(4670),
    [anon_sym_QMARK] = ACTIONS(4672),
    [anon_sym_BANG] = ACTIONS(4672),
    [anon_sym_PLUS_PLUS] = ACTIONS(4670),
    [anon_sym_DASH_DASH] = ACTIONS(4670),
    [anon_sym_PLUS] = ACTIONS(4672),
    [anon_sym_DASH] = ACTIONS(4672),
    [anon_sym_STAR] = ACTIONS(4672),
    [anon_sym_SLASH] = ACTIONS(4672),
    [anon_sym_PERCENT] = ACTIONS(4672),
    [anon_sym_CARET] = ACTIONS(4672),
    [anon_sym_PIPE] = ACTIONS(4672),
    [anon_sym_AMP] = ACTIONS(4672),
    [anon_sym_LT_LT] = ACTIONS(4672),
    [anon_sym_GT_GT] = ACTIONS(4672),
    [anon_sym_GT_GT_GT] = ACTIONS(4672),
    [anon_sym_EQ_EQ] = ACTIONS(4670),
    [anon_sym_BANG_EQ] = ACTIONS(4670),
    [anon_sym_GT_EQ] = ACTIONS(4670),
    [anon_sym_LT_EQ] = ACTIONS(4670),
    [anon_sym_DOT] = ACTIONS(4672),
    [anon_sym_EQ_GT] = ACTIONS(4670),
    [anon_sym_switch] = ACTIONS(4670),
    [anon_sym_DOT_DOT] = ACTIONS(4670),
    [anon_sym_and] = ACTIONS(4670),
    [anon_sym_or] = ACTIONS(4672),
    [anon_sym_PLUS_EQ] = ACTIONS(4670),
    [anon_sym_DASH_EQ] = ACTIONS(4670),
    [anon_sym_STAR_EQ] = ACTIONS(4670),
    [anon_sym_SLASH_EQ] = ACTIONS(4670),
    [anon_sym_PERCENT_EQ] = ACTIONS(4670),
    [anon_sym_AMP_EQ] = ACTIONS(4670),
    [anon_sym_CARET_EQ] = ACTIONS(4670),
    [anon_sym_PIPE_EQ] = ACTIONS(4670),
    [anon_sym_LT_LT_EQ] = ACTIONS(4670),
    [anon_sym_GT_GT_EQ] = ACTIONS(4670),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4670),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4670),
    [anon_sym_AMP_AMP] = ACTIONS(4670),
    [anon_sym_PIPE_PIPE] = ACTIONS(4670),
    [anon_sym_QMARK_QMARK] = ACTIONS(4672),
    [anon_sym_from] = ACTIONS(4670),
    [anon_sym_into] = ACTIONS(4670),
    [anon_sym_join] = ACTIONS(4670),
    [anon_sym_on] = ACTIONS(4670),
    [anon_sym_equals] = ACTIONS(4670),
    [anon_sym_let] = ACTIONS(4670),
    [anon_sym_orderby] = ACTIONS(4670),
    [anon_sym_group] = ACTIONS(4670),
    [anon_sym_by] = ACTIONS(4670),
    [anon_sym_select] = ACTIONS(4670),
    [anon_sym_as] = ACTIONS(4670),
    [anon_sym_is] = ACTIONS(4670),
    [anon_sym_DASH_GT] = ACTIONS(4670),
    [anon_sym_with] = ACTIONS(4670),
    [aux_sym_preproc_if_token3] = ACTIONS(4670),
    [aux_sym_preproc_else_token1] = ACTIONS(4670),
    [aux_sym_preproc_elif_token1] = ACTIONS(4670),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3003] = {
    [sym_preproc_region] = STATE(3003),
    [sym_preproc_endregion] = STATE(3003),
    [sym_preproc_line] = STATE(3003),
    [sym_preproc_pragma] = STATE(3003),
    [sym_preproc_nullable] = STATE(3003),
    [sym_preproc_error] = STATE(3003),
    [sym_preproc_warning] = STATE(3003),
    [sym_preproc_define] = STATE(3003),
    [sym_preproc_undef] = STATE(3003),
    [anon_sym_SEMI] = ACTIONS(4151),
    [anon_sym_EQ] = ACTIONS(4149),
    [anon_sym_LBRACK] = ACTIONS(4151),
    [anon_sym_COLON] = ACTIONS(4151),
    [anon_sym_COMMA] = ACTIONS(4151),
    [anon_sym_RBRACK] = ACTIONS(4151),
    [anon_sym_LPAREN] = ACTIONS(4151),
    [anon_sym_RPAREN] = ACTIONS(4151),
    [anon_sym_RBRACE] = ACTIONS(4151),
    [anon_sym_LT] = ACTIONS(4149),
    [anon_sym_GT] = ACTIONS(4149),
    [anon_sym_in] = ACTIONS(4149),
    [anon_sym_where] = ACTIONS(4151),
    [anon_sym_QMARK] = ACTIONS(4149),
    [anon_sym_BANG] = ACTIONS(4149),
    [anon_sym_PLUS_PLUS] = ACTIONS(4151),
    [anon_sym_DASH_DASH] = ACTIONS(4151),
    [anon_sym_PLUS] = ACTIONS(4149),
    [anon_sym_DASH] = ACTIONS(4149),
    [anon_sym_STAR] = ACTIONS(4149),
    [anon_sym_SLASH] = ACTIONS(4149),
    [anon_sym_PERCENT] = ACTIONS(4149),
    [anon_sym_CARET] = ACTIONS(4149),
    [anon_sym_PIPE] = ACTIONS(4149),
    [anon_sym_AMP] = ACTIONS(4149),
    [anon_sym_LT_LT] = ACTIONS(4149),
    [anon_sym_GT_GT] = ACTIONS(4149),
    [anon_sym_GT_GT_GT] = ACTIONS(4149),
    [anon_sym_EQ_EQ] = ACTIONS(4151),
    [anon_sym_BANG_EQ] = ACTIONS(4151),
    [anon_sym_GT_EQ] = ACTIONS(4151),
    [anon_sym_LT_EQ] = ACTIONS(4151),
    [anon_sym_DOT] = ACTIONS(4149),
    [anon_sym_EQ_GT] = ACTIONS(4151),
    [anon_sym_switch] = ACTIONS(4151),
    [anon_sym_DOT_DOT] = ACTIONS(4151),
    [anon_sym_and] = ACTIONS(4151),
    [anon_sym_or] = ACTIONS(4149),
    [anon_sym_PLUS_EQ] = ACTIONS(4151),
    [anon_sym_DASH_EQ] = ACTIONS(4151),
    [anon_sym_STAR_EQ] = ACTIONS(4151),
    [anon_sym_SLASH_EQ] = ACTIONS(4151),
    [anon_sym_PERCENT_EQ] = ACTIONS(4151),
    [anon_sym_AMP_EQ] = ACTIONS(4151),
    [anon_sym_CARET_EQ] = ACTIONS(4151),
    [anon_sym_PIPE_EQ] = ACTIONS(4151),
    [anon_sym_LT_LT_EQ] = ACTIONS(4151),
    [anon_sym_GT_GT_EQ] = ACTIONS(4151),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4151),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4151),
    [anon_sym_AMP_AMP] = ACTIONS(4151),
    [anon_sym_PIPE_PIPE] = ACTIONS(4151),
    [anon_sym_QMARK_QMARK] = ACTIONS(4149),
    [anon_sym_from] = ACTIONS(4151),
    [anon_sym_into] = ACTIONS(4151),
    [anon_sym_join] = ACTIONS(4151),
    [anon_sym_on] = ACTIONS(4151),
    [anon_sym_equals] = ACTIONS(4151),
    [anon_sym_let] = ACTIONS(4151),
    [anon_sym_orderby] = ACTIONS(4151),
    [anon_sym_group] = ACTIONS(4151),
    [anon_sym_by] = ACTIONS(4151),
    [anon_sym_select] = ACTIONS(4151),
    [anon_sym_as] = ACTIONS(4151),
    [anon_sym_is] = ACTIONS(4151),
    [anon_sym_DASH_GT] = ACTIONS(4151),
    [anon_sym_with] = ACTIONS(4151),
    [aux_sym_preproc_if_token3] = ACTIONS(4151),
    [aux_sym_preproc_else_token1] = ACTIONS(4151),
    [aux_sym_preproc_elif_token1] = ACTIONS(4151),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3004] = {
    [sym_preproc_region] = STATE(3004),
    [sym_preproc_endregion] = STATE(3004),
    [sym_preproc_line] = STATE(3004),
    [sym_preproc_pragma] = STATE(3004),
    [sym_preproc_nullable] = STATE(3004),
    [sym_preproc_error] = STATE(3004),
    [sym_preproc_warning] = STATE(3004),
    [sym_preproc_define] = STATE(3004),
    [sym_preproc_undef] = STATE(3004),
    [sym__identifier_token] = ACTIONS(4674),
    [anon_sym_alias] = ACTIONS(4674),
    [anon_sym_SEMI] = ACTIONS(4676),
    [anon_sym_global] = ACTIONS(4674),
    [anon_sym_LBRACK] = ACTIONS(4676),
    [anon_sym_COLON] = ACTIONS(4676),
    [anon_sym_COMMA] = ACTIONS(4676),
    [anon_sym_RBRACK] = ACTIONS(4676),
    [anon_sym_LPAREN] = ACTIONS(4676),
    [anon_sym_RPAREN] = ACTIONS(4676),
    [anon_sym_RBRACE] = ACTIONS(4676),
    [anon_sym_file] = ACTIONS(4674),
    [anon_sym_LT] = ACTIONS(4674),
    [anon_sym_GT] = ACTIONS(4674),
    [anon_sym_in] = ACTIONS(4674),
    [anon_sym_where] = ACTIONS(4674),
    [anon_sym_QMARK] = ACTIONS(4674),
    [anon_sym_notnull] = ACTIONS(4674),
    [anon_sym_unmanaged] = ACTIONS(4674),
    [anon_sym_BANG] = ACTIONS(4674),
    [anon_sym_PLUS_PLUS] = ACTIONS(4676),
    [anon_sym_DASH_DASH] = ACTIONS(4676),
    [anon_sym_PLUS] = ACTIONS(4674),
    [anon_sym_DASH] = ACTIONS(4674),
    [anon_sym_STAR] = ACTIONS(4676),
    [anon_sym_SLASH] = ACTIONS(4674),
    [anon_sym_PERCENT] = ACTIONS(4676),
    [anon_sym_CARET] = ACTIONS(4676),
    [anon_sym_PIPE] = ACTIONS(4674),
    [anon_sym_AMP] = ACTIONS(4674),
    [anon_sym_LT_LT] = ACTIONS(4676),
    [anon_sym_GT_GT] = ACTIONS(4674),
    [anon_sym_GT_GT_GT] = ACTIONS(4676),
    [anon_sym_EQ_EQ] = ACTIONS(4676),
    [anon_sym_BANG_EQ] = ACTIONS(4676),
    [anon_sym_GT_EQ] = ACTIONS(4676),
    [anon_sym_LT_EQ] = ACTIONS(4676),
    [anon_sym_DOT] = ACTIONS(4674),
    [anon_sym_scoped] = ACTIONS(4674),
    [anon_sym_EQ_GT] = ACTIONS(4676),
    [anon_sym_var] = ACTIONS(4674),
    [anon_sym_yield] = ACTIONS(4674),
    [anon_sym_switch] = ACTIONS(4674),
    [anon_sym_when] = ACTIONS(4674),
    [sym_discard] = ACTIONS(4674),
    [anon_sym_DOT_DOT] = ACTIONS(4676),
    [anon_sym_and] = ACTIONS(4674),
    [anon_sym_or] = ACTIONS(4674),
    [anon_sym_AMP_AMP] = ACTIONS(4676),
    [anon_sym_PIPE_PIPE] = ACTIONS(4676),
    [anon_sym_QMARK_QMARK] = ACTIONS(4676),
    [anon_sym_from] = ACTIONS(4674),
    [anon_sym_into] = ACTIONS(4674),
    [anon_sym_join] = ACTIONS(4674),
    [anon_sym_on] = ACTIONS(4674),
    [anon_sym_equals] = ACTIONS(4674),
    [anon_sym_let] = ACTIONS(4674),
    [anon_sym_orderby] = ACTIONS(4674),
    [anon_sym_ascending] = ACTIONS(4674),
    [anon_sym_descending] = ACTIONS(4674),
    [anon_sym_group] = ACTIONS(4674),
    [anon_sym_by] = ACTIONS(4674),
    [anon_sym_select] = ACTIONS(4674),
    [anon_sym_as] = ACTIONS(4674),
    [anon_sym_is] = ACTIONS(4674),
    [anon_sym_DASH_GT] = ACTIONS(4676),
    [anon_sym_with] = ACTIONS(4674),
    [aux_sym_preproc_if_token3] = ACTIONS(4676),
    [aux_sym_preproc_else_token1] = ACTIONS(4676),
    [aux_sym_preproc_elif_token1] = ACTIONS(4676),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3005] = {
    [sym_preproc_region] = STATE(3005),
    [sym_preproc_endregion] = STATE(3005),
    [sym_preproc_line] = STATE(3005),
    [sym_preproc_pragma] = STATE(3005),
    [sym_preproc_nullable] = STATE(3005),
    [sym_preproc_error] = STATE(3005),
    [sym_preproc_warning] = STATE(3005),
    [sym_preproc_define] = STATE(3005),
    [sym_preproc_undef] = STATE(3005),
    [anon_sym_SEMI] = ACTIONS(4132),
    [anon_sym_EQ] = ACTIONS(4130),
    [anon_sym_LBRACK] = ACTIONS(4132),
    [anon_sym_COLON] = ACTIONS(4132),
    [anon_sym_COMMA] = ACTIONS(4132),
    [anon_sym_RBRACK] = ACTIONS(4132),
    [anon_sym_LPAREN] = ACTIONS(4132),
    [anon_sym_RPAREN] = ACTIONS(4132),
    [anon_sym_RBRACE] = ACTIONS(4132),
    [anon_sym_LT] = ACTIONS(4130),
    [anon_sym_GT] = ACTIONS(4130),
    [anon_sym_in] = ACTIONS(4130),
    [anon_sym_where] = ACTIONS(4132),
    [anon_sym_QMARK] = ACTIONS(4130),
    [anon_sym_BANG] = ACTIONS(4130),
    [anon_sym_PLUS_PLUS] = ACTIONS(4132),
    [anon_sym_DASH_DASH] = ACTIONS(4132),
    [anon_sym_PLUS] = ACTIONS(4130),
    [anon_sym_DASH] = ACTIONS(4130),
    [anon_sym_STAR] = ACTIONS(4130),
    [anon_sym_SLASH] = ACTIONS(4130),
    [anon_sym_PERCENT] = ACTIONS(4130),
    [anon_sym_CARET] = ACTIONS(4130),
    [anon_sym_PIPE] = ACTIONS(4130),
    [anon_sym_AMP] = ACTIONS(4130),
    [anon_sym_LT_LT] = ACTIONS(4130),
    [anon_sym_GT_GT] = ACTIONS(4130),
    [anon_sym_GT_GT_GT] = ACTIONS(4130),
    [anon_sym_EQ_EQ] = ACTIONS(4132),
    [anon_sym_BANG_EQ] = ACTIONS(4132),
    [anon_sym_GT_EQ] = ACTIONS(4132),
    [anon_sym_LT_EQ] = ACTIONS(4132),
    [anon_sym_DOT] = ACTIONS(4130),
    [anon_sym_EQ_GT] = ACTIONS(4132),
    [anon_sym_switch] = ACTIONS(4132),
    [anon_sym_DOT_DOT] = ACTIONS(4132),
    [anon_sym_and] = ACTIONS(4132),
    [anon_sym_or] = ACTIONS(4130),
    [anon_sym_PLUS_EQ] = ACTIONS(4132),
    [anon_sym_DASH_EQ] = ACTIONS(4132),
    [anon_sym_STAR_EQ] = ACTIONS(4132),
    [anon_sym_SLASH_EQ] = ACTIONS(4132),
    [anon_sym_PERCENT_EQ] = ACTIONS(4132),
    [anon_sym_AMP_EQ] = ACTIONS(4132),
    [anon_sym_CARET_EQ] = ACTIONS(4132),
    [anon_sym_PIPE_EQ] = ACTIONS(4132),
    [anon_sym_LT_LT_EQ] = ACTIONS(4132),
    [anon_sym_GT_GT_EQ] = ACTIONS(4132),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4132),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4132),
    [anon_sym_AMP_AMP] = ACTIONS(4132),
    [anon_sym_PIPE_PIPE] = ACTIONS(4132),
    [anon_sym_QMARK_QMARK] = ACTIONS(4130),
    [anon_sym_from] = ACTIONS(4132),
    [anon_sym_into] = ACTIONS(4132),
    [anon_sym_join] = ACTIONS(4132),
    [anon_sym_on] = ACTIONS(4132),
    [anon_sym_equals] = ACTIONS(4132),
    [anon_sym_let] = ACTIONS(4132),
    [anon_sym_orderby] = ACTIONS(4132),
    [anon_sym_group] = ACTIONS(4132),
    [anon_sym_by] = ACTIONS(4132),
    [anon_sym_select] = ACTIONS(4132),
    [anon_sym_as] = ACTIONS(4132),
    [anon_sym_is] = ACTIONS(4132),
    [anon_sym_DASH_GT] = ACTIONS(4132),
    [anon_sym_with] = ACTIONS(4132),
    [aux_sym_preproc_if_token3] = ACTIONS(4132),
    [aux_sym_preproc_else_token1] = ACTIONS(4132),
    [aux_sym_preproc_elif_token1] = ACTIONS(4132),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3006] = {
    [sym__name] = STATE(3748),
    [sym_alias_qualified_name] = STATE(3680),
    [sym__simple_name] = STATE(3680),
    [sym_qualified_name] = STATE(3680),
    [sym_generic_name] = STATE(3648),
    [sym_ref_type] = STATE(3643),
    [sym__scoped_base_type] = STATE(3647),
    [sym_identifier] = STATE(3590),
    [sym__reserved_identifier] = STATE(3625),
    [sym_preproc_region] = STATE(3006),
    [sym_preproc_endregion] = STATE(3006),
    [sym_preproc_line] = STATE(3006),
    [sym_preproc_pragma] = STATE(3006),
    [sym_preproc_nullable] = STATE(3006),
    [sym_preproc_error] = STATE(3006),
    [sym_preproc_warning] = STATE(3006),
    [sym_preproc_define] = STATE(3006),
    [sym_preproc_undef] = STATE(3006),
    [sym__identifier_token] = ACTIONS(4349),
    [anon_sym_alias] = ACTIONS(4351),
    [anon_sym_global] = ACTIONS(4351),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_LPAREN] = ACTIONS(3993),
    [anon_sym_ref] = ACTIONS(4678),
    [anon_sym_LBRACE] = ACTIONS(3993),
    [anon_sym_file] = ACTIONS(4351),
    [anon_sym_LT] = ACTIONS(3995),
    [anon_sym_GT] = ACTIONS(3995),
    [anon_sym_where] = ACTIONS(4680),
    [anon_sym_QMARK] = ACTIONS(3995),
    [anon_sym_notnull] = ACTIONS(4351),
    [anon_sym_unmanaged] = ACTIONS(4351),
    [anon_sym_BANG] = ACTIONS(3995),
    [anon_sym_PLUS_PLUS] = ACTIONS(3993),
    [anon_sym_DASH_DASH] = ACTIONS(3993),
    [anon_sym_PLUS] = ACTIONS(3995),
    [anon_sym_DASH] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3993),
    [anon_sym_SLASH] = ACTIONS(3995),
    [anon_sym_PERCENT] = ACTIONS(3993),
    [anon_sym_CARET] = ACTIONS(3993),
    [anon_sym_PIPE] = ACTIONS(3995),
    [anon_sym_AMP] = ACTIONS(3995),
    [anon_sym_LT_LT] = ACTIONS(3993),
    [anon_sym_GT_GT] = ACTIONS(3995),
    [anon_sym_GT_GT_GT] = ACTIONS(3993),
    [anon_sym_EQ_EQ] = ACTIONS(3993),
    [anon_sym_BANG_EQ] = ACTIONS(3993),
    [anon_sym_GT_EQ] = ACTIONS(3993),
    [anon_sym_LT_EQ] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3995),
    [anon_sym_scoped] = ACTIONS(4351),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(4351),
    [anon_sym_yield] = ACTIONS(4351),
    [anon_sym_switch] = ACTIONS(3995),
    [anon_sym_when] = ACTIONS(4351),
    [anon_sym_DOT_DOT] = ACTIONS(3993),
    [anon_sym_and] = ACTIONS(3995),
    [anon_sym_or] = ACTIONS(3995),
    [anon_sym_AMP_AMP] = ACTIONS(3993),
    [anon_sym_PIPE_PIPE] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK] = ACTIONS(3993),
    [anon_sym_from] = ACTIONS(4680),
    [anon_sym_into] = ACTIONS(4351),
    [anon_sym_join] = ACTIONS(4680),
    [anon_sym_on] = ACTIONS(4351),
    [anon_sym_equals] = ACTIONS(4351),
    [anon_sym_let] = ACTIONS(4680),
    [anon_sym_orderby] = ACTIONS(4680),
    [anon_sym_ascending] = ACTIONS(4351),
    [anon_sym_descending] = ACTIONS(4351),
    [anon_sym_group] = ACTIONS(4680),
    [anon_sym_by] = ACTIONS(4351),
    [anon_sym_select] = ACTIONS(4680),
    [anon_sym_as] = ACTIONS(3995),
    [anon_sym_is] = ACTIONS(3995),
    [anon_sym_DASH_GT] = ACTIONS(3993),
    [anon_sym_with] = ACTIONS(3995),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3007] = {
    [sym_preproc_region] = STATE(3007),
    [sym_preproc_endregion] = STATE(3007),
    [sym_preproc_line] = STATE(3007),
    [sym_preproc_pragma] = STATE(3007),
    [sym_preproc_nullable] = STATE(3007),
    [sym_preproc_error] = STATE(3007),
    [sym_preproc_warning] = STATE(3007),
    [sym_preproc_define] = STATE(3007),
    [sym_preproc_undef] = STATE(3007),
    [anon_sym_SEMI] = ACTIONS(4683),
    [anon_sym_EQ] = ACTIONS(4685),
    [anon_sym_LBRACK] = ACTIONS(4683),
    [anon_sym_COLON] = ACTIONS(4683),
    [anon_sym_COMMA] = ACTIONS(4683),
    [anon_sym_RBRACK] = ACTIONS(4683),
    [anon_sym_LPAREN] = ACTIONS(4683),
    [anon_sym_RPAREN] = ACTIONS(4683),
    [anon_sym_RBRACE] = ACTIONS(4683),
    [anon_sym_LT] = ACTIONS(4685),
    [anon_sym_GT] = ACTIONS(4685),
    [anon_sym_in] = ACTIONS(4685),
    [anon_sym_where] = ACTIONS(4683),
    [anon_sym_QMARK] = ACTIONS(4685),
    [anon_sym_BANG] = ACTIONS(4685),
    [anon_sym_PLUS_PLUS] = ACTIONS(4683),
    [anon_sym_DASH_DASH] = ACTIONS(4683),
    [anon_sym_PLUS] = ACTIONS(4685),
    [anon_sym_DASH] = ACTIONS(4685),
    [anon_sym_STAR] = ACTIONS(4685),
    [anon_sym_SLASH] = ACTIONS(4685),
    [anon_sym_PERCENT] = ACTIONS(4685),
    [anon_sym_CARET] = ACTIONS(4685),
    [anon_sym_PIPE] = ACTIONS(4685),
    [anon_sym_AMP] = ACTIONS(4685),
    [anon_sym_LT_LT] = ACTIONS(4685),
    [anon_sym_GT_GT] = ACTIONS(4685),
    [anon_sym_GT_GT_GT] = ACTIONS(4685),
    [anon_sym_EQ_EQ] = ACTIONS(4683),
    [anon_sym_BANG_EQ] = ACTIONS(4683),
    [anon_sym_GT_EQ] = ACTIONS(4683),
    [anon_sym_LT_EQ] = ACTIONS(4683),
    [anon_sym_DOT] = ACTIONS(4685),
    [anon_sym_EQ_GT] = ACTIONS(4683),
    [anon_sym_switch] = ACTIONS(4683),
    [anon_sym_DOT_DOT] = ACTIONS(4683),
    [anon_sym_and] = ACTIONS(4683),
    [anon_sym_or] = ACTIONS(4685),
    [anon_sym_PLUS_EQ] = ACTIONS(4683),
    [anon_sym_DASH_EQ] = ACTIONS(4683),
    [anon_sym_STAR_EQ] = ACTIONS(4683),
    [anon_sym_SLASH_EQ] = ACTIONS(4683),
    [anon_sym_PERCENT_EQ] = ACTIONS(4683),
    [anon_sym_AMP_EQ] = ACTIONS(4683),
    [anon_sym_CARET_EQ] = ACTIONS(4683),
    [anon_sym_PIPE_EQ] = ACTIONS(4683),
    [anon_sym_LT_LT_EQ] = ACTIONS(4683),
    [anon_sym_GT_GT_EQ] = ACTIONS(4683),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4683),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4683),
    [anon_sym_AMP_AMP] = ACTIONS(4683),
    [anon_sym_PIPE_PIPE] = ACTIONS(4683),
    [anon_sym_QMARK_QMARK] = ACTIONS(4685),
    [anon_sym_from] = ACTIONS(4683),
    [anon_sym_into] = ACTIONS(4683),
    [anon_sym_join] = ACTIONS(4683),
    [anon_sym_on] = ACTIONS(4683),
    [anon_sym_equals] = ACTIONS(4683),
    [anon_sym_let] = ACTIONS(4683),
    [anon_sym_orderby] = ACTIONS(4683),
    [anon_sym_group] = ACTIONS(4683),
    [anon_sym_by] = ACTIONS(4683),
    [anon_sym_select] = ACTIONS(4683),
    [anon_sym_as] = ACTIONS(4683),
    [anon_sym_is] = ACTIONS(4683),
    [anon_sym_DASH_GT] = ACTIONS(4683),
    [anon_sym_with] = ACTIONS(4683),
    [aux_sym_preproc_if_token3] = ACTIONS(4683),
    [aux_sym_preproc_else_token1] = ACTIONS(4683),
    [aux_sym_preproc_elif_token1] = ACTIONS(4683),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3008] = {
    [sym_preproc_region] = STATE(3008),
    [sym_preproc_endregion] = STATE(3008),
    [sym_preproc_line] = STATE(3008),
    [sym_preproc_pragma] = STATE(3008),
    [sym_preproc_nullable] = STATE(3008),
    [sym_preproc_error] = STATE(3008),
    [sym_preproc_warning] = STATE(3008),
    [sym_preproc_define] = STATE(3008),
    [sym_preproc_undef] = STATE(3008),
    [anon_sym_SEMI] = ACTIONS(4687),
    [anon_sym_EQ] = ACTIONS(4689),
    [anon_sym_LBRACK] = ACTIONS(4687),
    [anon_sym_COLON] = ACTIONS(4687),
    [anon_sym_COMMA] = ACTIONS(4687),
    [anon_sym_RBRACK] = ACTIONS(4687),
    [anon_sym_LPAREN] = ACTIONS(4687),
    [anon_sym_RPAREN] = ACTIONS(4687),
    [anon_sym_RBRACE] = ACTIONS(4687),
    [anon_sym_LT] = ACTIONS(4689),
    [anon_sym_GT] = ACTIONS(4689),
    [anon_sym_in] = ACTIONS(4689),
    [anon_sym_where] = ACTIONS(4687),
    [anon_sym_QMARK] = ACTIONS(4689),
    [anon_sym_BANG] = ACTIONS(4689),
    [anon_sym_PLUS_PLUS] = ACTIONS(4687),
    [anon_sym_DASH_DASH] = ACTIONS(4687),
    [anon_sym_PLUS] = ACTIONS(4689),
    [anon_sym_DASH] = ACTIONS(4689),
    [anon_sym_STAR] = ACTIONS(4689),
    [anon_sym_SLASH] = ACTIONS(4689),
    [anon_sym_PERCENT] = ACTIONS(4689),
    [anon_sym_CARET] = ACTIONS(4689),
    [anon_sym_PIPE] = ACTIONS(4689),
    [anon_sym_AMP] = ACTIONS(4689),
    [anon_sym_LT_LT] = ACTIONS(4689),
    [anon_sym_GT_GT] = ACTIONS(4689),
    [anon_sym_GT_GT_GT] = ACTIONS(4689),
    [anon_sym_EQ_EQ] = ACTIONS(4687),
    [anon_sym_BANG_EQ] = ACTIONS(4687),
    [anon_sym_GT_EQ] = ACTIONS(4687),
    [anon_sym_LT_EQ] = ACTIONS(4687),
    [anon_sym_DOT] = ACTIONS(4689),
    [anon_sym_EQ_GT] = ACTIONS(4687),
    [anon_sym_switch] = ACTIONS(4687),
    [anon_sym_DOT_DOT] = ACTIONS(4687),
    [anon_sym_and] = ACTIONS(4687),
    [anon_sym_or] = ACTIONS(4689),
    [anon_sym_PLUS_EQ] = ACTIONS(4687),
    [anon_sym_DASH_EQ] = ACTIONS(4687),
    [anon_sym_STAR_EQ] = ACTIONS(4687),
    [anon_sym_SLASH_EQ] = ACTIONS(4687),
    [anon_sym_PERCENT_EQ] = ACTIONS(4687),
    [anon_sym_AMP_EQ] = ACTIONS(4687),
    [anon_sym_CARET_EQ] = ACTIONS(4687),
    [anon_sym_PIPE_EQ] = ACTIONS(4687),
    [anon_sym_LT_LT_EQ] = ACTIONS(4687),
    [anon_sym_GT_GT_EQ] = ACTIONS(4687),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4687),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4687),
    [anon_sym_AMP_AMP] = ACTIONS(4687),
    [anon_sym_PIPE_PIPE] = ACTIONS(4687),
    [anon_sym_QMARK_QMARK] = ACTIONS(4689),
    [anon_sym_from] = ACTIONS(4687),
    [anon_sym_into] = ACTIONS(4687),
    [anon_sym_join] = ACTIONS(4687),
    [anon_sym_on] = ACTIONS(4687),
    [anon_sym_equals] = ACTIONS(4687),
    [anon_sym_let] = ACTIONS(4687),
    [anon_sym_orderby] = ACTIONS(4687),
    [anon_sym_group] = ACTIONS(4687),
    [anon_sym_by] = ACTIONS(4687),
    [anon_sym_select] = ACTIONS(4687),
    [anon_sym_as] = ACTIONS(4687),
    [anon_sym_is] = ACTIONS(4687),
    [anon_sym_DASH_GT] = ACTIONS(4687),
    [anon_sym_with] = ACTIONS(4687),
    [aux_sym_preproc_if_token3] = ACTIONS(4687),
    [aux_sym_preproc_else_token1] = ACTIONS(4687),
    [aux_sym_preproc_elif_token1] = ACTIONS(4687),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3009] = {
    [sym_preproc_region] = STATE(3009),
    [sym_preproc_endregion] = STATE(3009),
    [sym_preproc_line] = STATE(3009),
    [sym_preproc_pragma] = STATE(3009),
    [sym_preproc_nullable] = STATE(3009),
    [sym_preproc_error] = STATE(3009),
    [sym_preproc_warning] = STATE(3009),
    [sym_preproc_define] = STATE(3009),
    [sym_preproc_undef] = STATE(3009),
    [anon_sym_SEMI] = ACTIONS(3993),
    [anon_sym_EQ] = ACTIONS(3995),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_COLON] = ACTIONS(3993),
    [anon_sym_COMMA] = ACTIONS(3993),
    [anon_sym_RBRACK] = ACTIONS(3993),
    [anon_sym_LPAREN] = ACTIONS(3993),
    [anon_sym_RPAREN] = ACTIONS(3993),
    [anon_sym_RBRACE] = ACTIONS(3993),
    [anon_sym_LT] = ACTIONS(3995),
    [anon_sym_GT] = ACTIONS(3995),
    [anon_sym_in] = ACTIONS(3995),
    [anon_sym_where] = ACTIONS(3993),
    [anon_sym_QMARK] = ACTIONS(3995),
    [anon_sym_BANG] = ACTIONS(3995),
    [anon_sym_PLUS_PLUS] = ACTIONS(3993),
    [anon_sym_DASH_DASH] = ACTIONS(3993),
    [anon_sym_PLUS] = ACTIONS(3995),
    [anon_sym_DASH] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3995),
    [anon_sym_SLASH] = ACTIONS(3995),
    [anon_sym_PERCENT] = ACTIONS(3995),
    [anon_sym_CARET] = ACTIONS(3995),
    [anon_sym_PIPE] = ACTIONS(3995),
    [anon_sym_AMP] = ACTIONS(3995),
    [anon_sym_LT_LT] = ACTIONS(3995),
    [anon_sym_GT_GT] = ACTIONS(3995),
    [anon_sym_GT_GT_GT] = ACTIONS(3995),
    [anon_sym_EQ_EQ] = ACTIONS(3993),
    [anon_sym_BANG_EQ] = ACTIONS(3993),
    [anon_sym_GT_EQ] = ACTIONS(3993),
    [anon_sym_LT_EQ] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3995),
    [anon_sym_EQ_GT] = ACTIONS(3993),
    [anon_sym_switch] = ACTIONS(3993),
    [anon_sym_DOT_DOT] = ACTIONS(3993),
    [anon_sym_and] = ACTIONS(3993),
    [anon_sym_or] = ACTIONS(3995),
    [anon_sym_PLUS_EQ] = ACTIONS(3993),
    [anon_sym_DASH_EQ] = ACTIONS(3993),
    [anon_sym_STAR_EQ] = ACTIONS(3993),
    [anon_sym_SLASH_EQ] = ACTIONS(3993),
    [anon_sym_PERCENT_EQ] = ACTIONS(3993),
    [anon_sym_AMP_EQ] = ACTIONS(3993),
    [anon_sym_CARET_EQ] = ACTIONS(3993),
    [anon_sym_PIPE_EQ] = ACTIONS(3993),
    [anon_sym_LT_LT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(3993),
    [anon_sym_AMP_AMP] = ACTIONS(3993),
    [anon_sym_PIPE_PIPE] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK] = ACTIONS(3995),
    [anon_sym_from] = ACTIONS(3993),
    [anon_sym_into] = ACTIONS(3993),
    [anon_sym_join] = ACTIONS(3993),
    [anon_sym_on] = ACTIONS(3993),
    [anon_sym_equals] = ACTIONS(3993),
    [anon_sym_let] = ACTIONS(3993),
    [anon_sym_orderby] = ACTIONS(3993),
    [anon_sym_group] = ACTIONS(3993),
    [anon_sym_by] = ACTIONS(3993),
    [anon_sym_select] = ACTIONS(3993),
    [anon_sym_as] = ACTIONS(3993),
    [anon_sym_is] = ACTIONS(3993),
    [anon_sym_DASH_GT] = ACTIONS(3993),
    [anon_sym_with] = ACTIONS(3993),
    [aux_sym_preproc_if_token3] = ACTIONS(3993),
    [aux_sym_preproc_else_token1] = ACTIONS(3993),
    [aux_sym_preproc_elif_token1] = ACTIONS(3993),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3010] = {
    [sym_preproc_region] = STATE(3010),
    [sym_preproc_endregion] = STATE(3010),
    [sym_preproc_line] = STATE(3010),
    [sym_preproc_pragma] = STATE(3010),
    [sym_preproc_nullable] = STATE(3010),
    [sym_preproc_error] = STATE(3010),
    [sym_preproc_warning] = STATE(3010),
    [sym_preproc_define] = STATE(3010),
    [sym_preproc_undef] = STATE(3010),
    [anon_sym_SEMI] = ACTIONS(4128),
    [anon_sym_EQ] = ACTIONS(4126),
    [anon_sym_LBRACK] = ACTIONS(4128),
    [anon_sym_COLON] = ACTIONS(4128),
    [anon_sym_COMMA] = ACTIONS(4128),
    [anon_sym_RBRACK] = ACTIONS(4128),
    [anon_sym_LPAREN] = ACTIONS(4128),
    [anon_sym_RPAREN] = ACTIONS(4128),
    [anon_sym_RBRACE] = ACTIONS(4128),
    [anon_sym_LT] = ACTIONS(4126),
    [anon_sym_GT] = ACTIONS(4126),
    [anon_sym_in] = ACTIONS(4126),
    [anon_sym_where] = ACTIONS(4128),
    [anon_sym_QMARK] = ACTIONS(4126),
    [anon_sym_BANG] = ACTIONS(4126),
    [anon_sym_PLUS_PLUS] = ACTIONS(4128),
    [anon_sym_DASH_DASH] = ACTIONS(4128),
    [anon_sym_PLUS] = ACTIONS(4126),
    [anon_sym_DASH] = ACTIONS(4126),
    [anon_sym_STAR] = ACTIONS(4126),
    [anon_sym_SLASH] = ACTIONS(4126),
    [anon_sym_PERCENT] = ACTIONS(4126),
    [anon_sym_CARET] = ACTIONS(4126),
    [anon_sym_PIPE] = ACTIONS(4126),
    [anon_sym_AMP] = ACTIONS(4126),
    [anon_sym_LT_LT] = ACTIONS(4126),
    [anon_sym_GT_GT] = ACTIONS(4126),
    [anon_sym_GT_GT_GT] = ACTIONS(4126),
    [anon_sym_EQ_EQ] = ACTIONS(4128),
    [anon_sym_BANG_EQ] = ACTIONS(4128),
    [anon_sym_GT_EQ] = ACTIONS(4128),
    [anon_sym_LT_EQ] = ACTIONS(4128),
    [anon_sym_DOT] = ACTIONS(4126),
    [anon_sym_EQ_GT] = ACTIONS(4128),
    [anon_sym_switch] = ACTIONS(4128),
    [anon_sym_DOT_DOT] = ACTIONS(4128),
    [anon_sym_and] = ACTIONS(4128),
    [anon_sym_or] = ACTIONS(4126),
    [anon_sym_PLUS_EQ] = ACTIONS(4128),
    [anon_sym_DASH_EQ] = ACTIONS(4128),
    [anon_sym_STAR_EQ] = ACTIONS(4128),
    [anon_sym_SLASH_EQ] = ACTIONS(4128),
    [anon_sym_PERCENT_EQ] = ACTIONS(4128),
    [anon_sym_AMP_EQ] = ACTIONS(4128),
    [anon_sym_CARET_EQ] = ACTIONS(4128),
    [anon_sym_PIPE_EQ] = ACTIONS(4128),
    [anon_sym_LT_LT_EQ] = ACTIONS(4128),
    [anon_sym_GT_GT_EQ] = ACTIONS(4128),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4128),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4128),
    [anon_sym_AMP_AMP] = ACTIONS(4128),
    [anon_sym_PIPE_PIPE] = ACTIONS(4128),
    [anon_sym_QMARK_QMARK] = ACTIONS(4126),
    [anon_sym_from] = ACTIONS(4128),
    [anon_sym_into] = ACTIONS(4128),
    [anon_sym_join] = ACTIONS(4128),
    [anon_sym_on] = ACTIONS(4128),
    [anon_sym_equals] = ACTIONS(4128),
    [anon_sym_let] = ACTIONS(4128),
    [anon_sym_orderby] = ACTIONS(4128),
    [anon_sym_group] = ACTIONS(4128),
    [anon_sym_by] = ACTIONS(4128),
    [anon_sym_select] = ACTIONS(4128),
    [anon_sym_as] = ACTIONS(4128),
    [anon_sym_is] = ACTIONS(4128),
    [anon_sym_DASH_GT] = ACTIONS(4128),
    [anon_sym_with] = ACTIONS(4128),
    [aux_sym_preproc_if_token3] = ACTIONS(4128),
    [aux_sym_preproc_else_token1] = ACTIONS(4128),
    [aux_sym_preproc_elif_token1] = ACTIONS(4128),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3011] = {
    [sym__name] = STATE(4159),
    [sym_alias_qualified_name] = STATE(4085),
    [sym__simple_name] = STATE(4085),
    [sym_qualified_name] = STATE(4085),
    [sym_generic_name] = STATE(3959),
    [sym_ref_type] = STATE(3971),
    [sym__scoped_base_type] = STATE(3973),
    [sym_identifier] = STATE(3889),
    [sym__reserved_identifier] = STATE(3911),
    [sym_preproc_region] = STATE(3011),
    [sym_preproc_endregion] = STATE(3011),
    [sym_preproc_line] = STATE(3011),
    [sym_preproc_pragma] = STATE(3011),
    [sym_preproc_nullable] = STATE(3011),
    [sym_preproc_error] = STATE(3011),
    [sym_preproc_warning] = STATE(3011),
    [sym_preproc_define] = STATE(3011),
    [sym_preproc_undef] = STATE(3011),
    [sym__identifier_token] = ACTIONS(4248),
    [anon_sym_alias] = ACTIONS(4250),
    [anon_sym_global] = ACTIONS(4250),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_LPAREN] = ACTIONS(3993),
    [anon_sym_ref] = ACTIONS(4691),
    [anon_sym_LBRACE] = ACTIONS(3993),
    [anon_sym_file] = ACTIONS(4250),
    [anon_sym_LT] = ACTIONS(3995),
    [anon_sym_GT] = ACTIONS(3995),
    [anon_sym_where] = ACTIONS(4250),
    [anon_sym_QMARK] = ACTIONS(3995),
    [anon_sym_notnull] = ACTIONS(4250),
    [anon_sym_unmanaged] = ACTIONS(4250),
    [anon_sym_BANG] = ACTIONS(3995),
    [anon_sym_PLUS_PLUS] = ACTIONS(3993),
    [anon_sym_DASH_DASH] = ACTIONS(3993),
    [anon_sym_PLUS] = ACTIONS(3995),
    [anon_sym_DASH] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3993),
    [anon_sym_SLASH] = ACTIONS(3995),
    [anon_sym_PERCENT] = ACTIONS(3993),
    [anon_sym_CARET] = ACTIONS(3993),
    [anon_sym_PIPE] = ACTIONS(3995),
    [anon_sym_AMP] = ACTIONS(3995),
    [anon_sym_LT_LT] = ACTIONS(3993),
    [anon_sym_GT_GT] = ACTIONS(3995),
    [anon_sym_GT_GT_GT] = ACTIONS(3993),
    [anon_sym_EQ_EQ] = ACTIONS(3993),
    [anon_sym_BANG_EQ] = ACTIONS(3993),
    [anon_sym_GT_EQ] = ACTIONS(3993),
    [anon_sym_LT_EQ] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3995),
    [anon_sym_scoped] = ACTIONS(4250),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(4250),
    [anon_sym_yield] = ACTIONS(4250),
    [anon_sym_switch] = ACTIONS(3995),
    [anon_sym_when] = ACTIONS(4250),
    [anon_sym_DOT_DOT] = ACTIONS(3993),
    [anon_sym_and] = ACTIONS(3995),
    [anon_sym_or] = ACTIONS(3995),
    [anon_sym_AMP_AMP] = ACTIONS(3993),
    [anon_sym_PIPE_PIPE] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK] = ACTIONS(3993),
    [anon_sym_from] = ACTIONS(4250),
    [anon_sym_into] = ACTIONS(4250),
    [anon_sym_join] = ACTIONS(4250),
    [anon_sym_on] = ACTIONS(4525),
    [anon_sym_equals] = ACTIONS(4250),
    [anon_sym_let] = ACTIONS(4250),
    [anon_sym_orderby] = ACTIONS(4250),
    [anon_sym_ascending] = ACTIONS(4250),
    [anon_sym_descending] = ACTIONS(4250),
    [anon_sym_group] = ACTIONS(4250),
    [anon_sym_by] = ACTIONS(4250),
    [anon_sym_select] = ACTIONS(4250),
    [anon_sym_as] = ACTIONS(3995),
    [anon_sym_is] = ACTIONS(3995),
    [anon_sym_DASH_GT] = ACTIONS(3993),
    [anon_sym_with] = ACTIONS(3995),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3012] = {
    [sym_preproc_region] = STATE(3012),
    [sym_preproc_endregion] = STATE(3012),
    [sym_preproc_line] = STATE(3012),
    [sym_preproc_pragma] = STATE(3012),
    [sym_preproc_nullable] = STATE(3012),
    [sym_preproc_error] = STATE(3012),
    [sym_preproc_warning] = STATE(3012),
    [sym_preproc_define] = STATE(3012),
    [sym_preproc_undef] = STATE(3012),
    [anon_sym_SEMI] = ACTIONS(4191),
    [anon_sym_EQ] = ACTIONS(4183),
    [anon_sym_LBRACK] = ACTIONS(4191),
    [anon_sym_COLON] = ACTIONS(4191),
    [anon_sym_COMMA] = ACTIONS(4191),
    [anon_sym_RBRACK] = ACTIONS(4191),
    [anon_sym_LPAREN] = ACTIONS(4191),
    [anon_sym_RPAREN] = ACTIONS(4191),
    [anon_sym_RBRACE] = ACTIONS(4191),
    [anon_sym_LT] = ACTIONS(4183),
    [anon_sym_GT] = ACTIONS(4183),
    [anon_sym_in] = ACTIONS(4183),
    [anon_sym_where] = ACTIONS(4191),
    [anon_sym_QMARK] = ACTIONS(4183),
    [anon_sym_BANG] = ACTIONS(4183),
    [anon_sym_PLUS_PLUS] = ACTIONS(4191),
    [anon_sym_DASH_DASH] = ACTIONS(4191),
    [anon_sym_PLUS] = ACTIONS(4183),
    [anon_sym_DASH] = ACTIONS(4183),
    [anon_sym_STAR] = ACTIONS(4183),
    [anon_sym_SLASH] = ACTIONS(4183),
    [anon_sym_PERCENT] = ACTIONS(4183),
    [anon_sym_CARET] = ACTIONS(4183),
    [anon_sym_PIPE] = ACTIONS(4183),
    [anon_sym_AMP] = ACTIONS(4183),
    [anon_sym_LT_LT] = ACTIONS(4183),
    [anon_sym_GT_GT] = ACTIONS(4183),
    [anon_sym_GT_GT_GT] = ACTIONS(4183),
    [anon_sym_EQ_EQ] = ACTIONS(4191),
    [anon_sym_BANG_EQ] = ACTIONS(4191),
    [anon_sym_GT_EQ] = ACTIONS(4191),
    [anon_sym_LT_EQ] = ACTIONS(4191),
    [anon_sym_DOT] = ACTIONS(4183),
    [anon_sym_EQ_GT] = ACTIONS(4191),
    [anon_sym_switch] = ACTIONS(4191),
    [anon_sym_DOT_DOT] = ACTIONS(4191),
    [anon_sym_and] = ACTIONS(4191),
    [anon_sym_or] = ACTIONS(4183),
    [anon_sym_PLUS_EQ] = ACTIONS(4191),
    [anon_sym_DASH_EQ] = ACTIONS(4191),
    [anon_sym_STAR_EQ] = ACTIONS(4191),
    [anon_sym_SLASH_EQ] = ACTIONS(4191),
    [anon_sym_PERCENT_EQ] = ACTIONS(4191),
    [anon_sym_AMP_EQ] = ACTIONS(4191),
    [anon_sym_CARET_EQ] = ACTIONS(4191),
    [anon_sym_PIPE_EQ] = ACTIONS(4191),
    [anon_sym_LT_LT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4191),
    [anon_sym_AMP_AMP] = ACTIONS(4191),
    [anon_sym_PIPE_PIPE] = ACTIONS(4191),
    [anon_sym_QMARK_QMARK] = ACTIONS(4183),
    [anon_sym_from] = ACTIONS(4191),
    [anon_sym_into] = ACTIONS(4191),
    [anon_sym_join] = ACTIONS(4191),
    [anon_sym_on] = ACTIONS(4191),
    [anon_sym_equals] = ACTIONS(4191),
    [anon_sym_let] = ACTIONS(4191),
    [anon_sym_orderby] = ACTIONS(4191),
    [anon_sym_group] = ACTIONS(4191),
    [anon_sym_by] = ACTIONS(4191),
    [anon_sym_select] = ACTIONS(4191),
    [anon_sym_as] = ACTIONS(4191),
    [anon_sym_is] = ACTIONS(4191),
    [anon_sym_DASH_GT] = ACTIONS(4191),
    [anon_sym_with] = ACTIONS(4191),
    [aux_sym_preproc_if_token3] = ACTIONS(4191),
    [aux_sym_preproc_else_token1] = ACTIONS(4191),
    [aux_sym_preproc_elif_token1] = ACTIONS(4191),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3013] = {
    [sym__name] = STATE(4962),
    [sym_alias_qualified_name] = STATE(3588),
    [sym__simple_name] = STATE(3588),
    [sym_qualified_name] = STATE(3588),
    [sym_generic_name] = STATE(3597),
    [sym_ref_type] = STATE(3601),
    [sym__scoped_base_type] = STATE(3606),
    [sym_identifier] = STATE(4574),
    [sym__reserved_identifier] = STATE(3572),
    [sym_preproc_region] = STATE(3013),
    [sym_preproc_endregion] = STATE(3013),
    [sym_preproc_line] = STATE(3013),
    [sym_preproc_pragma] = STATE(3013),
    [sym_preproc_nullable] = STATE(3013),
    [sym_preproc_error] = STATE(3013),
    [sym_preproc_warning] = STATE(3013),
    [sym_preproc_define] = STATE(3013),
    [sym_preproc_undef] = STATE(3013),
    [sym__identifier_token] = ACTIONS(4328),
    [anon_sym_alias] = ACTIONS(4330),
    [anon_sym_global] = ACTIONS(4330),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_LPAREN] = ACTIONS(3993),
    [anon_sym_ref] = ACTIONS(4693),
    [anon_sym_LBRACE] = ACTIONS(3993),
    [anon_sym_file] = ACTIONS(4330),
    [anon_sym_LT] = ACTIONS(3995),
    [anon_sym_GT] = ACTIONS(3995),
    [anon_sym_where] = ACTIONS(4334),
    [anon_sym_QMARK] = ACTIONS(3995),
    [anon_sym_notnull] = ACTIONS(4330),
    [anon_sym_unmanaged] = ACTIONS(4330),
    [anon_sym_BANG] = ACTIONS(3995),
    [anon_sym_PLUS_PLUS] = ACTIONS(3993),
    [anon_sym_DASH_DASH] = ACTIONS(3993),
    [anon_sym_PLUS] = ACTIONS(3995),
    [anon_sym_DASH] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3993),
    [anon_sym_SLASH] = ACTIONS(3995),
    [anon_sym_PERCENT] = ACTIONS(3993),
    [anon_sym_CARET] = ACTIONS(3993),
    [anon_sym_PIPE] = ACTIONS(3995),
    [anon_sym_AMP] = ACTIONS(3995),
    [anon_sym_LT_LT] = ACTIONS(3993),
    [anon_sym_GT_GT] = ACTIONS(3995),
    [anon_sym_GT_GT_GT] = ACTIONS(3993),
    [anon_sym_EQ_EQ] = ACTIONS(3993),
    [anon_sym_BANG_EQ] = ACTIONS(3993),
    [anon_sym_GT_EQ] = ACTIONS(3993),
    [anon_sym_LT_EQ] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3995),
    [anon_sym_scoped] = ACTIONS(4330),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(4330),
    [anon_sym_yield] = ACTIONS(4330),
    [anon_sym_switch] = ACTIONS(3995),
    [anon_sym_when] = ACTIONS(4330),
    [anon_sym_DOT_DOT] = ACTIONS(3993),
    [anon_sym_and] = ACTIONS(3995),
    [anon_sym_or] = ACTIONS(3995),
    [anon_sym_AMP_AMP] = ACTIONS(3993),
    [anon_sym_PIPE_PIPE] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK] = ACTIONS(3993),
    [anon_sym_from] = ACTIONS(4334),
    [anon_sym_into] = ACTIONS(4334),
    [anon_sym_join] = ACTIONS(4334),
    [anon_sym_on] = ACTIONS(4330),
    [anon_sym_equals] = ACTIONS(4330),
    [anon_sym_let] = ACTIONS(4334),
    [anon_sym_orderby] = ACTIONS(4334),
    [anon_sym_ascending] = ACTIONS(4330),
    [anon_sym_descending] = ACTIONS(4330),
    [anon_sym_group] = ACTIONS(4334),
    [anon_sym_by] = ACTIONS(4330),
    [anon_sym_select] = ACTIONS(4334),
    [anon_sym_as] = ACTIONS(3995),
    [anon_sym_is] = ACTIONS(3995),
    [anon_sym_DASH_GT] = ACTIONS(3993),
    [anon_sym_with] = ACTIONS(3995),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3014] = {
    [sym_preproc_region] = STATE(3014),
    [sym_preproc_endregion] = STATE(3014),
    [sym_preproc_line] = STATE(3014),
    [sym_preproc_pragma] = STATE(3014),
    [sym_preproc_nullable] = STATE(3014),
    [sym_preproc_error] = STATE(3014),
    [sym_preproc_warning] = STATE(3014),
    [sym_preproc_define] = STATE(3014),
    [sym_preproc_undef] = STATE(3014),
    [sym__identifier_token] = ACTIONS(4695),
    [anon_sym_alias] = ACTIONS(4695),
    [anon_sym_SEMI] = ACTIONS(4697),
    [anon_sym_global] = ACTIONS(4695),
    [anon_sym_LBRACK] = ACTIONS(4697),
    [anon_sym_COLON] = ACTIONS(4697),
    [anon_sym_COMMA] = ACTIONS(4697),
    [anon_sym_RBRACK] = ACTIONS(4697),
    [anon_sym_LPAREN] = ACTIONS(4697),
    [anon_sym_RPAREN] = ACTIONS(4697),
    [anon_sym_RBRACE] = ACTIONS(4697),
    [anon_sym_file] = ACTIONS(4695),
    [anon_sym_LT] = ACTIONS(4695),
    [anon_sym_GT] = ACTIONS(4695),
    [anon_sym_in] = ACTIONS(4695),
    [anon_sym_where] = ACTIONS(4695),
    [anon_sym_QMARK] = ACTIONS(4695),
    [anon_sym_notnull] = ACTIONS(4695),
    [anon_sym_unmanaged] = ACTIONS(4695),
    [anon_sym_BANG] = ACTIONS(4695),
    [anon_sym_PLUS_PLUS] = ACTIONS(4697),
    [anon_sym_DASH_DASH] = ACTIONS(4697),
    [anon_sym_PLUS] = ACTIONS(4695),
    [anon_sym_DASH] = ACTIONS(4695),
    [anon_sym_STAR] = ACTIONS(4697),
    [anon_sym_SLASH] = ACTIONS(4695),
    [anon_sym_PERCENT] = ACTIONS(4697),
    [anon_sym_CARET] = ACTIONS(4697),
    [anon_sym_PIPE] = ACTIONS(4695),
    [anon_sym_AMP] = ACTIONS(4695),
    [anon_sym_LT_LT] = ACTIONS(4697),
    [anon_sym_GT_GT] = ACTIONS(4695),
    [anon_sym_GT_GT_GT] = ACTIONS(4697),
    [anon_sym_EQ_EQ] = ACTIONS(4697),
    [anon_sym_BANG_EQ] = ACTIONS(4697),
    [anon_sym_GT_EQ] = ACTIONS(4697),
    [anon_sym_LT_EQ] = ACTIONS(4697),
    [anon_sym_DOT] = ACTIONS(4695),
    [anon_sym_scoped] = ACTIONS(4695),
    [anon_sym_EQ_GT] = ACTIONS(4697),
    [anon_sym_var] = ACTIONS(4695),
    [anon_sym_yield] = ACTIONS(4695),
    [anon_sym_switch] = ACTIONS(4695),
    [anon_sym_when] = ACTIONS(4695),
    [sym_discard] = ACTIONS(4695),
    [anon_sym_DOT_DOT] = ACTIONS(4697),
    [anon_sym_and] = ACTIONS(4695),
    [anon_sym_or] = ACTIONS(4695),
    [anon_sym_AMP_AMP] = ACTIONS(4697),
    [anon_sym_PIPE_PIPE] = ACTIONS(4697),
    [anon_sym_QMARK_QMARK] = ACTIONS(4697),
    [anon_sym_from] = ACTIONS(4695),
    [anon_sym_into] = ACTIONS(4695),
    [anon_sym_join] = ACTIONS(4695),
    [anon_sym_on] = ACTIONS(4695),
    [anon_sym_equals] = ACTIONS(4695),
    [anon_sym_let] = ACTIONS(4695),
    [anon_sym_orderby] = ACTIONS(4695),
    [anon_sym_ascending] = ACTIONS(4695),
    [anon_sym_descending] = ACTIONS(4695),
    [anon_sym_group] = ACTIONS(4695),
    [anon_sym_by] = ACTIONS(4695),
    [anon_sym_select] = ACTIONS(4695),
    [anon_sym_as] = ACTIONS(4695),
    [anon_sym_is] = ACTIONS(4695),
    [anon_sym_DASH_GT] = ACTIONS(4697),
    [anon_sym_with] = ACTIONS(4695),
    [aux_sym_preproc_if_token3] = ACTIONS(4697),
    [aux_sym_preproc_else_token1] = ACTIONS(4697),
    [aux_sym_preproc_elif_token1] = ACTIONS(4697),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3015] = {
    [sym_preproc_region] = STATE(3015),
    [sym_preproc_endregion] = STATE(3015),
    [sym_preproc_line] = STATE(3015),
    [sym_preproc_pragma] = STATE(3015),
    [sym_preproc_nullable] = STATE(3015),
    [sym_preproc_error] = STATE(3015),
    [sym_preproc_warning] = STATE(3015),
    [sym_preproc_define] = STATE(3015),
    [sym_preproc_undef] = STATE(3015),
    [sym__identifier_token] = ACTIONS(4453),
    [anon_sym_alias] = ACTIONS(4453),
    [anon_sym_SEMI] = ACTIONS(4455),
    [anon_sym_global] = ACTIONS(4453),
    [anon_sym_LBRACK] = ACTIONS(4455),
    [anon_sym_COMMA] = ACTIONS(4455),
    [anon_sym_RBRACK] = ACTIONS(4455),
    [anon_sym_LPAREN] = ACTIONS(4455),
    [anon_sym_RPAREN] = ACTIONS(4455),
    [anon_sym_LBRACE] = ACTIONS(4455),
    [anon_sym_RBRACE] = ACTIONS(4455),
    [anon_sym_file] = ACTIONS(4453),
    [anon_sym_LT] = ACTIONS(4453),
    [anon_sym_GT] = ACTIONS(4453),
    [anon_sym_in] = ACTIONS(4453),
    [anon_sym_where] = ACTIONS(4453),
    [anon_sym_QMARK] = ACTIONS(4453),
    [anon_sym_notnull] = ACTIONS(4453),
    [anon_sym_unmanaged] = ACTIONS(4453),
    [anon_sym_BANG] = ACTIONS(4453),
    [anon_sym_PLUS_PLUS] = ACTIONS(4455),
    [anon_sym_DASH_DASH] = ACTIONS(4455),
    [anon_sym_PLUS] = ACTIONS(4453),
    [anon_sym_DASH] = ACTIONS(4453),
    [anon_sym_STAR] = ACTIONS(4455),
    [anon_sym_SLASH] = ACTIONS(4453),
    [anon_sym_PERCENT] = ACTIONS(4455),
    [anon_sym_CARET] = ACTIONS(4455),
    [anon_sym_PIPE] = ACTIONS(4453),
    [anon_sym_AMP] = ACTIONS(4453),
    [anon_sym_LT_LT] = ACTIONS(4455),
    [anon_sym_GT_GT] = ACTIONS(4453),
    [anon_sym_GT_GT_GT] = ACTIONS(4455),
    [anon_sym_EQ_EQ] = ACTIONS(4455),
    [anon_sym_BANG_EQ] = ACTIONS(4455),
    [anon_sym_GT_EQ] = ACTIONS(4455),
    [anon_sym_LT_EQ] = ACTIONS(4455),
    [anon_sym_DOT] = ACTIONS(4646),
    [anon_sym_scoped] = ACTIONS(4453),
    [anon_sym_EQ_GT] = ACTIONS(4455),
    [anon_sym_var] = ACTIONS(4453),
    [anon_sym_yield] = ACTIONS(4453),
    [anon_sym_switch] = ACTIONS(4453),
    [anon_sym_when] = ACTIONS(4453),
    [sym_discard] = ACTIONS(4453),
    [anon_sym_DOT_DOT] = ACTIONS(4455),
    [anon_sym_and] = ACTIONS(4453),
    [anon_sym_or] = ACTIONS(4453),
    [anon_sym_AMP_AMP] = ACTIONS(4455),
    [anon_sym_PIPE_PIPE] = ACTIONS(4455),
    [anon_sym_QMARK_QMARK] = ACTIONS(4455),
    [anon_sym_from] = ACTIONS(4453),
    [anon_sym_into] = ACTIONS(4453),
    [anon_sym_join] = ACTIONS(4453),
    [anon_sym_on] = ACTIONS(4453),
    [anon_sym_equals] = ACTIONS(4453),
    [anon_sym_let] = ACTIONS(4453),
    [anon_sym_orderby] = ACTIONS(4453),
    [anon_sym_ascending] = ACTIONS(4453),
    [anon_sym_descending] = ACTIONS(4453),
    [anon_sym_group] = ACTIONS(4453),
    [anon_sym_by] = ACTIONS(4453),
    [anon_sym_select] = ACTIONS(4453),
    [anon_sym_as] = ACTIONS(4453),
    [anon_sym_is] = ACTIONS(4453),
    [anon_sym_DASH_GT] = ACTIONS(4455),
    [anon_sym_with] = ACTIONS(4453),
    [aux_sym_preproc_if_token3] = ACTIONS(4455),
    [aux_sym_preproc_else_token1] = ACTIONS(4455),
    [aux_sym_preproc_elif_token1] = ACTIONS(4455),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3016] = {
    [sym_preproc_region] = STATE(3016),
    [sym_preproc_endregion] = STATE(3016),
    [sym_preproc_line] = STATE(3016),
    [sym_preproc_pragma] = STATE(3016),
    [sym_preproc_nullable] = STATE(3016),
    [sym_preproc_error] = STATE(3016),
    [sym_preproc_warning] = STATE(3016),
    [sym_preproc_define] = STATE(3016),
    [sym_preproc_undef] = STATE(3016),
    [anon_sym_SEMI] = ACTIONS(4699),
    [anon_sym_EQ] = ACTIONS(4701),
    [anon_sym_LBRACK] = ACTIONS(4699),
    [anon_sym_COLON] = ACTIONS(4699),
    [anon_sym_COMMA] = ACTIONS(4699),
    [anon_sym_RBRACK] = ACTIONS(4699),
    [anon_sym_LPAREN] = ACTIONS(4699),
    [anon_sym_RPAREN] = ACTIONS(4699),
    [anon_sym_RBRACE] = ACTIONS(4699),
    [anon_sym_LT] = ACTIONS(4701),
    [anon_sym_GT] = ACTIONS(4701),
    [anon_sym_in] = ACTIONS(4701),
    [anon_sym_where] = ACTIONS(4699),
    [anon_sym_QMARK] = ACTIONS(4701),
    [anon_sym_BANG] = ACTIONS(4701),
    [anon_sym_PLUS_PLUS] = ACTIONS(4699),
    [anon_sym_DASH_DASH] = ACTIONS(4699),
    [anon_sym_PLUS] = ACTIONS(4701),
    [anon_sym_DASH] = ACTIONS(4701),
    [anon_sym_STAR] = ACTIONS(4701),
    [anon_sym_SLASH] = ACTIONS(4701),
    [anon_sym_PERCENT] = ACTIONS(4701),
    [anon_sym_CARET] = ACTIONS(4701),
    [anon_sym_PIPE] = ACTIONS(4701),
    [anon_sym_AMP] = ACTIONS(4701),
    [anon_sym_LT_LT] = ACTIONS(4701),
    [anon_sym_GT_GT] = ACTIONS(4701),
    [anon_sym_GT_GT_GT] = ACTIONS(4701),
    [anon_sym_EQ_EQ] = ACTIONS(4699),
    [anon_sym_BANG_EQ] = ACTIONS(4699),
    [anon_sym_GT_EQ] = ACTIONS(4699),
    [anon_sym_LT_EQ] = ACTIONS(4699),
    [anon_sym_DOT] = ACTIONS(4701),
    [anon_sym_EQ_GT] = ACTIONS(4699),
    [anon_sym_switch] = ACTIONS(4699),
    [anon_sym_DOT_DOT] = ACTIONS(4699),
    [anon_sym_and] = ACTIONS(4699),
    [anon_sym_or] = ACTIONS(4701),
    [anon_sym_PLUS_EQ] = ACTIONS(4699),
    [anon_sym_DASH_EQ] = ACTIONS(4699),
    [anon_sym_STAR_EQ] = ACTIONS(4699),
    [anon_sym_SLASH_EQ] = ACTIONS(4699),
    [anon_sym_PERCENT_EQ] = ACTIONS(4699),
    [anon_sym_AMP_EQ] = ACTIONS(4699),
    [anon_sym_CARET_EQ] = ACTIONS(4699),
    [anon_sym_PIPE_EQ] = ACTIONS(4699),
    [anon_sym_LT_LT_EQ] = ACTIONS(4699),
    [anon_sym_GT_GT_EQ] = ACTIONS(4699),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4699),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4699),
    [anon_sym_AMP_AMP] = ACTIONS(4699),
    [anon_sym_PIPE_PIPE] = ACTIONS(4699),
    [anon_sym_QMARK_QMARK] = ACTIONS(4701),
    [anon_sym_from] = ACTIONS(4699),
    [anon_sym_into] = ACTIONS(4699),
    [anon_sym_join] = ACTIONS(4699),
    [anon_sym_on] = ACTIONS(4699),
    [anon_sym_equals] = ACTIONS(4699),
    [anon_sym_let] = ACTIONS(4699),
    [anon_sym_orderby] = ACTIONS(4699),
    [anon_sym_group] = ACTIONS(4699),
    [anon_sym_by] = ACTIONS(4699),
    [anon_sym_select] = ACTIONS(4699),
    [anon_sym_as] = ACTIONS(4699),
    [anon_sym_is] = ACTIONS(4699),
    [anon_sym_DASH_GT] = ACTIONS(4699),
    [anon_sym_with] = ACTIONS(4699),
    [aux_sym_preproc_if_token3] = ACTIONS(4699),
    [aux_sym_preproc_else_token1] = ACTIONS(4699),
    [aux_sym_preproc_elif_token1] = ACTIONS(4699),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3017] = {
    [sym_preproc_region] = STATE(3017),
    [sym_preproc_endregion] = STATE(3017),
    [sym_preproc_line] = STATE(3017),
    [sym_preproc_pragma] = STATE(3017),
    [sym_preproc_nullable] = STATE(3017),
    [sym_preproc_error] = STATE(3017),
    [sym_preproc_warning] = STATE(3017),
    [sym_preproc_define] = STATE(3017),
    [sym_preproc_undef] = STATE(3017),
    [anon_sym_SEMI] = ACTIONS(4136),
    [anon_sym_EQ] = ACTIONS(4134),
    [anon_sym_LBRACK] = ACTIONS(4136),
    [anon_sym_COLON] = ACTIONS(4136),
    [anon_sym_COMMA] = ACTIONS(4136),
    [anon_sym_RBRACK] = ACTIONS(4136),
    [anon_sym_LPAREN] = ACTIONS(4136),
    [anon_sym_RPAREN] = ACTIONS(4136),
    [anon_sym_RBRACE] = ACTIONS(4136),
    [anon_sym_LT] = ACTIONS(4134),
    [anon_sym_GT] = ACTIONS(4134),
    [anon_sym_in] = ACTIONS(4134),
    [anon_sym_where] = ACTIONS(4136),
    [anon_sym_QMARK] = ACTIONS(4134),
    [anon_sym_BANG] = ACTIONS(4134),
    [anon_sym_PLUS_PLUS] = ACTIONS(4136),
    [anon_sym_DASH_DASH] = ACTIONS(4136),
    [anon_sym_PLUS] = ACTIONS(4134),
    [anon_sym_DASH] = ACTIONS(4134),
    [anon_sym_STAR] = ACTIONS(4134),
    [anon_sym_SLASH] = ACTIONS(4134),
    [anon_sym_PERCENT] = ACTIONS(4134),
    [anon_sym_CARET] = ACTIONS(4134),
    [anon_sym_PIPE] = ACTIONS(4134),
    [anon_sym_AMP] = ACTIONS(4134),
    [anon_sym_LT_LT] = ACTIONS(4134),
    [anon_sym_GT_GT] = ACTIONS(4134),
    [anon_sym_GT_GT_GT] = ACTIONS(4134),
    [anon_sym_EQ_EQ] = ACTIONS(4136),
    [anon_sym_BANG_EQ] = ACTIONS(4136),
    [anon_sym_GT_EQ] = ACTIONS(4136),
    [anon_sym_LT_EQ] = ACTIONS(4136),
    [anon_sym_DOT] = ACTIONS(4134),
    [anon_sym_EQ_GT] = ACTIONS(4136),
    [anon_sym_switch] = ACTIONS(4136),
    [anon_sym_DOT_DOT] = ACTIONS(4136),
    [anon_sym_and] = ACTIONS(4136),
    [anon_sym_or] = ACTIONS(4134),
    [anon_sym_PLUS_EQ] = ACTIONS(4136),
    [anon_sym_DASH_EQ] = ACTIONS(4136),
    [anon_sym_STAR_EQ] = ACTIONS(4136),
    [anon_sym_SLASH_EQ] = ACTIONS(4136),
    [anon_sym_PERCENT_EQ] = ACTIONS(4136),
    [anon_sym_AMP_EQ] = ACTIONS(4136),
    [anon_sym_CARET_EQ] = ACTIONS(4136),
    [anon_sym_PIPE_EQ] = ACTIONS(4136),
    [anon_sym_LT_LT_EQ] = ACTIONS(4136),
    [anon_sym_GT_GT_EQ] = ACTIONS(4136),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4136),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4136),
    [anon_sym_AMP_AMP] = ACTIONS(4136),
    [anon_sym_PIPE_PIPE] = ACTIONS(4136),
    [anon_sym_QMARK_QMARK] = ACTIONS(4134),
    [anon_sym_from] = ACTIONS(4136),
    [anon_sym_into] = ACTIONS(4136),
    [anon_sym_join] = ACTIONS(4136),
    [anon_sym_on] = ACTIONS(4136),
    [anon_sym_equals] = ACTIONS(4136),
    [anon_sym_let] = ACTIONS(4136),
    [anon_sym_orderby] = ACTIONS(4136),
    [anon_sym_group] = ACTIONS(4136),
    [anon_sym_by] = ACTIONS(4136),
    [anon_sym_select] = ACTIONS(4136),
    [anon_sym_as] = ACTIONS(4136),
    [anon_sym_is] = ACTIONS(4136),
    [anon_sym_DASH_GT] = ACTIONS(4136),
    [anon_sym_with] = ACTIONS(4136),
    [aux_sym_preproc_if_token3] = ACTIONS(4136),
    [aux_sym_preproc_else_token1] = ACTIONS(4136),
    [aux_sym_preproc_elif_token1] = ACTIONS(4136),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3018] = {
    [sym_preproc_region] = STATE(3018),
    [sym_preproc_endregion] = STATE(3018),
    [sym_preproc_line] = STATE(3018),
    [sym_preproc_pragma] = STATE(3018),
    [sym_preproc_nullable] = STATE(3018),
    [sym_preproc_error] = STATE(3018),
    [sym_preproc_warning] = STATE(3018),
    [sym_preproc_define] = STATE(3018),
    [sym_preproc_undef] = STATE(3018),
    [anon_sym_SEMI] = ACTIONS(4703),
    [anon_sym_EQ] = ACTIONS(4672),
    [anon_sym_LBRACK] = ACTIONS(4703),
    [anon_sym_COLON] = ACTIONS(4670),
    [anon_sym_COMMA] = ACTIONS(4703),
    [anon_sym_RBRACK] = ACTIONS(4703),
    [anon_sym_LPAREN] = ACTIONS(4703),
    [anon_sym_RPAREN] = ACTIONS(4703),
    [anon_sym_RBRACE] = ACTIONS(4703),
    [anon_sym_LT] = ACTIONS(4705),
    [anon_sym_GT] = ACTIONS(4705),
    [anon_sym_in] = ACTIONS(4705),
    [anon_sym_where] = ACTIONS(4703),
    [anon_sym_QMARK] = ACTIONS(4705),
    [anon_sym_BANG] = ACTIONS(4705),
    [anon_sym_PLUS_PLUS] = ACTIONS(4703),
    [anon_sym_DASH_DASH] = ACTIONS(4703),
    [anon_sym_PLUS] = ACTIONS(4705),
    [anon_sym_DASH] = ACTIONS(4705),
    [anon_sym_STAR] = ACTIONS(4705),
    [anon_sym_SLASH] = ACTIONS(4705),
    [anon_sym_PERCENT] = ACTIONS(4705),
    [anon_sym_CARET] = ACTIONS(4705),
    [anon_sym_PIPE] = ACTIONS(4705),
    [anon_sym_AMP] = ACTIONS(4705),
    [anon_sym_LT_LT] = ACTIONS(4705),
    [anon_sym_GT_GT] = ACTIONS(4705),
    [anon_sym_GT_GT_GT] = ACTIONS(4705),
    [anon_sym_EQ_EQ] = ACTIONS(4703),
    [anon_sym_BANG_EQ] = ACTIONS(4703),
    [anon_sym_GT_EQ] = ACTIONS(4703),
    [anon_sym_LT_EQ] = ACTIONS(4703),
    [anon_sym_DOT] = ACTIONS(4705),
    [anon_sym_EQ_GT] = ACTIONS(4703),
    [anon_sym_switch] = ACTIONS(4703),
    [anon_sym_DOT_DOT] = ACTIONS(4703),
    [anon_sym_and] = ACTIONS(4703),
    [anon_sym_or] = ACTIONS(4705),
    [anon_sym_PLUS_EQ] = ACTIONS(4670),
    [anon_sym_DASH_EQ] = ACTIONS(4670),
    [anon_sym_STAR_EQ] = ACTIONS(4670),
    [anon_sym_SLASH_EQ] = ACTIONS(4670),
    [anon_sym_PERCENT_EQ] = ACTIONS(4670),
    [anon_sym_AMP_EQ] = ACTIONS(4670),
    [anon_sym_CARET_EQ] = ACTIONS(4670),
    [anon_sym_PIPE_EQ] = ACTIONS(4670),
    [anon_sym_LT_LT_EQ] = ACTIONS(4670),
    [anon_sym_GT_GT_EQ] = ACTIONS(4670),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4670),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4670),
    [anon_sym_AMP_AMP] = ACTIONS(4703),
    [anon_sym_PIPE_PIPE] = ACTIONS(4703),
    [anon_sym_QMARK_QMARK] = ACTIONS(4705),
    [anon_sym_from] = ACTIONS(4703),
    [anon_sym_into] = ACTIONS(4703),
    [anon_sym_join] = ACTIONS(4703),
    [anon_sym_on] = ACTIONS(4703),
    [anon_sym_equals] = ACTIONS(4703),
    [anon_sym_let] = ACTIONS(4703),
    [anon_sym_orderby] = ACTIONS(4703),
    [anon_sym_group] = ACTIONS(4703),
    [anon_sym_by] = ACTIONS(4703),
    [anon_sym_select] = ACTIONS(4703),
    [anon_sym_as] = ACTIONS(4703),
    [anon_sym_is] = ACTIONS(4703),
    [anon_sym_DASH_GT] = ACTIONS(4703),
    [anon_sym_with] = ACTIONS(4703),
    [aux_sym_preproc_if_token3] = ACTIONS(4703),
    [aux_sym_preproc_else_token1] = ACTIONS(4703),
    [aux_sym_preproc_elif_token1] = ACTIONS(4703),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3019] = {
    [sym_preproc_region] = STATE(3019),
    [sym_preproc_endregion] = STATE(3019),
    [sym_preproc_line] = STATE(3019),
    [sym_preproc_pragma] = STATE(3019),
    [sym_preproc_nullable] = STATE(3019),
    [sym_preproc_error] = STATE(3019),
    [sym_preproc_warning] = STATE(3019),
    [sym_preproc_define] = STATE(3019),
    [sym_preproc_undef] = STATE(3019),
    [anon_sym_SEMI] = ACTIONS(4124),
    [anon_sym_EQ] = ACTIONS(4122),
    [anon_sym_LBRACK] = ACTIONS(4124),
    [anon_sym_COLON] = ACTIONS(4124),
    [anon_sym_COMMA] = ACTIONS(4124),
    [anon_sym_RBRACK] = ACTIONS(4124),
    [anon_sym_LPAREN] = ACTIONS(4124),
    [anon_sym_RPAREN] = ACTIONS(4124),
    [anon_sym_RBRACE] = ACTIONS(4124),
    [anon_sym_LT] = ACTIONS(4122),
    [anon_sym_GT] = ACTIONS(4122),
    [anon_sym_in] = ACTIONS(4122),
    [anon_sym_where] = ACTIONS(4124),
    [anon_sym_QMARK] = ACTIONS(4122),
    [anon_sym_BANG] = ACTIONS(4122),
    [anon_sym_PLUS_PLUS] = ACTIONS(4124),
    [anon_sym_DASH_DASH] = ACTIONS(4124),
    [anon_sym_PLUS] = ACTIONS(4122),
    [anon_sym_DASH] = ACTIONS(4122),
    [anon_sym_STAR] = ACTIONS(4122),
    [anon_sym_SLASH] = ACTIONS(4122),
    [anon_sym_PERCENT] = ACTIONS(4122),
    [anon_sym_CARET] = ACTIONS(4122),
    [anon_sym_PIPE] = ACTIONS(4122),
    [anon_sym_AMP] = ACTIONS(4122),
    [anon_sym_LT_LT] = ACTIONS(4122),
    [anon_sym_GT_GT] = ACTIONS(4122),
    [anon_sym_GT_GT_GT] = ACTIONS(4122),
    [anon_sym_EQ_EQ] = ACTIONS(4124),
    [anon_sym_BANG_EQ] = ACTIONS(4124),
    [anon_sym_GT_EQ] = ACTIONS(4124),
    [anon_sym_LT_EQ] = ACTIONS(4124),
    [anon_sym_DOT] = ACTIONS(4122),
    [anon_sym_EQ_GT] = ACTIONS(4124),
    [anon_sym_switch] = ACTIONS(4124),
    [anon_sym_DOT_DOT] = ACTIONS(4124),
    [anon_sym_and] = ACTIONS(4124),
    [anon_sym_or] = ACTIONS(4122),
    [anon_sym_PLUS_EQ] = ACTIONS(4124),
    [anon_sym_DASH_EQ] = ACTIONS(4124),
    [anon_sym_STAR_EQ] = ACTIONS(4124),
    [anon_sym_SLASH_EQ] = ACTIONS(4124),
    [anon_sym_PERCENT_EQ] = ACTIONS(4124),
    [anon_sym_AMP_EQ] = ACTIONS(4124),
    [anon_sym_CARET_EQ] = ACTIONS(4124),
    [anon_sym_PIPE_EQ] = ACTIONS(4124),
    [anon_sym_LT_LT_EQ] = ACTIONS(4124),
    [anon_sym_GT_GT_EQ] = ACTIONS(4124),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4124),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4124),
    [anon_sym_AMP_AMP] = ACTIONS(4124),
    [anon_sym_PIPE_PIPE] = ACTIONS(4124),
    [anon_sym_QMARK_QMARK] = ACTIONS(4122),
    [anon_sym_from] = ACTIONS(4124),
    [anon_sym_into] = ACTIONS(4124),
    [anon_sym_join] = ACTIONS(4124),
    [anon_sym_on] = ACTIONS(4124),
    [anon_sym_equals] = ACTIONS(4124),
    [anon_sym_let] = ACTIONS(4124),
    [anon_sym_orderby] = ACTIONS(4124),
    [anon_sym_group] = ACTIONS(4124),
    [anon_sym_by] = ACTIONS(4124),
    [anon_sym_select] = ACTIONS(4124),
    [anon_sym_as] = ACTIONS(4124),
    [anon_sym_is] = ACTIONS(4124),
    [anon_sym_DASH_GT] = ACTIONS(4124),
    [anon_sym_with] = ACTIONS(4124),
    [aux_sym_preproc_if_token3] = ACTIONS(4124),
    [aux_sym_preproc_else_token1] = ACTIONS(4124),
    [aux_sym_preproc_elif_token1] = ACTIONS(4124),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3020] = {
    [sym_preproc_region] = STATE(3020),
    [sym_preproc_endregion] = STATE(3020),
    [sym_preproc_line] = STATE(3020),
    [sym_preproc_pragma] = STATE(3020),
    [sym_preproc_nullable] = STATE(3020),
    [sym_preproc_error] = STATE(3020),
    [sym_preproc_warning] = STATE(3020),
    [sym_preproc_define] = STATE(3020),
    [sym_preproc_undef] = STATE(3020),
    [anon_sym_SEMI] = ACTIONS(4177),
    [anon_sym_EQ] = ACTIONS(4162),
    [anon_sym_LBRACK] = ACTIONS(4177),
    [anon_sym_COLON] = ACTIONS(4177),
    [anon_sym_COMMA] = ACTIONS(4177),
    [anon_sym_RBRACK] = ACTIONS(4177),
    [anon_sym_LPAREN] = ACTIONS(4177),
    [anon_sym_RPAREN] = ACTIONS(4177),
    [anon_sym_RBRACE] = ACTIONS(4177),
    [anon_sym_LT] = ACTIONS(4162),
    [anon_sym_GT] = ACTIONS(4162),
    [anon_sym_in] = ACTIONS(4162),
    [anon_sym_where] = ACTIONS(4177),
    [anon_sym_QMARK] = ACTIONS(4162),
    [anon_sym_BANG] = ACTIONS(4162),
    [anon_sym_PLUS_PLUS] = ACTIONS(4177),
    [anon_sym_DASH_DASH] = ACTIONS(4177),
    [anon_sym_PLUS] = ACTIONS(4162),
    [anon_sym_DASH] = ACTIONS(4162),
    [anon_sym_STAR] = ACTIONS(4162),
    [anon_sym_SLASH] = ACTIONS(4162),
    [anon_sym_PERCENT] = ACTIONS(4162),
    [anon_sym_CARET] = ACTIONS(4162),
    [anon_sym_PIPE] = ACTIONS(4162),
    [anon_sym_AMP] = ACTIONS(4162),
    [anon_sym_LT_LT] = ACTIONS(4162),
    [anon_sym_GT_GT] = ACTIONS(4162),
    [anon_sym_GT_GT_GT] = ACTIONS(4162),
    [anon_sym_EQ_EQ] = ACTIONS(4177),
    [anon_sym_BANG_EQ] = ACTIONS(4177),
    [anon_sym_GT_EQ] = ACTIONS(4177),
    [anon_sym_LT_EQ] = ACTIONS(4177),
    [anon_sym_DOT] = ACTIONS(4162),
    [anon_sym_EQ_GT] = ACTIONS(4177),
    [anon_sym_switch] = ACTIONS(4177),
    [anon_sym_DOT_DOT] = ACTIONS(4177),
    [anon_sym_and] = ACTIONS(4177),
    [anon_sym_or] = ACTIONS(4162),
    [anon_sym_PLUS_EQ] = ACTIONS(4177),
    [anon_sym_DASH_EQ] = ACTIONS(4177),
    [anon_sym_STAR_EQ] = ACTIONS(4177),
    [anon_sym_SLASH_EQ] = ACTIONS(4177),
    [anon_sym_PERCENT_EQ] = ACTIONS(4177),
    [anon_sym_AMP_EQ] = ACTIONS(4177),
    [anon_sym_CARET_EQ] = ACTIONS(4177),
    [anon_sym_PIPE_EQ] = ACTIONS(4177),
    [anon_sym_LT_LT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4177),
    [anon_sym_AMP_AMP] = ACTIONS(4177),
    [anon_sym_PIPE_PIPE] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK] = ACTIONS(4162),
    [anon_sym_from] = ACTIONS(4177),
    [anon_sym_into] = ACTIONS(4177),
    [anon_sym_join] = ACTIONS(4177),
    [anon_sym_on] = ACTIONS(4177),
    [anon_sym_equals] = ACTIONS(4177),
    [anon_sym_let] = ACTIONS(4177),
    [anon_sym_orderby] = ACTIONS(4177),
    [anon_sym_group] = ACTIONS(4177),
    [anon_sym_by] = ACTIONS(4177),
    [anon_sym_select] = ACTIONS(4177),
    [anon_sym_as] = ACTIONS(4177),
    [anon_sym_is] = ACTIONS(4177),
    [anon_sym_DASH_GT] = ACTIONS(4177),
    [anon_sym_with] = ACTIONS(4177),
    [aux_sym_preproc_if_token3] = ACTIONS(4177),
    [aux_sym_preproc_else_token1] = ACTIONS(4177),
    [aux_sym_preproc_elif_token1] = ACTIONS(4177),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3021] = {
    [sym_preproc_region] = STATE(3021),
    [sym_preproc_endregion] = STATE(3021),
    [sym_preproc_line] = STATE(3021),
    [sym_preproc_pragma] = STATE(3021),
    [sym_preproc_nullable] = STATE(3021),
    [sym_preproc_error] = STATE(3021),
    [sym_preproc_warning] = STATE(3021),
    [sym_preproc_define] = STATE(3021),
    [sym_preproc_undef] = STATE(3021),
    [anon_sym_SEMI] = ACTIONS(4140),
    [anon_sym_EQ] = ACTIONS(4138),
    [anon_sym_LBRACK] = ACTIONS(4140),
    [anon_sym_COLON] = ACTIONS(4140),
    [anon_sym_COMMA] = ACTIONS(4140),
    [anon_sym_RBRACK] = ACTIONS(4140),
    [anon_sym_LPAREN] = ACTIONS(4140),
    [anon_sym_RPAREN] = ACTIONS(4140),
    [anon_sym_RBRACE] = ACTIONS(4140),
    [anon_sym_LT] = ACTIONS(4138),
    [anon_sym_GT] = ACTIONS(4138),
    [anon_sym_in] = ACTIONS(4138),
    [anon_sym_where] = ACTIONS(4140),
    [anon_sym_QMARK] = ACTIONS(4138),
    [anon_sym_BANG] = ACTIONS(4138),
    [anon_sym_PLUS_PLUS] = ACTIONS(4140),
    [anon_sym_DASH_DASH] = ACTIONS(4140),
    [anon_sym_PLUS] = ACTIONS(4138),
    [anon_sym_DASH] = ACTIONS(4138),
    [anon_sym_STAR] = ACTIONS(4138),
    [anon_sym_SLASH] = ACTIONS(4138),
    [anon_sym_PERCENT] = ACTIONS(4138),
    [anon_sym_CARET] = ACTIONS(4138),
    [anon_sym_PIPE] = ACTIONS(4138),
    [anon_sym_AMP] = ACTIONS(4138),
    [anon_sym_LT_LT] = ACTIONS(4138),
    [anon_sym_GT_GT] = ACTIONS(4138),
    [anon_sym_GT_GT_GT] = ACTIONS(4138),
    [anon_sym_EQ_EQ] = ACTIONS(4140),
    [anon_sym_BANG_EQ] = ACTIONS(4140),
    [anon_sym_GT_EQ] = ACTIONS(4140),
    [anon_sym_LT_EQ] = ACTIONS(4140),
    [anon_sym_DOT] = ACTIONS(4138),
    [anon_sym_EQ_GT] = ACTIONS(4140),
    [anon_sym_switch] = ACTIONS(4140),
    [anon_sym_DOT_DOT] = ACTIONS(4140),
    [anon_sym_and] = ACTIONS(4140),
    [anon_sym_or] = ACTIONS(4138),
    [anon_sym_PLUS_EQ] = ACTIONS(4140),
    [anon_sym_DASH_EQ] = ACTIONS(4140),
    [anon_sym_STAR_EQ] = ACTIONS(4140),
    [anon_sym_SLASH_EQ] = ACTIONS(4140),
    [anon_sym_PERCENT_EQ] = ACTIONS(4140),
    [anon_sym_AMP_EQ] = ACTIONS(4140),
    [anon_sym_CARET_EQ] = ACTIONS(4140),
    [anon_sym_PIPE_EQ] = ACTIONS(4140),
    [anon_sym_LT_LT_EQ] = ACTIONS(4140),
    [anon_sym_GT_GT_EQ] = ACTIONS(4140),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4140),
    [anon_sym_AMP_AMP] = ACTIONS(4140),
    [anon_sym_PIPE_PIPE] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK] = ACTIONS(4138),
    [anon_sym_from] = ACTIONS(4140),
    [anon_sym_into] = ACTIONS(4140),
    [anon_sym_join] = ACTIONS(4140),
    [anon_sym_on] = ACTIONS(4140),
    [anon_sym_equals] = ACTIONS(4140),
    [anon_sym_let] = ACTIONS(4140),
    [anon_sym_orderby] = ACTIONS(4140),
    [anon_sym_group] = ACTIONS(4140),
    [anon_sym_by] = ACTIONS(4140),
    [anon_sym_select] = ACTIONS(4140),
    [anon_sym_as] = ACTIONS(4140),
    [anon_sym_is] = ACTIONS(4140),
    [anon_sym_DASH_GT] = ACTIONS(4140),
    [anon_sym_with] = ACTIONS(4140),
    [aux_sym_preproc_if_token3] = ACTIONS(4140),
    [aux_sym_preproc_else_token1] = ACTIONS(4140),
    [aux_sym_preproc_elif_token1] = ACTIONS(4140),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3022] = {
    [sym_preproc_region] = STATE(3022),
    [sym_preproc_endregion] = STATE(3022),
    [sym_preproc_line] = STATE(3022),
    [sym_preproc_pragma] = STATE(3022),
    [sym_preproc_nullable] = STATE(3022),
    [sym_preproc_error] = STATE(3022),
    [sym_preproc_warning] = STATE(3022),
    [sym_preproc_define] = STATE(3022),
    [sym_preproc_undef] = STATE(3022),
    [anon_sym_SEMI] = ACTIONS(4707),
    [anon_sym_EQ] = ACTIONS(4709),
    [anon_sym_LBRACK] = ACTIONS(4707),
    [anon_sym_COLON] = ACTIONS(4707),
    [anon_sym_COMMA] = ACTIONS(4707),
    [anon_sym_RBRACK] = ACTIONS(4707),
    [anon_sym_LPAREN] = ACTIONS(4707),
    [anon_sym_RPAREN] = ACTIONS(4707),
    [anon_sym_RBRACE] = ACTIONS(4707),
    [anon_sym_LT] = ACTIONS(4709),
    [anon_sym_GT] = ACTIONS(4709),
    [anon_sym_in] = ACTIONS(4709),
    [anon_sym_where] = ACTIONS(4707),
    [anon_sym_QMARK] = ACTIONS(4709),
    [anon_sym_BANG] = ACTIONS(4709),
    [anon_sym_PLUS_PLUS] = ACTIONS(4707),
    [anon_sym_DASH_DASH] = ACTIONS(4707),
    [anon_sym_PLUS] = ACTIONS(4709),
    [anon_sym_DASH] = ACTIONS(4709),
    [anon_sym_STAR] = ACTIONS(4709),
    [anon_sym_SLASH] = ACTIONS(4709),
    [anon_sym_PERCENT] = ACTIONS(4709),
    [anon_sym_CARET] = ACTIONS(4709),
    [anon_sym_PIPE] = ACTIONS(4709),
    [anon_sym_AMP] = ACTIONS(4709),
    [anon_sym_LT_LT] = ACTIONS(4709),
    [anon_sym_GT_GT] = ACTIONS(4709),
    [anon_sym_GT_GT_GT] = ACTIONS(4709),
    [anon_sym_EQ_EQ] = ACTIONS(4707),
    [anon_sym_BANG_EQ] = ACTIONS(4707),
    [anon_sym_GT_EQ] = ACTIONS(4707),
    [anon_sym_LT_EQ] = ACTIONS(4707),
    [anon_sym_DOT] = ACTIONS(4709),
    [anon_sym_EQ_GT] = ACTIONS(4707),
    [anon_sym_switch] = ACTIONS(4707),
    [anon_sym_DOT_DOT] = ACTIONS(4707),
    [anon_sym_and] = ACTIONS(4707),
    [anon_sym_or] = ACTIONS(4709),
    [anon_sym_PLUS_EQ] = ACTIONS(4707),
    [anon_sym_DASH_EQ] = ACTIONS(4707),
    [anon_sym_STAR_EQ] = ACTIONS(4707),
    [anon_sym_SLASH_EQ] = ACTIONS(4707),
    [anon_sym_PERCENT_EQ] = ACTIONS(4707),
    [anon_sym_AMP_EQ] = ACTIONS(4707),
    [anon_sym_CARET_EQ] = ACTIONS(4707),
    [anon_sym_PIPE_EQ] = ACTIONS(4707),
    [anon_sym_LT_LT_EQ] = ACTIONS(4707),
    [anon_sym_GT_GT_EQ] = ACTIONS(4707),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4707),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4707),
    [anon_sym_AMP_AMP] = ACTIONS(4707),
    [anon_sym_PIPE_PIPE] = ACTIONS(4707),
    [anon_sym_QMARK_QMARK] = ACTIONS(4709),
    [anon_sym_from] = ACTIONS(4707),
    [anon_sym_into] = ACTIONS(4707),
    [anon_sym_join] = ACTIONS(4707),
    [anon_sym_on] = ACTIONS(4707),
    [anon_sym_equals] = ACTIONS(4707),
    [anon_sym_let] = ACTIONS(4707),
    [anon_sym_orderby] = ACTIONS(4707),
    [anon_sym_group] = ACTIONS(4707),
    [anon_sym_by] = ACTIONS(4707),
    [anon_sym_select] = ACTIONS(4707),
    [anon_sym_as] = ACTIONS(4707),
    [anon_sym_is] = ACTIONS(4707),
    [anon_sym_DASH_GT] = ACTIONS(4707),
    [anon_sym_with] = ACTIONS(4707),
    [aux_sym_preproc_if_token3] = ACTIONS(4707),
    [aux_sym_preproc_else_token1] = ACTIONS(4707),
    [aux_sym_preproc_elif_token1] = ACTIONS(4707),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3023] = {
    [sym_preproc_region] = STATE(3023),
    [sym_preproc_endregion] = STATE(3023),
    [sym_preproc_line] = STATE(3023),
    [sym_preproc_pragma] = STATE(3023),
    [sym_preproc_nullable] = STATE(3023),
    [sym_preproc_error] = STATE(3023),
    [sym_preproc_warning] = STATE(3023),
    [sym_preproc_define] = STATE(3023),
    [sym_preproc_undef] = STATE(3023),
    [anon_sym_SEMI] = ACTIONS(4711),
    [anon_sym_EQ] = ACTIONS(4713),
    [anon_sym_LBRACK] = ACTIONS(4711),
    [anon_sym_COLON] = ACTIONS(4711),
    [anon_sym_COMMA] = ACTIONS(4711),
    [anon_sym_RBRACK] = ACTIONS(4711),
    [anon_sym_LPAREN] = ACTIONS(4711),
    [anon_sym_RPAREN] = ACTIONS(4711),
    [anon_sym_RBRACE] = ACTIONS(4711),
    [anon_sym_LT] = ACTIONS(4713),
    [anon_sym_GT] = ACTIONS(4713),
    [anon_sym_in] = ACTIONS(4713),
    [anon_sym_where] = ACTIONS(4711),
    [anon_sym_QMARK] = ACTIONS(4713),
    [anon_sym_BANG] = ACTIONS(4713),
    [anon_sym_PLUS_PLUS] = ACTIONS(4711),
    [anon_sym_DASH_DASH] = ACTIONS(4711),
    [anon_sym_PLUS] = ACTIONS(4713),
    [anon_sym_DASH] = ACTIONS(4713),
    [anon_sym_STAR] = ACTIONS(4713),
    [anon_sym_SLASH] = ACTIONS(4713),
    [anon_sym_PERCENT] = ACTIONS(4713),
    [anon_sym_CARET] = ACTIONS(4713),
    [anon_sym_PIPE] = ACTIONS(4713),
    [anon_sym_AMP] = ACTIONS(4713),
    [anon_sym_LT_LT] = ACTIONS(4713),
    [anon_sym_GT_GT] = ACTIONS(4713),
    [anon_sym_GT_GT_GT] = ACTIONS(4713),
    [anon_sym_EQ_EQ] = ACTIONS(4711),
    [anon_sym_BANG_EQ] = ACTIONS(4711),
    [anon_sym_GT_EQ] = ACTIONS(4711),
    [anon_sym_LT_EQ] = ACTIONS(4711),
    [anon_sym_DOT] = ACTIONS(4713),
    [anon_sym_EQ_GT] = ACTIONS(4711),
    [anon_sym_switch] = ACTIONS(4711),
    [anon_sym_DOT_DOT] = ACTIONS(4711),
    [anon_sym_and] = ACTIONS(4711),
    [anon_sym_or] = ACTIONS(4713),
    [anon_sym_PLUS_EQ] = ACTIONS(4711),
    [anon_sym_DASH_EQ] = ACTIONS(4711),
    [anon_sym_STAR_EQ] = ACTIONS(4711),
    [anon_sym_SLASH_EQ] = ACTIONS(4711),
    [anon_sym_PERCENT_EQ] = ACTIONS(4711),
    [anon_sym_AMP_EQ] = ACTIONS(4711),
    [anon_sym_CARET_EQ] = ACTIONS(4711),
    [anon_sym_PIPE_EQ] = ACTIONS(4711),
    [anon_sym_LT_LT_EQ] = ACTIONS(4711),
    [anon_sym_GT_GT_EQ] = ACTIONS(4711),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4711),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4711),
    [anon_sym_AMP_AMP] = ACTIONS(4711),
    [anon_sym_PIPE_PIPE] = ACTIONS(4711),
    [anon_sym_QMARK_QMARK] = ACTIONS(4713),
    [anon_sym_from] = ACTIONS(4711),
    [anon_sym_into] = ACTIONS(4711),
    [anon_sym_join] = ACTIONS(4711),
    [anon_sym_on] = ACTIONS(4711),
    [anon_sym_equals] = ACTIONS(4711),
    [anon_sym_let] = ACTIONS(4711),
    [anon_sym_orderby] = ACTIONS(4711),
    [anon_sym_group] = ACTIONS(4711),
    [anon_sym_by] = ACTIONS(4711),
    [anon_sym_select] = ACTIONS(4711),
    [anon_sym_as] = ACTIONS(4711),
    [anon_sym_is] = ACTIONS(4711),
    [anon_sym_DASH_GT] = ACTIONS(4711),
    [anon_sym_with] = ACTIONS(4711),
    [aux_sym_preproc_if_token3] = ACTIONS(4711),
    [aux_sym_preproc_else_token1] = ACTIONS(4711),
    [aux_sym_preproc_elif_token1] = ACTIONS(4711),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3024] = {
    [sym_preproc_region] = STATE(3024),
    [sym_preproc_endregion] = STATE(3024),
    [sym_preproc_line] = STATE(3024),
    [sym_preproc_pragma] = STATE(3024),
    [sym_preproc_nullable] = STATE(3024),
    [sym_preproc_error] = STATE(3024),
    [sym_preproc_warning] = STATE(3024),
    [sym_preproc_define] = STATE(3024),
    [sym_preproc_undef] = STATE(3024),
    [sym__identifier_token] = ACTIONS(4674),
    [anon_sym_alias] = ACTIONS(4674),
    [anon_sym_SEMI] = ACTIONS(4676),
    [anon_sym_global] = ACTIONS(4674),
    [anon_sym_LBRACK] = ACTIONS(4676),
    [anon_sym_COLON] = ACTIONS(4676),
    [anon_sym_COMMA] = ACTIONS(4676),
    [anon_sym_RBRACK] = ACTIONS(4676),
    [anon_sym_LPAREN] = ACTIONS(4676),
    [anon_sym_RPAREN] = ACTIONS(4676),
    [anon_sym_RBRACE] = ACTIONS(4676),
    [anon_sym_file] = ACTIONS(4674),
    [anon_sym_LT] = ACTIONS(4674),
    [anon_sym_GT] = ACTIONS(4674),
    [anon_sym_in] = ACTIONS(4674),
    [anon_sym_where] = ACTIONS(4674),
    [anon_sym_QMARK] = ACTIONS(4674),
    [anon_sym_notnull] = ACTIONS(4674),
    [anon_sym_unmanaged] = ACTIONS(4674),
    [anon_sym_BANG] = ACTIONS(4674),
    [anon_sym_PLUS_PLUS] = ACTIONS(4676),
    [anon_sym_DASH_DASH] = ACTIONS(4676),
    [anon_sym_PLUS] = ACTIONS(4674),
    [anon_sym_DASH] = ACTIONS(4674),
    [anon_sym_STAR] = ACTIONS(4676),
    [anon_sym_SLASH] = ACTIONS(4674),
    [anon_sym_PERCENT] = ACTIONS(4676),
    [anon_sym_CARET] = ACTIONS(4676),
    [anon_sym_PIPE] = ACTIONS(4674),
    [anon_sym_AMP] = ACTIONS(4674),
    [anon_sym_LT_LT] = ACTIONS(4676),
    [anon_sym_GT_GT] = ACTIONS(4674),
    [anon_sym_GT_GT_GT] = ACTIONS(4676),
    [anon_sym_EQ_EQ] = ACTIONS(4676),
    [anon_sym_BANG_EQ] = ACTIONS(4676),
    [anon_sym_GT_EQ] = ACTIONS(4676),
    [anon_sym_LT_EQ] = ACTIONS(4676),
    [anon_sym_DOT] = ACTIONS(4674),
    [anon_sym_scoped] = ACTIONS(4674),
    [anon_sym_EQ_GT] = ACTIONS(4676),
    [anon_sym_var] = ACTIONS(4674),
    [anon_sym_yield] = ACTIONS(4674),
    [anon_sym_switch] = ACTIONS(4674),
    [anon_sym_when] = ACTIONS(4674),
    [sym_discard] = ACTIONS(4674),
    [anon_sym_DOT_DOT] = ACTIONS(4676),
    [anon_sym_and] = ACTIONS(4674),
    [anon_sym_or] = ACTIONS(4674),
    [anon_sym_AMP_AMP] = ACTIONS(4676),
    [anon_sym_PIPE_PIPE] = ACTIONS(4676),
    [anon_sym_QMARK_QMARK] = ACTIONS(4676),
    [anon_sym_from] = ACTIONS(4674),
    [anon_sym_into] = ACTIONS(4674),
    [anon_sym_join] = ACTIONS(4674),
    [anon_sym_on] = ACTIONS(4674),
    [anon_sym_equals] = ACTIONS(4674),
    [anon_sym_let] = ACTIONS(4674),
    [anon_sym_orderby] = ACTIONS(4674),
    [anon_sym_ascending] = ACTIONS(4674),
    [anon_sym_descending] = ACTIONS(4674),
    [anon_sym_group] = ACTIONS(4674),
    [anon_sym_by] = ACTIONS(4674),
    [anon_sym_select] = ACTIONS(4674),
    [anon_sym_as] = ACTIONS(4674),
    [anon_sym_is] = ACTIONS(4674),
    [anon_sym_DASH_GT] = ACTIONS(4676),
    [anon_sym_with] = ACTIONS(4674),
    [aux_sym_preproc_if_token3] = ACTIONS(4676),
    [aux_sym_preproc_else_token1] = ACTIONS(4676),
    [aux_sym_preproc_elif_token1] = ACTIONS(4676),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3025] = {
    [sym_preproc_region] = STATE(3025),
    [sym_preproc_endregion] = STATE(3025),
    [sym_preproc_line] = STATE(3025),
    [sym_preproc_pragma] = STATE(3025),
    [sym_preproc_nullable] = STATE(3025),
    [sym_preproc_error] = STATE(3025),
    [sym_preproc_warning] = STATE(3025),
    [sym_preproc_define] = STATE(3025),
    [sym_preproc_undef] = STATE(3025),
    [sym__identifier_token] = ACTIONS(4492),
    [anon_sym_alias] = ACTIONS(4492),
    [anon_sym_SEMI] = ACTIONS(4494),
    [anon_sym_global] = ACTIONS(4492),
    [anon_sym_LBRACK] = ACTIONS(4593),
    [anon_sym_COMMA] = ACTIONS(4494),
    [anon_sym_RBRACK] = ACTIONS(4494),
    [anon_sym_LPAREN] = ACTIONS(4494),
    [anon_sym_RPAREN] = ACTIONS(4494),
    [anon_sym_LBRACE] = ACTIONS(4494),
    [anon_sym_RBRACE] = ACTIONS(4494),
    [anon_sym_file] = ACTIONS(4492),
    [anon_sym_LT] = ACTIONS(4492),
    [anon_sym_GT] = ACTIONS(4492),
    [anon_sym_in] = ACTIONS(4492),
    [anon_sym_where] = ACTIONS(4492),
    [anon_sym_QMARK] = ACTIONS(4596),
    [anon_sym_notnull] = ACTIONS(4492),
    [anon_sym_unmanaged] = ACTIONS(4492),
    [anon_sym_BANG] = ACTIONS(4492),
    [anon_sym_PLUS_PLUS] = ACTIONS(4494),
    [anon_sym_DASH_DASH] = ACTIONS(4494),
    [anon_sym_PLUS] = ACTIONS(4492),
    [anon_sym_DASH] = ACTIONS(4492),
    [anon_sym_STAR] = ACTIONS(4599),
    [anon_sym_SLASH] = ACTIONS(4492),
    [anon_sym_PERCENT] = ACTIONS(4494),
    [anon_sym_CARET] = ACTIONS(4494),
    [anon_sym_PIPE] = ACTIONS(4492),
    [anon_sym_AMP] = ACTIONS(4492),
    [anon_sym_LT_LT] = ACTIONS(4494),
    [anon_sym_GT_GT] = ACTIONS(4492),
    [anon_sym_GT_GT_GT] = ACTIONS(4494),
    [anon_sym_EQ_EQ] = ACTIONS(4494),
    [anon_sym_BANG_EQ] = ACTIONS(4494),
    [anon_sym_GT_EQ] = ACTIONS(4494),
    [anon_sym_LT_EQ] = ACTIONS(4494),
    [anon_sym_DOT] = ACTIONS(4715),
    [anon_sym_scoped] = ACTIONS(4492),
    [anon_sym_EQ_GT] = ACTIONS(4494),
    [anon_sym_var] = ACTIONS(4492),
    [anon_sym_yield] = ACTIONS(4492),
    [anon_sym_switch] = ACTIONS(4492),
    [anon_sym_when] = ACTIONS(4492),
    [sym_discard] = ACTIONS(4492),
    [anon_sym_DOT_DOT] = ACTIONS(4494),
    [anon_sym_and] = ACTIONS(4492),
    [anon_sym_or] = ACTIONS(4492),
    [anon_sym_AMP_AMP] = ACTIONS(4494),
    [anon_sym_PIPE_PIPE] = ACTIONS(4494),
    [anon_sym_QMARK_QMARK] = ACTIONS(4494),
    [anon_sym_from] = ACTIONS(4492),
    [anon_sym_into] = ACTIONS(4492),
    [anon_sym_join] = ACTIONS(4492),
    [anon_sym_on] = ACTIONS(4492),
    [anon_sym_equals] = ACTIONS(4492),
    [anon_sym_let] = ACTIONS(4492),
    [anon_sym_orderby] = ACTIONS(4492),
    [anon_sym_ascending] = ACTIONS(4492),
    [anon_sym_descending] = ACTIONS(4492),
    [anon_sym_group] = ACTIONS(4492),
    [anon_sym_by] = ACTIONS(4492),
    [anon_sym_select] = ACTIONS(4492),
    [anon_sym_as] = ACTIONS(4492),
    [anon_sym_is] = ACTIONS(4492),
    [anon_sym_DASH_GT] = ACTIONS(4604),
    [anon_sym_with] = ACTIONS(4492),
    [aux_sym_preproc_if_token3] = ACTIONS(4494),
    [aux_sym_preproc_else_token1] = ACTIONS(4494),
    [aux_sym_preproc_elif_token1] = ACTIONS(4494),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3026] = {
    [sym_preproc_region] = STATE(3026),
    [sym_preproc_endregion] = STATE(3026),
    [sym_preproc_line] = STATE(3026),
    [sym_preproc_pragma] = STATE(3026),
    [sym_preproc_nullable] = STATE(3026),
    [sym_preproc_error] = STATE(3026),
    [sym_preproc_warning] = STATE(3026),
    [sym_preproc_define] = STATE(3026),
    [sym_preproc_undef] = STATE(3026),
    [anon_sym_SEMI] = ACTIONS(4703),
    [anon_sym_EQ] = ACTIONS(4672),
    [anon_sym_LBRACK] = ACTIONS(4703),
    [anon_sym_COLON] = ACTIONS(4670),
    [anon_sym_COMMA] = ACTIONS(4703),
    [anon_sym_RBRACK] = ACTIONS(4703),
    [anon_sym_LPAREN] = ACTIONS(4703),
    [anon_sym_RPAREN] = ACTIONS(4703),
    [anon_sym_RBRACE] = ACTIONS(4703),
    [anon_sym_LT] = ACTIONS(4705),
    [anon_sym_GT] = ACTIONS(4705),
    [anon_sym_in] = ACTIONS(4703),
    [anon_sym_where] = ACTIONS(4703),
    [anon_sym_QMARK] = ACTIONS(4705),
    [anon_sym_BANG] = ACTIONS(4705),
    [anon_sym_PLUS_PLUS] = ACTIONS(4703),
    [anon_sym_DASH_DASH] = ACTIONS(4703),
    [anon_sym_PLUS] = ACTIONS(4705),
    [anon_sym_DASH] = ACTIONS(4705),
    [anon_sym_STAR] = ACTIONS(4705),
    [anon_sym_SLASH] = ACTIONS(4705),
    [anon_sym_PERCENT] = ACTIONS(4705),
    [anon_sym_CARET] = ACTIONS(4705),
    [anon_sym_PIPE] = ACTIONS(4705),
    [anon_sym_AMP] = ACTIONS(4705),
    [anon_sym_LT_LT] = ACTIONS(4705),
    [anon_sym_GT_GT] = ACTIONS(4705),
    [anon_sym_GT_GT_GT] = ACTIONS(4705),
    [anon_sym_EQ_EQ] = ACTIONS(4703),
    [anon_sym_BANG_EQ] = ACTIONS(4703),
    [anon_sym_GT_EQ] = ACTIONS(4703),
    [anon_sym_LT_EQ] = ACTIONS(4703),
    [anon_sym_DOT] = ACTIONS(4705),
    [anon_sym_EQ_GT] = ACTIONS(4703),
    [anon_sym_switch] = ACTIONS(4703),
    [anon_sym_DOT_DOT] = ACTIONS(4703),
    [anon_sym_and] = ACTIONS(4703),
    [anon_sym_or] = ACTIONS(4705),
    [anon_sym_PLUS_EQ] = ACTIONS(4670),
    [anon_sym_DASH_EQ] = ACTIONS(4670),
    [anon_sym_STAR_EQ] = ACTIONS(4670),
    [anon_sym_SLASH_EQ] = ACTIONS(4670),
    [anon_sym_PERCENT_EQ] = ACTIONS(4670),
    [anon_sym_AMP_EQ] = ACTIONS(4670),
    [anon_sym_CARET_EQ] = ACTIONS(4670),
    [anon_sym_PIPE_EQ] = ACTIONS(4670),
    [anon_sym_LT_LT_EQ] = ACTIONS(4670),
    [anon_sym_GT_GT_EQ] = ACTIONS(4670),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4670),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4670),
    [anon_sym_AMP_AMP] = ACTIONS(4703),
    [anon_sym_PIPE_PIPE] = ACTIONS(4703),
    [anon_sym_QMARK_QMARK] = ACTIONS(4705),
    [anon_sym_from] = ACTIONS(4703),
    [anon_sym_join] = ACTIONS(4703),
    [anon_sym_on] = ACTIONS(4703),
    [anon_sym_equals] = ACTIONS(4703),
    [anon_sym_let] = ACTIONS(4703),
    [anon_sym_orderby] = ACTIONS(4703),
    [anon_sym_group] = ACTIONS(4703),
    [anon_sym_by] = ACTIONS(4703),
    [anon_sym_select] = ACTIONS(4703),
    [anon_sym_as] = ACTIONS(4703),
    [anon_sym_is] = ACTIONS(4703),
    [anon_sym_DASH_GT] = ACTIONS(4703),
    [anon_sym_with] = ACTIONS(4703),
    [aux_sym_preproc_if_token3] = ACTIONS(4703),
    [aux_sym_preproc_else_token1] = ACTIONS(4703),
    [aux_sym_preproc_elif_token1] = ACTIONS(4703),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3027] = {
    [sym_preproc_region] = STATE(3027),
    [sym_preproc_endregion] = STATE(3027),
    [sym_preproc_line] = STATE(3027),
    [sym_preproc_pragma] = STATE(3027),
    [sym_preproc_nullable] = STATE(3027),
    [sym_preproc_error] = STATE(3027),
    [sym_preproc_warning] = STATE(3027),
    [sym_preproc_define] = STATE(3027),
    [sym_preproc_undef] = STATE(3027),
    [anon_sym_SEMI] = ACTIONS(4687),
    [anon_sym_EQ] = ACTIONS(4689),
    [anon_sym_LBRACK] = ACTIONS(4687),
    [anon_sym_COLON] = ACTIONS(4687),
    [anon_sym_COMMA] = ACTIONS(4687),
    [anon_sym_RBRACK] = ACTIONS(4687),
    [anon_sym_LPAREN] = ACTIONS(4687),
    [anon_sym_RPAREN] = ACTIONS(4687),
    [anon_sym_RBRACE] = ACTIONS(4687),
    [anon_sym_LT] = ACTIONS(4689),
    [anon_sym_GT] = ACTIONS(4689),
    [anon_sym_in] = ACTIONS(4687),
    [anon_sym_where] = ACTIONS(4687),
    [anon_sym_QMARK] = ACTIONS(4689),
    [anon_sym_BANG] = ACTIONS(4689),
    [anon_sym_PLUS_PLUS] = ACTIONS(4687),
    [anon_sym_DASH_DASH] = ACTIONS(4687),
    [anon_sym_PLUS] = ACTIONS(4689),
    [anon_sym_DASH] = ACTIONS(4689),
    [anon_sym_STAR] = ACTIONS(4689),
    [anon_sym_SLASH] = ACTIONS(4689),
    [anon_sym_PERCENT] = ACTIONS(4689),
    [anon_sym_CARET] = ACTIONS(4689),
    [anon_sym_PIPE] = ACTIONS(4689),
    [anon_sym_AMP] = ACTIONS(4689),
    [anon_sym_LT_LT] = ACTIONS(4689),
    [anon_sym_GT_GT] = ACTIONS(4689),
    [anon_sym_GT_GT_GT] = ACTIONS(4689),
    [anon_sym_EQ_EQ] = ACTIONS(4687),
    [anon_sym_BANG_EQ] = ACTIONS(4687),
    [anon_sym_GT_EQ] = ACTIONS(4687),
    [anon_sym_LT_EQ] = ACTIONS(4687),
    [anon_sym_DOT] = ACTIONS(4689),
    [anon_sym_EQ_GT] = ACTIONS(4687),
    [anon_sym_switch] = ACTIONS(4687),
    [anon_sym_DOT_DOT] = ACTIONS(4687),
    [anon_sym_and] = ACTIONS(4687),
    [anon_sym_or] = ACTIONS(4689),
    [anon_sym_PLUS_EQ] = ACTIONS(4687),
    [anon_sym_DASH_EQ] = ACTIONS(4687),
    [anon_sym_STAR_EQ] = ACTIONS(4687),
    [anon_sym_SLASH_EQ] = ACTIONS(4687),
    [anon_sym_PERCENT_EQ] = ACTIONS(4687),
    [anon_sym_AMP_EQ] = ACTIONS(4687),
    [anon_sym_CARET_EQ] = ACTIONS(4687),
    [anon_sym_PIPE_EQ] = ACTIONS(4687),
    [anon_sym_LT_LT_EQ] = ACTIONS(4687),
    [anon_sym_GT_GT_EQ] = ACTIONS(4687),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4687),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4687),
    [anon_sym_AMP_AMP] = ACTIONS(4687),
    [anon_sym_PIPE_PIPE] = ACTIONS(4687),
    [anon_sym_QMARK_QMARK] = ACTIONS(4689),
    [anon_sym_from] = ACTIONS(4687),
    [anon_sym_join] = ACTIONS(4687),
    [anon_sym_on] = ACTIONS(4687),
    [anon_sym_equals] = ACTIONS(4687),
    [anon_sym_let] = ACTIONS(4687),
    [anon_sym_orderby] = ACTIONS(4687),
    [anon_sym_group] = ACTIONS(4687),
    [anon_sym_by] = ACTIONS(4687),
    [anon_sym_select] = ACTIONS(4687),
    [anon_sym_as] = ACTIONS(4687),
    [anon_sym_is] = ACTIONS(4687),
    [anon_sym_DASH_GT] = ACTIONS(4687),
    [anon_sym_with] = ACTIONS(4687),
    [aux_sym_preproc_if_token3] = ACTIONS(4687),
    [aux_sym_preproc_else_token1] = ACTIONS(4687),
    [aux_sym_preproc_elif_token1] = ACTIONS(4687),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3028] = {
    [sym_parameter_list] = STATE(9685),
    [sym_positional_pattern_clause] = STATE(3131),
    [sym_property_pattern_clause] = STATE(3212),
    [sym__variable_designation] = STATE(4162),
    [sym_parenthesized_variable_designation] = STATE(4153),
    [sym__lambda_parameters] = STATE(9890),
    [sym_identifier] = STATE(4163),
    [sym__reserved_identifier] = STATE(3911),
    [sym_preproc_region] = STATE(3028),
    [sym_preproc_endregion] = STATE(3028),
    [sym_preproc_line] = STATE(3028),
    [sym_preproc_pragma] = STATE(3028),
    [sym_preproc_nullable] = STATE(3028),
    [sym_preproc_error] = STATE(3028),
    [sym_preproc_warning] = STATE(3028),
    [sym_preproc_define] = STATE(3028),
    [sym_preproc_undef] = STATE(3028),
    [sym__identifier_token] = ACTIONS(4248),
    [anon_sym_alias] = ACTIONS(4250),
    [anon_sym_global] = ACTIONS(4250),
    [anon_sym_LBRACK] = ACTIONS(4341),
    [anon_sym_LPAREN] = ACTIONS(4341),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_file] = ACTIONS(4250),
    [anon_sym_LT] = ACTIONS(4345),
    [anon_sym_GT] = ACTIONS(4345),
    [anon_sym_in] = ACTIONS(4345),
    [anon_sym_where] = ACTIONS(4250),
    [anon_sym_QMARK] = ACTIONS(4345),
    [anon_sym_notnull] = ACTIONS(4250),
    [anon_sym_unmanaged] = ACTIONS(4250),
    [anon_sym_BANG] = ACTIONS(4345),
    [anon_sym_PLUS_PLUS] = ACTIONS(4341),
    [anon_sym_DASH_DASH] = ACTIONS(4341),
    [anon_sym_PLUS] = ACTIONS(4345),
    [anon_sym_DASH] = ACTIONS(4345),
    [anon_sym_STAR] = ACTIONS(4341),
    [anon_sym_SLASH] = ACTIONS(4345),
    [anon_sym_PERCENT] = ACTIONS(4341),
    [anon_sym_CARET] = ACTIONS(4341),
    [anon_sym_PIPE] = ACTIONS(4345),
    [anon_sym_AMP] = ACTIONS(4345),
    [anon_sym_LT_LT] = ACTIONS(4341),
    [anon_sym_GT_GT] = ACTIONS(4345),
    [anon_sym_GT_GT_GT] = ACTIONS(4341),
    [anon_sym_EQ_EQ] = ACTIONS(4341),
    [anon_sym_BANG_EQ] = ACTIONS(4341),
    [anon_sym_GT_EQ] = ACTIONS(4341),
    [anon_sym_LT_EQ] = ACTIONS(4341),
    [anon_sym_DOT] = ACTIONS(4345),
    [anon_sym_scoped] = ACTIONS(4250),
    [anon_sym_var] = ACTIONS(4250),
    [anon_sym_yield] = ACTIONS(4250),
    [anon_sym_switch] = ACTIONS(4345),
    [anon_sym_when] = ACTIONS(4250),
    [sym_discard] = ACTIONS(4359),
    [anon_sym_DOT_DOT] = ACTIONS(4341),
    [anon_sym_and] = ACTIONS(4355),
    [anon_sym_or] = ACTIONS(4355),
    [anon_sym_AMP_AMP] = ACTIONS(4341),
    [anon_sym_PIPE_PIPE] = ACTIONS(4341),
    [anon_sym_QMARK_QMARK] = ACTIONS(4341),
    [anon_sym_from] = ACTIONS(4250),
    [anon_sym_into] = ACTIONS(4250),
    [anon_sym_join] = ACTIONS(4250),
    [anon_sym_on] = ACTIONS(4250),
    [anon_sym_equals] = ACTIONS(4250),
    [anon_sym_let] = ACTIONS(4250),
    [anon_sym_orderby] = ACTIONS(4250),
    [anon_sym_ascending] = ACTIONS(4250),
    [anon_sym_descending] = ACTIONS(4250),
    [anon_sym_group] = ACTIONS(4250),
    [anon_sym_by] = ACTIONS(4250),
    [anon_sym_select] = ACTIONS(4250),
    [anon_sym_as] = ACTIONS(4345),
    [anon_sym_is] = ACTIONS(4345),
    [anon_sym_DASH_GT] = ACTIONS(4341),
    [anon_sym_with] = ACTIONS(4345),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3029] = {
    [sym_parameter_list] = STATE(9685),
    [sym_positional_pattern_clause] = STATE(3106),
    [sym_property_pattern_clause] = STATE(3140),
    [sym__variable_designation] = STATE(4091),
    [sym_parenthesized_variable_designation] = STATE(3966),
    [sym__lambda_parameters] = STATE(9890),
    [sym_identifier] = STATE(4070),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3029),
    [sym_preproc_endregion] = STATE(3029),
    [sym_preproc_line] = STATE(3029),
    [sym_preproc_pragma] = STATE(3029),
    [sym_preproc_nullable] = STATE(3029),
    [sym_preproc_error] = STATE(3029),
    [sym_preproc_warning] = STATE(3029),
    [sym_preproc_define] = STATE(3029),
    [sym_preproc_undef] = STATE(3029),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4357),
    [anon_sym_COLON] = ACTIONS(4357),
    [anon_sym_LPAREN] = ACTIONS(4357),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4355),
    [anon_sym_GT] = ACTIONS(4355),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4355),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4355),
    [anon_sym_PLUS_PLUS] = ACTIONS(4357),
    [anon_sym_DASH_DASH] = ACTIONS(4357),
    [anon_sym_PLUS] = ACTIONS(4355),
    [anon_sym_DASH] = ACTIONS(4355),
    [anon_sym_STAR] = ACTIONS(4357),
    [anon_sym_SLASH] = ACTIONS(4355),
    [anon_sym_PERCENT] = ACTIONS(4357),
    [anon_sym_CARET] = ACTIONS(4357),
    [anon_sym_PIPE] = ACTIONS(4355),
    [anon_sym_AMP] = ACTIONS(4355),
    [anon_sym_LT_LT] = ACTIONS(4357),
    [anon_sym_GT_GT] = ACTIONS(4355),
    [anon_sym_GT_GT_GT] = ACTIONS(4357),
    [anon_sym_EQ_EQ] = ACTIONS(4357),
    [anon_sym_BANG_EQ] = ACTIONS(4357),
    [anon_sym_GT_EQ] = ACTIONS(4357),
    [anon_sym_LT_EQ] = ACTIONS(4357),
    [anon_sym_DOT] = ACTIONS(4355),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4355),
    [anon_sym_when] = ACTIONS(4355),
    [sym_discard] = ACTIONS(4347),
    [anon_sym_DOT_DOT] = ACTIONS(4357),
    [anon_sym_and] = ACTIONS(4355),
    [anon_sym_or] = ACTIONS(4355),
    [anon_sym_AMP_AMP] = ACTIONS(4357),
    [anon_sym_PIPE_PIPE] = ACTIONS(4357),
    [anon_sym_QMARK_QMARK] = ACTIONS(4357),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4355),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4355),
    [anon_sym_is] = ACTIONS(4355),
    [anon_sym_DASH_GT] = ACTIONS(4357),
    [anon_sym_with] = ACTIONS(4355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3030] = {
    [sym_preproc_region] = STATE(3030),
    [sym_preproc_endregion] = STATE(3030),
    [sym_preproc_line] = STATE(3030),
    [sym_preproc_pragma] = STATE(3030),
    [sym_preproc_nullable] = STATE(3030),
    [sym_preproc_error] = STATE(3030),
    [sym_preproc_warning] = STATE(3030),
    [sym_preproc_define] = STATE(3030),
    [sym_preproc_undef] = STATE(3030),
    [anon_sym_SEMI] = ACTIONS(4670),
    [anon_sym_EQ] = ACTIONS(4672),
    [anon_sym_LBRACK] = ACTIONS(4670),
    [anon_sym_COLON] = ACTIONS(4670),
    [anon_sym_COMMA] = ACTIONS(4670),
    [anon_sym_RBRACK] = ACTIONS(4670),
    [anon_sym_LPAREN] = ACTIONS(4670),
    [anon_sym_RPAREN] = ACTIONS(4670),
    [anon_sym_RBRACE] = ACTIONS(4670),
    [anon_sym_LT] = ACTIONS(4672),
    [anon_sym_GT] = ACTIONS(4672),
    [anon_sym_in] = ACTIONS(4670),
    [anon_sym_where] = ACTIONS(4670),
    [anon_sym_QMARK] = ACTIONS(4672),
    [anon_sym_BANG] = ACTIONS(4672),
    [anon_sym_PLUS_PLUS] = ACTIONS(4670),
    [anon_sym_DASH_DASH] = ACTIONS(4670),
    [anon_sym_PLUS] = ACTIONS(4672),
    [anon_sym_DASH] = ACTIONS(4672),
    [anon_sym_STAR] = ACTIONS(4672),
    [anon_sym_SLASH] = ACTIONS(4672),
    [anon_sym_PERCENT] = ACTIONS(4672),
    [anon_sym_CARET] = ACTIONS(4672),
    [anon_sym_PIPE] = ACTIONS(4672),
    [anon_sym_AMP] = ACTIONS(4672),
    [anon_sym_LT_LT] = ACTIONS(4672),
    [anon_sym_GT_GT] = ACTIONS(4672),
    [anon_sym_GT_GT_GT] = ACTIONS(4672),
    [anon_sym_EQ_EQ] = ACTIONS(4670),
    [anon_sym_BANG_EQ] = ACTIONS(4670),
    [anon_sym_GT_EQ] = ACTIONS(4670),
    [anon_sym_LT_EQ] = ACTIONS(4670),
    [anon_sym_DOT] = ACTIONS(4672),
    [anon_sym_EQ_GT] = ACTIONS(4670),
    [anon_sym_switch] = ACTIONS(4670),
    [anon_sym_DOT_DOT] = ACTIONS(4670),
    [anon_sym_and] = ACTIONS(4670),
    [anon_sym_or] = ACTIONS(4672),
    [anon_sym_PLUS_EQ] = ACTIONS(4670),
    [anon_sym_DASH_EQ] = ACTIONS(4670),
    [anon_sym_STAR_EQ] = ACTIONS(4670),
    [anon_sym_SLASH_EQ] = ACTIONS(4670),
    [anon_sym_PERCENT_EQ] = ACTIONS(4670),
    [anon_sym_AMP_EQ] = ACTIONS(4670),
    [anon_sym_CARET_EQ] = ACTIONS(4670),
    [anon_sym_PIPE_EQ] = ACTIONS(4670),
    [anon_sym_LT_LT_EQ] = ACTIONS(4670),
    [anon_sym_GT_GT_EQ] = ACTIONS(4670),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4670),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4670),
    [anon_sym_AMP_AMP] = ACTIONS(4670),
    [anon_sym_PIPE_PIPE] = ACTIONS(4670),
    [anon_sym_QMARK_QMARK] = ACTIONS(4672),
    [anon_sym_from] = ACTIONS(4670),
    [anon_sym_join] = ACTIONS(4670),
    [anon_sym_on] = ACTIONS(4670),
    [anon_sym_equals] = ACTIONS(4670),
    [anon_sym_let] = ACTIONS(4670),
    [anon_sym_orderby] = ACTIONS(4670),
    [anon_sym_group] = ACTIONS(4670),
    [anon_sym_by] = ACTIONS(4670),
    [anon_sym_select] = ACTIONS(4670),
    [anon_sym_as] = ACTIONS(4670),
    [anon_sym_is] = ACTIONS(4670),
    [anon_sym_DASH_GT] = ACTIONS(4670),
    [anon_sym_with] = ACTIONS(4670),
    [aux_sym_preproc_if_token3] = ACTIONS(4670),
    [aux_sym_preproc_else_token1] = ACTIONS(4670),
    [aux_sym_preproc_elif_token1] = ACTIONS(4670),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3031] = {
    [sym_parameter_list] = STATE(9685),
    [sym_positional_pattern_clause] = STATE(3131),
    [sym_property_pattern_clause] = STATE(3212),
    [sym__variable_designation] = STATE(4162),
    [sym_parenthesized_variable_designation] = STATE(4153),
    [sym__lambda_parameters] = STATE(9890),
    [sym_identifier] = STATE(4163),
    [sym__reserved_identifier] = STATE(3911),
    [sym_preproc_region] = STATE(3031),
    [sym_preproc_endregion] = STATE(3031),
    [sym_preproc_line] = STATE(3031),
    [sym_preproc_pragma] = STATE(3031),
    [sym_preproc_nullable] = STATE(3031),
    [sym_preproc_error] = STATE(3031),
    [sym_preproc_warning] = STATE(3031),
    [sym_preproc_define] = STATE(3031),
    [sym_preproc_undef] = STATE(3031),
    [sym__identifier_token] = ACTIONS(4248),
    [anon_sym_alias] = ACTIONS(4250),
    [anon_sym_global] = ACTIONS(4250),
    [anon_sym_LBRACK] = ACTIONS(4357),
    [anon_sym_LPAREN] = ACTIONS(4357),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_file] = ACTIONS(4250),
    [anon_sym_LT] = ACTIONS(4355),
    [anon_sym_GT] = ACTIONS(4355),
    [anon_sym_in] = ACTIONS(4355),
    [anon_sym_where] = ACTIONS(4250),
    [anon_sym_QMARK] = ACTIONS(4355),
    [anon_sym_notnull] = ACTIONS(4250),
    [anon_sym_unmanaged] = ACTIONS(4250),
    [anon_sym_BANG] = ACTIONS(4355),
    [anon_sym_PLUS_PLUS] = ACTIONS(4357),
    [anon_sym_DASH_DASH] = ACTIONS(4357),
    [anon_sym_PLUS] = ACTIONS(4355),
    [anon_sym_DASH] = ACTIONS(4355),
    [anon_sym_STAR] = ACTIONS(4357),
    [anon_sym_SLASH] = ACTIONS(4355),
    [anon_sym_PERCENT] = ACTIONS(4357),
    [anon_sym_CARET] = ACTIONS(4357),
    [anon_sym_PIPE] = ACTIONS(4355),
    [anon_sym_AMP] = ACTIONS(4355),
    [anon_sym_LT_LT] = ACTIONS(4357),
    [anon_sym_GT_GT] = ACTIONS(4355),
    [anon_sym_GT_GT_GT] = ACTIONS(4357),
    [anon_sym_EQ_EQ] = ACTIONS(4357),
    [anon_sym_BANG_EQ] = ACTIONS(4357),
    [anon_sym_GT_EQ] = ACTIONS(4357),
    [anon_sym_LT_EQ] = ACTIONS(4357),
    [anon_sym_DOT] = ACTIONS(4355),
    [anon_sym_scoped] = ACTIONS(4250),
    [anon_sym_var] = ACTIONS(4250),
    [anon_sym_yield] = ACTIONS(4250),
    [anon_sym_switch] = ACTIONS(4355),
    [anon_sym_when] = ACTIONS(4250),
    [sym_discard] = ACTIONS(4359),
    [anon_sym_DOT_DOT] = ACTIONS(4357),
    [anon_sym_and] = ACTIONS(4355),
    [anon_sym_or] = ACTIONS(4355),
    [anon_sym_AMP_AMP] = ACTIONS(4357),
    [anon_sym_PIPE_PIPE] = ACTIONS(4357),
    [anon_sym_QMARK_QMARK] = ACTIONS(4357),
    [anon_sym_from] = ACTIONS(4250),
    [anon_sym_into] = ACTIONS(4250),
    [anon_sym_join] = ACTIONS(4250),
    [anon_sym_on] = ACTIONS(4250),
    [anon_sym_equals] = ACTIONS(4250),
    [anon_sym_let] = ACTIONS(4250),
    [anon_sym_orderby] = ACTIONS(4250),
    [anon_sym_ascending] = ACTIONS(4250),
    [anon_sym_descending] = ACTIONS(4250),
    [anon_sym_group] = ACTIONS(4250),
    [anon_sym_by] = ACTIONS(4250),
    [anon_sym_select] = ACTIONS(4250),
    [anon_sym_as] = ACTIONS(4355),
    [anon_sym_is] = ACTIONS(4355),
    [anon_sym_DASH_GT] = ACTIONS(4357),
    [anon_sym_with] = ACTIONS(4355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3032] = {
    [sym_parameter_list] = STATE(9685),
    [sym_positional_pattern_clause] = STATE(3130),
    [sym_property_pattern_clause] = STATE(3173),
    [sym__variable_designation] = STATE(4551),
    [sym_parenthesized_variable_designation] = STATE(4748),
    [sym__lambda_parameters] = STATE(9890),
    [sym_identifier] = STATE(4500),
    [sym__reserved_identifier] = STATE(2928),
    [sym_preproc_region] = STATE(3032),
    [sym_preproc_endregion] = STATE(3032),
    [sym_preproc_line] = STATE(3032),
    [sym_preproc_pragma] = STATE(3032),
    [sym_preproc_nullable] = STATE(3032),
    [sym_preproc_error] = STATE(3032),
    [sym_preproc_warning] = STATE(3032),
    [sym_preproc_define] = STATE(3032),
    [sym_preproc_undef] = STATE(3032),
    [sym__identifier_token] = ACTIONS(4536),
    [anon_sym_alias] = ACTIONS(4538),
    [anon_sym_global] = ACTIONS(4538),
    [anon_sym_LBRACK] = ACTIONS(4341),
    [anon_sym_COMMA] = ACTIONS(4341),
    [anon_sym_LPAREN] = ACTIONS(4341),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_file] = ACTIONS(4538),
    [anon_sym_LT] = ACTIONS(4345),
    [anon_sym_GT] = ACTIONS(4345),
    [anon_sym_where] = ACTIONS(4345),
    [anon_sym_QMARK] = ACTIONS(4345),
    [anon_sym_notnull] = ACTIONS(4538),
    [anon_sym_unmanaged] = ACTIONS(4538),
    [anon_sym_BANG] = ACTIONS(4345),
    [anon_sym_PLUS_PLUS] = ACTIONS(4341),
    [anon_sym_DASH_DASH] = ACTIONS(4341),
    [anon_sym_PLUS] = ACTIONS(4345),
    [anon_sym_DASH] = ACTIONS(4345),
    [anon_sym_STAR] = ACTIONS(4341),
    [anon_sym_SLASH] = ACTIONS(4345),
    [anon_sym_PERCENT] = ACTIONS(4341),
    [anon_sym_CARET] = ACTIONS(4341),
    [anon_sym_PIPE] = ACTIONS(4345),
    [anon_sym_AMP] = ACTIONS(4345),
    [anon_sym_LT_LT] = ACTIONS(4341),
    [anon_sym_GT_GT] = ACTIONS(4345),
    [anon_sym_GT_GT_GT] = ACTIONS(4341),
    [anon_sym_EQ_EQ] = ACTIONS(4341),
    [anon_sym_BANG_EQ] = ACTIONS(4341),
    [anon_sym_GT_EQ] = ACTIONS(4341),
    [anon_sym_LT_EQ] = ACTIONS(4341),
    [anon_sym_DOT] = ACTIONS(4345),
    [anon_sym_scoped] = ACTIONS(4538),
    [anon_sym_var] = ACTIONS(4538),
    [anon_sym_yield] = ACTIONS(4538),
    [anon_sym_switch] = ACTIONS(4345),
    [anon_sym_when] = ACTIONS(4538),
    [sym_discard] = ACTIONS(4717),
    [anon_sym_DOT_DOT] = ACTIONS(4341),
    [anon_sym_and] = ACTIONS(4345),
    [anon_sym_or] = ACTIONS(4345),
    [anon_sym_AMP_AMP] = ACTIONS(4341),
    [anon_sym_PIPE_PIPE] = ACTIONS(4341),
    [anon_sym_QMARK_QMARK] = ACTIONS(4341),
    [anon_sym_from] = ACTIONS(4345),
    [anon_sym_into] = ACTIONS(4345),
    [anon_sym_join] = ACTIONS(4345),
    [anon_sym_on] = ACTIONS(4538),
    [anon_sym_equals] = ACTIONS(4538),
    [anon_sym_let] = ACTIONS(4345),
    [anon_sym_orderby] = ACTIONS(4345),
    [anon_sym_ascending] = ACTIONS(4345),
    [anon_sym_descending] = ACTIONS(4345),
    [anon_sym_group] = ACTIONS(4345),
    [anon_sym_by] = ACTIONS(4538),
    [anon_sym_select] = ACTIONS(4345),
    [anon_sym_as] = ACTIONS(4345),
    [anon_sym_is] = ACTIONS(4345),
    [anon_sym_DASH_GT] = ACTIONS(4341),
    [anon_sym_with] = ACTIONS(4345),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3033] = {
    [sym_preproc_region] = STATE(3033),
    [sym_preproc_endregion] = STATE(3033),
    [sym_preproc_line] = STATE(3033),
    [sym_preproc_pragma] = STATE(3033),
    [sym_preproc_nullable] = STATE(3033),
    [sym_preproc_error] = STATE(3033),
    [sym_preproc_warning] = STATE(3033),
    [sym_preproc_define] = STATE(3033),
    [sym_preproc_undef] = STATE(3033),
    [anon_sym_SEMI] = ACTIONS(4640),
    [anon_sym_EQ] = ACTIONS(4642),
    [anon_sym_LBRACK] = ACTIONS(4640),
    [anon_sym_COLON] = ACTIONS(4640),
    [anon_sym_COMMA] = ACTIONS(4640),
    [anon_sym_RBRACK] = ACTIONS(4640),
    [anon_sym_LPAREN] = ACTIONS(4640),
    [anon_sym_RPAREN] = ACTIONS(4640),
    [anon_sym_RBRACE] = ACTIONS(4640),
    [anon_sym_LT] = ACTIONS(4642),
    [anon_sym_GT] = ACTIONS(4642),
    [anon_sym_in] = ACTIONS(4640),
    [anon_sym_where] = ACTIONS(4640),
    [anon_sym_QMARK] = ACTIONS(4642),
    [anon_sym_BANG] = ACTIONS(4642),
    [anon_sym_PLUS_PLUS] = ACTIONS(4640),
    [anon_sym_DASH_DASH] = ACTIONS(4640),
    [anon_sym_PLUS] = ACTIONS(4642),
    [anon_sym_DASH] = ACTIONS(4642),
    [anon_sym_STAR] = ACTIONS(4642),
    [anon_sym_SLASH] = ACTIONS(4642),
    [anon_sym_PERCENT] = ACTIONS(4642),
    [anon_sym_CARET] = ACTIONS(4642),
    [anon_sym_PIPE] = ACTIONS(4642),
    [anon_sym_AMP] = ACTIONS(4642),
    [anon_sym_LT_LT] = ACTIONS(4642),
    [anon_sym_GT_GT] = ACTIONS(4642),
    [anon_sym_GT_GT_GT] = ACTIONS(4642),
    [anon_sym_EQ_EQ] = ACTIONS(4640),
    [anon_sym_BANG_EQ] = ACTIONS(4640),
    [anon_sym_GT_EQ] = ACTIONS(4640),
    [anon_sym_LT_EQ] = ACTIONS(4640),
    [anon_sym_DOT] = ACTIONS(4642),
    [anon_sym_EQ_GT] = ACTIONS(4640),
    [anon_sym_switch] = ACTIONS(4640),
    [anon_sym_DOT_DOT] = ACTIONS(4640),
    [anon_sym_and] = ACTIONS(4640),
    [anon_sym_or] = ACTIONS(4642),
    [anon_sym_PLUS_EQ] = ACTIONS(4640),
    [anon_sym_DASH_EQ] = ACTIONS(4640),
    [anon_sym_STAR_EQ] = ACTIONS(4640),
    [anon_sym_SLASH_EQ] = ACTIONS(4640),
    [anon_sym_PERCENT_EQ] = ACTIONS(4640),
    [anon_sym_AMP_EQ] = ACTIONS(4640),
    [anon_sym_CARET_EQ] = ACTIONS(4640),
    [anon_sym_PIPE_EQ] = ACTIONS(4640),
    [anon_sym_LT_LT_EQ] = ACTIONS(4640),
    [anon_sym_GT_GT_EQ] = ACTIONS(4640),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4640),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4640),
    [anon_sym_AMP_AMP] = ACTIONS(4640),
    [anon_sym_PIPE_PIPE] = ACTIONS(4640),
    [anon_sym_QMARK_QMARK] = ACTIONS(4642),
    [anon_sym_from] = ACTIONS(4640),
    [anon_sym_join] = ACTIONS(4640),
    [anon_sym_on] = ACTIONS(4640),
    [anon_sym_equals] = ACTIONS(4640),
    [anon_sym_let] = ACTIONS(4640),
    [anon_sym_orderby] = ACTIONS(4640),
    [anon_sym_group] = ACTIONS(4640),
    [anon_sym_by] = ACTIONS(4640),
    [anon_sym_select] = ACTIONS(4640),
    [anon_sym_as] = ACTIONS(4640),
    [anon_sym_is] = ACTIONS(4640),
    [anon_sym_DASH_GT] = ACTIONS(4640),
    [anon_sym_with] = ACTIONS(4640),
    [aux_sym_preproc_if_token3] = ACTIONS(4640),
    [aux_sym_preproc_else_token1] = ACTIONS(4640),
    [aux_sym_preproc_elif_token1] = ACTIONS(4640),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3034] = {
    [sym_parameter_list] = STATE(9685),
    [sym_positional_pattern_clause] = STATE(3111),
    [sym_property_pattern_clause] = STATE(3172),
    [sym__variable_designation] = STATE(4162),
    [sym_parenthesized_variable_designation] = STATE(4153),
    [sym__lambda_parameters] = STATE(9890),
    [sym_identifier] = STATE(5933),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3034),
    [sym_preproc_endregion] = STATE(3034),
    [sym_preproc_line] = STATE(3034),
    [sym_preproc_pragma] = STATE(3034),
    [sym_preproc_nullable] = STATE(3034),
    [sym_preproc_error] = STATE(3034),
    [sym_preproc_warning] = STATE(3034),
    [sym_preproc_define] = STATE(3034),
    [sym_preproc_undef] = STATE(3034),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4341),
    [anon_sym_LPAREN] = ACTIONS(4341),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4345),
    [anon_sym_GT] = ACTIONS(4345),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4345),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4345),
    [anon_sym_PLUS_PLUS] = ACTIONS(4341),
    [anon_sym_DASH_DASH] = ACTIONS(4341),
    [anon_sym_PLUS] = ACTIONS(4345),
    [anon_sym_DASH] = ACTIONS(4345),
    [anon_sym_STAR] = ACTIONS(4341),
    [anon_sym_SLASH] = ACTIONS(4345),
    [anon_sym_PERCENT] = ACTIONS(4341),
    [anon_sym_CARET] = ACTIONS(4341),
    [anon_sym_PIPE] = ACTIONS(4345),
    [anon_sym_AMP] = ACTIONS(4345),
    [anon_sym_LT_LT] = ACTIONS(4341),
    [anon_sym_GT_GT] = ACTIONS(4345),
    [anon_sym_GT_GT_GT] = ACTIONS(4341),
    [anon_sym_EQ_EQ] = ACTIONS(4341),
    [anon_sym_BANG_EQ] = ACTIONS(4341),
    [anon_sym_GT_EQ] = ACTIONS(4341),
    [anon_sym_LT_EQ] = ACTIONS(4341),
    [anon_sym_DOT] = ACTIONS(4345),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_EQ_GT] = ACTIONS(4341),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4345),
    [anon_sym_when] = ACTIONS(4345),
    [sym_discard] = ACTIONS(4359),
    [anon_sym_DOT_DOT] = ACTIONS(4341),
    [anon_sym_and] = ACTIONS(4345),
    [anon_sym_or] = ACTIONS(4345),
    [anon_sym_AMP_AMP] = ACTIONS(4341),
    [anon_sym_PIPE_PIPE] = ACTIONS(4341),
    [anon_sym_QMARK_QMARK] = ACTIONS(4341),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4339),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4345),
    [anon_sym_is] = ACTIONS(4345),
    [anon_sym_DASH_GT] = ACTIONS(4341),
    [anon_sym_with] = ACTIONS(4345),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3035] = {
    [sym_parameter_list] = STATE(9685),
    [sym_positional_pattern_clause] = STATE(3106),
    [sym_property_pattern_clause] = STATE(3140),
    [sym__variable_designation] = STATE(4091),
    [sym_parenthesized_variable_designation] = STATE(3966),
    [sym__lambda_parameters] = STATE(9890),
    [sym_identifier] = STATE(4070),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3035),
    [sym_preproc_endregion] = STATE(3035),
    [sym_preproc_line] = STATE(3035),
    [sym_preproc_pragma] = STATE(3035),
    [sym_preproc_nullable] = STATE(3035),
    [sym_preproc_error] = STATE(3035),
    [sym_preproc_warning] = STATE(3035),
    [sym_preproc_define] = STATE(3035),
    [sym_preproc_undef] = STATE(3035),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4341),
    [anon_sym_COLON] = ACTIONS(4341),
    [anon_sym_LPAREN] = ACTIONS(4341),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4345),
    [anon_sym_GT] = ACTIONS(4345),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4345),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4345),
    [anon_sym_PLUS_PLUS] = ACTIONS(4341),
    [anon_sym_DASH_DASH] = ACTIONS(4341),
    [anon_sym_PLUS] = ACTIONS(4345),
    [anon_sym_DASH] = ACTIONS(4345),
    [anon_sym_STAR] = ACTIONS(4341),
    [anon_sym_SLASH] = ACTIONS(4345),
    [anon_sym_PERCENT] = ACTIONS(4341),
    [anon_sym_CARET] = ACTIONS(4341),
    [anon_sym_PIPE] = ACTIONS(4345),
    [anon_sym_AMP] = ACTIONS(4345),
    [anon_sym_LT_LT] = ACTIONS(4341),
    [anon_sym_GT_GT] = ACTIONS(4345),
    [anon_sym_GT_GT_GT] = ACTIONS(4341),
    [anon_sym_EQ_EQ] = ACTIONS(4341),
    [anon_sym_BANG_EQ] = ACTIONS(4341),
    [anon_sym_GT_EQ] = ACTIONS(4341),
    [anon_sym_LT_EQ] = ACTIONS(4341),
    [anon_sym_DOT] = ACTIONS(4345),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4345),
    [anon_sym_when] = ACTIONS(4345),
    [sym_discard] = ACTIONS(4347),
    [anon_sym_DOT_DOT] = ACTIONS(4341),
    [anon_sym_and] = ACTIONS(4345),
    [anon_sym_or] = ACTIONS(4345),
    [anon_sym_AMP_AMP] = ACTIONS(4341),
    [anon_sym_PIPE_PIPE] = ACTIONS(4341),
    [anon_sym_QMARK_QMARK] = ACTIONS(4341),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4345),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4345),
    [anon_sym_is] = ACTIONS(4345),
    [anon_sym_DASH_GT] = ACTIONS(4341),
    [anon_sym_with] = ACTIONS(4345),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3036] = {
    [sym_parameter_list] = STATE(9685),
    [sym_positional_pattern_clause] = STATE(3130),
    [sym_property_pattern_clause] = STATE(3173),
    [sym__variable_designation] = STATE(4551),
    [sym_parenthesized_variable_designation] = STATE(4748),
    [sym__lambda_parameters] = STATE(9890),
    [sym_identifier] = STATE(4500),
    [sym__reserved_identifier] = STATE(2928),
    [sym_preproc_region] = STATE(3036),
    [sym_preproc_endregion] = STATE(3036),
    [sym_preproc_line] = STATE(3036),
    [sym_preproc_pragma] = STATE(3036),
    [sym_preproc_nullable] = STATE(3036),
    [sym_preproc_error] = STATE(3036),
    [sym_preproc_warning] = STATE(3036),
    [sym_preproc_define] = STATE(3036),
    [sym_preproc_undef] = STATE(3036),
    [sym__identifier_token] = ACTIONS(4536),
    [anon_sym_alias] = ACTIONS(4538),
    [anon_sym_global] = ACTIONS(4538),
    [anon_sym_LBRACK] = ACTIONS(4341),
    [anon_sym_COMMA] = ACTIONS(4341),
    [anon_sym_LPAREN] = ACTIONS(4341),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_file] = ACTIONS(4538),
    [anon_sym_LT] = ACTIONS(4345),
    [anon_sym_GT] = ACTIONS(4345),
    [anon_sym_where] = ACTIONS(4345),
    [anon_sym_QMARK] = ACTIONS(4345),
    [anon_sym_notnull] = ACTIONS(4538),
    [anon_sym_unmanaged] = ACTIONS(4538),
    [anon_sym_BANG] = ACTIONS(4345),
    [anon_sym_PLUS_PLUS] = ACTIONS(4341),
    [anon_sym_DASH_DASH] = ACTIONS(4341),
    [anon_sym_PLUS] = ACTIONS(4345),
    [anon_sym_DASH] = ACTIONS(4345),
    [anon_sym_STAR] = ACTIONS(4341),
    [anon_sym_SLASH] = ACTIONS(4345),
    [anon_sym_PERCENT] = ACTIONS(4341),
    [anon_sym_CARET] = ACTIONS(4341),
    [anon_sym_PIPE] = ACTIONS(4345),
    [anon_sym_AMP] = ACTIONS(4345),
    [anon_sym_LT_LT] = ACTIONS(4341),
    [anon_sym_GT_GT] = ACTIONS(4345),
    [anon_sym_GT_GT_GT] = ACTIONS(4341),
    [anon_sym_EQ_EQ] = ACTIONS(4341),
    [anon_sym_BANG_EQ] = ACTIONS(4341),
    [anon_sym_GT_EQ] = ACTIONS(4341),
    [anon_sym_LT_EQ] = ACTIONS(4341),
    [anon_sym_DOT] = ACTIONS(4345),
    [anon_sym_scoped] = ACTIONS(4538),
    [anon_sym_var] = ACTIONS(4538),
    [anon_sym_yield] = ACTIONS(4538),
    [anon_sym_switch] = ACTIONS(4345),
    [anon_sym_when] = ACTIONS(4538),
    [sym_discard] = ACTIONS(4717),
    [anon_sym_DOT_DOT] = ACTIONS(4341),
    [anon_sym_and] = ACTIONS(4355),
    [anon_sym_or] = ACTIONS(4355),
    [anon_sym_AMP_AMP] = ACTIONS(4341),
    [anon_sym_PIPE_PIPE] = ACTIONS(4341),
    [anon_sym_QMARK_QMARK] = ACTIONS(4341),
    [anon_sym_from] = ACTIONS(4345),
    [anon_sym_into] = ACTIONS(4345),
    [anon_sym_join] = ACTIONS(4345),
    [anon_sym_on] = ACTIONS(4538),
    [anon_sym_equals] = ACTIONS(4538),
    [anon_sym_let] = ACTIONS(4345),
    [anon_sym_orderby] = ACTIONS(4345),
    [anon_sym_ascending] = ACTIONS(4345),
    [anon_sym_descending] = ACTIONS(4345),
    [anon_sym_group] = ACTIONS(4345),
    [anon_sym_by] = ACTIONS(4538),
    [anon_sym_select] = ACTIONS(4345),
    [anon_sym_as] = ACTIONS(4345),
    [anon_sym_is] = ACTIONS(4345),
    [anon_sym_DASH_GT] = ACTIONS(4341),
    [anon_sym_with] = ACTIONS(4345),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3037] = {
    [sym_parameter_list] = STATE(9685),
    [sym_positional_pattern_clause] = STATE(3138),
    [sym_property_pattern_clause] = STATE(3209),
    [sym__variable_designation] = STATE(4551),
    [sym_parenthesized_variable_designation] = STATE(4748),
    [sym__lambda_parameters] = STATE(9890),
    [sym_identifier] = STATE(4500),
    [sym__reserved_identifier] = STATE(2928),
    [sym_preproc_region] = STATE(3037),
    [sym_preproc_endregion] = STATE(3037),
    [sym_preproc_line] = STATE(3037),
    [sym_preproc_pragma] = STATE(3037),
    [sym_preproc_nullable] = STATE(3037),
    [sym_preproc_error] = STATE(3037),
    [sym_preproc_warning] = STATE(3037),
    [sym_preproc_define] = STATE(3037),
    [sym_preproc_undef] = STATE(3037),
    [sym__identifier_token] = ACTIONS(4536),
    [anon_sym_alias] = ACTIONS(4538),
    [anon_sym_global] = ACTIONS(4538),
    [anon_sym_LBRACK] = ACTIONS(4341),
    [anon_sym_COMMA] = ACTIONS(4341),
    [anon_sym_LPAREN] = ACTIONS(4341),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_file] = ACTIONS(4538),
    [anon_sym_LT] = ACTIONS(4345),
    [anon_sym_GT] = ACTIONS(4345),
    [anon_sym_where] = ACTIONS(4345),
    [anon_sym_QMARK] = ACTIONS(4345),
    [anon_sym_notnull] = ACTIONS(4538),
    [anon_sym_unmanaged] = ACTIONS(4538),
    [anon_sym_BANG] = ACTIONS(4345),
    [anon_sym_PLUS_PLUS] = ACTIONS(4341),
    [anon_sym_DASH_DASH] = ACTIONS(4341),
    [anon_sym_PLUS] = ACTIONS(4345),
    [anon_sym_DASH] = ACTIONS(4345),
    [anon_sym_STAR] = ACTIONS(4341),
    [anon_sym_SLASH] = ACTIONS(4345),
    [anon_sym_PERCENT] = ACTIONS(4341),
    [anon_sym_CARET] = ACTIONS(4341),
    [anon_sym_PIPE] = ACTIONS(4345),
    [anon_sym_AMP] = ACTIONS(4345),
    [anon_sym_LT_LT] = ACTIONS(4341),
    [anon_sym_GT_GT] = ACTIONS(4345),
    [anon_sym_GT_GT_GT] = ACTIONS(4341),
    [anon_sym_EQ_EQ] = ACTIONS(4341),
    [anon_sym_BANG_EQ] = ACTIONS(4341),
    [anon_sym_GT_EQ] = ACTIONS(4341),
    [anon_sym_LT_EQ] = ACTIONS(4341),
    [anon_sym_DOT] = ACTIONS(4345),
    [anon_sym_scoped] = ACTIONS(4538),
    [anon_sym_var] = ACTIONS(4538),
    [anon_sym_yield] = ACTIONS(4538),
    [anon_sym_switch] = ACTIONS(4345),
    [anon_sym_when] = ACTIONS(4538),
    [sym_discard] = ACTIONS(4717),
    [anon_sym_DOT_DOT] = ACTIONS(4341),
    [anon_sym_and] = ACTIONS(4355),
    [anon_sym_or] = ACTIONS(4355),
    [anon_sym_AMP_AMP] = ACTIONS(4341),
    [anon_sym_PIPE_PIPE] = ACTIONS(4341),
    [anon_sym_QMARK_QMARK] = ACTIONS(4341),
    [anon_sym_from] = ACTIONS(4345),
    [anon_sym_into] = ACTIONS(4538),
    [anon_sym_join] = ACTIONS(4345),
    [anon_sym_on] = ACTIONS(4538),
    [anon_sym_equals] = ACTIONS(4538),
    [anon_sym_let] = ACTIONS(4345),
    [anon_sym_orderby] = ACTIONS(4345),
    [anon_sym_ascending] = ACTIONS(4345),
    [anon_sym_descending] = ACTIONS(4345),
    [anon_sym_group] = ACTIONS(4345),
    [anon_sym_by] = ACTIONS(4538),
    [anon_sym_select] = ACTIONS(4345),
    [anon_sym_as] = ACTIONS(4345),
    [anon_sym_is] = ACTIONS(4345),
    [anon_sym_DASH_GT] = ACTIONS(4341),
    [anon_sym_with] = ACTIONS(4345),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3038] = {
    [sym_parameter_list] = STATE(9685),
    [sym_positional_pattern_clause] = STATE(3131),
    [sym_property_pattern_clause] = STATE(3212),
    [sym__variable_designation] = STATE(4162),
    [sym_parenthesized_variable_designation] = STATE(4153),
    [sym__lambda_parameters] = STATE(9890),
    [sym_identifier] = STATE(4163),
    [sym__reserved_identifier] = STATE(3911),
    [sym_preproc_region] = STATE(3038),
    [sym_preproc_endregion] = STATE(3038),
    [sym_preproc_line] = STATE(3038),
    [sym_preproc_pragma] = STATE(3038),
    [sym_preproc_nullable] = STATE(3038),
    [sym_preproc_error] = STATE(3038),
    [sym_preproc_warning] = STATE(3038),
    [sym_preproc_define] = STATE(3038),
    [sym_preproc_undef] = STATE(3038),
    [sym__identifier_token] = ACTIONS(4248),
    [anon_sym_alias] = ACTIONS(4250),
    [anon_sym_global] = ACTIONS(4250),
    [anon_sym_LBRACK] = ACTIONS(4341),
    [anon_sym_LPAREN] = ACTIONS(4341),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_file] = ACTIONS(4250),
    [anon_sym_LT] = ACTIONS(4345),
    [anon_sym_GT] = ACTIONS(4345),
    [anon_sym_in] = ACTIONS(4345),
    [anon_sym_where] = ACTIONS(4250),
    [anon_sym_QMARK] = ACTIONS(4345),
    [anon_sym_notnull] = ACTIONS(4250),
    [anon_sym_unmanaged] = ACTIONS(4250),
    [anon_sym_BANG] = ACTIONS(4345),
    [anon_sym_PLUS_PLUS] = ACTIONS(4341),
    [anon_sym_DASH_DASH] = ACTIONS(4341),
    [anon_sym_PLUS] = ACTIONS(4345),
    [anon_sym_DASH] = ACTIONS(4345),
    [anon_sym_STAR] = ACTIONS(4341),
    [anon_sym_SLASH] = ACTIONS(4345),
    [anon_sym_PERCENT] = ACTIONS(4341),
    [anon_sym_CARET] = ACTIONS(4341),
    [anon_sym_PIPE] = ACTIONS(4345),
    [anon_sym_AMP] = ACTIONS(4345),
    [anon_sym_LT_LT] = ACTIONS(4341),
    [anon_sym_GT_GT] = ACTIONS(4345),
    [anon_sym_GT_GT_GT] = ACTIONS(4341),
    [anon_sym_EQ_EQ] = ACTIONS(4341),
    [anon_sym_BANG_EQ] = ACTIONS(4341),
    [anon_sym_GT_EQ] = ACTIONS(4341),
    [anon_sym_LT_EQ] = ACTIONS(4341),
    [anon_sym_DOT] = ACTIONS(4345),
    [anon_sym_scoped] = ACTIONS(4250),
    [anon_sym_var] = ACTIONS(4250),
    [anon_sym_yield] = ACTIONS(4250),
    [anon_sym_switch] = ACTIONS(4345),
    [anon_sym_when] = ACTIONS(4250),
    [sym_discard] = ACTIONS(4359),
    [anon_sym_DOT_DOT] = ACTIONS(4341),
    [anon_sym_and] = ACTIONS(4345),
    [anon_sym_or] = ACTIONS(4345),
    [anon_sym_AMP_AMP] = ACTIONS(4341),
    [anon_sym_PIPE_PIPE] = ACTIONS(4341),
    [anon_sym_QMARK_QMARK] = ACTIONS(4341),
    [anon_sym_from] = ACTIONS(4250),
    [anon_sym_into] = ACTIONS(4250),
    [anon_sym_join] = ACTIONS(4250),
    [anon_sym_on] = ACTIONS(4250),
    [anon_sym_equals] = ACTIONS(4250),
    [anon_sym_let] = ACTIONS(4250),
    [anon_sym_orderby] = ACTIONS(4250),
    [anon_sym_ascending] = ACTIONS(4250),
    [anon_sym_descending] = ACTIONS(4250),
    [anon_sym_group] = ACTIONS(4250),
    [anon_sym_by] = ACTIONS(4250),
    [anon_sym_select] = ACTIONS(4250),
    [anon_sym_as] = ACTIONS(4345),
    [anon_sym_is] = ACTIONS(4345),
    [anon_sym_DASH_GT] = ACTIONS(4341),
    [anon_sym_with] = ACTIONS(4345),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3039] = {
    [sym_parameter_list] = STATE(9685),
    [sym_positional_pattern_clause] = STATE(3106),
    [sym_property_pattern_clause] = STATE(3140),
    [sym__variable_designation] = STATE(4091),
    [sym_parenthesized_variable_designation] = STATE(3966),
    [sym__lambda_parameters] = STATE(9890),
    [sym_identifier] = STATE(5933),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3039),
    [sym_preproc_endregion] = STATE(3039),
    [sym_preproc_line] = STATE(3039),
    [sym_preproc_pragma] = STATE(3039),
    [sym_preproc_nullable] = STATE(3039),
    [sym_preproc_error] = STATE(3039),
    [sym_preproc_warning] = STATE(3039),
    [sym_preproc_define] = STATE(3039),
    [sym_preproc_undef] = STATE(3039),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4341),
    [anon_sym_LPAREN] = ACTIONS(4341),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4345),
    [anon_sym_GT] = ACTIONS(4345),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4345),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4345),
    [anon_sym_PLUS_PLUS] = ACTIONS(4341),
    [anon_sym_DASH_DASH] = ACTIONS(4341),
    [anon_sym_PLUS] = ACTIONS(4345),
    [anon_sym_DASH] = ACTIONS(4345),
    [anon_sym_STAR] = ACTIONS(4341),
    [anon_sym_SLASH] = ACTIONS(4345),
    [anon_sym_PERCENT] = ACTIONS(4341),
    [anon_sym_CARET] = ACTIONS(4341),
    [anon_sym_PIPE] = ACTIONS(4345),
    [anon_sym_AMP] = ACTIONS(4345),
    [anon_sym_LT_LT] = ACTIONS(4341),
    [anon_sym_GT_GT] = ACTIONS(4345),
    [anon_sym_GT_GT_GT] = ACTIONS(4341),
    [anon_sym_EQ_EQ] = ACTIONS(4341),
    [anon_sym_BANG_EQ] = ACTIONS(4341),
    [anon_sym_GT_EQ] = ACTIONS(4341),
    [anon_sym_LT_EQ] = ACTIONS(4341),
    [anon_sym_DOT] = ACTIONS(4345),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_EQ_GT] = ACTIONS(4341),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4345),
    [anon_sym_when] = ACTIONS(4345),
    [sym_discard] = ACTIONS(4347),
    [anon_sym_DOT_DOT] = ACTIONS(4341),
    [anon_sym_and] = ACTIONS(4345),
    [anon_sym_or] = ACTIONS(4345),
    [anon_sym_AMP_AMP] = ACTIONS(4341),
    [anon_sym_PIPE_PIPE] = ACTIONS(4341),
    [anon_sym_QMARK_QMARK] = ACTIONS(4341),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4345),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4345),
    [anon_sym_is] = ACTIONS(4345),
    [anon_sym_DASH_GT] = ACTIONS(4341),
    [anon_sym_with] = ACTIONS(4345),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3040] = {
    [sym_parameter_list] = STATE(9685),
    [sym_positional_pattern_clause] = STATE(3130),
    [sym_property_pattern_clause] = STATE(3173),
    [sym__variable_designation] = STATE(4551),
    [sym_parenthesized_variable_designation] = STATE(4748),
    [sym__lambda_parameters] = STATE(9890),
    [sym_identifier] = STATE(4500),
    [sym__reserved_identifier] = STATE(2928),
    [sym_preproc_region] = STATE(3040),
    [sym_preproc_endregion] = STATE(3040),
    [sym_preproc_line] = STATE(3040),
    [sym_preproc_pragma] = STATE(3040),
    [sym_preproc_nullable] = STATE(3040),
    [sym_preproc_error] = STATE(3040),
    [sym_preproc_warning] = STATE(3040),
    [sym_preproc_define] = STATE(3040),
    [sym_preproc_undef] = STATE(3040),
    [sym__identifier_token] = ACTIONS(4536),
    [anon_sym_alias] = ACTIONS(4538),
    [anon_sym_global] = ACTIONS(4538),
    [anon_sym_LBRACK] = ACTIONS(4357),
    [anon_sym_COMMA] = ACTIONS(4357),
    [anon_sym_LPAREN] = ACTIONS(4357),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_file] = ACTIONS(4538),
    [anon_sym_LT] = ACTIONS(4355),
    [anon_sym_GT] = ACTIONS(4355),
    [anon_sym_where] = ACTIONS(4355),
    [anon_sym_QMARK] = ACTIONS(4355),
    [anon_sym_notnull] = ACTIONS(4538),
    [anon_sym_unmanaged] = ACTIONS(4538),
    [anon_sym_BANG] = ACTIONS(4355),
    [anon_sym_PLUS_PLUS] = ACTIONS(4357),
    [anon_sym_DASH_DASH] = ACTIONS(4357),
    [anon_sym_PLUS] = ACTIONS(4355),
    [anon_sym_DASH] = ACTIONS(4355),
    [anon_sym_STAR] = ACTIONS(4357),
    [anon_sym_SLASH] = ACTIONS(4355),
    [anon_sym_PERCENT] = ACTIONS(4357),
    [anon_sym_CARET] = ACTIONS(4357),
    [anon_sym_PIPE] = ACTIONS(4355),
    [anon_sym_AMP] = ACTIONS(4355),
    [anon_sym_LT_LT] = ACTIONS(4357),
    [anon_sym_GT_GT] = ACTIONS(4355),
    [anon_sym_GT_GT_GT] = ACTIONS(4357),
    [anon_sym_EQ_EQ] = ACTIONS(4357),
    [anon_sym_BANG_EQ] = ACTIONS(4357),
    [anon_sym_GT_EQ] = ACTIONS(4357),
    [anon_sym_LT_EQ] = ACTIONS(4357),
    [anon_sym_DOT] = ACTIONS(4355),
    [anon_sym_scoped] = ACTIONS(4538),
    [anon_sym_var] = ACTIONS(4538),
    [anon_sym_yield] = ACTIONS(4538),
    [anon_sym_switch] = ACTIONS(4355),
    [anon_sym_when] = ACTIONS(4538),
    [sym_discard] = ACTIONS(4717),
    [anon_sym_DOT_DOT] = ACTIONS(4357),
    [anon_sym_and] = ACTIONS(4355),
    [anon_sym_or] = ACTIONS(4355),
    [anon_sym_AMP_AMP] = ACTIONS(4357),
    [anon_sym_PIPE_PIPE] = ACTIONS(4357),
    [anon_sym_QMARK_QMARK] = ACTIONS(4357),
    [anon_sym_from] = ACTIONS(4355),
    [anon_sym_into] = ACTIONS(4355),
    [anon_sym_join] = ACTIONS(4355),
    [anon_sym_on] = ACTIONS(4538),
    [anon_sym_equals] = ACTIONS(4538),
    [anon_sym_let] = ACTIONS(4355),
    [anon_sym_orderby] = ACTIONS(4355),
    [anon_sym_ascending] = ACTIONS(4355),
    [anon_sym_descending] = ACTIONS(4355),
    [anon_sym_group] = ACTIONS(4355),
    [anon_sym_by] = ACTIONS(4538),
    [anon_sym_select] = ACTIONS(4355),
    [anon_sym_as] = ACTIONS(4355),
    [anon_sym_is] = ACTIONS(4355),
    [anon_sym_DASH_GT] = ACTIONS(4357),
    [anon_sym_with] = ACTIONS(4355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3041] = {
    [sym_parameter_list] = STATE(9685),
    [sym_positional_pattern_clause] = STATE(2842),
    [sym_property_pattern_clause] = STATE(2879),
    [sym__variable_designation] = STATE(4091),
    [sym_parenthesized_variable_designation] = STATE(3966),
    [sym__lambda_parameters] = STATE(9890),
    [sym_identifier] = STATE(5933),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3041),
    [sym_preproc_endregion] = STATE(3041),
    [sym_preproc_line] = STATE(3041),
    [sym_preproc_pragma] = STATE(3041),
    [sym_preproc_nullable] = STATE(3041),
    [sym_preproc_error] = STATE(3041),
    [sym_preproc_warning] = STATE(3041),
    [sym_preproc_define] = STATE(3041),
    [sym_preproc_undef] = STATE(3041),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4357),
    [anon_sym_LPAREN] = ACTIONS(4357),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4355),
    [anon_sym_GT] = ACTIONS(4355),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4355),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4355),
    [anon_sym_PLUS_PLUS] = ACTIONS(4357),
    [anon_sym_DASH_DASH] = ACTIONS(4357),
    [anon_sym_PLUS] = ACTIONS(4355),
    [anon_sym_DASH] = ACTIONS(4355),
    [anon_sym_STAR] = ACTIONS(4357),
    [anon_sym_SLASH] = ACTIONS(4355),
    [anon_sym_PERCENT] = ACTIONS(4357),
    [anon_sym_CARET] = ACTIONS(4357),
    [anon_sym_PIPE] = ACTIONS(4355),
    [anon_sym_AMP] = ACTIONS(4355),
    [anon_sym_LT_LT] = ACTIONS(4357),
    [anon_sym_GT_GT] = ACTIONS(4355),
    [anon_sym_GT_GT_GT] = ACTIONS(4357),
    [anon_sym_EQ_EQ] = ACTIONS(4357),
    [anon_sym_BANG_EQ] = ACTIONS(4357),
    [anon_sym_GT_EQ] = ACTIONS(4357),
    [anon_sym_LT_EQ] = ACTIONS(4357),
    [anon_sym_DOT] = ACTIONS(4355),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_EQ_GT] = ACTIONS(4357),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4355),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4347),
    [anon_sym_DOT_DOT] = ACTIONS(4357),
    [anon_sym_and] = ACTIONS(4355),
    [anon_sym_or] = ACTIONS(4355),
    [anon_sym_AMP_AMP] = ACTIONS(4357),
    [anon_sym_PIPE_PIPE] = ACTIONS(4357),
    [anon_sym_QMARK_QMARK] = ACTIONS(4357),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4355),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4355),
    [anon_sym_is] = ACTIONS(4355),
    [anon_sym_DASH_GT] = ACTIONS(4357),
    [anon_sym_with] = ACTIONS(4355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3042] = {
    [sym_parameter_list] = STATE(9685),
    [sym_positional_pattern_clause] = STATE(3106),
    [sym_property_pattern_clause] = STATE(3140),
    [sym__variable_designation] = STATE(4091),
    [sym_parenthesized_variable_designation] = STATE(3966),
    [sym__lambda_parameters] = STATE(9890),
    [sym_identifier] = STATE(5933),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3042),
    [sym_preproc_endregion] = STATE(3042),
    [sym_preproc_line] = STATE(3042),
    [sym_preproc_pragma] = STATE(3042),
    [sym_preproc_nullable] = STATE(3042),
    [sym_preproc_error] = STATE(3042),
    [sym_preproc_warning] = STATE(3042),
    [sym_preproc_define] = STATE(3042),
    [sym_preproc_undef] = STATE(3042),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4357),
    [anon_sym_LPAREN] = ACTIONS(4357),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4355),
    [anon_sym_GT] = ACTIONS(4355),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4355),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4355),
    [anon_sym_PLUS_PLUS] = ACTIONS(4357),
    [anon_sym_DASH_DASH] = ACTIONS(4357),
    [anon_sym_PLUS] = ACTIONS(4355),
    [anon_sym_DASH] = ACTIONS(4355),
    [anon_sym_STAR] = ACTIONS(4357),
    [anon_sym_SLASH] = ACTIONS(4355),
    [anon_sym_PERCENT] = ACTIONS(4357),
    [anon_sym_CARET] = ACTIONS(4357),
    [anon_sym_PIPE] = ACTIONS(4355),
    [anon_sym_AMP] = ACTIONS(4355),
    [anon_sym_LT_LT] = ACTIONS(4357),
    [anon_sym_GT_GT] = ACTIONS(4355),
    [anon_sym_GT_GT_GT] = ACTIONS(4357),
    [anon_sym_EQ_EQ] = ACTIONS(4357),
    [anon_sym_BANG_EQ] = ACTIONS(4357),
    [anon_sym_GT_EQ] = ACTIONS(4357),
    [anon_sym_LT_EQ] = ACTIONS(4357),
    [anon_sym_DOT] = ACTIONS(4355),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_EQ_GT] = ACTIONS(4357),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4355),
    [anon_sym_when] = ACTIONS(4355),
    [sym_discard] = ACTIONS(4347),
    [anon_sym_DOT_DOT] = ACTIONS(4357),
    [anon_sym_and] = ACTIONS(4355),
    [anon_sym_or] = ACTIONS(4355),
    [anon_sym_AMP_AMP] = ACTIONS(4357),
    [anon_sym_PIPE_PIPE] = ACTIONS(4357),
    [anon_sym_QMARK_QMARK] = ACTIONS(4357),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4355),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4355),
    [anon_sym_is] = ACTIONS(4355),
    [anon_sym_DASH_GT] = ACTIONS(4357),
    [anon_sym_with] = ACTIONS(4355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3043] = {
    [sym_parameter_list] = STATE(9685),
    [sym_positional_pattern_clause] = STATE(2854),
    [sym_property_pattern_clause] = STATE(2886),
    [sym__variable_designation] = STATE(4162),
    [sym_parenthesized_variable_designation] = STATE(4153),
    [sym__lambda_parameters] = STATE(9890),
    [sym_identifier] = STATE(5933),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3043),
    [sym_preproc_endregion] = STATE(3043),
    [sym_preproc_line] = STATE(3043),
    [sym_preproc_pragma] = STATE(3043),
    [sym_preproc_nullable] = STATE(3043),
    [sym_preproc_error] = STATE(3043),
    [sym_preproc_warning] = STATE(3043),
    [sym_preproc_define] = STATE(3043),
    [sym_preproc_undef] = STATE(3043),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4357),
    [anon_sym_LPAREN] = ACTIONS(4357),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4355),
    [anon_sym_GT] = ACTIONS(4355),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4355),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4355),
    [anon_sym_PLUS_PLUS] = ACTIONS(4357),
    [anon_sym_DASH_DASH] = ACTIONS(4357),
    [anon_sym_PLUS] = ACTIONS(4355),
    [anon_sym_DASH] = ACTIONS(4355),
    [anon_sym_STAR] = ACTIONS(4357),
    [anon_sym_SLASH] = ACTIONS(4355),
    [anon_sym_PERCENT] = ACTIONS(4357),
    [anon_sym_CARET] = ACTIONS(4357),
    [anon_sym_PIPE] = ACTIONS(4355),
    [anon_sym_AMP] = ACTIONS(4355),
    [anon_sym_LT_LT] = ACTIONS(4357),
    [anon_sym_GT_GT] = ACTIONS(4355),
    [anon_sym_GT_GT_GT] = ACTIONS(4357),
    [anon_sym_EQ_EQ] = ACTIONS(4357),
    [anon_sym_BANG_EQ] = ACTIONS(4357),
    [anon_sym_GT_EQ] = ACTIONS(4357),
    [anon_sym_LT_EQ] = ACTIONS(4357),
    [anon_sym_DOT] = ACTIONS(4355),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_EQ_GT] = ACTIONS(4357),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4355),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4359),
    [anon_sym_DOT_DOT] = ACTIONS(4357),
    [anon_sym_and] = ACTIONS(4355),
    [anon_sym_or] = ACTIONS(4355),
    [anon_sym_AMP_AMP] = ACTIONS(4357),
    [anon_sym_PIPE_PIPE] = ACTIONS(4357),
    [anon_sym_QMARK_QMARK] = ACTIONS(4357),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4339),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4355),
    [anon_sym_is] = ACTIONS(4355),
    [anon_sym_DASH_GT] = ACTIONS(4357),
    [anon_sym_with] = ACTIONS(4355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3044] = {
    [sym_parameter_list] = STATE(9685),
    [sym_positional_pattern_clause] = STATE(3111),
    [sym_property_pattern_clause] = STATE(3172),
    [sym__variable_designation] = STATE(4162),
    [sym_parenthesized_variable_designation] = STATE(4153),
    [sym__lambda_parameters] = STATE(9890),
    [sym_identifier] = STATE(5933),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3044),
    [sym_preproc_endregion] = STATE(3044),
    [sym_preproc_line] = STATE(3044),
    [sym_preproc_pragma] = STATE(3044),
    [sym_preproc_nullable] = STATE(3044),
    [sym_preproc_error] = STATE(3044),
    [sym_preproc_warning] = STATE(3044),
    [sym_preproc_define] = STATE(3044),
    [sym_preproc_undef] = STATE(3044),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4357),
    [anon_sym_LPAREN] = ACTIONS(4357),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4355),
    [anon_sym_GT] = ACTIONS(4355),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4355),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4355),
    [anon_sym_PLUS_PLUS] = ACTIONS(4357),
    [anon_sym_DASH_DASH] = ACTIONS(4357),
    [anon_sym_PLUS] = ACTIONS(4355),
    [anon_sym_DASH] = ACTIONS(4355),
    [anon_sym_STAR] = ACTIONS(4357),
    [anon_sym_SLASH] = ACTIONS(4355),
    [anon_sym_PERCENT] = ACTIONS(4357),
    [anon_sym_CARET] = ACTIONS(4357),
    [anon_sym_PIPE] = ACTIONS(4355),
    [anon_sym_AMP] = ACTIONS(4355),
    [anon_sym_LT_LT] = ACTIONS(4357),
    [anon_sym_GT_GT] = ACTIONS(4355),
    [anon_sym_GT_GT_GT] = ACTIONS(4357),
    [anon_sym_EQ_EQ] = ACTIONS(4357),
    [anon_sym_BANG_EQ] = ACTIONS(4357),
    [anon_sym_GT_EQ] = ACTIONS(4357),
    [anon_sym_LT_EQ] = ACTIONS(4357),
    [anon_sym_DOT] = ACTIONS(4355),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_EQ_GT] = ACTIONS(4357),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4355),
    [anon_sym_when] = ACTIONS(4355),
    [sym_discard] = ACTIONS(4359),
    [anon_sym_DOT_DOT] = ACTIONS(4357),
    [anon_sym_and] = ACTIONS(4355),
    [anon_sym_or] = ACTIONS(4355),
    [anon_sym_AMP_AMP] = ACTIONS(4357),
    [anon_sym_PIPE_PIPE] = ACTIONS(4357),
    [anon_sym_QMARK_QMARK] = ACTIONS(4357),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4339),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4355),
    [anon_sym_is] = ACTIONS(4355),
    [anon_sym_DASH_GT] = ACTIONS(4357),
    [anon_sym_with] = ACTIONS(4355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3045] = {
    [sym_parameter_list] = STATE(9685),
    [sym_positional_pattern_clause] = STATE(3138),
    [sym_property_pattern_clause] = STATE(3209),
    [sym__variable_designation] = STATE(4551),
    [sym_parenthesized_variable_designation] = STATE(4748),
    [sym__lambda_parameters] = STATE(9890),
    [sym_identifier] = STATE(4500),
    [sym__reserved_identifier] = STATE(2928),
    [sym_preproc_region] = STATE(3045),
    [sym_preproc_endregion] = STATE(3045),
    [sym_preproc_line] = STATE(3045),
    [sym_preproc_pragma] = STATE(3045),
    [sym_preproc_nullable] = STATE(3045),
    [sym_preproc_error] = STATE(3045),
    [sym_preproc_warning] = STATE(3045),
    [sym_preproc_define] = STATE(3045),
    [sym_preproc_undef] = STATE(3045),
    [sym__identifier_token] = ACTIONS(4536),
    [anon_sym_alias] = ACTIONS(4538),
    [anon_sym_global] = ACTIONS(4538),
    [anon_sym_LBRACK] = ACTIONS(4341),
    [anon_sym_COMMA] = ACTIONS(4341),
    [anon_sym_LPAREN] = ACTIONS(4341),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_file] = ACTIONS(4538),
    [anon_sym_LT] = ACTIONS(4345),
    [anon_sym_GT] = ACTIONS(4345),
    [anon_sym_where] = ACTIONS(4345),
    [anon_sym_QMARK] = ACTIONS(4345),
    [anon_sym_notnull] = ACTIONS(4538),
    [anon_sym_unmanaged] = ACTIONS(4538),
    [anon_sym_BANG] = ACTIONS(4345),
    [anon_sym_PLUS_PLUS] = ACTIONS(4341),
    [anon_sym_DASH_DASH] = ACTIONS(4341),
    [anon_sym_PLUS] = ACTIONS(4345),
    [anon_sym_DASH] = ACTIONS(4345),
    [anon_sym_STAR] = ACTIONS(4341),
    [anon_sym_SLASH] = ACTIONS(4345),
    [anon_sym_PERCENT] = ACTIONS(4341),
    [anon_sym_CARET] = ACTIONS(4341),
    [anon_sym_PIPE] = ACTIONS(4345),
    [anon_sym_AMP] = ACTIONS(4345),
    [anon_sym_LT_LT] = ACTIONS(4341),
    [anon_sym_GT_GT] = ACTIONS(4345),
    [anon_sym_GT_GT_GT] = ACTIONS(4341),
    [anon_sym_EQ_EQ] = ACTIONS(4341),
    [anon_sym_BANG_EQ] = ACTIONS(4341),
    [anon_sym_GT_EQ] = ACTIONS(4341),
    [anon_sym_LT_EQ] = ACTIONS(4341),
    [anon_sym_DOT] = ACTIONS(4345),
    [anon_sym_scoped] = ACTIONS(4538),
    [anon_sym_var] = ACTIONS(4538),
    [anon_sym_yield] = ACTIONS(4538),
    [anon_sym_switch] = ACTIONS(4345),
    [anon_sym_when] = ACTIONS(4538),
    [sym_discard] = ACTIONS(4717),
    [anon_sym_DOT_DOT] = ACTIONS(4341),
    [anon_sym_and] = ACTIONS(4345),
    [anon_sym_or] = ACTIONS(4345),
    [anon_sym_AMP_AMP] = ACTIONS(4341),
    [anon_sym_PIPE_PIPE] = ACTIONS(4341),
    [anon_sym_QMARK_QMARK] = ACTIONS(4341),
    [anon_sym_from] = ACTIONS(4345),
    [anon_sym_into] = ACTIONS(4538),
    [anon_sym_join] = ACTIONS(4345),
    [anon_sym_on] = ACTIONS(4538),
    [anon_sym_equals] = ACTIONS(4538),
    [anon_sym_let] = ACTIONS(4345),
    [anon_sym_orderby] = ACTIONS(4345),
    [anon_sym_ascending] = ACTIONS(4345),
    [anon_sym_descending] = ACTIONS(4345),
    [anon_sym_group] = ACTIONS(4345),
    [anon_sym_by] = ACTIONS(4538),
    [anon_sym_select] = ACTIONS(4345),
    [anon_sym_as] = ACTIONS(4345),
    [anon_sym_is] = ACTIONS(4345),
    [anon_sym_DASH_GT] = ACTIONS(4341),
    [anon_sym_with] = ACTIONS(4345),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3046] = {
    [sym_preproc_region] = STATE(3046),
    [sym_preproc_endregion] = STATE(3046),
    [sym_preproc_line] = STATE(3046),
    [sym_preproc_pragma] = STATE(3046),
    [sym_preproc_nullable] = STATE(3046),
    [sym_preproc_error] = STATE(3046),
    [sym_preproc_warning] = STATE(3046),
    [sym_preproc_define] = STATE(3046),
    [sym_preproc_undef] = STATE(3046),
    [anon_sym_SEMI] = ACTIONS(4707),
    [anon_sym_EQ] = ACTIONS(4709),
    [anon_sym_LBRACK] = ACTIONS(4707),
    [anon_sym_COLON] = ACTIONS(4707),
    [anon_sym_COMMA] = ACTIONS(4707),
    [anon_sym_RBRACK] = ACTIONS(4707),
    [anon_sym_LPAREN] = ACTIONS(4707),
    [anon_sym_RPAREN] = ACTIONS(4707),
    [anon_sym_RBRACE] = ACTIONS(4707),
    [anon_sym_LT] = ACTIONS(4709),
    [anon_sym_GT] = ACTIONS(4709),
    [anon_sym_in] = ACTIONS(4707),
    [anon_sym_where] = ACTIONS(4707),
    [anon_sym_QMARK] = ACTIONS(4709),
    [anon_sym_BANG] = ACTIONS(4709),
    [anon_sym_PLUS_PLUS] = ACTIONS(4707),
    [anon_sym_DASH_DASH] = ACTIONS(4707),
    [anon_sym_PLUS] = ACTIONS(4709),
    [anon_sym_DASH] = ACTIONS(4709),
    [anon_sym_STAR] = ACTIONS(4709),
    [anon_sym_SLASH] = ACTIONS(4709),
    [anon_sym_PERCENT] = ACTIONS(4709),
    [anon_sym_CARET] = ACTIONS(4709),
    [anon_sym_PIPE] = ACTIONS(4709),
    [anon_sym_AMP] = ACTIONS(4709),
    [anon_sym_LT_LT] = ACTIONS(4709),
    [anon_sym_GT_GT] = ACTIONS(4709),
    [anon_sym_GT_GT_GT] = ACTIONS(4709),
    [anon_sym_EQ_EQ] = ACTIONS(4707),
    [anon_sym_BANG_EQ] = ACTIONS(4707),
    [anon_sym_GT_EQ] = ACTIONS(4707),
    [anon_sym_LT_EQ] = ACTIONS(4707),
    [anon_sym_DOT] = ACTIONS(4709),
    [anon_sym_EQ_GT] = ACTIONS(4707),
    [anon_sym_switch] = ACTIONS(4707),
    [anon_sym_DOT_DOT] = ACTIONS(4707),
    [anon_sym_and] = ACTIONS(4707),
    [anon_sym_or] = ACTIONS(4709),
    [anon_sym_PLUS_EQ] = ACTIONS(4707),
    [anon_sym_DASH_EQ] = ACTIONS(4707),
    [anon_sym_STAR_EQ] = ACTIONS(4707),
    [anon_sym_SLASH_EQ] = ACTIONS(4707),
    [anon_sym_PERCENT_EQ] = ACTIONS(4707),
    [anon_sym_AMP_EQ] = ACTIONS(4707),
    [anon_sym_CARET_EQ] = ACTIONS(4707),
    [anon_sym_PIPE_EQ] = ACTIONS(4707),
    [anon_sym_LT_LT_EQ] = ACTIONS(4707),
    [anon_sym_GT_GT_EQ] = ACTIONS(4707),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4707),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4707),
    [anon_sym_AMP_AMP] = ACTIONS(4707),
    [anon_sym_PIPE_PIPE] = ACTIONS(4707),
    [anon_sym_QMARK_QMARK] = ACTIONS(4709),
    [anon_sym_from] = ACTIONS(4707),
    [anon_sym_join] = ACTIONS(4707),
    [anon_sym_on] = ACTIONS(4707),
    [anon_sym_equals] = ACTIONS(4707),
    [anon_sym_let] = ACTIONS(4707),
    [anon_sym_orderby] = ACTIONS(4707),
    [anon_sym_group] = ACTIONS(4707),
    [anon_sym_by] = ACTIONS(4707),
    [anon_sym_select] = ACTIONS(4707),
    [anon_sym_as] = ACTIONS(4707),
    [anon_sym_is] = ACTIONS(4707),
    [anon_sym_DASH_GT] = ACTIONS(4707),
    [anon_sym_with] = ACTIONS(4707),
    [aux_sym_preproc_if_token3] = ACTIONS(4707),
    [aux_sym_preproc_else_token1] = ACTIONS(4707),
    [aux_sym_preproc_elif_token1] = ACTIONS(4707),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3047] = {
    [sym_parameter_list] = STATE(9685),
    [sym_positional_pattern_clause] = STATE(3111),
    [sym_property_pattern_clause] = STATE(3172),
    [sym__variable_designation] = STATE(4162),
    [sym_parenthesized_variable_designation] = STATE(4153),
    [sym__lambda_parameters] = STATE(9890),
    [sym_identifier] = STATE(4163),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3047),
    [sym_preproc_endregion] = STATE(3047),
    [sym_preproc_line] = STATE(3047),
    [sym_preproc_pragma] = STATE(3047),
    [sym_preproc_nullable] = STATE(3047),
    [sym_preproc_error] = STATE(3047),
    [sym_preproc_warning] = STATE(3047),
    [sym_preproc_define] = STATE(3047),
    [sym_preproc_undef] = STATE(3047),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4357),
    [anon_sym_COLON] = ACTIONS(4357),
    [anon_sym_LPAREN] = ACTIONS(4357),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4355),
    [anon_sym_GT] = ACTIONS(4355),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4355),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4355),
    [anon_sym_PLUS_PLUS] = ACTIONS(4357),
    [anon_sym_DASH_DASH] = ACTIONS(4357),
    [anon_sym_PLUS] = ACTIONS(4355),
    [anon_sym_DASH] = ACTIONS(4355),
    [anon_sym_STAR] = ACTIONS(4357),
    [anon_sym_SLASH] = ACTIONS(4355),
    [anon_sym_PERCENT] = ACTIONS(4357),
    [anon_sym_CARET] = ACTIONS(4357),
    [anon_sym_PIPE] = ACTIONS(4355),
    [anon_sym_AMP] = ACTIONS(4355),
    [anon_sym_LT_LT] = ACTIONS(4357),
    [anon_sym_GT_GT] = ACTIONS(4355),
    [anon_sym_GT_GT_GT] = ACTIONS(4357),
    [anon_sym_EQ_EQ] = ACTIONS(4357),
    [anon_sym_BANG_EQ] = ACTIONS(4357),
    [anon_sym_GT_EQ] = ACTIONS(4357),
    [anon_sym_LT_EQ] = ACTIONS(4357),
    [anon_sym_DOT] = ACTIONS(4355),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4355),
    [anon_sym_when] = ACTIONS(4355),
    [sym_discard] = ACTIONS(4359),
    [anon_sym_DOT_DOT] = ACTIONS(4357),
    [anon_sym_and] = ACTIONS(4355),
    [anon_sym_or] = ACTIONS(4355),
    [anon_sym_AMP_AMP] = ACTIONS(4357),
    [anon_sym_PIPE_PIPE] = ACTIONS(4357),
    [anon_sym_QMARK_QMARK] = ACTIONS(4357),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4339),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4355),
    [anon_sym_is] = ACTIONS(4355),
    [anon_sym_DASH_GT] = ACTIONS(4357),
    [anon_sym_with] = ACTIONS(4355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3048] = {
    [sym_parameter_list] = STATE(9685),
    [sym_positional_pattern_clause] = STATE(2842),
    [sym_property_pattern_clause] = STATE(2879),
    [sym__variable_designation] = STATE(4091),
    [sym_parenthesized_variable_designation] = STATE(3966),
    [sym__lambda_parameters] = STATE(9890),
    [sym_identifier] = STATE(5933),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3048),
    [sym_preproc_endregion] = STATE(3048),
    [sym_preproc_line] = STATE(3048),
    [sym_preproc_pragma] = STATE(3048),
    [sym_preproc_nullable] = STATE(3048),
    [sym_preproc_error] = STATE(3048),
    [sym_preproc_warning] = STATE(3048),
    [sym_preproc_define] = STATE(3048),
    [sym_preproc_undef] = STATE(3048),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4341),
    [anon_sym_LPAREN] = ACTIONS(4341),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4345),
    [anon_sym_GT] = ACTIONS(4345),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4345),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4345),
    [anon_sym_PLUS_PLUS] = ACTIONS(4341),
    [anon_sym_DASH_DASH] = ACTIONS(4341),
    [anon_sym_PLUS] = ACTIONS(4345),
    [anon_sym_DASH] = ACTIONS(4345),
    [anon_sym_STAR] = ACTIONS(4341),
    [anon_sym_SLASH] = ACTIONS(4345),
    [anon_sym_PERCENT] = ACTIONS(4341),
    [anon_sym_CARET] = ACTIONS(4341),
    [anon_sym_PIPE] = ACTIONS(4345),
    [anon_sym_AMP] = ACTIONS(4345),
    [anon_sym_LT_LT] = ACTIONS(4341),
    [anon_sym_GT_GT] = ACTIONS(4345),
    [anon_sym_GT_GT_GT] = ACTIONS(4341),
    [anon_sym_EQ_EQ] = ACTIONS(4341),
    [anon_sym_BANG_EQ] = ACTIONS(4341),
    [anon_sym_GT_EQ] = ACTIONS(4341),
    [anon_sym_LT_EQ] = ACTIONS(4341),
    [anon_sym_DOT] = ACTIONS(4345),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_EQ_GT] = ACTIONS(4341),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4345),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4347),
    [anon_sym_DOT_DOT] = ACTIONS(4341),
    [anon_sym_and] = ACTIONS(4355),
    [anon_sym_or] = ACTIONS(4355),
    [anon_sym_AMP_AMP] = ACTIONS(4341),
    [anon_sym_PIPE_PIPE] = ACTIONS(4341),
    [anon_sym_QMARK_QMARK] = ACTIONS(4341),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4345),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4345),
    [anon_sym_is] = ACTIONS(4345),
    [anon_sym_DASH_GT] = ACTIONS(4341),
    [anon_sym_with] = ACTIONS(4345),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3049] = {
    [sym_preproc_region] = STATE(3049),
    [sym_preproc_endregion] = STATE(3049),
    [sym_preproc_line] = STATE(3049),
    [sym_preproc_pragma] = STATE(3049),
    [sym_preproc_nullable] = STATE(3049),
    [sym_preproc_error] = STATE(3049),
    [sym_preproc_warning] = STATE(3049),
    [sym_preproc_define] = STATE(3049),
    [sym_preproc_undef] = STATE(3049),
    [anon_sym_SEMI] = ACTIONS(4177),
    [anon_sym_EQ] = ACTIONS(4162),
    [anon_sym_LBRACK] = ACTIONS(4177),
    [anon_sym_COLON] = ACTIONS(4177),
    [anon_sym_COMMA] = ACTIONS(4177),
    [anon_sym_RBRACK] = ACTIONS(4177),
    [anon_sym_LPAREN] = ACTIONS(4177),
    [anon_sym_RPAREN] = ACTIONS(4177),
    [anon_sym_RBRACE] = ACTIONS(4177),
    [anon_sym_LT] = ACTIONS(4162),
    [anon_sym_GT] = ACTIONS(4162),
    [anon_sym_in] = ACTIONS(4177),
    [anon_sym_where] = ACTIONS(4177),
    [anon_sym_QMARK] = ACTIONS(4162),
    [anon_sym_BANG] = ACTIONS(4162),
    [anon_sym_PLUS_PLUS] = ACTIONS(4177),
    [anon_sym_DASH_DASH] = ACTIONS(4177),
    [anon_sym_PLUS] = ACTIONS(4162),
    [anon_sym_DASH] = ACTIONS(4162),
    [anon_sym_STAR] = ACTIONS(4162),
    [anon_sym_SLASH] = ACTIONS(4162),
    [anon_sym_PERCENT] = ACTIONS(4162),
    [anon_sym_CARET] = ACTIONS(4162),
    [anon_sym_PIPE] = ACTIONS(4162),
    [anon_sym_AMP] = ACTIONS(4162),
    [anon_sym_LT_LT] = ACTIONS(4162),
    [anon_sym_GT_GT] = ACTIONS(4162),
    [anon_sym_GT_GT_GT] = ACTIONS(4162),
    [anon_sym_EQ_EQ] = ACTIONS(4177),
    [anon_sym_BANG_EQ] = ACTIONS(4177),
    [anon_sym_GT_EQ] = ACTIONS(4177),
    [anon_sym_LT_EQ] = ACTIONS(4177),
    [anon_sym_DOT] = ACTIONS(4162),
    [anon_sym_EQ_GT] = ACTIONS(4177),
    [anon_sym_switch] = ACTIONS(4177),
    [anon_sym_DOT_DOT] = ACTIONS(4177),
    [anon_sym_and] = ACTIONS(4177),
    [anon_sym_or] = ACTIONS(4162),
    [anon_sym_PLUS_EQ] = ACTIONS(4177),
    [anon_sym_DASH_EQ] = ACTIONS(4177),
    [anon_sym_STAR_EQ] = ACTIONS(4177),
    [anon_sym_SLASH_EQ] = ACTIONS(4177),
    [anon_sym_PERCENT_EQ] = ACTIONS(4177),
    [anon_sym_AMP_EQ] = ACTIONS(4177),
    [anon_sym_CARET_EQ] = ACTIONS(4177),
    [anon_sym_PIPE_EQ] = ACTIONS(4177),
    [anon_sym_LT_LT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4177),
    [anon_sym_AMP_AMP] = ACTIONS(4177),
    [anon_sym_PIPE_PIPE] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK] = ACTIONS(4162),
    [anon_sym_from] = ACTIONS(4177),
    [anon_sym_join] = ACTIONS(4177),
    [anon_sym_on] = ACTIONS(4177),
    [anon_sym_equals] = ACTIONS(4177),
    [anon_sym_let] = ACTIONS(4177),
    [anon_sym_orderby] = ACTIONS(4177),
    [anon_sym_group] = ACTIONS(4177),
    [anon_sym_by] = ACTIONS(4177),
    [anon_sym_select] = ACTIONS(4177),
    [anon_sym_as] = ACTIONS(4177),
    [anon_sym_is] = ACTIONS(4177),
    [anon_sym_DASH_GT] = ACTIONS(4177),
    [anon_sym_with] = ACTIONS(4177),
    [aux_sym_preproc_if_token3] = ACTIONS(4177),
    [aux_sym_preproc_else_token1] = ACTIONS(4177),
    [aux_sym_preproc_elif_token1] = ACTIONS(4177),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3050] = {
    [sym_preproc_region] = STATE(3050),
    [sym_preproc_endregion] = STATE(3050),
    [sym_preproc_line] = STATE(3050),
    [sym_preproc_pragma] = STATE(3050),
    [sym_preproc_nullable] = STATE(3050),
    [sym_preproc_error] = STATE(3050),
    [sym_preproc_warning] = STATE(3050),
    [sym_preproc_define] = STATE(3050),
    [sym_preproc_undef] = STATE(3050),
    [anon_sym_SEMI] = ACTIONS(4666),
    [anon_sym_EQ] = ACTIONS(4668),
    [anon_sym_LBRACK] = ACTIONS(4666),
    [anon_sym_COLON] = ACTIONS(4666),
    [anon_sym_COMMA] = ACTIONS(4666),
    [anon_sym_RBRACK] = ACTIONS(4666),
    [anon_sym_LPAREN] = ACTIONS(4666),
    [anon_sym_RPAREN] = ACTIONS(4666),
    [anon_sym_RBRACE] = ACTIONS(4666),
    [anon_sym_LT] = ACTIONS(4668),
    [anon_sym_GT] = ACTIONS(4668),
    [anon_sym_in] = ACTIONS(4666),
    [anon_sym_where] = ACTIONS(4666),
    [anon_sym_QMARK] = ACTIONS(4668),
    [anon_sym_BANG] = ACTIONS(4668),
    [anon_sym_PLUS_PLUS] = ACTIONS(4666),
    [anon_sym_DASH_DASH] = ACTIONS(4666),
    [anon_sym_PLUS] = ACTIONS(4668),
    [anon_sym_DASH] = ACTIONS(4668),
    [anon_sym_STAR] = ACTIONS(4668),
    [anon_sym_SLASH] = ACTIONS(4668),
    [anon_sym_PERCENT] = ACTIONS(4668),
    [anon_sym_CARET] = ACTIONS(4668),
    [anon_sym_PIPE] = ACTIONS(4668),
    [anon_sym_AMP] = ACTIONS(4668),
    [anon_sym_LT_LT] = ACTIONS(4668),
    [anon_sym_GT_GT] = ACTIONS(4668),
    [anon_sym_GT_GT_GT] = ACTIONS(4668),
    [anon_sym_EQ_EQ] = ACTIONS(4666),
    [anon_sym_BANG_EQ] = ACTIONS(4666),
    [anon_sym_GT_EQ] = ACTIONS(4666),
    [anon_sym_LT_EQ] = ACTIONS(4666),
    [anon_sym_DOT] = ACTIONS(4668),
    [anon_sym_EQ_GT] = ACTIONS(4666),
    [anon_sym_switch] = ACTIONS(4666),
    [anon_sym_DOT_DOT] = ACTIONS(4666),
    [anon_sym_and] = ACTIONS(4666),
    [anon_sym_or] = ACTIONS(4668),
    [anon_sym_PLUS_EQ] = ACTIONS(4666),
    [anon_sym_DASH_EQ] = ACTIONS(4666),
    [anon_sym_STAR_EQ] = ACTIONS(4666),
    [anon_sym_SLASH_EQ] = ACTIONS(4666),
    [anon_sym_PERCENT_EQ] = ACTIONS(4666),
    [anon_sym_AMP_EQ] = ACTIONS(4666),
    [anon_sym_CARET_EQ] = ACTIONS(4666),
    [anon_sym_PIPE_EQ] = ACTIONS(4666),
    [anon_sym_LT_LT_EQ] = ACTIONS(4666),
    [anon_sym_GT_GT_EQ] = ACTIONS(4666),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4666),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4666),
    [anon_sym_AMP_AMP] = ACTIONS(4666),
    [anon_sym_PIPE_PIPE] = ACTIONS(4666),
    [anon_sym_QMARK_QMARK] = ACTIONS(4668),
    [anon_sym_from] = ACTIONS(4666),
    [anon_sym_join] = ACTIONS(4666),
    [anon_sym_on] = ACTIONS(4666),
    [anon_sym_equals] = ACTIONS(4666),
    [anon_sym_let] = ACTIONS(4666),
    [anon_sym_orderby] = ACTIONS(4666),
    [anon_sym_group] = ACTIONS(4666),
    [anon_sym_by] = ACTIONS(4666),
    [anon_sym_select] = ACTIONS(4666),
    [anon_sym_as] = ACTIONS(4666),
    [anon_sym_is] = ACTIONS(4666),
    [anon_sym_DASH_GT] = ACTIONS(4666),
    [anon_sym_with] = ACTIONS(4666),
    [aux_sym_preproc_if_token3] = ACTIONS(4666),
    [aux_sym_preproc_else_token1] = ACTIONS(4666),
    [aux_sym_preproc_elif_token1] = ACTIONS(4666),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3051] = {
    [sym_parameter_list] = STATE(9685),
    [sym_positional_pattern_clause] = STATE(2842),
    [sym_property_pattern_clause] = STATE(2879),
    [sym__variable_designation] = STATE(4091),
    [sym_parenthesized_variable_designation] = STATE(3966),
    [sym__lambda_parameters] = STATE(9890),
    [sym_identifier] = STATE(5933),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3051),
    [sym_preproc_endregion] = STATE(3051),
    [sym_preproc_line] = STATE(3051),
    [sym_preproc_pragma] = STATE(3051),
    [sym_preproc_nullable] = STATE(3051),
    [sym_preproc_error] = STATE(3051),
    [sym_preproc_warning] = STATE(3051),
    [sym_preproc_define] = STATE(3051),
    [sym_preproc_undef] = STATE(3051),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4341),
    [anon_sym_LPAREN] = ACTIONS(4341),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4345),
    [anon_sym_GT] = ACTIONS(4345),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4345),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4345),
    [anon_sym_PLUS_PLUS] = ACTIONS(4341),
    [anon_sym_DASH_DASH] = ACTIONS(4341),
    [anon_sym_PLUS] = ACTIONS(4345),
    [anon_sym_DASH] = ACTIONS(4345),
    [anon_sym_STAR] = ACTIONS(4341),
    [anon_sym_SLASH] = ACTIONS(4345),
    [anon_sym_PERCENT] = ACTIONS(4341),
    [anon_sym_CARET] = ACTIONS(4341),
    [anon_sym_PIPE] = ACTIONS(4345),
    [anon_sym_AMP] = ACTIONS(4345),
    [anon_sym_LT_LT] = ACTIONS(4341),
    [anon_sym_GT_GT] = ACTIONS(4345),
    [anon_sym_GT_GT_GT] = ACTIONS(4341),
    [anon_sym_EQ_EQ] = ACTIONS(4341),
    [anon_sym_BANG_EQ] = ACTIONS(4341),
    [anon_sym_GT_EQ] = ACTIONS(4341),
    [anon_sym_LT_EQ] = ACTIONS(4341),
    [anon_sym_DOT] = ACTIONS(4345),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_EQ_GT] = ACTIONS(4341),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4345),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4347),
    [anon_sym_DOT_DOT] = ACTIONS(4341),
    [anon_sym_and] = ACTIONS(4345),
    [anon_sym_or] = ACTIONS(4345),
    [anon_sym_AMP_AMP] = ACTIONS(4341),
    [anon_sym_PIPE_PIPE] = ACTIONS(4341),
    [anon_sym_QMARK_QMARK] = ACTIONS(4341),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4345),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4345),
    [anon_sym_is] = ACTIONS(4345),
    [anon_sym_DASH_GT] = ACTIONS(4341),
    [anon_sym_with] = ACTIONS(4345),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3052] = {
    [sym_parameter_list] = STATE(9685),
    [sym_positional_pattern_clause] = STATE(2854),
    [sym_property_pattern_clause] = STATE(2886),
    [sym__variable_designation] = STATE(4162),
    [sym_parenthesized_variable_designation] = STATE(4153),
    [sym__lambda_parameters] = STATE(9890),
    [sym_identifier] = STATE(5933),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3052),
    [sym_preproc_endregion] = STATE(3052),
    [sym_preproc_line] = STATE(3052),
    [sym_preproc_pragma] = STATE(3052),
    [sym_preproc_nullable] = STATE(3052),
    [sym_preproc_error] = STATE(3052),
    [sym_preproc_warning] = STATE(3052),
    [sym_preproc_define] = STATE(3052),
    [sym_preproc_undef] = STATE(3052),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4341),
    [anon_sym_LPAREN] = ACTIONS(4341),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4345),
    [anon_sym_GT] = ACTIONS(4345),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4345),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4345),
    [anon_sym_PLUS_PLUS] = ACTIONS(4341),
    [anon_sym_DASH_DASH] = ACTIONS(4341),
    [anon_sym_PLUS] = ACTIONS(4345),
    [anon_sym_DASH] = ACTIONS(4345),
    [anon_sym_STAR] = ACTIONS(4341),
    [anon_sym_SLASH] = ACTIONS(4345),
    [anon_sym_PERCENT] = ACTIONS(4341),
    [anon_sym_CARET] = ACTIONS(4341),
    [anon_sym_PIPE] = ACTIONS(4345),
    [anon_sym_AMP] = ACTIONS(4345),
    [anon_sym_LT_LT] = ACTIONS(4341),
    [anon_sym_GT_GT] = ACTIONS(4345),
    [anon_sym_GT_GT_GT] = ACTIONS(4341),
    [anon_sym_EQ_EQ] = ACTIONS(4341),
    [anon_sym_BANG_EQ] = ACTIONS(4341),
    [anon_sym_GT_EQ] = ACTIONS(4341),
    [anon_sym_LT_EQ] = ACTIONS(4341),
    [anon_sym_DOT] = ACTIONS(4345),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_EQ_GT] = ACTIONS(4341),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4345),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4359),
    [anon_sym_DOT_DOT] = ACTIONS(4341),
    [anon_sym_and] = ACTIONS(4355),
    [anon_sym_or] = ACTIONS(4355),
    [anon_sym_AMP_AMP] = ACTIONS(4341),
    [anon_sym_PIPE_PIPE] = ACTIONS(4341),
    [anon_sym_QMARK_QMARK] = ACTIONS(4341),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4339),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4345),
    [anon_sym_is] = ACTIONS(4345),
    [anon_sym_DASH_GT] = ACTIONS(4341),
    [anon_sym_with] = ACTIONS(4345),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3053] = {
    [sym_parameter_list] = STATE(9685),
    [sym_positional_pattern_clause] = STATE(3138),
    [sym_property_pattern_clause] = STATE(3209),
    [sym__variable_designation] = STATE(4551),
    [sym_parenthesized_variable_designation] = STATE(4748),
    [sym__lambda_parameters] = STATE(9890),
    [sym_identifier] = STATE(4500),
    [sym__reserved_identifier] = STATE(2928),
    [sym_preproc_region] = STATE(3053),
    [sym_preproc_endregion] = STATE(3053),
    [sym_preproc_line] = STATE(3053),
    [sym_preproc_pragma] = STATE(3053),
    [sym_preproc_nullable] = STATE(3053),
    [sym_preproc_error] = STATE(3053),
    [sym_preproc_warning] = STATE(3053),
    [sym_preproc_define] = STATE(3053),
    [sym_preproc_undef] = STATE(3053),
    [sym__identifier_token] = ACTIONS(4536),
    [anon_sym_alias] = ACTIONS(4538),
    [anon_sym_global] = ACTIONS(4538),
    [anon_sym_LBRACK] = ACTIONS(4357),
    [anon_sym_COMMA] = ACTIONS(4357),
    [anon_sym_LPAREN] = ACTIONS(4357),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_file] = ACTIONS(4538),
    [anon_sym_LT] = ACTIONS(4355),
    [anon_sym_GT] = ACTIONS(4355),
    [anon_sym_where] = ACTIONS(4355),
    [anon_sym_QMARK] = ACTIONS(4355),
    [anon_sym_notnull] = ACTIONS(4538),
    [anon_sym_unmanaged] = ACTIONS(4538),
    [anon_sym_BANG] = ACTIONS(4355),
    [anon_sym_PLUS_PLUS] = ACTIONS(4357),
    [anon_sym_DASH_DASH] = ACTIONS(4357),
    [anon_sym_PLUS] = ACTIONS(4355),
    [anon_sym_DASH] = ACTIONS(4355),
    [anon_sym_STAR] = ACTIONS(4357),
    [anon_sym_SLASH] = ACTIONS(4355),
    [anon_sym_PERCENT] = ACTIONS(4357),
    [anon_sym_CARET] = ACTIONS(4357),
    [anon_sym_PIPE] = ACTIONS(4355),
    [anon_sym_AMP] = ACTIONS(4355),
    [anon_sym_LT_LT] = ACTIONS(4357),
    [anon_sym_GT_GT] = ACTIONS(4355),
    [anon_sym_GT_GT_GT] = ACTIONS(4357),
    [anon_sym_EQ_EQ] = ACTIONS(4357),
    [anon_sym_BANG_EQ] = ACTIONS(4357),
    [anon_sym_GT_EQ] = ACTIONS(4357),
    [anon_sym_LT_EQ] = ACTIONS(4357),
    [anon_sym_DOT] = ACTIONS(4355),
    [anon_sym_scoped] = ACTIONS(4538),
    [anon_sym_var] = ACTIONS(4538),
    [anon_sym_yield] = ACTIONS(4538),
    [anon_sym_switch] = ACTIONS(4355),
    [anon_sym_when] = ACTIONS(4538),
    [sym_discard] = ACTIONS(4717),
    [anon_sym_DOT_DOT] = ACTIONS(4357),
    [anon_sym_and] = ACTIONS(4355),
    [anon_sym_or] = ACTIONS(4355),
    [anon_sym_AMP_AMP] = ACTIONS(4357),
    [anon_sym_PIPE_PIPE] = ACTIONS(4357),
    [anon_sym_QMARK_QMARK] = ACTIONS(4357),
    [anon_sym_from] = ACTIONS(4355),
    [anon_sym_into] = ACTIONS(4538),
    [anon_sym_join] = ACTIONS(4355),
    [anon_sym_on] = ACTIONS(4538),
    [anon_sym_equals] = ACTIONS(4538),
    [anon_sym_let] = ACTIONS(4355),
    [anon_sym_orderby] = ACTIONS(4355),
    [anon_sym_ascending] = ACTIONS(4355),
    [anon_sym_descending] = ACTIONS(4355),
    [anon_sym_group] = ACTIONS(4355),
    [anon_sym_by] = ACTIONS(4538),
    [anon_sym_select] = ACTIONS(4355),
    [anon_sym_as] = ACTIONS(4355),
    [anon_sym_is] = ACTIONS(4355),
    [anon_sym_DASH_GT] = ACTIONS(4357),
    [anon_sym_with] = ACTIONS(4355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3054] = {
    [sym_preproc_region] = STATE(3054),
    [sym_preproc_endregion] = STATE(3054),
    [sym_preproc_line] = STATE(3054),
    [sym_preproc_pragma] = STATE(3054),
    [sym_preproc_nullable] = STATE(3054),
    [sym_preproc_error] = STATE(3054),
    [sym_preproc_warning] = STATE(3054),
    [sym_preproc_define] = STATE(3054),
    [sym_preproc_undef] = STATE(3054),
    [anon_sym_SEMI] = ACTIONS(4683),
    [anon_sym_EQ] = ACTIONS(4685),
    [anon_sym_LBRACK] = ACTIONS(4683),
    [anon_sym_COLON] = ACTIONS(4683),
    [anon_sym_COMMA] = ACTIONS(4683),
    [anon_sym_RBRACK] = ACTIONS(4683),
    [anon_sym_LPAREN] = ACTIONS(4683),
    [anon_sym_RPAREN] = ACTIONS(4683),
    [anon_sym_RBRACE] = ACTIONS(4683),
    [anon_sym_LT] = ACTIONS(4685),
    [anon_sym_GT] = ACTIONS(4685),
    [anon_sym_in] = ACTIONS(4683),
    [anon_sym_where] = ACTIONS(4683),
    [anon_sym_QMARK] = ACTIONS(4685),
    [anon_sym_BANG] = ACTIONS(4685),
    [anon_sym_PLUS_PLUS] = ACTIONS(4683),
    [anon_sym_DASH_DASH] = ACTIONS(4683),
    [anon_sym_PLUS] = ACTIONS(4685),
    [anon_sym_DASH] = ACTIONS(4685),
    [anon_sym_STAR] = ACTIONS(4685),
    [anon_sym_SLASH] = ACTIONS(4685),
    [anon_sym_PERCENT] = ACTIONS(4685),
    [anon_sym_CARET] = ACTIONS(4685),
    [anon_sym_PIPE] = ACTIONS(4685),
    [anon_sym_AMP] = ACTIONS(4685),
    [anon_sym_LT_LT] = ACTIONS(4685),
    [anon_sym_GT_GT] = ACTIONS(4685),
    [anon_sym_GT_GT_GT] = ACTIONS(4685),
    [anon_sym_EQ_EQ] = ACTIONS(4683),
    [anon_sym_BANG_EQ] = ACTIONS(4683),
    [anon_sym_GT_EQ] = ACTIONS(4683),
    [anon_sym_LT_EQ] = ACTIONS(4683),
    [anon_sym_DOT] = ACTIONS(4685),
    [anon_sym_EQ_GT] = ACTIONS(4683),
    [anon_sym_switch] = ACTIONS(4683),
    [anon_sym_DOT_DOT] = ACTIONS(4683),
    [anon_sym_and] = ACTIONS(4683),
    [anon_sym_or] = ACTIONS(4685),
    [anon_sym_PLUS_EQ] = ACTIONS(4683),
    [anon_sym_DASH_EQ] = ACTIONS(4683),
    [anon_sym_STAR_EQ] = ACTIONS(4683),
    [anon_sym_SLASH_EQ] = ACTIONS(4683),
    [anon_sym_PERCENT_EQ] = ACTIONS(4683),
    [anon_sym_AMP_EQ] = ACTIONS(4683),
    [anon_sym_CARET_EQ] = ACTIONS(4683),
    [anon_sym_PIPE_EQ] = ACTIONS(4683),
    [anon_sym_LT_LT_EQ] = ACTIONS(4683),
    [anon_sym_GT_GT_EQ] = ACTIONS(4683),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4683),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4683),
    [anon_sym_AMP_AMP] = ACTIONS(4683),
    [anon_sym_PIPE_PIPE] = ACTIONS(4683),
    [anon_sym_QMARK_QMARK] = ACTIONS(4685),
    [anon_sym_from] = ACTIONS(4683),
    [anon_sym_join] = ACTIONS(4683),
    [anon_sym_on] = ACTIONS(4683),
    [anon_sym_equals] = ACTIONS(4683),
    [anon_sym_let] = ACTIONS(4683),
    [anon_sym_orderby] = ACTIONS(4683),
    [anon_sym_group] = ACTIONS(4683),
    [anon_sym_by] = ACTIONS(4683),
    [anon_sym_select] = ACTIONS(4683),
    [anon_sym_as] = ACTIONS(4683),
    [anon_sym_is] = ACTIONS(4683),
    [anon_sym_DASH_GT] = ACTIONS(4683),
    [anon_sym_with] = ACTIONS(4683),
    [aux_sym_preproc_if_token3] = ACTIONS(4683),
    [aux_sym_preproc_else_token1] = ACTIONS(4683),
    [aux_sym_preproc_elif_token1] = ACTIONS(4683),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3055] = {
    [sym_parameter_list] = STATE(9685),
    [sym_positional_pattern_clause] = STATE(3111),
    [sym_property_pattern_clause] = STATE(3172),
    [sym__variable_designation] = STATE(4162),
    [sym_parenthesized_variable_designation] = STATE(4153),
    [sym__lambda_parameters] = STATE(9890),
    [sym_identifier] = STATE(4163),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3055),
    [sym_preproc_endregion] = STATE(3055),
    [sym_preproc_line] = STATE(3055),
    [sym_preproc_pragma] = STATE(3055),
    [sym_preproc_nullable] = STATE(3055),
    [sym_preproc_error] = STATE(3055),
    [sym_preproc_warning] = STATE(3055),
    [sym_preproc_define] = STATE(3055),
    [sym_preproc_undef] = STATE(3055),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4341),
    [anon_sym_COLON] = ACTIONS(4341),
    [anon_sym_LPAREN] = ACTIONS(4341),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4345),
    [anon_sym_GT] = ACTIONS(4345),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4345),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4345),
    [anon_sym_PLUS_PLUS] = ACTIONS(4341),
    [anon_sym_DASH_DASH] = ACTIONS(4341),
    [anon_sym_PLUS] = ACTIONS(4345),
    [anon_sym_DASH] = ACTIONS(4345),
    [anon_sym_STAR] = ACTIONS(4341),
    [anon_sym_SLASH] = ACTIONS(4345),
    [anon_sym_PERCENT] = ACTIONS(4341),
    [anon_sym_CARET] = ACTIONS(4341),
    [anon_sym_PIPE] = ACTIONS(4345),
    [anon_sym_AMP] = ACTIONS(4345),
    [anon_sym_LT_LT] = ACTIONS(4341),
    [anon_sym_GT_GT] = ACTIONS(4345),
    [anon_sym_GT_GT_GT] = ACTIONS(4341),
    [anon_sym_EQ_EQ] = ACTIONS(4341),
    [anon_sym_BANG_EQ] = ACTIONS(4341),
    [anon_sym_GT_EQ] = ACTIONS(4341),
    [anon_sym_LT_EQ] = ACTIONS(4341),
    [anon_sym_DOT] = ACTIONS(4345),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4345),
    [anon_sym_when] = ACTIONS(4345),
    [sym_discard] = ACTIONS(4359),
    [anon_sym_DOT_DOT] = ACTIONS(4341),
    [anon_sym_and] = ACTIONS(4345),
    [anon_sym_or] = ACTIONS(4345),
    [anon_sym_AMP_AMP] = ACTIONS(4341),
    [anon_sym_PIPE_PIPE] = ACTIONS(4341),
    [anon_sym_QMARK_QMARK] = ACTIONS(4341),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4339),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4345),
    [anon_sym_is] = ACTIONS(4345),
    [anon_sym_DASH_GT] = ACTIONS(4341),
    [anon_sym_with] = ACTIONS(4345),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3056] = {
    [sym_preproc_region] = STATE(3056),
    [sym_preproc_endregion] = STATE(3056),
    [sym_preproc_line] = STATE(3056),
    [sym_preproc_pragma] = STATE(3056),
    [sym_preproc_nullable] = STATE(3056),
    [sym_preproc_error] = STATE(3056),
    [sym_preproc_warning] = STATE(3056),
    [sym_preproc_define] = STATE(3056),
    [sym_preproc_undef] = STATE(3056),
    [anon_sym_SEMI] = ACTIONS(4699),
    [anon_sym_EQ] = ACTIONS(4701),
    [anon_sym_LBRACK] = ACTIONS(4699),
    [anon_sym_COLON] = ACTIONS(4699),
    [anon_sym_COMMA] = ACTIONS(4699),
    [anon_sym_RBRACK] = ACTIONS(4699),
    [anon_sym_LPAREN] = ACTIONS(4699),
    [anon_sym_RPAREN] = ACTIONS(4699),
    [anon_sym_RBRACE] = ACTIONS(4699),
    [anon_sym_LT] = ACTIONS(4701),
    [anon_sym_GT] = ACTIONS(4701),
    [anon_sym_in] = ACTIONS(4699),
    [anon_sym_where] = ACTIONS(4699),
    [anon_sym_QMARK] = ACTIONS(4701),
    [anon_sym_BANG] = ACTIONS(4701),
    [anon_sym_PLUS_PLUS] = ACTIONS(4699),
    [anon_sym_DASH_DASH] = ACTIONS(4699),
    [anon_sym_PLUS] = ACTIONS(4701),
    [anon_sym_DASH] = ACTIONS(4701),
    [anon_sym_STAR] = ACTIONS(4701),
    [anon_sym_SLASH] = ACTIONS(4701),
    [anon_sym_PERCENT] = ACTIONS(4701),
    [anon_sym_CARET] = ACTIONS(4701),
    [anon_sym_PIPE] = ACTIONS(4701),
    [anon_sym_AMP] = ACTIONS(4701),
    [anon_sym_LT_LT] = ACTIONS(4701),
    [anon_sym_GT_GT] = ACTIONS(4701),
    [anon_sym_GT_GT_GT] = ACTIONS(4701),
    [anon_sym_EQ_EQ] = ACTIONS(4699),
    [anon_sym_BANG_EQ] = ACTIONS(4699),
    [anon_sym_GT_EQ] = ACTIONS(4699),
    [anon_sym_LT_EQ] = ACTIONS(4699),
    [anon_sym_DOT] = ACTIONS(4701),
    [anon_sym_EQ_GT] = ACTIONS(4699),
    [anon_sym_switch] = ACTIONS(4699),
    [anon_sym_DOT_DOT] = ACTIONS(4699),
    [anon_sym_and] = ACTIONS(4699),
    [anon_sym_or] = ACTIONS(4701),
    [anon_sym_PLUS_EQ] = ACTIONS(4699),
    [anon_sym_DASH_EQ] = ACTIONS(4699),
    [anon_sym_STAR_EQ] = ACTIONS(4699),
    [anon_sym_SLASH_EQ] = ACTIONS(4699),
    [anon_sym_PERCENT_EQ] = ACTIONS(4699),
    [anon_sym_AMP_EQ] = ACTIONS(4699),
    [anon_sym_CARET_EQ] = ACTIONS(4699),
    [anon_sym_PIPE_EQ] = ACTIONS(4699),
    [anon_sym_LT_LT_EQ] = ACTIONS(4699),
    [anon_sym_GT_GT_EQ] = ACTIONS(4699),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4699),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4699),
    [anon_sym_AMP_AMP] = ACTIONS(4699),
    [anon_sym_PIPE_PIPE] = ACTIONS(4699),
    [anon_sym_QMARK_QMARK] = ACTIONS(4701),
    [anon_sym_from] = ACTIONS(4699),
    [anon_sym_join] = ACTIONS(4699),
    [anon_sym_on] = ACTIONS(4699),
    [anon_sym_equals] = ACTIONS(4699),
    [anon_sym_let] = ACTIONS(4699),
    [anon_sym_orderby] = ACTIONS(4699),
    [anon_sym_group] = ACTIONS(4699),
    [anon_sym_by] = ACTIONS(4699),
    [anon_sym_select] = ACTIONS(4699),
    [anon_sym_as] = ACTIONS(4699),
    [anon_sym_is] = ACTIONS(4699),
    [anon_sym_DASH_GT] = ACTIONS(4699),
    [anon_sym_with] = ACTIONS(4699),
    [aux_sym_preproc_if_token3] = ACTIONS(4699),
    [aux_sym_preproc_else_token1] = ACTIONS(4699),
    [aux_sym_preproc_elif_token1] = ACTIONS(4699),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3057] = {
    [sym_parameter_list] = STATE(9685),
    [sym_positional_pattern_clause] = STATE(2854),
    [sym_property_pattern_clause] = STATE(2886),
    [sym__variable_designation] = STATE(4162),
    [sym_parenthesized_variable_designation] = STATE(4153),
    [sym__lambda_parameters] = STATE(9890),
    [sym_identifier] = STATE(5933),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3057),
    [sym_preproc_endregion] = STATE(3057),
    [sym_preproc_line] = STATE(3057),
    [sym_preproc_pragma] = STATE(3057),
    [sym_preproc_nullable] = STATE(3057),
    [sym_preproc_error] = STATE(3057),
    [sym_preproc_warning] = STATE(3057),
    [sym_preproc_define] = STATE(3057),
    [sym_preproc_undef] = STATE(3057),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4341),
    [anon_sym_LPAREN] = ACTIONS(4341),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4345),
    [anon_sym_GT] = ACTIONS(4345),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4345),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4345),
    [anon_sym_PLUS_PLUS] = ACTIONS(4341),
    [anon_sym_DASH_DASH] = ACTIONS(4341),
    [anon_sym_PLUS] = ACTIONS(4345),
    [anon_sym_DASH] = ACTIONS(4345),
    [anon_sym_STAR] = ACTIONS(4341),
    [anon_sym_SLASH] = ACTIONS(4345),
    [anon_sym_PERCENT] = ACTIONS(4341),
    [anon_sym_CARET] = ACTIONS(4341),
    [anon_sym_PIPE] = ACTIONS(4345),
    [anon_sym_AMP] = ACTIONS(4345),
    [anon_sym_LT_LT] = ACTIONS(4341),
    [anon_sym_GT_GT] = ACTIONS(4345),
    [anon_sym_GT_GT_GT] = ACTIONS(4341),
    [anon_sym_EQ_EQ] = ACTIONS(4341),
    [anon_sym_BANG_EQ] = ACTIONS(4341),
    [anon_sym_GT_EQ] = ACTIONS(4341),
    [anon_sym_LT_EQ] = ACTIONS(4341),
    [anon_sym_DOT] = ACTIONS(4345),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_EQ_GT] = ACTIONS(4341),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4345),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4359),
    [anon_sym_DOT_DOT] = ACTIONS(4341),
    [anon_sym_and] = ACTIONS(4345),
    [anon_sym_or] = ACTIONS(4345),
    [anon_sym_AMP_AMP] = ACTIONS(4341),
    [anon_sym_PIPE_PIPE] = ACTIONS(4341),
    [anon_sym_QMARK_QMARK] = ACTIONS(4341),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4339),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4345),
    [anon_sym_is] = ACTIONS(4345),
    [anon_sym_DASH_GT] = ACTIONS(4341),
    [anon_sym_with] = ACTIONS(4345),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3058] = {
    [sym_parameter_list] = STATE(9685),
    [sym_positional_pattern_clause] = STATE(3161),
    [sym_property_pattern_clause] = STATE(3442),
    [sym__variable_designation] = STATE(5035),
    [sym_parenthesized_variable_designation] = STATE(5027),
    [sym__lambda_parameters] = STATE(9890),
    [sym_identifier] = STATE(4954),
    [sym__reserved_identifier] = STATE(3625),
    [sym_preproc_region] = STATE(3058),
    [sym_preproc_endregion] = STATE(3058),
    [sym_preproc_line] = STATE(3058),
    [sym_preproc_pragma] = STATE(3058),
    [sym_preproc_nullable] = STATE(3058),
    [sym_preproc_error] = STATE(3058),
    [sym_preproc_warning] = STATE(3058),
    [sym_preproc_define] = STATE(3058),
    [sym_preproc_undef] = STATE(3058),
    [sym__identifier_token] = ACTIONS(4349),
    [anon_sym_alias] = ACTIONS(4351),
    [anon_sym_global] = ACTIONS(4351),
    [anon_sym_LBRACK] = ACTIONS(4341),
    [anon_sym_LPAREN] = ACTIONS(4341),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_file] = ACTIONS(4351),
    [anon_sym_LT] = ACTIONS(4345),
    [anon_sym_GT] = ACTIONS(4345),
    [anon_sym_where] = ACTIONS(4345),
    [anon_sym_QMARK] = ACTIONS(4345),
    [anon_sym_notnull] = ACTIONS(4351),
    [anon_sym_unmanaged] = ACTIONS(4351),
    [anon_sym_BANG] = ACTIONS(4345),
    [anon_sym_PLUS_PLUS] = ACTIONS(4341),
    [anon_sym_DASH_DASH] = ACTIONS(4341),
    [anon_sym_PLUS] = ACTIONS(4345),
    [anon_sym_DASH] = ACTIONS(4345),
    [anon_sym_STAR] = ACTIONS(4341),
    [anon_sym_SLASH] = ACTIONS(4345),
    [anon_sym_PERCENT] = ACTIONS(4341),
    [anon_sym_CARET] = ACTIONS(4341),
    [anon_sym_PIPE] = ACTIONS(4345),
    [anon_sym_AMP] = ACTIONS(4345),
    [anon_sym_LT_LT] = ACTIONS(4341),
    [anon_sym_GT_GT] = ACTIONS(4345),
    [anon_sym_GT_GT_GT] = ACTIONS(4341),
    [anon_sym_EQ_EQ] = ACTIONS(4341),
    [anon_sym_BANG_EQ] = ACTIONS(4341),
    [anon_sym_GT_EQ] = ACTIONS(4341),
    [anon_sym_LT_EQ] = ACTIONS(4341),
    [anon_sym_DOT] = ACTIONS(4345),
    [anon_sym_scoped] = ACTIONS(4351),
    [anon_sym_var] = ACTIONS(4351),
    [anon_sym_yield] = ACTIONS(4351),
    [anon_sym_switch] = ACTIONS(4345),
    [anon_sym_when] = ACTIONS(4351),
    [sym_discard] = ACTIONS(4719),
    [anon_sym_DOT_DOT] = ACTIONS(4341),
    [anon_sym_and] = ACTIONS(4345),
    [anon_sym_or] = ACTIONS(4345),
    [anon_sym_AMP_AMP] = ACTIONS(4341),
    [anon_sym_PIPE_PIPE] = ACTIONS(4341),
    [anon_sym_QMARK_QMARK] = ACTIONS(4341),
    [anon_sym_from] = ACTIONS(4345),
    [anon_sym_into] = ACTIONS(4351),
    [anon_sym_join] = ACTIONS(4345),
    [anon_sym_on] = ACTIONS(4351),
    [anon_sym_equals] = ACTIONS(4351),
    [anon_sym_let] = ACTIONS(4345),
    [anon_sym_orderby] = ACTIONS(4345),
    [anon_sym_ascending] = ACTIONS(4351),
    [anon_sym_descending] = ACTIONS(4351),
    [anon_sym_group] = ACTIONS(4345),
    [anon_sym_by] = ACTIONS(4351),
    [anon_sym_select] = ACTIONS(4345),
    [anon_sym_as] = ACTIONS(4345),
    [anon_sym_is] = ACTIONS(4345),
    [anon_sym_DASH_GT] = ACTIONS(4341),
    [anon_sym_with] = ACTIONS(4345),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3059] = {
    [sym_parameter_list] = STATE(9685),
    [sym_positional_pattern_clause] = STATE(3167),
    [sym_property_pattern_clause] = STATE(3381),
    [sym__variable_designation] = STATE(4162),
    [sym_parenthesized_variable_designation] = STATE(4153),
    [sym__lambda_parameters] = STATE(9890),
    [sym_identifier] = STATE(4163),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3059),
    [sym_preproc_endregion] = STATE(3059),
    [sym_preproc_line] = STATE(3059),
    [sym_preproc_pragma] = STATE(3059),
    [sym_preproc_nullable] = STATE(3059),
    [sym_preproc_error] = STATE(3059),
    [sym_preproc_warning] = STATE(3059),
    [sym_preproc_define] = STATE(3059),
    [sym_preproc_undef] = STATE(3059),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4357),
    [anon_sym_LPAREN] = ACTIONS(4357),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4355),
    [anon_sym_GT] = ACTIONS(4355),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4355),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4355),
    [anon_sym_PLUS_PLUS] = ACTIONS(4357),
    [anon_sym_DASH_DASH] = ACTIONS(4357),
    [anon_sym_PLUS] = ACTIONS(4355),
    [anon_sym_DASH] = ACTIONS(4355),
    [anon_sym_STAR] = ACTIONS(4357),
    [anon_sym_SLASH] = ACTIONS(4355),
    [anon_sym_PERCENT] = ACTIONS(4357),
    [anon_sym_CARET] = ACTIONS(4357),
    [anon_sym_PIPE] = ACTIONS(4355),
    [anon_sym_AMP] = ACTIONS(4355),
    [anon_sym_LT_LT] = ACTIONS(4357),
    [anon_sym_GT_GT] = ACTIONS(4355),
    [anon_sym_GT_GT_GT] = ACTIONS(4357),
    [anon_sym_EQ_EQ] = ACTIONS(4357),
    [anon_sym_BANG_EQ] = ACTIONS(4357),
    [anon_sym_GT_EQ] = ACTIONS(4357),
    [anon_sym_LT_EQ] = ACTIONS(4357),
    [anon_sym_DOT] = ACTIONS(4355),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4355),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4359),
    [anon_sym_DOT_DOT] = ACTIONS(4357),
    [anon_sym_and] = ACTIONS(4355),
    [anon_sym_or] = ACTIONS(4355),
    [anon_sym_AMP_AMP] = ACTIONS(4357),
    [anon_sym_PIPE_PIPE] = ACTIONS(4357),
    [anon_sym_QMARK_QMARK] = ACTIONS(4357),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4339),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4355),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4355),
    [anon_sym_is] = ACTIONS(4355),
    [anon_sym_DASH_GT] = ACTIONS(4357),
    [anon_sym_with] = ACTIONS(4355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3060] = {
    [sym_parameter_list] = STATE(9685),
    [sym_positional_pattern_clause] = STATE(3153),
    [sym_property_pattern_clause] = STATE(3430),
    [sym__variable_designation] = STATE(4091),
    [sym_parenthesized_variable_designation] = STATE(3966),
    [sym__lambda_parameters] = STATE(9890),
    [sym_identifier] = STATE(4070),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3060),
    [sym_preproc_endregion] = STATE(3060),
    [sym_preproc_line] = STATE(3060),
    [sym_preproc_pragma] = STATE(3060),
    [sym_preproc_nullable] = STATE(3060),
    [sym_preproc_error] = STATE(3060),
    [sym_preproc_warning] = STATE(3060),
    [sym_preproc_define] = STATE(3060),
    [sym_preproc_undef] = STATE(3060),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4341),
    [anon_sym_LPAREN] = ACTIONS(4341),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4345),
    [anon_sym_GT] = ACTIONS(4345),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4345),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4345),
    [anon_sym_PLUS_PLUS] = ACTIONS(4341),
    [anon_sym_DASH_DASH] = ACTIONS(4341),
    [anon_sym_PLUS] = ACTIONS(4345),
    [anon_sym_DASH] = ACTIONS(4345),
    [anon_sym_STAR] = ACTIONS(4341),
    [anon_sym_SLASH] = ACTIONS(4345),
    [anon_sym_PERCENT] = ACTIONS(4341),
    [anon_sym_CARET] = ACTIONS(4341),
    [anon_sym_PIPE] = ACTIONS(4345),
    [anon_sym_AMP] = ACTIONS(4345),
    [anon_sym_LT_LT] = ACTIONS(4341),
    [anon_sym_GT_GT] = ACTIONS(4345),
    [anon_sym_GT_GT_GT] = ACTIONS(4341),
    [anon_sym_EQ_EQ] = ACTIONS(4341),
    [anon_sym_BANG_EQ] = ACTIONS(4341),
    [anon_sym_GT_EQ] = ACTIONS(4341),
    [anon_sym_LT_EQ] = ACTIONS(4341),
    [anon_sym_DOT] = ACTIONS(4345),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4345),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4347),
    [anon_sym_DOT_DOT] = ACTIONS(4341),
    [anon_sym_and] = ACTIONS(4345),
    [anon_sym_or] = ACTIONS(4345),
    [anon_sym_AMP_AMP] = ACTIONS(4341),
    [anon_sym_PIPE_PIPE] = ACTIONS(4341),
    [anon_sym_QMARK_QMARK] = ACTIONS(4341),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4345),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4345),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4345),
    [anon_sym_is] = ACTIONS(4345),
    [anon_sym_DASH_GT] = ACTIONS(4341),
    [anon_sym_with] = ACTIONS(4345),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3061] = {
    [sym_parameter_list] = STATE(9685),
    [sym_positional_pattern_clause] = STATE(3161),
    [sym_property_pattern_clause] = STATE(3442),
    [sym__variable_designation] = STATE(5035),
    [sym_parenthesized_variable_designation] = STATE(5027),
    [sym__lambda_parameters] = STATE(9890),
    [sym_identifier] = STATE(4954),
    [sym__reserved_identifier] = STATE(3625),
    [sym_preproc_region] = STATE(3061),
    [sym_preproc_endregion] = STATE(3061),
    [sym_preproc_line] = STATE(3061),
    [sym_preproc_pragma] = STATE(3061),
    [sym_preproc_nullable] = STATE(3061),
    [sym_preproc_error] = STATE(3061),
    [sym_preproc_warning] = STATE(3061),
    [sym_preproc_define] = STATE(3061),
    [sym_preproc_undef] = STATE(3061),
    [sym__identifier_token] = ACTIONS(4349),
    [anon_sym_alias] = ACTIONS(4351),
    [anon_sym_global] = ACTIONS(4351),
    [anon_sym_LBRACK] = ACTIONS(4341),
    [anon_sym_LPAREN] = ACTIONS(4341),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_file] = ACTIONS(4351),
    [anon_sym_LT] = ACTIONS(4345),
    [anon_sym_GT] = ACTIONS(4345),
    [anon_sym_where] = ACTIONS(4345),
    [anon_sym_QMARK] = ACTIONS(4345),
    [anon_sym_notnull] = ACTIONS(4351),
    [anon_sym_unmanaged] = ACTIONS(4351),
    [anon_sym_BANG] = ACTIONS(4345),
    [anon_sym_PLUS_PLUS] = ACTIONS(4341),
    [anon_sym_DASH_DASH] = ACTIONS(4341),
    [anon_sym_PLUS] = ACTIONS(4345),
    [anon_sym_DASH] = ACTIONS(4345),
    [anon_sym_STAR] = ACTIONS(4341),
    [anon_sym_SLASH] = ACTIONS(4345),
    [anon_sym_PERCENT] = ACTIONS(4341),
    [anon_sym_CARET] = ACTIONS(4341),
    [anon_sym_PIPE] = ACTIONS(4345),
    [anon_sym_AMP] = ACTIONS(4345),
    [anon_sym_LT_LT] = ACTIONS(4341),
    [anon_sym_GT_GT] = ACTIONS(4345),
    [anon_sym_GT_GT_GT] = ACTIONS(4341),
    [anon_sym_EQ_EQ] = ACTIONS(4341),
    [anon_sym_BANG_EQ] = ACTIONS(4341),
    [anon_sym_GT_EQ] = ACTIONS(4341),
    [anon_sym_LT_EQ] = ACTIONS(4341),
    [anon_sym_DOT] = ACTIONS(4345),
    [anon_sym_scoped] = ACTIONS(4351),
    [anon_sym_var] = ACTIONS(4351),
    [anon_sym_yield] = ACTIONS(4351),
    [anon_sym_switch] = ACTIONS(4345),
    [anon_sym_when] = ACTIONS(4351),
    [sym_discard] = ACTIONS(4719),
    [anon_sym_DOT_DOT] = ACTIONS(4341),
    [anon_sym_and] = ACTIONS(4355),
    [anon_sym_or] = ACTIONS(4355),
    [anon_sym_AMP_AMP] = ACTIONS(4341),
    [anon_sym_PIPE_PIPE] = ACTIONS(4341),
    [anon_sym_QMARK_QMARK] = ACTIONS(4341),
    [anon_sym_from] = ACTIONS(4345),
    [anon_sym_into] = ACTIONS(4351),
    [anon_sym_join] = ACTIONS(4345),
    [anon_sym_on] = ACTIONS(4351),
    [anon_sym_equals] = ACTIONS(4351),
    [anon_sym_let] = ACTIONS(4345),
    [anon_sym_orderby] = ACTIONS(4345),
    [anon_sym_ascending] = ACTIONS(4351),
    [anon_sym_descending] = ACTIONS(4351),
    [anon_sym_group] = ACTIONS(4345),
    [anon_sym_by] = ACTIONS(4351),
    [anon_sym_select] = ACTIONS(4345),
    [anon_sym_as] = ACTIONS(4345),
    [anon_sym_is] = ACTIONS(4345),
    [anon_sym_DASH_GT] = ACTIONS(4341),
    [anon_sym_with] = ACTIONS(4345),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3062] = {
    [sym_parameter_list] = STATE(9685),
    [sym_positional_pattern_clause] = STATE(3154),
    [sym_property_pattern_clause] = STATE(3374),
    [sym__variable_designation] = STATE(4162),
    [sym_parenthesized_variable_designation] = STATE(4153),
    [sym__lambda_parameters] = STATE(9890),
    [sym_identifier] = STATE(4163),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3062),
    [sym_preproc_endregion] = STATE(3062),
    [sym_preproc_line] = STATE(3062),
    [sym_preproc_pragma] = STATE(3062),
    [sym_preproc_nullable] = STATE(3062),
    [sym_preproc_error] = STATE(3062),
    [sym_preproc_warning] = STATE(3062),
    [sym_preproc_define] = STATE(3062),
    [sym_preproc_undef] = STATE(3062),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4341),
    [anon_sym_LPAREN] = ACTIONS(4341),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4345),
    [anon_sym_GT] = ACTIONS(4345),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4345),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4345),
    [anon_sym_PLUS_PLUS] = ACTIONS(4341),
    [anon_sym_DASH_DASH] = ACTIONS(4341),
    [anon_sym_PLUS] = ACTIONS(4345),
    [anon_sym_DASH] = ACTIONS(4345),
    [anon_sym_STAR] = ACTIONS(4341),
    [anon_sym_SLASH] = ACTIONS(4345),
    [anon_sym_PERCENT] = ACTIONS(4341),
    [anon_sym_CARET] = ACTIONS(4341),
    [anon_sym_PIPE] = ACTIONS(4345),
    [anon_sym_AMP] = ACTIONS(4345),
    [anon_sym_LT_LT] = ACTIONS(4341),
    [anon_sym_GT_GT] = ACTIONS(4345),
    [anon_sym_GT_GT_GT] = ACTIONS(4341),
    [anon_sym_EQ_EQ] = ACTIONS(4341),
    [anon_sym_BANG_EQ] = ACTIONS(4341),
    [anon_sym_GT_EQ] = ACTIONS(4341),
    [anon_sym_LT_EQ] = ACTIONS(4341),
    [anon_sym_DOT] = ACTIONS(4345),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4345),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4359),
    [anon_sym_DOT_DOT] = ACTIONS(4341),
    [anon_sym_and] = ACTIONS(4345),
    [anon_sym_or] = ACTIONS(4345),
    [anon_sym_AMP_AMP] = ACTIONS(4341),
    [anon_sym_PIPE_PIPE] = ACTIONS(4341),
    [anon_sym_QMARK_QMARK] = ACTIONS(4341),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4339),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4345),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4345),
    [anon_sym_is] = ACTIONS(4345),
    [anon_sym_DASH_GT] = ACTIONS(4341),
    [anon_sym_with] = ACTIONS(4345),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3063] = {
    [sym_parameter_list] = STATE(9685),
    [sym_positional_pattern_clause] = STATE(3162),
    [sym_property_pattern_clause] = STATE(3278),
    [sym__variable_designation] = STATE(4162),
    [sym_parenthesized_variable_designation] = STATE(4153),
    [sym__lambda_parameters] = STATE(9890),
    [sym_identifier] = STATE(4163),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3063),
    [sym_preproc_endregion] = STATE(3063),
    [sym_preproc_line] = STATE(3063),
    [sym_preproc_pragma] = STATE(3063),
    [sym_preproc_nullable] = STATE(3063),
    [sym_preproc_error] = STATE(3063),
    [sym_preproc_warning] = STATE(3063),
    [sym_preproc_define] = STATE(3063),
    [sym_preproc_undef] = STATE(3063),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4341),
    [anon_sym_LPAREN] = ACTIONS(4341),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4345),
    [anon_sym_GT] = ACTIONS(4345),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4345),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4345),
    [anon_sym_PLUS_PLUS] = ACTIONS(4341),
    [anon_sym_DASH_DASH] = ACTIONS(4341),
    [anon_sym_PLUS] = ACTIONS(4345),
    [anon_sym_DASH] = ACTIONS(4345),
    [anon_sym_STAR] = ACTIONS(4341),
    [anon_sym_SLASH] = ACTIONS(4345),
    [anon_sym_PERCENT] = ACTIONS(4341),
    [anon_sym_CARET] = ACTIONS(4341),
    [anon_sym_PIPE] = ACTIONS(4345),
    [anon_sym_AMP] = ACTIONS(4345),
    [anon_sym_LT_LT] = ACTIONS(4341),
    [anon_sym_GT_GT] = ACTIONS(4345),
    [anon_sym_GT_GT_GT] = ACTIONS(4341),
    [anon_sym_EQ_EQ] = ACTIONS(4341),
    [anon_sym_BANG_EQ] = ACTIONS(4341),
    [anon_sym_GT_EQ] = ACTIONS(4341),
    [anon_sym_LT_EQ] = ACTIONS(4341),
    [anon_sym_DOT] = ACTIONS(4345),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4345),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4359),
    [anon_sym_DOT_DOT] = ACTIONS(4341),
    [anon_sym_and] = ACTIONS(4345),
    [anon_sym_or] = ACTIONS(4345),
    [anon_sym_AMP_AMP] = ACTIONS(4341),
    [anon_sym_PIPE_PIPE] = ACTIONS(4341),
    [anon_sym_QMARK_QMARK] = ACTIONS(4341),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4339),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4345),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4345),
    [anon_sym_is] = ACTIONS(4345),
    [anon_sym_DASH_GT] = ACTIONS(4341),
    [anon_sym_with] = ACTIONS(4345),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3064] = {
    [sym_parameter_list] = STATE(9685),
    [sym_positional_pattern_clause] = STATE(3153),
    [sym_property_pattern_clause] = STATE(3430),
    [sym__variable_designation] = STATE(4091),
    [sym_parenthesized_variable_designation] = STATE(3966),
    [sym__lambda_parameters] = STATE(9890),
    [sym_identifier] = STATE(4070),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3064),
    [sym_preproc_endregion] = STATE(3064),
    [sym_preproc_line] = STATE(3064),
    [sym_preproc_pragma] = STATE(3064),
    [sym_preproc_nullable] = STATE(3064),
    [sym_preproc_error] = STATE(3064),
    [sym_preproc_warning] = STATE(3064),
    [sym_preproc_define] = STATE(3064),
    [sym_preproc_undef] = STATE(3064),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4357),
    [anon_sym_LPAREN] = ACTIONS(4357),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4355),
    [anon_sym_GT] = ACTIONS(4355),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4355),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4355),
    [anon_sym_PLUS_PLUS] = ACTIONS(4357),
    [anon_sym_DASH_DASH] = ACTIONS(4357),
    [anon_sym_PLUS] = ACTIONS(4355),
    [anon_sym_DASH] = ACTIONS(4355),
    [anon_sym_STAR] = ACTIONS(4357),
    [anon_sym_SLASH] = ACTIONS(4355),
    [anon_sym_PERCENT] = ACTIONS(4357),
    [anon_sym_CARET] = ACTIONS(4357),
    [anon_sym_PIPE] = ACTIONS(4355),
    [anon_sym_AMP] = ACTIONS(4355),
    [anon_sym_LT_LT] = ACTIONS(4357),
    [anon_sym_GT_GT] = ACTIONS(4355),
    [anon_sym_GT_GT_GT] = ACTIONS(4357),
    [anon_sym_EQ_EQ] = ACTIONS(4357),
    [anon_sym_BANG_EQ] = ACTIONS(4357),
    [anon_sym_GT_EQ] = ACTIONS(4357),
    [anon_sym_LT_EQ] = ACTIONS(4357),
    [anon_sym_DOT] = ACTIONS(4355),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4355),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4347),
    [anon_sym_DOT_DOT] = ACTIONS(4357),
    [anon_sym_and] = ACTIONS(4355),
    [anon_sym_or] = ACTIONS(4355),
    [anon_sym_AMP_AMP] = ACTIONS(4357),
    [anon_sym_PIPE_PIPE] = ACTIONS(4357),
    [anon_sym_QMARK_QMARK] = ACTIONS(4357),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4355),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4355),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4355),
    [anon_sym_is] = ACTIONS(4355),
    [anon_sym_DASH_GT] = ACTIONS(4357),
    [anon_sym_with] = ACTIONS(4355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3065] = {
    [sym_parameter_list] = STATE(9685),
    [sym_positional_pattern_clause] = STATE(3154),
    [sym_property_pattern_clause] = STATE(3374),
    [sym__variable_designation] = STATE(4162),
    [sym_parenthesized_variable_designation] = STATE(4153),
    [sym__lambda_parameters] = STATE(9890),
    [sym_identifier] = STATE(4163),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3065),
    [sym_preproc_endregion] = STATE(3065),
    [sym_preproc_line] = STATE(3065),
    [sym_preproc_pragma] = STATE(3065),
    [sym_preproc_nullable] = STATE(3065),
    [sym_preproc_error] = STATE(3065),
    [sym_preproc_warning] = STATE(3065),
    [sym_preproc_define] = STATE(3065),
    [sym_preproc_undef] = STATE(3065),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4357),
    [anon_sym_LPAREN] = ACTIONS(4357),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4355),
    [anon_sym_GT] = ACTIONS(4355),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4355),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4355),
    [anon_sym_PLUS_PLUS] = ACTIONS(4357),
    [anon_sym_DASH_DASH] = ACTIONS(4357),
    [anon_sym_PLUS] = ACTIONS(4355),
    [anon_sym_DASH] = ACTIONS(4355),
    [anon_sym_STAR] = ACTIONS(4357),
    [anon_sym_SLASH] = ACTIONS(4355),
    [anon_sym_PERCENT] = ACTIONS(4357),
    [anon_sym_CARET] = ACTIONS(4357),
    [anon_sym_PIPE] = ACTIONS(4355),
    [anon_sym_AMP] = ACTIONS(4355),
    [anon_sym_LT_LT] = ACTIONS(4357),
    [anon_sym_GT_GT] = ACTIONS(4355),
    [anon_sym_GT_GT_GT] = ACTIONS(4357),
    [anon_sym_EQ_EQ] = ACTIONS(4357),
    [anon_sym_BANG_EQ] = ACTIONS(4357),
    [anon_sym_GT_EQ] = ACTIONS(4357),
    [anon_sym_LT_EQ] = ACTIONS(4357),
    [anon_sym_DOT] = ACTIONS(4355),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4355),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4359),
    [anon_sym_DOT_DOT] = ACTIONS(4357),
    [anon_sym_and] = ACTIONS(4355),
    [anon_sym_or] = ACTIONS(4355),
    [anon_sym_AMP_AMP] = ACTIONS(4357),
    [anon_sym_PIPE_PIPE] = ACTIONS(4357),
    [anon_sym_QMARK_QMARK] = ACTIONS(4357),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4339),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4355),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4355),
    [anon_sym_is] = ACTIONS(4355),
    [anon_sym_DASH_GT] = ACTIONS(4357),
    [anon_sym_with] = ACTIONS(4355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3066] = {
    [sym__name] = STATE(3748),
    [sym_alias_qualified_name] = STATE(3680),
    [sym__simple_name] = STATE(3680),
    [sym_qualified_name] = STATE(3680),
    [sym_generic_name] = STATE(3648),
    [sym_ref_type] = STATE(3643),
    [sym__scoped_base_type] = STATE(3647),
    [sym_identifier] = STATE(3590),
    [sym__reserved_identifier] = STATE(3625),
    [sym_preproc_region] = STATE(3066),
    [sym_preproc_endregion] = STATE(3066),
    [sym_preproc_line] = STATE(3066),
    [sym_preproc_pragma] = STATE(3066),
    [sym_preproc_nullable] = STATE(3066),
    [sym_preproc_error] = STATE(3066),
    [sym_preproc_warning] = STATE(3066),
    [sym_preproc_define] = STATE(3066),
    [sym_preproc_undef] = STATE(3066),
    [sym__identifier_token] = ACTIONS(4349),
    [anon_sym_alias] = ACTIONS(4351),
    [anon_sym_global] = ACTIONS(4351),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_LPAREN] = ACTIONS(3993),
    [anon_sym_ref] = ACTIONS(4721),
    [anon_sym_LBRACE] = ACTIONS(3993),
    [anon_sym_file] = ACTIONS(4351),
    [anon_sym_LT] = ACTIONS(3995),
    [anon_sym_GT] = ACTIONS(3995),
    [anon_sym_where] = ACTIONS(4351),
    [anon_sym_QMARK] = ACTIONS(3995),
    [anon_sym_notnull] = ACTIONS(4351),
    [anon_sym_unmanaged] = ACTIONS(4351),
    [anon_sym_BANG] = ACTIONS(3995),
    [anon_sym_PLUS_PLUS] = ACTIONS(3993),
    [anon_sym_DASH_DASH] = ACTIONS(3993),
    [anon_sym_PLUS] = ACTIONS(3995),
    [anon_sym_DASH] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3993),
    [anon_sym_SLASH] = ACTIONS(3995),
    [anon_sym_PERCENT] = ACTIONS(3993),
    [anon_sym_CARET] = ACTIONS(3993),
    [anon_sym_PIPE] = ACTIONS(3995),
    [anon_sym_AMP] = ACTIONS(3995),
    [anon_sym_LT_LT] = ACTIONS(3993),
    [anon_sym_GT_GT] = ACTIONS(3995),
    [anon_sym_GT_GT_GT] = ACTIONS(3993),
    [anon_sym_EQ_EQ] = ACTIONS(3993),
    [anon_sym_BANG_EQ] = ACTIONS(3993),
    [anon_sym_GT_EQ] = ACTIONS(3993),
    [anon_sym_LT_EQ] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3995),
    [anon_sym_scoped] = ACTIONS(4351),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(4351),
    [anon_sym_yield] = ACTIONS(4351),
    [anon_sym_switch] = ACTIONS(3995),
    [anon_sym_when] = ACTIONS(4351),
    [anon_sym_DOT_DOT] = ACTIONS(3993),
    [anon_sym_AMP_AMP] = ACTIONS(3993),
    [anon_sym_PIPE_PIPE] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK] = ACTIONS(3993),
    [anon_sym_from] = ACTIONS(4351),
    [anon_sym_into] = ACTIONS(4351),
    [anon_sym_join] = ACTIONS(4351),
    [anon_sym_on] = ACTIONS(4351),
    [anon_sym_equals] = ACTIONS(4680),
    [anon_sym_let] = ACTIONS(4351),
    [anon_sym_orderby] = ACTIONS(4351),
    [anon_sym_ascending] = ACTIONS(4351),
    [anon_sym_descending] = ACTIONS(4351),
    [anon_sym_group] = ACTIONS(4351),
    [anon_sym_by] = ACTIONS(4351),
    [anon_sym_select] = ACTIONS(4351),
    [anon_sym_as] = ACTIONS(3995),
    [anon_sym_is] = ACTIONS(3995),
    [anon_sym_DASH_GT] = ACTIONS(3993),
    [anon_sym_with] = ACTIONS(3995),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3067] = {
    [sym_parameter_list] = STATE(9685),
    [sym_positional_pattern_clause] = STATE(3153),
    [sym_property_pattern_clause] = STATE(3430),
    [sym__variable_designation] = STATE(4091),
    [sym_parenthesized_variable_designation] = STATE(3966),
    [sym__lambda_parameters] = STATE(9890),
    [sym_identifier] = STATE(4070),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3067),
    [sym_preproc_endregion] = STATE(3067),
    [sym_preproc_line] = STATE(3067),
    [sym_preproc_pragma] = STATE(3067),
    [sym_preproc_nullable] = STATE(3067),
    [sym_preproc_error] = STATE(3067),
    [sym_preproc_warning] = STATE(3067),
    [sym_preproc_define] = STATE(3067),
    [sym_preproc_undef] = STATE(3067),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4341),
    [anon_sym_LPAREN] = ACTIONS(4341),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4345),
    [anon_sym_GT] = ACTIONS(4345),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4345),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4345),
    [anon_sym_PLUS_PLUS] = ACTIONS(4341),
    [anon_sym_DASH_DASH] = ACTIONS(4341),
    [anon_sym_PLUS] = ACTIONS(4345),
    [anon_sym_DASH] = ACTIONS(4345),
    [anon_sym_STAR] = ACTIONS(4341),
    [anon_sym_SLASH] = ACTIONS(4345),
    [anon_sym_PERCENT] = ACTIONS(4341),
    [anon_sym_CARET] = ACTIONS(4341),
    [anon_sym_PIPE] = ACTIONS(4345),
    [anon_sym_AMP] = ACTIONS(4345),
    [anon_sym_LT_LT] = ACTIONS(4341),
    [anon_sym_GT_GT] = ACTIONS(4345),
    [anon_sym_GT_GT_GT] = ACTIONS(4341),
    [anon_sym_EQ_EQ] = ACTIONS(4341),
    [anon_sym_BANG_EQ] = ACTIONS(4341),
    [anon_sym_GT_EQ] = ACTIONS(4341),
    [anon_sym_LT_EQ] = ACTIONS(4341),
    [anon_sym_DOT] = ACTIONS(4345),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4345),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4347),
    [anon_sym_DOT_DOT] = ACTIONS(4341),
    [anon_sym_and] = ACTIONS(4355),
    [anon_sym_or] = ACTIONS(4355),
    [anon_sym_AMP_AMP] = ACTIONS(4341),
    [anon_sym_PIPE_PIPE] = ACTIONS(4341),
    [anon_sym_QMARK_QMARK] = ACTIONS(4341),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4345),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4345),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4345),
    [anon_sym_is] = ACTIONS(4345),
    [anon_sym_DASH_GT] = ACTIONS(4341),
    [anon_sym_with] = ACTIONS(4345),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3068] = {
    [sym_parameter_list] = STATE(9685),
    [sym_positional_pattern_clause] = STATE(3167),
    [sym_property_pattern_clause] = STATE(3381),
    [sym__variable_designation] = STATE(4162),
    [sym_parenthesized_variable_designation] = STATE(4153),
    [sym__lambda_parameters] = STATE(9890),
    [sym_identifier] = STATE(4163),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3068),
    [sym_preproc_endregion] = STATE(3068),
    [sym_preproc_line] = STATE(3068),
    [sym_preproc_pragma] = STATE(3068),
    [sym_preproc_nullable] = STATE(3068),
    [sym_preproc_error] = STATE(3068),
    [sym_preproc_warning] = STATE(3068),
    [sym_preproc_define] = STATE(3068),
    [sym_preproc_undef] = STATE(3068),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4341),
    [anon_sym_LPAREN] = ACTIONS(4341),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4345),
    [anon_sym_GT] = ACTIONS(4345),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4345),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4345),
    [anon_sym_PLUS_PLUS] = ACTIONS(4341),
    [anon_sym_DASH_DASH] = ACTIONS(4341),
    [anon_sym_PLUS] = ACTIONS(4345),
    [anon_sym_DASH] = ACTIONS(4345),
    [anon_sym_STAR] = ACTIONS(4341),
    [anon_sym_SLASH] = ACTIONS(4345),
    [anon_sym_PERCENT] = ACTIONS(4341),
    [anon_sym_CARET] = ACTIONS(4341),
    [anon_sym_PIPE] = ACTIONS(4345),
    [anon_sym_AMP] = ACTIONS(4345),
    [anon_sym_LT_LT] = ACTIONS(4341),
    [anon_sym_GT_GT] = ACTIONS(4345),
    [anon_sym_GT_GT_GT] = ACTIONS(4341),
    [anon_sym_EQ_EQ] = ACTIONS(4341),
    [anon_sym_BANG_EQ] = ACTIONS(4341),
    [anon_sym_GT_EQ] = ACTIONS(4341),
    [anon_sym_LT_EQ] = ACTIONS(4341),
    [anon_sym_DOT] = ACTIONS(4345),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4345),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4359),
    [anon_sym_DOT_DOT] = ACTIONS(4341),
    [anon_sym_and] = ACTIONS(4345),
    [anon_sym_or] = ACTIONS(4345),
    [anon_sym_AMP_AMP] = ACTIONS(4341),
    [anon_sym_PIPE_PIPE] = ACTIONS(4341),
    [anon_sym_QMARK_QMARK] = ACTIONS(4341),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4339),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4345),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4345),
    [anon_sym_is] = ACTIONS(4345),
    [anon_sym_DASH_GT] = ACTIONS(4341),
    [anon_sym_with] = ACTIONS(4345),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3069] = {
    [sym_parameter_list] = STATE(9685),
    [sym_positional_pattern_clause] = STATE(3154),
    [sym_property_pattern_clause] = STATE(3374),
    [sym__variable_designation] = STATE(4162),
    [sym_parenthesized_variable_designation] = STATE(4153),
    [sym__lambda_parameters] = STATE(9890),
    [sym_identifier] = STATE(4163),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3069),
    [sym_preproc_endregion] = STATE(3069),
    [sym_preproc_line] = STATE(3069),
    [sym_preproc_pragma] = STATE(3069),
    [sym_preproc_nullable] = STATE(3069),
    [sym_preproc_error] = STATE(3069),
    [sym_preproc_warning] = STATE(3069),
    [sym_preproc_define] = STATE(3069),
    [sym_preproc_undef] = STATE(3069),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4341),
    [anon_sym_LPAREN] = ACTIONS(4341),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4345),
    [anon_sym_GT] = ACTIONS(4345),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4345),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4345),
    [anon_sym_PLUS_PLUS] = ACTIONS(4341),
    [anon_sym_DASH_DASH] = ACTIONS(4341),
    [anon_sym_PLUS] = ACTIONS(4345),
    [anon_sym_DASH] = ACTIONS(4345),
    [anon_sym_STAR] = ACTIONS(4341),
    [anon_sym_SLASH] = ACTIONS(4345),
    [anon_sym_PERCENT] = ACTIONS(4341),
    [anon_sym_CARET] = ACTIONS(4341),
    [anon_sym_PIPE] = ACTIONS(4345),
    [anon_sym_AMP] = ACTIONS(4345),
    [anon_sym_LT_LT] = ACTIONS(4341),
    [anon_sym_GT_GT] = ACTIONS(4345),
    [anon_sym_GT_GT_GT] = ACTIONS(4341),
    [anon_sym_EQ_EQ] = ACTIONS(4341),
    [anon_sym_BANG_EQ] = ACTIONS(4341),
    [anon_sym_GT_EQ] = ACTIONS(4341),
    [anon_sym_LT_EQ] = ACTIONS(4341),
    [anon_sym_DOT] = ACTIONS(4345),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4345),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4359),
    [anon_sym_DOT_DOT] = ACTIONS(4341),
    [anon_sym_and] = ACTIONS(4355),
    [anon_sym_or] = ACTIONS(4355),
    [anon_sym_AMP_AMP] = ACTIONS(4341),
    [anon_sym_PIPE_PIPE] = ACTIONS(4341),
    [anon_sym_QMARK_QMARK] = ACTIONS(4341),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4339),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4345),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4345),
    [anon_sym_is] = ACTIONS(4345),
    [anon_sym_DASH_GT] = ACTIONS(4341),
    [anon_sym_with] = ACTIONS(4345),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3070] = {
    [sym_parameter_list] = STATE(9685),
    [sym_positional_pattern_clause] = STATE(3171),
    [sym_property_pattern_clause] = STATE(3424),
    [sym__variable_designation] = STATE(4091),
    [sym_parenthesized_variable_designation] = STATE(3966),
    [sym__lambda_parameters] = STATE(9890),
    [sym_identifier] = STATE(4070),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3070),
    [sym_preproc_endregion] = STATE(3070),
    [sym_preproc_line] = STATE(3070),
    [sym_preproc_pragma] = STATE(3070),
    [sym_preproc_nullable] = STATE(3070),
    [sym_preproc_error] = STATE(3070),
    [sym_preproc_warning] = STATE(3070),
    [sym_preproc_define] = STATE(3070),
    [sym_preproc_undef] = STATE(3070),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4341),
    [anon_sym_LPAREN] = ACTIONS(4341),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4345),
    [anon_sym_GT] = ACTIONS(4345),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4345),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4345),
    [anon_sym_PLUS_PLUS] = ACTIONS(4341),
    [anon_sym_DASH_DASH] = ACTIONS(4341),
    [anon_sym_PLUS] = ACTIONS(4345),
    [anon_sym_DASH] = ACTIONS(4345),
    [anon_sym_STAR] = ACTIONS(4341),
    [anon_sym_SLASH] = ACTIONS(4345),
    [anon_sym_PERCENT] = ACTIONS(4341),
    [anon_sym_CARET] = ACTIONS(4341),
    [anon_sym_PIPE] = ACTIONS(4345),
    [anon_sym_AMP] = ACTIONS(4345),
    [anon_sym_LT_LT] = ACTIONS(4341),
    [anon_sym_GT_GT] = ACTIONS(4345),
    [anon_sym_GT_GT_GT] = ACTIONS(4341),
    [anon_sym_EQ_EQ] = ACTIONS(4341),
    [anon_sym_BANG_EQ] = ACTIONS(4341),
    [anon_sym_GT_EQ] = ACTIONS(4341),
    [anon_sym_LT_EQ] = ACTIONS(4341),
    [anon_sym_DOT] = ACTIONS(4345),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4345),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4347),
    [anon_sym_DOT_DOT] = ACTIONS(4341),
    [anon_sym_and] = ACTIONS(4355),
    [anon_sym_or] = ACTIONS(4355),
    [anon_sym_AMP_AMP] = ACTIONS(4341),
    [anon_sym_PIPE_PIPE] = ACTIONS(4341),
    [anon_sym_QMARK_QMARK] = ACTIONS(4341),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4345),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4345),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4345),
    [anon_sym_is] = ACTIONS(4345),
    [anon_sym_DASH_GT] = ACTIONS(4341),
    [anon_sym_with] = ACTIONS(4345),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3071] = {
    [sym__name] = STATE(3748),
    [sym_alias_qualified_name] = STATE(3680),
    [sym__simple_name] = STATE(3680),
    [sym_qualified_name] = STATE(3680),
    [sym_generic_name] = STATE(3648),
    [sym_ref_type] = STATE(3643),
    [sym__scoped_base_type] = STATE(3647),
    [sym_identifier] = STATE(3590),
    [sym__reserved_identifier] = STATE(3625),
    [sym_preproc_region] = STATE(3071),
    [sym_preproc_endregion] = STATE(3071),
    [sym_preproc_line] = STATE(3071),
    [sym_preproc_pragma] = STATE(3071),
    [sym_preproc_nullable] = STATE(3071),
    [sym_preproc_error] = STATE(3071),
    [sym_preproc_warning] = STATE(3071),
    [sym_preproc_define] = STATE(3071),
    [sym_preproc_undef] = STATE(3071),
    [sym__identifier_token] = ACTIONS(4349),
    [anon_sym_alias] = ACTIONS(4351),
    [anon_sym_global] = ACTIONS(4351),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_LPAREN] = ACTIONS(3993),
    [anon_sym_ref] = ACTIONS(4723),
    [anon_sym_LBRACE] = ACTIONS(3993),
    [anon_sym_file] = ACTIONS(4351),
    [anon_sym_LT] = ACTIONS(3995),
    [anon_sym_GT] = ACTIONS(3995),
    [anon_sym_where] = ACTIONS(4351),
    [anon_sym_QMARK] = ACTIONS(3995),
    [anon_sym_notnull] = ACTIONS(4351),
    [anon_sym_unmanaged] = ACTIONS(4351),
    [anon_sym_BANG] = ACTIONS(3995),
    [anon_sym_PLUS_PLUS] = ACTIONS(3993),
    [anon_sym_DASH_DASH] = ACTIONS(3993),
    [anon_sym_PLUS] = ACTIONS(3995),
    [anon_sym_DASH] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3993),
    [anon_sym_SLASH] = ACTIONS(3995),
    [anon_sym_PERCENT] = ACTIONS(3993),
    [anon_sym_CARET] = ACTIONS(3993),
    [anon_sym_PIPE] = ACTIONS(3995),
    [anon_sym_AMP] = ACTIONS(3995),
    [anon_sym_LT_LT] = ACTIONS(3993),
    [anon_sym_GT_GT] = ACTIONS(3995),
    [anon_sym_GT_GT_GT] = ACTIONS(3993),
    [anon_sym_EQ_EQ] = ACTIONS(3993),
    [anon_sym_BANG_EQ] = ACTIONS(3993),
    [anon_sym_GT_EQ] = ACTIONS(3993),
    [anon_sym_LT_EQ] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3995),
    [anon_sym_scoped] = ACTIONS(4351),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(4351),
    [anon_sym_yield] = ACTIONS(4351),
    [anon_sym_switch] = ACTIONS(3995),
    [anon_sym_when] = ACTIONS(4351),
    [anon_sym_DOT_DOT] = ACTIONS(3993),
    [anon_sym_AMP_AMP] = ACTIONS(3993),
    [anon_sym_PIPE_PIPE] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK] = ACTIONS(3993),
    [anon_sym_from] = ACTIONS(4351),
    [anon_sym_into] = ACTIONS(4351),
    [anon_sym_join] = ACTIONS(4351),
    [anon_sym_on] = ACTIONS(4680),
    [anon_sym_equals] = ACTIONS(4351),
    [anon_sym_let] = ACTIONS(4351),
    [anon_sym_orderby] = ACTIONS(4351),
    [anon_sym_ascending] = ACTIONS(4351),
    [anon_sym_descending] = ACTIONS(4351),
    [anon_sym_group] = ACTIONS(4351),
    [anon_sym_by] = ACTIONS(4351),
    [anon_sym_select] = ACTIONS(4351),
    [anon_sym_as] = ACTIONS(3995),
    [anon_sym_is] = ACTIONS(3995),
    [anon_sym_DASH_GT] = ACTIONS(3993),
    [anon_sym_with] = ACTIONS(3995),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3072] = {
    [sym_parameter_list] = STATE(9685),
    [sym_positional_pattern_clause] = STATE(3147),
    [sym_property_pattern_clause] = STATE(3409),
    [sym__variable_designation] = STATE(4091),
    [sym_parenthesized_variable_designation] = STATE(3966),
    [sym__lambda_parameters] = STATE(9890),
    [sym_identifier] = STATE(4070),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3072),
    [sym_preproc_endregion] = STATE(3072),
    [sym_preproc_line] = STATE(3072),
    [sym_preproc_pragma] = STATE(3072),
    [sym_preproc_nullable] = STATE(3072),
    [sym_preproc_error] = STATE(3072),
    [sym_preproc_warning] = STATE(3072),
    [sym_preproc_define] = STATE(3072),
    [sym_preproc_undef] = STATE(3072),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4341),
    [anon_sym_LPAREN] = ACTIONS(4341),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4345),
    [anon_sym_GT] = ACTIONS(4345),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4345),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4345),
    [anon_sym_PLUS_PLUS] = ACTIONS(4341),
    [anon_sym_DASH_DASH] = ACTIONS(4341),
    [anon_sym_PLUS] = ACTIONS(4345),
    [anon_sym_DASH] = ACTIONS(4345),
    [anon_sym_STAR] = ACTIONS(4341),
    [anon_sym_SLASH] = ACTIONS(4345),
    [anon_sym_PERCENT] = ACTIONS(4341),
    [anon_sym_CARET] = ACTIONS(4341),
    [anon_sym_PIPE] = ACTIONS(4345),
    [anon_sym_AMP] = ACTIONS(4345),
    [anon_sym_LT_LT] = ACTIONS(4341),
    [anon_sym_GT_GT] = ACTIONS(4345),
    [anon_sym_GT_GT_GT] = ACTIONS(4341),
    [anon_sym_EQ_EQ] = ACTIONS(4341),
    [anon_sym_BANG_EQ] = ACTIONS(4341),
    [anon_sym_GT_EQ] = ACTIONS(4341),
    [anon_sym_LT_EQ] = ACTIONS(4341),
    [anon_sym_DOT] = ACTIONS(4345),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4345),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4347),
    [anon_sym_DOT_DOT] = ACTIONS(4341),
    [anon_sym_and] = ACTIONS(4355),
    [anon_sym_or] = ACTIONS(4355),
    [anon_sym_AMP_AMP] = ACTIONS(4341),
    [anon_sym_PIPE_PIPE] = ACTIONS(4341),
    [anon_sym_QMARK_QMARK] = ACTIONS(4341),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4345),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4345),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4345),
    [anon_sym_is] = ACTIONS(4345),
    [anon_sym_DASH_GT] = ACTIONS(4341),
    [anon_sym_with] = ACTIONS(4345),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3073] = {
    [sym_parameter_list] = STATE(9685),
    [sym_positional_pattern_clause] = STATE(3144),
    [sym_property_pattern_clause] = STATE(3361),
    [sym__variable_designation] = STATE(5035),
    [sym_parenthesized_variable_designation] = STATE(5027),
    [sym__lambda_parameters] = STATE(9890),
    [sym_identifier] = STATE(4954),
    [sym__reserved_identifier] = STATE(3572),
    [sym_preproc_region] = STATE(3073),
    [sym_preproc_endregion] = STATE(3073),
    [sym_preproc_line] = STATE(3073),
    [sym_preproc_pragma] = STATE(3073),
    [sym_preproc_nullable] = STATE(3073),
    [sym_preproc_error] = STATE(3073),
    [sym_preproc_warning] = STATE(3073),
    [sym_preproc_define] = STATE(3073),
    [sym_preproc_undef] = STATE(3073),
    [sym__identifier_token] = ACTIONS(4328),
    [anon_sym_alias] = ACTIONS(4330),
    [anon_sym_global] = ACTIONS(4330),
    [anon_sym_LBRACK] = ACTIONS(4357),
    [anon_sym_LPAREN] = ACTIONS(4357),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_file] = ACTIONS(4330),
    [anon_sym_LT] = ACTIONS(4355),
    [anon_sym_GT] = ACTIONS(4355),
    [anon_sym_where] = ACTIONS(4355),
    [anon_sym_QMARK] = ACTIONS(4355),
    [anon_sym_notnull] = ACTIONS(4330),
    [anon_sym_unmanaged] = ACTIONS(4330),
    [anon_sym_BANG] = ACTIONS(4355),
    [anon_sym_PLUS_PLUS] = ACTIONS(4357),
    [anon_sym_DASH_DASH] = ACTIONS(4357),
    [anon_sym_PLUS] = ACTIONS(4355),
    [anon_sym_DASH] = ACTIONS(4355),
    [anon_sym_STAR] = ACTIONS(4357),
    [anon_sym_SLASH] = ACTIONS(4355),
    [anon_sym_PERCENT] = ACTIONS(4357),
    [anon_sym_CARET] = ACTIONS(4357),
    [anon_sym_PIPE] = ACTIONS(4355),
    [anon_sym_AMP] = ACTIONS(4355),
    [anon_sym_LT_LT] = ACTIONS(4357),
    [anon_sym_GT_GT] = ACTIONS(4355),
    [anon_sym_GT_GT_GT] = ACTIONS(4357),
    [anon_sym_EQ_EQ] = ACTIONS(4357),
    [anon_sym_BANG_EQ] = ACTIONS(4357),
    [anon_sym_GT_EQ] = ACTIONS(4357),
    [anon_sym_LT_EQ] = ACTIONS(4357),
    [anon_sym_DOT] = ACTIONS(4355),
    [anon_sym_scoped] = ACTIONS(4330),
    [anon_sym_var] = ACTIONS(4330),
    [anon_sym_yield] = ACTIONS(4330),
    [anon_sym_switch] = ACTIONS(4355),
    [anon_sym_when] = ACTIONS(4330),
    [sym_discard] = ACTIONS(4719),
    [anon_sym_DOT_DOT] = ACTIONS(4357),
    [anon_sym_and] = ACTIONS(4355),
    [anon_sym_or] = ACTIONS(4355),
    [anon_sym_AMP_AMP] = ACTIONS(4357),
    [anon_sym_PIPE_PIPE] = ACTIONS(4357),
    [anon_sym_QMARK_QMARK] = ACTIONS(4357),
    [anon_sym_from] = ACTIONS(4355),
    [anon_sym_into] = ACTIONS(4355),
    [anon_sym_join] = ACTIONS(4355),
    [anon_sym_on] = ACTIONS(4330),
    [anon_sym_equals] = ACTIONS(4330),
    [anon_sym_let] = ACTIONS(4355),
    [anon_sym_orderby] = ACTIONS(4355),
    [anon_sym_ascending] = ACTIONS(4330),
    [anon_sym_descending] = ACTIONS(4330),
    [anon_sym_group] = ACTIONS(4355),
    [anon_sym_by] = ACTIONS(4330),
    [anon_sym_select] = ACTIONS(4355),
    [anon_sym_as] = ACTIONS(4355),
    [anon_sym_is] = ACTIONS(4355),
    [anon_sym_DASH_GT] = ACTIONS(4357),
    [anon_sym_with] = ACTIONS(4355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3074] = {
    [sym_parameter_list] = STATE(9685),
    [sym_positional_pattern_clause] = STATE(3167),
    [sym_property_pattern_clause] = STATE(3381),
    [sym__variable_designation] = STATE(4162),
    [sym_parenthesized_variable_designation] = STATE(4153),
    [sym__lambda_parameters] = STATE(9890),
    [sym_identifier] = STATE(4163),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3074),
    [sym_preproc_endregion] = STATE(3074),
    [sym_preproc_line] = STATE(3074),
    [sym_preproc_pragma] = STATE(3074),
    [sym_preproc_nullable] = STATE(3074),
    [sym_preproc_error] = STATE(3074),
    [sym_preproc_warning] = STATE(3074),
    [sym_preproc_define] = STATE(3074),
    [sym_preproc_undef] = STATE(3074),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4341),
    [anon_sym_LPAREN] = ACTIONS(4341),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4345),
    [anon_sym_GT] = ACTIONS(4345),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4345),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4345),
    [anon_sym_PLUS_PLUS] = ACTIONS(4341),
    [anon_sym_DASH_DASH] = ACTIONS(4341),
    [anon_sym_PLUS] = ACTIONS(4345),
    [anon_sym_DASH] = ACTIONS(4345),
    [anon_sym_STAR] = ACTIONS(4341),
    [anon_sym_SLASH] = ACTIONS(4345),
    [anon_sym_PERCENT] = ACTIONS(4341),
    [anon_sym_CARET] = ACTIONS(4341),
    [anon_sym_PIPE] = ACTIONS(4345),
    [anon_sym_AMP] = ACTIONS(4345),
    [anon_sym_LT_LT] = ACTIONS(4341),
    [anon_sym_GT_GT] = ACTIONS(4345),
    [anon_sym_GT_GT_GT] = ACTIONS(4341),
    [anon_sym_EQ_EQ] = ACTIONS(4341),
    [anon_sym_BANG_EQ] = ACTIONS(4341),
    [anon_sym_GT_EQ] = ACTIONS(4341),
    [anon_sym_LT_EQ] = ACTIONS(4341),
    [anon_sym_DOT] = ACTIONS(4345),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4345),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4359),
    [anon_sym_DOT_DOT] = ACTIONS(4341),
    [anon_sym_and] = ACTIONS(4355),
    [anon_sym_or] = ACTIONS(4355),
    [anon_sym_AMP_AMP] = ACTIONS(4341),
    [anon_sym_PIPE_PIPE] = ACTIONS(4341),
    [anon_sym_QMARK_QMARK] = ACTIONS(4341),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4339),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4345),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4345),
    [anon_sym_is] = ACTIONS(4345),
    [anon_sym_DASH_GT] = ACTIONS(4341),
    [anon_sym_with] = ACTIONS(4345),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3075] = {
    [sym__name] = STATE(4348),
    [sym_alias_qualified_name] = STATE(3588),
    [sym__simple_name] = STATE(3588),
    [sym_qualified_name] = STATE(3588),
    [sym_generic_name] = STATE(3597),
    [sym_ref_type] = STATE(3601),
    [sym__scoped_base_type] = STATE(3606),
    [sym_identifier] = STATE(4004),
    [sym__reserved_identifier] = STATE(3572),
    [sym_preproc_region] = STATE(3075),
    [sym_preproc_endregion] = STATE(3075),
    [sym_preproc_line] = STATE(3075),
    [sym_preproc_pragma] = STATE(3075),
    [sym_preproc_nullable] = STATE(3075),
    [sym_preproc_error] = STATE(3075),
    [sym_preproc_warning] = STATE(3075),
    [sym_preproc_define] = STATE(3075),
    [sym_preproc_undef] = STATE(3075),
    [sym__identifier_token] = ACTIONS(4328),
    [anon_sym_alias] = ACTIONS(4330),
    [anon_sym_global] = ACTIONS(4330),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_LPAREN] = ACTIONS(3993),
    [anon_sym_ref] = ACTIONS(4725),
    [anon_sym_LBRACE] = ACTIONS(3993),
    [anon_sym_file] = ACTIONS(4330),
    [anon_sym_LT] = ACTIONS(3995),
    [anon_sym_GT] = ACTIONS(3995),
    [anon_sym_where] = ACTIONS(4330),
    [anon_sym_QMARK] = ACTIONS(3995),
    [anon_sym_notnull] = ACTIONS(4330),
    [anon_sym_unmanaged] = ACTIONS(4330),
    [anon_sym_BANG] = ACTIONS(3995),
    [anon_sym_PLUS_PLUS] = ACTIONS(3993),
    [anon_sym_DASH_DASH] = ACTIONS(3993),
    [anon_sym_PLUS] = ACTIONS(3995),
    [anon_sym_DASH] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3993),
    [anon_sym_SLASH] = ACTIONS(3995),
    [anon_sym_PERCENT] = ACTIONS(3993),
    [anon_sym_CARET] = ACTIONS(3993),
    [anon_sym_PIPE] = ACTIONS(3995),
    [anon_sym_AMP] = ACTIONS(3995),
    [anon_sym_LT_LT] = ACTIONS(3993),
    [anon_sym_GT_GT] = ACTIONS(3995),
    [anon_sym_GT_GT_GT] = ACTIONS(3993),
    [anon_sym_EQ_EQ] = ACTIONS(3993),
    [anon_sym_BANG_EQ] = ACTIONS(3993),
    [anon_sym_GT_EQ] = ACTIONS(3993),
    [anon_sym_LT_EQ] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3995),
    [anon_sym_scoped] = ACTIONS(4330),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(4330),
    [anon_sym_yield] = ACTIONS(4330),
    [anon_sym_switch] = ACTIONS(3995),
    [anon_sym_when] = ACTIONS(4330),
    [anon_sym_DOT_DOT] = ACTIONS(3993),
    [anon_sym_AMP_AMP] = ACTIONS(3993),
    [anon_sym_PIPE_PIPE] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK] = ACTIONS(3993),
    [anon_sym_from] = ACTIONS(4330),
    [anon_sym_into] = ACTIONS(4334),
    [anon_sym_join] = ACTIONS(4330),
    [anon_sym_on] = ACTIONS(4330),
    [anon_sym_equals] = ACTIONS(4330),
    [anon_sym_let] = ACTIONS(4330),
    [anon_sym_orderby] = ACTIONS(4330),
    [anon_sym_ascending] = ACTIONS(4330),
    [anon_sym_descending] = ACTIONS(4330),
    [anon_sym_group] = ACTIONS(4330),
    [anon_sym_by] = ACTIONS(4334),
    [anon_sym_select] = ACTIONS(4330),
    [anon_sym_as] = ACTIONS(3995),
    [anon_sym_is] = ACTIONS(3995),
    [anon_sym_DASH_GT] = ACTIONS(3993),
    [anon_sym_with] = ACTIONS(3995),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3076] = {
    [sym_property_pattern_clause] = STATE(3136),
    [sym__variable_designation] = STATE(5784),
    [sym_parenthesized_variable_designation] = STATE(5773),
    [sym_identifier] = STATE(5775),
    [sym__reserved_identifier] = STATE(5200),
    [sym_preproc_region] = STATE(3076),
    [sym_preproc_endregion] = STATE(3076),
    [sym_preproc_line] = STATE(3076),
    [sym_preproc_pragma] = STATE(3076),
    [sym_preproc_nullable] = STATE(3076),
    [sym_preproc_error] = STATE(3076),
    [sym_preproc_warning] = STATE(3076),
    [sym_preproc_define] = STATE(3076),
    [sym_preproc_undef] = STATE(3076),
    [sym__identifier_token] = ACTIONS(4575),
    [anon_sym_alias] = ACTIONS(4577),
    [anon_sym_global] = ACTIONS(4577),
    [anon_sym_LBRACK] = ACTIONS(4399),
    [anon_sym_COLON] = ACTIONS(4399),
    [anon_sym_COMMA] = ACTIONS(4399),
    [anon_sym_LPAREN] = ACTIONS(4399),
    [anon_sym_LBRACE] = ACTIONS(4579),
    [anon_sym_file] = ACTIONS(4577),
    [anon_sym_LT] = ACTIONS(4401),
    [anon_sym_GT] = ACTIONS(4401),
    [anon_sym_where] = ACTIONS(4577),
    [anon_sym_QMARK] = ACTIONS(4401),
    [anon_sym_notnull] = ACTIONS(4577),
    [anon_sym_unmanaged] = ACTIONS(4577),
    [anon_sym_BANG] = ACTIONS(4401),
    [anon_sym_PLUS_PLUS] = ACTIONS(4399),
    [anon_sym_DASH_DASH] = ACTIONS(4399),
    [anon_sym_PLUS] = ACTIONS(4401),
    [anon_sym_DASH] = ACTIONS(4401),
    [anon_sym_STAR] = ACTIONS(4399),
    [anon_sym_SLASH] = ACTIONS(4401),
    [anon_sym_PERCENT] = ACTIONS(4399),
    [anon_sym_CARET] = ACTIONS(4399),
    [anon_sym_PIPE] = ACTIONS(4401),
    [anon_sym_AMP] = ACTIONS(4401),
    [anon_sym_LT_LT] = ACTIONS(4399),
    [anon_sym_GT_GT] = ACTIONS(4401),
    [anon_sym_GT_GT_GT] = ACTIONS(4399),
    [anon_sym_EQ_EQ] = ACTIONS(4399),
    [anon_sym_BANG_EQ] = ACTIONS(4399),
    [anon_sym_GT_EQ] = ACTIONS(4399),
    [anon_sym_LT_EQ] = ACTIONS(4399),
    [anon_sym_DOT] = ACTIONS(4401),
    [anon_sym_scoped] = ACTIONS(4577),
    [anon_sym_var] = ACTIONS(4577),
    [anon_sym_yield] = ACTIONS(4577),
    [anon_sym_switch] = ACTIONS(4401),
    [anon_sym_when] = ACTIONS(4577),
    [sym_discard] = ACTIONS(4581),
    [anon_sym_DOT_DOT] = ACTIONS(4399),
    [anon_sym_and] = ACTIONS(4401),
    [anon_sym_or] = ACTIONS(4401),
    [anon_sym_AMP_AMP] = ACTIONS(4399),
    [anon_sym_PIPE_PIPE] = ACTIONS(4399),
    [anon_sym_QMARK_QMARK] = ACTIONS(4399),
    [anon_sym_from] = ACTIONS(4577),
    [anon_sym_into] = ACTIONS(4401),
    [anon_sym_join] = ACTIONS(4577),
    [anon_sym_on] = ACTIONS(4577),
    [anon_sym_equals] = ACTIONS(4577),
    [anon_sym_let] = ACTIONS(4577),
    [anon_sym_orderby] = ACTIONS(4577),
    [anon_sym_ascending] = ACTIONS(4577),
    [anon_sym_descending] = ACTIONS(4577),
    [anon_sym_group] = ACTIONS(4577),
    [anon_sym_by] = ACTIONS(4577),
    [anon_sym_select] = ACTIONS(4577),
    [anon_sym_as] = ACTIONS(4401),
    [anon_sym_is] = ACTIONS(4401),
    [anon_sym_DASH_GT] = ACTIONS(4399),
    [anon_sym_with] = ACTIONS(4401),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4399),
  },
  [3077] = {
    [sym_parameter_list] = STATE(9685),
    [sym_positional_pattern_clause] = STATE(3171),
    [sym_property_pattern_clause] = STATE(3424),
    [sym__variable_designation] = STATE(4091),
    [sym_parenthesized_variable_designation] = STATE(3966),
    [sym__lambda_parameters] = STATE(9890),
    [sym_identifier] = STATE(4070),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3077),
    [sym_preproc_endregion] = STATE(3077),
    [sym_preproc_line] = STATE(3077),
    [sym_preproc_pragma] = STATE(3077),
    [sym_preproc_nullable] = STATE(3077),
    [sym_preproc_error] = STATE(3077),
    [sym_preproc_warning] = STATE(3077),
    [sym_preproc_define] = STATE(3077),
    [sym_preproc_undef] = STATE(3077),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4357),
    [anon_sym_LPAREN] = ACTIONS(4357),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4355),
    [anon_sym_GT] = ACTIONS(4355),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4355),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4355),
    [anon_sym_PLUS_PLUS] = ACTIONS(4357),
    [anon_sym_DASH_DASH] = ACTIONS(4357),
    [anon_sym_PLUS] = ACTIONS(4355),
    [anon_sym_DASH] = ACTIONS(4355),
    [anon_sym_STAR] = ACTIONS(4357),
    [anon_sym_SLASH] = ACTIONS(4355),
    [anon_sym_PERCENT] = ACTIONS(4357),
    [anon_sym_CARET] = ACTIONS(4357),
    [anon_sym_PIPE] = ACTIONS(4355),
    [anon_sym_AMP] = ACTIONS(4355),
    [anon_sym_LT_LT] = ACTIONS(4357),
    [anon_sym_GT_GT] = ACTIONS(4355),
    [anon_sym_GT_GT_GT] = ACTIONS(4357),
    [anon_sym_EQ_EQ] = ACTIONS(4357),
    [anon_sym_BANG_EQ] = ACTIONS(4357),
    [anon_sym_GT_EQ] = ACTIONS(4357),
    [anon_sym_LT_EQ] = ACTIONS(4357),
    [anon_sym_DOT] = ACTIONS(4355),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4355),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4347),
    [anon_sym_DOT_DOT] = ACTIONS(4357),
    [anon_sym_and] = ACTIONS(4355),
    [anon_sym_or] = ACTIONS(4355),
    [anon_sym_AMP_AMP] = ACTIONS(4357),
    [anon_sym_PIPE_PIPE] = ACTIONS(4357),
    [anon_sym_QMARK_QMARK] = ACTIONS(4357),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4355),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4355),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4355),
    [anon_sym_is] = ACTIONS(4355),
    [anon_sym_DASH_GT] = ACTIONS(4357),
    [anon_sym_with] = ACTIONS(4355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3078] = {
    [sym_parameter_list] = STATE(9685),
    [sym_positional_pattern_clause] = STATE(3147),
    [sym_property_pattern_clause] = STATE(3409),
    [sym__variable_designation] = STATE(4091),
    [sym_parenthesized_variable_designation] = STATE(3966),
    [sym__lambda_parameters] = STATE(9890),
    [sym_identifier] = STATE(4070),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3078),
    [sym_preproc_endregion] = STATE(3078),
    [sym_preproc_line] = STATE(3078),
    [sym_preproc_pragma] = STATE(3078),
    [sym_preproc_nullable] = STATE(3078),
    [sym_preproc_error] = STATE(3078),
    [sym_preproc_warning] = STATE(3078),
    [sym_preproc_define] = STATE(3078),
    [sym_preproc_undef] = STATE(3078),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4341),
    [anon_sym_LPAREN] = ACTIONS(4341),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4345),
    [anon_sym_GT] = ACTIONS(4345),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4345),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4345),
    [anon_sym_PLUS_PLUS] = ACTIONS(4341),
    [anon_sym_DASH_DASH] = ACTIONS(4341),
    [anon_sym_PLUS] = ACTIONS(4345),
    [anon_sym_DASH] = ACTIONS(4345),
    [anon_sym_STAR] = ACTIONS(4341),
    [anon_sym_SLASH] = ACTIONS(4345),
    [anon_sym_PERCENT] = ACTIONS(4341),
    [anon_sym_CARET] = ACTIONS(4341),
    [anon_sym_PIPE] = ACTIONS(4345),
    [anon_sym_AMP] = ACTIONS(4345),
    [anon_sym_LT_LT] = ACTIONS(4341),
    [anon_sym_GT_GT] = ACTIONS(4345),
    [anon_sym_GT_GT_GT] = ACTIONS(4341),
    [anon_sym_EQ_EQ] = ACTIONS(4341),
    [anon_sym_BANG_EQ] = ACTIONS(4341),
    [anon_sym_GT_EQ] = ACTIONS(4341),
    [anon_sym_LT_EQ] = ACTIONS(4341),
    [anon_sym_DOT] = ACTIONS(4345),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4345),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4347),
    [anon_sym_DOT_DOT] = ACTIONS(4341),
    [anon_sym_and] = ACTIONS(4345),
    [anon_sym_or] = ACTIONS(4345),
    [anon_sym_AMP_AMP] = ACTIONS(4341),
    [anon_sym_PIPE_PIPE] = ACTIONS(4341),
    [anon_sym_QMARK_QMARK] = ACTIONS(4341),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4345),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4345),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4345),
    [anon_sym_is] = ACTIONS(4345),
    [anon_sym_DASH_GT] = ACTIONS(4341),
    [anon_sym_with] = ACTIONS(4345),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3079] = {
    [sym_parameter_list] = STATE(9685),
    [sym_positional_pattern_clause] = STATE(3144),
    [sym_property_pattern_clause] = STATE(3361),
    [sym__variable_designation] = STATE(5035),
    [sym_parenthesized_variable_designation] = STATE(5027),
    [sym__lambda_parameters] = STATE(9890),
    [sym_identifier] = STATE(4954),
    [sym__reserved_identifier] = STATE(3572),
    [sym_preproc_region] = STATE(3079),
    [sym_preproc_endregion] = STATE(3079),
    [sym_preproc_line] = STATE(3079),
    [sym_preproc_pragma] = STATE(3079),
    [sym_preproc_nullable] = STATE(3079),
    [sym_preproc_error] = STATE(3079),
    [sym_preproc_warning] = STATE(3079),
    [sym_preproc_define] = STATE(3079),
    [sym_preproc_undef] = STATE(3079),
    [sym__identifier_token] = ACTIONS(4328),
    [anon_sym_alias] = ACTIONS(4330),
    [anon_sym_global] = ACTIONS(4330),
    [anon_sym_LBRACK] = ACTIONS(4341),
    [anon_sym_LPAREN] = ACTIONS(4341),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_file] = ACTIONS(4330),
    [anon_sym_LT] = ACTIONS(4345),
    [anon_sym_GT] = ACTIONS(4345),
    [anon_sym_where] = ACTIONS(4345),
    [anon_sym_QMARK] = ACTIONS(4345),
    [anon_sym_notnull] = ACTIONS(4330),
    [anon_sym_unmanaged] = ACTIONS(4330),
    [anon_sym_BANG] = ACTIONS(4345),
    [anon_sym_PLUS_PLUS] = ACTIONS(4341),
    [anon_sym_DASH_DASH] = ACTIONS(4341),
    [anon_sym_PLUS] = ACTIONS(4345),
    [anon_sym_DASH] = ACTIONS(4345),
    [anon_sym_STAR] = ACTIONS(4341),
    [anon_sym_SLASH] = ACTIONS(4345),
    [anon_sym_PERCENT] = ACTIONS(4341),
    [anon_sym_CARET] = ACTIONS(4341),
    [anon_sym_PIPE] = ACTIONS(4345),
    [anon_sym_AMP] = ACTIONS(4345),
    [anon_sym_LT_LT] = ACTIONS(4341),
    [anon_sym_GT_GT] = ACTIONS(4345),
    [anon_sym_GT_GT_GT] = ACTIONS(4341),
    [anon_sym_EQ_EQ] = ACTIONS(4341),
    [anon_sym_BANG_EQ] = ACTIONS(4341),
    [anon_sym_GT_EQ] = ACTIONS(4341),
    [anon_sym_LT_EQ] = ACTIONS(4341),
    [anon_sym_DOT] = ACTIONS(4345),
    [anon_sym_scoped] = ACTIONS(4330),
    [anon_sym_var] = ACTIONS(4330),
    [anon_sym_yield] = ACTIONS(4330),
    [anon_sym_switch] = ACTIONS(4345),
    [anon_sym_when] = ACTIONS(4330),
    [sym_discard] = ACTIONS(4719),
    [anon_sym_DOT_DOT] = ACTIONS(4341),
    [anon_sym_and] = ACTIONS(4355),
    [anon_sym_or] = ACTIONS(4355),
    [anon_sym_AMP_AMP] = ACTIONS(4341),
    [anon_sym_PIPE_PIPE] = ACTIONS(4341),
    [anon_sym_QMARK_QMARK] = ACTIONS(4341),
    [anon_sym_from] = ACTIONS(4345),
    [anon_sym_into] = ACTIONS(4345),
    [anon_sym_join] = ACTIONS(4345),
    [anon_sym_on] = ACTIONS(4330),
    [anon_sym_equals] = ACTIONS(4330),
    [anon_sym_let] = ACTIONS(4345),
    [anon_sym_orderby] = ACTIONS(4345),
    [anon_sym_ascending] = ACTIONS(4330),
    [anon_sym_descending] = ACTIONS(4330),
    [anon_sym_group] = ACTIONS(4345),
    [anon_sym_by] = ACTIONS(4330),
    [anon_sym_select] = ACTIONS(4345),
    [anon_sym_as] = ACTIONS(4345),
    [anon_sym_is] = ACTIONS(4345),
    [anon_sym_DASH_GT] = ACTIONS(4341),
    [anon_sym_with] = ACTIONS(4345),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3080] = {
    [sym__name] = STATE(4348),
    [sym_alias_qualified_name] = STATE(3588),
    [sym__simple_name] = STATE(3588),
    [sym_qualified_name] = STATE(3588),
    [sym_generic_name] = STATE(3597),
    [sym_ref_type] = STATE(3601),
    [sym__scoped_base_type] = STATE(3606),
    [sym_identifier] = STATE(4004),
    [sym__reserved_identifier] = STATE(3572),
    [sym_preproc_region] = STATE(3080),
    [sym_preproc_endregion] = STATE(3080),
    [sym_preproc_line] = STATE(3080),
    [sym_preproc_pragma] = STATE(3080),
    [sym_preproc_nullable] = STATE(3080),
    [sym_preproc_error] = STATE(3080),
    [sym_preproc_warning] = STATE(3080),
    [sym_preproc_define] = STATE(3080),
    [sym_preproc_undef] = STATE(3080),
    [sym__identifier_token] = ACTIONS(4328),
    [anon_sym_alias] = ACTIONS(4330),
    [anon_sym_global] = ACTIONS(4330),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_LPAREN] = ACTIONS(3993),
    [anon_sym_ref] = ACTIONS(4727),
    [anon_sym_LBRACE] = ACTIONS(3993),
    [anon_sym_file] = ACTIONS(4330),
    [anon_sym_LT] = ACTIONS(3995),
    [anon_sym_GT] = ACTIONS(3995),
    [anon_sym_where] = ACTIONS(4330),
    [anon_sym_QMARK] = ACTIONS(3995),
    [anon_sym_notnull] = ACTIONS(4330),
    [anon_sym_unmanaged] = ACTIONS(4330),
    [anon_sym_BANG] = ACTIONS(3995),
    [anon_sym_PLUS_PLUS] = ACTIONS(3993),
    [anon_sym_DASH_DASH] = ACTIONS(3993),
    [anon_sym_PLUS] = ACTIONS(3995),
    [anon_sym_DASH] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3993),
    [anon_sym_SLASH] = ACTIONS(3995),
    [anon_sym_PERCENT] = ACTIONS(3993),
    [anon_sym_CARET] = ACTIONS(3993),
    [anon_sym_PIPE] = ACTIONS(3995),
    [anon_sym_AMP] = ACTIONS(3995),
    [anon_sym_LT_LT] = ACTIONS(3993),
    [anon_sym_GT_GT] = ACTIONS(3995),
    [anon_sym_GT_GT_GT] = ACTIONS(3993),
    [anon_sym_EQ_EQ] = ACTIONS(3993),
    [anon_sym_BANG_EQ] = ACTIONS(3993),
    [anon_sym_GT_EQ] = ACTIONS(3993),
    [anon_sym_LT_EQ] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3995),
    [anon_sym_scoped] = ACTIONS(4330),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(4330),
    [anon_sym_yield] = ACTIONS(4330),
    [anon_sym_switch] = ACTIONS(3995),
    [anon_sym_when] = ACTIONS(4330),
    [anon_sym_DOT_DOT] = ACTIONS(3993),
    [anon_sym_AMP_AMP] = ACTIONS(3993),
    [anon_sym_PIPE_PIPE] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK] = ACTIONS(3993),
    [anon_sym_from] = ACTIONS(4330),
    [anon_sym_into] = ACTIONS(4334),
    [anon_sym_join] = ACTIONS(4330),
    [anon_sym_on] = ACTIONS(4334),
    [anon_sym_equals] = ACTIONS(4330),
    [anon_sym_let] = ACTIONS(4330),
    [anon_sym_orderby] = ACTIONS(4330),
    [anon_sym_ascending] = ACTIONS(4330),
    [anon_sym_descending] = ACTIONS(4330),
    [anon_sym_group] = ACTIONS(4330),
    [anon_sym_by] = ACTIONS(4330),
    [anon_sym_select] = ACTIONS(4330),
    [anon_sym_as] = ACTIONS(3995),
    [anon_sym_is] = ACTIONS(3995),
    [anon_sym_DASH_GT] = ACTIONS(3993),
    [anon_sym_with] = ACTIONS(3995),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3081] = {
    [sym_property_pattern_clause] = STATE(3137),
    [sym__variable_designation] = STATE(5430),
    [sym_parenthesized_variable_designation] = STATE(5773),
    [sym_identifier] = STATE(5775),
    [sym__reserved_identifier] = STATE(5200),
    [sym_preproc_region] = STATE(3081),
    [sym_preproc_endregion] = STATE(3081),
    [sym_preproc_line] = STATE(3081),
    [sym_preproc_pragma] = STATE(3081),
    [sym_preproc_nullable] = STATE(3081),
    [sym_preproc_error] = STATE(3081),
    [sym_preproc_warning] = STATE(3081),
    [sym_preproc_define] = STATE(3081),
    [sym_preproc_undef] = STATE(3081),
    [sym__identifier_token] = ACTIONS(4575),
    [anon_sym_alias] = ACTIONS(4577),
    [anon_sym_global] = ACTIONS(4577),
    [anon_sym_LBRACK] = ACTIONS(4405),
    [anon_sym_COLON] = ACTIONS(4405),
    [anon_sym_COMMA] = ACTIONS(4405),
    [anon_sym_LPAREN] = ACTIONS(4405),
    [anon_sym_LBRACE] = ACTIONS(4579),
    [anon_sym_file] = ACTIONS(4577),
    [anon_sym_LT] = ACTIONS(4407),
    [anon_sym_GT] = ACTIONS(4407),
    [anon_sym_where] = ACTIONS(4577),
    [anon_sym_QMARK] = ACTIONS(4407),
    [anon_sym_notnull] = ACTIONS(4577),
    [anon_sym_unmanaged] = ACTIONS(4577),
    [anon_sym_BANG] = ACTIONS(4407),
    [anon_sym_PLUS_PLUS] = ACTIONS(4405),
    [anon_sym_DASH_DASH] = ACTIONS(4405),
    [anon_sym_PLUS] = ACTIONS(4407),
    [anon_sym_DASH] = ACTIONS(4407),
    [anon_sym_STAR] = ACTIONS(4405),
    [anon_sym_SLASH] = ACTIONS(4407),
    [anon_sym_PERCENT] = ACTIONS(4405),
    [anon_sym_CARET] = ACTIONS(4405),
    [anon_sym_PIPE] = ACTIONS(4407),
    [anon_sym_AMP] = ACTIONS(4407),
    [anon_sym_LT_LT] = ACTIONS(4405),
    [anon_sym_GT_GT] = ACTIONS(4407),
    [anon_sym_GT_GT_GT] = ACTIONS(4405),
    [anon_sym_EQ_EQ] = ACTIONS(4405),
    [anon_sym_BANG_EQ] = ACTIONS(4405),
    [anon_sym_GT_EQ] = ACTIONS(4405),
    [anon_sym_LT_EQ] = ACTIONS(4405),
    [anon_sym_DOT] = ACTIONS(4407),
    [anon_sym_scoped] = ACTIONS(4577),
    [anon_sym_var] = ACTIONS(4577),
    [anon_sym_yield] = ACTIONS(4577),
    [anon_sym_switch] = ACTIONS(4407),
    [anon_sym_when] = ACTIONS(4577),
    [sym_discard] = ACTIONS(4581),
    [anon_sym_DOT_DOT] = ACTIONS(4405),
    [anon_sym_and] = ACTIONS(4407),
    [anon_sym_or] = ACTIONS(4407),
    [anon_sym_AMP_AMP] = ACTIONS(4405),
    [anon_sym_PIPE_PIPE] = ACTIONS(4405),
    [anon_sym_QMARK_QMARK] = ACTIONS(4405),
    [anon_sym_from] = ACTIONS(4577),
    [anon_sym_into] = ACTIONS(4407),
    [anon_sym_join] = ACTIONS(4577),
    [anon_sym_on] = ACTIONS(4577),
    [anon_sym_equals] = ACTIONS(4577),
    [anon_sym_let] = ACTIONS(4577),
    [anon_sym_orderby] = ACTIONS(4577),
    [anon_sym_ascending] = ACTIONS(4577),
    [anon_sym_descending] = ACTIONS(4577),
    [anon_sym_group] = ACTIONS(4577),
    [anon_sym_by] = ACTIONS(4577),
    [anon_sym_select] = ACTIONS(4577),
    [anon_sym_as] = ACTIONS(4407),
    [anon_sym_is] = ACTIONS(4407),
    [anon_sym_DASH_GT] = ACTIONS(4405),
    [anon_sym_with] = ACTIONS(4407),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4405),
  },
  [3082] = {
    [sym_parameter_list] = STATE(9685),
    [sym_positional_pattern_clause] = STATE(3147),
    [sym_property_pattern_clause] = STATE(3409),
    [sym__variable_designation] = STATE(4091),
    [sym_parenthesized_variable_designation] = STATE(3966),
    [sym__lambda_parameters] = STATE(9890),
    [sym_identifier] = STATE(4070),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3082),
    [sym_preproc_endregion] = STATE(3082),
    [sym_preproc_line] = STATE(3082),
    [sym_preproc_pragma] = STATE(3082),
    [sym_preproc_nullable] = STATE(3082),
    [sym_preproc_error] = STATE(3082),
    [sym_preproc_warning] = STATE(3082),
    [sym_preproc_define] = STATE(3082),
    [sym_preproc_undef] = STATE(3082),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4357),
    [anon_sym_LPAREN] = ACTIONS(4357),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4355),
    [anon_sym_GT] = ACTIONS(4355),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4355),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4355),
    [anon_sym_PLUS_PLUS] = ACTIONS(4357),
    [anon_sym_DASH_DASH] = ACTIONS(4357),
    [anon_sym_PLUS] = ACTIONS(4355),
    [anon_sym_DASH] = ACTIONS(4355),
    [anon_sym_STAR] = ACTIONS(4357),
    [anon_sym_SLASH] = ACTIONS(4355),
    [anon_sym_PERCENT] = ACTIONS(4357),
    [anon_sym_CARET] = ACTIONS(4357),
    [anon_sym_PIPE] = ACTIONS(4355),
    [anon_sym_AMP] = ACTIONS(4355),
    [anon_sym_LT_LT] = ACTIONS(4357),
    [anon_sym_GT_GT] = ACTIONS(4355),
    [anon_sym_GT_GT_GT] = ACTIONS(4357),
    [anon_sym_EQ_EQ] = ACTIONS(4357),
    [anon_sym_BANG_EQ] = ACTIONS(4357),
    [anon_sym_GT_EQ] = ACTIONS(4357),
    [anon_sym_LT_EQ] = ACTIONS(4357),
    [anon_sym_DOT] = ACTIONS(4355),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4355),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4347),
    [anon_sym_DOT_DOT] = ACTIONS(4357),
    [anon_sym_and] = ACTIONS(4355),
    [anon_sym_or] = ACTIONS(4355),
    [anon_sym_AMP_AMP] = ACTIONS(4357),
    [anon_sym_PIPE_PIPE] = ACTIONS(4357),
    [anon_sym_QMARK_QMARK] = ACTIONS(4357),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4355),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4355),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4355),
    [anon_sym_is] = ACTIONS(4355),
    [anon_sym_DASH_GT] = ACTIONS(4357),
    [anon_sym_with] = ACTIONS(4355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3083] = {
    [sym_parameter_list] = STATE(9685),
    [sym_positional_pattern_clause] = STATE(3162),
    [sym_property_pattern_clause] = STATE(3278),
    [sym__variable_designation] = STATE(4162),
    [sym_parenthesized_variable_designation] = STATE(4153),
    [sym__lambda_parameters] = STATE(9890),
    [sym_identifier] = STATE(4163),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3083),
    [sym_preproc_endregion] = STATE(3083),
    [sym_preproc_line] = STATE(3083),
    [sym_preproc_pragma] = STATE(3083),
    [sym_preproc_nullable] = STATE(3083),
    [sym_preproc_error] = STATE(3083),
    [sym_preproc_warning] = STATE(3083),
    [sym_preproc_define] = STATE(3083),
    [sym_preproc_undef] = STATE(3083),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4341),
    [anon_sym_LPAREN] = ACTIONS(4341),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4345),
    [anon_sym_GT] = ACTIONS(4345),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4345),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4345),
    [anon_sym_PLUS_PLUS] = ACTIONS(4341),
    [anon_sym_DASH_DASH] = ACTIONS(4341),
    [anon_sym_PLUS] = ACTIONS(4345),
    [anon_sym_DASH] = ACTIONS(4345),
    [anon_sym_STAR] = ACTIONS(4341),
    [anon_sym_SLASH] = ACTIONS(4345),
    [anon_sym_PERCENT] = ACTIONS(4341),
    [anon_sym_CARET] = ACTIONS(4341),
    [anon_sym_PIPE] = ACTIONS(4345),
    [anon_sym_AMP] = ACTIONS(4345),
    [anon_sym_LT_LT] = ACTIONS(4341),
    [anon_sym_GT_GT] = ACTIONS(4345),
    [anon_sym_GT_GT_GT] = ACTIONS(4341),
    [anon_sym_EQ_EQ] = ACTIONS(4341),
    [anon_sym_BANG_EQ] = ACTIONS(4341),
    [anon_sym_GT_EQ] = ACTIONS(4341),
    [anon_sym_LT_EQ] = ACTIONS(4341),
    [anon_sym_DOT] = ACTIONS(4345),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4345),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4359),
    [anon_sym_DOT_DOT] = ACTIONS(4341),
    [anon_sym_and] = ACTIONS(4355),
    [anon_sym_or] = ACTIONS(4355),
    [anon_sym_AMP_AMP] = ACTIONS(4341),
    [anon_sym_PIPE_PIPE] = ACTIONS(4341),
    [anon_sym_QMARK_QMARK] = ACTIONS(4341),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4339),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4345),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4345),
    [anon_sym_is] = ACTIONS(4345),
    [anon_sym_DASH_GT] = ACTIONS(4341),
    [anon_sym_with] = ACTIONS(4345),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3084] = {
    [sym_property_pattern_clause] = STATE(3139),
    [sym__variable_designation] = STATE(5784),
    [sym_parenthesized_variable_designation] = STATE(5773),
    [sym_identifier] = STATE(5775),
    [sym__reserved_identifier] = STATE(5200),
    [sym_preproc_region] = STATE(3084),
    [sym_preproc_endregion] = STATE(3084),
    [sym_preproc_line] = STATE(3084),
    [sym_preproc_pragma] = STATE(3084),
    [sym_preproc_nullable] = STATE(3084),
    [sym_preproc_error] = STATE(3084),
    [sym_preproc_warning] = STATE(3084),
    [sym_preproc_define] = STATE(3084),
    [sym_preproc_undef] = STATE(3084),
    [sym__identifier_token] = ACTIONS(4575),
    [anon_sym_alias] = ACTIONS(4577),
    [anon_sym_global] = ACTIONS(4577),
    [anon_sym_LBRACK] = ACTIONS(4399),
    [anon_sym_COLON] = ACTIONS(4399),
    [anon_sym_COMMA] = ACTIONS(4399),
    [anon_sym_LPAREN] = ACTIONS(4399),
    [anon_sym_LBRACE] = ACTIONS(4579),
    [anon_sym_file] = ACTIONS(4577),
    [anon_sym_LT] = ACTIONS(4401),
    [anon_sym_GT] = ACTIONS(4401),
    [anon_sym_where] = ACTIONS(4577),
    [anon_sym_QMARK] = ACTIONS(4401),
    [anon_sym_notnull] = ACTIONS(4577),
    [anon_sym_unmanaged] = ACTIONS(4577),
    [anon_sym_BANG] = ACTIONS(4401),
    [anon_sym_PLUS_PLUS] = ACTIONS(4399),
    [anon_sym_DASH_DASH] = ACTIONS(4399),
    [anon_sym_PLUS] = ACTIONS(4401),
    [anon_sym_DASH] = ACTIONS(4401),
    [anon_sym_STAR] = ACTIONS(4399),
    [anon_sym_SLASH] = ACTIONS(4401),
    [anon_sym_PERCENT] = ACTIONS(4399),
    [anon_sym_CARET] = ACTIONS(4399),
    [anon_sym_PIPE] = ACTIONS(4401),
    [anon_sym_AMP] = ACTIONS(4401),
    [anon_sym_LT_LT] = ACTIONS(4399),
    [anon_sym_GT_GT] = ACTIONS(4401),
    [anon_sym_GT_GT_GT] = ACTIONS(4399),
    [anon_sym_EQ_EQ] = ACTIONS(4399),
    [anon_sym_BANG_EQ] = ACTIONS(4399),
    [anon_sym_GT_EQ] = ACTIONS(4399),
    [anon_sym_LT_EQ] = ACTIONS(4399),
    [anon_sym_DOT] = ACTIONS(4401),
    [anon_sym_scoped] = ACTIONS(4577),
    [anon_sym_var] = ACTIONS(4577),
    [anon_sym_yield] = ACTIONS(4577),
    [anon_sym_switch] = ACTIONS(4401),
    [anon_sym_when] = ACTIONS(4577),
    [sym_discard] = ACTIONS(4581),
    [anon_sym_DOT_DOT] = ACTIONS(4399),
    [anon_sym_and] = ACTIONS(4401),
    [anon_sym_or] = ACTIONS(4401),
    [anon_sym_AMP_AMP] = ACTIONS(4399),
    [anon_sym_PIPE_PIPE] = ACTIONS(4399),
    [anon_sym_QMARK_QMARK] = ACTIONS(4399),
    [anon_sym_from] = ACTIONS(4577),
    [anon_sym_into] = ACTIONS(4577),
    [anon_sym_join] = ACTIONS(4577),
    [anon_sym_on] = ACTIONS(4577),
    [anon_sym_equals] = ACTIONS(4577),
    [anon_sym_let] = ACTIONS(4577),
    [anon_sym_orderby] = ACTIONS(4577),
    [anon_sym_ascending] = ACTIONS(4577),
    [anon_sym_descending] = ACTIONS(4577),
    [anon_sym_group] = ACTIONS(4577),
    [anon_sym_by] = ACTIONS(4577),
    [anon_sym_select] = ACTIONS(4577),
    [anon_sym_as] = ACTIONS(4401),
    [anon_sym_is] = ACTIONS(4401),
    [anon_sym_DASH_GT] = ACTIONS(4399),
    [anon_sym_with] = ACTIONS(4401),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4399),
  },
  [3085] = {
    [sym_property_pattern_clause] = STATE(3121),
    [sym__variable_designation] = STATE(5430),
    [sym_parenthesized_variable_designation] = STATE(5773),
    [sym_identifier] = STATE(5775),
    [sym__reserved_identifier] = STATE(5200),
    [sym_preproc_region] = STATE(3085),
    [sym_preproc_endregion] = STATE(3085),
    [sym_preproc_line] = STATE(3085),
    [sym_preproc_pragma] = STATE(3085),
    [sym_preproc_nullable] = STATE(3085),
    [sym_preproc_error] = STATE(3085),
    [sym_preproc_warning] = STATE(3085),
    [sym_preproc_define] = STATE(3085),
    [sym_preproc_undef] = STATE(3085),
    [sym__identifier_token] = ACTIONS(4575),
    [anon_sym_alias] = ACTIONS(4577),
    [anon_sym_global] = ACTIONS(4577),
    [anon_sym_LBRACK] = ACTIONS(4405),
    [anon_sym_COLON] = ACTIONS(4405),
    [anon_sym_COMMA] = ACTIONS(4405),
    [anon_sym_LPAREN] = ACTIONS(4405),
    [anon_sym_LBRACE] = ACTIONS(4579),
    [anon_sym_file] = ACTIONS(4577),
    [anon_sym_LT] = ACTIONS(4407),
    [anon_sym_GT] = ACTIONS(4407),
    [anon_sym_where] = ACTIONS(4577),
    [anon_sym_QMARK] = ACTIONS(4407),
    [anon_sym_notnull] = ACTIONS(4577),
    [anon_sym_unmanaged] = ACTIONS(4577),
    [anon_sym_BANG] = ACTIONS(4407),
    [anon_sym_PLUS_PLUS] = ACTIONS(4405),
    [anon_sym_DASH_DASH] = ACTIONS(4405),
    [anon_sym_PLUS] = ACTIONS(4407),
    [anon_sym_DASH] = ACTIONS(4407),
    [anon_sym_STAR] = ACTIONS(4405),
    [anon_sym_SLASH] = ACTIONS(4407),
    [anon_sym_PERCENT] = ACTIONS(4405),
    [anon_sym_CARET] = ACTIONS(4405),
    [anon_sym_PIPE] = ACTIONS(4407),
    [anon_sym_AMP] = ACTIONS(4407),
    [anon_sym_LT_LT] = ACTIONS(4405),
    [anon_sym_GT_GT] = ACTIONS(4407),
    [anon_sym_GT_GT_GT] = ACTIONS(4405),
    [anon_sym_EQ_EQ] = ACTIONS(4405),
    [anon_sym_BANG_EQ] = ACTIONS(4405),
    [anon_sym_GT_EQ] = ACTIONS(4405),
    [anon_sym_LT_EQ] = ACTIONS(4405),
    [anon_sym_DOT] = ACTIONS(4407),
    [anon_sym_scoped] = ACTIONS(4577),
    [anon_sym_var] = ACTIONS(4577),
    [anon_sym_yield] = ACTIONS(4577),
    [anon_sym_switch] = ACTIONS(4407),
    [anon_sym_when] = ACTIONS(4577),
    [sym_discard] = ACTIONS(4581),
    [anon_sym_DOT_DOT] = ACTIONS(4405),
    [anon_sym_and] = ACTIONS(4407),
    [anon_sym_or] = ACTIONS(4407),
    [anon_sym_AMP_AMP] = ACTIONS(4405),
    [anon_sym_PIPE_PIPE] = ACTIONS(4405),
    [anon_sym_QMARK_QMARK] = ACTIONS(4405),
    [anon_sym_from] = ACTIONS(4577),
    [anon_sym_into] = ACTIONS(4577),
    [anon_sym_join] = ACTIONS(4577),
    [anon_sym_on] = ACTIONS(4577),
    [anon_sym_equals] = ACTIONS(4577),
    [anon_sym_let] = ACTIONS(4577),
    [anon_sym_orderby] = ACTIONS(4577),
    [anon_sym_ascending] = ACTIONS(4577),
    [anon_sym_descending] = ACTIONS(4577),
    [anon_sym_group] = ACTIONS(4577),
    [anon_sym_by] = ACTIONS(4577),
    [anon_sym_select] = ACTIONS(4577),
    [anon_sym_as] = ACTIONS(4407),
    [anon_sym_is] = ACTIONS(4407),
    [anon_sym_DASH_GT] = ACTIONS(4405),
    [anon_sym_with] = ACTIONS(4407),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4405),
  },
  [3086] = {
    [sym__name] = STATE(3748),
    [sym_alias_qualified_name] = STATE(3680),
    [sym__simple_name] = STATE(3680),
    [sym_qualified_name] = STATE(3680),
    [sym_generic_name] = STATE(3648),
    [sym_ref_type] = STATE(3643),
    [sym__scoped_base_type] = STATE(3647),
    [sym_identifier] = STATE(3590),
    [sym__reserved_identifier] = STATE(3625),
    [sym_preproc_region] = STATE(3086),
    [sym_preproc_endregion] = STATE(3086),
    [sym_preproc_line] = STATE(3086),
    [sym_preproc_pragma] = STATE(3086),
    [sym_preproc_nullable] = STATE(3086),
    [sym_preproc_error] = STATE(3086),
    [sym_preproc_warning] = STATE(3086),
    [sym_preproc_define] = STATE(3086),
    [sym_preproc_undef] = STATE(3086),
    [sym__identifier_token] = ACTIONS(4349),
    [anon_sym_alias] = ACTIONS(4351),
    [anon_sym_global] = ACTIONS(4351),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_LPAREN] = ACTIONS(3993),
    [anon_sym_ref] = ACTIONS(4729),
    [anon_sym_LBRACE] = ACTIONS(3993),
    [anon_sym_file] = ACTIONS(4351),
    [anon_sym_LT] = ACTIONS(3995),
    [anon_sym_GT] = ACTIONS(3995),
    [anon_sym_where] = ACTIONS(4351),
    [anon_sym_QMARK] = ACTIONS(3995),
    [anon_sym_notnull] = ACTIONS(4351),
    [anon_sym_unmanaged] = ACTIONS(4351),
    [anon_sym_BANG] = ACTIONS(3995),
    [anon_sym_PLUS_PLUS] = ACTIONS(3993),
    [anon_sym_DASH_DASH] = ACTIONS(3993),
    [anon_sym_PLUS] = ACTIONS(3995),
    [anon_sym_DASH] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3993),
    [anon_sym_SLASH] = ACTIONS(3995),
    [anon_sym_PERCENT] = ACTIONS(3993),
    [anon_sym_CARET] = ACTIONS(3993),
    [anon_sym_PIPE] = ACTIONS(3995),
    [anon_sym_AMP] = ACTIONS(3995),
    [anon_sym_LT_LT] = ACTIONS(3993),
    [anon_sym_GT_GT] = ACTIONS(3995),
    [anon_sym_GT_GT_GT] = ACTIONS(3993),
    [anon_sym_EQ_EQ] = ACTIONS(3993),
    [anon_sym_BANG_EQ] = ACTIONS(3993),
    [anon_sym_GT_EQ] = ACTIONS(3993),
    [anon_sym_LT_EQ] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3995),
    [anon_sym_scoped] = ACTIONS(4351),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(4351),
    [anon_sym_yield] = ACTIONS(4351),
    [anon_sym_switch] = ACTIONS(3995),
    [anon_sym_when] = ACTIONS(4351),
    [anon_sym_DOT_DOT] = ACTIONS(3993),
    [anon_sym_AMP_AMP] = ACTIONS(3993),
    [anon_sym_PIPE_PIPE] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK] = ACTIONS(3993),
    [anon_sym_from] = ACTIONS(4351),
    [anon_sym_into] = ACTIONS(4351),
    [anon_sym_join] = ACTIONS(4351),
    [anon_sym_on] = ACTIONS(4351),
    [anon_sym_equals] = ACTIONS(4351),
    [anon_sym_let] = ACTIONS(4351),
    [anon_sym_orderby] = ACTIONS(4351),
    [anon_sym_ascending] = ACTIONS(4351),
    [anon_sym_descending] = ACTIONS(4351),
    [anon_sym_group] = ACTIONS(4351),
    [anon_sym_by] = ACTIONS(4680),
    [anon_sym_select] = ACTIONS(4351),
    [anon_sym_as] = ACTIONS(3995),
    [anon_sym_is] = ACTIONS(3995),
    [anon_sym_DASH_GT] = ACTIONS(3993),
    [anon_sym_with] = ACTIONS(3995),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3087] = {
    [sym_parameter_list] = STATE(9685),
    [sym_positional_pattern_clause] = STATE(3144),
    [sym_property_pattern_clause] = STATE(3361),
    [sym__variable_designation] = STATE(5035),
    [sym_parenthesized_variable_designation] = STATE(5027),
    [sym__lambda_parameters] = STATE(9890),
    [sym_identifier] = STATE(4954),
    [sym__reserved_identifier] = STATE(3572),
    [sym_preproc_region] = STATE(3087),
    [sym_preproc_endregion] = STATE(3087),
    [sym_preproc_line] = STATE(3087),
    [sym_preproc_pragma] = STATE(3087),
    [sym_preproc_nullable] = STATE(3087),
    [sym_preproc_error] = STATE(3087),
    [sym_preproc_warning] = STATE(3087),
    [sym_preproc_define] = STATE(3087),
    [sym_preproc_undef] = STATE(3087),
    [sym__identifier_token] = ACTIONS(4328),
    [anon_sym_alias] = ACTIONS(4330),
    [anon_sym_global] = ACTIONS(4330),
    [anon_sym_LBRACK] = ACTIONS(4341),
    [anon_sym_LPAREN] = ACTIONS(4341),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_file] = ACTIONS(4330),
    [anon_sym_LT] = ACTIONS(4345),
    [anon_sym_GT] = ACTIONS(4345),
    [anon_sym_where] = ACTIONS(4345),
    [anon_sym_QMARK] = ACTIONS(4345),
    [anon_sym_notnull] = ACTIONS(4330),
    [anon_sym_unmanaged] = ACTIONS(4330),
    [anon_sym_BANG] = ACTIONS(4345),
    [anon_sym_PLUS_PLUS] = ACTIONS(4341),
    [anon_sym_DASH_DASH] = ACTIONS(4341),
    [anon_sym_PLUS] = ACTIONS(4345),
    [anon_sym_DASH] = ACTIONS(4345),
    [anon_sym_STAR] = ACTIONS(4341),
    [anon_sym_SLASH] = ACTIONS(4345),
    [anon_sym_PERCENT] = ACTIONS(4341),
    [anon_sym_CARET] = ACTIONS(4341),
    [anon_sym_PIPE] = ACTIONS(4345),
    [anon_sym_AMP] = ACTIONS(4345),
    [anon_sym_LT_LT] = ACTIONS(4341),
    [anon_sym_GT_GT] = ACTIONS(4345),
    [anon_sym_GT_GT_GT] = ACTIONS(4341),
    [anon_sym_EQ_EQ] = ACTIONS(4341),
    [anon_sym_BANG_EQ] = ACTIONS(4341),
    [anon_sym_GT_EQ] = ACTIONS(4341),
    [anon_sym_LT_EQ] = ACTIONS(4341),
    [anon_sym_DOT] = ACTIONS(4345),
    [anon_sym_scoped] = ACTIONS(4330),
    [anon_sym_var] = ACTIONS(4330),
    [anon_sym_yield] = ACTIONS(4330),
    [anon_sym_switch] = ACTIONS(4345),
    [anon_sym_when] = ACTIONS(4330),
    [sym_discard] = ACTIONS(4719),
    [anon_sym_DOT_DOT] = ACTIONS(4341),
    [anon_sym_and] = ACTIONS(4345),
    [anon_sym_or] = ACTIONS(4345),
    [anon_sym_AMP_AMP] = ACTIONS(4341),
    [anon_sym_PIPE_PIPE] = ACTIONS(4341),
    [anon_sym_QMARK_QMARK] = ACTIONS(4341),
    [anon_sym_from] = ACTIONS(4345),
    [anon_sym_into] = ACTIONS(4345),
    [anon_sym_join] = ACTIONS(4345),
    [anon_sym_on] = ACTIONS(4330),
    [anon_sym_equals] = ACTIONS(4330),
    [anon_sym_let] = ACTIONS(4345),
    [anon_sym_orderby] = ACTIONS(4345),
    [anon_sym_ascending] = ACTIONS(4330),
    [anon_sym_descending] = ACTIONS(4330),
    [anon_sym_group] = ACTIONS(4345),
    [anon_sym_by] = ACTIONS(4330),
    [anon_sym_select] = ACTIONS(4345),
    [anon_sym_as] = ACTIONS(4345),
    [anon_sym_is] = ACTIONS(4345),
    [anon_sym_DASH_GT] = ACTIONS(4341),
    [anon_sym_with] = ACTIONS(4345),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3088] = {
    [sym_parameter_list] = STATE(9685),
    [sym_positional_pattern_clause] = STATE(3162),
    [sym_property_pattern_clause] = STATE(3278),
    [sym__variable_designation] = STATE(4162),
    [sym_parenthesized_variable_designation] = STATE(4153),
    [sym__lambda_parameters] = STATE(9890),
    [sym_identifier] = STATE(4163),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3088),
    [sym_preproc_endregion] = STATE(3088),
    [sym_preproc_line] = STATE(3088),
    [sym_preproc_pragma] = STATE(3088),
    [sym_preproc_nullable] = STATE(3088),
    [sym_preproc_error] = STATE(3088),
    [sym_preproc_warning] = STATE(3088),
    [sym_preproc_define] = STATE(3088),
    [sym_preproc_undef] = STATE(3088),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4357),
    [anon_sym_LPAREN] = ACTIONS(4357),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4355),
    [anon_sym_GT] = ACTIONS(4355),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4355),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4355),
    [anon_sym_PLUS_PLUS] = ACTIONS(4357),
    [anon_sym_DASH_DASH] = ACTIONS(4357),
    [anon_sym_PLUS] = ACTIONS(4355),
    [anon_sym_DASH] = ACTIONS(4355),
    [anon_sym_STAR] = ACTIONS(4357),
    [anon_sym_SLASH] = ACTIONS(4355),
    [anon_sym_PERCENT] = ACTIONS(4357),
    [anon_sym_CARET] = ACTIONS(4357),
    [anon_sym_PIPE] = ACTIONS(4355),
    [anon_sym_AMP] = ACTIONS(4355),
    [anon_sym_LT_LT] = ACTIONS(4357),
    [anon_sym_GT_GT] = ACTIONS(4355),
    [anon_sym_GT_GT_GT] = ACTIONS(4357),
    [anon_sym_EQ_EQ] = ACTIONS(4357),
    [anon_sym_BANG_EQ] = ACTIONS(4357),
    [anon_sym_GT_EQ] = ACTIONS(4357),
    [anon_sym_LT_EQ] = ACTIONS(4357),
    [anon_sym_DOT] = ACTIONS(4355),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4355),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4359),
    [anon_sym_DOT_DOT] = ACTIONS(4357),
    [anon_sym_and] = ACTIONS(4355),
    [anon_sym_or] = ACTIONS(4355),
    [anon_sym_AMP_AMP] = ACTIONS(4357),
    [anon_sym_PIPE_PIPE] = ACTIONS(4357),
    [anon_sym_QMARK_QMARK] = ACTIONS(4357),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4339),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4355),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4355),
    [anon_sym_is] = ACTIONS(4355),
    [anon_sym_DASH_GT] = ACTIONS(4357),
    [anon_sym_with] = ACTIONS(4355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3089] = {
    [sym_parameter_list] = STATE(9685),
    [sym_positional_pattern_clause] = STATE(3171),
    [sym_property_pattern_clause] = STATE(3424),
    [sym__variable_designation] = STATE(4091),
    [sym_parenthesized_variable_designation] = STATE(3966),
    [sym__lambda_parameters] = STATE(9890),
    [sym_identifier] = STATE(4070),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3089),
    [sym_preproc_endregion] = STATE(3089),
    [sym_preproc_line] = STATE(3089),
    [sym_preproc_pragma] = STATE(3089),
    [sym_preproc_nullable] = STATE(3089),
    [sym_preproc_error] = STATE(3089),
    [sym_preproc_warning] = STATE(3089),
    [sym_preproc_define] = STATE(3089),
    [sym_preproc_undef] = STATE(3089),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4341),
    [anon_sym_LPAREN] = ACTIONS(4341),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4345),
    [anon_sym_GT] = ACTIONS(4345),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4345),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4345),
    [anon_sym_PLUS_PLUS] = ACTIONS(4341),
    [anon_sym_DASH_DASH] = ACTIONS(4341),
    [anon_sym_PLUS] = ACTIONS(4345),
    [anon_sym_DASH] = ACTIONS(4345),
    [anon_sym_STAR] = ACTIONS(4341),
    [anon_sym_SLASH] = ACTIONS(4345),
    [anon_sym_PERCENT] = ACTIONS(4341),
    [anon_sym_CARET] = ACTIONS(4341),
    [anon_sym_PIPE] = ACTIONS(4345),
    [anon_sym_AMP] = ACTIONS(4345),
    [anon_sym_LT_LT] = ACTIONS(4341),
    [anon_sym_GT_GT] = ACTIONS(4345),
    [anon_sym_GT_GT_GT] = ACTIONS(4341),
    [anon_sym_EQ_EQ] = ACTIONS(4341),
    [anon_sym_BANG_EQ] = ACTIONS(4341),
    [anon_sym_GT_EQ] = ACTIONS(4341),
    [anon_sym_LT_EQ] = ACTIONS(4341),
    [anon_sym_DOT] = ACTIONS(4345),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4345),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4347),
    [anon_sym_DOT_DOT] = ACTIONS(4341),
    [anon_sym_and] = ACTIONS(4345),
    [anon_sym_or] = ACTIONS(4345),
    [anon_sym_AMP_AMP] = ACTIONS(4341),
    [anon_sym_PIPE_PIPE] = ACTIONS(4341),
    [anon_sym_QMARK_QMARK] = ACTIONS(4341),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4345),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4345),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4345),
    [anon_sym_is] = ACTIONS(4345),
    [anon_sym_DASH_GT] = ACTIONS(4341),
    [anon_sym_with] = ACTIONS(4345),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3090] = {
    [sym_parameter_list] = STATE(9685),
    [sym_positional_pattern_clause] = STATE(3161),
    [sym_property_pattern_clause] = STATE(3442),
    [sym__variable_designation] = STATE(5035),
    [sym_parenthesized_variable_designation] = STATE(5027),
    [sym__lambda_parameters] = STATE(9890),
    [sym_identifier] = STATE(4954),
    [sym__reserved_identifier] = STATE(3625),
    [sym_preproc_region] = STATE(3090),
    [sym_preproc_endregion] = STATE(3090),
    [sym_preproc_line] = STATE(3090),
    [sym_preproc_pragma] = STATE(3090),
    [sym_preproc_nullable] = STATE(3090),
    [sym_preproc_error] = STATE(3090),
    [sym_preproc_warning] = STATE(3090),
    [sym_preproc_define] = STATE(3090),
    [sym_preproc_undef] = STATE(3090),
    [sym__identifier_token] = ACTIONS(4349),
    [anon_sym_alias] = ACTIONS(4351),
    [anon_sym_global] = ACTIONS(4351),
    [anon_sym_LBRACK] = ACTIONS(4357),
    [anon_sym_LPAREN] = ACTIONS(4357),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_file] = ACTIONS(4351),
    [anon_sym_LT] = ACTIONS(4355),
    [anon_sym_GT] = ACTIONS(4355),
    [anon_sym_where] = ACTIONS(4355),
    [anon_sym_QMARK] = ACTIONS(4355),
    [anon_sym_notnull] = ACTIONS(4351),
    [anon_sym_unmanaged] = ACTIONS(4351),
    [anon_sym_BANG] = ACTIONS(4355),
    [anon_sym_PLUS_PLUS] = ACTIONS(4357),
    [anon_sym_DASH_DASH] = ACTIONS(4357),
    [anon_sym_PLUS] = ACTIONS(4355),
    [anon_sym_DASH] = ACTIONS(4355),
    [anon_sym_STAR] = ACTIONS(4357),
    [anon_sym_SLASH] = ACTIONS(4355),
    [anon_sym_PERCENT] = ACTIONS(4357),
    [anon_sym_CARET] = ACTIONS(4357),
    [anon_sym_PIPE] = ACTIONS(4355),
    [anon_sym_AMP] = ACTIONS(4355),
    [anon_sym_LT_LT] = ACTIONS(4357),
    [anon_sym_GT_GT] = ACTIONS(4355),
    [anon_sym_GT_GT_GT] = ACTIONS(4357),
    [anon_sym_EQ_EQ] = ACTIONS(4357),
    [anon_sym_BANG_EQ] = ACTIONS(4357),
    [anon_sym_GT_EQ] = ACTIONS(4357),
    [anon_sym_LT_EQ] = ACTIONS(4357),
    [anon_sym_DOT] = ACTIONS(4355),
    [anon_sym_scoped] = ACTIONS(4351),
    [anon_sym_var] = ACTIONS(4351),
    [anon_sym_yield] = ACTIONS(4351),
    [anon_sym_switch] = ACTIONS(4355),
    [anon_sym_when] = ACTIONS(4351),
    [sym_discard] = ACTIONS(4719),
    [anon_sym_DOT_DOT] = ACTIONS(4357),
    [anon_sym_and] = ACTIONS(4355),
    [anon_sym_or] = ACTIONS(4355),
    [anon_sym_AMP_AMP] = ACTIONS(4357),
    [anon_sym_PIPE_PIPE] = ACTIONS(4357),
    [anon_sym_QMARK_QMARK] = ACTIONS(4357),
    [anon_sym_from] = ACTIONS(4355),
    [anon_sym_into] = ACTIONS(4351),
    [anon_sym_join] = ACTIONS(4355),
    [anon_sym_on] = ACTIONS(4351),
    [anon_sym_equals] = ACTIONS(4351),
    [anon_sym_let] = ACTIONS(4355),
    [anon_sym_orderby] = ACTIONS(4355),
    [anon_sym_ascending] = ACTIONS(4351),
    [anon_sym_descending] = ACTIONS(4351),
    [anon_sym_group] = ACTIONS(4355),
    [anon_sym_by] = ACTIONS(4351),
    [anon_sym_select] = ACTIONS(4355),
    [anon_sym_as] = ACTIONS(4355),
    [anon_sym_is] = ACTIONS(4355),
    [anon_sym_DASH_GT] = ACTIONS(4357),
    [anon_sym_with] = ACTIONS(4355),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3091] = {
    [sym__name] = STATE(4348),
    [sym_alias_qualified_name] = STATE(3588),
    [sym__simple_name] = STATE(3588),
    [sym_qualified_name] = STATE(3588),
    [sym_generic_name] = STATE(3597),
    [sym_ref_type] = STATE(3601),
    [sym__scoped_base_type] = STATE(3606),
    [sym_identifier] = STATE(4004),
    [sym__reserved_identifier] = STATE(3572),
    [sym_preproc_region] = STATE(3091),
    [sym_preproc_endregion] = STATE(3091),
    [sym_preproc_line] = STATE(3091),
    [sym_preproc_pragma] = STATE(3091),
    [sym_preproc_nullable] = STATE(3091),
    [sym_preproc_error] = STATE(3091),
    [sym_preproc_warning] = STATE(3091),
    [sym_preproc_define] = STATE(3091),
    [sym_preproc_undef] = STATE(3091),
    [sym__identifier_token] = ACTIONS(4328),
    [anon_sym_alias] = ACTIONS(4330),
    [anon_sym_global] = ACTIONS(4330),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_LPAREN] = ACTIONS(3993),
    [anon_sym_ref] = ACTIONS(4731),
    [anon_sym_LBRACE] = ACTIONS(3993),
    [anon_sym_file] = ACTIONS(4330),
    [anon_sym_LT] = ACTIONS(3995),
    [anon_sym_GT] = ACTIONS(3995),
    [anon_sym_where] = ACTIONS(4330),
    [anon_sym_QMARK] = ACTIONS(3995),
    [anon_sym_notnull] = ACTIONS(4330),
    [anon_sym_unmanaged] = ACTIONS(4330),
    [anon_sym_BANG] = ACTIONS(3995),
    [anon_sym_PLUS_PLUS] = ACTIONS(3993),
    [anon_sym_DASH_DASH] = ACTIONS(3993),
    [anon_sym_PLUS] = ACTIONS(3995),
    [anon_sym_DASH] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3993),
    [anon_sym_SLASH] = ACTIONS(3995),
    [anon_sym_PERCENT] = ACTIONS(3993),
    [anon_sym_CARET] = ACTIONS(3993),
    [anon_sym_PIPE] = ACTIONS(3995),
    [anon_sym_AMP] = ACTIONS(3995),
    [anon_sym_LT_LT] = ACTIONS(3993),
    [anon_sym_GT_GT] = ACTIONS(3995),
    [anon_sym_GT_GT_GT] = ACTIONS(3993),
    [anon_sym_EQ_EQ] = ACTIONS(3993),
    [anon_sym_BANG_EQ] = ACTIONS(3993),
    [anon_sym_GT_EQ] = ACTIONS(3993),
    [anon_sym_LT_EQ] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3995),
    [anon_sym_scoped] = ACTIONS(4330),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(4330),
    [anon_sym_yield] = ACTIONS(4330),
    [anon_sym_switch] = ACTIONS(3995),
    [anon_sym_when] = ACTIONS(4330),
    [anon_sym_DOT_DOT] = ACTIONS(3993),
    [anon_sym_AMP_AMP] = ACTIONS(3993),
    [anon_sym_PIPE_PIPE] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK] = ACTIONS(3993),
    [anon_sym_from] = ACTIONS(4330),
    [anon_sym_into] = ACTIONS(4334),
    [anon_sym_join] = ACTIONS(4330),
    [anon_sym_on] = ACTIONS(4330),
    [anon_sym_equals] = ACTIONS(4334),
    [anon_sym_let] = ACTIONS(4330),
    [anon_sym_orderby] = ACTIONS(4330),
    [anon_sym_ascending] = ACTIONS(4330),
    [anon_sym_descending] = ACTIONS(4330),
    [anon_sym_group] = ACTIONS(4330),
    [anon_sym_by] = ACTIONS(4330),
    [anon_sym_select] = ACTIONS(4330),
    [anon_sym_as] = ACTIONS(3995),
    [anon_sym_is] = ACTIONS(3995),
    [anon_sym_DASH_GT] = ACTIONS(3993),
    [anon_sym_with] = ACTIONS(3995),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3092] = {
    [sym_modifier] = STATE(4634),
    [sym_variable_declaration] = STATE(9010),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7112),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3092),
    [sym_preproc_endregion] = STATE(3092),
    [sym_preproc_line] = STATE(3092),
    [sym_preproc_pragma] = STATE(3092),
    [sym_preproc_nullable] = STATE(3092),
    [sym_preproc_error] = STATE(3092),
    [sym_preproc_warning] = STATE(3092),
    [sym_preproc_define] = STATE(3092),
    [sym_preproc_undef] = STATE(3092),
    [aux_sym_class_declaration_repeat2] = STATE(4397),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_unsafe] = ACTIONS(661),
    [anon_sym_static] = ACTIONS(661),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(661),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(4534),
    [anon_sym_fixed] = ACTIONS(661),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(661),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3093] = {
    [sym_modifier] = STATE(4634),
    [sym_variable_declaration] = STATE(9537),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7112),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3093),
    [sym_preproc_endregion] = STATE(3093),
    [sym_preproc_line] = STATE(3093),
    [sym_preproc_pragma] = STATE(3093),
    [sym_preproc_nullable] = STATE(3093),
    [sym_preproc_error] = STATE(3093),
    [sym_preproc_warning] = STATE(3093),
    [sym_preproc_define] = STATE(3093),
    [sym_preproc_undef] = STATE(3093),
    [aux_sym_class_declaration_repeat2] = STATE(4397),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_unsafe] = ACTIONS(661),
    [anon_sym_static] = ACTIONS(661),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(661),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(4534),
    [anon_sym_fixed] = ACTIONS(661),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(661),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3094] = {
    [sym_modifier] = STATE(4634),
    [sym_variable_declaration] = STATE(9599),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7109),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3094),
    [sym_preproc_endregion] = STATE(3094),
    [sym_preproc_line] = STATE(3094),
    [sym_preproc_pragma] = STATE(3094),
    [sym_preproc_nullable] = STATE(3094),
    [sym_preproc_error] = STATE(3094),
    [sym_preproc_warning] = STATE(3094),
    [sym_preproc_define] = STATE(3094),
    [sym_preproc_undef] = STATE(3094),
    [aux_sym_class_declaration_repeat2] = STATE(4397),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_unsafe] = ACTIONS(661),
    [anon_sym_static] = ACTIONS(661),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(661),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(4534),
    [anon_sym_fixed] = ACTIONS(661),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(661),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3095] = {
    [sym_modifier] = STATE(4634),
    [sym_variable_declaration] = STATE(9759),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7112),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3095),
    [sym_preproc_endregion] = STATE(3095),
    [sym_preproc_line] = STATE(3095),
    [sym_preproc_pragma] = STATE(3095),
    [sym_preproc_nullable] = STATE(3095),
    [sym_preproc_error] = STATE(3095),
    [sym_preproc_warning] = STATE(3095),
    [sym_preproc_define] = STATE(3095),
    [sym_preproc_undef] = STATE(3095),
    [aux_sym_class_declaration_repeat2] = STATE(4397),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_unsafe] = ACTIONS(661),
    [anon_sym_static] = ACTIONS(661),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(661),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(4534),
    [anon_sym_fixed] = ACTIONS(661),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(661),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3096] = {
    [sym_parameter_list] = STATE(9685),
    [sym__lambda_parameters] = STATE(9890),
    [sym_identifier] = STATE(9119),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_region] = STATE(3096),
    [sym_preproc_endregion] = STATE(3096),
    [sym_preproc_line] = STATE(3096),
    [sym_preproc_pragma] = STATE(3096),
    [sym_preproc_nullable] = STATE(3096),
    [sym_preproc_error] = STATE(3096),
    [sym_preproc_warning] = STATE(3096),
    [sym_preproc_define] = STATE(3096),
    [sym_preproc_undef] = STATE(3096),
    [sym__identifier_token] = ACTIONS(4431),
    [anon_sym_alias] = ACTIONS(4431),
    [anon_sym_global] = ACTIONS(4431),
    [anon_sym_LBRACK] = ACTIONS(4433),
    [anon_sym_COLON] = ACTIONS(4433),
    [anon_sym_COMMA] = ACTIONS(4433),
    [anon_sym_LPAREN] = ACTIONS(4433),
    [anon_sym_LBRACE] = ACTIONS(4433),
    [anon_sym_file] = ACTIONS(4431),
    [anon_sym_LT] = ACTIONS(4431),
    [anon_sym_GT] = ACTIONS(4431),
    [anon_sym_where] = ACTIONS(4431),
    [anon_sym_QMARK] = ACTIONS(4431),
    [anon_sym_notnull] = ACTIONS(4431),
    [anon_sym_unmanaged] = ACTIONS(4431),
    [anon_sym_BANG] = ACTIONS(4431),
    [anon_sym_PLUS_PLUS] = ACTIONS(4433),
    [anon_sym_DASH_DASH] = ACTIONS(4433),
    [anon_sym_PLUS] = ACTIONS(4431),
    [anon_sym_DASH] = ACTIONS(4431),
    [anon_sym_STAR] = ACTIONS(4433),
    [anon_sym_SLASH] = ACTIONS(4431),
    [anon_sym_PERCENT] = ACTIONS(4433),
    [anon_sym_CARET] = ACTIONS(4433),
    [anon_sym_PIPE] = ACTIONS(4431),
    [anon_sym_AMP] = ACTIONS(4431),
    [anon_sym_LT_LT] = ACTIONS(4433),
    [anon_sym_GT_GT] = ACTIONS(4431),
    [anon_sym_GT_GT_GT] = ACTIONS(4433),
    [anon_sym_EQ_EQ] = ACTIONS(4433),
    [anon_sym_BANG_EQ] = ACTIONS(4433),
    [anon_sym_GT_EQ] = ACTIONS(4433),
    [anon_sym_LT_EQ] = ACTIONS(4433),
    [anon_sym_DOT] = ACTIONS(4431),
    [anon_sym_scoped] = ACTIONS(4431),
    [anon_sym_var] = ACTIONS(4431),
    [anon_sym_yield] = ACTIONS(4431),
    [anon_sym_switch] = ACTIONS(4431),
    [anon_sym_when] = ACTIONS(4431),
    [sym_discard] = ACTIONS(4431),
    [anon_sym_DOT_DOT] = ACTIONS(4433),
    [anon_sym_and] = ACTIONS(4431),
    [anon_sym_or] = ACTIONS(4431),
    [anon_sym_AMP_AMP] = ACTIONS(4433),
    [anon_sym_PIPE_PIPE] = ACTIONS(4433),
    [anon_sym_QMARK_QMARK] = ACTIONS(4433),
    [anon_sym_from] = ACTIONS(4431),
    [anon_sym_into] = ACTIONS(4431),
    [anon_sym_join] = ACTIONS(4431),
    [anon_sym_on] = ACTIONS(4431),
    [anon_sym_equals] = ACTIONS(4431),
    [anon_sym_let] = ACTIONS(4431),
    [anon_sym_orderby] = ACTIONS(4431),
    [anon_sym_ascending] = ACTIONS(4431),
    [anon_sym_descending] = ACTIONS(4431),
    [anon_sym_group] = ACTIONS(4431),
    [anon_sym_by] = ACTIONS(4431),
    [anon_sym_select] = ACTIONS(4431),
    [anon_sym_as] = ACTIONS(4431),
    [anon_sym_is] = ACTIONS(4431),
    [anon_sym_DASH_GT] = ACTIONS(4433),
    [anon_sym_with] = ACTIONS(4431),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4433),
  },
  [3097] = {
    [sym_modifier] = STATE(4634),
    [sym_variable_declaration] = STATE(9117),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7136),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3097),
    [sym_preproc_endregion] = STATE(3097),
    [sym_preproc_line] = STATE(3097),
    [sym_preproc_pragma] = STATE(3097),
    [sym_preproc_nullable] = STATE(3097),
    [sym_preproc_error] = STATE(3097),
    [sym_preproc_warning] = STATE(3097),
    [sym_preproc_define] = STATE(3097),
    [sym_preproc_undef] = STATE(3097),
    [aux_sym_class_declaration_repeat2] = STATE(4397),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_unsafe] = ACTIONS(661),
    [anon_sym_static] = ACTIONS(661),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(661),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(4534),
    [anon_sym_fixed] = ACTIONS(661),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(661),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3098] = {
    [sym_modifier] = STATE(4634),
    [sym_variable_declaration] = STATE(9010),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7112),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3098),
    [sym_preproc_endregion] = STATE(3098),
    [sym_preproc_line] = STATE(3098),
    [sym_preproc_pragma] = STATE(3098),
    [sym_preproc_nullable] = STATE(3098),
    [sym_preproc_error] = STATE(3098),
    [sym_preproc_warning] = STATE(3098),
    [sym_preproc_define] = STATE(3098),
    [sym_preproc_undef] = STATE(3098),
    [aux_sym_class_declaration_repeat2] = STATE(3101),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_unsafe] = ACTIONS(661),
    [anon_sym_static] = ACTIONS(661),
    [anon_sym_LPAREN] = ACTIONS(4733),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(661),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(4534),
    [anon_sym_fixed] = ACTIONS(661),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(661),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3099] = {
    [sym_modifier] = STATE(4634),
    [sym_variable_declaration] = STATE(9599),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7112),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3099),
    [sym_preproc_endregion] = STATE(3099),
    [sym_preproc_line] = STATE(3099),
    [sym_preproc_pragma] = STATE(3099),
    [sym_preproc_nullable] = STATE(3099),
    [sym_preproc_error] = STATE(3099),
    [sym_preproc_warning] = STATE(3099),
    [sym_preproc_define] = STATE(3099),
    [sym_preproc_undef] = STATE(3099),
    [aux_sym_class_declaration_repeat2] = STATE(3092),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_unsafe] = ACTIONS(661),
    [anon_sym_static] = ACTIONS(661),
    [anon_sym_LPAREN] = ACTIONS(4735),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(661),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(4534),
    [anon_sym_fixed] = ACTIONS(661),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(661),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3100] = {
    [sym_modifier] = STATE(4634),
    [sym_variable_declaration] = STATE(9594),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7112),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3100),
    [sym_preproc_endregion] = STATE(3100),
    [sym_preproc_line] = STATE(3100),
    [sym_preproc_pragma] = STATE(3100),
    [sym_preproc_nullable] = STATE(3100),
    [sym_preproc_error] = STATE(3100),
    [sym_preproc_warning] = STATE(3100),
    [sym_preproc_define] = STATE(3100),
    [sym_preproc_undef] = STATE(3100),
    [aux_sym_class_declaration_repeat2] = STATE(4397),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_unsafe] = ACTIONS(661),
    [anon_sym_static] = ACTIONS(661),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(661),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(4534),
    [anon_sym_fixed] = ACTIONS(661),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(661),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3101] = {
    [sym_modifier] = STATE(4634),
    [sym_variable_declaration] = STATE(9340),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7112),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3101),
    [sym_preproc_endregion] = STATE(3101),
    [sym_preproc_line] = STATE(3101),
    [sym_preproc_pragma] = STATE(3101),
    [sym_preproc_nullable] = STATE(3101),
    [sym_preproc_error] = STATE(3101),
    [sym_preproc_warning] = STATE(3101),
    [sym_preproc_define] = STATE(3101),
    [sym_preproc_undef] = STATE(3101),
    [aux_sym_class_declaration_repeat2] = STATE(4397),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_unsafe] = ACTIONS(661),
    [anon_sym_static] = ACTIONS(661),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(661),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(4534),
    [anon_sym_fixed] = ACTIONS(661),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(661),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3102] = {
    [sym_modifier] = STATE(4634),
    [sym_variable_declaration] = STATE(9401),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7112),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3102),
    [sym_preproc_endregion] = STATE(3102),
    [sym_preproc_line] = STATE(3102),
    [sym_preproc_pragma] = STATE(3102),
    [sym_preproc_nullable] = STATE(3102),
    [sym_preproc_error] = STATE(3102),
    [sym_preproc_warning] = STATE(3102),
    [sym_preproc_define] = STATE(3102),
    [sym_preproc_undef] = STATE(3102),
    [aux_sym_class_declaration_repeat2] = STATE(3100),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_unsafe] = ACTIONS(661),
    [anon_sym_static] = ACTIONS(661),
    [anon_sym_LPAREN] = ACTIONS(4737),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(661),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(4534),
    [anon_sym_fixed] = ACTIONS(661),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(661),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3103] = {
    [sym_property_pattern_clause] = STATE(3168),
    [sym__variable_designation] = STATE(4166),
    [sym_parenthesized_variable_designation] = STATE(4153),
    [sym_identifier] = STATE(4156),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3103),
    [sym_preproc_endregion] = STATE(3103),
    [sym_preproc_line] = STATE(3103),
    [sym_preproc_pragma] = STATE(3103),
    [sym_preproc_nullable] = STATE(3103),
    [sym_preproc_error] = STATE(3103),
    [sym_preproc_warning] = STATE(3103),
    [sym_preproc_define] = STATE(3103),
    [sym_preproc_undef] = STATE(3103),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4399),
    [anon_sym_COLON] = ACTIONS(4399),
    [anon_sym_LPAREN] = ACTIONS(4399),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4401),
    [anon_sym_GT] = ACTIONS(4401),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4401),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4401),
    [anon_sym_PLUS_PLUS] = ACTIONS(4399),
    [anon_sym_DASH_DASH] = ACTIONS(4399),
    [anon_sym_PLUS] = ACTIONS(4401),
    [anon_sym_DASH] = ACTIONS(4401),
    [anon_sym_STAR] = ACTIONS(4399),
    [anon_sym_SLASH] = ACTIONS(4401),
    [anon_sym_PERCENT] = ACTIONS(4399),
    [anon_sym_CARET] = ACTIONS(4399),
    [anon_sym_PIPE] = ACTIONS(4401),
    [anon_sym_AMP] = ACTIONS(4401),
    [anon_sym_LT_LT] = ACTIONS(4399),
    [anon_sym_GT_GT] = ACTIONS(4401),
    [anon_sym_GT_GT_GT] = ACTIONS(4399),
    [anon_sym_EQ_EQ] = ACTIONS(4399),
    [anon_sym_BANG_EQ] = ACTIONS(4399),
    [anon_sym_GT_EQ] = ACTIONS(4399),
    [anon_sym_LT_EQ] = ACTIONS(4399),
    [anon_sym_DOT] = ACTIONS(4401),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_EQ_GT] = ACTIONS(4399),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4401),
    [anon_sym_when] = ACTIONS(4401),
    [sym_discard] = ACTIONS(4359),
    [anon_sym_DOT_DOT] = ACTIONS(4399),
    [anon_sym_and] = ACTIONS(4401),
    [anon_sym_or] = ACTIONS(4401),
    [anon_sym_AMP_AMP] = ACTIONS(4399),
    [anon_sym_PIPE_PIPE] = ACTIONS(4399),
    [anon_sym_QMARK_QMARK] = ACTIONS(4399),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4339),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4401),
    [anon_sym_is] = ACTIONS(4401),
    [anon_sym_DASH_GT] = ACTIONS(4399),
    [anon_sym_with] = ACTIONS(4401),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3104] = {
    [sym_argument_list] = STATE(3594),
    [sym__name] = STATE(3744),
    [sym_alias_qualified_name] = STATE(3680),
    [sym__simple_name] = STATE(3680),
    [sym_qualified_name] = STATE(3680),
    [sym_generic_name] = STATE(3648),
    [sym_type] = STATE(4138),
    [sym_implicit_type] = STATE(3707),
    [sym_array_type] = STATE(3586),
    [sym__array_base_type] = STATE(8829),
    [sym_nullable_type] = STATE(3681),
    [sym_pointer_type] = STATE(3681),
    [sym__pointer_base_type] = STATE(9538),
    [sym_function_pointer_type] = STATE(3681),
    [sym_ref_type] = STATE(3707),
    [sym_scoped_type] = STATE(3707),
    [sym_tuple_type] = STATE(3631),
    [sym_identifier] = STATE(3590),
    [sym__reserved_identifier] = STATE(3625),
    [sym_preproc_region] = STATE(3104),
    [sym_preproc_endregion] = STATE(3104),
    [sym_preproc_line] = STATE(3104),
    [sym_preproc_pragma] = STATE(3104),
    [sym_preproc_nullable] = STATE(3104),
    [sym_preproc_error] = STATE(3104),
    [sym_preproc_warning] = STATE(3104),
    [sym_preproc_define] = STATE(3104),
    [sym_preproc_undef] = STATE(3104),
    [sym__identifier_token] = ACTIONS(4349),
    [anon_sym_extern] = ACTIONS(4042),
    [anon_sym_alias] = ACTIONS(4351),
    [anon_sym_global] = ACTIONS(4351),
    [anon_sym_unsafe] = ACTIONS(4042),
    [anon_sym_static] = ACTIONS(4042),
    [anon_sym_LBRACK] = ACTIONS(4506),
    [anon_sym_LPAREN] = ACTIONS(4508),
    [anon_sym_ref] = ACTIONS(4353),
    [anon_sym_LBRACE] = ACTIONS(4510),
    [anon_sym_delegate] = ACTIONS(4512),
    [anon_sym_abstract] = ACTIONS(4042),
    [anon_sym_async] = ACTIONS(4042),
    [anon_sym_const] = ACTIONS(4042),
    [anon_sym_file] = ACTIONS(4351),
    [anon_sym_fixed] = ACTIONS(4042),
    [anon_sym_internal] = ACTIONS(4042),
    [anon_sym_new] = ACTIONS(4042),
    [anon_sym_override] = ACTIONS(4042),
    [anon_sym_partial] = ACTIONS(4042),
    [anon_sym_private] = ACTIONS(4042),
    [anon_sym_protected] = ACTIONS(4042),
    [anon_sym_public] = ACTIONS(4042),
    [anon_sym_readonly] = ACTIONS(4042),
    [anon_sym_required] = ACTIONS(4042),
    [anon_sym_sealed] = ACTIONS(4042),
    [anon_sym_virtual] = ACTIONS(4042),
    [anon_sym_volatile] = ACTIONS(4042),
    [anon_sym_where] = ACTIONS(4351),
    [anon_sym_notnull] = ACTIONS(4351),
    [anon_sym_unmanaged] = ACTIONS(4351),
    [anon_sym_scoped] = ACTIONS(4514),
    [anon_sym_var] = ACTIONS(4516),
    [sym_predefined_type] = ACTIONS(4518),
    [anon_sym_yield] = ACTIONS(4351),
    [anon_sym_when] = ACTIONS(4351),
    [anon_sym_from] = ACTIONS(4351),
    [anon_sym_into] = ACTIONS(4351),
    [anon_sym_join] = ACTIONS(4351),
    [anon_sym_on] = ACTIONS(4351),
    [anon_sym_equals] = ACTIONS(4351),
    [anon_sym_let] = ACTIONS(4351),
    [anon_sym_orderby] = ACTIONS(4351),
    [anon_sym_ascending] = ACTIONS(4351),
    [anon_sym_descending] = ACTIONS(4351),
    [anon_sym_group] = ACTIONS(4351),
    [anon_sym_by] = ACTIONS(4351),
    [anon_sym_select] = ACTIONS(4351),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3105] = {
    [sym_modifier] = STATE(4634),
    [sym_variable_declaration] = STATE(9406),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7112),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3105),
    [sym_preproc_endregion] = STATE(3105),
    [sym_preproc_line] = STATE(3105),
    [sym_preproc_pragma] = STATE(3105),
    [sym_preproc_nullable] = STATE(3105),
    [sym_preproc_error] = STATE(3105),
    [sym_preproc_warning] = STATE(3105),
    [sym_preproc_define] = STATE(3105),
    [sym_preproc_undef] = STATE(3105),
    [aux_sym_class_declaration_repeat2] = STATE(4397),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_unsafe] = ACTIONS(661),
    [anon_sym_static] = ACTIONS(661),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(661),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(4534),
    [anon_sym_fixed] = ACTIONS(661),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(661),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3106] = {
    [sym_property_pattern_clause] = STATE(3149),
    [sym__variable_designation] = STATE(4088),
    [sym_parenthesized_variable_designation] = STATE(3966),
    [sym_identifier] = STATE(3983),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3106),
    [sym_preproc_endregion] = STATE(3106),
    [sym_preproc_line] = STATE(3106),
    [sym_preproc_pragma] = STATE(3106),
    [sym_preproc_nullable] = STATE(3106),
    [sym_preproc_error] = STATE(3106),
    [sym_preproc_warning] = STATE(3106),
    [sym_preproc_define] = STATE(3106),
    [sym_preproc_undef] = STATE(3106),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4405),
    [anon_sym_COLON] = ACTIONS(4405),
    [anon_sym_LPAREN] = ACTIONS(4405),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4407),
    [anon_sym_GT] = ACTIONS(4407),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4407),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4407),
    [anon_sym_PLUS_PLUS] = ACTIONS(4405),
    [anon_sym_DASH_DASH] = ACTIONS(4405),
    [anon_sym_PLUS] = ACTIONS(4407),
    [anon_sym_DASH] = ACTIONS(4407),
    [anon_sym_STAR] = ACTIONS(4405),
    [anon_sym_SLASH] = ACTIONS(4407),
    [anon_sym_PERCENT] = ACTIONS(4405),
    [anon_sym_CARET] = ACTIONS(4405),
    [anon_sym_PIPE] = ACTIONS(4407),
    [anon_sym_AMP] = ACTIONS(4407),
    [anon_sym_LT_LT] = ACTIONS(4405),
    [anon_sym_GT_GT] = ACTIONS(4407),
    [anon_sym_GT_GT_GT] = ACTIONS(4405),
    [anon_sym_EQ_EQ] = ACTIONS(4405),
    [anon_sym_BANG_EQ] = ACTIONS(4405),
    [anon_sym_GT_EQ] = ACTIONS(4405),
    [anon_sym_LT_EQ] = ACTIONS(4405),
    [anon_sym_DOT] = ACTIONS(4407),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_EQ_GT] = ACTIONS(4405),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4407),
    [anon_sym_when] = ACTIONS(4407),
    [sym_discard] = ACTIONS(4347),
    [anon_sym_DOT_DOT] = ACTIONS(4405),
    [anon_sym_and] = ACTIONS(4407),
    [anon_sym_or] = ACTIONS(4407),
    [anon_sym_AMP_AMP] = ACTIONS(4405),
    [anon_sym_PIPE_PIPE] = ACTIONS(4405),
    [anon_sym_QMARK_QMARK] = ACTIONS(4405),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4407),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4407),
    [anon_sym_is] = ACTIONS(4407),
    [anon_sym_DASH_GT] = ACTIONS(4405),
    [anon_sym_with] = ACTIONS(4407),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3107] = {
    [sym_modifier] = STATE(4634),
    [sym_variable_declaration] = STATE(9594),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7112),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3107),
    [sym_preproc_endregion] = STATE(3107),
    [sym_preproc_line] = STATE(3107),
    [sym_preproc_pragma] = STATE(3107),
    [sym_preproc_nullable] = STATE(3107),
    [sym_preproc_error] = STATE(3107),
    [sym_preproc_warning] = STATE(3107),
    [sym_preproc_define] = STATE(3107),
    [sym_preproc_undef] = STATE(3107),
    [aux_sym_class_declaration_repeat2] = STATE(3113),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_unsafe] = ACTIONS(661),
    [anon_sym_static] = ACTIONS(661),
    [anon_sym_LPAREN] = ACTIONS(4739),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(661),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(4534),
    [anon_sym_fixed] = ACTIONS(661),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(661),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3108] = {
    [sym_modifier] = STATE(4634),
    [sym_variable_declaration] = STATE(9401),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(6978),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3108),
    [sym_preproc_endregion] = STATE(3108),
    [sym_preproc_line] = STATE(3108),
    [sym_preproc_pragma] = STATE(3108),
    [sym_preproc_nullable] = STATE(3108),
    [sym_preproc_error] = STATE(3108),
    [sym_preproc_warning] = STATE(3108),
    [sym_preproc_define] = STATE(3108),
    [sym_preproc_undef] = STATE(3108),
    [aux_sym_class_declaration_repeat2] = STATE(4397),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_unsafe] = ACTIONS(661),
    [anon_sym_static] = ACTIONS(661),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(661),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(4534),
    [anon_sym_fixed] = ACTIONS(661),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(661),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3109] = {
    [sym_modifier] = STATE(4634),
    [sym_variable_declaration] = STATE(9406),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7112),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3109),
    [sym_preproc_endregion] = STATE(3109),
    [sym_preproc_line] = STATE(3109),
    [sym_preproc_pragma] = STATE(3109),
    [sym_preproc_nullable] = STATE(3109),
    [sym_preproc_error] = STATE(3109),
    [sym_preproc_warning] = STATE(3109),
    [sym_preproc_define] = STATE(3109),
    [sym_preproc_undef] = STATE(3109),
    [aux_sym_class_declaration_repeat2] = STATE(3117),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_unsafe] = ACTIONS(661),
    [anon_sym_static] = ACTIONS(661),
    [anon_sym_LPAREN] = ACTIONS(4741),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(661),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(4534),
    [anon_sym_fixed] = ACTIONS(661),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(661),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3110] = {
    [sym_modifier] = STATE(4634),
    [sym_variable_declaration] = STATE(9401),
    [sym__name] = STATE(6942),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7112),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(6773),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3110),
    [sym_preproc_endregion] = STATE(3110),
    [sym_preproc_line] = STATE(3110),
    [sym_preproc_pragma] = STATE(3110),
    [sym_preproc_nullable] = STATE(3110),
    [sym_preproc_error] = STATE(3110),
    [sym_preproc_warning] = STATE(3110),
    [sym_preproc_define] = STATE(3110),
    [sym_preproc_undef] = STATE(3110),
    [aux_sym_class_declaration_repeat2] = STATE(3100),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_unsafe] = ACTIONS(4743),
    [anon_sym_static] = ACTIONS(4745),
    [anon_sym_LPAREN] = ACTIONS(4737),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(661),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(4534),
    [anon_sym_fixed] = ACTIONS(661),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(661),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3111] = {
    [sym_property_pattern_clause] = STATE(3155),
    [sym__variable_designation] = STATE(4161),
    [sym_parenthesized_variable_designation] = STATE(4153),
    [sym_identifier] = STATE(4156),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3111),
    [sym_preproc_endregion] = STATE(3111),
    [sym_preproc_line] = STATE(3111),
    [sym_preproc_pragma] = STATE(3111),
    [sym_preproc_nullable] = STATE(3111),
    [sym_preproc_error] = STATE(3111),
    [sym_preproc_warning] = STATE(3111),
    [sym_preproc_define] = STATE(3111),
    [sym_preproc_undef] = STATE(3111),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4405),
    [anon_sym_COLON] = ACTIONS(4405),
    [anon_sym_LPAREN] = ACTIONS(4405),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4407),
    [anon_sym_GT] = ACTIONS(4407),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4407),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4407),
    [anon_sym_PLUS_PLUS] = ACTIONS(4405),
    [anon_sym_DASH_DASH] = ACTIONS(4405),
    [anon_sym_PLUS] = ACTIONS(4407),
    [anon_sym_DASH] = ACTIONS(4407),
    [anon_sym_STAR] = ACTIONS(4405),
    [anon_sym_SLASH] = ACTIONS(4407),
    [anon_sym_PERCENT] = ACTIONS(4405),
    [anon_sym_CARET] = ACTIONS(4405),
    [anon_sym_PIPE] = ACTIONS(4407),
    [anon_sym_AMP] = ACTIONS(4407),
    [anon_sym_LT_LT] = ACTIONS(4405),
    [anon_sym_GT_GT] = ACTIONS(4407),
    [anon_sym_GT_GT_GT] = ACTIONS(4405),
    [anon_sym_EQ_EQ] = ACTIONS(4405),
    [anon_sym_BANG_EQ] = ACTIONS(4405),
    [anon_sym_GT_EQ] = ACTIONS(4405),
    [anon_sym_LT_EQ] = ACTIONS(4405),
    [anon_sym_DOT] = ACTIONS(4407),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_EQ_GT] = ACTIONS(4405),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4407),
    [anon_sym_when] = ACTIONS(4407),
    [sym_discard] = ACTIONS(4359),
    [anon_sym_DOT_DOT] = ACTIONS(4405),
    [anon_sym_and] = ACTIONS(4407),
    [anon_sym_or] = ACTIONS(4407),
    [anon_sym_AMP_AMP] = ACTIONS(4405),
    [anon_sym_PIPE_PIPE] = ACTIONS(4405),
    [anon_sym_QMARK_QMARK] = ACTIONS(4405),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4339),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4407),
    [anon_sym_is] = ACTIONS(4407),
    [anon_sym_DASH_GT] = ACTIONS(4405),
    [anon_sym_with] = ACTIONS(4407),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3112] = {
    [sym_argument_list] = STATE(3594),
    [sym__name] = STATE(3744),
    [sym_alias_qualified_name] = STATE(3680),
    [sym__simple_name] = STATE(3680),
    [sym_qualified_name] = STATE(3680),
    [sym_generic_name] = STATE(3648),
    [sym_type] = STATE(4138),
    [sym_implicit_type] = STATE(3707),
    [sym_array_type] = STATE(5141),
    [sym__array_base_type] = STATE(8829),
    [sym_nullable_type] = STATE(3681),
    [sym_pointer_type] = STATE(3681),
    [sym__pointer_base_type] = STATE(9538),
    [sym_function_pointer_type] = STATE(3681),
    [sym_ref_type] = STATE(3707),
    [sym_scoped_type] = STATE(3707),
    [sym_tuple_type] = STATE(3631),
    [sym_identifier] = STATE(3590),
    [sym__reserved_identifier] = STATE(3625),
    [sym_preproc_region] = STATE(3112),
    [sym_preproc_endregion] = STATE(3112),
    [sym_preproc_line] = STATE(3112),
    [sym_preproc_pragma] = STATE(3112),
    [sym_preproc_nullable] = STATE(3112),
    [sym_preproc_error] = STATE(3112),
    [sym_preproc_warning] = STATE(3112),
    [sym_preproc_define] = STATE(3112),
    [sym_preproc_undef] = STATE(3112),
    [sym__identifier_token] = ACTIONS(4349),
    [anon_sym_extern] = ACTIONS(4042),
    [anon_sym_alias] = ACTIONS(4351),
    [anon_sym_global] = ACTIONS(4351),
    [anon_sym_unsafe] = ACTIONS(4042),
    [anon_sym_static] = ACTIONS(4042),
    [anon_sym_LBRACK] = ACTIONS(4506),
    [anon_sym_LPAREN] = ACTIONS(4508),
    [anon_sym_ref] = ACTIONS(4353),
    [anon_sym_LBRACE] = ACTIONS(4510),
    [anon_sym_delegate] = ACTIONS(4512),
    [anon_sym_abstract] = ACTIONS(4042),
    [anon_sym_async] = ACTIONS(4042),
    [anon_sym_const] = ACTIONS(4042),
    [anon_sym_file] = ACTIONS(4351),
    [anon_sym_fixed] = ACTIONS(4042),
    [anon_sym_internal] = ACTIONS(4042),
    [anon_sym_new] = ACTIONS(4042),
    [anon_sym_override] = ACTIONS(4042),
    [anon_sym_partial] = ACTIONS(4042),
    [anon_sym_private] = ACTIONS(4042),
    [anon_sym_protected] = ACTIONS(4042),
    [anon_sym_public] = ACTIONS(4042),
    [anon_sym_readonly] = ACTIONS(4042),
    [anon_sym_required] = ACTIONS(4042),
    [anon_sym_sealed] = ACTIONS(4042),
    [anon_sym_virtual] = ACTIONS(4042),
    [anon_sym_volatile] = ACTIONS(4042),
    [anon_sym_where] = ACTIONS(4351),
    [anon_sym_notnull] = ACTIONS(4351),
    [anon_sym_unmanaged] = ACTIONS(4351),
    [anon_sym_scoped] = ACTIONS(4514),
    [anon_sym_var] = ACTIONS(4516),
    [sym_predefined_type] = ACTIONS(4518),
    [anon_sym_yield] = ACTIONS(4351),
    [anon_sym_when] = ACTIONS(4351),
    [anon_sym_from] = ACTIONS(4351),
    [anon_sym_into] = ACTIONS(4351),
    [anon_sym_join] = ACTIONS(4351),
    [anon_sym_on] = ACTIONS(4351),
    [anon_sym_equals] = ACTIONS(4351),
    [anon_sym_let] = ACTIONS(4351),
    [anon_sym_orderby] = ACTIONS(4351),
    [anon_sym_ascending] = ACTIONS(4351),
    [anon_sym_descending] = ACTIONS(4351),
    [anon_sym_group] = ACTIONS(4351),
    [anon_sym_by] = ACTIONS(4351),
    [anon_sym_select] = ACTIONS(4351),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3113] = {
    [sym_modifier] = STATE(4634),
    [sym_variable_declaration] = STATE(9732),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7112),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3113),
    [sym_preproc_endregion] = STATE(3113),
    [sym_preproc_line] = STATE(3113),
    [sym_preproc_pragma] = STATE(3113),
    [sym_preproc_nullable] = STATE(3113),
    [sym_preproc_error] = STATE(3113),
    [sym_preproc_warning] = STATE(3113),
    [sym_preproc_define] = STATE(3113),
    [sym_preproc_undef] = STATE(3113),
    [aux_sym_class_declaration_repeat2] = STATE(4397),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_unsafe] = ACTIONS(661),
    [anon_sym_static] = ACTIONS(661),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(661),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(4534),
    [anon_sym_fixed] = ACTIONS(661),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(661),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3114] = {
    [sym_modifier] = STATE(4634),
    [sym_variable_declaration] = STATE(9387),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7112),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3114),
    [sym_preproc_endregion] = STATE(3114),
    [sym_preproc_line] = STATE(3114),
    [sym_preproc_pragma] = STATE(3114),
    [sym_preproc_nullable] = STATE(3114),
    [sym_preproc_error] = STATE(3114),
    [sym_preproc_warning] = STATE(3114),
    [sym_preproc_define] = STATE(3114),
    [sym_preproc_undef] = STATE(3114),
    [aux_sym_class_declaration_repeat2] = STATE(3093),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_unsafe] = ACTIONS(661),
    [anon_sym_static] = ACTIONS(661),
    [anon_sym_LPAREN] = ACTIONS(4747),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(661),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(4534),
    [anon_sym_fixed] = ACTIONS(661),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(661),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3115] = {
    [sym_modifier] = STATE(4634),
    [sym_variable_declaration] = STATE(9387),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7090),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3115),
    [sym_preproc_endregion] = STATE(3115),
    [sym_preproc_line] = STATE(3115),
    [sym_preproc_pragma] = STATE(3115),
    [sym_preproc_nullable] = STATE(3115),
    [sym_preproc_error] = STATE(3115),
    [sym_preproc_warning] = STATE(3115),
    [sym_preproc_define] = STATE(3115),
    [sym_preproc_undef] = STATE(3115),
    [aux_sym_class_declaration_repeat2] = STATE(4397),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_unsafe] = ACTIONS(661),
    [anon_sym_static] = ACTIONS(661),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(661),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(4534),
    [anon_sym_fixed] = ACTIONS(661),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(661),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3116] = {
    [sym_modifier] = STATE(4634),
    [sym_variable_declaration] = STATE(9537),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7112),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3116),
    [sym_preproc_endregion] = STATE(3116),
    [sym_preproc_line] = STATE(3116),
    [sym_preproc_pragma] = STATE(3116),
    [sym_preproc_nullable] = STATE(3116),
    [sym_preproc_error] = STATE(3116),
    [sym_preproc_warning] = STATE(3116),
    [sym_preproc_define] = STATE(3116),
    [sym_preproc_undef] = STATE(3116),
    [aux_sym_class_declaration_repeat2] = STATE(3095),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_unsafe] = ACTIONS(661),
    [anon_sym_static] = ACTIONS(661),
    [anon_sym_LPAREN] = ACTIONS(4749),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(661),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(4534),
    [anon_sym_fixed] = ACTIONS(661),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(661),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3117] = {
    [sym_modifier] = STATE(4634),
    [sym_variable_declaration] = STATE(9307),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7112),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3117),
    [sym_preproc_endregion] = STATE(3117),
    [sym_preproc_line] = STATE(3117),
    [sym_preproc_pragma] = STATE(3117),
    [sym_preproc_nullable] = STATE(3117),
    [sym_preproc_error] = STATE(3117),
    [sym_preproc_warning] = STATE(3117),
    [sym_preproc_define] = STATE(3117),
    [sym_preproc_undef] = STATE(3117),
    [aux_sym_class_declaration_repeat2] = STATE(4397),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_unsafe] = ACTIONS(661),
    [anon_sym_static] = ACTIONS(661),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(661),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(4534),
    [anon_sym_fixed] = ACTIONS(661),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(661),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3118] = {
    [sym_modifier] = STATE(4634),
    [sym_variable_declaration] = STATE(9117),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7112),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3118),
    [sym_preproc_endregion] = STATE(3118),
    [sym_preproc_line] = STATE(3118),
    [sym_preproc_pragma] = STATE(3118),
    [sym_preproc_nullable] = STATE(3118),
    [sym_preproc_error] = STATE(3118),
    [sym_preproc_warning] = STATE(3118),
    [sym_preproc_define] = STATE(3118),
    [sym_preproc_undef] = STATE(3118),
    [aux_sym_class_declaration_repeat2] = STATE(3105),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_unsafe] = ACTIONS(661),
    [anon_sym_static] = ACTIONS(661),
    [anon_sym_LPAREN] = ACTIONS(4751),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(661),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(4534),
    [anon_sym_fixed] = ACTIONS(661),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(661),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3119] = {
    [sym_modifier] = STATE(4634),
    [sym_variable_declaration] = STATE(9117),
    [sym__name] = STATE(6938),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7112),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(6766),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3119),
    [sym_preproc_endregion] = STATE(3119),
    [sym_preproc_line] = STATE(3119),
    [sym_preproc_pragma] = STATE(3119),
    [sym_preproc_nullable] = STATE(3119),
    [sym_preproc_error] = STATE(3119),
    [sym_preproc_warning] = STATE(3119),
    [sym_preproc_define] = STATE(3119),
    [sym_preproc_undef] = STATE(3119),
    [aux_sym_class_declaration_repeat2] = STATE(3105),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_unsafe] = ACTIONS(4753),
    [anon_sym_static] = ACTIONS(4755),
    [anon_sym_LPAREN] = ACTIONS(4751),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(661),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(4534),
    [anon_sym_fixed] = ACTIONS(661),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(661),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3120] = {
    [sym_property_pattern_clause] = STATE(3146),
    [sym__variable_designation] = STATE(4035),
    [sym_parenthesized_variable_designation] = STATE(3966),
    [sym_identifier] = STATE(3983),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3120),
    [sym_preproc_endregion] = STATE(3120),
    [sym_preproc_line] = STATE(3120),
    [sym_preproc_pragma] = STATE(3120),
    [sym_preproc_nullable] = STATE(3120),
    [sym_preproc_error] = STATE(3120),
    [sym_preproc_warning] = STATE(3120),
    [sym_preproc_define] = STATE(3120),
    [sym_preproc_undef] = STATE(3120),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4399),
    [anon_sym_COLON] = ACTIONS(4399),
    [anon_sym_LPAREN] = ACTIONS(4399),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4401),
    [anon_sym_GT] = ACTIONS(4401),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4401),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4401),
    [anon_sym_PLUS_PLUS] = ACTIONS(4399),
    [anon_sym_DASH_DASH] = ACTIONS(4399),
    [anon_sym_PLUS] = ACTIONS(4401),
    [anon_sym_DASH] = ACTIONS(4401),
    [anon_sym_STAR] = ACTIONS(4399),
    [anon_sym_SLASH] = ACTIONS(4401),
    [anon_sym_PERCENT] = ACTIONS(4399),
    [anon_sym_CARET] = ACTIONS(4399),
    [anon_sym_PIPE] = ACTIONS(4401),
    [anon_sym_AMP] = ACTIONS(4401),
    [anon_sym_LT_LT] = ACTIONS(4399),
    [anon_sym_GT_GT] = ACTIONS(4401),
    [anon_sym_GT_GT_GT] = ACTIONS(4399),
    [anon_sym_EQ_EQ] = ACTIONS(4399),
    [anon_sym_BANG_EQ] = ACTIONS(4399),
    [anon_sym_GT_EQ] = ACTIONS(4399),
    [anon_sym_LT_EQ] = ACTIONS(4399),
    [anon_sym_DOT] = ACTIONS(4401),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_EQ_GT] = ACTIONS(4399),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4401),
    [anon_sym_when] = ACTIONS(4401),
    [sym_discard] = ACTIONS(4347),
    [anon_sym_DOT_DOT] = ACTIONS(4399),
    [anon_sym_and] = ACTIONS(4401),
    [anon_sym_or] = ACTIONS(4401),
    [anon_sym_AMP_AMP] = ACTIONS(4399),
    [anon_sym_PIPE_PIPE] = ACTIONS(4399),
    [anon_sym_QMARK_QMARK] = ACTIONS(4399),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4401),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4401),
    [anon_sym_is] = ACTIONS(4401),
    [anon_sym_DASH_GT] = ACTIONS(4399),
    [anon_sym_with] = ACTIONS(4401),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3121] = {
    [sym__variable_designation] = STATE(5437),
    [sym_parenthesized_variable_designation] = STATE(5773),
    [sym_identifier] = STATE(5775),
    [sym__reserved_identifier] = STATE(5200),
    [sym_preproc_region] = STATE(3121),
    [sym_preproc_endregion] = STATE(3121),
    [sym_preproc_line] = STATE(3121),
    [sym_preproc_pragma] = STATE(3121),
    [sym_preproc_nullable] = STATE(3121),
    [sym_preproc_error] = STATE(3121),
    [sym_preproc_warning] = STATE(3121),
    [sym_preproc_define] = STATE(3121),
    [sym_preproc_undef] = STATE(3121),
    [sym__identifier_token] = ACTIONS(4575),
    [anon_sym_alias] = ACTIONS(4577),
    [anon_sym_global] = ACTIONS(4577),
    [anon_sym_LBRACK] = ACTIONS(4441),
    [anon_sym_COLON] = ACTIONS(4441),
    [anon_sym_COMMA] = ACTIONS(4441),
    [anon_sym_LPAREN] = ACTIONS(4441),
    [anon_sym_file] = ACTIONS(4577),
    [anon_sym_LT] = ACTIONS(4443),
    [anon_sym_GT] = ACTIONS(4443),
    [anon_sym_where] = ACTIONS(4577),
    [anon_sym_QMARK] = ACTIONS(4443),
    [anon_sym_notnull] = ACTIONS(4577),
    [anon_sym_unmanaged] = ACTIONS(4577),
    [anon_sym_BANG] = ACTIONS(4443),
    [anon_sym_PLUS_PLUS] = ACTIONS(4441),
    [anon_sym_DASH_DASH] = ACTIONS(4441),
    [anon_sym_PLUS] = ACTIONS(4443),
    [anon_sym_DASH] = ACTIONS(4443),
    [anon_sym_STAR] = ACTIONS(4441),
    [anon_sym_SLASH] = ACTIONS(4443),
    [anon_sym_PERCENT] = ACTIONS(4441),
    [anon_sym_CARET] = ACTIONS(4441),
    [anon_sym_PIPE] = ACTIONS(4443),
    [anon_sym_AMP] = ACTIONS(4443),
    [anon_sym_LT_LT] = ACTIONS(4441),
    [anon_sym_GT_GT] = ACTIONS(4443),
    [anon_sym_GT_GT_GT] = ACTIONS(4441),
    [anon_sym_EQ_EQ] = ACTIONS(4441),
    [anon_sym_BANG_EQ] = ACTIONS(4441),
    [anon_sym_GT_EQ] = ACTIONS(4441),
    [anon_sym_LT_EQ] = ACTIONS(4441),
    [anon_sym_DOT] = ACTIONS(4443),
    [anon_sym_scoped] = ACTIONS(4577),
    [anon_sym_var] = ACTIONS(4577),
    [anon_sym_yield] = ACTIONS(4577),
    [anon_sym_switch] = ACTIONS(4443),
    [anon_sym_when] = ACTIONS(4577),
    [sym_discard] = ACTIONS(4581),
    [anon_sym_DOT_DOT] = ACTIONS(4441),
    [anon_sym_and] = ACTIONS(4443),
    [anon_sym_or] = ACTIONS(4443),
    [anon_sym_AMP_AMP] = ACTIONS(4441),
    [anon_sym_PIPE_PIPE] = ACTIONS(4441),
    [anon_sym_QMARK_QMARK] = ACTIONS(4441),
    [anon_sym_from] = ACTIONS(4577),
    [anon_sym_into] = ACTIONS(4577),
    [anon_sym_join] = ACTIONS(4577),
    [anon_sym_on] = ACTIONS(4577),
    [anon_sym_equals] = ACTIONS(4577),
    [anon_sym_let] = ACTIONS(4577),
    [anon_sym_orderby] = ACTIONS(4577),
    [anon_sym_ascending] = ACTIONS(4577),
    [anon_sym_descending] = ACTIONS(4577),
    [anon_sym_group] = ACTIONS(4577),
    [anon_sym_by] = ACTIONS(4577),
    [anon_sym_select] = ACTIONS(4577),
    [anon_sym_as] = ACTIONS(4443),
    [anon_sym_is] = ACTIONS(4443),
    [anon_sym_DASH_GT] = ACTIONS(4441),
    [anon_sym_with] = ACTIONS(4443),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4441),
  },
  [3122] = {
    [sym__variable_designation] = STATE(5431),
    [sym_parenthesized_variable_designation] = STATE(5773),
    [sym_identifier] = STATE(5775),
    [sym__reserved_identifier] = STATE(5200),
    [sym_preproc_region] = STATE(3122),
    [sym_preproc_endregion] = STATE(3122),
    [sym_preproc_line] = STATE(3122),
    [sym_preproc_pragma] = STATE(3122),
    [sym_preproc_nullable] = STATE(3122),
    [sym_preproc_error] = STATE(3122),
    [sym_preproc_warning] = STATE(3122),
    [sym_preproc_define] = STATE(3122),
    [sym_preproc_undef] = STATE(3122),
    [sym__identifier_token] = ACTIONS(4575),
    [anon_sym_alias] = ACTIONS(4577),
    [anon_sym_global] = ACTIONS(4577),
    [anon_sym_LBRACK] = ACTIONS(4405),
    [anon_sym_COLON] = ACTIONS(4405),
    [anon_sym_COMMA] = ACTIONS(4405),
    [anon_sym_LPAREN] = ACTIONS(4405),
    [anon_sym_file] = ACTIONS(4577),
    [anon_sym_LT] = ACTIONS(4407),
    [anon_sym_GT] = ACTIONS(4407),
    [anon_sym_where] = ACTIONS(4577),
    [anon_sym_QMARK] = ACTIONS(4407),
    [anon_sym_notnull] = ACTIONS(4577),
    [anon_sym_unmanaged] = ACTIONS(4577),
    [anon_sym_BANG] = ACTIONS(4407),
    [anon_sym_PLUS_PLUS] = ACTIONS(4405),
    [anon_sym_DASH_DASH] = ACTIONS(4405),
    [anon_sym_PLUS] = ACTIONS(4407),
    [anon_sym_DASH] = ACTIONS(4407),
    [anon_sym_STAR] = ACTIONS(4405),
    [anon_sym_SLASH] = ACTIONS(4407),
    [anon_sym_PERCENT] = ACTIONS(4405),
    [anon_sym_CARET] = ACTIONS(4405),
    [anon_sym_PIPE] = ACTIONS(4407),
    [anon_sym_AMP] = ACTIONS(4407),
    [anon_sym_LT_LT] = ACTIONS(4405),
    [anon_sym_GT_GT] = ACTIONS(4407),
    [anon_sym_GT_GT_GT] = ACTIONS(4405),
    [anon_sym_EQ_EQ] = ACTIONS(4405),
    [anon_sym_BANG_EQ] = ACTIONS(4405),
    [anon_sym_GT_EQ] = ACTIONS(4405),
    [anon_sym_LT_EQ] = ACTIONS(4405),
    [anon_sym_DOT] = ACTIONS(4407),
    [anon_sym_scoped] = ACTIONS(4577),
    [anon_sym_var] = ACTIONS(4577),
    [anon_sym_yield] = ACTIONS(4577),
    [anon_sym_switch] = ACTIONS(4407),
    [anon_sym_when] = ACTIONS(4577),
    [sym_discard] = ACTIONS(4581),
    [anon_sym_DOT_DOT] = ACTIONS(4405),
    [anon_sym_and] = ACTIONS(4407),
    [anon_sym_or] = ACTIONS(4407),
    [anon_sym_AMP_AMP] = ACTIONS(4405),
    [anon_sym_PIPE_PIPE] = ACTIONS(4405),
    [anon_sym_QMARK_QMARK] = ACTIONS(4405),
    [anon_sym_from] = ACTIONS(4577),
    [anon_sym_into] = ACTIONS(4577),
    [anon_sym_join] = ACTIONS(4577),
    [anon_sym_on] = ACTIONS(4577),
    [anon_sym_equals] = ACTIONS(4577),
    [anon_sym_let] = ACTIONS(4577),
    [anon_sym_orderby] = ACTIONS(4577),
    [anon_sym_ascending] = ACTIONS(4577),
    [anon_sym_descending] = ACTIONS(4577),
    [anon_sym_group] = ACTIONS(4577),
    [anon_sym_by] = ACTIONS(4577),
    [anon_sym_select] = ACTIONS(4577),
    [anon_sym_as] = ACTIONS(4407),
    [anon_sym_is] = ACTIONS(4407),
    [anon_sym_DASH_GT] = ACTIONS(4405),
    [anon_sym_with] = ACTIONS(4407),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4405),
  },
  [3123] = {
    [sym_type_argument_list] = STATE(2945),
    [sym_preproc_region] = STATE(3123),
    [sym_preproc_endregion] = STATE(3123),
    [sym_preproc_line] = STATE(3123),
    [sym_preproc_pragma] = STATE(3123),
    [sym_preproc_nullable] = STATE(3123),
    [sym_preproc_error] = STATE(3123),
    [sym_preproc_warning] = STATE(3123),
    [sym_preproc_define] = STATE(3123),
    [sym_preproc_undef] = STATE(3123),
    [sym__identifier_token] = ACTIONS(4138),
    [anon_sym_alias] = ACTIONS(4138),
    [anon_sym_global] = ACTIONS(4138),
    [anon_sym_LBRACK] = ACTIONS(4140),
    [anon_sym_COLON] = ACTIONS(4138),
    [anon_sym_COMMA] = ACTIONS(4140),
    [anon_sym_LPAREN] = ACTIONS(4140),
    [anon_sym_RPAREN] = ACTIONS(4140),
    [anon_sym_LBRACE] = ACTIONS(4140),
    [anon_sym_RBRACE] = ACTIONS(4140),
    [anon_sym_file] = ACTIONS(4138),
    [anon_sym_LT] = ACTIONS(4520),
    [anon_sym_GT] = ACTIONS(4138),
    [anon_sym_where] = ACTIONS(4138),
    [anon_sym_QMARK] = ACTIONS(4138),
    [anon_sym_notnull] = ACTIONS(4138),
    [anon_sym_unmanaged] = ACTIONS(4138),
    [anon_sym_BANG] = ACTIONS(4138),
    [anon_sym_PLUS_PLUS] = ACTIONS(4140),
    [anon_sym_DASH_DASH] = ACTIONS(4140),
    [anon_sym_PLUS] = ACTIONS(4138),
    [anon_sym_DASH] = ACTIONS(4138),
    [anon_sym_STAR] = ACTIONS(4140),
    [anon_sym_SLASH] = ACTIONS(4138),
    [anon_sym_PERCENT] = ACTIONS(4140),
    [anon_sym_CARET] = ACTIONS(4140),
    [anon_sym_PIPE] = ACTIONS(4138),
    [anon_sym_AMP] = ACTIONS(4138),
    [anon_sym_LT_LT] = ACTIONS(4140),
    [anon_sym_GT_GT] = ACTIONS(4138),
    [anon_sym_GT_GT_GT] = ACTIONS(4140),
    [anon_sym_EQ_EQ] = ACTIONS(4140),
    [anon_sym_BANG_EQ] = ACTIONS(4140),
    [anon_sym_GT_EQ] = ACTIONS(4140),
    [anon_sym_LT_EQ] = ACTIONS(4140),
    [anon_sym_DOT] = ACTIONS(4138),
    [anon_sym_scoped] = ACTIONS(4138),
    [anon_sym_COLON_COLON] = ACTIONS(4254),
    [anon_sym_var] = ACTIONS(4138),
    [anon_sym_yield] = ACTIONS(4138),
    [anon_sym_switch] = ACTIONS(4138),
    [anon_sym_when] = ACTIONS(4138),
    [sym_discard] = ACTIONS(4138),
    [anon_sym_DOT_DOT] = ACTIONS(4140),
    [anon_sym_and] = ACTIONS(4138),
    [anon_sym_or] = ACTIONS(4138),
    [anon_sym_AMP_AMP] = ACTIONS(4140),
    [anon_sym_PIPE_PIPE] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK] = ACTIONS(4140),
    [anon_sym_from] = ACTIONS(4138),
    [anon_sym_into] = ACTIONS(4138),
    [anon_sym_join] = ACTIONS(4138),
    [anon_sym_on] = ACTIONS(4138),
    [anon_sym_equals] = ACTIONS(4138),
    [anon_sym_let] = ACTIONS(4138),
    [anon_sym_orderby] = ACTIONS(4138),
    [anon_sym_ascending] = ACTIONS(4138),
    [anon_sym_descending] = ACTIONS(4138),
    [anon_sym_group] = ACTIONS(4138),
    [anon_sym_by] = ACTIONS(4138),
    [anon_sym_select] = ACTIONS(4138),
    [anon_sym_as] = ACTIONS(4138),
    [anon_sym_is] = ACTIONS(4138),
    [anon_sym_DASH_GT] = ACTIONS(4140),
    [anon_sym_with] = ACTIONS(4138),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3124] = {
    [sym_property_pattern_clause] = STATE(3225),
    [sym__variable_designation] = STATE(4166),
    [sym_parenthesized_variable_designation] = STATE(4153),
    [sym_identifier] = STATE(4156),
    [sym__reserved_identifier] = STATE(3911),
    [sym_preproc_region] = STATE(3124),
    [sym_preproc_endregion] = STATE(3124),
    [sym_preproc_line] = STATE(3124),
    [sym_preproc_pragma] = STATE(3124),
    [sym_preproc_nullable] = STATE(3124),
    [sym_preproc_error] = STATE(3124),
    [sym_preproc_warning] = STATE(3124),
    [sym_preproc_define] = STATE(3124),
    [sym_preproc_undef] = STATE(3124),
    [sym__identifier_token] = ACTIONS(4248),
    [anon_sym_alias] = ACTIONS(4250),
    [anon_sym_global] = ACTIONS(4250),
    [anon_sym_LBRACK] = ACTIONS(4399),
    [anon_sym_LPAREN] = ACTIONS(4399),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_file] = ACTIONS(4250),
    [anon_sym_LT] = ACTIONS(4401),
    [anon_sym_GT] = ACTIONS(4401),
    [anon_sym_in] = ACTIONS(4401),
    [anon_sym_where] = ACTIONS(4250),
    [anon_sym_QMARK] = ACTIONS(4401),
    [anon_sym_notnull] = ACTIONS(4250),
    [anon_sym_unmanaged] = ACTIONS(4250),
    [anon_sym_BANG] = ACTIONS(4401),
    [anon_sym_PLUS_PLUS] = ACTIONS(4399),
    [anon_sym_DASH_DASH] = ACTIONS(4399),
    [anon_sym_PLUS] = ACTIONS(4401),
    [anon_sym_DASH] = ACTIONS(4401),
    [anon_sym_STAR] = ACTIONS(4399),
    [anon_sym_SLASH] = ACTIONS(4401),
    [anon_sym_PERCENT] = ACTIONS(4399),
    [anon_sym_CARET] = ACTIONS(4399),
    [anon_sym_PIPE] = ACTIONS(4401),
    [anon_sym_AMP] = ACTIONS(4401),
    [anon_sym_LT_LT] = ACTIONS(4399),
    [anon_sym_GT_GT] = ACTIONS(4401),
    [anon_sym_GT_GT_GT] = ACTIONS(4399),
    [anon_sym_EQ_EQ] = ACTIONS(4399),
    [anon_sym_BANG_EQ] = ACTIONS(4399),
    [anon_sym_GT_EQ] = ACTIONS(4399),
    [anon_sym_LT_EQ] = ACTIONS(4399),
    [anon_sym_DOT] = ACTIONS(4401),
    [anon_sym_scoped] = ACTIONS(4250),
    [anon_sym_var] = ACTIONS(4250),
    [anon_sym_yield] = ACTIONS(4250),
    [anon_sym_switch] = ACTIONS(4401),
    [anon_sym_when] = ACTIONS(4250),
    [sym_discard] = ACTIONS(4359),
    [anon_sym_DOT_DOT] = ACTIONS(4399),
    [anon_sym_and] = ACTIONS(4401),
    [anon_sym_or] = ACTIONS(4401),
    [anon_sym_AMP_AMP] = ACTIONS(4399),
    [anon_sym_PIPE_PIPE] = ACTIONS(4399),
    [anon_sym_QMARK_QMARK] = ACTIONS(4399),
    [anon_sym_from] = ACTIONS(4250),
    [anon_sym_into] = ACTIONS(4250),
    [anon_sym_join] = ACTIONS(4250),
    [anon_sym_on] = ACTIONS(4250),
    [anon_sym_equals] = ACTIONS(4250),
    [anon_sym_let] = ACTIONS(4250),
    [anon_sym_orderby] = ACTIONS(4250),
    [anon_sym_ascending] = ACTIONS(4250),
    [anon_sym_descending] = ACTIONS(4250),
    [anon_sym_group] = ACTIONS(4250),
    [anon_sym_by] = ACTIONS(4250),
    [anon_sym_select] = ACTIONS(4250),
    [anon_sym_as] = ACTIONS(4401),
    [anon_sym_is] = ACTIONS(4401),
    [anon_sym_DASH_GT] = ACTIONS(4399),
    [anon_sym_with] = ACTIONS(4401),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3125] = {
    [sym_modifier] = STATE(4634),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7345),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3125),
    [sym_preproc_endregion] = STATE(3125),
    [sym_preproc_line] = STATE(3125),
    [sym_preproc_pragma] = STATE(3125),
    [sym_preproc_nullable] = STATE(3125),
    [sym_preproc_error] = STATE(3125),
    [sym_preproc_warning] = STATE(3125),
    [sym_preproc_define] = STATE(3125),
    [sym_preproc_undef] = STATE(3125),
    [aux_sym_class_declaration_repeat2] = STATE(4397),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_unsafe] = ACTIONS(661),
    [anon_sym_static] = ACTIONS(661),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(661),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(4757),
    [anon_sym_fixed] = ACTIONS(661),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(661),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3126] = {
    [sym_modifier] = STATE(4634),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7314),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3126),
    [sym_preproc_endregion] = STATE(3126),
    [sym_preproc_line] = STATE(3126),
    [sym_preproc_pragma] = STATE(3126),
    [sym_preproc_nullable] = STATE(3126),
    [sym_preproc_error] = STATE(3126),
    [sym_preproc_warning] = STATE(3126),
    [sym_preproc_define] = STATE(3126),
    [sym_preproc_undef] = STATE(3126),
    [aux_sym_class_declaration_repeat2] = STATE(4397),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_unsafe] = ACTIONS(661),
    [anon_sym_static] = ACTIONS(661),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(661),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(4757),
    [anon_sym_fixed] = ACTIONS(661),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(661),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3127] = {
    [sym_property_pattern_clause] = STATE(3185),
    [sym__variable_designation] = STATE(4555),
    [sym_parenthesized_variable_designation] = STATE(4748),
    [sym_identifier] = STATE(4548),
    [sym__reserved_identifier] = STATE(2928),
    [sym_preproc_region] = STATE(3127),
    [sym_preproc_endregion] = STATE(3127),
    [sym_preproc_line] = STATE(3127),
    [sym_preproc_pragma] = STATE(3127),
    [sym_preproc_nullable] = STATE(3127),
    [sym_preproc_error] = STATE(3127),
    [sym_preproc_warning] = STATE(3127),
    [sym_preproc_define] = STATE(3127),
    [sym_preproc_undef] = STATE(3127),
    [sym__identifier_token] = ACTIONS(4536),
    [anon_sym_alias] = ACTIONS(4538),
    [anon_sym_global] = ACTIONS(4538),
    [anon_sym_LBRACK] = ACTIONS(4399),
    [anon_sym_COMMA] = ACTIONS(4399),
    [anon_sym_LPAREN] = ACTIONS(4399),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_file] = ACTIONS(4538),
    [anon_sym_LT] = ACTIONS(4401),
    [anon_sym_GT] = ACTIONS(4401),
    [anon_sym_where] = ACTIONS(4401),
    [anon_sym_QMARK] = ACTIONS(4401),
    [anon_sym_notnull] = ACTIONS(4538),
    [anon_sym_unmanaged] = ACTIONS(4538),
    [anon_sym_BANG] = ACTIONS(4401),
    [anon_sym_PLUS_PLUS] = ACTIONS(4399),
    [anon_sym_DASH_DASH] = ACTIONS(4399),
    [anon_sym_PLUS] = ACTIONS(4401),
    [anon_sym_DASH] = ACTIONS(4401),
    [anon_sym_STAR] = ACTIONS(4399),
    [anon_sym_SLASH] = ACTIONS(4401),
    [anon_sym_PERCENT] = ACTIONS(4399),
    [anon_sym_CARET] = ACTIONS(4399),
    [anon_sym_PIPE] = ACTIONS(4401),
    [anon_sym_AMP] = ACTIONS(4401),
    [anon_sym_LT_LT] = ACTIONS(4399),
    [anon_sym_GT_GT] = ACTIONS(4401),
    [anon_sym_GT_GT_GT] = ACTIONS(4399),
    [anon_sym_EQ_EQ] = ACTIONS(4399),
    [anon_sym_BANG_EQ] = ACTIONS(4399),
    [anon_sym_GT_EQ] = ACTIONS(4399),
    [anon_sym_LT_EQ] = ACTIONS(4399),
    [anon_sym_DOT] = ACTIONS(4401),
    [anon_sym_scoped] = ACTIONS(4538),
    [anon_sym_var] = ACTIONS(4538),
    [anon_sym_yield] = ACTIONS(4538),
    [anon_sym_switch] = ACTIONS(4401),
    [anon_sym_when] = ACTIONS(4538),
    [sym_discard] = ACTIONS(4717),
    [anon_sym_DOT_DOT] = ACTIONS(4399),
    [anon_sym_and] = ACTIONS(4401),
    [anon_sym_or] = ACTIONS(4401),
    [anon_sym_AMP_AMP] = ACTIONS(4399),
    [anon_sym_PIPE_PIPE] = ACTIONS(4399),
    [anon_sym_QMARK_QMARK] = ACTIONS(4399),
    [anon_sym_from] = ACTIONS(4401),
    [anon_sym_into] = ACTIONS(4401),
    [anon_sym_join] = ACTIONS(4401),
    [anon_sym_on] = ACTIONS(4538),
    [anon_sym_equals] = ACTIONS(4538),
    [anon_sym_let] = ACTIONS(4401),
    [anon_sym_orderby] = ACTIONS(4401),
    [anon_sym_ascending] = ACTIONS(4401),
    [anon_sym_descending] = ACTIONS(4401),
    [anon_sym_group] = ACTIONS(4401),
    [anon_sym_by] = ACTIONS(4538),
    [anon_sym_select] = ACTIONS(4401),
    [anon_sym_as] = ACTIONS(4401),
    [anon_sym_is] = ACTIONS(4401),
    [anon_sym_DASH_GT] = ACTIONS(4399),
    [anon_sym_with] = ACTIONS(4401),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3128] = {
    [sym_property_pattern_clause] = STATE(3204),
    [sym__variable_designation] = STATE(4555),
    [sym_parenthesized_variable_designation] = STATE(4748),
    [sym_identifier] = STATE(4548),
    [sym__reserved_identifier] = STATE(2928),
    [sym_preproc_region] = STATE(3128),
    [sym_preproc_endregion] = STATE(3128),
    [sym_preproc_line] = STATE(3128),
    [sym_preproc_pragma] = STATE(3128),
    [sym_preproc_nullable] = STATE(3128),
    [sym_preproc_error] = STATE(3128),
    [sym_preproc_warning] = STATE(3128),
    [sym_preproc_define] = STATE(3128),
    [sym_preproc_undef] = STATE(3128),
    [sym__identifier_token] = ACTIONS(4536),
    [anon_sym_alias] = ACTIONS(4538),
    [anon_sym_global] = ACTIONS(4538),
    [anon_sym_LBRACK] = ACTIONS(4399),
    [anon_sym_COMMA] = ACTIONS(4399),
    [anon_sym_LPAREN] = ACTIONS(4399),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_file] = ACTIONS(4538),
    [anon_sym_LT] = ACTIONS(4401),
    [anon_sym_GT] = ACTIONS(4401),
    [anon_sym_where] = ACTIONS(4401),
    [anon_sym_QMARK] = ACTIONS(4401),
    [anon_sym_notnull] = ACTIONS(4538),
    [anon_sym_unmanaged] = ACTIONS(4538),
    [anon_sym_BANG] = ACTIONS(4401),
    [anon_sym_PLUS_PLUS] = ACTIONS(4399),
    [anon_sym_DASH_DASH] = ACTIONS(4399),
    [anon_sym_PLUS] = ACTIONS(4401),
    [anon_sym_DASH] = ACTIONS(4401),
    [anon_sym_STAR] = ACTIONS(4399),
    [anon_sym_SLASH] = ACTIONS(4401),
    [anon_sym_PERCENT] = ACTIONS(4399),
    [anon_sym_CARET] = ACTIONS(4399),
    [anon_sym_PIPE] = ACTIONS(4401),
    [anon_sym_AMP] = ACTIONS(4401),
    [anon_sym_LT_LT] = ACTIONS(4399),
    [anon_sym_GT_GT] = ACTIONS(4401),
    [anon_sym_GT_GT_GT] = ACTIONS(4399),
    [anon_sym_EQ_EQ] = ACTIONS(4399),
    [anon_sym_BANG_EQ] = ACTIONS(4399),
    [anon_sym_GT_EQ] = ACTIONS(4399),
    [anon_sym_LT_EQ] = ACTIONS(4399),
    [anon_sym_DOT] = ACTIONS(4401),
    [anon_sym_scoped] = ACTIONS(4538),
    [anon_sym_var] = ACTIONS(4538),
    [anon_sym_yield] = ACTIONS(4538),
    [anon_sym_switch] = ACTIONS(4401),
    [anon_sym_when] = ACTIONS(4538),
    [sym_discard] = ACTIONS(4717),
    [anon_sym_DOT_DOT] = ACTIONS(4399),
    [anon_sym_and] = ACTIONS(4401),
    [anon_sym_or] = ACTIONS(4401),
    [anon_sym_AMP_AMP] = ACTIONS(4399),
    [anon_sym_PIPE_PIPE] = ACTIONS(4399),
    [anon_sym_QMARK_QMARK] = ACTIONS(4399),
    [anon_sym_from] = ACTIONS(4401),
    [anon_sym_into] = ACTIONS(4538),
    [anon_sym_join] = ACTIONS(4401),
    [anon_sym_on] = ACTIONS(4538),
    [anon_sym_equals] = ACTIONS(4538),
    [anon_sym_let] = ACTIONS(4401),
    [anon_sym_orderby] = ACTIONS(4401),
    [anon_sym_ascending] = ACTIONS(4401),
    [anon_sym_descending] = ACTIONS(4401),
    [anon_sym_group] = ACTIONS(4401),
    [anon_sym_by] = ACTIONS(4538),
    [anon_sym_select] = ACTIONS(4401),
    [anon_sym_as] = ACTIONS(4401),
    [anon_sym_is] = ACTIONS(4401),
    [anon_sym_DASH_GT] = ACTIONS(4399),
    [anon_sym_with] = ACTIONS(4401),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3129] = {
    [sym__variable_designation] = STATE(5785),
    [sym_parenthesized_variable_designation] = STATE(5773),
    [sym_identifier] = STATE(5775),
    [sym__reserved_identifier] = STATE(5200),
    [sym_preproc_region] = STATE(3129),
    [sym_preproc_endregion] = STATE(3129),
    [sym_preproc_line] = STATE(3129),
    [sym_preproc_pragma] = STATE(3129),
    [sym_preproc_nullable] = STATE(3129),
    [sym_preproc_error] = STATE(3129),
    [sym_preproc_warning] = STATE(3129),
    [sym_preproc_define] = STATE(3129),
    [sym_preproc_undef] = STATE(3129),
    [sym__identifier_token] = ACTIONS(4575),
    [anon_sym_alias] = ACTIONS(4577),
    [anon_sym_global] = ACTIONS(4577),
    [anon_sym_LBRACK] = ACTIONS(4399),
    [anon_sym_COLON] = ACTIONS(4399),
    [anon_sym_COMMA] = ACTIONS(4399),
    [anon_sym_LPAREN] = ACTIONS(4399),
    [anon_sym_file] = ACTIONS(4577),
    [anon_sym_LT] = ACTIONS(4401),
    [anon_sym_GT] = ACTIONS(4401),
    [anon_sym_where] = ACTIONS(4577),
    [anon_sym_QMARK] = ACTIONS(4401),
    [anon_sym_notnull] = ACTIONS(4577),
    [anon_sym_unmanaged] = ACTIONS(4577),
    [anon_sym_BANG] = ACTIONS(4401),
    [anon_sym_PLUS_PLUS] = ACTIONS(4399),
    [anon_sym_DASH_DASH] = ACTIONS(4399),
    [anon_sym_PLUS] = ACTIONS(4401),
    [anon_sym_DASH] = ACTIONS(4401),
    [anon_sym_STAR] = ACTIONS(4399),
    [anon_sym_SLASH] = ACTIONS(4401),
    [anon_sym_PERCENT] = ACTIONS(4399),
    [anon_sym_CARET] = ACTIONS(4399),
    [anon_sym_PIPE] = ACTIONS(4401),
    [anon_sym_AMP] = ACTIONS(4401),
    [anon_sym_LT_LT] = ACTIONS(4399),
    [anon_sym_GT_GT] = ACTIONS(4401),
    [anon_sym_GT_GT_GT] = ACTIONS(4399),
    [anon_sym_EQ_EQ] = ACTIONS(4399),
    [anon_sym_BANG_EQ] = ACTIONS(4399),
    [anon_sym_GT_EQ] = ACTIONS(4399),
    [anon_sym_LT_EQ] = ACTIONS(4399),
    [anon_sym_DOT] = ACTIONS(4401),
    [anon_sym_scoped] = ACTIONS(4577),
    [anon_sym_var] = ACTIONS(4577),
    [anon_sym_yield] = ACTIONS(4577),
    [anon_sym_switch] = ACTIONS(4401),
    [anon_sym_when] = ACTIONS(4577),
    [sym_discard] = ACTIONS(4581),
    [anon_sym_DOT_DOT] = ACTIONS(4399),
    [anon_sym_and] = ACTIONS(4401),
    [anon_sym_or] = ACTIONS(4401),
    [anon_sym_AMP_AMP] = ACTIONS(4399),
    [anon_sym_PIPE_PIPE] = ACTIONS(4399),
    [anon_sym_QMARK_QMARK] = ACTIONS(4399),
    [anon_sym_from] = ACTIONS(4577),
    [anon_sym_into] = ACTIONS(4401),
    [anon_sym_join] = ACTIONS(4577),
    [anon_sym_on] = ACTIONS(4577),
    [anon_sym_equals] = ACTIONS(4577),
    [anon_sym_let] = ACTIONS(4577),
    [anon_sym_orderby] = ACTIONS(4577),
    [anon_sym_ascending] = ACTIONS(4577),
    [anon_sym_descending] = ACTIONS(4577),
    [anon_sym_group] = ACTIONS(4577),
    [anon_sym_by] = ACTIONS(4577),
    [anon_sym_select] = ACTIONS(4577),
    [anon_sym_as] = ACTIONS(4401),
    [anon_sym_is] = ACTIONS(4401),
    [anon_sym_DASH_GT] = ACTIONS(4399),
    [anon_sym_with] = ACTIONS(4401),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4399),
  },
  [3130] = {
    [sym_property_pattern_clause] = STATE(3192),
    [sym__variable_designation] = STATE(4611),
    [sym_parenthesized_variable_designation] = STATE(4748),
    [sym_identifier] = STATE(4548),
    [sym__reserved_identifier] = STATE(2928),
    [sym_preproc_region] = STATE(3130),
    [sym_preproc_endregion] = STATE(3130),
    [sym_preproc_line] = STATE(3130),
    [sym_preproc_pragma] = STATE(3130),
    [sym_preproc_nullable] = STATE(3130),
    [sym_preproc_error] = STATE(3130),
    [sym_preproc_warning] = STATE(3130),
    [sym_preproc_define] = STATE(3130),
    [sym_preproc_undef] = STATE(3130),
    [sym__identifier_token] = ACTIONS(4536),
    [anon_sym_alias] = ACTIONS(4538),
    [anon_sym_global] = ACTIONS(4538),
    [anon_sym_LBRACK] = ACTIONS(4405),
    [anon_sym_COMMA] = ACTIONS(4405),
    [anon_sym_LPAREN] = ACTIONS(4405),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_file] = ACTIONS(4538),
    [anon_sym_LT] = ACTIONS(4407),
    [anon_sym_GT] = ACTIONS(4407),
    [anon_sym_where] = ACTIONS(4407),
    [anon_sym_QMARK] = ACTIONS(4407),
    [anon_sym_notnull] = ACTIONS(4538),
    [anon_sym_unmanaged] = ACTIONS(4538),
    [anon_sym_BANG] = ACTIONS(4407),
    [anon_sym_PLUS_PLUS] = ACTIONS(4405),
    [anon_sym_DASH_DASH] = ACTIONS(4405),
    [anon_sym_PLUS] = ACTIONS(4407),
    [anon_sym_DASH] = ACTIONS(4407),
    [anon_sym_STAR] = ACTIONS(4405),
    [anon_sym_SLASH] = ACTIONS(4407),
    [anon_sym_PERCENT] = ACTIONS(4405),
    [anon_sym_CARET] = ACTIONS(4405),
    [anon_sym_PIPE] = ACTIONS(4407),
    [anon_sym_AMP] = ACTIONS(4407),
    [anon_sym_LT_LT] = ACTIONS(4405),
    [anon_sym_GT_GT] = ACTIONS(4407),
    [anon_sym_GT_GT_GT] = ACTIONS(4405),
    [anon_sym_EQ_EQ] = ACTIONS(4405),
    [anon_sym_BANG_EQ] = ACTIONS(4405),
    [anon_sym_GT_EQ] = ACTIONS(4405),
    [anon_sym_LT_EQ] = ACTIONS(4405),
    [anon_sym_DOT] = ACTIONS(4407),
    [anon_sym_scoped] = ACTIONS(4538),
    [anon_sym_var] = ACTIONS(4538),
    [anon_sym_yield] = ACTIONS(4538),
    [anon_sym_switch] = ACTIONS(4407),
    [anon_sym_when] = ACTIONS(4538),
    [sym_discard] = ACTIONS(4717),
    [anon_sym_DOT_DOT] = ACTIONS(4405),
    [anon_sym_and] = ACTIONS(4407),
    [anon_sym_or] = ACTIONS(4407),
    [anon_sym_AMP_AMP] = ACTIONS(4405),
    [anon_sym_PIPE_PIPE] = ACTIONS(4405),
    [anon_sym_QMARK_QMARK] = ACTIONS(4405),
    [anon_sym_from] = ACTIONS(4407),
    [anon_sym_into] = ACTIONS(4407),
    [anon_sym_join] = ACTIONS(4407),
    [anon_sym_on] = ACTIONS(4538),
    [anon_sym_equals] = ACTIONS(4538),
    [anon_sym_let] = ACTIONS(4407),
    [anon_sym_orderby] = ACTIONS(4407),
    [anon_sym_ascending] = ACTIONS(4407),
    [anon_sym_descending] = ACTIONS(4407),
    [anon_sym_group] = ACTIONS(4407),
    [anon_sym_by] = ACTIONS(4538),
    [anon_sym_select] = ACTIONS(4407),
    [anon_sym_as] = ACTIONS(4407),
    [anon_sym_is] = ACTIONS(4407),
    [anon_sym_DASH_GT] = ACTIONS(4405),
    [anon_sym_with] = ACTIONS(4407),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3131] = {
    [sym_property_pattern_clause] = STATE(3226),
    [sym__variable_designation] = STATE(4161),
    [sym_parenthesized_variable_designation] = STATE(4153),
    [sym_identifier] = STATE(4156),
    [sym__reserved_identifier] = STATE(3911),
    [sym_preproc_region] = STATE(3131),
    [sym_preproc_endregion] = STATE(3131),
    [sym_preproc_line] = STATE(3131),
    [sym_preproc_pragma] = STATE(3131),
    [sym_preproc_nullable] = STATE(3131),
    [sym_preproc_error] = STATE(3131),
    [sym_preproc_warning] = STATE(3131),
    [sym_preproc_define] = STATE(3131),
    [sym_preproc_undef] = STATE(3131),
    [sym__identifier_token] = ACTIONS(4248),
    [anon_sym_alias] = ACTIONS(4250),
    [anon_sym_global] = ACTIONS(4250),
    [anon_sym_LBRACK] = ACTIONS(4405),
    [anon_sym_LPAREN] = ACTIONS(4405),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_file] = ACTIONS(4250),
    [anon_sym_LT] = ACTIONS(4407),
    [anon_sym_GT] = ACTIONS(4407),
    [anon_sym_in] = ACTIONS(4407),
    [anon_sym_where] = ACTIONS(4250),
    [anon_sym_QMARK] = ACTIONS(4407),
    [anon_sym_notnull] = ACTIONS(4250),
    [anon_sym_unmanaged] = ACTIONS(4250),
    [anon_sym_BANG] = ACTIONS(4407),
    [anon_sym_PLUS_PLUS] = ACTIONS(4405),
    [anon_sym_DASH_DASH] = ACTIONS(4405),
    [anon_sym_PLUS] = ACTIONS(4407),
    [anon_sym_DASH] = ACTIONS(4407),
    [anon_sym_STAR] = ACTIONS(4405),
    [anon_sym_SLASH] = ACTIONS(4407),
    [anon_sym_PERCENT] = ACTIONS(4405),
    [anon_sym_CARET] = ACTIONS(4405),
    [anon_sym_PIPE] = ACTIONS(4407),
    [anon_sym_AMP] = ACTIONS(4407),
    [anon_sym_LT_LT] = ACTIONS(4405),
    [anon_sym_GT_GT] = ACTIONS(4407),
    [anon_sym_GT_GT_GT] = ACTIONS(4405),
    [anon_sym_EQ_EQ] = ACTIONS(4405),
    [anon_sym_BANG_EQ] = ACTIONS(4405),
    [anon_sym_GT_EQ] = ACTIONS(4405),
    [anon_sym_LT_EQ] = ACTIONS(4405),
    [anon_sym_DOT] = ACTIONS(4407),
    [anon_sym_scoped] = ACTIONS(4250),
    [anon_sym_var] = ACTIONS(4250),
    [anon_sym_yield] = ACTIONS(4250),
    [anon_sym_switch] = ACTIONS(4407),
    [anon_sym_when] = ACTIONS(4250),
    [sym_discard] = ACTIONS(4359),
    [anon_sym_DOT_DOT] = ACTIONS(4405),
    [anon_sym_and] = ACTIONS(4407),
    [anon_sym_or] = ACTIONS(4407),
    [anon_sym_AMP_AMP] = ACTIONS(4405),
    [anon_sym_PIPE_PIPE] = ACTIONS(4405),
    [anon_sym_QMARK_QMARK] = ACTIONS(4405),
    [anon_sym_from] = ACTIONS(4250),
    [anon_sym_into] = ACTIONS(4250),
    [anon_sym_join] = ACTIONS(4250),
    [anon_sym_on] = ACTIONS(4250),
    [anon_sym_equals] = ACTIONS(4250),
    [anon_sym_let] = ACTIONS(4250),
    [anon_sym_orderby] = ACTIONS(4250),
    [anon_sym_ascending] = ACTIONS(4250),
    [anon_sym_descending] = ACTIONS(4250),
    [anon_sym_group] = ACTIONS(4250),
    [anon_sym_by] = ACTIONS(4250),
    [anon_sym_select] = ACTIONS(4250),
    [anon_sym_as] = ACTIONS(4407),
    [anon_sym_is] = ACTIONS(4407),
    [anon_sym_DASH_GT] = ACTIONS(4405),
    [anon_sym_with] = ACTIONS(4407),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3132] = {
    [sym__variable_designation] = STATE(5785),
    [sym_parenthesized_variable_designation] = STATE(5773),
    [sym_identifier] = STATE(5775),
    [sym__reserved_identifier] = STATE(5200),
    [sym_preproc_region] = STATE(3132),
    [sym_preproc_endregion] = STATE(3132),
    [sym_preproc_line] = STATE(3132),
    [sym_preproc_pragma] = STATE(3132),
    [sym_preproc_nullable] = STATE(3132),
    [sym_preproc_error] = STATE(3132),
    [sym_preproc_warning] = STATE(3132),
    [sym_preproc_define] = STATE(3132),
    [sym_preproc_undef] = STATE(3132),
    [sym__identifier_token] = ACTIONS(4575),
    [anon_sym_alias] = ACTIONS(4577),
    [anon_sym_global] = ACTIONS(4577),
    [anon_sym_LBRACK] = ACTIONS(4399),
    [anon_sym_COLON] = ACTIONS(4399),
    [anon_sym_COMMA] = ACTIONS(4399),
    [anon_sym_LPAREN] = ACTIONS(4399),
    [anon_sym_file] = ACTIONS(4577),
    [anon_sym_LT] = ACTIONS(4401),
    [anon_sym_GT] = ACTIONS(4401),
    [anon_sym_where] = ACTIONS(4577),
    [anon_sym_QMARK] = ACTIONS(4401),
    [anon_sym_notnull] = ACTIONS(4577),
    [anon_sym_unmanaged] = ACTIONS(4577),
    [anon_sym_BANG] = ACTIONS(4401),
    [anon_sym_PLUS_PLUS] = ACTIONS(4399),
    [anon_sym_DASH_DASH] = ACTIONS(4399),
    [anon_sym_PLUS] = ACTIONS(4401),
    [anon_sym_DASH] = ACTIONS(4401),
    [anon_sym_STAR] = ACTIONS(4399),
    [anon_sym_SLASH] = ACTIONS(4401),
    [anon_sym_PERCENT] = ACTIONS(4399),
    [anon_sym_CARET] = ACTIONS(4399),
    [anon_sym_PIPE] = ACTIONS(4401),
    [anon_sym_AMP] = ACTIONS(4401),
    [anon_sym_LT_LT] = ACTIONS(4399),
    [anon_sym_GT_GT] = ACTIONS(4401),
    [anon_sym_GT_GT_GT] = ACTIONS(4399),
    [anon_sym_EQ_EQ] = ACTIONS(4399),
    [anon_sym_BANG_EQ] = ACTIONS(4399),
    [anon_sym_GT_EQ] = ACTIONS(4399),
    [anon_sym_LT_EQ] = ACTIONS(4399),
    [anon_sym_DOT] = ACTIONS(4401),
    [anon_sym_scoped] = ACTIONS(4577),
    [anon_sym_var] = ACTIONS(4577),
    [anon_sym_yield] = ACTIONS(4577),
    [anon_sym_switch] = ACTIONS(4401),
    [anon_sym_when] = ACTIONS(4577),
    [sym_discard] = ACTIONS(4581),
    [anon_sym_DOT_DOT] = ACTIONS(4399),
    [anon_sym_and] = ACTIONS(4401),
    [anon_sym_or] = ACTIONS(4401),
    [anon_sym_AMP_AMP] = ACTIONS(4399),
    [anon_sym_PIPE_PIPE] = ACTIONS(4399),
    [anon_sym_QMARK_QMARK] = ACTIONS(4399),
    [anon_sym_from] = ACTIONS(4577),
    [anon_sym_into] = ACTIONS(4577),
    [anon_sym_join] = ACTIONS(4577),
    [anon_sym_on] = ACTIONS(4577),
    [anon_sym_equals] = ACTIONS(4577),
    [anon_sym_let] = ACTIONS(4577),
    [anon_sym_orderby] = ACTIONS(4577),
    [anon_sym_ascending] = ACTIONS(4577),
    [anon_sym_descending] = ACTIONS(4577),
    [anon_sym_group] = ACTIONS(4577),
    [anon_sym_by] = ACTIONS(4577),
    [anon_sym_select] = ACTIONS(4577),
    [anon_sym_as] = ACTIONS(4401),
    [anon_sym_is] = ACTIONS(4401),
    [anon_sym_DASH_GT] = ACTIONS(4399),
    [anon_sym_with] = ACTIONS(4401),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4399),
  },
  [3133] = {
    [sym_modifier] = STATE(4634),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7332),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3133),
    [sym_preproc_endregion] = STATE(3133),
    [sym_preproc_line] = STATE(3133),
    [sym_preproc_pragma] = STATE(3133),
    [sym_preproc_nullable] = STATE(3133),
    [sym_preproc_error] = STATE(3133),
    [sym_preproc_warning] = STATE(3133),
    [sym_preproc_define] = STATE(3133),
    [sym_preproc_undef] = STATE(3133),
    [aux_sym_class_declaration_repeat2] = STATE(4397),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_unsafe] = ACTIONS(661),
    [anon_sym_static] = ACTIONS(661),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(661),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(4757),
    [anon_sym_fixed] = ACTIONS(661),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(661),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3134] = {
    [sym_modifier] = STATE(4634),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7380),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3134),
    [sym_preproc_endregion] = STATE(3134),
    [sym_preproc_line] = STATE(3134),
    [sym_preproc_pragma] = STATE(3134),
    [sym_preproc_nullable] = STATE(3134),
    [sym_preproc_error] = STATE(3134),
    [sym_preproc_warning] = STATE(3134),
    [sym_preproc_define] = STATE(3134),
    [sym_preproc_undef] = STATE(3134),
    [aux_sym_class_declaration_repeat2] = STATE(4397),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_extern] = ACTIONS(661),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_unsafe] = ACTIONS(661),
    [anon_sym_static] = ACTIONS(661),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_abstract] = ACTIONS(661),
    [anon_sym_async] = ACTIONS(661),
    [anon_sym_const] = ACTIONS(661),
    [anon_sym_file] = ACTIONS(4757),
    [anon_sym_fixed] = ACTIONS(661),
    [anon_sym_internal] = ACTIONS(661),
    [anon_sym_new] = ACTIONS(661),
    [anon_sym_override] = ACTIONS(661),
    [anon_sym_partial] = ACTIONS(661),
    [anon_sym_private] = ACTIONS(661),
    [anon_sym_protected] = ACTIONS(661),
    [anon_sym_public] = ACTIONS(661),
    [anon_sym_readonly] = ACTIONS(661),
    [anon_sym_required] = ACTIONS(661),
    [anon_sym_sealed] = ACTIONS(661),
    [anon_sym_virtual] = ACTIONS(661),
    [anon_sym_volatile] = ACTIONS(661),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3135] = {
    [sym__variable_designation] = STATE(5431),
    [sym_parenthesized_variable_designation] = STATE(5773),
    [sym_identifier] = STATE(5775),
    [sym__reserved_identifier] = STATE(5200),
    [sym_preproc_region] = STATE(3135),
    [sym_preproc_endregion] = STATE(3135),
    [sym_preproc_line] = STATE(3135),
    [sym_preproc_pragma] = STATE(3135),
    [sym_preproc_nullable] = STATE(3135),
    [sym_preproc_error] = STATE(3135),
    [sym_preproc_warning] = STATE(3135),
    [sym_preproc_define] = STATE(3135),
    [sym_preproc_undef] = STATE(3135),
    [sym__identifier_token] = ACTIONS(4575),
    [anon_sym_alias] = ACTIONS(4577),
    [anon_sym_global] = ACTIONS(4577),
    [anon_sym_LBRACK] = ACTIONS(4405),
    [anon_sym_COLON] = ACTIONS(4405),
    [anon_sym_COMMA] = ACTIONS(4405),
    [anon_sym_LPAREN] = ACTIONS(4405),
    [anon_sym_file] = ACTIONS(4577),
    [anon_sym_LT] = ACTIONS(4407),
    [anon_sym_GT] = ACTIONS(4407),
    [anon_sym_where] = ACTIONS(4577),
    [anon_sym_QMARK] = ACTIONS(4407),
    [anon_sym_notnull] = ACTIONS(4577),
    [anon_sym_unmanaged] = ACTIONS(4577),
    [anon_sym_BANG] = ACTIONS(4407),
    [anon_sym_PLUS_PLUS] = ACTIONS(4405),
    [anon_sym_DASH_DASH] = ACTIONS(4405),
    [anon_sym_PLUS] = ACTIONS(4407),
    [anon_sym_DASH] = ACTIONS(4407),
    [anon_sym_STAR] = ACTIONS(4405),
    [anon_sym_SLASH] = ACTIONS(4407),
    [anon_sym_PERCENT] = ACTIONS(4405),
    [anon_sym_CARET] = ACTIONS(4405),
    [anon_sym_PIPE] = ACTIONS(4407),
    [anon_sym_AMP] = ACTIONS(4407),
    [anon_sym_LT_LT] = ACTIONS(4405),
    [anon_sym_GT_GT] = ACTIONS(4407),
    [anon_sym_GT_GT_GT] = ACTIONS(4405),
    [anon_sym_EQ_EQ] = ACTIONS(4405),
    [anon_sym_BANG_EQ] = ACTIONS(4405),
    [anon_sym_GT_EQ] = ACTIONS(4405),
    [anon_sym_LT_EQ] = ACTIONS(4405),
    [anon_sym_DOT] = ACTIONS(4407),
    [anon_sym_scoped] = ACTIONS(4577),
    [anon_sym_var] = ACTIONS(4577),
    [anon_sym_yield] = ACTIONS(4577),
    [anon_sym_switch] = ACTIONS(4407),
    [anon_sym_when] = ACTIONS(4577),
    [sym_discard] = ACTIONS(4581),
    [anon_sym_DOT_DOT] = ACTIONS(4405),
    [anon_sym_and] = ACTIONS(4407),
    [anon_sym_or] = ACTIONS(4407),
    [anon_sym_AMP_AMP] = ACTIONS(4405),
    [anon_sym_PIPE_PIPE] = ACTIONS(4405),
    [anon_sym_QMARK_QMARK] = ACTIONS(4405),
    [anon_sym_from] = ACTIONS(4577),
    [anon_sym_into] = ACTIONS(4407),
    [anon_sym_join] = ACTIONS(4577),
    [anon_sym_on] = ACTIONS(4577),
    [anon_sym_equals] = ACTIONS(4577),
    [anon_sym_let] = ACTIONS(4577),
    [anon_sym_orderby] = ACTIONS(4577),
    [anon_sym_ascending] = ACTIONS(4577),
    [anon_sym_descending] = ACTIONS(4577),
    [anon_sym_group] = ACTIONS(4577),
    [anon_sym_by] = ACTIONS(4577),
    [anon_sym_select] = ACTIONS(4577),
    [anon_sym_as] = ACTIONS(4407),
    [anon_sym_is] = ACTIONS(4407),
    [anon_sym_DASH_GT] = ACTIONS(4405),
    [anon_sym_with] = ACTIONS(4407),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4405),
  },
  [3136] = {
    [sym__variable_designation] = STATE(5433),
    [sym_parenthesized_variable_designation] = STATE(5773),
    [sym_identifier] = STATE(5775),
    [sym__reserved_identifier] = STATE(5200),
    [sym_preproc_region] = STATE(3136),
    [sym_preproc_endregion] = STATE(3136),
    [sym_preproc_line] = STATE(3136),
    [sym_preproc_pragma] = STATE(3136),
    [sym_preproc_nullable] = STATE(3136),
    [sym_preproc_error] = STATE(3136),
    [sym_preproc_warning] = STATE(3136),
    [sym_preproc_define] = STATE(3136),
    [sym_preproc_undef] = STATE(3136),
    [sym__identifier_token] = ACTIONS(4575),
    [anon_sym_alias] = ACTIONS(4577),
    [anon_sym_global] = ACTIONS(4577),
    [anon_sym_LBRACK] = ACTIONS(4437),
    [anon_sym_COLON] = ACTIONS(4437),
    [anon_sym_COMMA] = ACTIONS(4437),
    [anon_sym_LPAREN] = ACTIONS(4437),
    [anon_sym_file] = ACTIONS(4577),
    [anon_sym_LT] = ACTIONS(4439),
    [anon_sym_GT] = ACTIONS(4439),
    [anon_sym_where] = ACTIONS(4577),
    [anon_sym_QMARK] = ACTIONS(4439),
    [anon_sym_notnull] = ACTIONS(4577),
    [anon_sym_unmanaged] = ACTIONS(4577),
    [anon_sym_BANG] = ACTIONS(4439),
    [anon_sym_PLUS_PLUS] = ACTIONS(4437),
    [anon_sym_DASH_DASH] = ACTIONS(4437),
    [anon_sym_PLUS] = ACTIONS(4439),
    [anon_sym_DASH] = ACTIONS(4439),
    [anon_sym_STAR] = ACTIONS(4437),
    [anon_sym_SLASH] = ACTIONS(4439),
    [anon_sym_PERCENT] = ACTIONS(4437),
    [anon_sym_CARET] = ACTIONS(4437),
    [anon_sym_PIPE] = ACTIONS(4439),
    [anon_sym_AMP] = ACTIONS(4439),
    [anon_sym_LT_LT] = ACTIONS(4437),
    [anon_sym_GT_GT] = ACTIONS(4439),
    [anon_sym_GT_GT_GT] = ACTIONS(4437),
    [anon_sym_EQ_EQ] = ACTIONS(4437),
    [anon_sym_BANG_EQ] = ACTIONS(4437),
    [anon_sym_GT_EQ] = ACTIONS(4437),
    [anon_sym_LT_EQ] = ACTIONS(4437),
    [anon_sym_DOT] = ACTIONS(4439),
    [anon_sym_scoped] = ACTIONS(4577),
    [anon_sym_var] = ACTIONS(4577),
    [anon_sym_yield] = ACTIONS(4577),
    [anon_sym_switch] = ACTIONS(4439),
    [anon_sym_when] = ACTIONS(4577),
    [sym_discard] = ACTIONS(4581),
    [anon_sym_DOT_DOT] = ACTIONS(4437),
    [anon_sym_and] = ACTIONS(4439),
    [anon_sym_or] = ACTIONS(4439),
    [anon_sym_AMP_AMP] = ACTIONS(4437),
    [anon_sym_PIPE_PIPE] = ACTIONS(4437),
    [anon_sym_QMARK_QMARK] = ACTIONS(4437),
    [anon_sym_from] = ACTIONS(4577),
    [anon_sym_into] = ACTIONS(4439),
    [anon_sym_join] = ACTIONS(4577),
    [anon_sym_on] = ACTIONS(4577),
    [anon_sym_equals] = ACTIONS(4577),
    [anon_sym_let] = ACTIONS(4577),
    [anon_sym_orderby] = ACTIONS(4577),
    [anon_sym_ascending] = ACTIONS(4577),
    [anon_sym_descending] = ACTIONS(4577),
    [anon_sym_group] = ACTIONS(4577),
    [anon_sym_by] = ACTIONS(4577),
    [anon_sym_select] = ACTIONS(4577),
    [anon_sym_as] = ACTIONS(4439),
    [anon_sym_is] = ACTIONS(4439),
    [anon_sym_DASH_GT] = ACTIONS(4437),
    [anon_sym_with] = ACTIONS(4439),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4437),
  },
  [3137] = {
    [sym__variable_designation] = STATE(5437),
    [sym_parenthesized_variable_designation] = STATE(5773),
    [sym_identifier] = STATE(5775),
    [sym__reserved_identifier] = STATE(5200),
    [sym_preproc_region] = STATE(3137),
    [sym_preproc_endregion] = STATE(3137),
    [sym_preproc_line] = STATE(3137),
    [sym_preproc_pragma] = STATE(3137),
    [sym_preproc_nullable] = STATE(3137),
    [sym_preproc_error] = STATE(3137),
    [sym_preproc_warning] = STATE(3137),
    [sym_preproc_define] = STATE(3137),
    [sym_preproc_undef] = STATE(3137),
    [sym__identifier_token] = ACTIONS(4575),
    [anon_sym_alias] = ACTIONS(4577),
    [anon_sym_global] = ACTIONS(4577),
    [anon_sym_LBRACK] = ACTIONS(4441),
    [anon_sym_COLON] = ACTIONS(4441),
    [anon_sym_COMMA] = ACTIONS(4441),
    [anon_sym_LPAREN] = ACTIONS(4441),
    [anon_sym_file] = ACTIONS(4577),
    [anon_sym_LT] = ACTIONS(4443),
    [anon_sym_GT] = ACTIONS(4443),
    [anon_sym_where] = ACTIONS(4577),
    [anon_sym_QMARK] = ACTIONS(4443),
    [anon_sym_notnull] = ACTIONS(4577),
    [anon_sym_unmanaged] = ACTIONS(4577),
    [anon_sym_BANG] = ACTIONS(4443),
    [anon_sym_PLUS_PLUS] = ACTIONS(4441),
    [anon_sym_DASH_DASH] = ACTIONS(4441),
    [anon_sym_PLUS] = ACTIONS(4443),
    [anon_sym_DASH] = ACTIONS(4443),
    [anon_sym_STAR] = ACTIONS(4441),
    [anon_sym_SLASH] = ACTIONS(4443),
    [anon_sym_PERCENT] = ACTIONS(4441),
    [anon_sym_CARET] = ACTIONS(4441),
    [anon_sym_PIPE] = ACTIONS(4443),
    [anon_sym_AMP] = ACTIONS(4443),
    [anon_sym_LT_LT] = ACTIONS(4441),
    [anon_sym_GT_GT] = ACTIONS(4443),
    [anon_sym_GT_GT_GT] = ACTIONS(4441),
    [anon_sym_EQ_EQ] = ACTIONS(4441),
    [anon_sym_BANG_EQ] = ACTIONS(4441),
    [anon_sym_GT_EQ] = ACTIONS(4441),
    [anon_sym_LT_EQ] = ACTIONS(4441),
    [anon_sym_DOT] = ACTIONS(4443),
    [anon_sym_scoped] = ACTIONS(4577),
    [anon_sym_var] = ACTIONS(4577),
    [anon_sym_yield] = ACTIONS(4577),
    [anon_sym_switch] = ACTIONS(4443),
    [anon_sym_when] = ACTIONS(4577),
    [sym_discard] = ACTIONS(4581),
    [anon_sym_DOT_DOT] = ACTIONS(4441),
    [anon_sym_and] = ACTIONS(4443),
    [anon_sym_or] = ACTIONS(4443),
    [anon_sym_AMP_AMP] = ACTIONS(4441),
    [anon_sym_PIPE_PIPE] = ACTIONS(4441),
    [anon_sym_QMARK_QMARK] = ACTIONS(4441),
    [anon_sym_from] = ACTIONS(4577),
    [anon_sym_into] = ACTIONS(4443),
    [anon_sym_join] = ACTIONS(4577),
    [anon_sym_on] = ACTIONS(4577),
    [anon_sym_equals] = ACTIONS(4577),
    [anon_sym_let] = ACTIONS(4577),
    [anon_sym_orderby] = ACTIONS(4577),
    [anon_sym_ascending] = ACTIONS(4577),
    [anon_sym_descending] = ACTIONS(4577),
    [anon_sym_group] = ACTIONS(4577),
    [anon_sym_by] = ACTIONS(4577),
    [anon_sym_select] = ACTIONS(4577),
    [anon_sym_as] = ACTIONS(4443),
    [anon_sym_is] = ACTIONS(4443),
    [anon_sym_DASH_GT] = ACTIONS(4441),
    [anon_sym_with] = ACTIONS(4443),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4441),
  },
  [3138] = {
    [sym_property_pattern_clause] = STATE(3197),
    [sym__variable_designation] = STATE(4611),
    [sym_parenthesized_variable_designation] = STATE(4748),
    [sym_identifier] = STATE(4548),
    [sym__reserved_identifier] = STATE(2928),
    [sym_preproc_region] = STATE(3138),
    [sym_preproc_endregion] = STATE(3138),
    [sym_preproc_line] = STATE(3138),
    [sym_preproc_pragma] = STATE(3138),
    [sym_preproc_nullable] = STATE(3138),
    [sym_preproc_error] = STATE(3138),
    [sym_preproc_warning] = STATE(3138),
    [sym_preproc_define] = STATE(3138),
    [sym_preproc_undef] = STATE(3138),
    [sym__identifier_token] = ACTIONS(4536),
    [anon_sym_alias] = ACTIONS(4538),
    [anon_sym_global] = ACTIONS(4538),
    [anon_sym_LBRACK] = ACTIONS(4405),
    [anon_sym_COMMA] = ACTIONS(4405),
    [anon_sym_LPAREN] = ACTIONS(4405),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_file] = ACTIONS(4538),
    [anon_sym_LT] = ACTIONS(4407),
    [anon_sym_GT] = ACTIONS(4407),
    [anon_sym_where] = ACTIONS(4407),
    [anon_sym_QMARK] = ACTIONS(4407),
    [anon_sym_notnull] = ACTIONS(4538),
    [anon_sym_unmanaged] = ACTIONS(4538),
    [anon_sym_BANG] = ACTIONS(4407),
    [anon_sym_PLUS_PLUS] = ACTIONS(4405),
    [anon_sym_DASH_DASH] = ACTIONS(4405),
    [anon_sym_PLUS] = ACTIONS(4407),
    [anon_sym_DASH] = ACTIONS(4407),
    [anon_sym_STAR] = ACTIONS(4405),
    [anon_sym_SLASH] = ACTIONS(4407),
    [anon_sym_PERCENT] = ACTIONS(4405),
    [anon_sym_CARET] = ACTIONS(4405),
    [anon_sym_PIPE] = ACTIONS(4407),
    [anon_sym_AMP] = ACTIONS(4407),
    [anon_sym_LT_LT] = ACTIONS(4405),
    [anon_sym_GT_GT] = ACTIONS(4407),
    [anon_sym_GT_GT_GT] = ACTIONS(4405),
    [anon_sym_EQ_EQ] = ACTIONS(4405),
    [anon_sym_BANG_EQ] = ACTIONS(4405),
    [anon_sym_GT_EQ] = ACTIONS(4405),
    [anon_sym_LT_EQ] = ACTIONS(4405),
    [anon_sym_DOT] = ACTIONS(4407),
    [anon_sym_scoped] = ACTIONS(4538),
    [anon_sym_var] = ACTIONS(4538),
    [anon_sym_yield] = ACTIONS(4538),
    [anon_sym_switch] = ACTIONS(4407),
    [anon_sym_when] = ACTIONS(4538),
    [sym_discard] = ACTIONS(4717),
    [anon_sym_DOT_DOT] = ACTIONS(4405),
    [anon_sym_and] = ACTIONS(4407),
    [anon_sym_or] = ACTIONS(4407),
    [anon_sym_AMP_AMP] = ACTIONS(4405),
    [anon_sym_PIPE_PIPE] = ACTIONS(4405),
    [anon_sym_QMARK_QMARK] = ACTIONS(4405),
    [anon_sym_from] = ACTIONS(4407),
    [anon_sym_into] = ACTIONS(4538),
    [anon_sym_join] = ACTIONS(4407),
    [anon_sym_on] = ACTIONS(4538),
    [anon_sym_equals] = ACTIONS(4538),
    [anon_sym_let] = ACTIONS(4407),
    [anon_sym_orderby] = ACTIONS(4407),
    [anon_sym_ascending] = ACTIONS(4407),
    [anon_sym_descending] = ACTIONS(4407),
    [anon_sym_group] = ACTIONS(4407),
    [anon_sym_by] = ACTIONS(4538),
    [anon_sym_select] = ACTIONS(4407),
    [anon_sym_as] = ACTIONS(4407),
    [anon_sym_is] = ACTIONS(4407),
    [anon_sym_DASH_GT] = ACTIONS(4405),
    [anon_sym_with] = ACTIONS(4407),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3139] = {
    [sym__variable_designation] = STATE(5433),
    [sym_parenthesized_variable_designation] = STATE(5773),
    [sym_identifier] = STATE(5775),
    [sym__reserved_identifier] = STATE(5200),
    [sym_preproc_region] = STATE(3139),
    [sym_preproc_endregion] = STATE(3139),
    [sym_preproc_line] = STATE(3139),
    [sym_preproc_pragma] = STATE(3139),
    [sym_preproc_nullable] = STATE(3139),
    [sym_preproc_error] = STATE(3139),
    [sym_preproc_warning] = STATE(3139),
    [sym_preproc_define] = STATE(3139),
    [sym_preproc_undef] = STATE(3139),
    [sym__identifier_token] = ACTIONS(4575),
    [anon_sym_alias] = ACTIONS(4577),
    [anon_sym_global] = ACTIONS(4577),
    [anon_sym_LBRACK] = ACTIONS(4437),
    [anon_sym_COLON] = ACTIONS(4437),
    [anon_sym_COMMA] = ACTIONS(4437),
    [anon_sym_LPAREN] = ACTIONS(4437),
    [anon_sym_file] = ACTIONS(4577),
    [anon_sym_LT] = ACTIONS(4439),
    [anon_sym_GT] = ACTIONS(4439),
    [anon_sym_where] = ACTIONS(4577),
    [anon_sym_QMARK] = ACTIONS(4439),
    [anon_sym_notnull] = ACTIONS(4577),
    [anon_sym_unmanaged] = ACTIONS(4577),
    [anon_sym_BANG] = ACTIONS(4439),
    [anon_sym_PLUS_PLUS] = ACTIONS(4437),
    [anon_sym_DASH_DASH] = ACTIONS(4437),
    [anon_sym_PLUS] = ACTIONS(4439),
    [anon_sym_DASH] = ACTIONS(4439),
    [anon_sym_STAR] = ACTIONS(4437),
    [anon_sym_SLASH] = ACTIONS(4439),
    [anon_sym_PERCENT] = ACTIONS(4437),
    [anon_sym_CARET] = ACTIONS(4437),
    [anon_sym_PIPE] = ACTIONS(4439),
    [anon_sym_AMP] = ACTIONS(4439),
    [anon_sym_LT_LT] = ACTIONS(4437),
    [anon_sym_GT_GT] = ACTIONS(4439),
    [anon_sym_GT_GT_GT] = ACTIONS(4437),
    [anon_sym_EQ_EQ] = ACTIONS(4437),
    [anon_sym_BANG_EQ] = ACTIONS(4437),
    [anon_sym_GT_EQ] = ACTIONS(4437),
    [anon_sym_LT_EQ] = ACTIONS(4437),
    [anon_sym_DOT] = ACTIONS(4439),
    [anon_sym_scoped] = ACTIONS(4577),
    [anon_sym_var] = ACTIONS(4577),
    [anon_sym_yield] = ACTIONS(4577),
    [anon_sym_switch] = ACTIONS(4439),
    [anon_sym_when] = ACTIONS(4577),
    [sym_discard] = ACTIONS(4581),
    [anon_sym_DOT_DOT] = ACTIONS(4437),
    [anon_sym_and] = ACTIONS(4439),
    [anon_sym_or] = ACTIONS(4439),
    [anon_sym_AMP_AMP] = ACTIONS(4437),
    [anon_sym_PIPE_PIPE] = ACTIONS(4437),
    [anon_sym_QMARK_QMARK] = ACTIONS(4437),
    [anon_sym_from] = ACTIONS(4577),
    [anon_sym_into] = ACTIONS(4577),
    [anon_sym_join] = ACTIONS(4577),
    [anon_sym_on] = ACTIONS(4577),
    [anon_sym_equals] = ACTIONS(4577),
    [anon_sym_let] = ACTIONS(4577),
    [anon_sym_orderby] = ACTIONS(4577),
    [anon_sym_ascending] = ACTIONS(4577),
    [anon_sym_descending] = ACTIONS(4577),
    [anon_sym_group] = ACTIONS(4577),
    [anon_sym_by] = ACTIONS(4577),
    [anon_sym_select] = ACTIONS(4577),
    [anon_sym_as] = ACTIONS(4439),
    [anon_sym_is] = ACTIONS(4439),
    [anon_sym_DASH_GT] = ACTIONS(4437),
    [anon_sym_with] = ACTIONS(4439),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4437),
  },
  [3140] = {
    [sym__variable_designation] = STATE(4043),
    [sym_parenthesized_variable_designation] = STATE(3966),
    [sym_identifier] = STATE(3983),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3140),
    [sym_preproc_endregion] = STATE(3140),
    [sym_preproc_line] = STATE(3140),
    [sym_preproc_pragma] = STATE(3140),
    [sym_preproc_nullable] = STATE(3140),
    [sym_preproc_error] = STATE(3140),
    [sym_preproc_warning] = STATE(3140),
    [sym_preproc_define] = STATE(3140),
    [sym_preproc_undef] = STATE(3140),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4405),
    [anon_sym_COLON] = ACTIONS(4405),
    [anon_sym_LPAREN] = ACTIONS(4405),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4407),
    [anon_sym_GT] = ACTIONS(4407),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4407),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4407),
    [anon_sym_PLUS_PLUS] = ACTIONS(4405),
    [anon_sym_DASH_DASH] = ACTIONS(4405),
    [anon_sym_PLUS] = ACTIONS(4407),
    [anon_sym_DASH] = ACTIONS(4407),
    [anon_sym_STAR] = ACTIONS(4405),
    [anon_sym_SLASH] = ACTIONS(4407),
    [anon_sym_PERCENT] = ACTIONS(4405),
    [anon_sym_CARET] = ACTIONS(4405),
    [anon_sym_PIPE] = ACTIONS(4407),
    [anon_sym_AMP] = ACTIONS(4407),
    [anon_sym_LT_LT] = ACTIONS(4405),
    [anon_sym_GT_GT] = ACTIONS(4407),
    [anon_sym_GT_GT_GT] = ACTIONS(4405),
    [anon_sym_EQ_EQ] = ACTIONS(4405),
    [anon_sym_BANG_EQ] = ACTIONS(4405),
    [anon_sym_GT_EQ] = ACTIONS(4405),
    [anon_sym_LT_EQ] = ACTIONS(4405),
    [anon_sym_DOT] = ACTIONS(4407),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_EQ_GT] = ACTIONS(4405),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4407),
    [anon_sym_when] = ACTIONS(4407),
    [sym_discard] = ACTIONS(4347),
    [anon_sym_DOT_DOT] = ACTIONS(4405),
    [anon_sym_and] = ACTIONS(4407),
    [anon_sym_or] = ACTIONS(4407),
    [anon_sym_AMP_AMP] = ACTIONS(4405),
    [anon_sym_PIPE_PIPE] = ACTIONS(4405),
    [anon_sym_QMARK_QMARK] = ACTIONS(4405),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4407),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4407),
    [anon_sym_is] = ACTIONS(4407),
    [anon_sym_DASH_GT] = ACTIONS(4405),
    [anon_sym_with] = ACTIONS(4407),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3141] = {
    [sym_property_pattern_clause] = STATE(3279),
    [sym__variable_designation] = STATE(4166),
    [sym_parenthesized_variable_designation] = STATE(4153),
    [sym_identifier] = STATE(4156),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3141),
    [sym_preproc_endregion] = STATE(3141),
    [sym_preproc_line] = STATE(3141),
    [sym_preproc_pragma] = STATE(3141),
    [sym_preproc_nullable] = STATE(3141),
    [sym_preproc_error] = STATE(3141),
    [sym_preproc_warning] = STATE(3141),
    [sym_preproc_define] = STATE(3141),
    [sym_preproc_undef] = STATE(3141),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4399),
    [anon_sym_LPAREN] = ACTIONS(4399),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4401),
    [anon_sym_GT] = ACTIONS(4401),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4401),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4401),
    [anon_sym_PLUS_PLUS] = ACTIONS(4399),
    [anon_sym_DASH_DASH] = ACTIONS(4399),
    [anon_sym_PLUS] = ACTIONS(4401),
    [anon_sym_DASH] = ACTIONS(4401),
    [anon_sym_STAR] = ACTIONS(4399),
    [anon_sym_SLASH] = ACTIONS(4401),
    [anon_sym_PERCENT] = ACTIONS(4399),
    [anon_sym_CARET] = ACTIONS(4399),
    [anon_sym_PIPE] = ACTIONS(4401),
    [anon_sym_AMP] = ACTIONS(4401),
    [anon_sym_LT_LT] = ACTIONS(4399),
    [anon_sym_GT_GT] = ACTIONS(4401),
    [anon_sym_GT_GT_GT] = ACTIONS(4399),
    [anon_sym_EQ_EQ] = ACTIONS(4399),
    [anon_sym_BANG_EQ] = ACTIONS(4399),
    [anon_sym_GT_EQ] = ACTIONS(4399),
    [anon_sym_LT_EQ] = ACTIONS(4399),
    [anon_sym_DOT] = ACTIONS(4401),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4401),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4359),
    [anon_sym_DOT_DOT] = ACTIONS(4399),
    [anon_sym_and] = ACTIONS(4401),
    [anon_sym_or] = ACTIONS(4401),
    [anon_sym_AMP_AMP] = ACTIONS(4399),
    [anon_sym_PIPE_PIPE] = ACTIONS(4399),
    [anon_sym_QMARK_QMARK] = ACTIONS(4399),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4339),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4401),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4401),
    [anon_sym_is] = ACTIONS(4401),
    [anon_sym_DASH_GT] = ACTIONS(4399),
    [anon_sym_with] = ACTIONS(4401),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3142] = {
    [sym_preproc_region] = STATE(3142),
    [sym_preproc_endregion] = STATE(3142),
    [sym_preproc_line] = STATE(3142),
    [sym_preproc_pragma] = STATE(3142),
    [sym_preproc_nullable] = STATE(3142),
    [sym_preproc_error] = STATE(3142),
    [sym_preproc_warning] = STATE(3142),
    [sym_preproc_define] = STATE(3142),
    [sym_preproc_undef] = STATE(3142),
    [sym__identifier_token] = ACTIONS(4674),
    [anon_sym_alias] = ACTIONS(4674),
    [anon_sym_global] = ACTIONS(4674),
    [anon_sym_LBRACK] = ACTIONS(3001),
    [anon_sym_COLON] = ACTIONS(3001),
    [anon_sym_COMMA] = ACTIONS(4676),
    [anon_sym_RBRACK] = ACTIONS(4676),
    [anon_sym_LPAREN] = ACTIONS(4676),
    [anon_sym_RPAREN] = ACTIONS(4676),
    [anon_sym_RBRACE] = ACTIONS(4676),
    [anon_sym_file] = ACTIONS(4674),
    [anon_sym_LT] = ACTIONS(2999),
    [anon_sym_GT] = ACTIONS(2999),
    [anon_sym_where] = ACTIONS(4674),
    [anon_sym_QMARK] = ACTIONS(2999),
    [anon_sym_notnull] = ACTIONS(4674),
    [anon_sym_unmanaged] = ACTIONS(4674),
    [anon_sym_BANG] = ACTIONS(2999),
    [anon_sym_PLUS_PLUS] = ACTIONS(3001),
    [anon_sym_DASH_DASH] = ACTIONS(3001),
    [anon_sym_PLUS] = ACTIONS(2999),
    [anon_sym_DASH] = ACTIONS(2999),
    [anon_sym_STAR] = ACTIONS(3001),
    [anon_sym_SLASH] = ACTIONS(2999),
    [anon_sym_PERCENT] = ACTIONS(3001),
    [anon_sym_CARET] = ACTIONS(3001),
    [anon_sym_PIPE] = ACTIONS(2999),
    [anon_sym_AMP] = ACTIONS(2999),
    [anon_sym_LT_LT] = ACTIONS(3001),
    [anon_sym_GT_GT] = ACTIONS(2999),
    [anon_sym_GT_GT_GT] = ACTIONS(3001),
    [anon_sym_EQ_EQ] = ACTIONS(3001),
    [anon_sym_BANG_EQ] = ACTIONS(3001),
    [anon_sym_GT_EQ] = ACTIONS(3001),
    [anon_sym_LT_EQ] = ACTIONS(3001),
    [anon_sym_DOT] = ACTIONS(2999),
    [anon_sym_scoped] = ACTIONS(4674),
    [anon_sym_EQ_GT] = ACTIONS(4676),
    [anon_sym_var] = ACTIONS(4674),
    [anon_sym_yield] = ACTIONS(4674),
    [anon_sym_switch] = ACTIONS(2999),
    [anon_sym_when] = ACTIONS(4674),
    [sym_discard] = ACTIONS(4674),
    [anon_sym_DOT_DOT] = ACTIONS(3001),
    [anon_sym_and] = ACTIONS(4674),
    [anon_sym_or] = ACTIONS(4674),
    [anon_sym_AMP_AMP] = ACTIONS(3001),
    [anon_sym_PIPE_PIPE] = ACTIONS(3001),
    [anon_sym_QMARK_QMARK] = ACTIONS(3001),
    [anon_sym_from] = ACTIONS(4674),
    [anon_sym_into] = ACTIONS(4674),
    [anon_sym_join] = ACTIONS(4674),
    [anon_sym_on] = ACTIONS(4674),
    [anon_sym_equals] = ACTIONS(4674),
    [anon_sym_let] = ACTIONS(4674),
    [anon_sym_orderby] = ACTIONS(4674),
    [anon_sym_ascending] = ACTIONS(4674),
    [anon_sym_descending] = ACTIONS(4674),
    [anon_sym_group] = ACTIONS(4674),
    [anon_sym_by] = ACTIONS(4674),
    [anon_sym_select] = ACTIONS(4674),
    [anon_sym_as] = ACTIONS(2999),
    [anon_sym_is] = ACTIONS(2999),
    [anon_sym_DASH_GT] = ACTIONS(3001),
    [anon_sym_with] = ACTIONS(2999),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3143] = {
    [sym_property_pattern_clause] = STATE(3362),
    [sym__variable_designation] = STATE(5045),
    [sym_parenthesized_variable_designation] = STATE(5027),
    [sym_identifier] = STATE(5034),
    [sym__reserved_identifier] = STATE(3572),
    [sym_preproc_region] = STATE(3143),
    [sym_preproc_endregion] = STATE(3143),
    [sym_preproc_line] = STATE(3143),
    [sym_preproc_pragma] = STATE(3143),
    [sym_preproc_nullable] = STATE(3143),
    [sym_preproc_error] = STATE(3143),
    [sym_preproc_warning] = STATE(3143),
    [sym_preproc_define] = STATE(3143),
    [sym_preproc_undef] = STATE(3143),
    [sym__identifier_token] = ACTIONS(4328),
    [anon_sym_alias] = ACTIONS(4330),
    [anon_sym_global] = ACTIONS(4330),
    [anon_sym_LBRACK] = ACTIONS(4399),
    [anon_sym_LPAREN] = ACTIONS(4399),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_file] = ACTIONS(4330),
    [anon_sym_LT] = ACTIONS(4401),
    [anon_sym_GT] = ACTIONS(4401),
    [anon_sym_where] = ACTIONS(4401),
    [anon_sym_QMARK] = ACTIONS(4401),
    [anon_sym_notnull] = ACTIONS(4330),
    [anon_sym_unmanaged] = ACTIONS(4330),
    [anon_sym_BANG] = ACTIONS(4401),
    [anon_sym_PLUS_PLUS] = ACTIONS(4399),
    [anon_sym_DASH_DASH] = ACTIONS(4399),
    [anon_sym_PLUS] = ACTIONS(4401),
    [anon_sym_DASH] = ACTIONS(4401),
    [anon_sym_STAR] = ACTIONS(4399),
    [anon_sym_SLASH] = ACTIONS(4401),
    [anon_sym_PERCENT] = ACTIONS(4399),
    [anon_sym_CARET] = ACTIONS(4399),
    [anon_sym_PIPE] = ACTIONS(4401),
    [anon_sym_AMP] = ACTIONS(4401),
    [anon_sym_LT_LT] = ACTIONS(4399),
    [anon_sym_GT_GT] = ACTIONS(4401),
    [anon_sym_GT_GT_GT] = ACTIONS(4399),
    [anon_sym_EQ_EQ] = ACTIONS(4399),
    [anon_sym_BANG_EQ] = ACTIONS(4399),
    [anon_sym_GT_EQ] = ACTIONS(4399),
    [anon_sym_LT_EQ] = ACTIONS(4399),
    [anon_sym_DOT] = ACTIONS(4401),
    [anon_sym_scoped] = ACTIONS(4330),
    [anon_sym_var] = ACTIONS(4330),
    [anon_sym_yield] = ACTIONS(4330),
    [anon_sym_switch] = ACTIONS(4401),
    [anon_sym_when] = ACTIONS(4330),
    [sym_discard] = ACTIONS(4719),
    [anon_sym_DOT_DOT] = ACTIONS(4399),
    [anon_sym_and] = ACTIONS(4401),
    [anon_sym_or] = ACTIONS(4401),
    [anon_sym_AMP_AMP] = ACTIONS(4399),
    [anon_sym_PIPE_PIPE] = ACTIONS(4399),
    [anon_sym_QMARK_QMARK] = ACTIONS(4399),
    [anon_sym_from] = ACTIONS(4401),
    [anon_sym_into] = ACTIONS(4401),
    [anon_sym_join] = ACTIONS(4401),
    [anon_sym_on] = ACTIONS(4330),
    [anon_sym_equals] = ACTIONS(4330),
    [anon_sym_let] = ACTIONS(4401),
    [anon_sym_orderby] = ACTIONS(4401),
    [anon_sym_ascending] = ACTIONS(4330),
    [anon_sym_descending] = ACTIONS(4330),
    [anon_sym_group] = ACTIONS(4401),
    [anon_sym_by] = ACTIONS(4330),
    [anon_sym_select] = ACTIONS(4401),
    [anon_sym_as] = ACTIONS(4401),
    [anon_sym_is] = ACTIONS(4401),
    [anon_sym_DASH_GT] = ACTIONS(4399),
    [anon_sym_with] = ACTIONS(4401),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3144] = {
    [sym_property_pattern_clause] = STATE(3363),
    [sym__variable_designation] = STATE(5002),
    [sym_parenthesized_variable_designation] = STATE(5027),
    [sym_identifier] = STATE(5034),
    [sym__reserved_identifier] = STATE(3572),
    [sym_preproc_region] = STATE(3144),
    [sym_preproc_endregion] = STATE(3144),
    [sym_preproc_line] = STATE(3144),
    [sym_preproc_pragma] = STATE(3144),
    [sym_preproc_nullable] = STATE(3144),
    [sym_preproc_error] = STATE(3144),
    [sym_preproc_warning] = STATE(3144),
    [sym_preproc_define] = STATE(3144),
    [sym_preproc_undef] = STATE(3144),
    [sym__identifier_token] = ACTIONS(4328),
    [anon_sym_alias] = ACTIONS(4330),
    [anon_sym_global] = ACTIONS(4330),
    [anon_sym_LBRACK] = ACTIONS(4405),
    [anon_sym_LPAREN] = ACTIONS(4405),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_file] = ACTIONS(4330),
    [anon_sym_LT] = ACTIONS(4407),
    [anon_sym_GT] = ACTIONS(4407),
    [anon_sym_where] = ACTIONS(4407),
    [anon_sym_QMARK] = ACTIONS(4407),
    [anon_sym_notnull] = ACTIONS(4330),
    [anon_sym_unmanaged] = ACTIONS(4330),
    [anon_sym_BANG] = ACTIONS(4407),
    [anon_sym_PLUS_PLUS] = ACTIONS(4405),
    [anon_sym_DASH_DASH] = ACTIONS(4405),
    [anon_sym_PLUS] = ACTIONS(4407),
    [anon_sym_DASH] = ACTIONS(4407),
    [anon_sym_STAR] = ACTIONS(4405),
    [anon_sym_SLASH] = ACTIONS(4407),
    [anon_sym_PERCENT] = ACTIONS(4405),
    [anon_sym_CARET] = ACTIONS(4405),
    [anon_sym_PIPE] = ACTIONS(4407),
    [anon_sym_AMP] = ACTIONS(4407),
    [anon_sym_LT_LT] = ACTIONS(4405),
    [anon_sym_GT_GT] = ACTIONS(4407),
    [anon_sym_GT_GT_GT] = ACTIONS(4405),
    [anon_sym_EQ_EQ] = ACTIONS(4405),
    [anon_sym_BANG_EQ] = ACTIONS(4405),
    [anon_sym_GT_EQ] = ACTIONS(4405),
    [anon_sym_LT_EQ] = ACTIONS(4405),
    [anon_sym_DOT] = ACTIONS(4407),
    [anon_sym_scoped] = ACTIONS(4330),
    [anon_sym_var] = ACTIONS(4330),
    [anon_sym_yield] = ACTIONS(4330),
    [anon_sym_switch] = ACTIONS(4407),
    [anon_sym_when] = ACTIONS(4330),
    [sym_discard] = ACTIONS(4719),
    [anon_sym_DOT_DOT] = ACTIONS(4405),
    [anon_sym_and] = ACTIONS(4407),
    [anon_sym_or] = ACTIONS(4407),
    [anon_sym_AMP_AMP] = ACTIONS(4405),
    [anon_sym_PIPE_PIPE] = ACTIONS(4405),
    [anon_sym_QMARK_QMARK] = ACTIONS(4405),
    [anon_sym_from] = ACTIONS(4407),
    [anon_sym_into] = ACTIONS(4407),
    [anon_sym_join] = ACTIONS(4407),
    [anon_sym_on] = ACTIONS(4330),
    [anon_sym_equals] = ACTIONS(4330),
    [anon_sym_let] = ACTIONS(4407),
    [anon_sym_orderby] = ACTIONS(4407),
    [anon_sym_ascending] = ACTIONS(4330),
    [anon_sym_descending] = ACTIONS(4330),
    [anon_sym_group] = ACTIONS(4407),
    [anon_sym_by] = ACTIONS(4330),
    [anon_sym_select] = ACTIONS(4407),
    [anon_sym_as] = ACTIONS(4407),
    [anon_sym_is] = ACTIONS(4407),
    [anon_sym_DASH_GT] = ACTIONS(4405),
    [anon_sym_with] = ACTIONS(4407),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3145] = {
    [sym_preproc_region] = STATE(3145),
    [sym_preproc_endregion] = STATE(3145),
    [sym_preproc_line] = STATE(3145),
    [sym_preproc_pragma] = STATE(3145),
    [sym_preproc_nullable] = STATE(3145),
    [sym_preproc_error] = STATE(3145),
    [sym_preproc_warning] = STATE(3145),
    [sym_preproc_define] = STATE(3145),
    [sym_preproc_undef] = STATE(3145),
    [anon_sym_SEMI] = ACTIONS(3993),
    [anon_sym_EQ] = ACTIONS(3995),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_COLON] = ACTIONS(3993),
    [anon_sym_COMMA] = ACTIONS(3993),
    [anon_sym_RBRACK] = ACTIONS(3993),
    [anon_sym_LPAREN] = ACTIONS(3993),
    [anon_sym_RPAREN] = ACTIONS(3993),
    [anon_sym_LBRACE] = ACTIONS(3993),
    [anon_sym_RBRACE] = ACTIONS(3993),
    [anon_sym_LT] = ACTIONS(3995),
    [anon_sym_GT] = ACTIONS(3995),
    [anon_sym_in] = ACTIONS(3993),
    [anon_sym_where] = ACTIONS(3993),
    [anon_sym_QMARK] = ACTIONS(3995),
    [anon_sym_BANG] = ACTIONS(3995),
    [anon_sym_PLUS_PLUS] = ACTIONS(3993),
    [anon_sym_DASH_DASH] = ACTIONS(3993),
    [anon_sym_PLUS] = ACTIONS(3995),
    [anon_sym_DASH] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3995),
    [anon_sym_SLASH] = ACTIONS(3995),
    [anon_sym_PERCENT] = ACTIONS(3995),
    [anon_sym_CARET] = ACTIONS(3995),
    [anon_sym_PIPE] = ACTIONS(3995),
    [anon_sym_AMP] = ACTIONS(3995),
    [anon_sym_LT_LT] = ACTIONS(3995),
    [anon_sym_GT_GT] = ACTIONS(3995),
    [anon_sym_GT_GT_GT] = ACTIONS(3995),
    [anon_sym_EQ_EQ] = ACTIONS(3993),
    [anon_sym_BANG_EQ] = ACTIONS(3993),
    [anon_sym_GT_EQ] = ACTIONS(3993),
    [anon_sym_LT_EQ] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3995),
    [anon_sym_EQ_GT] = ACTIONS(3993),
    [anon_sym_switch] = ACTIONS(3993),
    [anon_sym_when] = ACTIONS(3993),
    [anon_sym_DOT_DOT] = ACTIONS(3993),
    [anon_sym_and] = ACTIONS(3993),
    [anon_sym_or] = ACTIONS(3993),
    [anon_sym_PLUS_EQ] = ACTIONS(3993),
    [anon_sym_DASH_EQ] = ACTIONS(3993),
    [anon_sym_STAR_EQ] = ACTIONS(3993),
    [anon_sym_SLASH_EQ] = ACTIONS(3993),
    [anon_sym_PERCENT_EQ] = ACTIONS(3993),
    [anon_sym_AMP_EQ] = ACTIONS(3993),
    [anon_sym_CARET_EQ] = ACTIONS(3993),
    [anon_sym_PIPE_EQ] = ACTIONS(3993),
    [anon_sym_LT_LT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(3993),
    [anon_sym_AMP_AMP] = ACTIONS(3993),
    [anon_sym_PIPE_PIPE] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK] = ACTIONS(3995),
    [anon_sym_on] = ACTIONS(3993),
    [anon_sym_equals] = ACTIONS(3993),
    [anon_sym_by] = ACTIONS(3993),
    [anon_sym_as] = ACTIONS(3993),
    [anon_sym_is] = ACTIONS(3993),
    [anon_sym_DASH_GT] = ACTIONS(3993),
    [anon_sym_with] = ACTIONS(3993),
    [aux_sym_preproc_if_token3] = ACTIONS(3993),
    [aux_sym_preproc_else_token1] = ACTIONS(3993),
    [aux_sym_preproc_elif_token1] = ACTIONS(3993),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3146] = {
    [sym__variable_designation] = STATE(4065),
    [sym_parenthesized_variable_designation] = STATE(3966),
    [sym_identifier] = STATE(3983),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3146),
    [sym_preproc_endregion] = STATE(3146),
    [sym_preproc_line] = STATE(3146),
    [sym_preproc_pragma] = STATE(3146),
    [sym_preproc_nullable] = STATE(3146),
    [sym_preproc_error] = STATE(3146),
    [sym_preproc_warning] = STATE(3146),
    [sym_preproc_define] = STATE(3146),
    [sym_preproc_undef] = STATE(3146),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4437),
    [anon_sym_COLON] = ACTIONS(4437),
    [anon_sym_LPAREN] = ACTIONS(4437),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4439),
    [anon_sym_GT] = ACTIONS(4439),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4439),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4439),
    [anon_sym_PLUS_PLUS] = ACTIONS(4437),
    [anon_sym_DASH_DASH] = ACTIONS(4437),
    [anon_sym_PLUS] = ACTIONS(4439),
    [anon_sym_DASH] = ACTIONS(4439),
    [anon_sym_STAR] = ACTIONS(4437),
    [anon_sym_SLASH] = ACTIONS(4439),
    [anon_sym_PERCENT] = ACTIONS(4437),
    [anon_sym_CARET] = ACTIONS(4437),
    [anon_sym_PIPE] = ACTIONS(4439),
    [anon_sym_AMP] = ACTIONS(4439),
    [anon_sym_LT_LT] = ACTIONS(4437),
    [anon_sym_GT_GT] = ACTIONS(4439),
    [anon_sym_GT_GT_GT] = ACTIONS(4437),
    [anon_sym_EQ_EQ] = ACTIONS(4437),
    [anon_sym_BANG_EQ] = ACTIONS(4437),
    [anon_sym_GT_EQ] = ACTIONS(4437),
    [anon_sym_LT_EQ] = ACTIONS(4437),
    [anon_sym_DOT] = ACTIONS(4439),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_EQ_GT] = ACTIONS(4437),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4439),
    [anon_sym_when] = ACTIONS(4439),
    [sym_discard] = ACTIONS(4347),
    [anon_sym_DOT_DOT] = ACTIONS(4437),
    [anon_sym_and] = ACTIONS(4439),
    [anon_sym_or] = ACTIONS(4439),
    [anon_sym_AMP_AMP] = ACTIONS(4437),
    [anon_sym_PIPE_PIPE] = ACTIONS(4437),
    [anon_sym_QMARK_QMARK] = ACTIONS(4437),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4439),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4439),
    [anon_sym_is] = ACTIONS(4439),
    [anon_sym_DASH_GT] = ACTIONS(4437),
    [anon_sym_with] = ACTIONS(4439),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3147] = {
    [sym_property_pattern_clause] = STATE(3411),
    [sym__variable_designation] = STATE(4088),
    [sym_parenthesized_variable_designation] = STATE(3966),
    [sym_identifier] = STATE(3983),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3147),
    [sym_preproc_endregion] = STATE(3147),
    [sym_preproc_line] = STATE(3147),
    [sym_preproc_pragma] = STATE(3147),
    [sym_preproc_nullable] = STATE(3147),
    [sym_preproc_error] = STATE(3147),
    [sym_preproc_warning] = STATE(3147),
    [sym_preproc_define] = STATE(3147),
    [sym_preproc_undef] = STATE(3147),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4405),
    [anon_sym_LPAREN] = ACTIONS(4405),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4407),
    [anon_sym_GT] = ACTIONS(4407),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4407),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4407),
    [anon_sym_PLUS_PLUS] = ACTIONS(4405),
    [anon_sym_DASH_DASH] = ACTIONS(4405),
    [anon_sym_PLUS] = ACTIONS(4407),
    [anon_sym_DASH] = ACTIONS(4407),
    [anon_sym_STAR] = ACTIONS(4405),
    [anon_sym_SLASH] = ACTIONS(4407),
    [anon_sym_PERCENT] = ACTIONS(4405),
    [anon_sym_CARET] = ACTIONS(4405),
    [anon_sym_PIPE] = ACTIONS(4407),
    [anon_sym_AMP] = ACTIONS(4407),
    [anon_sym_LT_LT] = ACTIONS(4405),
    [anon_sym_GT_GT] = ACTIONS(4407),
    [anon_sym_GT_GT_GT] = ACTIONS(4405),
    [anon_sym_EQ_EQ] = ACTIONS(4405),
    [anon_sym_BANG_EQ] = ACTIONS(4405),
    [anon_sym_GT_EQ] = ACTIONS(4405),
    [anon_sym_LT_EQ] = ACTIONS(4405),
    [anon_sym_DOT] = ACTIONS(4407),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4407),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4347),
    [anon_sym_DOT_DOT] = ACTIONS(4405),
    [anon_sym_and] = ACTIONS(4407),
    [anon_sym_or] = ACTIONS(4407),
    [anon_sym_AMP_AMP] = ACTIONS(4405),
    [anon_sym_PIPE_PIPE] = ACTIONS(4405),
    [anon_sym_QMARK_QMARK] = ACTIONS(4405),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4407),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4407),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4407),
    [anon_sym_is] = ACTIONS(4407),
    [anon_sym_DASH_GT] = ACTIONS(4405),
    [anon_sym_with] = ACTIONS(4407),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3148] = {
    [sym_property_pattern_clause] = STATE(3410),
    [sym__variable_designation] = STATE(4035),
    [sym_parenthesized_variable_designation] = STATE(3966),
    [sym_identifier] = STATE(3983),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3148),
    [sym_preproc_endregion] = STATE(3148),
    [sym_preproc_line] = STATE(3148),
    [sym_preproc_pragma] = STATE(3148),
    [sym_preproc_nullable] = STATE(3148),
    [sym_preproc_error] = STATE(3148),
    [sym_preproc_warning] = STATE(3148),
    [sym_preproc_define] = STATE(3148),
    [sym_preproc_undef] = STATE(3148),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4399),
    [anon_sym_LPAREN] = ACTIONS(4399),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4401),
    [anon_sym_GT] = ACTIONS(4401),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4401),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4401),
    [anon_sym_PLUS_PLUS] = ACTIONS(4399),
    [anon_sym_DASH_DASH] = ACTIONS(4399),
    [anon_sym_PLUS] = ACTIONS(4401),
    [anon_sym_DASH] = ACTIONS(4401),
    [anon_sym_STAR] = ACTIONS(4399),
    [anon_sym_SLASH] = ACTIONS(4401),
    [anon_sym_PERCENT] = ACTIONS(4399),
    [anon_sym_CARET] = ACTIONS(4399),
    [anon_sym_PIPE] = ACTIONS(4401),
    [anon_sym_AMP] = ACTIONS(4401),
    [anon_sym_LT_LT] = ACTIONS(4399),
    [anon_sym_GT_GT] = ACTIONS(4401),
    [anon_sym_GT_GT_GT] = ACTIONS(4399),
    [anon_sym_EQ_EQ] = ACTIONS(4399),
    [anon_sym_BANG_EQ] = ACTIONS(4399),
    [anon_sym_GT_EQ] = ACTIONS(4399),
    [anon_sym_LT_EQ] = ACTIONS(4399),
    [anon_sym_DOT] = ACTIONS(4401),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4401),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4347),
    [anon_sym_DOT_DOT] = ACTIONS(4399),
    [anon_sym_and] = ACTIONS(4401),
    [anon_sym_or] = ACTIONS(4401),
    [anon_sym_AMP_AMP] = ACTIONS(4399),
    [anon_sym_PIPE_PIPE] = ACTIONS(4399),
    [anon_sym_QMARK_QMARK] = ACTIONS(4399),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4401),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4401),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4401),
    [anon_sym_is] = ACTIONS(4401),
    [anon_sym_DASH_GT] = ACTIONS(4399),
    [anon_sym_with] = ACTIONS(4401),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3149] = {
    [sym__variable_designation] = STATE(3957),
    [sym_parenthesized_variable_designation] = STATE(3966),
    [sym_identifier] = STATE(3983),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3149),
    [sym_preproc_endregion] = STATE(3149),
    [sym_preproc_line] = STATE(3149),
    [sym_preproc_pragma] = STATE(3149),
    [sym_preproc_nullable] = STATE(3149),
    [sym_preproc_error] = STATE(3149),
    [sym_preproc_warning] = STATE(3149),
    [sym_preproc_define] = STATE(3149),
    [sym_preproc_undef] = STATE(3149),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4441),
    [anon_sym_COLON] = ACTIONS(4441),
    [anon_sym_LPAREN] = ACTIONS(4441),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4443),
    [anon_sym_GT] = ACTIONS(4443),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4443),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4443),
    [anon_sym_PLUS_PLUS] = ACTIONS(4441),
    [anon_sym_DASH_DASH] = ACTIONS(4441),
    [anon_sym_PLUS] = ACTIONS(4443),
    [anon_sym_DASH] = ACTIONS(4443),
    [anon_sym_STAR] = ACTIONS(4441),
    [anon_sym_SLASH] = ACTIONS(4443),
    [anon_sym_PERCENT] = ACTIONS(4441),
    [anon_sym_CARET] = ACTIONS(4441),
    [anon_sym_PIPE] = ACTIONS(4443),
    [anon_sym_AMP] = ACTIONS(4443),
    [anon_sym_LT_LT] = ACTIONS(4441),
    [anon_sym_GT_GT] = ACTIONS(4443),
    [anon_sym_GT_GT_GT] = ACTIONS(4441),
    [anon_sym_EQ_EQ] = ACTIONS(4441),
    [anon_sym_BANG_EQ] = ACTIONS(4441),
    [anon_sym_GT_EQ] = ACTIONS(4441),
    [anon_sym_LT_EQ] = ACTIONS(4441),
    [anon_sym_DOT] = ACTIONS(4443),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_EQ_GT] = ACTIONS(4441),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4443),
    [anon_sym_when] = ACTIONS(4443),
    [sym_discard] = ACTIONS(4347),
    [anon_sym_DOT_DOT] = ACTIONS(4441),
    [anon_sym_and] = ACTIONS(4443),
    [anon_sym_or] = ACTIONS(4443),
    [anon_sym_AMP_AMP] = ACTIONS(4441),
    [anon_sym_PIPE_PIPE] = ACTIONS(4441),
    [anon_sym_QMARK_QMARK] = ACTIONS(4441),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4443),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4443),
    [anon_sym_is] = ACTIONS(4443),
    [anon_sym_DASH_GT] = ACTIONS(4441),
    [anon_sym_with] = ACTIONS(4443),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3150] = {
    [sym_type_argument_list] = STATE(3177),
    [sym_preproc_region] = STATE(3150),
    [sym_preproc_endregion] = STATE(3150),
    [sym_preproc_line] = STATE(3150),
    [sym_preproc_pragma] = STATE(3150),
    [sym_preproc_nullable] = STATE(3150),
    [sym_preproc_error] = STATE(3150),
    [sym_preproc_warning] = STATE(3150),
    [sym_preproc_define] = STATE(3150),
    [sym_preproc_undef] = STATE(3150),
    [anon_sym_SEMI] = ACTIONS(4140),
    [anon_sym_EQ] = ACTIONS(4138),
    [anon_sym_LBRACK] = ACTIONS(4140),
    [anon_sym_COLON] = ACTIONS(4140),
    [anon_sym_COMMA] = ACTIONS(4140),
    [anon_sym_RBRACK] = ACTIONS(4140),
    [anon_sym_LPAREN] = ACTIONS(4140),
    [anon_sym_RPAREN] = ACTIONS(4140),
    [anon_sym_RBRACE] = ACTIONS(4140),
    [anon_sym_LT] = ACTIONS(4759),
    [anon_sym_GT] = ACTIONS(4138),
    [anon_sym_in] = ACTIONS(4138),
    [anon_sym_QMARK] = ACTIONS(4138),
    [anon_sym_BANG] = ACTIONS(4138),
    [anon_sym_PLUS_PLUS] = ACTIONS(4140),
    [anon_sym_DASH_DASH] = ACTIONS(4140),
    [anon_sym_PLUS] = ACTIONS(4138),
    [anon_sym_DASH] = ACTIONS(4138),
    [anon_sym_STAR] = ACTIONS(4138),
    [anon_sym_SLASH] = ACTIONS(4138),
    [anon_sym_PERCENT] = ACTIONS(4138),
    [anon_sym_CARET] = ACTIONS(4138),
    [anon_sym_PIPE] = ACTIONS(4138),
    [anon_sym_AMP] = ACTIONS(4138),
    [anon_sym_LT_LT] = ACTIONS(4138),
    [anon_sym_GT_GT] = ACTIONS(4138),
    [anon_sym_GT_GT_GT] = ACTIONS(4138),
    [anon_sym_EQ_EQ] = ACTIONS(4140),
    [anon_sym_BANG_EQ] = ACTIONS(4140),
    [anon_sym_GT_EQ] = ACTIONS(4140),
    [anon_sym_LT_EQ] = ACTIONS(4140),
    [anon_sym_DOT] = ACTIONS(4138),
    [anon_sym_EQ_GT] = ACTIONS(4140),
    [anon_sym_switch] = ACTIONS(4140),
    [anon_sym_when] = ACTIONS(4140),
    [anon_sym_DOT_DOT] = ACTIONS(4140),
    [anon_sym_and] = ACTIONS(4140),
    [anon_sym_or] = ACTIONS(4140),
    [anon_sym_PLUS_EQ] = ACTIONS(4140),
    [anon_sym_DASH_EQ] = ACTIONS(4140),
    [anon_sym_STAR_EQ] = ACTIONS(4140),
    [anon_sym_SLASH_EQ] = ACTIONS(4140),
    [anon_sym_PERCENT_EQ] = ACTIONS(4140),
    [anon_sym_AMP_EQ] = ACTIONS(4140),
    [anon_sym_CARET_EQ] = ACTIONS(4140),
    [anon_sym_PIPE_EQ] = ACTIONS(4140),
    [anon_sym_LT_LT_EQ] = ACTIONS(4140),
    [anon_sym_GT_GT_EQ] = ACTIONS(4140),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4140),
    [anon_sym_AMP_AMP] = ACTIONS(4140),
    [anon_sym_PIPE_PIPE] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK] = ACTIONS(4138),
    [anon_sym_into] = ACTIONS(4140),
    [anon_sym_on] = ACTIONS(4140),
    [anon_sym_equals] = ACTIONS(4140),
    [anon_sym_by] = ACTIONS(4140),
    [anon_sym_as] = ACTIONS(4140),
    [anon_sym_is] = ACTIONS(4140),
    [anon_sym_DASH_GT] = ACTIONS(4140),
    [anon_sym_with] = ACTIONS(4140),
    [aux_sym_preproc_if_token3] = ACTIONS(4140),
    [aux_sym_preproc_else_token1] = ACTIONS(4140),
    [aux_sym_preproc_elif_token1] = ACTIONS(4140),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3151] = {
    [sym_property_pattern_clause] = STATE(3425),
    [sym__variable_designation] = STATE(4035),
    [sym_parenthesized_variable_designation] = STATE(3966),
    [sym_identifier] = STATE(3983),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3151),
    [sym_preproc_endregion] = STATE(3151),
    [sym_preproc_line] = STATE(3151),
    [sym_preproc_pragma] = STATE(3151),
    [sym_preproc_nullable] = STATE(3151),
    [sym_preproc_error] = STATE(3151),
    [sym_preproc_warning] = STATE(3151),
    [sym_preproc_define] = STATE(3151),
    [sym_preproc_undef] = STATE(3151),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4399),
    [anon_sym_LPAREN] = ACTIONS(4399),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4401),
    [anon_sym_GT] = ACTIONS(4401),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4401),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4401),
    [anon_sym_PLUS_PLUS] = ACTIONS(4399),
    [anon_sym_DASH_DASH] = ACTIONS(4399),
    [anon_sym_PLUS] = ACTIONS(4401),
    [anon_sym_DASH] = ACTIONS(4401),
    [anon_sym_STAR] = ACTIONS(4399),
    [anon_sym_SLASH] = ACTIONS(4401),
    [anon_sym_PERCENT] = ACTIONS(4399),
    [anon_sym_CARET] = ACTIONS(4399),
    [anon_sym_PIPE] = ACTIONS(4401),
    [anon_sym_AMP] = ACTIONS(4401),
    [anon_sym_LT_LT] = ACTIONS(4399),
    [anon_sym_GT_GT] = ACTIONS(4401),
    [anon_sym_GT_GT_GT] = ACTIONS(4399),
    [anon_sym_EQ_EQ] = ACTIONS(4399),
    [anon_sym_BANG_EQ] = ACTIONS(4399),
    [anon_sym_GT_EQ] = ACTIONS(4399),
    [anon_sym_LT_EQ] = ACTIONS(4399),
    [anon_sym_DOT] = ACTIONS(4401),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4401),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4347),
    [anon_sym_DOT_DOT] = ACTIONS(4399),
    [anon_sym_and] = ACTIONS(4401),
    [anon_sym_or] = ACTIONS(4401),
    [anon_sym_AMP_AMP] = ACTIONS(4399),
    [anon_sym_PIPE_PIPE] = ACTIONS(4399),
    [anon_sym_QMARK_QMARK] = ACTIONS(4399),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4401),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4401),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4401),
    [anon_sym_is] = ACTIONS(4401),
    [anon_sym_DASH_GT] = ACTIONS(4399),
    [anon_sym_with] = ACTIONS(4401),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3152] = {
    [sym_preproc_region] = STATE(3152),
    [sym_preproc_endregion] = STATE(3152),
    [sym_preproc_line] = STATE(3152),
    [sym_preproc_pragma] = STATE(3152),
    [sym_preproc_nullable] = STATE(3152),
    [sym_preproc_error] = STATE(3152),
    [sym_preproc_warning] = STATE(3152),
    [sym_preproc_define] = STATE(3152),
    [sym_preproc_undef] = STATE(3152),
    [sym__identifier_token] = ACTIONS(3397),
    [anon_sym_extern] = ACTIONS(3397),
    [anon_sym_alias] = ACTIONS(3397),
    [anon_sym_global] = ACTIONS(3397),
    [anon_sym_using] = ACTIONS(3397),
    [anon_sym_unsafe] = ACTIONS(3397),
    [anon_sym_static] = ACTIONS(3397),
    [anon_sym_LBRACK] = ACTIONS(3399),
    [anon_sym_LPAREN] = ACTIONS(3399),
    [anon_sym_event] = ACTIONS(3397),
    [anon_sym_namespace] = ACTIONS(3397),
    [anon_sym_class] = ACTIONS(3397),
    [anon_sym_ref] = ACTIONS(3397),
    [anon_sym_struct] = ACTIONS(3397),
    [anon_sym_enum] = ACTIONS(3397),
    [anon_sym_RBRACE] = ACTIONS(3399),
    [anon_sym_interface] = ACTIONS(3397),
    [anon_sym_delegate] = ACTIONS(3397),
    [anon_sym_record] = ACTIONS(3397),
    [anon_sym_abstract] = ACTIONS(3397),
    [anon_sym_async] = ACTIONS(3397),
    [anon_sym_const] = ACTIONS(3397),
    [anon_sym_file] = ACTIONS(3397),
    [anon_sym_fixed] = ACTIONS(3397),
    [anon_sym_internal] = ACTIONS(3397),
    [anon_sym_new] = ACTIONS(3397),
    [anon_sym_override] = ACTIONS(3397),
    [anon_sym_partial] = ACTIONS(3397),
    [anon_sym_private] = ACTIONS(3397),
    [anon_sym_protected] = ACTIONS(3397),
    [anon_sym_public] = ACTIONS(3397),
    [anon_sym_readonly] = ACTIONS(3397),
    [anon_sym_required] = ACTIONS(3397),
    [anon_sym_sealed] = ACTIONS(3397),
    [anon_sym_virtual] = ACTIONS(3397),
    [anon_sym_volatile] = ACTIONS(3397),
    [anon_sym_where] = ACTIONS(3397),
    [anon_sym_notnull] = ACTIONS(3397),
    [anon_sym_unmanaged] = ACTIONS(3397),
    [anon_sym_TILDE] = ACTIONS(3399),
    [anon_sym_implicit] = ACTIONS(3397),
    [anon_sym_explicit] = ACTIONS(3397),
    [anon_sym_scoped] = ACTIONS(3397),
    [anon_sym_var] = ACTIONS(3397),
    [sym_predefined_type] = ACTIONS(3397),
    [anon_sym_while] = ACTIONS(3397),
    [anon_sym_yield] = ACTIONS(3397),
    [anon_sym_when] = ACTIONS(3397),
    [anon_sym_else] = ACTIONS(3397),
    [anon_sym_from] = ACTIONS(3397),
    [anon_sym_into] = ACTIONS(3397),
    [anon_sym_join] = ACTIONS(3397),
    [anon_sym_on] = ACTIONS(3397),
    [anon_sym_equals] = ACTIONS(3397),
    [anon_sym_let] = ACTIONS(3397),
    [anon_sym_orderby] = ACTIONS(3397),
    [anon_sym_ascending] = ACTIONS(3397),
    [anon_sym_descending] = ACTIONS(3397),
    [anon_sym_group] = ACTIONS(3397),
    [anon_sym_by] = ACTIONS(3397),
    [anon_sym_select] = ACTIONS(3397),
    [aux_sym_preproc_if_token1] = ACTIONS(3399),
    [aux_sym_preproc_if_token3] = ACTIONS(3399),
    [aux_sym_preproc_else_token1] = ACTIONS(3399),
    [aux_sym_preproc_elif_token1] = ACTIONS(3399),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3153] = {
    [sym_property_pattern_clause] = STATE(3435),
    [sym__variable_designation] = STATE(4088),
    [sym_parenthesized_variable_designation] = STATE(3966),
    [sym_identifier] = STATE(3983),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3153),
    [sym_preproc_endregion] = STATE(3153),
    [sym_preproc_line] = STATE(3153),
    [sym_preproc_pragma] = STATE(3153),
    [sym_preproc_nullable] = STATE(3153),
    [sym_preproc_error] = STATE(3153),
    [sym_preproc_warning] = STATE(3153),
    [sym_preproc_define] = STATE(3153),
    [sym_preproc_undef] = STATE(3153),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4405),
    [anon_sym_LPAREN] = ACTIONS(4405),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4407),
    [anon_sym_GT] = ACTIONS(4407),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4407),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4407),
    [anon_sym_PLUS_PLUS] = ACTIONS(4405),
    [anon_sym_DASH_DASH] = ACTIONS(4405),
    [anon_sym_PLUS] = ACTIONS(4407),
    [anon_sym_DASH] = ACTIONS(4407),
    [anon_sym_STAR] = ACTIONS(4405),
    [anon_sym_SLASH] = ACTIONS(4407),
    [anon_sym_PERCENT] = ACTIONS(4405),
    [anon_sym_CARET] = ACTIONS(4405),
    [anon_sym_PIPE] = ACTIONS(4407),
    [anon_sym_AMP] = ACTIONS(4407),
    [anon_sym_LT_LT] = ACTIONS(4405),
    [anon_sym_GT_GT] = ACTIONS(4407),
    [anon_sym_GT_GT_GT] = ACTIONS(4405),
    [anon_sym_EQ_EQ] = ACTIONS(4405),
    [anon_sym_BANG_EQ] = ACTIONS(4405),
    [anon_sym_GT_EQ] = ACTIONS(4405),
    [anon_sym_LT_EQ] = ACTIONS(4405),
    [anon_sym_DOT] = ACTIONS(4407),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4407),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4347),
    [anon_sym_DOT_DOT] = ACTIONS(4405),
    [anon_sym_and] = ACTIONS(4407),
    [anon_sym_or] = ACTIONS(4407),
    [anon_sym_AMP_AMP] = ACTIONS(4405),
    [anon_sym_PIPE_PIPE] = ACTIONS(4405),
    [anon_sym_QMARK_QMARK] = ACTIONS(4405),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4407),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4407),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4407),
    [anon_sym_is] = ACTIONS(4407),
    [anon_sym_DASH_GT] = ACTIONS(4405),
    [anon_sym_with] = ACTIONS(4407),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3154] = {
    [sym_property_pattern_clause] = STATE(3376),
    [sym__variable_designation] = STATE(4161),
    [sym_parenthesized_variable_designation] = STATE(4153),
    [sym_identifier] = STATE(4156),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3154),
    [sym_preproc_endregion] = STATE(3154),
    [sym_preproc_line] = STATE(3154),
    [sym_preproc_pragma] = STATE(3154),
    [sym_preproc_nullable] = STATE(3154),
    [sym_preproc_error] = STATE(3154),
    [sym_preproc_warning] = STATE(3154),
    [sym_preproc_define] = STATE(3154),
    [sym_preproc_undef] = STATE(3154),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4405),
    [anon_sym_LPAREN] = ACTIONS(4405),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4407),
    [anon_sym_GT] = ACTIONS(4407),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4407),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4407),
    [anon_sym_PLUS_PLUS] = ACTIONS(4405),
    [anon_sym_DASH_DASH] = ACTIONS(4405),
    [anon_sym_PLUS] = ACTIONS(4407),
    [anon_sym_DASH] = ACTIONS(4407),
    [anon_sym_STAR] = ACTIONS(4405),
    [anon_sym_SLASH] = ACTIONS(4407),
    [anon_sym_PERCENT] = ACTIONS(4405),
    [anon_sym_CARET] = ACTIONS(4405),
    [anon_sym_PIPE] = ACTIONS(4407),
    [anon_sym_AMP] = ACTIONS(4407),
    [anon_sym_LT_LT] = ACTIONS(4405),
    [anon_sym_GT_GT] = ACTIONS(4407),
    [anon_sym_GT_GT_GT] = ACTIONS(4405),
    [anon_sym_EQ_EQ] = ACTIONS(4405),
    [anon_sym_BANG_EQ] = ACTIONS(4405),
    [anon_sym_GT_EQ] = ACTIONS(4405),
    [anon_sym_LT_EQ] = ACTIONS(4405),
    [anon_sym_DOT] = ACTIONS(4407),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4407),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4359),
    [anon_sym_DOT_DOT] = ACTIONS(4405),
    [anon_sym_and] = ACTIONS(4407),
    [anon_sym_or] = ACTIONS(4407),
    [anon_sym_AMP_AMP] = ACTIONS(4405),
    [anon_sym_PIPE_PIPE] = ACTIONS(4405),
    [anon_sym_QMARK_QMARK] = ACTIONS(4405),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4339),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4407),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4407),
    [anon_sym_is] = ACTIONS(4407),
    [anon_sym_DASH_GT] = ACTIONS(4405),
    [anon_sym_with] = ACTIONS(4407),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3155] = {
    [sym__variable_designation] = STATE(4190),
    [sym_parenthesized_variable_designation] = STATE(4153),
    [sym_identifier] = STATE(4156),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3155),
    [sym_preproc_endregion] = STATE(3155),
    [sym_preproc_line] = STATE(3155),
    [sym_preproc_pragma] = STATE(3155),
    [sym_preproc_nullable] = STATE(3155),
    [sym_preproc_error] = STATE(3155),
    [sym_preproc_warning] = STATE(3155),
    [sym_preproc_define] = STATE(3155),
    [sym_preproc_undef] = STATE(3155),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4441),
    [anon_sym_COLON] = ACTIONS(4441),
    [anon_sym_LPAREN] = ACTIONS(4441),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4443),
    [anon_sym_GT] = ACTIONS(4443),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4443),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4443),
    [anon_sym_PLUS_PLUS] = ACTIONS(4441),
    [anon_sym_DASH_DASH] = ACTIONS(4441),
    [anon_sym_PLUS] = ACTIONS(4443),
    [anon_sym_DASH] = ACTIONS(4443),
    [anon_sym_STAR] = ACTIONS(4441),
    [anon_sym_SLASH] = ACTIONS(4443),
    [anon_sym_PERCENT] = ACTIONS(4441),
    [anon_sym_CARET] = ACTIONS(4441),
    [anon_sym_PIPE] = ACTIONS(4443),
    [anon_sym_AMP] = ACTIONS(4443),
    [anon_sym_LT_LT] = ACTIONS(4441),
    [anon_sym_GT_GT] = ACTIONS(4443),
    [anon_sym_GT_GT_GT] = ACTIONS(4441),
    [anon_sym_EQ_EQ] = ACTIONS(4441),
    [anon_sym_BANG_EQ] = ACTIONS(4441),
    [anon_sym_GT_EQ] = ACTIONS(4441),
    [anon_sym_LT_EQ] = ACTIONS(4441),
    [anon_sym_DOT] = ACTIONS(4443),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_EQ_GT] = ACTIONS(4441),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4443),
    [anon_sym_when] = ACTIONS(4443),
    [sym_discard] = ACTIONS(4359),
    [anon_sym_DOT_DOT] = ACTIONS(4441),
    [anon_sym_and] = ACTIONS(4443),
    [anon_sym_or] = ACTIONS(4443),
    [anon_sym_AMP_AMP] = ACTIONS(4441),
    [anon_sym_PIPE_PIPE] = ACTIONS(4441),
    [anon_sym_QMARK_QMARK] = ACTIONS(4441),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4339),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4443),
    [anon_sym_is] = ACTIONS(4443),
    [anon_sym_DASH_GT] = ACTIONS(4441),
    [anon_sym_with] = ACTIONS(4443),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3156] = {
    [sym_property_pattern_clause] = STATE(3382),
    [sym__variable_designation] = STATE(4166),
    [sym_parenthesized_variable_designation] = STATE(4153),
    [sym_identifier] = STATE(4156),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3156),
    [sym_preproc_endregion] = STATE(3156),
    [sym_preproc_line] = STATE(3156),
    [sym_preproc_pragma] = STATE(3156),
    [sym_preproc_nullable] = STATE(3156),
    [sym_preproc_error] = STATE(3156),
    [sym_preproc_warning] = STATE(3156),
    [sym_preproc_define] = STATE(3156),
    [sym_preproc_undef] = STATE(3156),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4399),
    [anon_sym_LPAREN] = ACTIONS(4399),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4401),
    [anon_sym_GT] = ACTIONS(4401),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4401),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4401),
    [anon_sym_PLUS_PLUS] = ACTIONS(4399),
    [anon_sym_DASH_DASH] = ACTIONS(4399),
    [anon_sym_PLUS] = ACTIONS(4401),
    [anon_sym_DASH] = ACTIONS(4401),
    [anon_sym_STAR] = ACTIONS(4399),
    [anon_sym_SLASH] = ACTIONS(4401),
    [anon_sym_PERCENT] = ACTIONS(4399),
    [anon_sym_CARET] = ACTIONS(4399),
    [anon_sym_PIPE] = ACTIONS(4401),
    [anon_sym_AMP] = ACTIONS(4401),
    [anon_sym_LT_LT] = ACTIONS(4399),
    [anon_sym_GT_GT] = ACTIONS(4401),
    [anon_sym_GT_GT_GT] = ACTIONS(4399),
    [anon_sym_EQ_EQ] = ACTIONS(4399),
    [anon_sym_BANG_EQ] = ACTIONS(4399),
    [anon_sym_GT_EQ] = ACTIONS(4399),
    [anon_sym_LT_EQ] = ACTIONS(4399),
    [anon_sym_DOT] = ACTIONS(4401),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4401),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4359),
    [anon_sym_DOT_DOT] = ACTIONS(4399),
    [anon_sym_and] = ACTIONS(4401),
    [anon_sym_or] = ACTIONS(4401),
    [anon_sym_AMP_AMP] = ACTIONS(4399),
    [anon_sym_PIPE_PIPE] = ACTIONS(4399),
    [anon_sym_QMARK_QMARK] = ACTIONS(4399),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4339),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4401),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4401),
    [anon_sym_is] = ACTIONS(4401),
    [anon_sym_DASH_GT] = ACTIONS(4399),
    [anon_sym_with] = ACTIONS(4401),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3157] = {
    [sym_property_pattern_clause] = STATE(3443),
    [sym__variable_designation] = STATE(5045),
    [sym_parenthesized_variable_designation] = STATE(5027),
    [sym_identifier] = STATE(5034),
    [sym__reserved_identifier] = STATE(3625),
    [sym_preproc_region] = STATE(3157),
    [sym_preproc_endregion] = STATE(3157),
    [sym_preproc_line] = STATE(3157),
    [sym_preproc_pragma] = STATE(3157),
    [sym_preproc_nullable] = STATE(3157),
    [sym_preproc_error] = STATE(3157),
    [sym_preproc_warning] = STATE(3157),
    [sym_preproc_define] = STATE(3157),
    [sym_preproc_undef] = STATE(3157),
    [sym__identifier_token] = ACTIONS(4349),
    [anon_sym_alias] = ACTIONS(4351),
    [anon_sym_global] = ACTIONS(4351),
    [anon_sym_LBRACK] = ACTIONS(4399),
    [anon_sym_LPAREN] = ACTIONS(4399),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_file] = ACTIONS(4351),
    [anon_sym_LT] = ACTIONS(4401),
    [anon_sym_GT] = ACTIONS(4401),
    [anon_sym_where] = ACTIONS(4401),
    [anon_sym_QMARK] = ACTIONS(4401),
    [anon_sym_notnull] = ACTIONS(4351),
    [anon_sym_unmanaged] = ACTIONS(4351),
    [anon_sym_BANG] = ACTIONS(4401),
    [anon_sym_PLUS_PLUS] = ACTIONS(4399),
    [anon_sym_DASH_DASH] = ACTIONS(4399),
    [anon_sym_PLUS] = ACTIONS(4401),
    [anon_sym_DASH] = ACTIONS(4401),
    [anon_sym_STAR] = ACTIONS(4399),
    [anon_sym_SLASH] = ACTIONS(4401),
    [anon_sym_PERCENT] = ACTIONS(4399),
    [anon_sym_CARET] = ACTIONS(4399),
    [anon_sym_PIPE] = ACTIONS(4401),
    [anon_sym_AMP] = ACTIONS(4401),
    [anon_sym_LT_LT] = ACTIONS(4399),
    [anon_sym_GT_GT] = ACTIONS(4401),
    [anon_sym_GT_GT_GT] = ACTIONS(4399),
    [anon_sym_EQ_EQ] = ACTIONS(4399),
    [anon_sym_BANG_EQ] = ACTIONS(4399),
    [anon_sym_GT_EQ] = ACTIONS(4399),
    [anon_sym_LT_EQ] = ACTIONS(4399),
    [anon_sym_DOT] = ACTIONS(4401),
    [anon_sym_scoped] = ACTIONS(4351),
    [anon_sym_var] = ACTIONS(4351),
    [anon_sym_yield] = ACTIONS(4351),
    [anon_sym_switch] = ACTIONS(4401),
    [anon_sym_when] = ACTIONS(4351),
    [sym_discard] = ACTIONS(4719),
    [anon_sym_DOT_DOT] = ACTIONS(4399),
    [anon_sym_and] = ACTIONS(4401),
    [anon_sym_or] = ACTIONS(4401),
    [anon_sym_AMP_AMP] = ACTIONS(4399),
    [anon_sym_PIPE_PIPE] = ACTIONS(4399),
    [anon_sym_QMARK_QMARK] = ACTIONS(4399),
    [anon_sym_from] = ACTIONS(4401),
    [anon_sym_into] = ACTIONS(4351),
    [anon_sym_join] = ACTIONS(4401),
    [anon_sym_on] = ACTIONS(4351),
    [anon_sym_equals] = ACTIONS(4351),
    [anon_sym_let] = ACTIONS(4401),
    [anon_sym_orderby] = ACTIONS(4401),
    [anon_sym_ascending] = ACTIONS(4351),
    [anon_sym_descending] = ACTIONS(4351),
    [anon_sym_group] = ACTIONS(4401),
    [anon_sym_by] = ACTIONS(4351),
    [anon_sym_select] = ACTIONS(4401),
    [anon_sym_as] = ACTIONS(4401),
    [anon_sym_is] = ACTIONS(4401),
    [anon_sym_DASH_GT] = ACTIONS(4399),
    [anon_sym_with] = ACTIONS(4401),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3158] = {
    [sym_type_argument_list] = STATE(3328),
    [sym_preproc_region] = STATE(3158),
    [sym_preproc_endregion] = STATE(3158),
    [sym_preproc_line] = STATE(3158),
    [sym_preproc_pragma] = STATE(3158),
    [sym_preproc_nullable] = STATE(3158),
    [sym_preproc_error] = STATE(3158),
    [sym_preproc_warning] = STATE(3158),
    [sym_preproc_define] = STATE(3158),
    [sym_preproc_undef] = STATE(3158),
    [sym__identifier_token] = ACTIONS(4138),
    [anon_sym_alias] = ACTIONS(4138),
    [anon_sym_global] = ACTIONS(4138),
    [anon_sym_LBRACK] = ACTIONS(4140),
    [anon_sym_COLON] = ACTIONS(4138),
    [anon_sym_COMMA] = ACTIONS(4140),
    [anon_sym_LPAREN] = ACTIONS(4140),
    [anon_sym_LBRACE] = ACTIONS(4140),
    [anon_sym_file] = ACTIONS(4138),
    [anon_sym_LT] = ACTIONS(4762),
    [anon_sym_GT] = ACTIONS(4138),
    [anon_sym_where] = ACTIONS(4138),
    [anon_sym_QMARK] = ACTIONS(4138),
    [anon_sym_notnull] = ACTIONS(4138),
    [anon_sym_unmanaged] = ACTIONS(4138),
    [anon_sym_BANG] = ACTIONS(4138),
    [anon_sym_PLUS_PLUS] = ACTIONS(4140),
    [anon_sym_DASH_DASH] = ACTIONS(4140),
    [anon_sym_PLUS] = ACTIONS(4138),
    [anon_sym_DASH] = ACTIONS(4138),
    [anon_sym_STAR] = ACTIONS(4140),
    [anon_sym_SLASH] = ACTIONS(4138),
    [anon_sym_PERCENT] = ACTIONS(4140),
    [anon_sym_CARET] = ACTIONS(4140),
    [anon_sym_PIPE] = ACTIONS(4138),
    [anon_sym_AMP] = ACTIONS(4138),
    [anon_sym_LT_LT] = ACTIONS(4140),
    [anon_sym_GT_GT] = ACTIONS(4138),
    [anon_sym_GT_GT_GT] = ACTIONS(4140),
    [anon_sym_EQ_EQ] = ACTIONS(4140),
    [anon_sym_BANG_EQ] = ACTIONS(4140),
    [anon_sym_GT_EQ] = ACTIONS(4140),
    [anon_sym_LT_EQ] = ACTIONS(4140),
    [anon_sym_DOT] = ACTIONS(4138),
    [anon_sym_scoped] = ACTIONS(4138),
    [anon_sym_COLON_COLON] = ACTIONS(4326),
    [anon_sym_var] = ACTIONS(4138),
    [anon_sym_yield] = ACTIONS(4138),
    [anon_sym_switch] = ACTIONS(4138),
    [anon_sym_when] = ACTIONS(4138),
    [sym_discard] = ACTIONS(4138),
    [anon_sym_DOT_DOT] = ACTIONS(4140),
    [anon_sym_and] = ACTIONS(4138),
    [anon_sym_or] = ACTIONS(4138),
    [anon_sym_AMP_AMP] = ACTIONS(4140),
    [anon_sym_PIPE_PIPE] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK] = ACTIONS(4140),
    [anon_sym_from] = ACTIONS(4138),
    [anon_sym_into] = ACTIONS(4138),
    [anon_sym_join] = ACTIONS(4138),
    [anon_sym_on] = ACTIONS(4138),
    [anon_sym_equals] = ACTIONS(4138),
    [anon_sym_let] = ACTIONS(4138),
    [anon_sym_orderby] = ACTIONS(4138),
    [anon_sym_ascending] = ACTIONS(4138),
    [anon_sym_descending] = ACTIONS(4138),
    [anon_sym_group] = ACTIONS(4138),
    [anon_sym_by] = ACTIONS(4138),
    [anon_sym_select] = ACTIONS(4138),
    [anon_sym_as] = ACTIONS(4138),
    [anon_sym_is] = ACTIONS(4138),
    [anon_sym_DASH_GT] = ACTIONS(4140),
    [anon_sym_with] = ACTIONS(4138),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4140),
  },
  [3159] = {
    [sym__variable_designation] = STATE(4167),
    [sym_parenthesized_variable_designation] = STATE(4153),
    [sym_identifier] = STATE(4156),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3159),
    [sym_preproc_endregion] = STATE(3159),
    [sym_preproc_line] = STATE(3159),
    [sym_preproc_pragma] = STATE(3159),
    [sym_preproc_nullable] = STATE(3159),
    [sym_preproc_error] = STATE(3159),
    [sym_preproc_warning] = STATE(3159),
    [sym_preproc_define] = STATE(3159),
    [sym_preproc_undef] = STATE(3159),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4399),
    [anon_sym_COLON] = ACTIONS(4399),
    [anon_sym_LPAREN] = ACTIONS(4399),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4401),
    [anon_sym_GT] = ACTIONS(4401),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4401),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4401),
    [anon_sym_PLUS_PLUS] = ACTIONS(4399),
    [anon_sym_DASH_DASH] = ACTIONS(4399),
    [anon_sym_PLUS] = ACTIONS(4401),
    [anon_sym_DASH] = ACTIONS(4401),
    [anon_sym_STAR] = ACTIONS(4399),
    [anon_sym_SLASH] = ACTIONS(4401),
    [anon_sym_PERCENT] = ACTIONS(4399),
    [anon_sym_CARET] = ACTIONS(4399),
    [anon_sym_PIPE] = ACTIONS(4401),
    [anon_sym_AMP] = ACTIONS(4401),
    [anon_sym_LT_LT] = ACTIONS(4399),
    [anon_sym_GT_GT] = ACTIONS(4401),
    [anon_sym_GT_GT_GT] = ACTIONS(4399),
    [anon_sym_EQ_EQ] = ACTIONS(4399),
    [anon_sym_BANG_EQ] = ACTIONS(4399),
    [anon_sym_GT_EQ] = ACTIONS(4399),
    [anon_sym_LT_EQ] = ACTIONS(4399),
    [anon_sym_DOT] = ACTIONS(4401),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_EQ_GT] = ACTIONS(4399),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4401),
    [anon_sym_when] = ACTIONS(4401),
    [sym_discard] = ACTIONS(4359),
    [anon_sym_DOT_DOT] = ACTIONS(4399),
    [anon_sym_and] = ACTIONS(4401),
    [anon_sym_or] = ACTIONS(4401),
    [anon_sym_AMP_AMP] = ACTIONS(4399),
    [anon_sym_PIPE_PIPE] = ACTIONS(4399),
    [anon_sym_QMARK_QMARK] = ACTIONS(4399),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4339),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4401),
    [anon_sym_is] = ACTIONS(4401),
    [anon_sym_DASH_GT] = ACTIONS(4399),
    [anon_sym_with] = ACTIONS(4401),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3160] = {
    [sym_preproc_region] = STATE(3160),
    [sym_preproc_endregion] = STATE(3160),
    [sym_preproc_line] = STATE(3160),
    [sym_preproc_pragma] = STATE(3160),
    [sym_preproc_nullable] = STATE(3160),
    [sym_preproc_error] = STATE(3160),
    [sym_preproc_warning] = STATE(3160),
    [sym_preproc_define] = STATE(3160),
    [sym_preproc_undef] = STATE(3160),
    [sym__identifier_token] = ACTIONS(3401),
    [anon_sym_extern] = ACTIONS(3401),
    [anon_sym_alias] = ACTIONS(3401),
    [anon_sym_global] = ACTIONS(3401),
    [anon_sym_using] = ACTIONS(3401),
    [anon_sym_unsafe] = ACTIONS(3401),
    [anon_sym_static] = ACTIONS(3401),
    [anon_sym_LBRACK] = ACTIONS(3403),
    [anon_sym_LPAREN] = ACTIONS(3403),
    [anon_sym_event] = ACTIONS(3401),
    [anon_sym_namespace] = ACTIONS(3401),
    [anon_sym_class] = ACTIONS(3401),
    [anon_sym_ref] = ACTIONS(3401),
    [anon_sym_struct] = ACTIONS(3401),
    [anon_sym_enum] = ACTIONS(3401),
    [anon_sym_RBRACE] = ACTIONS(3403),
    [anon_sym_interface] = ACTIONS(3401),
    [anon_sym_delegate] = ACTIONS(3401),
    [anon_sym_record] = ACTIONS(3401),
    [anon_sym_abstract] = ACTIONS(3401),
    [anon_sym_async] = ACTIONS(3401),
    [anon_sym_const] = ACTIONS(3401),
    [anon_sym_file] = ACTIONS(3401),
    [anon_sym_fixed] = ACTIONS(3401),
    [anon_sym_internal] = ACTIONS(3401),
    [anon_sym_new] = ACTIONS(3401),
    [anon_sym_override] = ACTIONS(3401),
    [anon_sym_partial] = ACTIONS(3401),
    [anon_sym_private] = ACTIONS(3401),
    [anon_sym_protected] = ACTIONS(3401),
    [anon_sym_public] = ACTIONS(3401),
    [anon_sym_readonly] = ACTIONS(3401),
    [anon_sym_required] = ACTIONS(3401),
    [anon_sym_sealed] = ACTIONS(3401),
    [anon_sym_virtual] = ACTIONS(3401),
    [anon_sym_volatile] = ACTIONS(3401),
    [anon_sym_where] = ACTIONS(3401),
    [anon_sym_notnull] = ACTIONS(3401),
    [anon_sym_unmanaged] = ACTIONS(3401),
    [anon_sym_TILDE] = ACTIONS(3403),
    [anon_sym_implicit] = ACTIONS(3401),
    [anon_sym_explicit] = ACTIONS(3401),
    [anon_sym_scoped] = ACTIONS(3401),
    [anon_sym_var] = ACTIONS(3401),
    [sym_predefined_type] = ACTIONS(3401),
    [anon_sym_while] = ACTIONS(3401),
    [anon_sym_yield] = ACTIONS(3401),
    [anon_sym_when] = ACTIONS(3401),
    [anon_sym_else] = ACTIONS(3401),
    [anon_sym_from] = ACTIONS(3401),
    [anon_sym_into] = ACTIONS(3401),
    [anon_sym_join] = ACTIONS(3401),
    [anon_sym_on] = ACTIONS(3401),
    [anon_sym_equals] = ACTIONS(3401),
    [anon_sym_let] = ACTIONS(3401),
    [anon_sym_orderby] = ACTIONS(3401),
    [anon_sym_ascending] = ACTIONS(3401),
    [anon_sym_descending] = ACTIONS(3401),
    [anon_sym_group] = ACTIONS(3401),
    [anon_sym_by] = ACTIONS(3401),
    [anon_sym_select] = ACTIONS(3401),
    [aux_sym_preproc_if_token1] = ACTIONS(3403),
    [aux_sym_preproc_if_token3] = ACTIONS(3403),
    [aux_sym_preproc_else_token1] = ACTIONS(3403),
    [aux_sym_preproc_elif_token1] = ACTIONS(3403),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3161] = {
    [sym_property_pattern_clause] = STATE(3455),
    [sym__variable_designation] = STATE(5002),
    [sym_parenthesized_variable_designation] = STATE(5027),
    [sym_identifier] = STATE(5034),
    [sym__reserved_identifier] = STATE(3625),
    [sym_preproc_region] = STATE(3161),
    [sym_preproc_endregion] = STATE(3161),
    [sym_preproc_line] = STATE(3161),
    [sym_preproc_pragma] = STATE(3161),
    [sym_preproc_nullable] = STATE(3161),
    [sym_preproc_error] = STATE(3161),
    [sym_preproc_warning] = STATE(3161),
    [sym_preproc_define] = STATE(3161),
    [sym_preproc_undef] = STATE(3161),
    [sym__identifier_token] = ACTIONS(4349),
    [anon_sym_alias] = ACTIONS(4351),
    [anon_sym_global] = ACTIONS(4351),
    [anon_sym_LBRACK] = ACTIONS(4405),
    [anon_sym_LPAREN] = ACTIONS(4405),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_file] = ACTIONS(4351),
    [anon_sym_LT] = ACTIONS(4407),
    [anon_sym_GT] = ACTIONS(4407),
    [anon_sym_where] = ACTIONS(4407),
    [anon_sym_QMARK] = ACTIONS(4407),
    [anon_sym_notnull] = ACTIONS(4351),
    [anon_sym_unmanaged] = ACTIONS(4351),
    [anon_sym_BANG] = ACTIONS(4407),
    [anon_sym_PLUS_PLUS] = ACTIONS(4405),
    [anon_sym_DASH_DASH] = ACTIONS(4405),
    [anon_sym_PLUS] = ACTIONS(4407),
    [anon_sym_DASH] = ACTIONS(4407),
    [anon_sym_STAR] = ACTIONS(4405),
    [anon_sym_SLASH] = ACTIONS(4407),
    [anon_sym_PERCENT] = ACTIONS(4405),
    [anon_sym_CARET] = ACTIONS(4405),
    [anon_sym_PIPE] = ACTIONS(4407),
    [anon_sym_AMP] = ACTIONS(4407),
    [anon_sym_LT_LT] = ACTIONS(4405),
    [anon_sym_GT_GT] = ACTIONS(4407),
    [anon_sym_GT_GT_GT] = ACTIONS(4405),
    [anon_sym_EQ_EQ] = ACTIONS(4405),
    [anon_sym_BANG_EQ] = ACTIONS(4405),
    [anon_sym_GT_EQ] = ACTIONS(4405),
    [anon_sym_LT_EQ] = ACTIONS(4405),
    [anon_sym_DOT] = ACTIONS(4407),
    [anon_sym_scoped] = ACTIONS(4351),
    [anon_sym_var] = ACTIONS(4351),
    [anon_sym_yield] = ACTIONS(4351),
    [anon_sym_switch] = ACTIONS(4407),
    [anon_sym_when] = ACTIONS(4351),
    [sym_discard] = ACTIONS(4719),
    [anon_sym_DOT_DOT] = ACTIONS(4405),
    [anon_sym_and] = ACTIONS(4407),
    [anon_sym_or] = ACTIONS(4407),
    [anon_sym_AMP_AMP] = ACTIONS(4405),
    [anon_sym_PIPE_PIPE] = ACTIONS(4405),
    [anon_sym_QMARK_QMARK] = ACTIONS(4405),
    [anon_sym_from] = ACTIONS(4407),
    [anon_sym_into] = ACTIONS(4351),
    [anon_sym_join] = ACTIONS(4407),
    [anon_sym_on] = ACTIONS(4351),
    [anon_sym_equals] = ACTIONS(4351),
    [anon_sym_let] = ACTIONS(4407),
    [anon_sym_orderby] = ACTIONS(4407),
    [anon_sym_ascending] = ACTIONS(4351),
    [anon_sym_descending] = ACTIONS(4351),
    [anon_sym_group] = ACTIONS(4407),
    [anon_sym_by] = ACTIONS(4351),
    [anon_sym_select] = ACTIONS(4407),
    [anon_sym_as] = ACTIONS(4407),
    [anon_sym_is] = ACTIONS(4407),
    [anon_sym_DASH_GT] = ACTIONS(4405),
    [anon_sym_with] = ACTIONS(4407),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3162] = {
    [sym_property_pattern_clause] = STATE(3287),
    [sym__variable_designation] = STATE(4161),
    [sym_parenthesized_variable_designation] = STATE(4153),
    [sym_identifier] = STATE(4156),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3162),
    [sym_preproc_endregion] = STATE(3162),
    [sym_preproc_line] = STATE(3162),
    [sym_preproc_pragma] = STATE(3162),
    [sym_preproc_nullable] = STATE(3162),
    [sym_preproc_error] = STATE(3162),
    [sym_preproc_warning] = STATE(3162),
    [sym_preproc_define] = STATE(3162),
    [sym_preproc_undef] = STATE(3162),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4405),
    [anon_sym_LPAREN] = ACTIONS(4405),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4407),
    [anon_sym_GT] = ACTIONS(4407),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4407),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4407),
    [anon_sym_PLUS_PLUS] = ACTIONS(4405),
    [anon_sym_DASH_DASH] = ACTIONS(4405),
    [anon_sym_PLUS] = ACTIONS(4407),
    [anon_sym_DASH] = ACTIONS(4407),
    [anon_sym_STAR] = ACTIONS(4405),
    [anon_sym_SLASH] = ACTIONS(4407),
    [anon_sym_PERCENT] = ACTIONS(4405),
    [anon_sym_CARET] = ACTIONS(4405),
    [anon_sym_PIPE] = ACTIONS(4407),
    [anon_sym_AMP] = ACTIONS(4407),
    [anon_sym_LT_LT] = ACTIONS(4405),
    [anon_sym_GT_GT] = ACTIONS(4407),
    [anon_sym_GT_GT_GT] = ACTIONS(4405),
    [anon_sym_EQ_EQ] = ACTIONS(4405),
    [anon_sym_BANG_EQ] = ACTIONS(4405),
    [anon_sym_GT_EQ] = ACTIONS(4405),
    [anon_sym_LT_EQ] = ACTIONS(4405),
    [anon_sym_DOT] = ACTIONS(4407),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4407),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4359),
    [anon_sym_DOT_DOT] = ACTIONS(4405),
    [anon_sym_and] = ACTIONS(4407),
    [anon_sym_or] = ACTIONS(4407),
    [anon_sym_AMP_AMP] = ACTIONS(4405),
    [anon_sym_PIPE_PIPE] = ACTIONS(4405),
    [anon_sym_QMARK_QMARK] = ACTIONS(4405),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4339),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4407),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4407),
    [anon_sym_is] = ACTIONS(4407),
    [anon_sym_DASH_GT] = ACTIONS(4405),
    [anon_sym_with] = ACTIONS(4407),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3163] = {
    [sym_property_pattern_clause] = STATE(3432),
    [sym__variable_designation] = STATE(4035),
    [sym_parenthesized_variable_designation] = STATE(3966),
    [sym_identifier] = STATE(3983),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3163),
    [sym_preproc_endregion] = STATE(3163),
    [sym_preproc_line] = STATE(3163),
    [sym_preproc_pragma] = STATE(3163),
    [sym_preproc_nullable] = STATE(3163),
    [sym_preproc_error] = STATE(3163),
    [sym_preproc_warning] = STATE(3163),
    [sym_preproc_define] = STATE(3163),
    [sym_preproc_undef] = STATE(3163),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4399),
    [anon_sym_LPAREN] = ACTIONS(4399),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4401),
    [anon_sym_GT] = ACTIONS(4401),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4401),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4401),
    [anon_sym_PLUS_PLUS] = ACTIONS(4399),
    [anon_sym_DASH_DASH] = ACTIONS(4399),
    [anon_sym_PLUS] = ACTIONS(4401),
    [anon_sym_DASH] = ACTIONS(4401),
    [anon_sym_STAR] = ACTIONS(4399),
    [anon_sym_SLASH] = ACTIONS(4401),
    [anon_sym_PERCENT] = ACTIONS(4399),
    [anon_sym_CARET] = ACTIONS(4399),
    [anon_sym_PIPE] = ACTIONS(4401),
    [anon_sym_AMP] = ACTIONS(4401),
    [anon_sym_LT_LT] = ACTIONS(4399),
    [anon_sym_GT_GT] = ACTIONS(4401),
    [anon_sym_GT_GT_GT] = ACTIONS(4399),
    [anon_sym_EQ_EQ] = ACTIONS(4399),
    [anon_sym_BANG_EQ] = ACTIONS(4399),
    [anon_sym_GT_EQ] = ACTIONS(4399),
    [anon_sym_LT_EQ] = ACTIONS(4399),
    [anon_sym_DOT] = ACTIONS(4401),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4401),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4347),
    [anon_sym_DOT_DOT] = ACTIONS(4399),
    [anon_sym_and] = ACTIONS(4401),
    [anon_sym_or] = ACTIONS(4401),
    [anon_sym_AMP_AMP] = ACTIONS(4399),
    [anon_sym_PIPE_PIPE] = ACTIONS(4399),
    [anon_sym_QMARK_QMARK] = ACTIONS(4399),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4401),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4401),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4401),
    [anon_sym_is] = ACTIONS(4401),
    [anon_sym_DASH_GT] = ACTIONS(4399),
    [anon_sym_with] = ACTIONS(4401),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3164] = {
    [sym_preproc_region] = STATE(3164),
    [sym_preproc_endregion] = STATE(3164),
    [sym_preproc_line] = STATE(3164),
    [sym_preproc_pragma] = STATE(3164),
    [sym_preproc_nullable] = STATE(3164),
    [sym_preproc_error] = STATE(3164),
    [sym_preproc_warning] = STATE(3164),
    [sym_preproc_define] = STATE(3164),
    [sym_preproc_undef] = STATE(3164),
    [sym__identifier_token] = ACTIONS(4650),
    [anon_sym_alias] = ACTIONS(4650),
    [anon_sym_global] = ACTIONS(4650),
    [anon_sym_LBRACK] = ACTIONS(4765),
    [anon_sym_COLON] = ACTIONS(4765),
    [anon_sym_COMMA] = ACTIONS(4652),
    [anon_sym_RBRACK] = ACTIONS(4652),
    [anon_sym_LPAREN] = ACTIONS(4652),
    [anon_sym_RPAREN] = ACTIONS(4652),
    [anon_sym_RBRACE] = ACTIONS(4652),
    [anon_sym_file] = ACTIONS(4650),
    [anon_sym_LT] = ACTIONS(4767),
    [anon_sym_GT] = ACTIONS(4767),
    [anon_sym_where] = ACTIONS(4650),
    [anon_sym_QMARK] = ACTIONS(4767),
    [anon_sym_notnull] = ACTIONS(4650),
    [anon_sym_unmanaged] = ACTIONS(4650),
    [anon_sym_BANG] = ACTIONS(4767),
    [anon_sym_PLUS_PLUS] = ACTIONS(4765),
    [anon_sym_DASH_DASH] = ACTIONS(4765),
    [anon_sym_PLUS] = ACTIONS(4767),
    [anon_sym_DASH] = ACTIONS(4767),
    [anon_sym_STAR] = ACTIONS(4765),
    [anon_sym_SLASH] = ACTIONS(4767),
    [anon_sym_PERCENT] = ACTIONS(4765),
    [anon_sym_CARET] = ACTIONS(4765),
    [anon_sym_PIPE] = ACTIONS(4767),
    [anon_sym_AMP] = ACTIONS(4767),
    [anon_sym_LT_LT] = ACTIONS(4765),
    [anon_sym_GT_GT] = ACTIONS(4767),
    [anon_sym_GT_GT_GT] = ACTIONS(4765),
    [anon_sym_EQ_EQ] = ACTIONS(4765),
    [anon_sym_BANG_EQ] = ACTIONS(4765),
    [anon_sym_GT_EQ] = ACTIONS(4765),
    [anon_sym_LT_EQ] = ACTIONS(4765),
    [anon_sym_DOT] = ACTIONS(4767),
    [anon_sym_scoped] = ACTIONS(4650),
    [anon_sym_EQ_GT] = ACTIONS(4652),
    [anon_sym_var] = ACTIONS(4650),
    [anon_sym_yield] = ACTIONS(4650),
    [anon_sym_switch] = ACTIONS(4767),
    [anon_sym_when] = ACTIONS(4650),
    [sym_discard] = ACTIONS(4650),
    [anon_sym_DOT_DOT] = ACTIONS(4765),
    [anon_sym_and] = ACTIONS(4650),
    [anon_sym_or] = ACTIONS(4650),
    [anon_sym_AMP_AMP] = ACTIONS(4765),
    [anon_sym_PIPE_PIPE] = ACTIONS(4765),
    [anon_sym_QMARK_QMARK] = ACTIONS(4765),
    [anon_sym_from] = ACTIONS(4650),
    [anon_sym_into] = ACTIONS(4650),
    [anon_sym_join] = ACTIONS(4650),
    [anon_sym_on] = ACTIONS(4650),
    [anon_sym_equals] = ACTIONS(4650),
    [anon_sym_let] = ACTIONS(4650),
    [anon_sym_orderby] = ACTIONS(4650),
    [anon_sym_ascending] = ACTIONS(4650),
    [anon_sym_descending] = ACTIONS(4650),
    [anon_sym_group] = ACTIONS(4650),
    [anon_sym_by] = ACTIONS(4650),
    [anon_sym_select] = ACTIONS(4650),
    [anon_sym_as] = ACTIONS(4767),
    [anon_sym_is] = ACTIONS(4767),
    [anon_sym_DASH_GT] = ACTIONS(4765),
    [anon_sym_with] = ACTIONS(4767),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3165] = {
    [sym_preproc_region] = STATE(3165),
    [sym_preproc_endregion] = STATE(3165),
    [sym_preproc_line] = STATE(3165),
    [sym_preproc_pragma] = STATE(3165),
    [sym_preproc_nullable] = STATE(3165),
    [sym_preproc_error] = STATE(3165),
    [sym_preproc_warning] = STATE(3165),
    [sym_preproc_define] = STATE(3165),
    [sym_preproc_undef] = STATE(3165),
    [anon_sym_SEMI] = ACTIONS(4124),
    [anon_sym_EQ] = ACTIONS(4122),
    [anon_sym_LBRACK] = ACTIONS(4124),
    [anon_sym_COLON] = ACTIONS(4124),
    [anon_sym_COMMA] = ACTIONS(4124),
    [anon_sym_RBRACK] = ACTIONS(4124),
    [anon_sym_LPAREN] = ACTIONS(4124),
    [anon_sym_RPAREN] = ACTIONS(4124),
    [anon_sym_LBRACE] = ACTIONS(4124),
    [anon_sym_RBRACE] = ACTIONS(4124),
    [anon_sym_LT] = ACTIONS(4122),
    [anon_sym_GT] = ACTIONS(4122),
    [anon_sym_in] = ACTIONS(4124),
    [anon_sym_where] = ACTIONS(4124),
    [anon_sym_QMARK] = ACTIONS(4122),
    [anon_sym_BANG] = ACTIONS(4122),
    [anon_sym_PLUS_PLUS] = ACTIONS(4124),
    [anon_sym_DASH_DASH] = ACTIONS(4124),
    [anon_sym_PLUS] = ACTIONS(4122),
    [anon_sym_DASH] = ACTIONS(4122),
    [anon_sym_STAR] = ACTIONS(4122),
    [anon_sym_SLASH] = ACTIONS(4122),
    [anon_sym_PERCENT] = ACTIONS(4122),
    [anon_sym_CARET] = ACTIONS(4122),
    [anon_sym_PIPE] = ACTIONS(4122),
    [anon_sym_AMP] = ACTIONS(4122),
    [anon_sym_LT_LT] = ACTIONS(4122),
    [anon_sym_GT_GT] = ACTIONS(4122),
    [anon_sym_GT_GT_GT] = ACTIONS(4122),
    [anon_sym_EQ_EQ] = ACTIONS(4124),
    [anon_sym_BANG_EQ] = ACTIONS(4124),
    [anon_sym_GT_EQ] = ACTIONS(4124),
    [anon_sym_LT_EQ] = ACTIONS(4124),
    [anon_sym_DOT] = ACTIONS(4122),
    [anon_sym_EQ_GT] = ACTIONS(4124),
    [anon_sym_switch] = ACTIONS(4124),
    [anon_sym_when] = ACTIONS(4124),
    [anon_sym_DOT_DOT] = ACTIONS(4124),
    [anon_sym_and] = ACTIONS(4124),
    [anon_sym_or] = ACTIONS(4124),
    [anon_sym_PLUS_EQ] = ACTIONS(4124),
    [anon_sym_DASH_EQ] = ACTIONS(4124),
    [anon_sym_STAR_EQ] = ACTIONS(4124),
    [anon_sym_SLASH_EQ] = ACTIONS(4124),
    [anon_sym_PERCENT_EQ] = ACTIONS(4124),
    [anon_sym_AMP_EQ] = ACTIONS(4124),
    [anon_sym_CARET_EQ] = ACTIONS(4124),
    [anon_sym_PIPE_EQ] = ACTIONS(4124),
    [anon_sym_LT_LT_EQ] = ACTIONS(4124),
    [anon_sym_GT_GT_EQ] = ACTIONS(4124),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4124),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4124),
    [anon_sym_AMP_AMP] = ACTIONS(4124),
    [anon_sym_PIPE_PIPE] = ACTIONS(4124),
    [anon_sym_QMARK_QMARK] = ACTIONS(4122),
    [anon_sym_on] = ACTIONS(4124),
    [anon_sym_equals] = ACTIONS(4124),
    [anon_sym_by] = ACTIONS(4124),
    [anon_sym_as] = ACTIONS(4124),
    [anon_sym_is] = ACTIONS(4124),
    [anon_sym_DASH_GT] = ACTIONS(4124),
    [anon_sym_with] = ACTIONS(4124),
    [aux_sym_preproc_if_token3] = ACTIONS(4124),
    [aux_sym_preproc_else_token1] = ACTIONS(4124),
    [aux_sym_preproc_elif_token1] = ACTIONS(4124),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3166] = {
    [sym_preproc_region] = STATE(3166),
    [sym_preproc_endregion] = STATE(3166),
    [sym_preproc_line] = STATE(3166),
    [sym_preproc_pragma] = STATE(3166),
    [sym_preproc_nullable] = STATE(3166),
    [sym_preproc_error] = STATE(3166),
    [sym_preproc_warning] = STATE(3166),
    [sym_preproc_define] = STATE(3166),
    [sym_preproc_undef] = STATE(3166),
    [sym__identifier_token] = ACTIONS(3049),
    [anon_sym_extern] = ACTIONS(3049),
    [anon_sym_alias] = ACTIONS(3049),
    [anon_sym_global] = ACTIONS(3049),
    [anon_sym_using] = ACTIONS(3049),
    [anon_sym_unsafe] = ACTIONS(3049),
    [anon_sym_static] = ACTIONS(3049),
    [anon_sym_LBRACK] = ACTIONS(3051),
    [anon_sym_LPAREN] = ACTIONS(3051),
    [anon_sym_event] = ACTIONS(3049),
    [anon_sym_namespace] = ACTIONS(3049),
    [anon_sym_class] = ACTIONS(3049),
    [anon_sym_ref] = ACTIONS(3049),
    [anon_sym_struct] = ACTIONS(3049),
    [anon_sym_enum] = ACTIONS(3049),
    [anon_sym_RBRACE] = ACTIONS(3051),
    [anon_sym_interface] = ACTIONS(3049),
    [anon_sym_delegate] = ACTIONS(3049),
    [anon_sym_record] = ACTIONS(3049),
    [anon_sym_abstract] = ACTIONS(3049),
    [anon_sym_async] = ACTIONS(3049),
    [anon_sym_const] = ACTIONS(3049),
    [anon_sym_file] = ACTIONS(3049),
    [anon_sym_fixed] = ACTIONS(3049),
    [anon_sym_internal] = ACTIONS(3049),
    [anon_sym_new] = ACTIONS(3049),
    [anon_sym_override] = ACTIONS(3049),
    [anon_sym_partial] = ACTIONS(3049),
    [anon_sym_private] = ACTIONS(3049),
    [anon_sym_protected] = ACTIONS(3049),
    [anon_sym_public] = ACTIONS(3049),
    [anon_sym_readonly] = ACTIONS(3049),
    [anon_sym_required] = ACTIONS(3049),
    [anon_sym_sealed] = ACTIONS(3049),
    [anon_sym_virtual] = ACTIONS(3049),
    [anon_sym_volatile] = ACTIONS(3049),
    [anon_sym_where] = ACTIONS(3049),
    [anon_sym_notnull] = ACTIONS(3049),
    [anon_sym_unmanaged] = ACTIONS(3049),
    [anon_sym_TILDE] = ACTIONS(3051),
    [anon_sym_implicit] = ACTIONS(3049),
    [anon_sym_explicit] = ACTIONS(3049),
    [anon_sym_scoped] = ACTIONS(3049),
    [anon_sym_var] = ACTIONS(3049),
    [sym_predefined_type] = ACTIONS(3049),
    [anon_sym_while] = ACTIONS(3049),
    [anon_sym_yield] = ACTIONS(3049),
    [anon_sym_when] = ACTIONS(3049),
    [anon_sym_else] = ACTIONS(3049),
    [anon_sym_from] = ACTIONS(3049),
    [anon_sym_into] = ACTIONS(3049),
    [anon_sym_join] = ACTIONS(3049),
    [anon_sym_on] = ACTIONS(3049),
    [anon_sym_equals] = ACTIONS(3049),
    [anon_sym_let] = ACTIONS(3049),
    [anon_sym_orderby] = ACTIONS(3049),
    [anon_sym_ascending] = ACTIONS(3049),
    [anon_sym_descending] = ACTIONS(3049),
    [anon_sym_group] = ACTIONS(3049),
    [anon_sym_by] = ACTIONS(3049),
    [anon_sym_select] = ACTIONS(3049),
    [aux_sym_preproc_if_token1] = ACTIONS(3051),
    [aux_sym_preproc_if_token3] = ACTIONS(3051),
    [aux_sym_preproc_else_token1] = ACTIONS(3051),
    [aux_sym_preproc_elif_token1] = ACTIONS(3051),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3167] = {
    [sym_property_pattern_clause] = STATE(3384),
    [sym__variable_designation] = STATE(4161),
    [sym_parenthesized_variable_designation] = STATE(4153),
    [sym_identifier] = STATE(4156),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3167),
    [sym_preproc_endregion] = STATE(3167),
    [sym_preproc_line] = STATE(3167),
    [sym_preproc_pragma] = STATE(3167),
    [sym_preproc_nullable] = STATE(3167),
    [sym_preproc_error] = STATE(3167),
    [sym_preproc_warning] = STATE(3167),
    [sym_preproc_define] = STATE(3167),
    [sym_preproc_undef] = STATE(3167),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4405),
    [anon_sym_LPAREN] = ACTIONS(4405),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4407),
    [anon_sym_GT] = ACTIONS(4407),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4407),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4407),
    [anon_sym_PLUS_PLUS] = ACTIONS(4405),
    [anon_sym_DASH_DASH] = ACTIONS(4405),
    [anon_sym_PLUS] = ACTIONS(4407),
    [anon_sym_DASH] = ACTIONS(4407),
    [anon_sym_STAR] = ACTIONS(4405),
    [anon_sym_SLASH] = ACTIONS(4407),
    [anon_sym_PERCENT] = ACTIONS(4405),
    [anon_sym_CARET] = ACTIONS(4405),
    [anon_sym_PIPE] = ACTIONS(4407),
    [anon_sym_AMP] = ACTIONS(4407),
    [anon_sym_LT_LT] = ACTIONS(4405),
    [anon_sym_GT_GT] = ACTIONS(4407),
    [anon_sym_GT_GT_GT] = ACTIONS(4405),
    [anon_sym_EQ_EQ] = ACTIONS(4405),
    [anon_sym_BANG_EQ] = ACTIONS(4405),
    [anon_sym_GT_EQ] = ACTIONS(4405),
    [anon_sym_LT_EQ] = ACTIONS(4405),
    [anon_sym_DOT] = ACTIONS(4407),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4407),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4359),
    [anon_sym_DOT_DOT] = ACTIONS(4405),
    [anon_sym_and] = ACTIONS(4407),
    [anon_sym_or] = ACTIONS(4407),
    [anon_sym_AMP_AMP] = ACTIONS(4405),
    [anon_sym_PIPE_PIPE] = ACTIONS(4405),
    [anon_sym_QMARK_QMARK] = ACTIONS(4405),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4339),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4407),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4407),
    [anon_sym_is] = ACTIONS(4407),
    [anon_sym_DASH_GT] = ACTIONS(4405),
    [anon_sym_with] = ACTIONS(4407),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3168] = {
    [sym__variable_designation] = STATE(4207),
    [sym_parenthesized_variable_designation] = STATE(4153),
    [sym_identifier] = STATE(4156),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3168),
    [sym_preproc_endregion] = STATE(3168),
    [sym_preproc_line] = STATE(3168),
    [sym_preproc_pragma] = STATE(3168),
    [sym_preproc_nullable] = STATE(3168),
    [sym_preproc_error] = STATE(3168),
    [sym_preproc_warning] = STATE(3168),
    [sym_preproc_define] = STATE(3168),
    [sym_preproc_undef] = STATE(3168),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4437),
    [anon_sym_COLON] = ACTIONS(4437),
    [anon_sym_LPAREN] = ACTIONS(4437),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4439),
    [anon_sym_GT] = ACTIONS(4439),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4439),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4439),
    [anon_sym_PLUS_PLUS] = ACTIONS(4437),
    [anon_sym_DASH_DASH] = ACTIONS(4437),
    [anon_sym_PLUS] = ACTIONS(4439),
    [anon_sym_DASH] = ACTIONS(4439),
    [anon_sym_STAR] = ACTIONS(4437),
    [anon_sym_SLASH] = ACTIONS(4439),
    [anon_sym_PERCENT] = ACTIONS(4437),
    [anon_sym_CARET] = ACTIONS(4437),
    [anon_sym_PIPE] = ACTIONS(4439),
    [anon_sym_AMP] = ACTIONS(4439),
    [anon_sym_LT_LT] = ACTIONS(4437),
    [anon_sym_GT_GT] = ACTIONS(4439),
    [anon_sym_GT_GT_GT] = ACTIONS(4437),
    [anon_sym_EQ_EQ] = ACTIONS(4437),
    [anon_sym_BANG_EQ] = ACTIONS(4437),
    [anon_sym_GT_EQ] = ACTIONS(4437),
    [anon_sym_LT_EQ] = ACTIONS(4437),
    [anon_sym_DOT] = ACTIONS(4439),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_EQ_GT] = ACTIONS(4437),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4439),
    [anon_sym_when] = ACTIONS(4439),
    [sym_discard] = ACTIONS(4359),
    [anon_sym_DOT_DOT] = ACTIONS(4437),
    [anon_sym_and] = ACTIONS(4439),
    [anon_sym_or] = ACTIONS(4439),
    [anon_sym_AMP_AMP] = ACTIONS(4437),
    [anon_sym_PIPE_PIPE] = ACTIONS(4437),
    [anon_sym_QMARK_QMARK] = ACTIONS(4437),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4339),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4439),
    [anon_sym_is] = ACTIONS(4439),
    [anon_sym_DASH_GT] = ACTIONS(4437),
    [anon_sym_with] = ACTIONS(4439),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3169] = {
    [sym__variable_designation] = STATE(4040),
    [sym_parenthesized_variable_designation] = STATE(3966),
    [sym_identifier] = STATE(3983),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3169),
    [sym_preproc_endregion] = STATE(3169),
    [sym_preproc_line] = STATE(3169),
    [sym_preproc_pragma] = STATE(3169),
    [sym_preproc_nullable] = STATE(3169),
    [sym_preproc_error] = STATE(3169),
    [sym_preproc_warning] = STATE(3169),
    [sym_preproc_define] = STATE(3169),
    [sym_preproc_undef] = STATE(3169),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4399),
    [anon_sym_COLON] = ACTIONS(4399),
    [anon_sym_LPAREN] = ACTIONS(4399),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4401),
    [anon_sym_GT] = ACTIONS(4401),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4401),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4401),
    [anon_sym_PLUS_PLUS] = ACTIONS(4399),
    [anon_sym_DASH_DASH] = ACTIONS(4399),
    [anon_sym_PLUS] = ACTIONS(4401),
    [anon_sym_DASH] = ACTIONS(4401),
    [anon_sym_STAR] = ACTIONS(4399),
    [anon_sym_SLASH] = ACTIONS(4401),
    [anon_sym_PERCENT] = ACTIONS(4399),
    [anon_sym_CARET] = ACTIONS(4399),
    [anon_sym_PIPE] = ACTIONS(4401),
    [anon_sym_AMP] = ACTIONS(4401),
    [anon_sym_LT_LT] = ACTIONS(4399),
    [anon_sym_GT_GT] = ACTIONS(4401),
    [anon_sym_GT_GT_GT] = ACTIONS(4399),
    [anon_sym_EQ_EQ] = ACTIONS(4399),
    [anon_sym_BANG_EQ] = ACTIONS(4399),
    [anon_sym_GT_EQ] = ACTIONS(4399),
    [anon_sym_LT_EQ] = ACTIONS(4399),
    [anon_sym_DOT] = ACTIONS(4401),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_EQ_GT] = ACTIONS(4399),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4401),
    [anon_sym_when] = ACTIONS(4401),
    [sym_discard] = ACTIONS(4347),
    [anon_sym_DOT_DOT] = ACTIONS(4399),
    [anon_sym_and] = ACTIONS(4401),
    [anon_sym_or] = ACTIONS(4401),
    [anon_sym_AMP_AMP] = ACTIONS(4399),
    [anon_sym_PIPE_PIPE] = ACTIONS(4399),
    [anon_sym_QMARK_QMARK] = ACTIONS(4399),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4401),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4401),
    [anon_sym_is] = ACTIONS(4401),
    [anon_sym_DASH_GT] = ACTIONS(4399),
    [anon_sym_with] = ACTIONS(4401),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3170] = {
    [sym_property_pattern_clause] = STATE(3375),
    [sym__variable_designation] = STATE(4166),
    [sym_parenthesized_variable_designation] = STATE(4153),
    [sym_identifier] = STATE(4156),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3170),
    [sym_preproc_endregion] = STATE(3170),
    [sym_preproc_line] = STATE(3170),
    [sym_preproc_pragma] = STATE(3170),
    [sym_preproc_nullable] = STATE(3170),
    [sym_preproc_error] = STATE(3170),
    [sym_preproc_warning] = STATE(3170),
    [sym_preproc_define] = STATE(3170),
    [sym_preproc_undef] = STATE(3170),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4399),
    [anon_sym_LPAREN] = ACTIONS(4399),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4401),
    [anon_sym_GT] = ACTIONS(4401),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4401),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4401),
    [anon_sym_PLUS_PLUS] = ACTIONS(4399),
    [anon_sym_DASH_DASH] = ACTIONS(4399),
    [anon_sym_PLUS] = ACTIONS(4401),
    [anon_sym_DASH] = ACTIONS(4401),
    [anon_sym_STAR] = ACTIONS(4399),
    [anon_sym_SLASH] = ACTIONS(4401),
    [anon_sym_PERCENT] = ACTIONS(4399),
    [anon_sym_CARET] = ACTIONS(4399),
    [anon_sym_PIPE] = ACTIONS(4401),
    [anon_sym_AMP] = ACTIONS(4401),
    [anon_sym_LT_LT] = ACTIONS(4399),
    [anon_sym_GT_GT] = ACTIONS(4401),
    [anon_sym_GT_GT_GT] = ACTIONS(4399),
    [anon_sym_EQ_EQ] = ACTIONS(4399),
    [anon_sym_BANG_EQ] = ACTIONS(4399),
    [anon_sym_GT_EQ] = ACTIONS(4399),
    [anon_sym_LT_EQ] = ACTIONS(4399),
    [anon_sym_DOT] = ACTIONS(4401),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4401),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4359),
    [anon_sym_DOT_DOT] = ACTIONS(4399),
    [anon_sym_and] = ACTIONS(4401),
    [anon_sym_or] = ACTIONS(4401),
    [anon_sym_AMP_AMP] = ACTIONS(4399),
    [anon_sym_PIPE_PIPE] = ACTIONS(4399),
    [anon_sym_QMARK_QMARK] = ACTIONS(4399),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4339),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4401),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4401),
    [anon_sym_is] = ACTIONS(4401),
    [anon_sym_DASH_GT] = ACTIONS(4399),
    [anon_sym_with] = ACTIONS(4401),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3171] = {
    [sym_property_pattern_clause] = STATE(3426),
    [sym__variable_designation] = STATE(4088),
    [sym_parenthesized_variable_designation] = STATE(3966),
    [sym_identifier] = STATE(3983),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3171),
    [sym_preproc_endregion] = STATE(3171),
    [sym_preproc_line] = STATE(3171),
    [sym_preproc_pragma] = STATE(3171),
    [sym_preproc_nullable] = STATE(3171),
    [sym_preproc_error] = STATE(3171),
    [sym_preproc_warning] = STATE(3171),
    [sym_preproc_define] = STATE(3171),
    [sym_preproc_undef] = STATE(3171),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4405),
    [anon_sym_LPAREN] = ACTIONS(4405),
    [anon_sym_LBRACE] = ACTIONS(4343),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4407),
    [anon_sym_GT] = ACTIONS(4407),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4407),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4407),
    [anon_sym_PLUS_PLUS] = ACTIONS(4405),
    [anon_sym_DASH_DASH] = ACTIONS(4405),
    [anon_sym_PLUS] = ACTIONS(4407),
    [anon_sym_DASH] = ACTIONS(4407),
    [anon_sym_STAR] = ACTIONS(4405),
    [anon_sym_SLASH] = ACTIONS(4407),
    [anon_sym_PERCENT] = ACTIONS(4405),
    [anon_sym_CARET] = ACTIONS(4405),
    [anon_sym_PIPE] = ACTIONS(4407),
    [anon_sym_AMP] = ACTIONS(4407),
    [anon_sym_LT_LT] = ACTIONS(4405),
    [anon_sym_GT_GT] = ACTIONS(4407),
    [anon_sym_GT_GT_GT] = ACTIONS(4405),
    [anon_sym_EQ_EQ] = ACTIONS(4405),
    [anon_sym_BANG_EQ] = ACTIONS(4405),
    [anon_sym_GT_EQ] = ACTIONS(4405),
    [anon_sym_LT_EQ] = ACTIONS(4405),
    [anon_sym_DOT] = ACTIONS(4407),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4407),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4347),
    [anon_sym_DOT_DOT] = ACTIONS(4405),
    [anon_sym_and] = ACTIONS(4407),
    [anon_sym_or] = ACTIONS(4407),
    [anon_sym_AMP_AMP] = ACTIONS(4405),
    [anon_sym_PIPE_PIPE] = ACTIONS(4405),
    [anon_sym_QMARK_QMARK] = ACTIONS(4405),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4407),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4407),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4407),
    [anon_sym_is] = ACTIONS(4407),
    [anon_sym_DASH_GT] = ACTIONS(4405),
    [anon_sym_with] = ACTIONS(4407),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3172] = {
    [sym__variable_designation] = STATE(4182),
    [sym_parenthesized_variable_designation] = STATE(4153),
    [sym_identifier] = STATE(4156),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3172),
    [sym_preproc_endregion] = STATE(3172),
    [sym_preproc_line] = STATE(3172),
    [sym_preproc_pragma] = STATE(3172),
    [sym_preproc_nullable] = STATE(3172),
    [sym_preproc_error] = STATE(3172),
    [sym_preproc_warning] = STATE(3172),
    [sym_preproc_define] = STATE(3172),
    [sym_preproc_undef] = STATE(3172),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4405),
    [anon_sym_COLON] = ACTIONS(4405),
    [anon_sym_LPAREN] = ACTIONS(4405),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4407),
    [anon_sym_GT] = ACTIONS(4407),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4407),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4407),
    [anon_sym_PLUS_PLUS] = ACTIONS(4405),
    [anon_sym_DASH_DASH] = ACTIONS(4405),
    [anon_sym_PLUS] = ACTIONS(4407),
    [anon_sym_DASH] = ACTIONS(4407),
    [anon_sym_STAR] = ACTIONS(4405),
    [anon_sym_SLASH] = ACTIONS(4407),
    [anon_sym_PERCENT] = ACTIONS(4405),
    [anon_sym_CARET] = ACTIONS(4405),
    [anon_sym_PIPE] = ACTIONS(4407),
    [anon_sym_AMP] = ACTIONS(4407),
    [anon_sym_LT_LT] = ACTIONS(4405),
    [anon_sym_GT_GT] = ACTIONS(4407),
    [anon_sym_GT_GT_GT] = ACTIONS(4405),
    [anon_sym_EQ_EQ] = ACTIONS(4405),
    [anon_sym_BANG_EQ] = ACTIONS(4405),
    [anon_sym_GT_EQ] = ACTIONS(4405),
    [anon_sym_LT_EQ] = ACTIONS(4405),
    [anon_sym_DOT] = ACTIONS(4407),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_EQ_GT] = ACTIONS(4405),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4407),
    [anon_sym_when] = ACTIONS(4407),
    [sym_discard] = ACTIONS(4359),
    [anon_sym_DOT_DOT] = ACTIONS(4405),
    [anon_sym_and] = ACTIONS(4407),
    [anon_sym_or] = ACTIONS(4407),
    [anon_sym_AMP_AMP] = ACTIONS(4405),
    [anon_sym_PIPE_PIPE] = ACTIONS(4405),
    [anon_sym_QMARK_QMARK] = ACTIONS(4405),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4339),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4407),
    [anon_sym_is] = ACTIONS(4407),
    [anon_sym_DASH_GT] = ACTIONS(4405),
    [anon_sym_with] = ACTIONS(4407),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3173] = {
    [sym__variable_designation] = STATE(4612),
    [sym_parenthesized_variable_designation] = STATE(4748),
    [sym_identifier] = STATE(4548),
    [sym__reserved_identifier] = STATE(2928),
    [sym_preproc_region] = STATE(3173),
    [sym_preproc_endregion] = STATE(3173),
    [sym_preproc_line] = STATE(3173),
    [sym_preproc_pragma] = STATE(3173),
    [sym_preproc_nullable] = STATE(3173),
    [sym_preproc_error] = STATE(3173),
    [sym_preproc_warning] = STATE(3173),
    [sym_preproc_define] = STATE(3173),
    [sym_preproc_undef] = STATE(3173),
    [sym__identifier_token] = ACTIONS(4536),
    [anon_sym_alias] = ACTIONS(4538),
    [anon_sym_global] = ACTIONS(4538),
    [anon_sym_LBRACK] = ACTIONS(4405),
    [anon_sym_COMMA] = ACTIONS(4405),
    [anon_sym_LPAREN] = ACTIONS(4405),
    [anon_sym_file] = ACTIONS(4538),
    [anon_sym_LT] = ACTIONS(4407),
    [anon_sym_GT] = ACTIONS(4407),
    [anon_sym_where] = ACTIONS(4407),
    [anon_sym_QMARK] = ACTIONS(4407),
    [anon_sym_notnull] = ACTIONS(4538),
    [anon_sym_unmanaged] = ACTIONS(4538),
    [anon_sym_BANG] = ACTIONS(4407),
    [anon_sym_PLUS_PLUS] = ACTIONS(4405),
    [anon_sym_DASH_DASH] = ACTIONS(4405),
    [anon_sym_PLUS] = ACTIONS(4407),
    [anon_sym_DASH] = ACTIONS(4407),
    [anon_sym_STAR] = ACTIONS(4405),
    [anon_sym_SLASH] = ACTIONS(4407),
    [anon_sym_PERCENT] = ACTIONS(4405),
    [anon_sym_CARET] = ACTIONS(4405),
    [anon_sym_PIPE] = ACTIONS(4407),
    [anon_sym_AMP] = ACTIONS(4407),
    [anon_sym_LT_LT] = ACTIONS(4405),
    [anon_sym_GT_GT] = ACTIONS(4407),
    [anon_sym_GT_GT_GT] = ACTIONS(4405),
    [anon_sym_EQ_EQ] = ACTIONS(4405),
    [anon_sym_BANG_EQ] = ACTIONS(4405),
    [anon_sym_GT_EQ] = ACTIONS(4405),
    [anon_sym_LT_EQ] = ACTIONS(4405),
    [anon_sym_DOT] = ACTIONS(4407),
    [anon_sym_scoped] = ACTIONS(4538),
    [anon_sym_var] = ACTIONS(4538),
    [anon_sym_yield] = ACTIONS(4538),
    [anon_sym_switch] = ACTIONS(4407),
    [anon_sym_when] = ACTIONS(4538),
    [sym_discard] = ACTIONS(4717),
    [anon_sym_DOT_DOT] = ACTIONS(4405),
    [anon_sym_and] = ACTIONS(4407),
    [anon_sym_or] = ACTIONS(4407),
    [anon_sym_AMP_AMP] = ACTIONS(4405),
    [anon_sym_PIPE_PIPE] = ACTIONS(4405),
    [anon_sym_QMARK_QMARK] = ACTIONS(4405),
    [anon_sym_from] = ACTIONS(4407),
    [anon_sym_into] = ACTIONS(4407),
    [anon_sym_join] = ACTIONS(4407),
    [anon_sym_on] = ACTIONS(4538),
    [anon_sym_equals] = ACTIONS(4538),
    [anon_sym_let] = ACTIONS(4407),
    [anon_sym_orderby] = ACTIONS(4407),
    [anon_sym_ascending] = ACTIONS(4407),
    [anon_sym_descending] = ACTIONS(4407),
    [anon_sym_group] = ACTIONS(4407),
    [anon_sym_by] = ACTIONS(4538),
    [anon_sym_select] = ACTIONS(4407),
    [anon_sym_as] = ACTIONS(4407),
    [anon_sym_is] = ACTIONS(4407),
    [anon_sym_DASH_GT] = ACTIONS(4405),
    [anon_sym_with] = ACTIONS(4407),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3174] = {
    [sym_preproc_region] = STATE(3174),
    [sym_preproc_endregion] = STATE(3174),
    [sym_preproc_line] = STATE(3174),
    [sym_preproc_pragma] = STATE(3174),
    [sym_preproc_nullable] = STATE(3174),
    [sym_preproc_error] = STATE(3174),
    [sym_preproc_warning] = STATE(3174),
    [sym_preproc_define] = STATE(3174),
    [sym_preproc_undef] = STATE(3174),
    [sym__identifier_token] = ACTIONS(4769),
    [anon_sym_extern] = ACTIONS(4769),
    [anon_sym_alias] = ACTIONS(4769),
    [anon_sym_global] = ACTIONS(4769),
    [anon_sym_using] = ACTIONS(4769),
    [anon_sym_unsafe] = ACTIONS(4769),
    [anon_sym_EQ] = ACTIONS(4771),
    [anon_sym_static] = ACTIONS(4769),
    [anon_sym_LBRACK] = ACTIONS(4773),
    [anon_sym_LPAREN] = ACTIONS(4773),
    [anon_sym_event] = ACTIONS(4769),
    [anon_sym_namespace] = ACTIONS(4769),
    [anon_sym_class] = ACTIONS(4769),
    [anon_sym_ref] = ACTIONS(4769),
    [anon_sym_struct] = ACTIONS(4769),
    [anon_sym_enum] = ACTIONS(4769),
    [anon_sym_RBRACE] = ACTIONS(4773),
    [anon_sym_interface] = ACTIONS(4769),
    [anon_sym_delegate] = ACTIONS(4769),
    [anon_sym_record] = ACTIONS(4769),
    [anon_sym_abstract] = ACTIONS(4769),
    [anon_sym_async] = ACTIONS(4769),
    [anon_sym_const] = ACTIONS(4769),
    [anon_sym_file] = ACTIONS(4769),
    [anon_sym_fixed] = ACTIONS(4769),
    [anon_sym_internal] = ACTIONS(4769),
    [anon_sym_new] = ACTIONS(4769),
    [anon_sym_override] = ACTIONS(4769),
    [anon_sym_partial] = ACTIONS(4769),
    [anon_sym_private] = ACTIONS(4769),
    [anon_sym_protected] = ACTIONS(4769),
    [anon_sym_public] = ACTIONS(4769),
    [anon_sym_readonly] = ACTIONS(4769),
    [anon_sym_required] = ACTIONS(4769),
    [anon_sym_sealed] = ACTIONS(4769),
    [anon_sym_virtual] = ACTIONS(4769),
    [anon_sym_volatile] = ACTIONS(4769),
    [anon_sym_where] = ACTIONS(4769),
    [anon_sym_notnull] = ACTIONS(4769),
    [anon_sym_unmanaged] = ACTIONS(4769),
    [anon_sym_TILDE] = ACTIONS(4773),
    [anon_sym_implicit] = ACTIONS(4769),
    [anon_sym_explicit] = ACTIONS(4769),
    [anon_sym_scoped] = ACTIONS(4769),
    [anon_sym_var] = ACTIONS(4769),
    [sym_predefined_type] = ACTIONS(4769),
    [anon_sym_yield] = ACTIONS(4769),
    [anon_sym_when] = ACTIONS(4769),
    [anon_sym_from] = ACTIONS(4769),
    [anon_sym_into] = ACTIONS(4769),
    [anon_sym_join] = ACTIONS(4769),
    [anon_sym_on] = ACTIONS(4769),
    [anon_sym_equals] = ACTIONS(4769),
    [anon_sym_let] = ACTIONS(4769),
    [anon_sym_orderby] = ACTIONS(4769),
    [anon_sym_ascending] = ACTIONS(4769),
    [anon_sym_descending] = ACTIONS(4769),
    [anon_sym_group] = ACTIONS(4769),
    [anon_sym_by] = ACTIONS(4769),
    [anon_sym_select] = ACTIONS(4769),
    [aux_sym_preproc_if_token1] = ACTIONS(4773),
    [aux_sym_preproc_if_token3] = ACTIONS(4773),
    [aux_sym_preproc_else_token1] = ACTIONS(4773),
    [aux_sym_preproc_elif_token1] = ACTIONS(4773),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3175] = {
    [sym_preproc_region] = STATE(3175),
    [sym_preproc_endregion] = STATE(3175),
    [sym_preproc_line] = STATE(3175),
    [sym_preproc_pragma] = STATE(3175),
    [sym_preproc_nullable] = STATE(3175),
    [sym_preproc_error] = STATE(3175),
    [sym_preproc_warning] = STATE(3175),
    [sym_preproc_define] = STATE(3175),
    [sym_preproc_undef] = STATE(3175),
    [anon_sym_SEMI] = ACTIONS(4683),
    [anon_sym_EQ] = ACTIONS(4685),
    [anon_sym_LBRACK] = ACTIONS(4683),
    [anon_sym_COLON] = ACTIONS(4683),
    [anon_sym_COMMA] = ACTIONS(4683),
    [anon_sym_RBRACK] = ACTIONS(4683),
    [anon_sym_LPAREN] = ACTIONS(4683),
    [anon_sym_RPAREN] = ACTIONS(4683),
    [anon_sym_RBRACE] = ACTIONS(4683),
    [anon_sym_LT] = ACTIONS(4685),
    [anon_sym_GT] = ACTIONS(4685),
    [anon_sym_in] = ACTIONS(4685),
    [anon_sym_QMARK] = ACTIONS(4685),
    [anon_sym_BANG] = ACTIONS(4685),
    [anon_sym_PLUS_PLUS] = ACTIONS(4683),
    [anon_sym_DASH_DASH] = ACTIONS(4683),
    [anon_sym_PLUS] = ACTIONS(4685),
    [anon_sym_DASH] = ACTIONS(4685),
    [anon_sym_STAR] = ACTIONS(4685),
    [anon_sym_SLASH] = ACTIONS(4685),
    [anon_sym_PERCENT] = ACTIONS(4685),
    [anon_sym_CARET] = ACTIONS(4685),
    [anon_sym_PIPE] = ACTIONS(4685),
    [anon_sym_AMP] = ACTIONS(4685),
    [anon_sym_LT_LT] = ACTIONS(4685),
    [anon_sym_GT_GT] = ACTIONS(4685),
    [anon_sym_GT_GT_GT] = ACTIONS(4685),
    [anon_sym_EQ_EQ] = ACTIONS(4683),
    [anon_sym_BANG_EQ] = ACTIONS(4683),
    [anon_sym_GT_EQ] = ACTIONS(4683),
    [anon_sym_LT_EQ] = ACTIONS(4683),
    [anon_sym_DOT] = ACTIONS(4685),
    [anon_sym_EQ_GT] = ACTIONS(4683),
    [anon_sym_switch] = ACTIONS(4683),
    [anon_sym_when] = ACTIONS(4683),
    [anon_sym_DOT_DOT] = ACTIONS(4683),
    [anon_sym_and] = ACTIONS(4683),
    [anon_sym_or] = ACTIONS(4683),
    [anon_sym_PLUS_EQ] = ACTIONS(4683),
    [anon_sym_DASH_EQ] = ACTIONS(4683),
    [anon_sym_STAR_EQ] = ACTIONS(4683),
    [anon_sym_SLASH_EQ] = ACTIONS(4683),
    [anon_sym_PERCENT_EQ] = ACTIONS(4683),
    [anon_sym_AMP_EQ] = ACTIONS(4683),
    [anon_sym_CARET_EQ] = ACTIONS(4683),
    [anon_sym_PIPE_EQ] = ACTIONS(4683),
    [anon_sym_LT_LT_EQ] = ACTIONS(4683),
    [anon_sym_GT_GT_EQ] = ACTIONS(4683),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4683),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4683),
    [anon_sym_AMP_AMP] = ACTIONS(4683),
    [anon_sym_PIPE_PIPE] = ACTIONS(4683),
    [anon_sym_QMARK_QMARK] = ACTIONS(4685),
    [anon_sym_into] = ACTIONS(4683),
    [anon_sym_on] = ACTIONS(4683),
    [anon_sym_equals] = ACTIONS(4683),
    [anon_sym_by] = ACTIONS(4683),
    [anon_sym_as] = ACTIONS(4683),
    [anon_sym_is] = ACTIONS(4683),
    [anon_sym_DASH_GT] = ACTIONS(4683),
    [anon_sym_with] = ACTIONS(4683),
    [aux_sym_preproc_if_token3] = ACTIONS(4683),
    [aux_sym_preproc_else_token1] = ACTIONS(4683),
    [aux_sym_preproc_elif_token1] = ACTIONS(4683),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3176] = {
    [sym_preproc_region] = STATE(3176),
    [sym_preproc_endregion] = STATE(3176),
    [sym_preproc_line] = STATE(3176),
    [sym_preproc_pragma] = STATE(3176),
    [sym_preproc_nullable] = STATE(3176),
    [sym_preproc_error] = STATE(3176),
    [sym_preproc_warning] = STATE(3176),
    [sym_preproc_define] = STATE(3176),
    [sym_preproc_undef] = STATE(3176),
    [sym__identifier_token] = ACTIONS(4775),
    [anon_sym_extern] = ACTIONS(4775),
    [anon_sym_alias] = ACTIONS(4775),
    [anon_sym_global] = ACTIONS(4775),
    [anon_sym_using] = ACTIONS(4775),
    [anon_sym_unsafe] = ACTIONS(4775),
    [anon_sym_EQ] = ACTIONS(4777),
    [anon_sym_static] = ACTIONS(4775),
    [anon_sym_LBRACK] = ACTIONS(4779),
    [anon_sym_LPAREN] = ACTIONS(4779),
    [anon_sym_event] = ACTIONS(4775),
    [anon_sym_namespace] = ACTIONS(4775),
    [anon_sym_class] = ACTIONS(4775),
    [anon_sym_ref] = ACTIONS(4775),
    [anon_sym_struct] = ACTIONS(4775),
    [anon_sym_enum] = ACTIONS(4775),
    [anon_sym_RBRACE] = ACTIONS(4779),
    [anon_sym_interface] = ACTIONS(4775),
    [anon_sym_delegate] = ACTIONS(4775),
    [anon_sym_record] = ACTIONS(4775),
    [anon_sym_abstract] = ACTIONS(4775),
    [anon_sym_async] = ACTIONS(4775),
    [anon_sym_const] = ACTIONS(4775),
    [anon_sym_file] = ACTIONS(4775),
    [anon_sym_fixed] = ACTIONS(4775),
    [anon_sym_internal] = ACTIONS(4775),
    [anon_sym_new] = ACTIONS(4775),
    [anon_sym_override] = ACTIONS(4775),
    [anon_sym_partial] = ACTIONS(4775),
    [anon_sym_private] = ACTIONS(4775),
    [anon_sym_protected] = ACTIONS(4775),
    [anon_sym_public] = ACTIONS(4775),
    [anon_sym_readonly] = ACTIONS(4775),
    [anon_sym_required] = ACTIONS(4775),
    [anon_sym_sealed] = ACTIONS(4775),
    [anon_sym_virtual] = ACTIONS(4775),
    [anon_sym_volatile] = ACTIONS(4775),
    [anon_sym_where] = ACTIONS(4775),
    [anon_sym_notnull] = ACTIONS(4775),
    [anon_sym_unmanaged] = ACTIONS(4775),
    [anon_sym_TILDE] = ACTIONS(4779),
    [anon_sym_implicit] = ACTIONS(4775),
    [anon_sym_explicit] = ACTIONS(4775),
    [anon_sym_scoped] = ACTIONS(4775),
    [anon_sym_var] = ACTIONS(4775),
    [sym_predefined_type] = ACTIONS(4775),
    [anon_sym_yield] = ACTIONS(4775),
    [anon_sym_when] = ACTIONS(4775),
    [anon_sym_from] = ACTIONS(4775),
    [anon_sym_into] = ACTIONS(4775),
    [anon_sym_join] = ACTIONS(4775),
    [anon_sym_on] = ACTIONS(4775),
    [anon_sym_equals] = ACTIONS(4775),
    [anon_sym_let] = ACTIONS(4775),
    [anon_sym_orderby] = ACTIONS(4775),
    [anon_sym_ascending] = ACTIONS(4775),
    [anon_sym_descending] = ACTIONS(4775),
    [anon_sym_group] = ACTIONS(4775),
    [anon_sym_by] = ACTIONS(4775),
    [anon_sym_select] = ACTIONS(4775),
    [aux_sym_preproc_if_token1] = ACTIONS(4779),
    [aux_sym_preproc_if_token3] = ACTIONS(4779),
    [aux_sym_preproc_else_token1] = ACTIONS(4779),
    [aux_sym_preproc_elif_token1] = ACTIONS(4779),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3177] = {
    [sym_preproc_region] = STATE(3177),
    [sym_preproc_endregion] = STATE(3177),
    [sym_preproc_line] = STATE(3177),
    [sym_preproc_pragma] = STATE(3177),
    [sym_preproc_nullable] = STATE(3177),
    [sym_preproc_error] = STATE(3177),
    [sym_preproc_warning] = STATE(3177),
    [sym_preproc_define] = STATE(3177),
    [sym_preproc_undef] = STATE(3177),
    [anon_sym_SEMI] = ACTIONS(4132),
    [anon_sym_EQ] = ACTIONS(4130),
    [anon_sym_LBRACK] = ACTIONS(4132),
    [anon_sym_COLON] = ACTIONS(4132),
    [anon_sym_COMMA] = ACTIONS(4132),
    [anon_sym_RBRACK] = ACTIONS(4132),
    [anon_sym_LPAREN] = ACTIONS(4132),
    [anon_sym_RPAREN] = ACTIONS(4132),
    [anon_sym_RBRACE] = ACTIONS(4132),
    [anon_sym_LT] = ACTIONS(4130),
    [anon_sym_GT] = ACTIONS(4130),
    [anon_sym_in] = ACTIONS(4130),
    [anon_sym_QMARK] = ACTIONS(4130),
    [anon_sym_BANG] = ACTIONS(4130),
    [anon_sym_PLUS_PLUS] = ACTIONS(4132),
    [anon_sym_DASH_DASH] = ACTIONS(4132),
    [anon_sym_PLUS] = ACTIONS(4130),
    [anon_sym_DASH] = ACTIONS(4130),
    [anon_sym_STAR] = ACTIONS(4130),
    [anon_sym_SLASH] = ACTIONS(4130),
    [anon_sym_PERCENT] = ACTIONS(4130),
    [anon_sym_CARET] = ACTIONS(4130),
    [anon_sym_PIPE] = ACTIONS(4130),
    [anon_sym_AMP] = ACTIONS(4130),
    [anon_sym_LT_LT] = ACTIONS(4130),
    [anon_sym_GT_GT] = ACTIONS(4130),
    [anon_sym_GT_GT_GT] = ACTIONS(4130),
    [anon_sym_EQ_EQ] = ACTIONS(4132),
    [anon_sym_BANG_EQ] = ACTIONS(4132),
    [anon_sym_GT_EQ] = ACTIONS(4132),
    [anon_sym_LT_EQ] = ACTIONS(4132),
    [anon_sym_DOT] = ACTIONS(4130),
    [anon_sym_EQ_GT] = ACTIONS(4132),
    [anon_sym_switch] = ACTIONS(4132),
    [anon_sym_when] = ACTIONS(4132),
    [anon_sym_DOT_DOT] = ACTIONS(4132),
    [anon_sym_and] = ACTIONS(4132),
    [anon_sym_or] = ACTIONS(4132),
    [anon_sym_PLUS_EQ] = ACTIONS(4132),
    [anon_sym_DASH_EQ] = ACTIONS(4132),
    [anon_sym_STAR_EQ] = ACTIONS(4132),
    [anon_sym_SLASH_EQ] = ACTIONS(4132),
    [anon_sym_PERCENT_EQ] = ACTIONS(4132),
    [anon_sym_AMP_EQ] = ACTIONS(4132),
    [anon_sym_CARET_EQ] = ACTIONS(4132),
    [anon_sym_PIPE_EQ] = ACTIONS(4132),
    [anon_sym_LT_LT_EQ] = ACTIONS(4132),
    [anon_sym_GT_GT_EQ] = ACTIONS(4132),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4132),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4132),
    [anon_sym_AMP_AMP] = ACTIONS(4132),
    [anon_sym_PIPE_PIPE] = ACTIONS(4132),
    [anon_sym_QMARK_QMARK] = ACTIONS(4130),
    [anon_sym_into] = ACTIONS(4132),
    [anon_sym_on] = ACTIONS(4132),
    [anon_sym_equals] = ACTIONS(4132),
    [anon_sym_by] = ACTIONS(4132),
    [anon_sym_as] = ACTIONS(4132),
    [anon_sym_is] = ACTIONS(4132),
    [anon_sym_DASH_GT] = ACTIONS(4132),
    [anon_sym_with] = ACTIONS(4132),
    [aux_sym_preproc_if_token3] = ACTIONS(4132),
    [aux_sym_preproc_else_token1] = ACTIONS(4132),
    [aux_sym_preproc_elif_token1] = ACTIONS(4132),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3178] = {
    [sym_preproc_region] = STATE(3178),
    [sym_preproc_endregion] = STATE(3178),
    [sym_preproc_line] = STATE(3178),
    [sym_preproc_pragma] = STATE(3178),
    [sym_preproc_nullable] = STATE(3178),
    [sym_preproc_error] = STATE(3178),
    [sym_preproc_warning] = STATE(3178),
    [sym_preproc_define] = STATE(3178),
    [sym_preproc_undef] = STATE(3178),
    [sym__identifier_token] = ACTIONS(4122),
    [anon_sym_alias] = ACTIONS(4122),
    [anon_sym_global] = ACTIONS(4122),
    [anon_sym_LBRACK] = ACTIONS(4124),
    [anon_sym_COLON] = ACTIONS(4122),
    [anon_sym_COMMA] = ACTIONS(4124),
    [anon_sym_LPAREN] = ACTIONS(4124),
    [anon_sym_LBRACE] = ACTIONS(4124),
    [anon_sym_file] = ACTIONS(4122),
    [anon_sym_LT] = ACTIONS(4122),
    [anon_sym_GT] = ACTIONS(4122),
    [anon_sym_where] = ACTIONS(4122),
    [anon_sym_QMARK] = ACTIONS(4122),
    [anon_sym_notnull] = ACTIONS(4122),
    [anon_sym_unmanaged] = ACTIONS(4122),
    [anon_sym_BANG] = ACTIONS(4122),
    [anon_sym_PLUS_PLUS] = ACTIONS(4124),
    [anon_sym_DASH_DASH] = ACTIONS(4124),
    [anon_sym_PLUS] = ACTIONS(4122),
    [anon_sym_DASH] = ACTIONS(4122),
    [anon_sym_STAR] = ACTIONS(4124),
    [anon_sym_SLASH] = ACTIONS(4122),
    [anon_sym_PERCENT] = ACTIONS(4124),
    [anon_sym_CARET] = ACTIONS(4124),
    [anon_sym_PIPE] = ACTIONS(4122),
    [anon_sym_AMP] = ACTIONS(4122),
    [anon_sym_LT_LT] = ACTIONS(4124),
    [anon_sym_GT_GT] = ACTIONS(4122),
    [anon_sym_GT_GT_GT] = ACTIONS(4124),
    [anon_sym_EQ_EQ] = ACTIONS(4124),
    [anon_sym_BANG_EQ] = ACTIONS(4124),
    [anon_sym_GT_EQ] = ACTIONS(4124),
    [anon_sym_LT_EQ] = ACTIONS(4124),
    [anon_sym_DOT] = ACTIONS(4122),
    [anon_sym_scoped] = ACTIONS(4122),
    [anon_sym_COLON_COLON] = ACTIONS(4124),
    [anon_sym_var] = ACTIONS(4122),
    [anon_sym_yield] = ACTIONS(4122),
    [anon_sym_switch] = ACTIONS(4122),
    [anon_sym_when] = ACTIONS(4122),
    [sym_discard] = ACTIONS(4122),
    [anon_sym_DOT_DOT] = ACTIONS(4124),
    [anon_sym_and] = ACTIONS(4122),
    [anon_sym_or] = ACTIONS(4122),
    [anon_sym_AMP_AMP] = ACTIONS(4124),
    [anon_sym_PIPE_PIPE] = ACTIONS(4124),
    [anon_sym_QMARK_QMARK] = ACTIONS(4124),
    [anon_sym_from] = ACTIONS(4122),
    [anon_sym_into] = ACTIONS(4122),
    [anon_sym_join] = ACTIONS(4122),
    [anon_sym_on] = ACTIONS(4122),
    [anon_sym_equals] = ACTIONS(4122),
    [anon_sym_let] = ACTIONS(4122),
    [anon_sym_orderby] = ACTIONS(4122),
    [anon_sym_ascending] = ACTIONS(4122),
    [anon_sym_descending] = ACTIONS(4122),
    [anon_sym_group] = ACTIONS(4122),
    [anon_sym_by] = ACTIONS(4122),
    [anon_sym_select] = ACTIONS(4122),
    [anon_sym_as] = ACTIONS(4122),
    [anon_sym_is] = ACTIONS(4122),
    [anon_sym_DASH_GT] = ACTIONS(4124),
    [anon_sym_with] = ACTIONS(4122),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4124),
  },
  [3179] = {
    [sym_preproc_region] = STATE(3179),
    [sym_preproc_endregion] = STATE(3179),
    [sym_preproc_line] = STATE(3179),
    [sym_preproc_pragma] = STATE(3179),
    [sym_preproc_nullable] = STATE(3179),
    [sym_preproc_error] = STATE(3179),
    [sym_preproc_warning] = STATE(3179),
    [sym_preproc_define] = STATE(3179),
    [sym_preproc_undef] = STATE(3179),
    [sym__identifier_token] = ACTIONS(4091),
    [anon_sym_alias] = ACTIONS(4091),
    [anon_sym_global] = ACTIONS(4091),
    [anon_sym_LBRACK] = ACTIONS(4088),
    [anon_sym_COLON] = ACTIONS(4091),
    [anon_sym_COMMA] = ACTIONS(4088),
    [anon_sym_LPAREN] = ACTIONS(4088),
    [anon_sym_LBRACE] = ACTIONS(4088),
    [anon_sym_file] = ACTIONS(4091),
    [anon_sym_LT] = ACTIONS(4091),
    [anon_sym_GT] = ACTIONS(4091),
    [anon_sym_where] = ACTIONS(4091),
    [anon_sym_QMARK] = ACTIONS(4091),
    [anon_sym_notnull] = ACTIONS(4091),
    [anon_sym_unmanaged] = ACTIONS(4091),
    [anon_sym_BANG] = ACTIONS(4091),
    [anon_sym_PLUS_PLUS] = ACTIONS(4088),
    [anon_sym_DASH_DASH] = ACTIONS(4088),
    [anon_sym_PLUS] = ACTIONS(4091),
    [anon_sym_DASH] = ACTIONS(4091),
    [anon_sym_STAR] = ACTIONS(4088),
    [anon_sym_SLASH] = ACTIONS(4091),
    [anon_sym_PERCENT] = ACTIONS(4088),
    [anon_sym_CARET] = ACTIONS(4088),
    [anon_sym_PIPE] = ACTIONS(4091),
    [anon_sym_AMP] = ACTIONS(4091),
    [anon_sym_LT_LT] = ACTIONS(4088),
    [anon_sym_GT_GT] = ACTIONS(4091),
    [anon_sym_GT_GT_GT] = ACTIONS(4088),
    [anon_sym_EQ_EQ] = ACTIONS(4088),
    [anon_sym_BANG_EQ] = ACTIONS(4088),
    [anon_sym_GT_EQ] = ACTIONS(4088),
    [anon_sym_LT_EQ] = ACTIONS(4088),
    [anon_sym_DOT] = ACTIONS(4091),
    [anon_sym_scoped] = ACTIONS(4091),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(4091),
    [anon_sym_yield] = ACTIONS(4091),
    [anon_sym_switch] = ACTIONS(4091),
    [anon_sym_when] = ACTIONS(4091),
    [sym_discard] = ACTIONS(4091),
    [anon_sym_DOT_DOT] = ACTIONS(4088),
    [anon_sym_and] = ACTIONS(4091),
    [anon_sym_or] = ACTIONS(4091),
    [anon_sym_AMP_AMP] = ACTIONS(4088),
    [anon_sym_PIPE_PIPE] = ACTIONS(4088),
    [anon_sym_QMARK_QMARK] = ACTIONS(4088),
    [anon_sym_from] = ACTIONS(4091),
    [anon_sym_into] = ACTIONS(4091),
    [anon_sym_join] = ACTIONS(4091),
    [anon_sym_on] = ACTIONS(4091),
    [anon_sym_equals] = ACTIONS(4091),
    [anon_sym_let] = ACTIONS(4091),
    [anon_sym_orderby] = ACTIONS(4091),
    [anon_sym_ascending] = ACTIONS(4091),
    [anon_sym_descending] = ACTIONS(4091),
    [anon_sym_group] = ACTIONS(4091),
    [anon_sym_by] = ACTIONS(4091),
    [anon_sym_select] = ACTIONS(4091),
    [anon_sym_as] = ACTIONS(4091),
    [anon_sym_is] = ACTIONS(4091),
    [anon_sym_DASH_GT] = ACTIONS(4088),
    [anon_sym_with] = ACTIONS(4091),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4088),
  },
  [3180] = {
    [sym_preproc_region] = STATE(3180),
    [sym_preproc_endregion] = STATE(3180),
    [sym_preproc_line] = STATE(3180),
    [sym_preproc_pragma] = STATE(3180),
    [sym_preproc_nullable] = STATE(3180),
    [sym_preproc_error] = STATE(3180),
    [sym_preproc_warning] = STATE(3180),
    [sym_preproc_define] = STATE(3180),
    [sym_preproc_undef] = STATE(3180),
    [anon_sym_SEMI] = ACTIONS(4699),
    [anon_sym_EQ] = ACTIONS(4701),
    [anon_sym_LBRACK] = ACTIONS(4699),
    [anon_sym_COLON] = ACTIONS(4699),
    [anon_sym_COMMA] = ACTIONS(4699),
    [anon_sym_RBRACK] = ACTIONS(4699),
    [anon_sym_LPAREN] = ACTIONS(4699),
    [anon_sym_RPAREN] = ACTIONS(4699),
    [anon_sym_RBRACE] = ACTIONS(4699),
    [anon_sym_LT] = ACTIONS(4701),
    [anon_sym_GT] = ACTIONS(4701),
    [anon_sym_in] = ACTIONS(4701),
    [anon_sym_QMARK] = ACTIONS(4701),
    [anon_sym_BANG] = ACTIONS(4701),
    [anon_sym_PLUS_PLUS] = ACTIONS(4699),
    [anon_sym_DASH_DASH] = ACTIONS(4699),
    [anon_sym_PLUS] = ACTIONS(4701),
    [anon_sym_DASH] = ACTIONS(4701),
    [anon_sym_STAR] = ACTIONS(4701),
    [anon_sym_SLASH] = ACTIONS(4701),
    [anon_sym_PERCENT] = ACTIONS(4701),
    [anon_sym_CARET] = ACTIONS(4701),
    [anon_sym_PIPE] = ACTIONS(4701),
    [anon_sym_AMP] = ACTIONS(4701),
    [anon_sym_LT_LT] = ACTIONS(4701),
    [anon_sym_GT_GT] = ACTIONS(4701),
    [anon_sym_GT_GT_GT] = ACTIONS(4701),
    [anon_sym_EQ_EQ] = ACTIONS(4699),
    [anon_sym_BANG_EQ] = ACTIONS(4699),
    [anon_sym_GT_EQ] = ACTIONS(4699),
    [anon_sym_LT_EQ] = ACTIONS(4699),
    [anon_sym_DOT] = ACTIONS(4701),
    [anon_sym_EQ_GT] = ACTIONS(4699),
    [anon_sym_switch] = ACTIONS(4699),
    [anon_sym_when] = ACTIONS(4699),
    [anon_sym_DOT_DOT] = ACTIONS(4699),
    [anon_sym_and] = ACTIONS(4699),
    [anon_sym_or] = ACTIONS(4699),
    [anon_sym_PLUS_EQ] = ACTIONS(4699),
    [anon_sym_DASH_EQ] = ACTIONS(4699),
    [anon_sym_STAR_EQ] = ACTIONS(4699),
    [anon_sym_SLASH_EQ] = ACTIONS(4699),
    [anon_sym_PERCENT_EQ] = ACTIONS(4699),
    [anon_sym_AMP_EQ] = ACTIONS(4699),
    [anon_sym_CARET_EQ] = ACTIONS(4699),
    [anon_sym_PIPE_EQ] = ACTIONS(4699),
    [anon_sym_LT_LT_EQ] = ACTIONS(4699),
    [anon_sym_GT_GT_EQ] = ACTIONS(4699),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4699),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4699),
    [anon_sym_AMP_AMP] = ACTIONS(4699),
    [anon_sym_PIPE_PIPE] = ACTIONS(4699),
    [anon_sym_QMARK_QMARK] = ACTIONS(4701),
    [anon_sym_into] = ACTIONS(4699),
    [anon_sym_on] = ACTIONS(4699),
    [anon_sym_equals] = ACTIONS(4699),
    [anon_sym_by] = ACTIONS(4699),
    [anon_sym_as] = ACTIONS(4699),
    [anon_sym_is] = ACTIONS(4699),
    [anon_sym_DASH_GT] = ACTIONS(4699),
    [anon_sym_with] = ACTIONS(4699),
    [aux_sym_preproc_if_token3] = ACTIONS(4699),
    [aux_sym_preproc_else_token1] = ACTIONS(4699),
    [aux_sym_preproc_elif_token1] = ACTIONS(4699),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3181] = {
    [sym_preproc_region] = STATE(3181),
    [sym_preproc_endregion] = STATE(3181),
    [sym_preproc_line] = STATE(3181),
    [sym_preproc_pragma] = STATE(3181),
    [sym_preproc_nullable] = STATE(3181),
    [sym_preproc_error] = STATE(3181),
    [sym_preproc_warning] = STATE(3181),
    [sym_preproc_define] = STATE(3181),
    [sym_preproc_undef] = STATE(3181),
    [anon_sym_SEMI] = ACTIONS(4711),
    [anon_sym_EQ] = ACTIONS(4713),
    [anon_sym_LBRACK] = ACTIONS(4711),
    [anon_sym_COLON] = ACTIONS(4711),
    [anon_sym_COMMA] = ACTIONS(4711),
    [anon_sym_RBRACK] = ACTIONS(4711),
    [anon_sym_LPAREN] = ACTIONS(4711),
    [anon_sym_RPAREN] = ACTIONS(4711),
    [anon_sym_RBRACE] = ACTIONS(4711),
    [anon_sym_LT] = ACTIONS(4713),
    [anon_sym_GT] = ACTIONS(4713),
    [anon_sym_in] = ACTIONS(4713),
    [anon_sym_QMARK] = ACTIONS(4713),
    [anon_sym_BANG] = ACTIONS(4713),
    [anon_sym_PLUS_PLUS] = ACTIONS(4711),
    [anon_sym_DASH_DASH] = ACTIONS(4711),
    [anon_sym_PLUS] = ACTIONS(4713),
    [anon_sym_DASH] = ACTIONS(4713),
    [anon_sym_STAR] = ACTIONS(4713),
    [anon_sym_SLASH] = ACTIONS(4713),
    [anon_sym_PERCENT] = ACTIONS(4713),
    [anon_sym_CARET] = ACTIONS(4713),
    [anon_sym_PIPE] = ACTIONS(4713),
    [anon_sym_AMP] = ACTIONS(4713),
    [anon_sym_LT_LT] = ACTIONS(4713),
    [anon_sym_GT_GT] = ACTIONS(4713),
    [anon_sym_GT_GT_GT] = ACTIONS(4713),
    [anon_sym_EQ_EQ] = ACTIONS(4711),
    [anon_sym_BANG_EQ] = ACTIONS(4711),
    [anon_sym_GT_EQ] = ACTIONS(4711),
    [anon_sym_LT_EQ] = ACTIONS(4711),
    [anon_sym_DOT] = ACTIONS(4713),
    [anon_sym_EQ_GT] = ACTIONS(4711),
    [anon_sym_switch] = ACTIONS(4711),
    [anon_sym_when] = ACTIONS(4711),
    [anon_sym_DOT_DOT] = ACTIONS(4711),
    [anon_sym_and] = ACTIONS(4711),
    [anon_sym_or] = ACTIONS(4711),
    [anon_sym_PLUS_EQ] = ACTIONS(4711),
    [anon_sym_DASH_EQ] = ACTIONS(4711),
    [anon_sym_STAR_EQ] = ACTIONS(4711),
    [anon_sym_SLASH_EQ] = ACTIONS(4711),
    [anon_sym_PERCENT_EQ] = ACTIONS(4711),
    [anon_sym_AMP_EQ] = ACTIONS(4711),
    [anon_sym_CARET_EQ] = ACTIONS(4711),
    [anon_sym_PIPE_EQ] = ACTIONS(4711),
    [anon_sym_LT_LT_EQ] = ACTIONS(4711),
    [anon_sym_GT_GT_EQ] = ACTIONS(4711),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4711),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4711),
    [anon_sym_AMP_AMP] = ACTIONS(4711),
    [anon_sym_PIPE_PIPE] = ACTIONS(4711),
    [anon_sym_QMARK_QMARK] = ACTIONS(4713),
    [anon_sym_into] = ACTIONS(4711),
    [anon_sym_on] = ACTIONS(4711),
    [anon_sym_equals] = ACTIONS(4711),
    [anon_sym_by] = ACTIONS(4711),
    [anon_sym_as] = ACTIONS(4711),
    [anon_sym_is] = ACTIONS(4711),
    [anon_sym_DASH_GT] = ACTIONS(4711),
    [anon_sym_with] = ACTIONS(4711),
    [aux_sym_preproc_if_token3] = ACTIONS(4711),
    [aux_sym_preproc_else_token1] = ACTIONS(4711),
    [aux_sym_preproc_elif_token1] = ACTIONS(4711),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3182] = {
    [sym_preproc_region] = STATE(3182),
    [sym_preproc_endregion] = STATE(3182),
    [sym_preproc_line] = STATE(3182),
    [sym_preproc_pragma] = STATE(3182),
    [sym_preproc_nullable] = STATE(3182),
    [sym_preproc_error] = STATE(3182),
    [sym_preproc_warning] = STATE(3182),
    [sym_preproc_define] = STATE(3182),
    [sym_preproc_undef] = STATE(3182),
    [sym__identifier_token] = ACTIONS(4781),
    [anon_sym_extern] = ACTIONS(4781),
    [anon_sym_alias] = ACTIONS(4781),
    [anon_sym_global] = ACTIONS(4781),
    [anon_sym_using] = ACTIONS(4781),
    [anon_sym_unsafe] = ACTIONS(4781),
    [anon_sym_EQ] = ACTIONS(4783),
    [anon_sym_static] = ACTIONS(4781),
    [anon_sym_LBRACK] = ACTIONS(4785),
    [anon_sym_LPAREN] = ACTIONS(4785),
    [anon_sym_event] = ACTIONS(4781),
    [anon_sym_namespace] = ACTIONS(4781),
    [anon_sym_class] = ACTIONS(4781),
    [anon_sym_ref] = ACTIONS(4781),
    [anon_sym_struct] = ACTIONS(4781),
    [anon_sym_enum] = ACTIONS(4781),
    [anon_sym_RBRACE] = ACTIONS(4785),
    [anon_sym_interface] = ACTIONS(4781),
    [anon_sym_delegate] = ACTIONS(4781),
    [anon_sym_record] = ACTIONS(4781),
    [anon_sym_abstract] = ACTIONS(4781),
    [anon_sym_async] = ACTIONS(4781),
    [anon_sym_const] = ACTIONS(4781),
    [anon_sym_file] = ACTIONS(4781),
    [anon_sym_fixed] = ACTIONS(4781),
    [anon_sym_internal] = ACTIONS(4781),
    [anon_sym_new] = ACTIONS(4781),
    [anon_sym_override] = ACTIONS(4781),
    [anon_sym_partial] = ACTIONS(4781),
    [anon_sym_private] = ACTIONS(4781),
    [anon_sym_protected] = ACTIONS(4781),
    [anon_sym_public] = ACTIONS(4781),
    [anon_sym_readonly] = ACTIONS(4781),
    [anon_sym_required] = ACTIONS(4781),
    [anon_sym_sealed] = ACTIONS(4781),
    [anon_sym_virtual] = ACTIONS(4781),
    [anon_sym_volatile] = ACTIONS(4781),
    [anon_sym_where] = ACTIONS(4781),
    [anon_sym_notnull] = ACTIONS(4781),
    [anon_sym_unmanaged] = ACTIONS(4781),
    [anon_sym_TILDE] = ACTIONS(4785),
    [anon_sym_implicit] = ACTIONS(4781),
    [anon_sym_explicit] = ACTIONS(4781),
    [anon_sym_scoped] = ACTIONS(4781),
    [anon_sym_var] = ACTIONS(4781),
    [sym_predefined_type] = ACTIONS(4781),
    [anon_sym_yield] = ACTIONS(4781),
    [anon_sym_when] = ACTIONS(4781),
    [anon_sym_from] = ACTIONS(4781),
    [anon_sym_into] = ACTIONS(4781),
    [anon_sym_join] = ACTIONS(4781),
    [anon_sym_on] = ACTIONS(4781),
    [anon_sym_equals] = ACTIONS(4781),
    [anon_sym_let] = ACTIONS(4781),
    [anon_sym_orderby] = ACTIONS(4781),
    [anon_sym_ascending] = ACTIONS(4781),
    [anon_sym_descending] = ACTIONS(4781),
    [anon_sym_group] = ACTIONS(4781),
    [anon_sym_by] = ACTIONS(4781),
    [anon_sym_select] = ACTIONS(4781),
    [aux_sym_preproc_if_token1] = ACTIONS(4785),
    [aux_sym_preproc_if_token3] = ACTIONS(4785),
    [aux_sym_preproc_else_token1] = ACTIONS(4785),
    [aux_sym_preproc_elif_token1] = ACTIONS(4785),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3183] = {
    [sym_preproc_region] = STATE(3183),
    [sym_preproc_endregion] = STATE(3183),
    [sym_preproc_line] = STATE(3183),
    [sym_preproc_pragma] = STATE(3183),
    [sym_preproc_nullable] = STATE(3183),
    [sym_preproc_error] = STATE(3183),
    [sym_preproc_warning] = STATE(3183),
    [sym_preproc_define] = STATE(3183),
    [sym_preproc_undef] = STATE(3183),
    [sym__identifier_token] = ACTIONS(4122),
    [anon_sym_alias] = ACTIONS(4122),
    [anon_sym_global] = ACTIONS(4122),
    [anon_sym_LBRACK] = ACTIONS(4124),
    [anon_sym_COLON] = ACTIONS(4124),
    [anon_sym_COMMA] = ACTIONS(4124),
    [anon_sym_LPAREN] = ACTIONS(4124),
    [anon_sym_RPAREN] = ACTIONS(4124),
    [anon_sym_LBRACE] = ACTIONS(4124),
    [anon_sym_RBRACE] = ACTIONS(4124),
    [anon_sym_file] = ACTIONS(4122),
    [anon_sym_LT] = ACTIONS(4122),
    [anon_sym_GT] = ACTIONS(4122),
    [anon_sym_where] = ACTIONS(4122),
    [anon_sym_QMARK] = ACTIONS(4122),
    [anon_sym_notnull] = ACTIONS(4122),
    [anon_sym_unmanaged] = ACTIONS(4122),
    [anon_sym_BANG] = ACTIONS(4122),
    [anon_sym_PLUS_PLUS] = ACTIONS(4124),
    [anon_sym_DASH_DASH] = ACTIONS(4124),
    [anon_sym_PLUS] = ACTIONS(4122),
    [anon_sym_DASH] = ACTIONS(4122),
    [anon_sym_STAR] = ACTIONS(4124),
    [anon_sym_SLASH] = ACTIONS(4122),
    [anon_sym_PERCENT] = ACTIONS(4124),
    [anon_sym_CARET] = ACTIONS(4124),
    [anon_sym_PIPE] = ACTIONS(4122),
    [anon_sym_AMP] = ACTIONS(4122),
    [anon_sym_LT_LT] = ACTIONS(4124),
    [anon_sym_GT_GT] = ACTIONS(4122),
    [anon_sym_GT_GT_GT] = ACTIONS(4124),
    [anon_sym_EQ_EQ] = ACTIONS(4124),
    [anon_sym_BANG_EQ] = ACTIONS(4124),
    [anon_sym_GT_EQ] = ACTIONS(4124),
    [anon_sym_LT_EQ] = ACTIONS(4124),
    [anon_sym_DOT] = ACTIONS(4122),
    [anon_sym_scoped] = ACTIONS(4122),
    [anon_sym_var] = ACTIONS(4122),
    [anon_sym_yield] = ACTIONS(4122),
    [anon_sym_switch] = ACTIONS(4122),
    [anon_sym_when] = ACTIONS(4122),
    [sym_discard] = ACTIONS(4122),
    [anon_sym_DOT_DOT] = ACTIONS(4124),
    [anon_sym_and] = ACTIONS(4122),
    [anon_sym_or] = ACTIONS(4122),
    [anon_sym_AMP_AMP] = ACTIONS(4124),
    [anon_sym_PIPE_PIPE] = ACTIONS(4124),
    [anon_sym_QMARK_QMARK] = ACTIONS(4124),
    [anon_sym_from] = ACTIONS(4122),
    [anon_sym_into] = ACTIONS(4122),
    [anon_sym_join] = ACTIONS(4122),
    [anon_sym_on] = ACTIONS(4122),
    [anon_sym_equals] = ACTIONS(4122),
    [anon_sym_let] = ACTIONS(4122),
    [anon_sym_orderby] = ACTIONS(4122),
    [anon_sym_ascending] = ACTIONS(4122),
    [anon_sym_descending] = ACTIONS(4122),
    [anon_sym_group] = ACTIONS(4122),
    [anon_sym_by] = ACTIONS(4122),
    [anon_sym_select] = ACTIONS(4122),
    [anon_sym_as] = ACTIONS(4122),
    [anon_sym_is] = ACTIONS(4122),
    [anon_sym_DASH_GT] = ACTIONS(4124),
    [anon_sym_with] = ACTIONS(4122),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3184] = {
    [sym__variable_designation] = STATE(4556),
    [sym_parenthesized_variable_designation] = STATE(4748),
    [sym_identifier] = STATE(4548),
    [sym__reserved_identifier] = STATE(2928),
    [sym_preproc_region] = STATE(3184),
    [sym_preproc_endregion] = STATE(3184),
    [sym_preproc_line] = STATE(3184),
    [sym_preproc_pragma] = STATE(3184),
    [sym_preproc_nullable] = STATE(3184),
    [sym_preproc_error] = STATE(3184),
    [sym_preproc_warning] = STATE(3184),
    [sym_preproc_define] = STATE(3184),
    [sym_preproc_undef] = STATE(3184),
    [sym__identifier_token] = ACTIONS(4536),
    [anon_sym_alias] = ACTIONS(4538),
    [anon_sym_global] = ACTIONS(4538),
    [anon_sym_LBRACK] = ACTIONS(4399),
    [anon_sym_COMMA] = ACTIONS(4399),
    [anon_sym_LPAREN] = ACTIONS(4399),
    [anon_sym_file] = ACTIONS(4538),
    [anon_sym_LT] = ACTIONS(4401),
    [anon_sym_GT] = ACTIONS(4401),
    [anon_sym_where] = ACTIONS(4401),
    [anon_sym_QMARK] = ACTIONS(4401),
    [anon_sym_notnull] = ACTIONS(4538),
    [anon_sym_unmanaged] = ACTIONS(4538),
    [anon_sym_BANG] = ACTIONS(4401),
    [anon_sym_PLUS_PLUS] = ACTIONS(4399),
    [anon_sym_DASH_DASH] = ACTIONS(4399),
    [anon_sym_PLUS] = ACTIONS(4401),
    [anon_sym_DASH] = ACTIONS(4401),
    [anon_sym_STAR] = ACTIONS(4399),
    [anon_sym_SLASH] = ACTIONS(4401),
    [anon_sym_PERCENT] = ACTIONS(4399),
    [anon_sym_CARET] = ACTIONS(4399),
    [anon_sym_PIPE] = ACTIONS(4401),
    [anon_sym_AMP] = ACTIONS(4401),
    [anon_sym_LT_LT] = ACTIONS(4399),
    [anon_sym_GT_GT] = ACTIONS(4401),
    [anon_sym_GT_GT_GT] = ACTIONS(4399),
    [anon_sym_EQ_EQ] = ACTIONS(4399),
    [anon_sym_BANG_EQ] = ACTIONS(4399),
    [anon_sym_GT_EQ] = ACTIONS(4399),
    [anon_sym_LT_EQ] = ACTIONS(4399),
    [anon_sym_DOT] = ACTIONS(4401),
    [anon_sym_scoped] = ACTIONS(4538),
    [anon_sym_var] = ACTIONS(4538),
    [anon_sym_yield] = ACTIONS(4538),
    [anon_sym_switch] = ACTIONS(4401),
    [anon_sym_when] = ACTIONS(4538),
    [sym_discard] = ACTIONS(4717),
    [anon_sym_DOT_DOT] = ACTIONS(4399),
    [anon_sym_and] = ACTIONS(4401),
    [anon_sym_or] = ACTIONS(4401),
    [anon_sym_AMP_AMP] = ACTIONS(4399),
    [anon_sym_PIPE_PIPE] = ACTIONS(4399),
    [anon_sym_QMARK_QMARK] = ACTIONS(4399),
    [anon_sym_from] = ACTIONS(4401),
    [anon_sym_into] = ACTIONS(4401),
    [anon_sym_join] = ACTIONS(4401),
    [anon_sym_on] = ACTIONS(4538),
    [anon_sym_equals] = ACTIONS(4538),
    [anon_sym_let] = ACTIONS(4401),
    [anon_sym_orderby] = ACTIONS(4401),
    [anon_sym_ascending] = ACTIONS(4401),
    [anon_sym_descending] = ACTIONS(4401),
    [anon_sym_group] = ACTIONS(4401),
    [anon_sym_by] = ACTIONS(4538),
    [anon_sym_select] = ACTIONS(4401),
    [anon_sym_as] = ACTIONS(4401),
    [anon_sym_is] = ACTIONS(4401),
    [anon_sym_DASH_GT] = ACTIONS(4399),
    [anon_sym_with] = ACTIONS(4401),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3185] = {
    [sym__variable_designation] = STATE(4614),
    [sym_parenthesized_variable_designation] = STATE(4748),
    [sym_identifier] = STATE(4548),
    [sym__reserved_identifier] = STATE(2928),
    [sym_preproc_region] = STATE(3185),
    [sym_preproc_endregion] = STATE(3185),
    [sym_preproc_line] = STATE(3185),
    [sym_preproc_pragma] = STATE(3185),
    [sym_preproc_nullable] = STATE(3185),
    [sym_preproc_error] = STATE(3185),
    [sym_preproc_warning] = STATE(3185),
    [sym_preproc_define] = STATE(3185),
    [sym_preproc_undef] = STATE(3185),
    [sym__identifier_token] = ACTIONS(4536),
    [anon_sym_alias] = ACTIONS(4538),
    [anon_sym_global] = ACTIONS(4538),
    [anon_sym_LBRACK] = ACTIONS(4437),
    [anon_sym_COMMA] = ACTIONS(4437),
    [anon_sym_LPAREN] = ACTIONS(4437),
    [anon_sym_file] = ACTIONS(4538),
    [anon_sym_LT] = ACTIONS(4439),
    [anon_sym_GT] = ACTIONS(4439),
    [anon_sym_where] = ACTIONS(4439),
    [anon_sym_QMARK] = ACTIONS(4439),
    [anon_sym_notnull] = ACTIONS(4538),
    [anon_sym_unmanaged] = ACTIONS(4538),
    [anon_sym_BANG] = ACTIONS(4439),
    [anon_sym_PLUS_PLUS] = ACTIONS(4437),
    [anon_sym_DASH_DASH] = ACTIONS(4437),
    [anon_sym_PLUS] = ACTIONS(4439),
    [anon_sym_DASH] = ACTIONS(4439),
    [anon_sym_STAR] = ACTIONS(4437),
    [anon_sym_SLASH] = ACTIONS(4439),
    [anon_sym_PERCENT] = ACTIONS(4437),
    [anon_sym_CARET] = ACTIONS(4437),
    [anon_sym_PIPE] = ACTIONS(4439),
    [anon_sym_AMP] = ACTIONS(4439),
    [anon_sym_LT_LT] = ACTIONS(4437),
    [anon_sym_GT_GT] = ACTIONS(4439),
    [anon_sym_GT_GT_GT] = ACTIONS(4437),
    [anon_sym_EQ_EQ] = ACTIONS(4437),
    [anon_sym_BANG_EQ] = ACTIONS(4437),
    [anon_sym_GT_EQ] = ACTIONS(4437),
    [anon_sym_LT_EQ] = ACTIONS(4437),
    [anon_sym_DOT] = ACTIONS(4439),
    [anon_sym_scoped] = ACTIONS(4538),
    [anon_sym_var] = ACTIONS(4538),
    [anon_sym_yield] = ACTIONS(4538),
    [anon_sym_switch] = ACTIONS(4439),
    [anon_sym_when] = ACTIONS(4538),
    [sym_discard] = ACTIONS(4717),
    [anon_sym_DOT_DOT] = ACTIONS(4437),
    [anon_sym_and] = ACTIONS(4439),
    [anon_sym_or] = ACTIONS(4439),
    [anon_sym_AMP_AMP] = ACTIONS(4437),
    [anon_sym_PIPE_PIPE] = ACTIONS(4437),
    [anon_sym_QMARK_QMARK] = ACTIONS(4437),
    [anon_sym_from] = ACTIONS(4439),
    [anon_sym_into] = ACTIONS(4439),
    [anon_sym_join] = ACTIONS(4439),
    [anon_sym_on] = ACTIONS(4538),
    [anon_sym_equals] = ACTIONS(4538),
    [anon_sym_let] = ACTIONS(4439),
    [anon_sym_orderby] = ACTIONS(4439),
    [anon_sym_ascending] = ACTIONS(4439),
    [anon_sym_descending] = ACTIONS(4439),
    [anon_sym_group] = ACTIONS(4439),
    [anon_sym_by] = ACTIONS(4538),
    [anon_sym_select] = ACTIONS(4439),
    [anon_sym_as] = ACTIONS(4439),
    [anon_sym_is] = ACTIONS(4439),
    [anon_sym_DASH_GT] = ACTIONS(4437),
    [anon_sym_with] = ACTIONS(4439),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3186] = {
    [sym_preproc_region] = STATE(3186),
    [sym_preproc_endregion] = STATE(3186),
    [sym_preproc_line] = STATE(3186),
    [sym_preproc_pragma] = STATE(3186),
    [sym_preproc_nullable] = STATE(3186),
    [sym_preproc_error] = STATE(3186),
    [sym_preproc_warning] = STATE(3186),
    [sym_preproc_define] = STATE(3186),
    [sym_preproc_undef] = STATE(3186),
    [sym__identifier_token] = ACTIONS(3995),
    [anon_sym_alias] = ACTIONS(3995),
    [anon_sym_global] = ACTIONS(3995),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_COLON] = ACTIONS(3995),
    [anon_sym_COMMA] = ACTIONS(3993),
    [anon_sym_LPAREN] = ACTIONS(3993),
    [anon_sym_LBRACE] = ACTIONS(3993),
    [anon_sym_file] = ACTIONS(3995),
    [anon_sym_LT] = ACTIONS(3995),
    [anon_sym_GT] = ACTIONS(3995),
    [anon_sym_where] = ACTIONS(3995),
    [anon_sym_QMARK] = ACTIONS(3995),
    [anon_sym_notnull] = ACTIONS(3995),
    [anon_sym_unmanaged] = ACTIONS(3995),
    [anon_sym_BANG] = ACTIONS(3995),
    [anon_sym_PLUS_PLUS] = ACTIONS(3993),
    [anon_sym_DASH_DASH] = ACTIONS(3993),
    [anon_sym_PLUS] = ACTIONS(3995),
    [anon_sym_DASH] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3993),
    [anon_sym_SLASH] = ACTIONS(3995),
    [anon_sym_PERCENT] = ACTIONS(3993),
    [anon_sym_CARET] = ACTIONS(3993),
    [anon_sym_PIPE] = ACTIONS(3995),
    [anon_sym_AMP] = ACTIONS(3995),
    [anon_sym_LT_LT] = ACTIONS(3993),
    [anon_sym_GT_GT] = ACTIONS(3995),
    [anon_sym_GT_GT_GT] = ACTIONS(3993),
    [anon_sym_EQ_EQ] = ACTIONS(3993),
    [anon_sym_BANG_EQ] = ACTIONS(3993),
    [anon_sym_GT_EQ] = ACTIONS(3993),
    [anon_sym_LT_EQ] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3995),
    [anon_sym_scoped] = ACTIONS(3995),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(3995),
    [anon_sym_yield] = ACTIONS(3995),
    [anon_sym_switch] = ACTIONS(3995),
    [anon_sym_when] = ACTIONS(3995),
    [sym_discard] = ACTIONS(3995),
    [anon_sym_DOT_DOT] = ACTIONS(3993),
    [anon_sym_and] = ACTIONS(3995),
    [anon_sym_or] = ACTIONS(3995),
    [anon_sym_AMP_AMP] = ACTIONS(3993),
    [anon_sym_PIPE_PIPE] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK] = ACTIONS(3993),
    [anon_sym_from] = ACTIONS(3995),
    [anon_sym_into] = ACTIONS(3995),
    [anon_sym_join] = ACTIONS(3995),
    [anon_sym_on] = ACTIONS(3995),
    [anon_sym_equals] = ACTIONS(3995),
    [anon_sym_let] = ACTIONS(3995),
    [anon_sym_orderby] = ACTIONS(3995),
    [anon_sym_ascending] = ACTIONS(3995),
    [anon_sym_descending] = ACTIONS(3995),
    [anon_sym_group] = ACTIONS(3995),
    [anon_sym_by] = ACTIONS(3995),
    [anon_sym_select] = ACTIONS(3995),
    [anon_sym_as] = ACTIONS(3995),
    [anon_sym_is] = ACTIONS(3995),
    [anon_sym_DASH_GT] = ACTIONS(3993),
    [anon_sym_with] = ACTIONS(3995),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(3993),
  },
  [3187] = {
    [sym_preproc_region] = STATE(3187),
    [sym_preproc_endregion] = STATE(3187),
    [sym_preproc_line] = STATE(3187),
    [sym_preproc_pragma] = STATE(3187),
    [sym_preproc_nullable] = STATE(3187),
    [sym_preproc_error] = STATE(3187),
    [sym_preproc_warning] = STATE(3187),
    [sym_preproc_define] = STATE(3187),
    [sym_preproc_undef] = STATE(3187),
    [anon_sym_SEMI] = ACTIONS(4687),
    [anon_sym_EQ] = ACTIONS(4689),
    [anon_sym_LBRACK] = ACTIONS(4687),
    [anon_sym_COLON] = ACTIONS(4687),
    [anon_sym_COMMA] = ACTIONS(4687),
    [anon_sym_RBRACK] = ACTIONS(4687),
    [anon_sym_LPAREN] = ACTIONS(4687),
    [anon_sym_RPAREN] = ACTIONS(4687),
    [anon_sym_RBRACE] = ACTIONS(4687),
    [anon_sym_LT] = ACTIONS(4689),
    [anon_sym_GT] = ACTIONS(4689),
    [anon_sym_in] = ACTIONS(4689),
    [anon_sym_QMARK] = ACTIONS(4689),
    [anon_sym_BANG] = ACTIONS(4689),
    [anon_sym_PLUS_PLUS] = ACTIONS(4687),
    [anon_sym_DASH_DASH] = ACTIONS(4687),
    [anon_sym_PLUS] = ACTIONS(4689),
    [anon_sym_DASH] = ACTIONS(4689),
    [anon_sym_STAR] = ACTIONS(4689),
    [anon_sym_SLASH] = ACTIONS(4689),
    [anon_sym_PERCENT] = ACTIONS(4689),
    [anon_sym_CARET] = ACTIONS(4689),
    [anon_sym_PIPE] = ACTIONS(4689),
    [anon_sym_AMP] = ACTIONS(4689),
    [anon_sym_LT_LT] = ACTIONS(4689),
    [anon_sym_GT_GT] = ACTIONS(4689),
    [anon_sym_GT_GT_GT] = ACTIONS(4689),
    [anon_sym_EQ_EQ] = ACTIONS(4687),
    [anon_sym_BANG_EQ] = ACTIONS(4687),
    [anon_sym_GT_EQ] = ACTIONS(4687),
    [anon_sym_LT_EQ] = ACTIONS(4687),
    [anon_sym_DOT] = ACTIONS(4689),
    [anon_sym_EQ_GT] = ACTIONS(4687),
    [anon_sym_switch] = ACTIONS(4687),
    [anon_sym_when] = ACTIONS(4687),
    [anon_sym_DOT_DOT] = ACTIONS(4687),
    [anon_sym_and] = ACTIONS(4687),
    [anon_sym_or] = ACTIONS(4687),
    [anon_sym_PLUS_EQ] = ACTIONS(4687),
    [anon_sym_DASH_EQ] = ACTIONS(4687),
    [anon_sym_STAR_EQ] = ACTIONS(4687),
    [anon_sym_SLASH_EQ] = ACTIONS(4687),
    [anon_sym_PERCENT_EQ] = ACTIONS(4687),
    [anon_sym_AMP_EQ] = ACTIONS(4687),
    [anon_sym_CARET_EQ] = ACTIONS(4687),
    [anon_sym_PIPE_EQ] = ACTIONS(4687),
    [anon_sym_LT_LT_EQ] = ACTIONS(4687),
    [anon_sym_GT_GT_EQ] = ACTIONS(4687),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4687),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4687),
    [anon_sym_AMP_AMP] = ACTIONS(4687),
    [anon_sym_PIPE_PIPE] = ACTIONS(4687),
    [anon_sym_QMARK_QMARK] = ACTIONS(4689),
    [anon_sym_into] = ACTIONS(4687),
    [anon_sym_on] = ACTIONS(4687),
    [anon_sym_equals] = ACTIONS(4687),
    [anon_sym_by] = ACTIONS(4687),
    [anon_sym_as] = ACTIONS(4687),
    [anon_sym_is] = ACTIONS(4687),
    [anon_sym_DASH_GT] = ACTIONS(4687),
    [anon_sym_with] = ACTIONS(4687),
    [aux_sym_preproc_if_token3] = ACTIONS(4687),
    [aux_sym_preproc_else_token1] = ACTIONS(4687),
    [aux_sym_preproc_elif_token1] = ACTIONS(4687),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3188] = {
    [sym_preproc_region] = STATE(3188),
    [sym_preproc_endregion] = STATE(3188),
    [sym_preproc_line] = STATE(3188),
    [sym_preproc_pragma] = STATE(3188),
    [sym_preproc_nullable] = STATE(3188),
    [sym_preproc_error] = STATE(3188),
    [sym_preproc_warning] = STATE(3188),
    [sym_preproc_define] = STATE(3188),
    [sym_preproc_undef] = STATE(3188),
    [anon_sym_SEMI] = ACTIONS(4151),
    [anon_sym_EQ] = ACTIONS(4149),
    [anon_sym_LBRACK] = ACTIONS(4151),
    [anon_sym_COLON] = ACTIONS(4151),
    [anon_sym_COMMA] = ACTIONS(4151),
    [anon_sym_RBRACK] = ACTIONS(4151),
    [anon_sym_LPAREN] = ACTIONS(4151),
    [anon_sym_RPAREN] = ACTIONS(4151),
    [anon_sym_RBRACE] = ACTIONS(4151),
    [anon_sym_LT] = ACTIONS(4149),
    [anon_sym_GT] = ACTIONS(4149),
    [anon_sym_in] = ACTIONS(4149),
    [anon_sym_QMARK] = ACTIONS(4149),
    [anon_sym_BANG] = ACTIONS(4149),
    [anon_sym_PLUS_PLUS] = ACTIONS(4151),
    [anon_sym_DASH_DASH] = ACTIONS(4151),
    [anon_sym_PLUS] = ACTIONS(4149),
    [anon_sym_DASH] = ACTIONS(4149),
    [anon_sym_STAR] = ACTIONS(4149),
    [anon_sym_SLASH] = ACTIONS(4149),
    [anon_sym_PERCENT] = ACTIONS(4149),
    [anon_sym_CARET] = ACTIONS(4149),
    [anon_sym_PIPE] = ACTIONS(4149),
    [anon_sym_AMP] = ACTIONS(4149),
    [anon_sym_LT_LT] = ACTIONS(4149),
    [anon_sym_GT_GT] = ACTIONS(4149),
    [anon_sym_GT_GT_GT] = ACTIONS(4149),
    [anon_sym_EQ_EQ] = ACTIONS(4151),
    [anon_sym_BANG_EQ] = ACTIONS(4151),
    [anon_sym_GT_EQ] = ACTIONS(4151),
    [anon_sym_LT_EQ] = ACTIONS(4151),
    [anon_sym_DOT] = ACTIONS(4149),
    [anon_sym_EQ_GT] = ACTIONS(4151),
    [anon_sym_switch] = ACTIONS(4151),
    [anon_sym_when] = ACTIONS(4151),
    [anon_sym_DOT_DOT] = ACTIONS(4151),
    [anon_sym_and] = ACTIONS(4151),
    [anon_sym_or] = ACTIONS(4151),
    [anon_sym_PLUS_EQ] = ACTIONS(4151),
    [anon_sym_DASH_EQ] = ACTIONS(4151),
    [anon_sym_STAR_EQ] = ACTIONS(4151),
    [anon_sym_SLASH_EQ] = ACTIONS(4151),
    [anon_sym_PERCENT_EQ] = ACTIONS(4151),
    [anon_sym_AMP_EQ] = ACTIONS(4151),
    [anon_sym_CARET_EQ] = ACTIONS(4151),
    [anon_sym_PIPE_EQ] = ACTIONS(4151),
    [anon_sym_LT_LT_EQ] = ACTIONS(4151),
    [anon_sym_GT_GT_EQ] = ACTIONS(4151),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4151),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4151),
    [anon_sym_AMP_AMP] = ACTIONS(4151),
    [anon_sym_PIPE_PIPE] = ACTIONS(4151),
    [anon_sym_QMARK_QMARK] = ACTIONS(4149),
    [anon_sym_into] = ACTIONS(4151),
    [anon_sym_on] = ACTIONS(4151),
    [anon_sym_equals] = ACTIONS(4151),
    [anon_sym_by] = ACTIONS(4151),
    [anon_sym_as] = ACTIONS(4151),
    [anon_sym_is] = ACTIONS(4151),
    [anon_sym_DASH_GT] = ACTIONS(4151),
    [anon_sym_with] = ACTIONS(4151),
    [aux_sym_preproc_if_token3] = ACTIONS(4151),
    [aux_sym_preproc_else_token1] = ACTIONS(4151),
    [aux_sym_preproc_elif_token1] = ACTIONS(4151),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3189] = {
    [sym_preproc_region] = STATE(3189),
    [sym_preproc_endregion] = STATE(3189),
    [sym_preproc_line] = STATE(3189),
    [sym_preproc_pragma] = STATE(3189),
    [sym_preproc_nullable] = STATE(3189),
    [sym_preproc_error] = STATE(3189),
    [sym_preproc_warning] = STATE(3189),
    [sym_preproc_define] = STATE(3189),
    [sym_preproc_undef] = STATE(3189),
    [anon_sym_SEMI] = ACTIONS(4666),
    [anon_sym_EQ] = ACTIONS(4668),
    [anon_sym_LBRACK] = ACTIONS(4666),
    [anon_sym_COLON] = ACTIONS(4666),
    [anon_sym_COMMA] = ACTIONS(4666),
    [anon_sym_RBRACK] = ACTIONS(4666),
    [anon_sym_LPAREN] = ACTIONS(4666),
    [anon_sym_RPAREN] = ACTIONS(4666),
    [anon_sym_RBRACE] = ACTIONS(4666),
    [anon_sym_LT] = ACTIONS(4668),
    [anon_sym_GT] = ACTIONS(4668),
    [anon_sym_in] = ACTIONS(4668),
    [anon_sym_QMARK] = ACTIONS(4668),
    [anon_sym_BANG] = ACTIONS(4668),
    [anon_sym_PLUS_PLUS] = ACTIONS(4666),
    [anon_sym_DASH_DASH] = ACTIONS(4666),
    [anon_sym_PLUS] = ACTIONS(4668),
    [anon_sym_DASH] = ACTIONS(4668),
    [anon_sym_STAR] = ACTIONS(4668),
    [anon_sym_SLASH] = ACTIONS(4668),
    [anon_sym_PERCENT] = ACTIONS(4668),
    [anon_sym_CARET] = ACTIONS(4668),
    [anon_sym_PIPE] = ACTIONS(4668),
    [anon_sym_AMP] = ACTIONS(4668),
    [anon_sym_LT_LT] = ACTIONS(4668),
    [anon_sym_GT_GT] = ACTIONS(4668),
    [anon_sym_GT_GT_GT] = ACTIONS(4668),
    [anon_sym_EQ_EQ] = ACTIONS(4666),
    [anon_sym_BANG_EQ] = ACTIONS(4666),
    [anon_sym_GT_EQ] = ACTIONS(4666),
    [anon_sym_LT_EQ] = ACTIONS(4666),
    [anon_sym_DOT] = ACTIONS(4668),
    [anon_sym_EQ_GT] = ACTIONS(4666),
    [anon_sym_switch] = ACTIONS(4666),
    [anon_sym_when] = ACTIONS(4666),
    [anon_sym_DOT_DOT] = ACTIONS(4666),
    [anon_sym_and] = ACTIONS(4666),
    [anon_sym_or] = ACTIONS(4666),
    [anon_sym_PLUS_EQ] = ACTIONS(4666),
    [anon_sym_DASH_EQ] = ACTIONS(4666),
    [anon_sym_STAR_EQ] = ACTIONS(4666),
    [anon_sym_SLASH_EQ] = ACTIONS(4666),
    [anon_sym_PERCENT_EQ] = ACTIONS(4666),
    [anon_sym_AMP_EQ] = ACTIONS(4666),
    [anon_sym_CARET_EQ] = ACTIONS(4666),
    [anon_sym_PIPE_EQ] = ACTIONS(4666),
    [anon_sym_LT_LT_EQ] = ACTIONS(4666),
    [anon_sym_GT_GT_EQ] = ACTIONS(4666),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4666),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4666),
    [anon_sym_AMP_AMP] = ACTIONS(4666),
    [anon_sym_PIPE_PIPE] = ACTIONS(4666),
    [anon_sym_QMARK_QMARK] = ACTIONS(4668),
    [anon_sym_into] = ACTIONS(4666),
    [anon_sym_on] = ACTIONS(4666),
    [anon_sym_equals] = ACTIONS(4666),
    [anon_sym_by] = ACTIONS(4666),
    [anon_sym_as] = ACTIONS(4666),
    [anon_sym_is] = ACTIONS(4666),
    [anon_sym_DASH_GT] = ACTIONS(4666),
    [anon_sym_with] = ACTIONS(4666),
    [aux_sym_preproc_if_token3] = ACTIONS(4666),
    [aux_sym_preproc_else_token1] = ACTIONS(4666),
    [aux_sym_preproc_elif_token1] = ACTIONS(4666),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3190] = {
    [sym_preproc_region] = STATE(3190),
    [sym_preproc_endregion] = STATE(3190),
    [sym_preproc_line] = STATE(3190),
    [sym_preproc_pragma] = STATE(3190),
    [sym_preproc_nullable] = STATE(3190),
    [sym_preproc_error] = STATE(3190),
    [sym_preproc_warning] = STATE(3190),
    [sym_preproc_define] = STATE(3190),
    [sym_preproc_undef] = STATE(3190),
    [anon_sym_SEMI] = ACTIONS(4670),
    [anon_sym_EQ] = ACTIONS(4672),
    [anon_sym_LBRACK] = ACTIONS(4670),
    [anon_sym_COLON] = ACTIONS(4670),
    [anon_sym_COMMA] = ACTIONS(4670),
    [anon_sym_RBRACK] = ACTIONS(4670),
    [anon_sym_LPAREN] = ACTIONS(4670),
    [anon_sym_RPAREN] = ACTIONS(4670),
    [anon_sym_RBRACE] = ACTIONS(4670),
    [anon_sym_LT] = ACTIONS(4672),
    [anon_sym_GT] = ACTIONS(4672),
    [anon_sym_in] = ACTIONS(4672),
    [anon_sym_QMARK] = ACTIONS(4672),
    [anon_sym_BANG] = ACTIONS(4672),
    [anon_sym_PLUS_PLUS] = ACTIONS(4670),
    [anon_sym_DASH_DASH] = ACTIONS(4670),
    [anon_sym_PLUS] = ACTIONS(4672),
    [anon_sym_DASH] = ACTIONS(4672),
    [anon_sym_STAR] = ACTIONS(4672),
    [anon_sym_SLASH] = ACTIONS(4672),
    [anon_sym_PERCENT] = ACTIONS(4672),
    [anon_sym_CARET] = ACTIONS(4672),
    [anon_sym_PIPE] = ACTIONS(4672),
    [anon_sym_AMP] = ACTIONS(4672),
    [anon_sym_LT_LT] = ACTIONS(4672),
    [anon_sym_GT_GT] = ACTIONS(4672),
    [anon_sym_GT_GT_GT] = ACTIONS(4672),
    [anon_sym_EQ_EQ] = ACTIONS(4670),
    [anon_sym_BANG_EQ] = ACTIONS(4670),
    [anon_sym_GT_EQ] = ACTIONS(4670),
    [anon_sym_LT_EQ] = ACTIONS(4670),
    [anon_sym_DOT] = ACTIONS(4672),
    [anon_sym_EQ_GT] = ACTIONS(4670),
    [anon_sym_switch] = ACTIONS(4670),
    [anon_sym_when] = ACTIONS(4670),
    [anon_sym_DOT_DOT] = ACTIONS(4670),
    [anon_sym_and] = ACTIONS(4670),
    [anon_sym_or] = ACTIONS(4670),
    [anon_sym_PLUS_EQ] = ACTIONS(4670),
    [anon_sym_DASH_EQ] = ACTIONS(4670),
    [anon_sym_STAR_EQ] = ACTIONS(4670),
    [anon_sym_SLASH_EQ] = ACTIONS(4670),
    [anon_sym_PERCENT_EQ] = ACTIONS(4670),
    [anon_sym_AMP_EQ] = ACTIONS(4670),
    [anon_sym_CARET_EQ] = ACTIONS(4670),
    [anon_sym_PIPE_EQ] = ACTIONS(4670),
    [anon_sym_LT_LT_EQ] = ACTIONS(4670),
    [anon_sym_GT_GT_EQ] = ACTIONS(4670),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4670),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4670),
    [anon_sym_AMP_AMP] = ACTIONS(4670),
    [anon_sym_PIPE_PIPE] = ACTIONS(4670),
    [anon_sym_QMARK_QMARK] = ACTIONS(4672),
    [anon_sym_into] = ACTIONS(4670),
    [anon_sym_on] = ACTIONS(4670),
    [anon_sym_equals] = ACTIONS(4670),
    [anon_sym_by] = ACTIONS(4670),
    [anon_sym_as] = ACTIONS(4670),
    [anon_sym_is] = ACTIONS(4670),
    [anon_sym_DASH_GT] = ACTIONS(4670),
    [anon_sym_with] = ACTIONS(4670),
    [aux_sym_preproc_if_token3] = ACTIONS(4670),
    [aux_sym_preproc_else_token1] = ACTIONS(4670),
    [aux_sym_preproc_elif_token1] = ACTIONS(4670),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3191] = {
    [sym_preproc_region] = STATE(3191),
    [sym_preproc_endregion] = STATE(3191),
    [sym_preproc_line] = STATE(3191),
    [sym_preproc_pragma] = STATE(3191),
    [sym_preproc_nullable] = STATE(3191),
    [sym_preproc_error] = STATE(3191),
    [sym_preproc_warning] = STATE(3191),
    [sym_preproc_define] = STATE(3191),
    [sym_preproc_undef] = STATE(3191),
    [anon_sym_SEMI] = ACTIONS(4191),
    [anon_sym_EQ] = ACTIONS(4183),
    [anon_sym_LBRACK] = ACTIONS(4191),
    [anon_sym_COLON] = ACTIONS(4191),
    [anon_sym_COMMA] = ACTIONS(4191),
    [anon_sym_RBRACK] = ACTIONS(4191),
    [anon_sym_LPAREN] = ACTIONS(4191),
    [anon_sym_RPAREN] = ACTIONS(4191),
    [anon_sym_RBRACE] = ACTIONS(4191),
    [anon_sym_LT] = ACTIONS(4183),
    [anon_sym_GT] = ACTIONS(4183),
    [anon_sym_in] = ACTIONS(4183),
    [anon_sym_QMARK] = ACTIONS(4183),
    [anon_sym_BANG] = ACTIONS(4183),
    [anon_sym_PLUS_PLUS] = ACTIONS(4191),
    [anon_sym_DASH_DASH] = ACTIONS(4191),
    [anon_sym_PLUS] = ACTIONS(4183),
    [anon_sym_DASH] = ACTIONS(4183),
    [anon_sym_STAR] = ACTIONS(4183),
    [anon_sym_SLASH] = ACTIONS(4183),
    [anon_sym_PERCENT] = ACTIONS(4183),
    [anon_sym_CARET] = ACTIONS(4183),
    [anon_sym_PIPE] = ACTIONS(4183),
    [anon_sym_AMP] = ACTIONS(4183),
    [anon_sym_LT_LT] = ACTIONS(4183),
    [anon_sym_GT_GT] = ACTIONS(4183),
    [anon_sym_GT_GT_GT] = ACTIONS(4183),
    [anon_sym_EQ_EQ] = ACTIONS(4191),
    [anon_sym_BANG_EQ] = ACTIONS(4191),
    [anon_sym_GT_EQ] = ACTIONS(4191),
    [anon_sym_LT_EQ] = ACTIONS(4191),
    [anon_sym_DOT] = ACTIONS(4183),
    [anon_sym_EQ_GT] = ACTIONS(4191),
    [anon_sym_switch] = ACTIONS(4191),
    [anon_sym_when] = ACTIONS(4191),
    [anon_sym_DOT_DOT] = ACTIONS(4191),
    [anon_sym_and] = ACTIONS(4191),
    [anon_sym_or] = ACTIONS(4191),
    [anon_sym_PLUS_EQ] = ACTIONS(4191),
    [anon_sym_DASH_EQ] = ACTIONS(4191),
    [anon_sym_STAR_EQ] = ACTIONS(4191),
    [anon_sym_SLASH_EQ] = ACTIONS(4191),
    [anon_sym_PERCENT_EQ] = ACTIONS(4191),
    [anon_sym_AMP_EQ] = ACTIONS(4191),
    [anon_sym_CARET_EQ] = ACTIONS(4191),
    [anon_sym_PIPE_EQ] = ACTIONS(4191),
    [anon_sym_LT_LT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4191),
    [anon_sym_AMP_AMP] = ACTIONS(4191),
    [anon_sym_PIPE_PIPE] = ACTIONS(4191),
    [anon_sym_QMARK_QMARK] = ACTIONS(4183),
    [anon_sym_into] = ACTIONS(4191),
    [anon_sym_on] = ACTIONS(4191),
    [anon_sym_equals] = ACTIONS(4191),
    [anon_sym_by] = ACTIONS(4191),
    [anon_sym_as] = ACTIONS(4191),
    [anon_sym_is] = ACTIONS(4191),
    [anon_sym_DASH_GT] = ACTIONS(4191),
    [anon_sym_with] = ACTIONS(4191),
    [aux_sym_preproc_if_token3] = ACTIONS(4191),
    [aux_sym_preproc_else_token1] = ACTIONS(4191),
    [aux_sym_preproc_elif_token1] = ACTIONS(4191),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3192] = {
    [sym__variable_designation] = STATE(4663),
    [sym_parenthesized_variable_designation] = STATE(4748),
    [sym_identifier] = STATE(4548),
    [sym__reserved_identifier] = STATE(2928),
    [sym_preproc_region] = STATE(3192),
    [sym_preproc_endregion] = STATE(3192),
    [sym_preproc_line] = STATE(3192),
    [sym_preproc_pragma] = STATE(3192),
    [sym_preproc_nullable] = STATE(3192),
    [sym_preproc_error] = STATE(3192),
    [sym_preproc_warning] = STATE(3192),
    [sym_preproc_define] = STATE(3192),
    [sym_preproc_undef] = STATE(3192),
    [sym__identifier_token] = ACTIONS(4536),
    [anon_sym_alias] = ACTIONS(4538),
    [anon_sym_global] = ACTIONS(4538),
    [anon_sym_LBRACK] = ACTIONS(4441),
    [anon_sym_COMMA] = ACTIONS(4441),
    [anon_sym_LPAREN] = ACTIONS(4441),
    [anon_sym_file] = ACTIONS(4538),
    [anon_sym_LT] = ACTIONS(4443),
    [anon_sym_GT] = ACTIONS(4443),
    [anon_sym_where] = ACTIONS(4443),
    [anon_sym_QMARK] = ACTIONS(4443),
    [anon_sym_notnull] = ACTIONS(4538),
    [anon_sym_unmanaged] = ACTIONS(4538),
    [anon_sym_BANG] = ACTIONS(4443),
    [anon_sym_PLUS_PLUS] = ACTIONS(4441),
    [anon_sym_DASH_DASH] = ACTIONS(4441),
    [anon_sym_PLUS] = ACTIONS(4443),
    [anon_sym_DASH] = ACTIONS(4443),
    [anon_sym_STAR] = ACTIONS(4441),
    [anon_sym_SLASH] = ACTIONS(4443),
    [anon_sym_PERCENT] = ACTIONS(4441),
    [anon_sym_CARET] = ACTIONS(4441),
    [anon_sym_PIPE] = ACTIONS(4443),
    [anon_sym_AMP] = ACTIONS(4443),
    [anon_sym_LT_LT] = ACTIONS(4441),
    [anon_sym_GT_GT] = ACTIONS(4443),
    [anon_sym_GT_GT_GT] = ACTIONS(4441),
    [anon_sym_EQ_EQ] = ACTIONS(4441),
    [anon_sym_BANG_EQ] = ACTIONS(4441),
    [anon_sym_GT_EQ] = ACTIONS(4441),
    [anon_sym_LT_EQ] = ACTIONS(4441),
    [anon_sym_DOT] = ACTIONS(4443),
    [anon_sym_scoped] = ACTIONS(4538),
    [anon_sym_var] = ACTIONS(4538),
    [anon_sym_yield] = ACTIONS(4538),
    [anon_sym_switch] = ACTIONS(4443),
    [anon_sym_when] = ACTIONS(4538),
    [sym_discard] = ACTIONS(4717),
    [anon_sym_DOT_DOT] = ACTIONS(4441),
    [anon_sym_and] = ACTIONS(4443),
    [anon_sym_or] = ACTIONS(4443),
    [anon_sym_AMP_AMP] = ACTIONS(4441),
    [anon_sym_PIPE_PIPE] = ACTIONS(4441),
    [anon_sym_QMARK_QMARK] = ACTIONS(4441),
    [anon_sym_from] = ACTIONS(4443),
    [anon_sym_into] = ACTIONS(4443),
    [anon_sym_join] = ACTIONS(4443),
    [anon_sym_on] = ACTIONS(4538),
    [anon_sym_equals] = ACTIONS(4538),
    [anon_sym_let] = ACTIONS(4443),
    [anon_sym_orderby] = ACTIONS(4443),
    [anon_sym_ascending] = ACTIONS(4443),
    [anon_sym_descending] = ACTIONS(4443),
    [anon_sym_group] = ACTIONS(4443),
    [anon_sym_by] = ACTIONS(4538),
    [anon_sym_select] = ACTIONS(4443),
    [anon_sym_as] = ACTIONS(4443),
    [anon_sym_is] = ACTIONS(4443),
    [anon_sym_DASH_GT] = ACTIONS(4441),
    [anon_sym_with] = ACTIONS(4443),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3193] = {
    [sym_preproc_region] = STATE(3193),
    [sym_preproc_endregion] = STATE(3193),
    [sym_preproc_line] = STATE(3193),
    [sym_preproc_pragma] = STATE(3193),
    [sym_preproc_nullable] = STATE(3193),
    [sym_preproc_error] = STATE(3193),
    [sym_preproc_warning] = STATE(3193),
    [sym_preproc_define] = STATE(3193),
    [sym_preproc_undef] = STATE(3193),
    [anon_sym_SEMI] = ACTIONS(4128),
    [anon_sym_EQ] = ACTIONS(4126),
    [anon_sym_LBRACK] = ACTIONS(4128),
    [anon_sym_COLON] = ACTIONS(4128),
    [anon_sym_COMMA] = ACTIONS(4128),
    [anon_sym_RBRACK] = ACTIONS(4128),
    [anon_sym_LPAREN] = ACTIONS(4128),
    [anon_sym_RPAREN] = ACTIONS(4128),
    [anon_sym_RBRACE] = ACTIONS(4128),
    [anon_sym_LT] = ACTIONS(4126),
    [anon_sym_GT] = ACTIONS(4126),
    [anon_sym_in] = ACTIONS(4126),
    [anon_sym_QMARK] = ACTIONS(4126),
    [anon_sym_BANG] = ACTIONS(4126),
    [anon_sym_PLUS_PLUS] = ACTIONS(4128),
    [anon_sym_DASH_DASH] = ACTIONS(4128),
    [anon_sym_PLUS] = ACTIONS(4126),
    [anon_sym_DASH] = ACTIONS(4126),
    [anon_sym_STAR] = ACTIONS(4126),
    [anon_sym_SLASH] = ACTIONS(4126),
    [anon_sym_PERCENT] = ACTIONS(4126),
    [anon_sym_CARET] = ACTIONS(4126),
    [anon_sym_PIPE] = ACTIONS(4126),
    [anon_sym_AMP] = ACTIONS(4126),
    [anon_sym_LT_LT] = ACTIONS(4126),
    [anon_sym_GT_GT] = ACTIONS(4126),
    [anon_sym_GT_GT_GT] = ACTIONS(4126),
    [anon_sym_EQ_EQ] = ACTIONS(4128),
    [anon_sym_BANG_EQ] = ACTIONS(4128),
    [anon_sym_GT_EQ] = ACTIONS(4128),
    [anon_sym_LT_EQ] = ACTIONS(4128),
    [anon_sym_DOT] = ACTIONS(4126),
    [anon_sym_EQ_GT] = ACTIONS(4128),
    [anon_sym_switch] = ACTIONS(4128),
    [anon_sym_when] = ACTIONS(4128),
    [anon_sym_DOT_DOT] = ACTIONS(4128),
    [anon_sym_and] = ACTIONS(4128),
    [anon_sym_or] = ACTIONS(4128),
    [anon_sym_PLUS_EQ] = ACTIONS(4128),
    [anon_sym_DASH_EQ] = ACTIONS(4128),
    [anon_sym_STAR_EQ] = ACTIONS(4128),
    [anon_sym_SLASH_EQ] = ACTIONS(4128),
    [anon_sym_PERCENT_EQ] = ACTIONS(4128),
    [anon_sym_AMP_EQ] = ACTIONS(4128),
    [anon_sym_CARET_EQ] = ACTIONS(4128),
    [anon_sym_PIPE_EQ] = ACTIONS(4128),
    [anon_sym_LT_LT_EQ] = ACTIONS(4128),
    [anon_sym_GT_GT_EQ] = ACTIONS(4128),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4128),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4128),
    [anon_sym_AMP_AMP] = ACTIONS(4128),
    [anon_sym_PIPE_PIPE] = ACTIONS(4128),
    [anon_sym_QMARK_QMARK] = ACTIONS(4126),
    [anon_sym_into] = ACTIONS(4128),
    [anon_sym_on] = ACTIONS(4128),
    [anon_sym_equals] = ACTIONS(4128),
    [anon_sym_by] = ACTIONS(4128),
    [anon_sym_as] = ACTIONS(4128),
    [anon_sym_is] = ACTIONS(4128),
    [anon_sym_DASH_GT] = ACTIONS(4128),
    [anon_sym_with] = ACTIONS(4128),
    [aux_sym_preproc_if_token3] = ACTIONS(4128),
    [aux_sym_preproc_else_token1] = ACTIONS(4128),
    [aux_sym_preproc_elif_token1] = ACTIONS(4128),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3194] = {
    [sym_preproc_region] = STATE(3194),
    [sym_preproc_endregion] = STATE(3194),
    [sym_preproc_line] = STATE(3194),
    [sym_preproc_pragma] = STATE(3194),
    [sym_preproc_nullable] = STATE(3194),
    [sym_preproc_error] = STATE(3194),
    [sym_preproc_warning] = STATE(3194),
    [sym_preproc_define] = STATE(3194),
    [sym_preproc_undef] = STATE(3194),
    [anon_sym_SEMI] = ACTIONS(4177),
    [anon_sym_EQ] = ACTIONS(4162),
    [anon_sym_LBRACK] = ACTIONS(4177),
    [anon_sym_COLON] = ACTIONS(4177),
    [anon_sym_COMMA] = ACTIONS(4177),
    [anon_sym_RBRACK] = ACTIONS(4177),
    [anon_sym_LPAREN] = ACTIONS(4177),
    [anon_sym_RPAREN] = ACTIONS(4177),
    [anon_sym_RBRACE] = ACTIONS(4177),
    [anon_sym_LT] = ACTIONS(4162),
    [anon_sym_GT] = ACTIONS(4162),
    [anon_sym_in] = ACTIONS(4162),
    [anon_sym_QMARK] = ACTIONS(4162),
    [anon_sym_BANG] = ACTIONS(4162),
    [anon_sym_PLUS_PLUS] = ACTIONS(4177),
    [anon_sym_DASH_DASH] = ACTIONS(4177),
    [anon_sym_PLUS] = ACTIONS(4162),
    [anon_sym_DASH] = ACTIONS(4162),
    [anon_sym_STAR] = ACTIONS(4162),
    [anon_sym_SLASH] = ACTIONS(4162),
    [anon_sym_PERCENT] = ACTIONS(4162),
    [anon_sym_CARET] = ACTIONS(4162),
    [anon_sym_PIPE] = ACTIONS(4162),
    [anon_sym_AMP] = ACTIONS(4162),
    [anon_sym_LT_LT] = ACTIONS(4162),
    [anon_sym_GT_GT] = ACTIONS(4162),
    [anon_sym_GT_GT_GT] = ACTIONS(4162),
    [anon_sym_EQ_EQ] = ACTIONS(4177),
    [anon_sym_BANG_EQ] = ACTIONS(4177),
    [anon_sym_GT_EQ] = ACTIONS(4177),
    [anon_sym_LT_EQ] = ACTIONS(4177),
    [anon_sym_DOT] = ACTIONS(4162),
    [anon_sym_EQ_GT] = ACTIONS(4177),
    [anon_sym_switch] = ACTIONS(4177),
    [anon_sym_when] = ACTIONS(4177),
    [anon_sym_DOT_DOT] = ACTIONS(4177),
    [anon_sym_and] = ACTIONS(4177),
    [anon_sym_or] = ACTIONS(4177),
    [anon_sym_PLUS_EQ] = ACTIONS(4177),
    [anon_sym_DASH_EQ] = ACTIONS(4177),
    [anon_sym_STAR_EQ] = ACTIONS(4177),
    [anon_sym_SLASH_EQ] = ACTIONS(4177),
    [anon_sym_PERCENT_EQ] = ACTIONS(4177),
    [anon_sym_AMP_EQ] = ACTIONS(4177),
    [anon_sym_CARET_EQ] = ACTIONS(4177),
    [anon_sym_PIPE_EQ] = ACTIONS(4177),
    [anon_sym_LT_LT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4177),
    [anon_sym_AMP_AMP] = ACTIONS(4177),
    [anon_sym_PIPE_PIPE] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK] = ACTIONS(4162),
    [anon_sym_into] = ACTIONS(4177),
    [anon_sym_on] = ACTIONS(4177),
    [anon_sym_equals] = ACTIONS(4177),
    [anon_sym_by] = ACTIONS(4177),
    [anon_sym_as] = ACTIONS(4177),
    [anon_sym_is] = ACTIONS(4177),
    [anon_sym_DASH_GT] = ACTIONS(4177),
    [anon_sym_with] = ACTIONS(4177),
    [aux_sym_preproc_if_token3] = ACTIONS(4177),
    [aux_sym_preproc_else_token1] = ACTIONS(4177),
    [aux_sym_preproc_elif_token1] = ACTIONS(4177),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3195] = {
    [sym_type_argument_list] = STATE(3393),
    [sym_preproc_region] = STATE(3195),
    [sym_preproc_endregion] = STATE(3195),
    [sym_preproc_line] = STATE(3195),
    [sym_preproc_pragma] = STATE(3195),
    [sym_preproc_nullable] = STATE(3195),
    [sym_preproc_error] = STATE(3195),
    [sym_preproc_warning] = STATE(3195),
    [sym_preproc_define] = STATE(3195),
    [sym_preproc_undef] = STATE(3195),
    [anon_sym_SEMI] = ACTIONS(4140),
    [anon_sym_EQ] = ACTIONS(4138),
    [anon_sym_LBRACK] = ACTIONS(4140),
    [anon_sym_COLON] = ACTIONS(4140),
    [anon_sym_COMMA] = ACTIONS(4140),
    [anon_sym_RBRACK] = ACTIONS(4140),
    [anon_sym_LPAREN] = ACTIONS(4140),
    [anon_sym_RPAREN] = ACTIONS(4140),
    [anon_sym_RBRACE] = ACTIONS(4140),
    [anon_sym_LT] = ACTIONS(4787),
    [anon_sym_GT] = ACTIONS(4138),
    [anon_sym_in] = ACTIONS(4140),
    [anon_sym_QMARK] = ACTIONS(4138),
    [anon_sym_BANG] = ACTIONS(4138),
    [anon_sym_PLUS_PLUS] = ACTIONS(4140),
    [anon_sym_DASH_DASH] = ACTIONS(4140),
    [anon_sym_PLUS] = ACTIONS(4138),
    [anon_sym_DASH] = ACTIONS(4138),
    [anon_sym_STAR] = ACTIONS(4138),
    [anon_sym_SLASH] = ACTIONS(4138),
    [anon_sym_PERCENT] = ACTIONS(4138),
    [anon_sym_CARET] = ACTIONS(4138),
    [anon_sym_PIPE] = ACTIONS(4138),
    [anon_sym_AMP] = ACTIONS(4138),
    [anon_sym_LT_LT] = ACTIONS(4138),
    [anon_sym_GT_GT] = ACTIONS(4138),
    [anon_sym_GT_GT_GT] = ACTIONS(4138),
    [anon_sym_EQ_EQ] = ACTIONS(4140),
    [anon_sym_BANG_EQ] = ACTIONS(4140),
    [anon_sym_GT_EQ] = ACTIONS(4140),
    [anon_sym_LT_EQ] = ACTIONS(4140),
    [anon_sym_DOT] = ACTIONS(4138),
    [anon_sym_EQ_GT] = ACTIONS(4140),
    [anon_sym_switch] = ACTIONS(4140),
    [anon_sym_when] = ACTIONS(4140),
    [anon_sym_DOT_DOT] = ACTIONS(4140),
    [anon_sym_and] = ACTIONS(4140),
    [anon_sym_or] = ACTIONS(4140),
    [anon_sym_PLUS_EQ] = ACTIONS(4140),
    [anon_sym_DASH_EQ] = ACTIONS(4140),
    [anon_sym_STAR_EQ] = ACTIONS(4140),
    [anon_sym_SLASH_EQ] = ACTIONS(4140),
    [anon_sym_PERCENT_EQ] = ACTIONS(4140),
    [anon_sym_AMP_EQ] = ACTIONS(4140),
    [anon_sym_CARET_EQ] = ACTIONS(4140),
    [anon_sym_PIPE_EQ] = ACTIONS(4140),
    [anon_sym_LT_LT_EQ] = ACTIONS(4140),
    [anon_sym_GT_GT_EQ] = ACTIONS(4140),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4140),
    [anon_sym_AMP_AMP] = ACTIONS(4140),
    [anon_sym_PIPE_PIPE] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK] = ACTIONS(4138),
    [anon_sym_on] = ACTIONS(4140),
    [anon_sym_equals] = ACTIONS(4140),
    [anon_sym_by] = ACTIONS(4140),
    [anon_sym_as] = ACTIONS(4140),
    [anon_sym_is] = ACTIONS(4140),
    [anon_sym_DASH_GT] = ACTIONS(4140),
    [anon_sym_with] = ACTIONS(4140),
    [aux_sym_preproc_if_token3] = ACTIONS(4140),
    [aux_sym_preproc_else_token1] = ACTIONS(4140),
    [aux_sym_preproc_elif_token1] = ACTIONS(4140),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3196] = {
    [sym_preproc_region] = STATE(3196),
    [sym_preproc_endregion] = STATE(3196),
    [sym_preproc_line] = STATE(3196),
    [sym_preproc_pragma] = STATE(3196),
    [sym_preproc_nullable] = STATE(3196),
    [sym_preproc_error] = STATE(3196),
    [sym_preproc_warning] = STATE(3196),
    [sym_preproc_define] = STATE(3196),
    [sym_preproc_undef] = STATE(3196),
    [sym__identifier_token] = ACTIONS(4587),
    [anon_sym_alias] = ACTIONS(4587),
    [anon_sym_global] = ACTIONS(4587),
    [anon_sym_LBRACK] = ACTIONS(4589),
    [anon_sym_COLON] = ACTIONS(4589),
    [anon_sym_COMMA] = ACTIONS(4589),
    [anon_sym_LPAREN] = ACTIONS(4589),
    [anon_sym_LBRACE] = ACTIONS(4589),
    [anon_sym_file] = ACTIONS(4587),
    [anon_sym_LT] = ACTIONS(4587),
    [anon_sym_GT] = ACTIONS(4587),
    [anon_sym_where] = ACTIONS(4587),
    [anon_sym_QMARK] = ACTIONS(4587),
    [anon_sym_notnull] = ACTIONS(4587),
    [anon_sym_unmanaged] = ACTIONS(4587),
    [anon_sym_BANG] = ACTIONS(4587),
    [anon_sym_PLUS_PLUS] = ACTIONS(4589),
    [anon_sym_DASH_DASH] = ACTIONS(4589),
    [anon_sym_PLUS] = ACTIONS(4587),
    [anon_sym_DASH] = ACTIONS(4587),
    [anon_sym_STAR] = ACTIONS(4589),
    [anon_sym_SLASH] = ACTIONS(4587),
    [anon_sym_PERCENT] = ACTIONS(4589),
    [anon_sym_CARET] = ACTIONS(4589),
    [anon_sym_PIPE] = ACTIONS(4587),
    [anon_sym_AMP] = ACTIONS(4587),
    [anon_sym_LT_LT] = ACTIONS(4589),
    [anon_sym_GT_GT] = ACTIONS(4587),
    [anon_sym_GT_GT_GT] = ACTIONS(4589),
    [anon_sym_EQ_EQ] = ACTIONS(4589),
    [anon_sym_BANG_EQ] = ACTIONS(4589),
    [anon_sym_GT_EQ] = ACTIONS(4589),
    [anon_sym_LT_EQ] = ACTIONS(4589),
    [anon_sym_DOT] = ACTIONS(4587),
    [anon_sym_scoped] = ACTIONS(4587),
    [anon_sym_EQ_GT] = ACTIONS(4591),
    [anon_sym_var] = ACTIONS(4587),
    [anon_sym_yield] = ACTIONS(4587),
    [anon_sym_switch] = ACTIONS(4587),
    [anon_sym_when] = ACTIONS(4587),
    [sym_discard] = ACTIONS(4587),
    [anon_sym_DOT_DOT] = ACTIONS(4589),
    [anon_sym_and] = ACTIONS(4587),
    [anon_sym_or] = ACTIONS(4587),
    [anon_sym_AMP_AMP] = ACTIONS(4589),
    [anon_sym_PIPE_PIPE] = ACTIONS(4589),
    [anon_sym_QMARK_QMARK] = ACTIONS(4589),
    [anon_sym_from] = ACTIONS(4587),
    [anon_sym_into] = ACTIONS(4587),
    [anon_sym_join] = ACTIONS(4587),
    [anon_sym_on] = ACTIONS(4587),
    [anon_sym_equals] = ACTIONS(4587),
    [anon_sym_let] = ACTIONS(4587),
    [anon_sym_orderby] = ACTIONS(4587),
    [anon_sym_ascending] = ACTIONS(4587),
    [anon_sym_descending] = ACTIONS(4587),
    [anon_sym_group] = ACTIONS(4587),
    [anon_sym_by] = ACTIONS(4587),
    [anon_sym_select] = ACTIONS(4587),
    [anon_sym_as] = ACTIONS(4587),
    [anon_sym_is] = ACTIONS(4587),
    [anon_sym_DASH_GT] = ACTIONS(4589),
    [anon_sym_with] = ACTIONS(4587),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4589),
  },
  [3197] = {
    [sym__variable_designation] = STATE(4663),
    [sym_parenthesized_variable_designation] = STATE(4748),
    [sym_identifier] = STATE(4548),
    [sym__reserved_identifier] = STATE(2928),
    [sym_preproc_region] = STATE(3197),
    [sym_preproc_endregion] = STATE(3197),
    [sym_preproc_line] = STATE(3197),
    [sym_preproc_pragma] = STATE(3197),
    [sym_preproc_nullable] = STATE(3197),
    [sym_preproc_error] = STATE(3197),
    [sym_preproc_warning] = STATE(3197),
    [sym_preproc_define] = STATE(3197),
    [sym_preproc_undef] = STATE(3197),
    [sym__identifier_token] = ACTIONS(4536),
    [anon_sym_alias] = ACTIONS(4538),
    [anon_sym_global] = ACTIONS(4538),
    [anon_sym_LBRACK] = ACTIONS(4441),
    [anon_sym_COMMA] = ACTIONS(4441),
    [anon_sym_LPAREN] = ACTIONS(4441),
    [anon_sym_file] = ACTIONS(4538),
    [anon_sym_LT] = ACTIONS(4443),
    [anon_sym_GT] = ACTIONS(4443),
    [anon_sym_where] = ACTIONS(4443),
    [anon_sym_QMARK] = ACTIONS(4443),
    [anon_sym_notnull] = ACTIONS(4538),
    [anon_sym_unmanaged] = ACTIONS(4538),
    [anon_sym_BANG] = ACTIONS(4443),
    [anon_sym_PLUS_PLUS] = ACTIONS(4441),
    [anon_sym_DASH_DASH] = ACTIONS(4441),
    [anon_sym_PLUS] = ACTIONS(4443),
    [anon_sym_DASH] = ACTIONS(4443),
    [anon_sym_STAR] = ACTIONS(4441),
    [anon_sym_SLASH] = ACTIONS(4443),
    [anon_sym_PERCENT] = ACTIONS(4441),
    [anon_sym_CARET] = ACTIONS(4441),
    [anon_sym_PIPE] = ACTIONS(4443),
    [anon_sym_AMP] = ACTIONS(4443),
    [anon_sym_LT_LT] = ACTIONS(4441),
    [anon_sym_GT_GT] = ACTIONS(4443),
    [anon_sym_GT_GT_GT] = ACTIONS(4441),
    [anon_sym_EQ_EQ] = ACTIONS(4441),
    [anon_sym_BANG_EQ] = ACTIONS(4441),
    [anon_sym_GT_EQ] = ACTIONS(4441),
    [anon_sym_LT_EQ] = ACTIONS(4441),
    [anon_sym_DOT] = ACTIONS(4443),
    [anon_sym_scoped] = ACTIONS(4538),
    [anon_sym_var] = ACTIONS(4538),
    [anon_sym_yield] = ACTIONS(4538),
    [anon_sym_switch] = ACTIONS(4443),
    [anon_sym_when] = ACTIONS(4538),
    [sym_discard] = ACTIONS(4717),
    [anon_sym_DOT_DOT] = ACTIONS(4441),
    [anon_sym_and] = ACTIONS(4443),
    [anon_sym_or] = ACTIONS(4443),
    [anon_sym_AMP_AMP] = ACTIONS(4441),
    [anon_sym_PIPE_PIPE] = ACTIONS(4441),
    [anon_sym_QMARK_QMARK] = ACTIONS(4441),
    [anon_sym_from] = ACTIONS(4443),
    [anon_sym_into] = ACTIONS(4538),
    [anon_sym_join] = ACTIONS(4443),
    [anon_sym_on] = ACTIONS(4538),
    [anon_sym_equals] = ACTIONS(4538),
    [anon_sym_let] = ACTIONS(4443),
    [anon_sym_orderby] = ACTIONS(4443),
    [anon_sym_ascending] = ACTIONS(4443),
    [anon_sym_descending] = ACTIONS(4443),
    [anon_sym_group] = ACTIONS(4443),
    [anon_sym_by] = ACTIONS(4538),
    [anon_sym_select] = ACTIONS(4443),
    [anon_sym_as] = ACTIONS(4443),
    [anon_sym_is] = ACTIONS(4443),
    [anon_sym_DASH_GT] = ACTIONS(4441),
    [anon_sym_with] = ACTIONS(4443),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3198] = {
    [sym_preproc_region] = STATE(3198),
    [sym_preproc_endregion] = STATE(3198),
    [sym_preproc_line] = STATE(3198),
    [sym_preproc_pragma] = STATE(3198),
    [sym_preproc_nullable] = STATE(3198),
    [sym_preproc_error] = STATE(3198),
    [sym_preproc_warning] = STATE(3198),
    [sym_preproc_define] = STATE(3198),
    [sym_preproc_undef] = STATE(3198),
    [sym__identifier_token] = ACTIONS(4790),
    [anon_sym_extern] = ACTIONS(4790),
    [anon_sym_alias] = ACTIONS(4790),
    [anon_sym_global] = ACTIONS(4790),
    [anon_sym_using] = ACTIONS(4790),
    [anon_sym_unsafe] = ACTIONS(4790),
    [anon_sym_EQ] = ACTIONS(4792),
    [anon_sym_static] = ACTIONS(4790),
    [anon_sym_LBRACK] = ACTIONS(4794),
    [anon_sym_LPAREN] = ACTIONS(4794),
    [anon_sym_event] = ACTIONS(4790),
    [anon_sym_namespace] = ACTIONS(4790),
    [anon_sym_class] = ACTIONS(4790),
    [anon_sym_ref] = ACTIONS(4790),
    [anon_sym_struct] = ACTIONS(4790),
    [anon_sym_enum] = ACTIONS(4790),
    [anon_sym_RBRACE] = ACTIONS(4794),
    [anon_sym_interface] = ACTIONS(4790),
    [anon_sym_delegate] = ACTIONS(4790),
    [anon_sym_record] = ACTIONS(4790),
    [anon_sym_abstract] = ACTIONS(4790),
    [anon_sym_async] = ACTIONS(4790),
    [anon_sym_const] = ACTIONS(4790),
    [anon_sym_file] = ACTIONS(4790),
    [anon_sym_fixed] = ACTIONS(4790),
    [anon_sym_internal] = ACTIONS(4790),
    [anon_sym_new] = ACTIONS(4790),
    [anon_sym_override] = ACTIONS(4790),
    [anon_sym_partial] = ACTIONS(4790),
    [anon_sym_private] = ACTIONS(4790),
    [anon_sym_protected] = ACTIONS(4790),
    [anon_sym_public] = ACTIONS(4790),
    [anon_sym_readonly] = ACTIONS(4790),
    [anon_sym_required] = ACTIONS(4790),
    [anon_sym_sealed] = ACTIONS(4790),
    [anon_sym_virtual] = ACTIONS(4790),
    [anon_sym_volatile] = ACTIONS(4790),
    [anon_sym_where] = ACTIONS(4790),
    [anon_sym_notnull] = ACTIONS(4790),
    [anon_sym_unmanaged] = ACTIONS(4790),
    [anon_sym_TILDE] = ACTIONS(4794),
    [anon_sym_implicit] = ACTIONS(4790),
    [anon_sym_explicit] = ACTIONS(4790),
    [anon_sym_scoped] = ACTIONS(4790),
    [anon_sym_var] = ACTIONS(4790),
    [sym_predefined_type] = ACTIONS(4790),
    [anon_sym_yield] = ACTIONS(4790),
    [anon_sym_when] = ACTIONS(4790),
    [anon_sym_from] = ACTIONS(4790),
    [anon_sym_into] = ACTIONS(4790),
    [anon_sym_join] = ACTIONS(4790),
    [anon_sym_on] = ACTIONS(4790),
    [anon_sym_equals] = ACTIONS(4790),
    [anon_sym_let] = ACTIONS(4790),
    [anon_sym_orderby] = ACTIONS(4790),
    [anon_sym_ascending] = ACTIONS(4790),
    [anon_sym_descending] = ACTIONS(4790),
    [anon_sym_group] = ACTIONS(4790),
    [anon_sym_by] = ACTIONS(4790),
    [anon_sym_select] = ACTIONS(4790),
    [aux_sym_preproc_if_token1] = ACTIONS(4794),
    [aux_sym_preproc_if_token3] = ACTIONS(4794),
    [aux_sym_preproc_else_token1] = ACTIONS(4794),
    [aux_sym_preproc_elif_token1] = ACTIONS(4794),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3199] = {
    [sym_preproc_region] = STATE(3199),
    [sym_preproc_endregion] = STATE(3199),
    [sym_preproc_line] = STATE(3199),
    [sym_preproc_pragma] = STATE(3199),
    [sym_preproc_nullable] = STATE(3199),
    [sym_preproc_error] = STATE(3199),
    [sym_preproc_warning] = STATE(3199),
    [sym_preproc_define] = STATE(3199),
    [sym_preproc_undef] = STATE(3199),
    [sym__identifier_token] = ACTIONS(4453),
    [anon_sym_alias] = ACTIONS(4453),
    [anon_sym_global] = ACTIONS(4453),
    [anon_sym_LBRACK] = ACTIONS(4455),
    [anon_sym_COLON] = ACTIONS(4455),
    [anon_sym_COMMA] = ACTIONS(4455),
    [anon_sym_LPAREN] = ACTIONS(4455),
    [anon_sym_RPAREN] = ACTIONS(4455),
    [anon_sym_LBRACE] = ACTIONS(4455),
    [anon_sym_RBRACE] = ACTIONS(4455),
    [anon_sym_file] = ACTIONS(4453),
    [anon_sym_LT] = ACTIONS(4453),
    [anon_sym_GT] = ACTIONS(4453),
    [anon_sym_where] = ACTIONS(4453),
    [anon_sym_QMARK] = ACTIONS(4453),
    [anon_sym_notnull] = ACTIONS(4453),
    [anon_sym_unmanaged] = ACTIONS(4453),
    [anon_sym_BANG] = ACTIONS(4453),
    [anon_sym_PLUS_PLUS] = ACTIONS(4455),
    [anon_sym_DASH_DASH] = ACTIONS(4455),
    [anon_sym_PLUS] = ACTIONS(4453),
    [anon_sym_DASH] = ACTIONS(4453),
    [anon_sym_STAR] = ACTIONS(4455),
    [anon_sym_SLASH] = ACTIONS(4453),
    [anon_sym_PERCENT] = ACTIONS(4455),
    [anon_sym_CARET] = ACTIONS(4455),
    [anon_sym_PIPE] = ACTIONS(4453),
    [anon_sym_AMP] = ACTIONS(4453),
    [anon_sym_LT_LT] = ACTIONS(4455),
    [anon_sym_GT_GT] = ACTIONS(4453),
    [anon_sym_GT_GT_GT] = ACTIONS(4455),
    [anon_sym_EQ_EQ] = ACTIONS(4455),
    [anon_sym_BANG_EQ] = ACTIONS(4455),
    [anon_sym_GT_EQ] = ACTIONS(4455),
    [anon_sym_LT_EQ] = ACTIONS(4455),
    [anon_sym_DOT] = ACTIONS(4796),
    [anon_sym_scoped] = ACTIONS(4453),
    [anon_sym_var] = ACTIONS(4453),
    [anon_sym_yield] = ACTIONS(4453),
    [anon_sym_switch] = ACTIONS(4453),
    [anon_sym_when] = ACTIONS(4453),
    [sym_discard] = ACTIONS(4453),
    [anon_sym_DOT_DOT] = ACTIONS(4455),
    [anon_sym_and] = ACTIONS(4453),
    [anon_sym_or] = ACTIONS(4453),
    [anon_sym_AMP_AMP] = ACTIONS(4455),
    [anon_sym_PIPE_PIPE] = ACTIONS(4455),
    [anon_sym_QMARK_QMARK] = ACTIONS(4455),
    [anon_sym_from] = ACTIONS(4453),
    [anon_sym_into] = ACTIONS(4453),
    [anon_sym_join] = ACTIONS(4453),
    [anon_sym_on] = ACTIONS(4453),
    [anon_sym_equals] = ACTIONS(4453),
    [anon_sym_let] = ACTIONS(4453),
    [anon_sym_orderby] = ACTIONS(4453),
    [anon_sym_ascending] = ACTIONS(4453),
    [anon_sym_descending] = ACTIONS(4453),
    [anon_sym_group] = ACTIONS(4453),
    [anon_sym_by] = ACTIONS(4453),
    [anon_sym_select] = ACTIONS(4453),
    [anon_sym_as] = ACTIONS(4453),
    [anon_sym_is] = ACTIONS(4453),
    [anon_sym_DASH_GT] = ACTIONS(4455),
    [anon_sym_with] = ACTIONS(4453),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3200] = {
    [sym_preproc_region] = STATE(3200),
    [sym_preproc_endregion] = STATE(3200),
    [sym_preproc_line] = STATE(3200),
    [sym_preproc_pragma] = STATE(3200),
    [sym_preproc_nullable] = STATE(3200),
    [sym_preproc_error] = STATE(3200),
    [sym_preproc_warning] = STATE(3200),
    [sym_preproc_define] = STATE(3200),
    [sym_preproc_undef] = STATE(3200),
    [sym__identifier_token] = ACTIONS(4587),
    [anon_sym_alias] = ACTIONS(4587),
    [anon_sym_global] = ACTIONS(4587),
    [anon_sym_LBRACK] = ACTIONS(4589),
    [anon_sym_COLON] = ACTIONS(4589),
    [anon_sym_COMMA] = ACTIONS(4589),
    [anon_sym_LPAREN] = ACTIONS(4589),
    [anon_sym_LBRACE] = ACTIONS(4589),
    [anon_sym_file] = ACTIONS(4587),
    [anon_sym_LT] = ACTIONS(4587),
    [anon_sym_GT] = ACTIONS(4587),
    [anon_sym_where] = ACTIONS(4587),
    [anon_sym_QMARK] = ACTIONS(4587),
    [anon_sym_notnull] = ACTIONS(4587),
    [anon_sym_unmanaged] = ACTIONS(4587),
    [anon_sym_BANG] = ACTIONS(4587),
    [anon_sym_PLUS_PLUS] = ACTIONS(4589),
    [anon_sym_DASH_DASH] = ACTIONS(4589),
    [anon_sym_PLUS] = ACTIONS(4587),
    [anon_sym_DASH] = ACTIONS(4587),
    [anon_sym_STAR] = ACTIONS(4589),
    [anon_sym_SLASH] = ACTIONS(4587),
    [anon_sym_PERCENT] = ACTIONS(4589),
    [anon_sym_CARET] = ACTIONS(4589),
    [anon_sym_PIPE] = ACTIONS(4587),
    [anon_sym_AMP] = ACTIONS(4587),
    [anon_sym_LT_LT] = ACTIONS(4589),
    [anon_sym_GT_GT] = ACTIONS(4587),
    [anon_sym_GT_GT_GT] = ACTIONS(4589),
    [anon_sym_EQ_EQ] = ACTIONS(4589),
    [anon_sym_BANG_EQ] = ACTIONS(4589),
    [anon_sym_GT_EQ] = ACTIONS(4589),
    [anon_sym_LT_EQ] = ACTIONS(4589),
    [anon_sym_DOT] = ACTIONS(4587),
    [anon_sym_scoped] = ACTIONS(4587),
    [anon_sym_EQ_GT] = ACTIONS(4591),
    [anon_sym_var] = ACTIONS(4587),
    [anon_sym_yield] = ACTIONS(4587),
    [anon_sym_switch] = ACTIONS(4587),
    [anon_sym_when] = ACTIONS(4587),
    [sym_discard] = ACTIONS(4587),
    [anon_sym_DOT_DOT] = ACTIONS(4589),
    [anon_sym_and] = ACTIONS(4587),
    [anon_sym_or] = ACTIONS(4587),
    [anon_sym_AMP_AMP] = ACTIONS(4589),
    [anon_sym_PIPE_PIPE] = ACTIONS(4589),
    [anon_sym_QMARK_QMARK] = ACTIONS(4589),
    [anon_sym_from] = ACTIONS(4587),
    [anon_sym_into] = ACTIONS(4587),
    [anon_sym_join] = ACTIONS(4587),
    [anon_sym_on] = ACTIONS(4587),
    [anon_sym_equals] = ACTIONS(4587),
    [anon_sym_let] = ACTIONS(4587),
    [anon_sym_orderby] = ACTIONS(4587),
    [anon_sym_ascending] = ACTIONS(4587),
    [anon_sym_descending] = ACTIONS(4587),
    [anon_sym_group] = ACTIONS(4587),
    [anon_sym_by] = ACTIONS(4587),
    [anon_sym_select] = ACTIONS(4587),
    [anon_sym_as] = ACTIONS(4587),
    [anon_sym_is] = ACTIONS(4587),
    [anon_sym_DASH_GT] = ACTIONS(4589),
    [anon_sym_with] = ACTIONS(4587),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4589),
  },
  [3201] = {
    [sym_preproc_region] = STATE(3201),
    [sym_preproc_endregion] = STATE(3201),
    [sym_preproc_line] = STATE(3201),
    [sym_preproc_pragma] = STATE(3201),
    [sym_preproc_nullable] = STATE(3201),
    [sym_preproc_error] = STATE(3201),
    [sym_preproc_warning] = STATE(3201),
    [sym_preproc_define] = STATE(3201),
    [sym_preproc_undef] = STATE(3201),
    [sym__identifier_token] = ACTIONS(4798),
    [anon_sym_extern] = ACTIONS(4798),
    [anon_sym_alias] = ACTIONS(4798),
    [anon_sym_global] = ACTIONS(4798),
    [anon_sym_using] = ACTIONS(4798),
    [anon_sym_unsafe] = ACTIONS(4798),
    [anon_sym_EQ] = ACTIONS(4800),
    [anon_sym_static] = ACTIONS(4798),
    [anon_sym_LBRACK] = ACTIONS(4800),
    [anon_sym_LPAREN] = ACTIONS(4800),
    [anon_sym_event] = ACTIONS(4798),
    [anon_sym_namespace] = ACTIONS(4798),
    [anon_sym_class] = ACTIONS(4798),
    [anon_sym_ref] = ACTIONS(4798),
    [anon_sym_struct] = ACTIONS(4798),
    [anon_sym_enum] = ACTIONS(4798),
    [anon_sym_RBRACE] = ACTIONS(4800),
    [anon_sym_interface] = ACTIONS(4798),
    [anon_sym_delegate] = ACTIONS(4798),
    [anon_sym_record] = ACTIONS(4798),
    [anon_sym_abstract] = ACTIONS(4798),
    [anon_sym_async] = ACTIONS(4798),
    [anon_sym_const] = ACTIONS(4798),
    [anon_sym_file] = ACTIONS(4798),
    [anon_sym_fixed] = ACTIONS(4798),
    [anon_sym_internal] = ACTIONS(4798),
    [anon_sym_new] = ACTIONS(4798),
    [anon_sym_override] = ACTIONS(4798),
    [anon_sym_partial] = ACTIONS(4798),
    [anon_sym_private] = ACTIONS(4798),
    [anon_sym_protected] = ACTIONS(4798),
    [anon_sym_public] = ACTIONS(4798),
    [anon_sym_readonly] = ACTIONS(4798),
    [anon_sym_required] = ACTIONS(4798),
    [anon_sym_sealed] = ACTIONS(4798),
    [anon_sym_virtual] = ACTIONS(4798),
    [anon_sym_volatile] = ACTIONS(4798),
    [anon_sym_where] = ACTIONS(4798),
    [anon_sym_notnull] = ACTIONS(4798),
    [anon_sym_unmanaged] = ACTIONS(4798),
    [anon_sym_TILDE] = ACTIONS(4800),
    [anon_sym_implicit] = ACTIONS(4798),
    [anon_sym_explicit] = ACTIONS(4798),
    [anon_sym_scoped] = ACTIONS(4798),
    [anon_sym_var] = ACTIONS(4798),
    [sym_predefined_type] = ACTIONS(4798),
    [anon_sym_yield] = ACTIONS(4798),
    [anon_sym_when] = ACTIONS(4798),
    [anon_sym_from] = ACTIONS(4798),
    [anon_sym_into] = ACTIONS(4798),
    [anon_sym_join] = ACTIONS(4798),
    [anon_sym_on] = ACTIONS(4798),
    [anon_sym_equals] = ACTIONS(4798),
    [anon_sym_let] = ACTIONS(4798),
    [anon_sym_orderby] = ACTIONS(4798),
    [anon_sym_ascending] = ACTIONS(4798),
    [anon_sym_descending] = ACTIONS(4798),
    [anon_sym_group] = ACTIONS(4798),
    [anon_sym_by] = ACTIONS(4798),
    [anon_sym_select] = ACTIONS(4798),
    [aux_sym_preproc_if_token1] = ACTIONS(4800),
    [aux_sym_preproc_if_token3] = ACTIONS(4800),
    [aux_sym_preproc_else_token1] = ACTIONS(4800),
    [aux_sym_preproc_elif_token1] = ACTIONS(4800),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3202] = {
    [sym_preproc_region] = STATE(3202),
    [sym_preproc_endregion] = STATE(3202),
    [sym_preproc_line] = STATE(3202),
    [sym_preproc_pragma] = STATE(3202),
    [sym_preproc_nullable] = STATE(3202),
    [sym_preproc_error] = STATE(3202),
    [sym_preproc_warning] = STATE(3202),
    [sym_preproc_define] = STATE(3202),
    [sym_preproc_undef] = STATE(3202),
    [sym__identifier_token] = ACTIONS(4802),
    [anon_sym_extern] = ACTIONS(4802),
    [anon_sym_alias] = ACTIONS(4802),
    [anon_sym_global] = ACTIONS(4802),
    [anon_sym_using] = ACTIONS(4802),
    [anon_sym_unsafe] = ACTIONS(4802),
    [anon_sym_EQ] = ACTIONS(4804),
    [anon_sym_static] = ACTIONS(4802),
    [anon_sym_LBRACK] = ACTIONS(4804),
    [anon_sym_LPAREN] = ACTIONS(4804),
    [anon_sym_event] = ACTIONS(4802),
    [anon_sym_namespace] = ACTIONS(4802),
    [anon_sym_class] = ACTIONS(4802),
    [anon_sym_ref] = ACTIONS(4802),
    [anon_sym_struct] = ACTIONS(4802),
    [anon_sym_enum] = ACTIONS(4802),
    [anon_sym_RBRACE] = ACTIONS(4804),
    [anon_sym_interface] = ACTIONS(4802),
    [anon_sym_delegate] = ACTIONS(4802),
    [anon_sym_record] = ACTIONS(4802),
    [anon_sym_abstract] = ACTIONS(4802),
    [anon_sym_async] = ACTIONS(4802),
    [anon_sym_const] = ACTIONS(4802),
    [anon_sym_file] = ACTIONS(4802),
    [anon_sym_fixed] = ACTIONS(4802),
    [anon_sym_internal] = ACTIONS(4802),
    [anon_sym_new] = ACTIONS(4802),
    [anon_sym_override] = ACTIONS(4802),
    [anon_sym_partial] = ACTIONS(4802),
    [anon_sym_private] = ACTIONS(4802),
    [anon_sym_protected] = ACTIONS(4802),
    [anon_sym_public] = ACTIONS(4802),
    [anon_sym_readonly] = ACTIONS(4802),
    [anon_sym_required] = ACTIONS(4802),
    [anon_sym_sealed] = ACTIONS(4802),
    [anon_sym_virtual] = ACTIONS(4802),
    [anon_sym_volatile] = ACTIONS(4802),
    [anon_sym_where] = ACTIONS(4802),
    [anon_sym_notnull] = ACTIONS(4802),
    [anon_sym_unmanaged] = ACTIONS(4802),
    [anon_sym_TILDE] = ACTIONS(4804),
    [anon_sym_implicit] = ACTIONS(4802),
    [anon_sym_explicit] = ACTIONS(4802),
    [anon_sym_scoped] = ACTIONS(4802),
    [anon_sym_var] = ACTIONS(4802),
    [sym_predefined_type] = ACTIONS(4802),
    [anon_sym_yield] = ACTIONS(4802),
    [anon_sym_when] = ACTIONS(4802),
    [anon_sym_from] = ACTIONS(4802),
    [anon_sym_into] = ACTIONS(4802),
    [anon_sym_join] = ACTIONS(4802),
    [anon_sym_on] = ACTIONS(4802),
    [anon_sym_equals] = ACTIONS(4802),
    [anon_sym_let] = ACTIONS(4802),
    [anon_sym_orderby] = ACTIONS(4802),
    [anon_sym_ascending] = ACTIONS(4802),
    [anon_sym_descending] = ACTIONS(4802),
    [anon_sym_group] = ACTIONS(4802),
    [anon_sym_by] = ACTIONS(4802),
    [anon_sym_select] = ACTIONS(4802),
    [aux_sym_preproc_if_token1] = ACTIONS(4804),
    [aux_sym_preproc_if_token3] = ACTIONS(4804),
    [aux_sym_preproc_else_token1] = ACTIONS(4804),
    [aux_sym_preproc_elif_token1] = ACTIONS(4804),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3203] = {
    [sym_type_argument_list] = STATE(3328),
    [sym_preproc_region] = STATE(3203),
    [sym_preproc_endregion] = STATE(3203),
    [sym_preproc_line] = STATE(3203),
    [sym_preproc_pragma] = STATE(3203),
    [sym_preproc_nullable] = STATE(3203),
    [sym_preproc_error] = STATE(3203),
    [sym_preproc_warning] = STATE(3203),
    [sym_preproc_define] = STATE(3203),
    [sym_preproc_undef] = STATE(3203),
    [sym__identifier_token] = ACTIONS(4138),
    [anon_sym_alias] = ACTIONS(4138),
    [anon_sym_global] = ACTIONS(4138),
    [anon_sym_LBRACK] = ACTIONS(4140),
    [anon_sym_COLON] = ACTIONS(4140),
    [anon_sym_COMMA] = ACTIONS(4140),
    [anon_sym_LPAREN] = ACTIONS(4140),
    [anon_sym_LBRACE] = ACTIONS(4140),
    [anon_sym_file] = ACTIONS(4138),
    [anon_sym_LT] = ACTIONS(4762),
    [anon_sym_GT] = ACTIONS(4138),
    [anon_sym_where] = ACTIONS(4138),
    [anon_sym_QMARK] = ACTIONS(4138),
    [anon_sym_notnull] = ACTIONS(4138),
    [anon_sym_unmanaged] = ACTIONS(4138),
    [anon_sym_BANG] = ACTIONS(4138),
    [anon_sym_PLUS_PLUS] = ACTIONS(4140),
    [anon_sym_DASH_DASH] = ACTIONS(4140),
    [anon_sym_PLUS] = ACTIONS(4138),
    [anon_sym_DASH] = ACTIONS(4138),
    [anon_sym_STAR] = ACTIONS(4140),
    [anon_sym_SLASH] = ACTIONS(4138),
    [anon_sym_PERCENT] = ACTIONS(4140),
    [anon_sym_CARET] = ACTIONS(4140),
    [anon_sym_PIPE] = ACTIONS(4138),
    [anon_sym_AMP] = ACTIONS(4138),
    [anon_sym_LT_LT] = ACTIONS(4140),
    [anon_sym_GT_GT] = ACTIONS(4138),
    [anon_sym_GT_GT_GT] = ACTIONS(4140),
    [anon_sym_EQ_EQ] = ACTIONS(4140),
    [anon_sym_BANG_EQ] = ACTIONS(4140),
    [anon_sym_GT_EQ] = ACTIONS(4140),
    [anon_sym_LT_EQ] = ACTIONS(4140),
    [anon_sym_DOT] = ACTIONS(4138),
    [anon_sym_scoped] = ACTIONS(4138),
    [anon_sym_var] = ACTIONS(4138),
    [anon_sym_yield] = ACTIONS(4138),
    [anon_sym_switch] = ACTIONS(4138),
    [anon_sym_when] = ACTIONS(4138),
    [sym_discard] = ACTIONS(4138),
    [anon_sym_DOT_DOT] = ACTIONS(4140),
    [anon_sym_and] = ACTIONS(4138),
    [anon_sym_or] = ACTIONS(4138),
    [anon_sym_AMP_AMP] = ACTIONS(4140),
    [anon_sym_PIPE_PIPE] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK] = ACTIONS(4140),
    [anon_sym_from] = ACTIONS(4138),
    [anon_sym_into] = ACTIONS(4138),
    [anon_sym_join] = ACTIONS(4138),
    [anon_sym_on] = ACTIONS(4138),
    [anon_sym_equals] = ACTIONS(4138),
    [anon_sym_let] = ACTIONS(4138),
    [anon_sym_orderby] = ACTIONS(4138),
    [anon_sym_ascending] = ACTIONS(4138),
    [anon_sym_descending] = ACTIONS(4138),
    [anon_sym_group] = ACTIONS(4138),
    [anon_sym_by] = ACTIONS(4138),
    [anon_sym_select] = ACTIONS(4138),
    [anon_sym_as] = ACTIONS(4138),
    [anon_sym_is] = ACTIONS(4138),
    [anon_sym_DASH_GT] = ACTIONS(4140),
    [anon_sym_with] = ACTIONS(4138),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4140),
  },
  [3204] = {
    [sym__variable_designation] = STATE(4614),
    [sym_parenthesized_variable_designation] = STATE(4748),
    [sym_identifier] = STATE(4548),
    [sym__reserved_identifier] = STATE(2928),
    [sym_preproc_region] = STATE(3204),
    [sym_preproc_endregion] = STATE(3204),
    [sym_preproc_line] = STATE(3204),
    [sym_preproc_pragma] = STATE(3204),
    [sym_preproc_nullable] = STATE(3204),
    [sym_preproc_error] = STATE(3204),
    [sym_preproc_warning] = STATE(3204),
    [sym_preproc_define] = STATE(3204),
    [sym_preproc_undef] = STATE(3204),
    [sym__identifier_token] = ACTIONS(4536),
    [anon_sym_alias] = ACTIONS(4538),
    [anon_sym_global] = ACTIONS(4538),
    [anon_sym_LBRACK] = ACTIONS(4437),
    [anon_sym_COMMA] = ACTIONS(4437),
    [anon_sym_LPAREN] = ACTIONS(4437),
    [anon_sym_file] = ACTIONS(4538),
    [anon_sym_LT] = ACTIONS(4439),
    [anon_sym_GT] = ACTIONS(4439),
    [anon_sym_where] = ACTIONS(4439),
    [anon_sym_QMARK] = ACTIONS(4439),
    [anon_sym_notnull] = ACTIONS(4538),
    [anon_sym_unmanaged] = ACTIONS(4538),
    [anon_sym_BANG] = ACTIONS(4439),
    [anon_sym_PLUS_PLUS] = ACTIONS(4437),
    [anon_sym_DASH_DASH] = ACTIONS(4437),
    [anon_sym_PLUS] = ACTIONS(4439),
    [anon_sym_DASH] = ACTIONS(4439),
    [anon_sym_STAR] = ACTIONS(4437),
    [anon_sym_SLASH] = ACTIONS(4439),
    [anon_sym_PERCENT] = ACTIONS(4437),
    [anon_sym_CARET] = ACTIONS(4437),
    [anon_sym_PIPE] = ACTIONS(4439),
    [anon_sym_AMP] = ACTIONS(4439),
    [anon_sym_LT_LT] = ACTIONS(4437),
    [anon_sym_GT_GT] = ACTIONS(4439),
    [anon_sym_GT_GT_GT] = ACTIONS(4437),
    [anon_sym_EQ_EQ] = ACTIONS(4437),
    [anon_sym_BANG_EQ] = ACTIONS(4437),
    [anon_sym_GT_EQ] = ACTIONS(4437),
    [anon_sym_LT_EQ] = ACTIONS(4437),
    [anon_sym_DOT] = ACTIONS(4439),
    [anon_sym_scoped] = ACTIONS(4538),
    [anon_sym_var] = ACTIONS(4538),
    [anon_sym_yield] = ACTIONS(4538),
    [anon_sym_switch] = ACTIONS(4439),
    [anon_sym_when] = ACTIONS(4538),
    [sym_discard] = ACTIONS(4717),
    [anon_sym_DOT_DOT] = ACTIONS(4437),
    [anon_sym_and] = ACTIONS(4439),
    [anon_sym_or] = ACTIONS(4439),
    [anon_sym_AMP_AMP] = ACTIONS(4437),
    [anon_sym_PIPE_PIPE] = ACTIONS(4437),
    [anon_sym_QMARK_QMARK] = ACTIONS(4437),
    [anon_sym_from] = ACTIONS(4439),
    [anon_sym_into] = ACTIONS(4538),
    [anon_sym_join] = ACTIONS(4439),
    [anon_sym_on] = ACTIONS(4538),
    [anon_sym_equals] = ACTIONS(4538),
    [anon_sym_let] = ACTIONS(4439),
    [anon_sym_orderby] = ACTIONS(4439),
    [anon_sym_ascending] = ACTIONS(4439),
    [anon_sym_descending] = ACTIONS(4439),
    [anon_sym_group] = ACTIONS(4439),
    [anon_sym_by] = ACTIONS(4538),
    [anon_sym_select] = ACTIONS(4439),
    [anon_sym_as] = ACTIONS(4439),
    [anon_sym_is] = ACTIONS(4439),
    [anon_sym_DASH_GT] = ACTIONS(4437),
    [anon_sym_with] = ACTIONS(4439),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3205] = {
    [sym_preproc_region] = STATE(3205),
    [sym_preproc_endregion] = STATE(3205),
    [sym_preproc_line] = STATE(3205),
    [sym_preproc_pragma] = STATE(3205),
    [sym_preproc_nullable] = STATE(3205),
    [sym_preproc_error] = STATE(3205),
    [sym_preproc_warning] = STATE(3205),
    [sym_preproc_define] = STATE(3205),
    [sym_preproc_undef] = STATE(3205),
    [anon_sym_SEMI] = ACTIONS(4707),
    [anon_sym_EQ] = ACTIONS(4709),
    [anon_sym_LBRACK] = ACTIONS(4707),
    [anon_sym_COLON] = ACTIONS(4707),
    [anon_sym_COMMA] = ACTIONS(4707),
    [anon_sym_RBRACK] = ACTIONS(4707),
    [anon_sym_LPAREN] = ACTIONS(4707),
    [anon_sym_RPAREN] = ACTIONS(4707),
    [anon_sym_RBRACE] = ACTIONS(4707),
    [anon_sym_LT] = ACTIONS(4709),
    [anon_sym_GT] = ACTIONS(4709),
    [anon_sym_in] = ACTIONS(4709),
    [anon_sym_QMARK] = ACTIONS(4709),
    [anon_sym_BANG] = ACTIONS(4709),
    [anon_sym_PLUS_PLUS] = ACTIONS(4707),
    [anon_sym_DASH_DASH] = ACTIONS(4707),
    [anon_sym_PLUS] = ACTIONS(4709),
    [anon_sym_DASH] = ACTIONS(4709),
    [anon_sym_STAR] = ACTIONS(4709),
    [anon_sym_SLASH] = ACTIONS(4709),
    [anon_sym_PERCENT] = ACTIONS(4709),
    [anon_sym_CARET] = ACTIONS(4709),
    [anon_sym_PIPE] = ACTIONS(4709),
    [anon_sym_AMP] = ACTIONS(4709),
    [anon_sym_LT_LT] = ACTIONS(4709),
    [anon_sym_GT_GT] = ACTIONS(4709),
    [anon_sym_GT_GT_GT] = ACTIONS(4709),
    [anon_sym_EQ_EQ] = ACTIONS(4707),
    [anon_sym_BANG_EQ] = ACTIONS(4707),
    [anon_sym_GT_EQ] = ACTIONS(4707),
    [anon_sym_LT_EQ] = ACTIONS(4707),
    [anon_sym_DOT] = ACTIONS(4709),
    [anon_sym_EQ_GT] = ACTIONS(4707),
    [anon_sym_switch] = ACTIONS(4707),
    [anon_sym_when] = ACTIONS(4707),
    [anon_sym_DOT_DOT] = ACTIONS(4707),
    [anon_sym_and] = ACTIONS(4707),
    [anon_sym_or] = ACTIONS(4707),
    [anon_sym_PLUS_EQ] = ACTIONS(4707),
    [anon_sym_DASH_EQ] = ACTIONS(4707),
    [anon_sym_STAR_EQ] = ACTIONS(4707),
    [anon_sym_SLASH_EQ] = ACTIONS(4707),
    [anon_sym_PERCENT_EQ] = ACTIONS(4707),
    [anon_sym_AMP_EQ] = ACTIONS(4707),
    [anon_sym_CARET_EQ] = ACTIONS(4707),
    [anon_sym_PIPE_EQ] = ACTIONS(4707),
    [anon_sym_LT_LT_EQ] = ACTIONS(4707),
    [anon_sym_GT_GT_EQ] = ACTIONS(4707),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4707),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4707),
    [anon_sym_AMP_AMP] = ACTIONS(4707),
    [anon_sym_PIPE_PIPE] = ACTIONS(4707),
    [anon_sym_QMARK_QMARK] = ACTIONS(4709),
    [anon_sym_into] = ACTIONS(4707),
    [anon_sym_on] = ACTIONS(4707),
    [anon_sym_equals] = ACTIONS(4707),
    [anon_sym_by] = ACTIONS(4707),
    [anon_sym_as] = ACTIONS(4707),
    [anon_sym_is] = ACTIONS(4707),
    [anon_sym_DASH_GT] = ACTIONS(4707),
    [anon_sym_with] = ACTIONS(4707),
    [aux_sym_preproc_if_token3] = ACTIONS(4707),
    [aux_sym_preproc_else_token1] = ACTIONS(4707),
    [aux_sym_preproc_elif_token1] = ACTIONS(4707),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3206] = {
    [sym_preproc_region] = STATE(3206),
    [sym_preproc_endregion] = STATE(3206),
    [sym_preproc_line] = STATE(3206),
    [sym_preproc_pragma] = STATE(3206),
    [sym_preproc_nullable] = STATE(3206),
    [sym_preproc_error] = STATE(3206),
    [sym_preproc_warning] = STATE(3206),
    [sym_preproc_define] = STATE(3206),
    [sym_preproc_undef] = STATE(3206),
    [anon_sym_SEMI] = ACTIONS(4806),
    [anon_sym_EQ] = ACTIONS(4162),
    [anon_sym_LBRACK] = ACTIONS(4808),
    [anon_sym_COLON] = ACTIONS(4806),
    [anon_sym_COMMA] = ACTIONS(4806),
    [anon_sym_RBRACK] = ACTIONS(4806),
    [anon_sym_LPAREN] = ACTIONS(4808),
    [anon_sym_RPAREN] = ACTIONS(4806),
    [anon_sym_RBRACE] = ACTIONS(4806),
    [anon_sym_LT] = ACTIONS(4811),
    [anon_sym_GT] = ACTIONS(4811),
    [anon_sym_in] = ACTIONS(4814),
    [anon_sym_QMARK] = ACTIONS(4811),
    [anon_sym_BANG] = ACTIONS(4811),
    [anon_sym_PLUS_PLUS] = ACTIONS(4808),
    [anon_sym_DASH_DASH] = ACTIONS(4808),
    [anon_sym_PLUS] = ACTIONS(4811),
    [anon_sym_DASH] = ACTIONS(4811),
    [anon_sym_STAR] = ACTIONS(4811),
    [anon_sym_SLASH] = ACTIONS(4811),
    [anon_sym_PERCENT] = ACTIONS(4811),
    [anon_sym_CARET] = ACTIONS(4811),
    [anon_sym_PIPE] = ACTIONS(4811),
    [anon_sym_AMP] = ACTIONS(4811),
    [anon_sym_LT_LT] = ACTIONS(4811),
    [anon_sym_GT_GT] = ACTIONS(4811),
    [anon_sym_GT_GT_GT] = ACTIONS(4811),
    [anon_sym_EQ_EQ] = ACTIONS(4808),
    [anon_sym_BANG_EQ] = ACTIONS(4808),
    [anon_sym_GT_EQ] = ACTIONS(4808),
    [anon_sym_LT_EQ] = ACTIONS(4808),
    [anon_sym_DOT] = ACTIONS(4811),
    [anon_sym_EQ_GT] = ACTIONS(4806),
    [anon_sym_switch] = ACTIONS(4808),
    [anon_sym_when] = ACTIONS(4806),
    [anon_sym_DOT_DOT] = ACTIONS(4808),
    [anon_sym_and] = ACTIONS(4806),
    [anon_sym_or] = ACTIONS(4806),
    [anon_sym_PLUS_EQ] = ACTIONS(4177),
    [anon_sym_DASH_EQ] = ACTIONS(4177),
    [anon_sym_STAR_EQ] = ACTIONS(4177),
    [anon_sym_SLASH_EQ] = ACTIONS(4177),
    [anon_sym_PERCENT_EQ] = ACTIONS(4177),
    [anon_sym_AMP_EQ] = ACTIONS(4177),
    [anon_sym_CARET_EQ] = ACTIONS(4177),
    [anon_sym_PIPE_EQ] = ACTIONS(4177),
    [anon_sym_LT_LT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4177),
    [anon_sym_AMP_AMP] = ACTIONS(4808),
    [anon_sym_PIPE_PIPE] = ACTIONS(4808),
    [anon_sym_QMARK_QMARK] = ACTIONS(4811),
    [anon_sym_into] = ACTIONS(4806),
    [anon_sym_on] = ACTIONS(4806),
    [anon_sym_equals] = ACTIONS(4806),
    [anon_sym_by] = ACTIONS(4806),
    [anon_sym_as] = ACTIONS(4808),
    [anon_sym_is] = ACTIONS(4808),
    [anon_sym_DASH_GT] = ACTIONS(4808),
    [anon_sym_with] = ACTIONS(4808),
    [aux_sym_preproc_if_token3] = ACTIONS(4806),
    [aux_sym_preproc_else_token1] = ACTIONS(4806),
    [aux_sym_preproc_elif_token1] = ACTIONS(4806),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3207] = {
    [sym__variable_designation] = STATE(4167),
    [sym_parenthesized_variable_designation] = STATE(4153),
    [sym_identifier] = STATE(4156),
    [sym__reserved_identifier] = STATE(3911),
    [sym_preproc_region] = STATE(3207),
    [sym_preproc_endregion] = STATE(3207),
    [sym_preproc_line] = STATE(3207),
    [sym_preproc_pragma] = STATE(3207),
    [sym_preproc_nullable] = STATE(3207),
    [sym_preproc_error] = STATE(3207),
    [sym_preproc_warning] = STATE(3207),
    [sym_preproc_define] = STATE(3207),
    [sym_preproc_undef] = STATE(3207),
    [sym__identifier_token] = ACTIONS(4248),
    [anon_sym_alias] = ACTIONS(4250),
    [anon_sym_global] = ACTIONS(4250),
    [anon_sym_LBRACK] = ACTIONS(4399),
    [anon_sym_LPAREN] = ACTIONS(4399),
    [anon_sym_file] = ACTIONS(4250),
    [anon_sym_LT] = ACTIONS(4401),
    [anon_sym_GT] = ACTIONS(4401),
    [anon_sym_in] = ACTIONS(4401),
    [anon_sym_where] = ACTIONS(4250),
    [anon_sym_QMARK] = ACTIONS(4401),
    [anon_sym_notnull] = ACTIONS(4250),
    [anon_sym_unmanaged] = ACTIONS(4250),
    [anon_sym_BANG] = ACTIONS(4401),
    [anon_sym_PLUS_PLUS] = ACTIONS(4399),
    [anon_sym_DASH_DASH] = ACTIONS(4399),
    [anon_sym_PLUS] = ACTIONS(4401),
    [anon_sym_DASH] = ACTIONS(4401),
    [anon_sym_STAR] = ACTIONS(4399),
    [anon_sym_SLASH] = ACTIONS(4401),
    [anon_sym_PERCENT] = ACTIONS(4399),
    [anon_sym_CARET] = ACTIONS(4399),
    [anon_sym_PIPE] = ACTIONS(4401),
    [anon_sym_AMP] = ACTIONS(4401),
    [anon_sym_LT_LT] = ACTIONS(4399),
    [anon_sym_GT_GT] = ACTIONS(4401),
    [anon_sym_GT_GT_GT] = ACTIONS(4399),
    [anon_sym_EQ_EQ] = ACTIONS(4399),
    [anon_sym_BANG_EQ] = ACTIONS(4399),
    [anon_sym_GT_EQ] = ACTIONS(4399),
    [anon_sym_LT_EQ] = ACTIONS(4399),
    [anon_sym_DOT] = ACTIONS(4401),
    [anon_sym_scoped] = ACTIONS(4250),
    [anon_sym_var] = ACTIONS(4250),
    [anon_sym_yield] = ACTIONS(4250),
    [anon_sym_switch] = ACTIONS(4401),
    [anon_sym_when] = ACTIONS(4250),
    [sym_discard] = ACTIONS(4359),
    [anon_sym_DOT_DOT] = ACTIONS(4399),
    [anon_sym_and] = ACTIONS(4401),
    [anon_sym_or] = ACTIONS(4401),
    [anon_sym_AMP_AMP] = ACTIONS(4399),
    [anon_sym_PIPE_PIPE] = ACTIONS(4399),
    [anon_sym_QMARK_QMARK] = ACTIONS(4399),
    [anon_sym_from] = ACTIONS(4250),
    [anon_sym_into] = ACTIONS(4250),
    [anon_sym_join] = ACTIONS(4250),
    [anon_sym_on] = ACTIONS(4250),
    [anon_sym_equals] = ACTIONS(4250),
    [anon_sym_let] = ACTIONS(4250),
    [anon_sym_orderby] = ACTIONS(4250),
    [anon_sym_ascending] = ACTIONS(4250),
    [anon_sym_descending] = ACTIONS(4250),
    [anon_sym_group] = ACTIONS(4250),
    [anon_sym_by] = ACTIONS(4250),
    [anon_sym_select] = ACTIONS(4250),
    [anon_sym_as] = ACTIONS(4401),
    [anon_sym_is] = ACTIONS(4401),
    [anon_sym_DASH_GT] = ACTIONS(4399),
    [anon_sym_with] = ACTIONS(4401),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3208] = {
    [sym_preproc_region] = STATE(3208),
    [sym_preproc_endregion] = STATE(3208),
    [sym_preproc_line] = STATE(3208),
    [sym_preproc_pragma] = STATE(3208),
    [sym_preproc_nullable] = STATE(3208),
    [sym_preproc_error] = STATE(3208),
    [sym_preproc_warning] = STATE(3208),
    [sym_preproc_define] = STATE(3208),
    [sym_preproc_undef] = STATE(3208),
    [anon_sym_SEMI] = ACTIONS(4140),
    [anon_sym_EQ] = ACTIONS(4138),
    [anon_sym_LBRACK] = ACTIONS(4140),
    [anon_sym_COLON] = ACTIONS(4140),
    [anon_sym_COMMA] = ACTIONS(4140),
    [anon_sym_RBRACK] = ACTIONS(4140),
    [anon_sym_LPAREN] = ACTIONS(4140),
    [anon_sym_RPAREN] = ACTIONS(4140),
    [anon_sym_RBRACE] = ACTIONS(4140),
    [anon_sym_LT] = ACTIONS(4138),
    [anon_sym_GT] = ACTIONS(4138),
    [anon_sym_in] = ACTIONS(4138),
    [anon_sym_QMARK] = ACTIONS(4138),
    [anon_sym_BANG] = ACTIONS(4138),
    [anon_sym_PLUS_PLUS] = ACTIONS(4140),
    [anon_sym_DASH_DASH] = ACTIONS(4140),
    [anon_sym_PLUS] = ACTIONS(4138),
    [anon_sym_DASH] = ACTIONS(4138),
    [anon_sym_STAR] = ACTIONS(4138),
    [anon_sym_SLASH] = ACTIONS(4138),
    [anon_sym_PERCENT] = ACTIONS(4138),
    [anon_sym_CARET] = ACTIONS(4138),
    [anon_sym_PIPE] = ACTIONS(4138),
    [anon_sym_AMP] = ACTIONS(4138),
    [anon_sym_LT_LT] = ACTIONS(4138),
    [anon_sym_GT_GT] = ACTIONS(4138),
    [anon_sym_GT_GT_GT] = ACTIONS(4138),
    [anon_sym_EQ_EQ] = ACTIONS(4140),
    [anon_sym_BANG_EQ] = ACTIONS(4140),
    [anon_sym_GT_EQ] = ACTIONS(4140),
    [anon_sym_LT_EQ] = ACTIONS(4140),
    [anon_sym_DOT] = ACTIONS(4138),
    [anon_sym_EQ_GT] = ACTIONS(4140),
    [anon_sym_switch] = ACTIONS(4140),
    [anon_sym_when] = ACTIONS(4140),
    [anon_sym_DOT_DOT] = ACTIONS(4140),
    [anon_sym_and] = ACTIONS(4140),
    [anon_sym_or] = ACTIONS(4140),
    [anon_sym_PLUS_EQ] = ACTIONS(4140),
    [anon_sym_DASH_EQ] = ACTIONS(4140),
    [anon_sym_STAR_EQ] = ACTIONS(4140),
    [anon_sym_SLASH_EQ] = ACTIONS(4140),
    [anon_sym_PERCENT_EQ] = ACTIONS(4140),
    [anon_sym_AMP_EQ] = ACTIONS(4140),
    [anon_sym_CARET_EQ] = ACTIONS(4140),
    [anon_sym_PIPE_EQ] = ACTIONS(4140),
    [anon_sym_LT_LT_EQ] = ACTIONS(4140),
    [anon_sym_GT_GT_EQ] = ACTIONS(4140),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4140),
    [anon_sym_AMP_AMP] = ACTIONS(4140),
    [anon_sym_PIPE_PIPE] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK] = ACTIONS(4138),
    [anon_sym_into] = ACTIONS(4140),
    [anon_sym_on] = ACTIONS(4140),
    [anon_sym_equals] = ACTIONS(4140),
    [anon_sym_by] = ACTIONS(4140),
    [anon_sym_as] = ACTIONS(4140),
    [anon_sym_is] = ACTIONS(4140),
    [anon_sym_DASH_GT] = ACTIONS(4140),
    [anon_sym_with] = ACTIONS(4140),
    [aux_sym_preproc_if_token3] = ACTIONS(4140),
    [aux_sym_preproc_else_token1] = ACTIONS(4140),
    [aux_sym_preproc_elif_token1] = ACTIONS(4140),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3209] = {
    [sym__variable_designation] = STATE(4612),
    [sym_parenthesized_variable_designation] = STATE(4748),
    [sym_identifier] = STATE(4548),
    [sym__reserved_identifier] = STATE(2928),
    [sym_preproc_region] = STATE(3209),
    [sym_preproc_endregion] = STATE(3209),
    [sym_preproc_line] = STATE(3209),
    [sym_preproc_pragma] = STATE(3209),
    [sym_preproc_nullable] = STATE(3209),
    [sym_preproc_error] = STATE(3209),
    [sym_preproc_warning] = STATE(3209),
    [sym_preproc_define] = STATE(3209),
    [sym_preproc_undef] = STATE(3209),
    [sym__identifier_token] = ACTIONS(4536),
    [anon_sym_alias] = ACTIONS(4538),
    [anon_sym_global] = ACTIONS(4538),
    [anon_sym_LBRACK] = ACTIONS(4405),
    [anon_sym_COMMA] = ACTIONS(4405),
    [anon_sym_LPAREN] = ACTIONS(4405),
    [anon_sym_file] = ACTIONS(4538),
    [anon_sym_LT] = ACTIONS(4407),
    [anon_sym_GT] = ACTIONS(4407),
    [anon_sym_where] = ACTIONS(4407),
    [anon_sym_QMARK] = ACTIONS(4407),
    [anon_sym_notnull] = ACTIONS(4538),
    [anon_sym_unmanaged] = ACTIONS(4538),
    [anon_sym_BANG] = ACTIONS(4407),
    [anon_sym_PLUS_PLUS] = ACTIONS(4405),
    [anon_sym_DASH_DASH] = ACTIONS(4405),
    [anon_sym_PLUS] = ACTIONS(4407),
    [anon_sym_DASH] = ACTIONS(4407),
    [anon_sym_STAR] = ACTIONS(4405),
    [anon_sym_SLASH] = ACTIONS(4407),
    [anon_sym_PERCENT] = ACTIONS(4405),
    [anon_sym_CARET] = ACTIONS(4405),
    [anon_sym_PIPE] = ACTIONS(4407),
    [anon_sym_AMP] = ACTIONS(4407),
    [anon_sym_LT_LT] = ACTIONS(4405),
    [anon_sym_GT_GT] = ACTIONS(4407),
    [anon_sym_GT_GT_GT] = ACTIONS(4405),
    [anon_sym_EQ_EQ] = ACTIONS(4405),
    [anon_sym_BANG_EQ] = ACTIONS(4405),
    [anon_sym_GT_EQ] = ACTIONS(4405),
    [anon_sym_LT_EQ] = ACTIONS(4405),
    [anon_sym_DOT] = ACTIONS(4407),
    [anon_sym_scoped] = ACTIONS(4538),
    [anon_sym_var] = ACTIONS(4538),
    [anon_sym_yield] = ACTIONS(4538),
    [anon_sym_switch] = ACTIONS(4407),
    [anon_sym_when] = ACTIONS(4538),
    [sym_discard] = ACTIONS(4717),
    [anon_sym_DOT_DOT] = ACTIONS(4405),
    [anon_sym_and] = ACTIONS(4407),
    [anon_sym_or] = ACTIONS(4407),
    [anon_sym_AMP_AMP] = ACTIONS(4405),
    [anon_sym_PIPE_PIPE] = ACTIONS(4405),
    [anon_sym_QMARK_QMARK] = ACTIONS(4405),
    [anon_sym_from] = ACTIONS(4407),
    [anon_sym_into] = ACTIONS(4538),
    [anon_sym_join] = ACTIONS(4407),
    [anon_sym_on] = ACTIONS(4538),
    [anon_sym_equals] = ACTIONS(4538),
    [anon_sym_let] = ACTIONS(4407),
    [anon_sym_orderby] = ACTIONS(4407),
    [anon_sym_ascending] = ACTIONS(4407),
    [anon_sym_descending] = ACTIONS(4407),
    [anon_sym_group] = ACTIONS(4407),
    [anon_sym_by] = ACTIONS(4538),
    [anon_sym_select] = ACTIONS(4407),
    [anon_sym_as] = ACTIONS(4407),
    [anon_sym_is] = ACTIONS(4407),
    [anon_sym_DASH_GT] = ACTIONS(4405),
    [anon_sym_with] = ACTIONS(4407),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3210] = {
    [sym_preproc_region] = STATE(3210),
    [sym_preproc_endregion] = STATE(3210),
    [sym_preproc_line] = STATE(3210),
    [sym_preproc_pragma] = STATE(3210),
    [sym_preproc_nullable] = STATE(3210),
    [sym_preproc_error] = STATE(3210),
    [sym_preproc_warning] = STATE(3210),
    [sym_preproc_define] = STATE(3210),
    [sym_preproc_undef] = STATE(3210),
    [anon_sym_SEMI] = ACTIONS(4124),
    [anon_sym_EQ] = ACTIONS(4122),
    [anon_sym_LBRACK] = ACTIONS(4124),
    [anon_sym_COLON] = ACTIONS(4124),
    [anon_sym_COMMA] = ACTIONS(4124),
    [anon_sym_RBRACK] = ACTIONS(4124),
    [anon_sym_LPAREN] = ACTIONS(4124),
    [anon_sym_RPAREN] = ACTIONS(4124),
    [anon_sym_RBRACE] = ACTIONS(4124),
    [anon_sym_LT] = ACTIONS(4122),
    [anon_sym_GT] = ACTIONS(4122),
    [anon_sym_in] = ACTIONS(4122),
    [anon_sym_QMARK] = ACTIONS(4122),
    [anon_sym_BANG] = ACTIONS(4122),
    [anon_sym_PLUS_PLUS] = ACTIONS(4124),
    [anon_sym_DASH_DASH] = ACTIONS(4124),
    [anon_sym_PLUS] = ACTIONS(4122),
    [anon_sym_DASH] = ACTIONS(4122),
    [anon_sym_STAR] = ACTIONS(4122),
    [anon_sym_SLASH] = ACTIONS(4122),
    [anon_sym_PERCENT] = ACTIONS(4122),
    [anon_sym_CARET] = ACTIONS(4122),
    [anon_sym_PIPE] = ACTIONS(4122),
    [anon_sym_AMP] = ACTIONS(4122),
    [anon_sym_LT_LT] = ACTIONS(4122),
    [anon_sym_GT_GT] = ACTIONS(4122),
    [anon_sym_GT_GT_GT] = ACTIONS(4122),
    [anon_sym_EQ_EQ] = ACTIONS(4124),
    [anon_sym_BANG_EQ] = ACTIONS(4124),
    [anon_sym_GT_EQ] = ACTIONS(4124),
    [anon_sym_LT_EQ] = ACTIONS(4124),
    [anon_sym_DOT] = ACTIONS(4122),
    [anon_sym_EQ_GT] = ACTIONS(4124),
    [anon_sym_switch] = ACTIONS(4124),
    [anon_sym_when] = ACTIONS(4124),
    [anon_sym_DOT_DOT] = ACTIONS(4124),
    [anon_sym_and] = ACTIONS(4124),
    [anon_sym_or] = ACTIONS(4124),
    [anon_sym_PLUS_EQ] = ACTIONS(4124),
    [anon_sym_DASH_EQ] = ACTIONS(4124),
    [anon_sym_STAR_EQ] = ACTIONS(4124),
    [anon_sym_SLASH_EQ] = ACTIONS(4124),
    [anon_sym_PERCENT_EQ] = ACTIONS(4124),
    [anon_sym_AMP_EQ] = ACTIONS(4124),
    [anon_sym_CARET_EQ] = ACTIONS(4124),
    [anon_sym_PIPE_EQ] = ACTIONS(4124),
    [anon_sym_LT_LT_EQ] = ACTIONS(4124),
    [anon_sym_GT_GT_EQ] = ACTIONS(4124),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4124),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4124),
    [anon_sym_AMP_AMP] = ACTIONS(4124),
    [anon_sym_PIPE_PIPE] = ACTIONS(4124),
    [anon_sym_QMARK_QMARK] = ACTIONS(4122),
    [anon_sym_into] = ACTIONS(4124),
    [anon_sym_on] = ACTIONS(4124),
    [anon_sym_equals] = ACTIONS(4124),
    [anon_sym_by] = ACTIONS(4124),
    [anon_sym_as] = ACTIONS(4124),
    [anon_sym_is] = ACTIONS(4124),
    [anon_sym_DASH_GT] = ACTIONS(4124),
    [anon_sym_with] = ACTIONS(4124),
    [aux_sym_preproc_if_token3] = ACTIONS(4124),
    [aux_sym_preproc_else_token1] = ACTIONS(4124),
    [aux_sym_preproc_elif_token1] = ACTIONS(4124),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3211] = {
    [sym_preproc_region] = STATE(3211),
    [sym_preproc_endregion] = STATE(3211),
    [sym_preproc_line] = STATE(3211),
    [sym_preproc_pragma] = STATE(3211),
    [sym_preproc_nullable] = STATE(3211),
    [sym_preproc_error] = STATE(3211),
    [sym_preproc_warning] = STATE(3211),
    [sym_preproc_define] = STATE(3211),
    [sym_preproc_undef] = STATE(3211),
    [sym__identifier_token] = ACTIONS(4492),
    [anon_sym_alias] = ACTIONS(4492),
    [anon_sym_global] = ACTIONS(4492),
    [anon_sym_LBRACK] = ACTIONS(4593),
    [anon_sym_COLON] = ACTIONS(4494),
    [anon_sym_COMMA] = ACTIONS(4494),
    [anon_sym_LPAREN] = ACTIONS(4494),
    [anon_sym_RPAREN] = ACTIONS(4494),
    [anon_sym_LBRACE] = ACTIONS(4494),
    [anon_sym_RBRACE] = ACTIONS(4494),
    [anon_sym_file] = ACTIONS(4492),
    [anon_sym_LT] = ACTIONS(4492),
    [anon_sym_GT] = ACTIONS(4492),
    [anon_sym_where] = ACTIONS(4492),
    [anon_sym_QMARK] = ACTIONS(4596),
    [anon_sym_notnull] = ACTIONS(4492),
    [anon_sym_unmanaged] = ACTIONS(4492),
    [anon_sym_BANG] = ACTIONS(4492),
    [anon_sym_PLUS_PLUS] = ACTIONS(4494),
    [anon_sym_DASH_DASH] = ACTIONS(4494),
    [anon_sym_PLUS] = ACTIONS(4492),
    [anon_sym_DASH] = ACTIONS(4492),
    [anon_sym_STAR] = ACTIONS(4599),
    [anon_sym_SLASH] = ACTIONS(4492),
    [anon_sym_PERCENT] = ACTIONS(4494),
    [anon_sym_CARET] = ACTIONS(4494),
    [anon_sym_PIPE] = ACTIONS(4492),
    [anon_sym_AMP] = ACTIONS(4492),
    [anon_sym_LT_LT] = ACTIONS(4494),
    [anon_sym_GT_GT] = ACTIONS(4492),
    [anon_sym_GT_GT_GT] = ACTIONS(4494),
    [anon_sym_EQ_EQ] = ACTIONS(4494),
    [anon_sym_BANG_EQ] = ACTIONS(4494),
    [anon_sym_GT_EQ] = ACTIONS(4494),
    [anon_sym_LT_EQ] = ACTIONS(4494),
    [anon_sym_DOT] = ACTIONS(4816),
    [anon_sym_scoped] = ACTIONS(4492),
    [anon_sym_var] = ACTIONS(4492),
    [anon_sym_yield] = ACTIONS(4492),
    [anon_sym_switch] = ACTIONS(4492),
    [anon_sym_when] = ACTIONS(4492),
    [sym_discard] = ACTIONS(4492),
    [anon_sym_DOT_DOT] = ACTIONS(4494),
    [anon_sym_and] = ACTIONS(4492),
    [anon_sym_or] = ACTIONS(4492),
    [anon_sym_AMP_AMP] = ACTIONS(4494),
    [anon_sym_PIPE_PIPE] = ACTIONS(4494),
    [anon_sym_QMARK_QMARK] = ACTIONS(4494),
    [anon_sym_from] = ACTIONS(4492),
    [anon_sym_into] = ACTIONS(4492),
    [anon_sym_join] = ACTIONS(4492),
    [anon_sym_on] = ACTIONS(4492),
    [anon_sym_equals] = ACTIONS(4492),
    [anon_sym_let] = ACTIONS(4492),
    [anon_sym_orderby] = ACTIONS(4492),
    [anon_sym_ascending] = ACTIONS(4492),
    [anon_sym_descending] = ACTIONS(4492),
    [anon_sym_group] = ACTIONS(4492),
    [anon_sym_by] = ACTIONS(4492),
    [anon_sym_select] = ACTIONS(4492),
    [anon_sym_as] = ACTIONS(4492),
    [anon_sym_is] = ACTIONS(4492),
    [anon_sym_DASH_GT] = ACTIONS(4604),
    [anon_sym_with] = ACTIONS(4492),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3212] = {
    [sym__variable_designation] = STATE(4182),
    [sym_parenthesized_variable_designation] = STATE(4153),
    [sym_identifier] = STATE(4156),
    [sym__reserved_identifier] = STATE(3911),
    [sym_preproc_region] = STATE(3212),
    [sym_preproc_endregion] = STATE(3212),
    [sym_preproc_line] = STATE(3212),
    [sym_preproc_pragma] = STATE(3212),
    [sym_preproc_nullable] = STATE(3212),
    [sym_preproc_error] = STATE(3212),
    [sym_preproc_warning] = STATE(3212),
    [sym_preproc_define] = STATE(3212),
    [sym_preproc_undef] = STATE(3212),
    [sym__identifier_token] = ACTIONS(4248),
    [anon_sym_alias] = ACTIONS(4250),
    [anon_sym_global] = ACTIONS(4250),
    [anon_sym_LBRACK] = ACTIONS(4405),
    [anon_sym_LPAREN] = ACTIONS(4405),
    [anon_sym_file] = ACTIONS(4250),
    [anon_sym_LT] = ACTIONS(4407),
    [anon_sym_GT] = ACTIONS(4407),
    [anon_sym_in] = ACTIONS(4407),
    [anon_sym_where] = ACTIONS(4250),
    [anon_sym_QMARK] = ACTIONS(4407),
    [anon_sym_notnull] = ACTIONS(4250),
    [anon_sym_unmanaged] = ACTIONS(4250),
    [anon_sym_BANG] = ACTIONS(4407),
    [anon_sym_PLUS_PLUS] = ACTIONS(4405),
    [anon_sym_DASH_DASH] = ACTIONS(4405),
    [anon_sym_PLUS] = ACTIONS(4407),
    [anon_sym_DASH] = ACTIONS(4407),
    [anon_sym_STAR] = ACTIONS(4405),
    [anon_sym_SLASH] = ACTIONS(4407),
    [anon_sym_PERCENT] = ACTIONS(4405),
    [anon_sym_CARET] = ACTIONS(4405),
    [anon_sym_PIPE] = ACTIONS(4407),
    [anon_sym_AMP] = ACTIONS(4407),
    [anon_sym_LT_LT] = ACTIONS(4405),
    [anon_sym_GT_GT] = ACTIONS(4407),
    [anon_sym_GT_GT_GT] = ACTIONS(4405),
    [anon_sym_EQ_EQ] = ACTIONS(4405),
    [anon_sym_BANG_EQ] = ACTIONS(4405),
    [anon_sym_GT_EQ] = ACTIONS(4405),
    [anon_sym_LT_EQ] = ACTIONS(4405),
    [anon_sym_DOT] = ACTIONS(4407),
    [anon_sym_scoped] = ACTIONS(4250),
    [anon_sym_var] = ACTIONS(4250),
    [anon_sym_yield] = ACTIONS(4250),
    [anon_sym_switch] = ACTIONS(4407),
    [anon_sym_when] = ACTIONS(4250),
    [sym_discard] = ACTIONS(4359),
    [anon_sym_DOT_DOT] = ACTIONS(4405),
    [anon_sym_and] = ACTIONS(4407),
    [anon_sym_or] = ACTIONS(4407),
    [anon_sym_AMP_AMP] = ACTIONS(4405),
    [anon_sym_PIPE_PIPE] = ACTIONS(4405),
    [anon_sym_QMARK_QMARK] = ACTIONS(4405),
    [anon_sym_from] = ACTIONS(4250),
    [anon_sym_into] = ACTIONS(4250),
    [anon_sym_join] = ACTIONS(4250),
    [anon_sym_on] = ACTIONS(4250),
    [anon_sym_equals] = ACTIONS(4250),
    [anon_sym_let] = ACTIONS(4250),
    [anon_sym_orderby] = ACTIONS(4250),
    [anon_sym_ascending] = ACTIONS(4250),
    [anon_sym_descending] = ACTIONS(4250),
    [anon_sym_group] = ACTIONS(4250),
    [anon_sym_by] = ACTIONS(4250),
    [anon_sym_select] = ACTIONS(4250),
    [anon_sym_as] = ACTIONS(4407),
    [anon_sym_is] = ACTIONS(4407),
    [anon_sym_DASH_GT] = ACTIONS(4405),
    [anon_sym_with] = ACTIONS(4407),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3213] = {
    [sym_preproc_region] = STATE(3213),
    [sym_preproc_endregion] = STATE(3213),
    [sym_preproc_line] = STATE(3213),
    [sym_preproc_pragma] = STATE(3213),
    [sym_preproc_nullable] = STATE(3213),
    [sym_preproc_error] = STATE(3213),
    [sym_preproc_warning] = STATE(3213),
    [sym_preproc_define] = STATE(3213),
    [sym_preproc_undef] = STATE(3213),
    [anon_sym_SEMI] = ACTIONS(4640),
    [anon_sym_EQ] = ACTIONS(4642),
    [anon_sym_LBRACK] = ACTIONS(4640),
    [anon_sym_COLON] = ACTIONS(4640),
    [anon_sym_COMMA] = ACTIONS(4640),
    [anon_sym_RBRACK] = ACTIONS(4640),
    [anon_sym_LPAREN] = ACTIONS(4640),
    [anon_sym_RPAREN] = ACTIONS(4640),
    [anon_sym_RBRACE] = ACTIONS(4640),
    [anon_sym_LT] = ACTIONS(4642),
    [anon_sym_GT] = ACTIONS(4642),
    [anon_sym_in] = ACTIONS(4642),
    [anon_sym_QMARK] = ACTIONS(4642),
    [anon_sym_BANG] = ACTIONS(4642),
    [anon_sym_PLUS_PLUS] = ACTIONS(4640),
    [anon_sym_DASH_DASH] = ACTIONS(4640),
    [anon_sym_PLUS] = ACTIONS(4642),
    [anon_sym_DASH] = ACTIONS(4642),
    [anon_sym_STAR] = ACTIONS(4642),
    [anon_sym_SLASH] = ACTIONS(4642),
    [anon_sym_PERCENT] = ACTIONS(4642),
    [anon_sym_CARET] = ACTIONS(4642),
    [anon_sym_PIPE] = ACTIONS(4642),
    [anon_sym_AMP] = ACTIONS(4642),
    [anon_sym_LT_LT] = ACTIONS(4642),
    [anon_sym_GT_GT] = ACTIONS(4642),
    [anon_sym_GT_GT_GT] = ACTIONS(4642),
    [anon_sym_EQ_EQ] = ACTIONS(4640),
    [anon_sym_BANG_EQ] = ACTIONS(4640),
    [anon_sym_GT_EQ] = ACTIONS(4640),
    [anon_sym_LT_EQ] = ACTIONS(4640),
    [anon_sym_DOT] = ACTIONS(4642),
    [anon_sym_EQ_GT] = ACTIONS(4640),
    [anon_sym_switch] = ACTIONS(4640),
    [anon_sym_when] = ACTIONS(4640),
    [anon_sym_DOT_DOT] = ACTIONS(4640),
    [anon_sym_and] = ACTIONS(4640),
    [anon_sym_or] = ACTIONS(4640),
    [anon_sym_PLUS_EQ] = ACTIONS(4640),
    [anon_sym_DASH_EQ] = ACTIONS(4640),
    [anon_sym_STAR_EQ] = ACTIONS(4640),
    [anon_sym_SLASH_EQ] = ACTIONS(4640),
    [anon_sym_PERCENT_EQ] = ACTIONS(4640),
    [anon_sym_AMP_EQ] = ACTIONS(4640),
    [anon_sym_CARET_EQ] = ACTIONS(4640),
    [anon_sym_PIPE_EQ] = ACTIONS(4640),
    [anon_sym_LT_LT_EQ] = ACTIONS(4640),
    [anon_sym_GT_GT_EQ] = ACTIONS(4640),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4640),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4640),
    [anon_sym_AMP_AMP] = ACTIONS(4640),
    [anon_sym_PIPE_PIPE] = ACTIONS(4640),
    [anon_sym_QMARK_QMARK] = ACTIONS(4642),
    [anon_sym_into] = ACTIONS(4640),
    [anon_sym_on] = ACTIONS(4640),
    [anon_sym_equals] = ACTIONS(4640),
    [anon_sym_by] = ACTIONS(4640),
    [anon_sym_as] = ACTIONS(4640),
    [anon_sym_is] = ACTIONS(4640),
    [anon_sym_DASH_GT] = ACTIONS(4640),
    [anon_sym_with] = ACTIONS(4640),
    [aux_sym_preproc_if_token3] = ACTIONS(4640),
    [aux_sym_preproc_else_token1] = ACTIONS(4640),
    [aux_sym_preproc_elif_token1] = ACTIONS(4640),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3214] = {
    [sym_preproc_region] = STATE(3214),
    [sym_preproc_endregion] = STATE(3214),
    [sym_preproc_line] = STATE(3214),
    [sym_preproc_pragma] = STATE(3214),
    [sym_preproc_nullable] = STATE(3214),
    [sym_preproc_error] = STATE(3214),
    [sym_preproc_warning] = STATE(3214),
    [sym_preproc_define] = STATE(3214),
    [sym_preproc_undef] = STATE(3214),
    [anon_sym_SEMI] = ACTIONS(4711),
    [anon_sym_EQ] = ACTIONS(4713),
    [anon_sym_LBRACK] = ACTIONS(4711),
    [anon_sym_COLON] = ACTIONS(4711),
    [anon_sym_COMMA] = ACTIONS(4711),
    [anon_sym_RBRACK] = ACTIONS(4711),
    [anon_sym_LPAREN] = ACTIONS(4711),
    [anon_sym_RPAREN] = ACTIONS(4711),
    [anon_sym_LBRACE] = ACTIONS(4711),
    [anon_sym_RBRACE] = ACTIONS(4711),
    [anon_sym_LT] = ACTIONS(4713),
    [anon_sym_GT] = ACTIONS(4713),
    [anon_sym_in] = ACTIONS(4711),
    [anon_sym_QMARK] = ACTIONS(4713),
    [anon_sym_BANG] = ACTIONS(4713),
    [anon_sym_PLUS_PLUS] = ACTIONS(4711),
    [anon_sym_DASH_DASH] = ACTIONS(4711),
    [anon_sym_PLUS] = ACTIONS(4713),
    [anon_sym_DASH] = ACTIONS(4713),
    [anon_sym_STAR] = ACTIONS(4713),
    [anon_sym_SLASH] = ACTIONS(4713),
    [anon_sym_PERCENT] = ACTIONS(4713),
    [anon_sym_CARET] = ACTIONS(4713),
    [anon_sym_PIPE] = ACTIONS(4713),
    [anon_sym_AMP] = ACTIONS(4713),
    [anon_sym_LT_LT] = ACTIONS(4713),
    [anon_sym_GT_GT] = ACTIONS(4713),
    [anon_sym_GT_GT_GT] = ACTIONS(4713),
    [anon_sym_EQ_EQ] = ACTIONS(4711),
    [anon_sym_BANG_EQ] = ACTIONS(4711),
    [anon_sym_GT_EQ] = ACTIONS(4711),
    [anon_sym_LT_EQ] = ACTIONS(4711),
    [anon_sym_DOT] = ACTIONS(4713),
    [anon_sym_EQ_GT] = ACTIONS(4711),
    [anon_sym_switch] = ACTIONS(4711),
    [anon_sym_when] = ACTIONS(4711),
    [anon_sym_DOT_DOT] = ACTIONS(4711),
    [anon_sym_and] = ACTIONS(4711),
    [anon_sym_or] = ACTIONS(4711),
    [anon_sym_PLUS_EQ] = ACTIONS(4711),
    [anon_sym_DASH_EQ] = ACTIONS(4711),
    [anon_sym_STAR_EQ] = ACTIONS(4711),
    [anon_sym_SLASH_EQ] = ACTIONS(4711),
    [anon_sym_PERCENT_EQ] = ACTIONS(4711),
    [anon_sym_AMP_EQ] = ACTIONS(4711),
    [anon_sym_CARET_EQ] = ACTIONS(4711),
    [anon_sym_PIPE_EQ] = ACTIONS(4711),
    [anon_sym_LT_LT_EQ] = ACTIONS(4711),
    [anon_sym_GT_GT_EQ] = ACTIONS(4711),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4711),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4711),
    [anon_sym_AMP_AMP] = ACTIONS(4711),
    [anon_sym_PIPE_PIPE] = ACTIONS(4711),
    [anon_sym_QMARK_QMARK] = ACTIONS(4713),
    [anon_sym_on] = ACTIONS(4711),
    [anon_sym_equals] = ACTIONS(4711),
    [anon_sym_by] = ACTIONS(4711),
    [anon_sym_as] = ACTIONS(4711),
    [anon_sym_is] = ACTIONS(4711),
    [anon_sym_DASH_GT] = ACTIONS(4711),
    [anon_sym_with] = ACTIONS(4711),
    [aux_sym_preproc_if_token3] = ACTIONS(4711),
    [aux_sym_preproc_else_token1] = ACTIONS(4711),
    [aux_sym_preproc_elif_token1] = ACTIONS(4711),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3215] = {
    [sym_preproc_region] = STATE(3215),
    [sym_preproc_endregion] = STATE(3215),
    [sym_preproc_line] = STATE(3215),
    [sym_preproc_pragma] = STATE(3215),
    [sym_preproc_nullable] = STATE(3215),
    [sym_preproc_error] = STATE(3215),
    [sym_preproc_warning] = STATE(3215),
    [sym_preproc_define] = STATE(3215),
    [sym_preproc_undef] = STATE(3215),
    [sym__identifier_token] = ACTIONS(4818),
    [anon_sym_extern] = ACTIONS(4818),
    [anon_sym_alias] = ACTIONS(4818),
    [anon_sym_global] = ACTIONS(4818),
    [anon_sym_using] = ACTIONS(4818),
    [anon_sym_unsafe] = ACTIONS(4818),
    [anon_sym_EQ] = ACTIONS(4820),
    [anon_sym_static] = ACTIONS(4818),
    [anon_sym_LBRACK] = ACTIONS(4822),
    [anon_sym_LPAREN] = ACTIONS(4822),
    [anon_sym_event] = ACTIONS(4818),
    [anon_sym_namespace] = ACTIONS(4818),
    [anon_sym_class] = ACTIONS(4818),
    [anon_sym_ref] = ACTIONS(4818),
    [anon_sym_struct] = ACTIONS(4818),
    [anon_sym_enum] = ACTIONS(4818),
    [anon_sym_RBRACE] = ACTIONS(4822),
    [anon_sym_interface] = ACTIONS(4818),
    [anon_sym_delegate] = ACTIONS(4818),
    [anon_sym_record] = ACTIONS(4818),
    [anon_sym_abstract] = ACTIONS(4818),
    [anon_sym_async] = ACTIONS(4818),
    [anon_sym_const] = ACTIONS(4818),
    [anon_sym_file] = ACTIONS(4818),
    [anon_sym_fixed] = ACTIONS(4818),
    [anon_sym_internal] = ACTIONS(4818),
    [anon_sym_new] = ACTIONS(4818),
    [anon_sym_override] = ACTIONS(4818),
    [anon_sym_partial] = ACTIONS(4818),
    [anon_sym_private] = ACTIONS(4818),
    [anon_sym_protected] = ACTIONS(4818),
    [anon_sym_public] = ACTIONS(4818),
    [anon_sym_readonly] = ACTIONS(4818),
    [anon_sym_required] = ACTIONS(4818),
    [anon_sym_sealed] = ACTIONS(4818),
    [anon_sym_virtual] = ACTIONS(4818),
    [anon_sym_volatile] = ACTIONS(4818),
    [anon_sym_where] = ACTIONS(4818),
    [anon_sym_notnull] = ACTIONS(4818),
    [anon_sym_unmanaged] = ACTIONS(4818),
    [anon_sym_TILDE] = ACTIONS(4822),
    [anon_sym_implicit] = ACTIONS(4818),
    [anon_sym_explicit] = ACTIONS(4818),
    [anon_sym_scoped] = ACTIONS(4818),
    [anon_sym_var] = ACTIONS(4818),
    [sym_predefined_type] = ACTIONS(4818),
    [anon_sym_yield] = ACTIONS(4818),
    [anon_sym_when] = ACTIONS(4818),
    [anon_sym_from] = ACTIONS(4818),
    [anon_sym_into] = ACTIONS(4818),
    [anon_sym_join] = ACTIONS(4818),
    [anon_sym_on] = ACTIONS(4818),
    [anon_sym_equals] = ACTIONS(4818),
    [anon_sym_let] = ACTIONS(4818),
    [anon_sym_orderby] = ACTIONS(4818),
    [anon_sym_ascending] = ACTIONS(4818),
    [anon_sym_descending] = ACTIONS(4818),
    [anon_sym_group] = ACTIONS(4818),
    [anon_sym_by] = ACTIONS(4818),
    [anon_sym_select] = ACTIONS(4818),
    [aux_sym_preproc_if_token1] = ACTIONS(4822),
    [aux_sym_preproc_if_token3] = ACTIONS(4822),
    [aux_sym_preproc_else_token1] = ACTIONS(4822),
    [aux_sym_preproc_elif_token1] = ACTIONS(4822),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3216] = {
    [sym_preproc_region] = STATE(3216),
    [sym_preproc_endregion] = STATE(3216),
    [sym_preproc_line] = STATE(3216),
    [sym_preproc_pragma] = STATE(3216),
    [sym_preproc_nullable] = STATE(3216),
    [sym_preproc_error] = STATE(3216),
    [sym_preproc_warning] = STATE(3216),
    [sym_preproc_define] = STATE(3216),
    [sym_preproc_undef] = STATE(3216),
    [anon_sym_SEMI] = ACTIONS(4136),
    [anon_sym_EQ] = ACTIONS(4134),
    [anon_sym_LBRACK] = ACTIONS(4136),
    [anon_sym_COLON] = ACTIONS(4136),
    [anon_sym_COMMA] = ACTIONS(4136),
    [anon_sym_RBRACK] = ACTIONS(4136),
    [anon_sym_LPAREN] = ACTIONS(4136),
    [anon_sym_RPAREN] = ACTIONS(4136),
    [anon_sym_RBRACE] = ACTIONS(4136),
    [anon_sym_LT] = ACTIONS(4134),
    [anon_sym_GT] = ACTIONS(4134),
    [anon_sym_in] = ACTIONS(4134),
    [anon_sym_QMARK] = ACTIONS(4134),
    [anon_sym_BANG] = ACTIONS(4134),
    [anon_sym_PLUS_PLUS] = ACTIONS(4136),
    [anon_sym_DASH_DASH] = ACTIONS(4136),
    [anon_sym_PLUS] = ACTIONS(4134),
    [anon_sym_DASH] = ACTIONS(4134),
    [anon_sym_STAR] = ACTIONS(4134),
    [anon_sym_SLASH] = ACTIONS(4134),
    [anon_sym_PERCENT] = ACTIONS(4134),
    [anon_sym_CARET] = ACTIONS(4134),
    [anon_sym_PIPE] = ACTIONS(4134),
    [anon_sym_AMP] = ACTIONS(4134),
    [anon_sym_LT_LT] = ACTIONS(4134),
    [anon_sym_GT_GT] = ACTIONS(4134),
    [anon_sym_GT_GT_GT] = ACTIONS(4134),
    [anon_sym_EQ_EQ] = ACTIONS(4136),
    [anon_sym_BANG_EQ] = ACTIONS(4136),
    [anon_sym_GT_EQ] = ACTIONS(4136),
    [anon_sym_LT_EQ] = ACTIONS(4136),
    [anon_sym_DOT] = ACTIONS(4134),
    [anon_sym_EQ_GT] = ACTIONS(4136),
    [anon_sym_switch] = ACTIONS(4136),
    [anon_sym_when] = ACTIONS(4136),
    [anon_sym_DOT_DOT] = ACTIONS(4136),
    [anon_sym_and] = ACTIONS(4136),
    [anon_sym_or] = ACTIONS(4136),
    [anon_sym_PLUS_EQ] = ACTIONS(4136),
    [anon_sym_DASH_EQ] = ACTIONS(4136),
    [anon_sym_STAR_EQ] = ACTIONS(4136),
    [anon_sym_SLASH_EQ] = ACTIONS(4136),
    [anon_sym_PERCENT_EQ] = ACTIONS(4136),
    [anon_sym_AMP_EQ] = ACTIONS(4136),
    [anon_sym_CARET_EQ] = ACTIONS(4136),
    [anon_sym_PIPE_EQ] = ACTIONS(4136),
    [anon_sym_LT_LT_EQ] = ACTIONS(4136),
    [anon_sym_GT_GT_EQ] = ACTIONS(4136),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4136),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4136),
    [anon_sym_AMP_AMP] = ACTIONS(4136),
    [anon_sym_PIPE_PIPE] = ACTIONS(4136),
    [anon_sym_QMARK_QMARK] = ACTIONS(4134),
    [anon_sym_into] = ACTIONS(4136),
    [anon_sym_on] = ACTIONS(4136),
    [anon_sym_equals] = ACTIONS(4136),
    [anon_sym_by] = ACTIONS(4136),
    [anon_sym_as] = ACTIONS(4136),
    [anon_sym_is] = ACTIONS(4136),
    [anon_sym_DASH_GT] = ACTIONS(4136),
    [anon_sym_with] = ACTIONS(4136),
    [aux_sym_preproc_if_token3] = ACTIONS(4136),
    [aux_sym_preproc_else_token1] = ACTIONS(4136),
    [aux_sym_preproc_elif_token1] = ACTIONS(4136),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3217] = {
    [sym_preproc_region] = STATE(3217),
    [sym_preproc_endregion] = STATE(3217),
    [sym_preproc_line] = STATE(3217),
    [sym_preproc_pragma] = STATE(3217),
    [sym_preproc_nullable] = STATE(3217),
    [sym_preproc_error] = STATE(3217),
    [sym_preproc_warning] = STATE(3217),
    [sym_preproc_define] = STATE(3217),
    [sym_preproc_undef] = STATE(3217),
    [sym__identifier_token] = ACTIONS(4492),
    [anon_sym_alias] = ACTIONS(4492),
    [anon_sym_global] = ACTIONS(4492),
    [anon_sym_LBRACK] = ACTIONS(4593),
    [anon_sym_COLON] = ACTIONS(4494),
    [anon_sym_COMMA] = ACTIONS(4494),
    [anon_sym_LPAREN] = ACTIONS(4494),
    [anon_sym_RPAREN] = ACTIONS(4494),
    [anon_sym_LBRACE] = ACTIONS(4494),
    [anon_sym_RBRACE] = ACTIONS(4494),
    [anon_sym_file] = ACTIONS(4492),
    [anon_sym_LT] = ACTIONS(4492),
    [anon_sym_GT] = ACTIONS(4492),
    [anon_sym_where] = ACTIONS(4492),
    [anon_sym_QMARK] = ACTIONS(4596),
    [anon_sym_notnull] = ACTIONS(4492),
    [anon_sym_unmanaged] = ACTIONS(4492),
    [anon_sym_BANG] = ACTIONS(4492),
    [anon_sym_PLUS_PLUS] = ACTIONS(4494),
    [anon_sym_DASH_DASH] = ACTIONS(4494),
    [anon_sym_PLUS] = ACTIONS(4492),
    [anon_sym_DASH] = ACTIONS(4492),
    [anon_sym_STAR] = ACTIONS(4599),
    [anon_sym_SLASH] = ACTIONS(4492),
    [anon_sym_PERCENT] = ACTIONS(4494),
    [anon_sym_CARET] = ACTIONS(4494),
    [anon_sym_PIPE] = ACTIONS(4492),
    [anon_sym_AMP] = ACTIONS(4492),
    [anon_sym_LT_LT] = ACTIONS(4494),
    [anon_sym_GT_GT] = ACTIONS(4492),
    [anon_sym_GT_GT_GT] = ACTIONS(4494),
    [anon_sym_EQ_EQ] = ACTIONS(4494),
    [anon_sym_BANG_EQ] = ACTIONS(4494),
    [anon_sym_GT_EQ] = ACTIONS(4494),
    [anon_sym_LT_EQ] = ACTIONS(4494),
    [anon_sym_DOT] = ACTIONS(4796),
    [anon_sym_scoped] = ACTIONS(4492),
    [anon_sym_var] = ACTIONS(4492),
    [anon_sym_yield] = ACTIONS(4492),
    [anon_sym_switch] = ACTIONS(4492),
    [anon_sym_when] = ACTIONS(4492),
    [sym_discard] = ACTIONS(4492),
    [anon_sym_DOT_DOT] = ACTIONS(4494),
    [anon_sym_and] = ACTIONS(4492),
    [anon_sym_or] = ACTIONS(4492),
    [anon_sym_AMP_AMP] = ACTIONS(4494),
    [anon_sym_PIPE_PIPE] = ACTIONS(4494),
    [anon_sym_QMARK_QMARK] = ACTIONS(4494),
    [anon_sym_from] = ACTIONS(4492),
    [anon_sym_into] = ACTIONS(4492),
    [anon_sym_join] = ACTIONS(4492),
    [anon_sym_on] = ACTIONS(4492),
    [anon_sym_equals] = ACTIONS(4492),
    [anon_sym_let] = ACTIONS(4492),
    [anon_sym_orderby] = ACTIONS(4492),
    [anon_sym_ascending] = ACTIONS(4492),
    [anon_sym_descending] = ACTIONS(4492),
    [anon_sym_group] = ACTIONS(4492),
    [anon_sym_by] = ACTIONS(4492),
    [anon_sym_select] = ACTIONS(4492),
    [anon_sym_as] = ACTIONS(4492),
    [anon_sym_is] = ACTIONS(4492),
    [anon_sym_DASH_GT] = ACTIONS(4494),
    [anon_sym_with] = ACTIONS(4492),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3218] = {
    [sym_preproc_region] = STATE(3218),
    [sym_preproc_endregion] = STATE(3218),
    [sym_preproc_line] = STATE(3218),
    [sym_preproc_pragma] = STATE(3218),
    [sym_preproc_nullable] = STATE(3218),
    [sym_preproc_error] = STATE(3218),
    [sym_preproc_warning] = STATE(3218),
    [sym_preproc_define] = STATE(3218),
    [sym_preproc_undef] = STATE(3218),
    [sym__identifier_token] = ACTIONS(4824),
    [anon_sym_extern] = ACTIONS(4824),
    [anon_sym_alias] = ACTIONS(4824),
    [anon_sym_global] = ACTIONS(4824),
    [anon_sym_using] = ACTIONS(4824),
    [anon_sym_unsafe] = ACTIONS(4824),
    [anon_sym_EQ] = ACTIONS(4826),
    [anon_sym_static] = ACTIONS(4824),
    [anon_sym_LBRACK] = ACTIONS(4828),
    [anon_sym_LPAREN] = ACTIONS(4828),
    [anon_sym_event] = ACTIONS(4824),
    [anon_sym_namespace] = ACTIONS(4824),
    [anon_sym_class] = ACTIONS(4824),
    [anon_sym_ref] = ACTIONS(4824),
    [anon_sym_struct] = ACTIONS(4824),
    [anon_sym_enum] = ACTIONS(4824),
    [anon_sym_RBRACE] = ACTIONS(4828),
    [anon_sym_interface] = ACTIONS(4824),
    [anon_sym_delegate] = ACTIONS(4824),
    [anon_sym_record] = ACTIONS(4824),
    [anon_sym_abstract] = ACTIONS(4824),
    [anon_sym_async] = ACTIONS(4824),
    [anon_sym_const] = ACTIONS(4824),
    [anon_sym_file] = ACTIONS(4824),
    [anon_sym_fixed] = ACTIONS(4824),
    [anon_sym_internal] = ACTIONS(4824),
    [anon_sym_new] = ACTIONS(4824),
    [anon_sym_override] = ACTIONS(4824),
    [anon_sym_partial] = ACTIONS(4824),
    [anon_sym_private] = ACTIONS(4824),
    [anon_sym_protected] = ACTIONS(4824),
    [anon_sym_public] = ACTIONS(4824),
    [anon_sym_readonly] = ACTIONS(4824),
    [anon_sym_required] = ACTIONS(4824),
    [anon_sym_sealed] = ACTIONS(4824),
    [anon_sym_virtual] = ACTIONS(4824),
    [anon_sym_volatile] = ACTIONS(4824),
    [anon_sym_where] = ACTIONS(4824),
    [anon_sym_notnull] = ACTIONS(4824),
    [anon_sym_unmanaged] = ACTIONS(4824),
    [anon_sym_TILDE] = ACTIONS(4828),
    [anon_sym_implicit] = ACTIONS(4824),
    [anon_sym_explicit] = ACTIONS(4824),
    [anon_sym_scoped] = ACTIONS(4824),
    [anon_sym_var] = ACTIONS(4824),
    [sym_predefined_type] = ACTIONS(4824),
    [anon_sym_yield] = ACTIONS(4824),
    [anon_sym_when] = ACTIONS(4824),
    [anon_sym_from] = ACTIONS(4824),
    [anon_sym_into] = ACTIONS(4824),
    [anon_sym_join] = ACTIONS(4824),
    [anon_sym_on] = ACTIONS(4824),
    [anon_sym_equals] = ACTIONS(4824),
    [anon_sym_let] = ACTIONS(4824),
    [anon_sym_orderby] = ACTIONS(4824),
    [anon_sym_ascending] = ACTIONS(4824),
    [anon_sym_descending] = ACTIONS(4824),
    [anon_sym_group] = ACTIONS(4824),
    [anon_sym_by] = ACTIONS(4824),
    [anon_sym_select] = ACTIONS(4824),
    [aux_sym_preproc_if_token1] = ACTIONS(4828),
    [aux_sym_preproc_if_token3] = ACTIONS(4828),
    [aux_sym_preproc_else_token1] = ACTIONS(4828),
    [aux_sym_preproc_elif_token1] = ACTIONS(4828),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3219] = {
    [sym_preproc_region] = STATE(3219),
    [sym_preproc_endregion] = STATE(3219),
    [sym_preproc_line] = STATE(3219),
    [sym_preproc_pragma] = STATE(3219),
    [sym_preproc_nullable] = STATE(3219),
    [sym_preproc_error] = STATE(3219),
    [sym_preproc_warning] = STATE(3219),
    [sym_preproc_define] = STATE(3219),
    [sym_preproc_undef] = STATE(3219),
    [sym__identifier_token] = ACTIONS(4492),
    [anon_sym_alias] = ACTIONS(4492),
    [anon_sym_global] = ACTIONS(4492),
    [anon_sym_LBRACK] = ACTIONS(4593),
    [anon_sym_COLON] = ACTIONS(4494),
    [anon_sym_COMMA] = ACTIONS(4494),
    [anon_sym_LPAREN] = ACTIONS(4494),
    [anon_sym_RPAREN] = ACTIONS(4494),
    [anon_sym_LBRACE] = ACTIONS(4494),
    [anon_sym_RBRACE] = ACTIONS(4494),
    [anon_sym_file] = ACTIONS(4492),
    [anon_sym_LT] = ACTIONS(4492),
    [anon_sym_GT] = ACTIONS(4492),
    [anon_sym_where] = ACTIONS(4492),
    [anon_sym_QMARK] = ACTIONS(4596),
    [anon_sym_notnull] = ACTIONS(4492),
    [anon_sym_unmanaged] = ACTIONS(4492),
    [anon_sym_BANG] = ACTIONS(4492),
    [anon_sym_PLUS_PLUS] = ACTIONS(4494),
    [anon_sym_DASH_DASH] = ACTIONS(4494),
    [anon_sym_PLUS] = ACTIONS(4492),
    [anon_sym_DASH] = ACTIONS(4492),
    [anon_sym_STAR] = ACTIONS(4599),
    [anon_sym_SLASH] = ACTIONS(4492),
    [anon_sym_PERCENT] = ACTIONS(4494),
    [anon_sym_CARET] = ACTIONS(4494),
    [anon_sym_PIPE] = ACTIONS(4492),
    [anon_sym_AMP] = ACTIONS(4492),
    [anon_sym_LT_LT] = ACTIONS(4494),
    [anon_sym_GT_GT] = ACTIONS(4492),
    [anon_sym_GT_GT_GT] = ACTIONS(4494),
    [anon_sym_EQ_EQ] = ACTIONS(4494),
    [anon_sym_BANG_EQ] = ACTIONS(4494),
    [anon_sym_GT_EQ] = ACTIONS(4494),
    [anon_sym_LT_EQ] = ACTIONS(4494),
    [anon_sym_DOT] = ACTIONS(4830),
    [anon_sym_scoped] = ACTIONS(4492),
    [anon_sym_var] = ACTIONS(4492),
    [anon_sym_yield] = ACTIONS(4492),
    [anon_sym_switch] = ACTIONS(4492),
    [anon_sym_when] = ACTIONS(4492),
    [sym_discard] = ACTIONS(4492),
    [anon_sym_DOT_DOT] = ACTIONS(4494),
    [anon_sym_and] = ACTIONS(4492),
    [anon_sym_or] = ACTIONS(4492),
    [anon_sym_AMP_AMP] = ACTIONS(4494),
    [anon_sym_PIPE_PIPE] = ACTIONS(4494),
    [anon_sym_QMARK_QMARK] = ACTIONS(4494),
    [anon_sym_from] = ACTIONS(4492),
    [anon_sym_into] = ACTIONS(4492),
    [anon_sym_join] = ACTIONS(4492),
    [anon_sym_on] = ACTIONS(4492),
    [anon_sym_equals] = ACTIONS(4492),
    [anon_sym_let] = ACTIONS(4492),
    [anon_sym_orderby] = ACTIONS(4492),
    [anon_sym_ascending] = ACTIONS(4492),
    [anon_sym_descending] = ACTIONS(4492),
    [anon_sym_group] = ACTIONS(4492),
    [anon_sym_by] = ACTIONS(4492),
    [anon_sym_select] = ACTIONS(4492),
    [anon_sym_as] = ACTIONS(4492),
    [anon_sym_is] = ACTIONS(4492),
    [anon_sym_DASH_GT] = ACTIONS(4604),
    [anon_sym_with] = ACTIONS(4492),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3220] = {
    [sym_preproc_region] = STATE(3220),
    [sym_preproc_endregion] = STATE(3220),
    [sym_preproc_line] = STATE(3220),
    [sym_preproc_pragma] = STATE(3220),
    [sym_preproc_nullable] = STATE(3220),
    [sym_preproc_error] = STATE(3220),
    [sym_preproc_warning] = STATE(3220),
    [sym_preproc_define] = STATE(3220),
    [sym_preproc_undef] = STATE(3220),
    [anon_sym_SEMI] = ACTIONS(4703),
    [anon_sym_EQ] = ACTIONS(4672),
    [anon_sym_LBRACK] = ACTIONS(4703),
    [anon_sym_COLON] = ACTIONS(4670),
    [anon_sym_COMMA] = ACTIONS(4703),
    [anon_sym_RBRACK] = ACTIONS(4703),
    [anon_sym_LPAREN] = ACTIONS(4703),
    [anon_sym_RPAREN] = ACTIONS(4703),
    [anon_sym_RBRACE] = ACTIONS(4703),
    [anon_sym_LT] = ACTIONS(4705),
    [anon_sym_GT] = ACTIONS(4705),
    [anon_sym_in] = ACTIONS(4705),
    [anon_sym_QMARK] = ACTIONS(4705),
    [anon_sym_BANG] = ACTIONS(4705),
    [anon_sym_PLUS_PLUS] = ACTIONS(4703),
    [anon_sym_DASH_DASH] = ACTIONS(4703),
    [anon_sym_PLUS] = ACTIONS(4705),
    [anon_sym_DASH] = ACTIONS(4705),
    [anon_sym_STAR] = ACTIONS(4705),
    [anon_sym_SLASH] = ACTIONS(4705),
    [anon_sym_PERCENT] = ACTIONS(4705),
    [anon_sym_CARET] = ACTIONS(4705),
    [anon_sym_PIPE] = ACTIONS(4705),
    [anon_sym_AMP] = ACTIONS(4705),
    [anon_sym_LT_LT] = ACTIONS(4705),
    [anon_sym_GT_GT] = ACTIONS(4705),
    [anon_sym_GT_GT_GT] = ACTIONS(4705),
    [anon_sym_EQ_EQ] = ACTIONS(4703),
    [anon_sym_BANG_EQ] = ACTIONS(4703),
    [anon_sym_GT_EQ] = ACTIONS(4703),
    [anon_sym_LT_EQ] = ACTIONS(4703),
    [anon_sym_DOT] = ACTIONS(4705),
    [anon_sym_EQ_GT] = ACTIONS(4703),
    [anon_sym_switch] = ACTIONS(4703),
    [anon_sym_when] = ACTIONS(4703),
    [anon_sym_DOT_DOT] = ACTIONS(4703),
    [anon_sym_and] = ACTIONS(4703),
    [anon_sym_or] = ACTIONS(4703),
    [anon_sym_PLUS_EQ] = ACTIONS(4670),
    [anon_sym_DASH_EQ] = ACTIONS(4670),
    [anon_sym_STAR_EQ] = ACTIONS(4670),
    [anon_sym_SLASH_EQ] = ACTIONS(4670),
    [anon_sym_PERCENT_EQ] = ACTIONS(4670),
    [anon_sym_AMP_EQ] = ACTIONS(4670),
    [anon_sym_CARET_EQ] = ACTIONS(4670),
    [anon_sym_PIPE_EQ] = ACTIONS(4670),
    [anon_sym_LT_LT_EQ] = ACTIONS(4670),
    [anon_sym_GT_GT_EQ] = ACTIONS(4670),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4670),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4670),
    [anon_sym_AMP_AMP] = ACTIONS(4703),
    [anon_sym_PIPE_PIPE] = ACTIONS(4703),
    [anon_sym_QMARK_QMARK] = ACTIONS(4705),
    [anon_sym_into] = ACTIONS(4703),
    [anon_sym_on] = ACTIONS(4703),
    [anon_sym_equals] = ACTIONS(4703),
    [anon_sym_by] = ACTIONS(4703),
    [anon_sym_as] = ACTIONS(4703),
    [anon_sym_is] = ACTIONS(4703),
    [anon_sym_DASH_GT] = ACTIONS(4703),
    [anon_sym_with] = ACTIONS(4703),
    [aux_sym_preproc_if_token3] = ACTIONS(4703),
    [aux_sym_preproc_else_token1] = ACTIONS(4703),
    [aux_sym_preproc_elif_token1] = ACTIONS(4703),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3221] = {
    [sym_preproc_region] = STATE(3221),
    [sym_preproc_endregion] = STATE(3221),
    [sym_preproc_line] = STATE(3221),
    [sym_preproc_pragma] = STATE(3221),
    [sym_preproc_nullable] = STATE(3221),
    [sym_preproc_error] = STATE(3221),
    [sym_preproc_warning] = STATE(3221),
    [sym_preproc_define] = STATE(3221),
    [sym_preproc_undef] = STATE(3221),
    [anon_sym_SEMI] = ACTIONS(3993),
    [anon_sym_EQ] = ACTIONS(3995),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_COLON] = ACTIONS(3993),
    [anon_sym_COMMA] = ACTIONS(3993),
    [anon_sym_RBRACK] = ACTIONS(3993),
    [anon_sym_LPAREN] = ACTIONS(3993),
    [anon_sym_RPAREN] = ACTIONS(3993),
    [anon_sym_RBRACE] = ACTIONS(3993),
    [anon_sym_LT] = ACTIONS(3995),
    [anon_sym_GT] = ACTIONS(3995),
    [anon_sym_in] = ACTIONS(3995),
    [anon_sym_QMARK] = ACTIONS(3995),
    [anon_sym_BANG] = ACTIONS(3995),
    [anon_sym_PLUS_PLUS] = ACTIONS(3993),
    [anon_sym_DASH_DASH] = ACTIONS(3993),
    [anon_sym_PLUS] = ACTIONS(3995),
    [anon_sym_DASH] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3995),
    [anon_sym_SLASH] = ACTIONS(3995),
    [anon_sym_PERCENT] = ACTIONS(3995),
    [anon_sym_CARET] = ACTIONS(3995),
    [anon_sym_PIPE] = ACTIONS(3995),
    [anon_sym_AMP] = ACTIONS(3995),
    [anon_sym_LT_LT] = ACTIONS(3995),
    [anon_sym_GT_GT] = ACTIONS(3995),
    [anon_sym_GT_GT_GT] = ACTIONS(3995),
    [anon_sym_EQ_EQ] = ACTIONS(3993),
    [anon_sym_BANG_EQ] = ACTIONS(3993),
    [anon_sym_GT_EQ] = ACTIONS(3993),
    [anon_sym_LT_EQ] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3995),
    [anon_sym_EQ_GT] = ACTIONS(3993),
    [anon_sym_switch] = ACTIONS(3993),
    [anon_sym_when] = ACTIONS(3993),
    [anon_sym_DOT_DOT] = ACTIONS(3993),
    [anon_sym_and] = ACTIONS(3993),
    [anon_sym_or] = ACTIONS(3993),
    [anon_sym_PLUS_EQ] = ACTIONS(3993),
    [anon_sym_DASH_EQ] = ACTIONS(3993),
    [anon_sym_STAR_EQ] = ACTIONS(3993),
    [anon_sym_SLASH_EQ] = ACTIONS(3993),
    [anon_sym_PERCENT_EQ] = ACTIONS(3993),
    [anon_sym_AMP_EQ] = ACTIONS(3993),
    [anon_sym_CARET_EQ] = ACTIONS(3993),
    [anon_sym_PIPE_EQ] = ACTIONS(3993),
    [anon_sym_LT_LT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(3993),
    [anon_sym_AMP_AMP] = ACTIONS(3993),
    [anon_sym_PIPE_PIPE] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK] = ACTIONS(3995),
    [anon_sym_into] = ACTIONS(3993),
    [anon_sym_on] = ACTIONS(3993),
    [anon_sym_equals] = ACTIONS(3993),
    [anon_sym_by] = ACTIONS(3993),
    [anon_sym_as] = ACTIONS(3993),
    [anon_sym_is] = ACTIONS(3993),
    [anon_sym_DASH_GT] = ACTIONS(3993),
    [anon_sym_with] = ACTIONS(3993),
    [aux_sym_preproc_if_token3] = ACTIONS(3993),
    [aux_sym_preproc_else_token1] = ACTIONS(3993),
    [aux_sym_preproc_elif_token1] = ACTIONS(3993),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3222] = {
    [sym__variable_designation] = STATE(4556),
    [sym_parenthesized_variable_designation] = STATE(4748),
    [sym_identifier] = STATE(4548),
    [sym__reserved_identifier] = STATE(2928),
    [sym_preproc_region] = STATE(3222),
    [sym_preproc_endregion] = STATE(3222),
    [sym_preproc_line] = STATE(3222),
    [sym_preproc_pragma] = STATE(3222),
    [sym_preproc_nullable] = STATE(3222),
    [sym_preproc_error] = STATE(3222),
    [sym_preproc_warning] = STATE(3222),
    [sym_preproc_define] = STATE(3222),
    [sym_preproc_undef] = STATE(3222),
    [sym__identifier_token] = ACTIONS(4536),
    [anon_sym_alias] = ACTIONS(4538),
    [anon_sym_global] = ACTIONS(4538),
    [anon_sym_LBRACK] = ACTIONS(4399),
    [anon_sym_COMMA] = ACTIONS(4399),
    [anon_sym_LPAREN] = ACTIONS(4399),
    [anon_sym_file] = ACTIONS(4538),
    [anon_sym_LT] = ACTIONS(4401),
    [anon_sym_GT] = ACTIONS(4401),
    [anon_sym_where] = ACTIONS(4401),
    [anon_sym_QMARK] = ACTIONS(4401),
    [anon_sym_notnull] = ACTIONS(4538),
    [anon_sym_unmanaged] = ACTIONS(4538),
    [anon_sym_BANG] = ACTIONS(4401),
    [anon_sym_PLUS_PLUS] = ACTIONS(4399),
    [anon_sym_DASH_DASH] = ACTIONS(4399),
    [anon_sym_PLUS] = ACTIONS(4401),
    [anon_sym_DASH] = ACTIONS(4401),
    [anon_sym_STAR] = ACTIONS(4399),
    [anon_sym_SLASH] = ACTIONS(4401),
    [anon_sym_PERCENT] = ACTIONS(4399),
    [anon_sym_CARET] = ACTIONS(4399),
    [anon_sym_PIPE] = ACTIONS(4401),
    [anon_sym_AMP] = ACTIONS(4401),
    [anon_sym_LT_LT] = ACTIONS(4399),
    [anon_sym_GT_GT] = ACTIONS(4401),
    [anon_sym_GT_GT_GT] = ACTIONS(4399),
    [anon_sym_EQ_EQ] = ACTIONS(4399),
    [anon_sym_BANG_EQ] = ACTIONS(4399),
    [anon_sym_GT_EQ] = ACTIONS(4399),
    [anon_sym_LT_EQ] = ACTIONS(4399),
    [anon_sym_DOT] = ACTIONS(4401),
    [anon_sym_scoped] = ACTIONS(4538),
    [anon_sym_var] = ACTIONS(4538),
    [anon_sym_yield] = ACTIONS(4538),
    [anon_sym_switch] = ACTIONS(4401),
    [anon_sym_when] = ACTIONS(4538),
    [sym_discard] = ACTIONS(4717),
    [anon_sym_DOT_DOT] = ACTIONS(4399),
    [anon_sym_and] = ACTIONS(4401),
    [anon_sym_or] = ACTIONS(4401),
    [anon_sym_AMP_AMP] = ACTIONS(4399),
    [anon_sym_PIPE_PIPE] = ACTIONS(4399),
    [anon_sym_QMARK_QMARK] = ACTIONS(4399),
    [anon_sym_from] = ACTIONS(4401),
    [anon_sym_into] = ACTIONS(4538),
    [anon_sym_join] = ACTIONS(4401),
    [anon_sym_on] = ACTIONS(4538),
    [anon_sym_equals] = ACTIONS(4538),
    [anon_sym_let] = ACTIONS(4401),
    [anon_sym_orderby] = ACTIONS(4401),
    [anon_sym_ascending] = ACTIONS(4401),
    [anon_sym_descending] = ACTIONS(4401),
    [anon_sym_group] = ACTIONS(4401),
    [anon_sym_by] = ACTIONS(4538),
    [anon_sym_select] = ACTIONS(4401),
    [anon_sym_as] = ACTIONS(4401),
    [anon_sym_is] = ACTIONS(4401),
    [anon_sym_DASH_GT] = ACTIONS(4399),
    [anon_sym_with] = ACTIONS(4401),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3223] = {
    [sym_preproc_region] = STATE(3223),
    [sym_preproc_endregion] = STATE(3223),
    [sym_preproc_line] = STATE(3223),
    [sym_preproc_pragma] = STATE(3223),
    [sym_preproc_nullable] = STATE(3223),
    [sym_preproc_error] = STATE(3223),
    [sym_preproc_warning] = STATE(3223),
    [sym_preproc_define] = STATE(3223),
    [sym_preproc_undef] = STATE(3223),
    [sym__identifier_token] = ACTIONS(4492),
    [anon_sym_alias] = ACTIONS(4492),
    [anon_sym_global] = ACTIONS(4492),
    [anon_sym_LBRACK] = ACTIONS(4593),
    [anon_sym_COLON] = ACTIONS(4494),
    [anon_sym_COMMA] = ACTIONS(4494),
    [anon_sym_LPAREN] = ACTIONS(4494),
    [anon_sym_RPAREN] = ACTIONS(4494),
    [anon_sym_LBRACE] = ACTIONS(4494),
    [anon_sym_RBRACE] = ACTIONS(4494),
    [anon_sym_file] = ACTIONS(4492),
    [anon_sym_LT] = ACTIONS(4492),
    [anon_sym_GT] = ACTIONS(4492),
    [anon_sym_where] = ACTIONS(4492),
    [anon_sym_QMARK] = ACTIONS(4596),
    [anon_sym_notnull] = ACTIONS(4492),
    [anon_sym_unmanaged] = ACTIONS(4492),
    [anon_sym_BANG] = ACTIONS(4492),
    [anon_sym_PLUS_PLUS] = ACTIONS(4494),
    [anon_sym_DASH_DASH] = ACTIONS(4494),
    [anon_sym_PLUS] = ACTIONS(4492),
    [anon_sym_DASH] = ACTIONS(4492),
    [anon_sym_STAR] = ACTIONS(4599),
    [anon_sym_SLASH] = ACTIONS(4492),
    [anon_sym_PERCENT] = ACTIONS(4494),
    [anon_sym_CARET] = ACTIONS(4494),
    [anon_sym_PIPE] = ACTIONS(4492),
    [anon_sym_AMP] = ACTIONS(4492),
    [anon_sym_LT_LT] = ACTIONS(4494),
    [anon_sym_GT_GT] = ACTIONS(4492),
    [anon_sym_GT_GT_GT] = ACTIONS(4494),
    [anon_sym_EQ_EQ] = ACTIONS(4494),
    [anon_sym_BANG_EQ] = ACTIONS(4494),
    [anon_sym_GT_EQ] = ACTIONS(4494),
    [anon_sym_LT_EQ] = ACTIONS(4494),
    [anon_sym_DOT] = ACTIONS(4832),
    [anon_sym_scoped] = ACTIONS(4492),
    [anon_sym_var] = ACTIONS(4492),
    [anon_sym_yield] = ACTIONS(4492),
    [anon_sym_switch] = ACTIONS(4492),
    [anon_sym_when] = ACTIONS(4492),
    [sym_discard] = ACTIONS(4492),
    [anon_sym_DOT_DOT] = ACTIONS(4494),
    [anon_sym_and] = ACTIONS(4492),
    [anon_sym_or] = ACTIONS(4492),
    [anon_sym_AMP_AMP] = ACTIONS(4494),
    [anon_sym_PIPE_PIPE] = ACTIONS(4494),
    [anon_sym_QMARK_QMARK] = ACTIONS(4494),
    [anon_sym_from] = ACTIONS(4492),
    [anon_sym_into] = ACTIONS(4492),
    [anon_sym_join] = ACTIONS(4492),
    [anon_sym_on] = ACTIONS(4492),
    [anon_sym_equals] = ACTIONS(4492),
    [anon_sym_let] = ACTIONS(4492),
    [anon_sym_orderby] = ACTIONS(4492),
    [anon_sym_ascending] = ACTIONS(4492),
    [anon_sym_descending] = ACTIONS(4492),
    [anon_sym_group] = ACTIONS(4492),
    [anon_sym_by] = ACTIONS(4492),
    [anon_sym_select] = ACTIONS(4492),
    [anon_sym_as] = ACTIONS(4492),
    [anon_sym_is] = ACTIONS(4492),
    [anon_sym_DASH_GT] = ACTIONS(4636),
    [anon_sym_with] = ACTIONS(4492),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3224] = {
    [sym_preproc_region] = STATE(3224),
    [sym_preproc_endregion] = STATE(3224),
    [sym_preproc_line] = STATE(3224),
    [sym_preproc_pragma] = STATE(3224),
    [sym_preproc_nullable] = STATE(3224),
    [sym_preproc_error] = STATE(3224),
    [sym_preproc_warning] = STATE(3224),
    [sym_preproc_define] = STATE(3224),
    [sym_preproc_undef] = STATE(3224),
    [sym__identifier_token] = ACTIONS(3995),
    [anon_sym_alias] = ACTIONS(3995),
    [anon_sym_global] = ACTIONS(3995),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_COLON] = ACTIONS(3993),
    [anon_sym_COMMA] = ACTIONS(3993),
    [anon_sym_LPAREN] = ACTIONS(3993),
    [anon_sym_RPAREN] = ACTIONS(3993),
    [anon_sym_LBRACE] = ACTIONS(3993),
    [anon_sym_RBRACE] = ACTIONS(3993),
    [anon_sym_file] = ACTIONS(3995),
    [anon_sym_LT] = ACTIONS(3995),
    [anon_sym_GT] = ACTIONS(3995),
    [anon_sym_where] = ACTIONS(3995),
    [anon_sym_QMARK] = ACTIONS(3995),
    [anon_sym_notnull] = ACTIONS(3995),
    [anon_sym_unmanaged] = ACTIONS(3995),
    [anon_sym_BANG] = ACTIONS(3995),
    [anon_sym_PLUS_PLUS] = ACTIONS(3993),
    [anon_sym_DASH_DASH] = ACTIONS(3993),
    [anon_sym_PLUS] = ACTIONS(3995),
    [anon_sym_DASH] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3993),
    [anon_sym_SLASH] = ACTIONS(3995),
    [anon_sym_PERCENT] = ACTIONS(3993),
    [anon_sym_CARET] = ACTIONS(3993),
    [anon_sym_PIPE] = ACTIONS(3995),
    [anon_sym_AMP] = ACTIONS(3995),
    [anon_sym_LT_LT] = ACTIONS(3993),
    [anon_sym_GT_GT] = ACTIONS(3995),
    [anon_sym_GT_GT_GT] = ACTIONS(3993),
    [anon_sym_EQ_EQ] = ACTIONS(3993),
    [anon_sym_BANG_EQ] = ACTIONS(3993),
    [anon_sym_GT_EQ] = ACTIONS(3993),
    [anon_sym_LT_EQ] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3995),
    [anon_sym_scoped] = ACTIONS(3995),
    [anon_sym_var] = ACTIONS(3995),
    [anon_sym_yield] = ACTIONS(3995),
    [anon_sym_switch] = ACTIONS(3995),
    [anon_sym_when] = ACTIONS(3995),
    [sym_discard] = ACTIONS(3995),
    [anon_sym_DOT_DOT] = ACTIONS(3993),
    [anon_sym_and] = ACTIONS(3995),
    [anon_sym_or] = ACTIONS(3995),
    [anon_sym_AMP_AMP] = ACTIONS(3993),
    [anon_sym_PIPE_PIPE] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK] = ACTIONS(3993),
    [anon_sym_from] = ACTIONS(3995),
    [anon_sym_into] = ACTIONS(3995),
    [anon_sym_join] = ACTIONS(3995),
    [anon_sym_on] = ACTIONS(3995),
    [anon_sym_equals] = ACTIONS(3995),
    [anon_sym_let] = ACTIONS(3995),
    [anon_sym_orderby] = ACTIONS(3995),
    [anon_sym_ascending] = ACTIONS(3995),
    [anon_sym_descending] = ACTIONS(3995),
    [anon_sym_group] = ACTIONS(3995),
    [anon_sym_by] = ACTIONS(3995),
    [anon_sym_select] = ACTIONS(3995),
    [anon_sym_as] = ACTIONS(3995),
    [anon_sym_is] = ACTIONS(3995),
    [anon_sym_DASH_GT] = ACTIONS(3993),
    [anon_sym_with] = ACTIONS(3995),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3225] = {
    [sym__variable_designation] = STATE(4207),
    [sym_parenthesized_variable_designation] = STATE(4153),
    [sym_identifier] = STATE(4156),
    [sym__reserved_identifier] = STATE(3911),
    [sym_preproc_region] = STATE(3225),
    [sym_preproc_endregion] = STATE(3225),
    [sym_preproc_line] = STATE(3225),
    [sym_preproc_pragma] = STATE(3225),
    [sym_preproc_nullable] = STATE(3225),
    [sym_preproc_error] = STATE(3225),
    [sym_preproc_warning] = STATE(3225),
    [sym_preproc_define] = STATE(3225),
    [sym_preproc_undef] = STATE(3225),
    [sym__identifier_token] = ACTIONS(4248),
    [anon_sym_alias] = ACTIONS(4250),
    [anon_sym_global] = ACTIONS(4250),
    [anon_sym_LBRACK] = ACTIONS(4437),
    [anon_sym_LPAREN] = ACTIONS(4437),
    [anon_sym_file] = ACTIONS(4250),
    [anon_sym_LT] = ACTIONS(4439),
    [anon_sym_GT] = ACTIONS(4439),
    [anon_sym_in] = ACTIONS(4439),
    [anon_sym_where] = ACTIONS(4250),
    [anon_sym_QMARK] = ACTIONS(4439),
    [anon_sym_notnull] = ACTIONS(4250),
    [anon_sym_unmanaged] = ACTIONS(4250),
    [anon_sym_BANG] = ACTIONS(4439),
    [anon_sym_PLUS_PLUS] = ACTIONS(4437),
    [anon_sym_DASH_DASH] = ACTIONS(4437),
    [anon_sym_PLUS] = ACTIONS(4439),
    [anon_sym_DASH] = ACTIONS(4439),
    [anon_sym_STAR] = ACTIONS(4437),
    [anon_sym_SLASH] = ACTIONS(4439),
    [anon_sym_PERCENT] = ACTIONS(4437),
    [anon_sym_CARET] = ACTIONS(4437),
    [anon_sym_PIPE] = ACTIONS(4439),
    [anon_sym_AMP] = ACTIONS(4439),
    [anon_sym_LT_LT] = ACTIONS(4437),
    [anon_sym_GT_GT] = ACTIONS(4439),
    [anon_sym_GT_GT_GT] = ACTIONS(4437),
    [anon_sym_EQ_EQ] = ACTIONS(4437),
    [anon_sym_BANG_EQ] = ACTIONS(4437),
    [anon_sym_GT_EQ] = ACTIONS(4437),
    [anon_sym_LT_EQ] = ACTIONS(4437),
    [anon_sym_DOT] = ACTIONS(4439),
    [anon_sym_scoped] = ACTIONS(4250),
    [anon_sym_var] = ACTIONS(4250),
    [anon_sym_yield] = ACTIONS(4250),
    [anon_sym_switch] = ACTIONS(4439),
    [anon_sym_when] = ACTIONS(4250),
    [sym_discard] = ACTIONS(4359),
    [anon_sym_DOT_DOT] = ACTIONS(4437),
    [anon_sym_and] = ACTIONS(4439),
    [anon_sym_or] = ACTIONS(4439),
    [anon_sym_AMP_AMP] = ACTIONS(4437),
    [anon_sym_PIPE_PIPE] = ACTIONS(4437),
    [anon_sym_QMARK_QMARK] = ACTIONS(4437),
    [anon_sym_from] = ACTIONS(4250),
    [anon_sym_into] = ACTIONS(4250),
    [anon_sym_join] = ACTIONS(4250),
    [anon_sym_on] = ACTIONS(4250),
    [anon_sym_equals] = ACTIONS(4250),
    [anon_sym_let] = ACTIONS(4250),
    [anon_sym_orderby] = ACTIONS(4250),
    [anon_sym_ascending] = ACTIONS(4250),
    [anon_sym_descending] = ACTIONS(4250),
    [anon_sym_group] = ACTIONS(4250),
    [anon_sym_by] = ACTIONS(4250),
    [anon_sym_select] = ACTIONS(4250),
    [anon_sym_as] = ACTIONS(4439),
    [anon_sym_is] = ACTIONS(4439),
    [anon_sym_DASH_GT] = ACTIONS(4437),
    [anon_sym_with] = ACTIONS(4439),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3226] = {
    [sym__variable_designation] = STATE(4190),
    [sym_parenthesized_variable_designation] = STATE(4153),
    [sym_identifier] = STATE(4156),
    [sym__reserved_identifier] = STATE(3911),
    [sym_preproc_region] = STATE(3226),
    [sym_preproc_endregion] = STATE(3226),
    [sym_preproc_line] = STATE(3226),
    [sym_preproc_pragma] = STATE(3226),
    [sym_preproc_nullable] = STATE(3226),
    [sym_preproc_error] = STATE(3226),
    [sym_preproc_warning] = STATE(3226),
    [sym_preproc_define] = STATE(3226),
    [sym_preproc_undef] = STATE(3226),
    [sym__identifier_token] = ACTIONS(4248),
    [anon_sym_alias] = ACTIONS(4250),
    [anon_sym_global] = ACTIONS(4250),
    [anon_sym_LBRACK] = ACTIONS(4441),
    [anon_sym_LPAREN] = ACTIONS(4441),
    [anon_sym_file] = ACTIONS(4250),
    [anon_sym_LT] = ACTIONS(4443),
    [anon_sym_GT] = ACTIONS(4443),
    [anon_sym_in] = ACTIONS(4443),
    [anon_sym_where] = ACTIONS(4250),
    [anon_sym_QMARK] = ACTIONS(4443),
    [anon_sym_notnull] = ACTIONS(4250),
    [anon_sym_unmanaged] = ACTIONS(4250),
    [anon_sym_BANG] = ACTIONS(4443),
    [anon_sym_PLUS_PLUS] = ACTIONS(4441),
    [anon_sym_DASH_DASH] = ACTIONS(4441),
    [anon_sym_PLUS] = ACTIONS(4443),
    [anon_sym_DASH] = ACTIONS(4443),
    [anon_sym_STAR] = ACTIONS(4441),
    [anon_sym_SLASH] = ACTIONS(4443),
    [anon_sym_PERCENT] = ACTIONS(4441),
    [anon_sym_CARET] = ACTIONS(4441),
    [anon_sym_PIPE] = ACTIONS(4443),
    [anon_sym_AMP] = ACTIONS(4443),
    [anon_sym_LT_LT] = ACTIONS(4441),
    [anon_sym_GT_GT] = ACTIONS(4443),
    [anon_sym_GT_GT_GT] = ACTIONS(4441),
    [anon_sym_EQ_EQ] = ACTIONS(4441),
    [anon_sym_BANG_EQ] = ACTIONS(4441),
    [anon_sym_GT_EQ] = ACTIONS(4441),
    [anon_sym_LT_EQ] = ACTIONS(4441),
    [anon_sym_DOT] = ACTIONS(4443),
    [anon_sym_scoped] = ACTIONS(4250),
    [anon_sym_var] = ACTIONS(4250),
    [anon_sym_yield] = ACTIONS(4250),
    [anon_sym_switch] = ACTIONS(4443),
    [anon_sym_when] = ACTIONS(4250),
    [sym_discard] = ACTIONS(4359),
    [anon_sym_DOT_DOT] = ACTIONS(4441),
    [anon_sym_and] = ACTIONS(4443),
    [anon_sym_or] = ACTIONS(4443),
    [anon_sym_AMP_AMP] = ACTIONS(4441),
    [anon_sym_PIPE_PIPE] = ACTIONS(4441),
    [anon_sym_QMARK_QMARK] = ACTIONS(4441),
    [anon_sym_from] = ACTIONS(4250),
    [anon_sym_into] = ACTIONS(4250),
    [anon_sym_join] = ACTIONS(4250),
    [anon_sym_on] = ACTIONS(4250),
    [anon_sym_equals] = ACTIONS(4250),
    [anon_sym_let] = ACTIONS(4250),
    [anon_sym_orderby] = ACTIONS(4250),
    [anon_sym_ascending] = ACTIONS(4250),
    [anon_sym_descending] = ACTIONS(4250),
    [anon_sym_group] = ACTIONS(4250),
    [anon_sym_by] = ACTIONS(4250),
    [anon_sym_select] = ACTIONS(4250),
    [anon_sym_as] = ACTIONS(4443),
    [anon_sym_is] = ACTIONS(4443),
    [anon_sym_DASH_GT] = ACTIONS(4441),
    [anon_sym_with] = ACTIONS(4443),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3227] = {
    [sym_preproc_region] = STATE(3227),
    [sym_preproc_endregion] = STATE(3227),
    [sym_preproc_line] = STATE(3227),
    [sym_preproc_pragma] = STATE(3227),
    [sym_preproc_nullable] = STATE(3227),
    [sym_preproc_error] = STATE(3227),
    [sym_preproc_warning] = STATE(3227),
    [sym_preproc_define] = STATE(3227),
    [sym_preproc_undef] = STATE(3227),
    [sym__identifier_token] = ACTIONS(3529),
    [anon_sym_extern] = ACTIONS(3529),
    [anon_sym_alias] = ACTIONS(3529),
    [anon_sym_global] = ACTIONS(3529),
    [anon_sym_using] = ACTIONS(3529),
    [anon_sym_unsafe] = ACTIONS(3529),
    [anon_sym_static] = ACTIONS(3529),
    [anon_sym_LBRACK] = ACTIONS(3531),
    [anon_sym_LPAREN] = ACTIONS(3531),
    [anon_sym_event] = ACTIONS(3529),
    [anon_sym_namespace] = ACTIONS(3529),
    [anon_sym_class] = ACTIONS(3529),
    [anon_sym_ref] = ACTIONS(3529),
    [anon_sym_struct] = ACTIONS(3529),
    [anon_sym_enum] = ACTIONS(3529),
    [anon_sym_RBRACE] = ACTIONS(3531),
    [anon_sym_interface] = ACTIONS(3529),
    [anon_sym_delegate] = ACTIONS(3529),
    [anon_sym_record] = ACTIONS(3529),
    [anon_sym_abstract] = ACTIONS(3529),
    [anon_sym_async] = ACTIONS(3529),
    [anon_sym_const] = ACTIONS(3529),
    [anon_sym_file] = ACTIONS(3529),
    [anon_sym_fixed] = ACTIONS(3529),
    [anon_sym_internal] = ACTIONS(3529),
    [anon_sym_new] = ACTIONS(3529),
    [anon_sym_override] = ACTIONS(3529),
    [anon_sym_partial] = ACTIONS(3529),
    [anon_sym_private] = ACTIONS(3529),
    [anon_sym_protected] = ACTIONS(3529),
    [anon_sym_public] = ACTIONS(3529),
    [anon_sym_readonly] = ACTIONS(3529),
    [anon_sym_required] = ACTIONS(3529),
    [anon_sym_sealed] = ACTIONS(3529),
    [anon_sym_virtual] = ACTIONS(3529),
    [anon_sym_volatile] = ACTIONS(3529),
    [anon_sym_where] = ACTIONS(3529),
    [anon_sym_notnull] = ACTIONS(3529),
    [anon_sym_unmanaged] = ACTIONS(3529),
    [anon_sym_TILDE] = ACTIONS(3531),
    [anon_sym_implicit] = ACTIONS(3529),
    [anon_sym_explicit] = ACTIONS(3529),
    [anon_sym_scoped] = ACTIONS(3529),
    [anon_sym_var] = ACTIONS(3529),
    [sym_predefined_type] = ACTIONS(3529),
    [anon_sym_yield] = ACTIONS(3529),
    [anon_sym_when] = ACTIONS(3529),
    [anon_sym_from] = ACTIONS(3529),
    [anon_sym_into] = ACTIONS(3529),
    [anon_sym_join] = ACTIONS(3529),
    [anon_sym_on] = ACTIONS(3529),
    [anon_sym_equals] = ACTIONS(3529),
    [anon_sym_let] = ACTIONS(3529),
    [anon_sym_orderby] = ACTIONS(3529),
    [anon_sym_ascending] = ACTIONS(3529),
    [anon_sym_descending] = ACTIONS(3529),
    [anon_sym_group] = ACTIONS(3529),
    [anon_sym_by] = ACTIONS(3529),
    [anon_sym_select] = ACTIONS(3529),
    [aux_sym_preproc_if_token1] = ACTIONS(3531),
    [aux_sym_preproc_if_token3] = ACTIONS(3531),
    [aux_sym_preproc_else_token1] = ACTIONS(3531),
    [aux_sym_preproc_elif_token1] = ACTIONS(3531),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3228] = {
    [sym_preproc_region] = STATE(3228),
    [sym_preproc_endregion] = STATE(3228),
    [sym_preproc_line] = STATE(3228),
    [sym_preproc_pragma] = STATE(3228),
    [sym_preproc_nullable] = STATE(3228),
    [sym_preproc_error] = STATE(3228),
    [sym_preproc_warning] = STATE(3228),
    [sym_preproc_define] = STATE(3228),
    [sym_preproc_undef] = STATE(3228),
    [sym__identifier_token] = ACTIONS(3741),
    [anon_sym_extern] = ACTIONS(3741),
    [anon_sym_alias] = ACTIONS(3741),
    [anon_sym_global] = ACTIONS(3741),
    [anon_sym_using] = ACTIONS(3741),
    [anon_sym_unsafe] = ACTIONS(3741),
    [anon_sym_static] = ACTIONS(3741),
    [anon_sym_LBRACK] = ACTIONS(3743),
    [anon_sym_LPAREN] = ACTIONS(3743),
    [anon_sym_event] = ACTIONS(3741),
    [anon_sym_namespace] = ACTIONS(3741),
    [anon_sym_class] = ACTIONS(3741),
    [anon_sym_ref] = ACTIONS(3741),
    [anon_sym_struct] = ACTIONS(3741),
    [anon_sym_enum] = ACTIONS(3741),
    [anon_sym_RBRACE] = ACTIONS(3743),
    [anon_sym_interface] = ACTIONS(3741),
    [anon_sym_delegate] = ACTIONS(3741),
    [anon_sym_record] = ACTIONS(3741),
    [anon_sym_abstract] = ACTIONS(3741),
    [anon_sym_async] = ACTIONS(3741),
    [anon_sym_const] = ACTIONS(3741),
    [anon_sym_file] = ACTIONS(3741),
    [anon_sym_fixed] = ACTIONS(3741),
    [anon_sym_internal] = ACTIONS(3741),
    [anon_sym_new] = ACTIONS(3741),
    [anon_sym_override] = ACTIONS(3741),
    [anon_sym_partial] = ACTIONS(3741),
    [anon_sym_private] = ACTIONS(3741),
    [anon_sym_protected] = ACTIONS(3741),
    [anon_sym_public] = ACTIONS(3741),
    [anon_sym_readonly] = ACTIONS(3741),
    [anon_sym_required] = ACTIONS(3741),
    [anon_sym_sealed] = ACTIONS(3741),
    [anon_sym_virtual] = ACTIONS(3741),
    [anon_sym_volatile] = ACTIONS(3741),
    [anon_sym_where] = ACTIONS(3741),
    [anon_sym_notnull] = ACTIONS(3741),
    [anon_sym_unmanaged] = ACTIONS(3741),
    [anon_sym_TILDE] = ACTIONS(3743),
    [anon_sym_implicit] = ACTIONS(3741),
    [anon_sym_explicit] = ACTIONS(3741),
    [anon_sym_scoped] = ACTIONS(3741),
    [anon_sym_var] = ACTIONS(3741),
    [sym_predefined_type] = ACTIONS(3741),
    [anon_sym_yield] = ACTIONS(3741),
    [anon_sym_when] = ACTIONS(3741),
    [anon_sym_from] = ACTIONS(3741),
    [anon_sym_into] = ACTIONS(3741),
    [anon_sym_join] = ACTIONS(3741),
    [anon_sym_on] = ACTIONS(3741),
    [anon_sym_equals] = ACTIONS(3741),
    [anon_sym_let] = ACTIONS(3741),
    [anon_sym_orderby] = ACTIONS(3741),
    [anon_sym_ascending] = ACTIONS(3741),
    [anon_sym_descending] = ACTIONS(3741),
    [anon_sym_group] = ACTIONS(3741),
    [anon_sym_by] = ACTIONS(3741),
    [anon_sym_select] = ACTIONS(3741),
    [aux_sym_preproc_if_token1] = ACTIONS(3743),
    [aux_sym_preproc_if_token3] = ACTIONS(3743),
    [aux_sym_preproc_else_token1] = ACTIONS(3743),
    [aux_sym_preproc_elif_token1] = ACTIONS(3743),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3229] = {
    [sym_preproc_region] = STATE(3229),
    [sym_preproc_endregion] = STATE(3229),
    [sym_preproc_line] = STATE(3229),
    [sym_preproc_pragma] = STATE(3229),
    [sym_preproc_nullable] = STATE(3229),
    [sym_preproc_error] = STATE(3229),
    [sym_preproc_warning] = STATE(3229),
    [sym_preproc_define] = STATE(3229),
    [sym_preproc_undef] = STATE(3229),
    [sym__identifier_token] = ACTIONS(4552),
    [anon_sym_alias] = ACTIONS(4552),
    [anon_sym_global] = ACTIONS(4552),
    [anon_sym_LBRACK] = ACTIONS(4554),
    [anon_sym_COLON] = ACTIONS(4554),
    [anon_sym_COMMA] = ACTIONS(4554),
    [anon_sym_LPAREN] = ACTIONS(4554),
    [anon_sym_LBRACE] = ACTIONS(4554),
    [anon_sym_file] = ACTIONS(4552),
    [anon_sym_LT] = ACTIONS(4552),
    [anon_sym_GT] = ACTIONS(4552),
    [anon_sym_where] = ACTIONS(4552),
    [anon_sym_QMARK] = ACTIONS(4552),
    [anon_sym_notnull] = ACTIONS(4552),
    [anon_sym_unmanaged] = ACTIONS(4552),
    [anon_sym_BANG] = ACTIONS(4552),
    [anon_sym_PLUS_PLUS] = ACTIONS(4554),
    [anon_sym_DASH_DASH] = ACTIONS(4554),
    [anon_sym_PLUS] = ACTIONS(4552),
    [anon_sym_DASH] = ACTIONS(4552),
    [anon_sym_STAR] = ACTIONS(4554),
    [anon_sym_SLASH] = ACTIONS(4552),
    [anon_sym_PERCENT] = ACTIONS(4554),
    [anon_sym_CARET] = ACTIONS(4554),
    [anon_sym_PIPE] = ACTIONS(4552),
    [anon_sym_AMP] = ACTIONS(4552),
    [anon_sym_LT_LT] = ACTIONS(4554),
    [anon_sym_GT_GT] = ACTIONS(4552),
    [anon_sym_GT_GT_GT] = ACTIONS(4554),
    [anon_sym_EQ_EQ] = ACTIONS(4554),
    [anon_sym_BANG_EQ] = ACTIONS(4554),
    [anon_sym_GT_EQ] = ACTIONS(4554),
    [anon_sym_LT_EQ] = ACTIONS(4554),
    [anon_sym_DOT] = ACTIONS(4552),
    [anon_sym_scoped] = ACTIONS(4552),
    [anon_sym_var] = ACTIONS(4552),
    [anon_sym_yield] = ACTIONS(4552),
    [anon_sym_switch] = ACTIONS(4552),
    [anon_sym_when] = ACTIONS(4552),
    [sym_discard] = ACTIONS(4552),
    [anon_sym_DOT_DOT] = ACTIONS(4554),
    [anon_sym_and] = ACTIONS(4552),
    [anon_sym_or] = ACTIONS(4552),
    [anon_sym_AMP_AMP] = ACTIONS(4554),
    [anon_sym_PIPE_PIPE] = ACTIONS(4554),
    [anon_sym_QMARK_QMARK] = ACTIONS(4554),
    [anon_sym_from] = ACTIONS(4552),
    [anon_sym_into] = ACTIONS(4552),
    [anon_sym_join] = ACTIONS(4552),
    [anon_sym_on] = ACTIONS(4552),
    [anon_sym_equals] = ACTIONS(4552),
    [anon_sym_let] = ACTIONS(4552),
    [anon_sym_orderby] = ACTIONS(4552),
    [anon_sym_ascending] = ACTIONS(4552),
    [anon_sym_descending] = ACTIONS(4552),
    [anon_sym_group] = ACTIONS(4552),
    [anon_sym_by] = ACTIONS(4552),
    [anon_sym_select] = ACTIONS(4552),
    [anon_sym_as] = ACTIONS(4552),
    [anon_sym_is] = ACTIONS(4552),
    [anon_sym_DASH_GT] = ACTIONS(4554),
    [anon_sym_with] = ACTIONS(4552),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4554),
  },
  [3230] = {
    [sym_preproc_region] = STATE(3230),
    [sym_preproc_endregion] = STATE(3230),
    [sym_preproc_line] = STATE(3230),
    [sym_preproc_pragma] = STATE(3230),
    [sym_preproc_nullable] = STATE(3230),
    [sym_preproc_error] = STATE(3230),
    [sym_preproc_warning] = STATE(3230),
    [sym_preproc_define] = STATE(3230),
    [sym_preproc_undef] = STATE(3230),
    [sym__identifier_token] = ACTIONS(3745),
    [anon_sym_extern] = ACTIONS(3745),
    [anon_sym_alias] = ACTIONS(3745),
    [anon_sym_global] = ACTIONS(3745),
    [anon_sym_using] = ACTIONS(3745),
    [anon_sym_unsafe] = ACTIONS(3745),
    [anon_sym_static] = ACTIONS(3745),
    [anon_sym_LBRACK] = ACTIONS(3747),
    [anon_sym_LPAREN] = ACTIONS(3747),
    [anon_sym_event] = ACTIONS(3745),
    [anon_sym_namespace] = ACTIONS(3745),
    [anon_sym_class] = ACTIONS(3745),
    [anon_sym_ref] = ACTIONS(3745),
    [anon_sym_struct] = ACTIONS(3745),
    [anon_sym_enum] = ACTIONS(3745),
    [anon_sym_RBRACE] = ACTIONS(3747),
    [anon_sym_interface] = ACTIONS(3745),
    [anon_sym_delegate] = ACTIONS(3745),
    [anon_sym_record] = ACTIONS(3745),
    [anon_sym_abstract] = ACTIONS(3745),
    [anon_sym_async] = ACTIONS(3745),
    [anon_sym_const] = ACTIONS(3745),
    [anon_sym_file] = ACTIONS(3745),
    [anon_sym_fixed] = ACTIONS(3745),
    [anon_sym_internal] = ACTIONS(3745),
    [anon_sym_new] = ACTIONS(3745),
    [anon_sym_override] = ACTIONS(3745),
    [anon_sym_partial] = ACTIONS(3745),
    [anon_sym_private] = ACTIONS(3745),
    [anon_sym_protected] = ACTIONS(3745),
    [anon_sym_public] = ACTIONS(3745),
    [anon_sym_readonly] = ACTIONS(3745),
    [anon_sym_required] = ACTIONS(3745),
    [anon_sym_sealed] = ACTIONS(3745),
    [anon_sym_virtual] = ACTIONS(3745),
    [anon_sym_volatile] = ACTIONS(3745),
    [anon_sym_where] = ACTIONS(3745),
    [anon_sym_notnull] = ACTIONS(3745),
    [anon_sym_unmanaged] = ACTIONS(3745),
    [anon_sym_TILDE] = ACTIONS(3747),
    [anon_sym_implicit] = ACTIONS(3745),
    [anon_sym_explicit] = ACTIONS(3745),
    [anon_sym_scoped] = ACTIONS(3745),
    [anon_sym_var] = ACTIONS(3745),
    [sym_predefined_type] = ACTIONS(3745),
    [anon_sym_yield] = ACTIONS(3745),
    [anon_sym_when] = ACTIONS(3745),
    [anon_sym_from] = ACTIONS(3745),
    [anon_sym_into] = ACTIONS(3745),
    [anon_sym_join] = ACTIONS(3745),
    [anon_sym_on] = ACTIONS(3745),
    [anon_sym_equals] = ACTIONS(3745),
    [anon_sym_let] = ACTIONS(3745),
    [anon_sym_orderby] = ACTIONS(3745),
    [anon_sym_ascending] = ACTIONS(3745),
    [anon_sym_descending] = ACTIONS(3745),
    [anon_sym_group] = ACTIONS(3745),
    [anon_sym_by] = ACTIONS(3745),
    [anon_sym_select] = ACTIONS(3745),
    [aux_sym_preproc_if_token1] = ACTIONS(3747),
    [aux_sym_preproc_if_token3] = ACTIONS(3747),
    [aux_sym_preproc_else_token1] = ACTIONS(3747),
    [aux_sym_preproc_elif_token1] = ACTIONS(3747),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3231] = {
    [sym_preproc_region] = STATE(3231),
    [sym_preproc_endregion] = STATE(3231),
    [sym_preproc_line] = STATE(3231),
    [sym_preproc_pragma] = STATE(3231),
    [sym_preproc_nullable] = STATE(3231),
    [sym_preproc_error] = STATE(3231),
    [sym_preproc_warning] = STATE(3231),
    [sym_preproc_define] = STATE(3231),
    [sym_preproc_undef] = STATE(3231),
    [sym__identifier_token] = ACTIONS(3749),
    [anon_sym_extern] = ACTIONS(3749),
    [anon_sym_alias] = ACTIONS(3749),
    [anon_sym_global] = ACTIONS(3749),
    [anon_sym_using] = ACTIONS(3749),
    [anon_sym_unsafe] = ACTIONS(3749),
    [anon_sym_static] = ACTIONS(3749),
    [anon_sym_LBRACK] = ACTIONS(3751),
    [anon_sym_LPAREN] = ACTIONS(3751),
    [anon_sym_event] = ACTIONS(3749),
    [anon_sym_namespace] = ACTIONS(3749),
    [anon_sym_class] = ACTIONS(3749),
    [anon_sym_ref] = ACTIONS(3749),
    [anon_sym_struct] = ACTIONS(3749),
    [anon_sym_enum] = ACTIONS(3749),
    [anon_sym_RBRACE] = ACTIONS(3751),
    [anon_sym_interface] = ACTIONS(3749),
    [anon_sym_delegate] = ACTIONS(3749),
    [anon_sym_record] = ACTIONS(3749),
    [anon_sym_abstract] = ACTIONS(3749),
    [anon_sym_async] = ACTIONS(3749),
    [anon_sym_const] = ACTIONS(3749),
    [anon_sym_file] = ACTIONS(3749),
    [anon_sym_fixed] = ACTIONS(3749),
    [anon_sym_internal] = ACTIONS(3749),
    [anon_sym_new] = ACTIONS(3749),
    [anon_sym_override] = ACTIONS(3749),
    [anon_sym_partial] = ACTIONS(3749),
    [anon_sym_private] = ACTIONS(3749),
    [anon_sym_protected] = ACTIONS(3749),
    [anon_sym_public] = ACTIONS(3749),
    [anon_sym_readonly] = ACTIONS(3749),
    [anon_sym_required] = ACTIONS(3749),
    [anon_sym_sealed] = ACTIONS(3749),
    [anon_sym_virtual] = ACTIONS(3749),
    [anon_sym_volatile] = ACTIONS(3749),
    [anon_sym_where] = ACTIONS(3749),
    [anon_sym_notnull] = ACTIONS(3749),
    [anon_sym_unmanaged] = ACTIONS(3749),
    [anon_sym_TILDE] = ACTIONS(3751),
    [anon_sym_implicit] = ACTIONS(3749),
    [anon_sym_explicit] = ACTIONS(3749),
    [anon_sym_scoped] = ACTIONS(3749),
    [anon_sym_var] = ACTIONS(3749),
    [sym_predefined_type] = ACTIONS(3749),
    [anon_sym_yield] = ACTIONS(3749),
    [anon_sym_when] = ACTIONS(3749),
    [anon_sym_from] = ACTIONS(3749),
    [anon_sym_into] = ACTIONS(3749),
    [anon_sym_join] = ACTIONS(3749),
    [anon_sym_on] = ACTIONS(3749),
    [anon_sym_equals] = ACTIONS(3749),
    [anon_sym_let] = ACTIONS(3749),
    [anon_sym_orderby] = ACTIONS(3749),
    [anon_sym_ascending] = ACTIONS(3749),
    [anon_sym_descending] = ACTIONS(3749),
    [anon_sym_group] = ACTIONS(3749),
    [anon_sym_by] = ACTIONS(3749),
    [anon_sym_select] = ACTIONS(3749),
    [aux_sym_preproc_if_token1] = ACTIONS(3751),
    [aux_sym_preproc_if_token3] = ACTIONS(3751),
    [aux_sym_preproc_else_token1] = ACTIONS(3751),
    [aux_sym_preproc_elif_token1] = ACTIONS(3751),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3232] = {
    [sym_preproc_region] = STATE(3232),
    [sym_preproc_endregion] = STATE(3232),
    [sym_preproc_line] = STATE(3232),
    [sym_preproc_pragma] = STATE(3232),
    [sym_preproc_nullable] = STATE(3232),
    [sym_preproc_error] = STATE(3232),
    [sym_preproc_warning] = STATE(3232),
    [sym_preproc_define] = STATE(3232),
    [sym_preproc_undef] = STATE(3232),
    [sym__identifier_token] = ACTIONS(3753),
    [anon_sym_extern] = ACTIONS(3753),
    [anon_sym_alias] = ACTIONS(3753),
    [anon_sym_global] = ACTIONS(3753),
    [anon_sym_using] = ACTIONS(3753),
    [anon_sym_unsafe] = ACTIONS(3753),
    [anon_sym_static] = ACTIONS(3753),
    [anon_sym_LBRACK] = ACTIONS(3755),
    [anon_sym_LPAREN] = ACTIONS(3755),
    [anon_sym_event] = ACTIONS(3753),
    [anon_sym_namespace] = ACTIONS(3753),
    [anon_sym_class] = ACTIONS(3753),
    [anon_sym_ref] = ACTIONS(3753),
    [anon_sym_struct] = ACTIONS(3753),
    [anon_sym_enum] = ACTIONS(3753),
    [anon_sym_RBRACE] = ACTIONS(3755),
    [anon_sym_interface] = ACTIONS(3753),
    [anon_sym_delegate] = ACTIONS(3753),
    [anon_sym_record] = ACTIONS(3753),
    [anon_sym_abstract] = ACTIONS(3753),
    [anon_sym_async] = ACTIONS(3753),
    [anon_sym_const] = ACTIONS(3753),
    [anon_sym_file] = ACTIONS(3753),
    [anon_sym_fixed] = ACTIONS(3753),
    [anon_sym_internal] = ACTIONS(3753),
    [anon_sym_new] = ACTIONS(3753),
    [anon_sym_override] = ACTIONS(3753),
    [anon_sym_partial] = ACTIONS(3753),
    [anon_sym_private] = ACTIONS(3753),
    [anon_sym_protected] = ACTIONS(3753),
    [anon_sym_public] = ACTIONS(3753),
    [anon_sym_readonly] = ACTIONS(3753),
    [anon_sym_required] = ACTIONS(3753),
    [anon_sym_sealed] = ACTIONS(3753),
    [anon_sym_virtual] = ACTIONS(3753),
    [anon_sym_volatile] = ACTIONS(3753),
    [anon_sym_where] = ACTIONS(3753),
    [anon_sym_notnull] = ACTIONS(3753),
    [anon_sym_unmanaged] = ACTIONS(3753),
    [anon_sym_TILDE] = ACTIONS(3755),
    [anon_sym_implicit] = ACTIONS(3753),
    [anon_sym_explicit] = ACTIONS(3753),
    [anon_sym_scoped] = ACTIONS(3753),
    [anon_sym_var] = ACTIONS(3753),
    [sym_predefined_type] = ACTIONS(3753),
    [anon_sym_yield] = ACTIONS(3753),
    [anon_sym_when] = ACTIONS(3753),
    [anon_sym_from] = ACTIONS(3753),
    [anon_sym_into] = ACTIONS(3753),
    [anon_sym_join] = ACTIONS(3753),
    [anon_sym_on] = ACTIONS(3753),
    [anon_sym_equals] = ACTIONS(3753),
    [anon_sym_let] = ACTIONS(3753),
    [anon_sym_orderby] = ACTIONS(3753),
    [anon_sym_ascending] = ACTIONS(3753),
    [anon_sym_descending] = ACTIONS(3753),
    [anon_sym_group] = ACTIONS(3753),
    [anon_sym_by] = ACTIONS(3753),
    [anon_sym_select] = ACTIONS(3753),
    [aux_sym_preproc_if_token1] = ACTIONS(3755),
    [aux_sym_preproc_if_token3] = ACTIONS(3755),
    [aux_sym_preproc_else_token1] = ACTIONS(3755),
    [aux_sym_preproc_elif_token1] = ACTIONS(3755),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3233] = {
    [sym_preproc_region] = STATE(3233),
    [sym_preproc_endregion] = STATE(3233),
    [sym_preproc_line] = STATE(3233),
    [sym_preproc_pragma] = STATE(3233),
    [sym_preproc_nullable] = STATE(3233),
    [sym_preproc_error] = STATE(3233),
    [sym_preproc_warning] = STATE(3233),
    [sym_preproc_define] = STATE(3233),
    [sym_preproc_undef] = STATE(3233),
    [sym__identifier_token] = ACTIONS(3757),
    [anon_sym_extern] = ACTIONS(3757),
    [anon_sym_alias] = ACTIONS(3757),
    [anon_sym_global] = ACTIONS(3757),
    [anon_sym_using] = ACTIONS(3757),
    [anon_sym_unsafe] = ACTIONS(3757),
    [anon_sym_static] = ACTIONS(3757),
    [anon_sym_LBRACK] = ACTIONS(3759),
    [anon_sym_LPAREN] = ACTIONS(3759),
    [anon_sym_event] = ACTIONS(3757),
    [anon_sym_namespace] = ACTIONS(3757),
    [anon_sym_class] = ACTIONS(3757),
    [anon_sym_ref] = ACTIONS(3757),
    [anon_sym_struct] = ACTIONS(3757),
    [anon_sym_enum] = ACTIONS(3757),
    [anon_sym_RBRACE] = ACTIONS(3759),
    [anon_sym_interface] = ACTIONS(3757),
    [anon_sym_delegate] = ACTIONS(3757),
    [anon_sym_record] = ACTIONS(3757),
    [anon_sym_abstract] = ACTIONS(3757),
    [anon_sym_async] = ACTIONS(3757),
    [anon_sym_const] = ACTIONS(3757),
    [anon_sym_file] = ACTIONS(3757),
    [anon_sym_fixed] = ACTIONS(3757),
    [anon_sym_internal] = ACTIONS(3757),
    [anon_sym_new] = ACTIONS(3757),
    [anon_sym_override] = ACTIONS(3757),
    [anon_sym_partial] = ACTIONS(3757),
    [anon_sym_private] = ACTIONS(3757),
    [anon_sym_protected] = ACTIONS(3757),
    [anon_sym_public] = ACTIONS(3757),
    [anon_sym_readonly] = ACTIONS(3757),
    [anon_sym_required] = ACTIONS(3757),
    [anon_sym_sealed] = ACTIONS(3757),
    [anon_sym_virtual] = ACTIONS(3757),
    [anon_sym_volatile] = ACTIONS(3757),
    [anon_sym_where] = ACTIONS(3757),
    [anon_sym_notnull] = ACTIONS(3757),
    [anon_sym_unmanaged] = ACTIONS(3757),
    [anon_sym_TILDE] = ACTIONS(3759),
    [anon_sym_implicit] = ACTIONS(3757),
    [anon_sym_explicit] = ACTIONS(3757),
    [anon_sym_scoped] = ACTIONS(3757),
    [anon_sym_var] = ACTIONS(3757),
    [sym_predefined_type] = ACTIONS(3757),
    [anon_sym_yield] = ACTIONS(3757),
    [anon_sym_when] = ACTIONS(3757),
    [anon_sym_from] = ACTIONS(3757),
    [anon_sym_into] = ACTIONS(3757),
    [anon_sym_join] = ACTIONS(3757),
    [anon_sym_on] = ACTIONS(3757),
    [anon_sym_equals] = ACTIONS(3757),
    [anon_sym_let] = ACTIONS(3757),
    [anon_sym_orderby] = ACTIONS(3757),
    [anon_sym_ascending] = ACTIONS(3757),
    [anon_sym_descending] = ACTIONS(3757),
    [anon_sym_group] = ACTIONS(3757),
    [anon_sym_by] = ACTIONS(3757),
    [anon_sym_select] = ACTIONS(3757),
    [aux_sym_preproc_if_token1] = ACTIONS(3759),
    [aux_sym_preproc_if_token3] = ACTIONS(3759),
    [aux_sym_preproc_else_token1] = ACTIONS(3759),
    [aux_sym_preproc_elif_token1] = ACTIONS(3759),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3234] = {
    [sym_preproc_region] = STATE(3234),
    [sym_preproc_endregion] = STATE(3234),
    [sym_preproc_line] = STATE(3234),
    [sym_preproc_pragma] = STATE(3234),
    [sym_preproc_nullable] = STATE(3234),
    [sym_preproc_error] = STATE(3234),
    [sym_preproc_warning] = STATE(3234),
    [sym_preproc_define] = STATE(3234),
    [sym_preproc_undef] = STATE(3234),
    [sym__identifier_token] = ACTIONS(4624),
    [anon_sym_alias] = ACTIONS(4624),
    [anon_sym_global] = ACTIONS(4624),
    [anon_sym_LBRACK] = ACTIONS(4626),
    [anon_sym_COLON] = ACTIONS(4626),
    [anon_sym_COMMA] = ACTIONS(4626),
    [anon_sym_LPAREN] = ACTIONS(4626),
    [anon_sym_LBRACE] = ACTIONS(4626),
    [anon_sym_file] = ACTIONS(4624),
    [anon_sym_LT] = ACTIONS(4624),
    [anon_sym_GT] = ACTIONS(4624),
    [anon_sym_where] = ACTIONS(4624),
    [anon_sym_QMARK] = ACTIONS(4624),
    [anon_sym_notnull] = ACTIONS(4624),
    [anon_sym_unmanaged] = ACTIONS(4624),
    [anon_sym_BANG] = ACTIONS(4624),
    [anon_sym_PLUS_PLUS] = ACTIONS(4626),
    [anon_sym_DASH_DASH] = ACTIONS(4626),
    [anon_sym_PLUS] = ACTIONS(4624),
    [anon_sym_DASH] = ACTIONS(4624),
    [anon_sym_STAR] = ACTIONS(4626),
    [anon_sym_SLASH] = ACTIONS(4624),
    [anon_sym_PERCENT] = ACTIONS(4626),
    [anon_sym_CARET] = ACTIONS(4626),
    [anon_sym_PIPE] = ACTIONS(4624),
    [anon_sym_AMP] = ACTIONS(4624),
    [anon_sym_LT_LT] = ACTIONS(4626),
    [anon_sym_GT_GT] = ACTIONS(4624),
    [anon_sym_GT_GT_GT] = ACTIONS(4626),
    [anon_sym_EQ_EQ] = ACTIONS(4626),
    [anon_sym_BANG_EQ] = ACTIONS(4626),
    [anon_sym_GT_EQ] = ACTIONS(4626),
    [anon_sym_LT_EQ] = ACTIONS(4626),
    [anon_sym_DOT] = ACTIONS(4624),
    [anon_sym_scoped] = ACTIONS(4624),
    [anon_sym_var] = ACTIONS(4624),
    [anon_sym_yield] = ACTIONS(4624),
    [anon_sym_switch] = ACTIONS(4624),
    [anon_sym_when] = ACTIONS(4624),
    [sym_discard] = ACTIONS(4624),
    [anon_sym_DOT_DOT] = ACTIONS(4626),
    [anon_sym_and] = ACTIONS(4624),
    [anon_sym_or] = ACTIONS(4624),
    [anon_sym_AMP_AMP] = ACTIONS(4626),
    [anon_sym_PIPE_PIPE] = ACTIONS(4626),
    [anon_sym_QMARK_QMARK] = ACTIONS(4626),
    [anon_sym_from] = ACTIONS(4624),
    [anon_sym_into] = ACTIONS(4624),
    [anon_sym_join] = ACTIONS(4624),
    [anon_sym_on] = ACTIONS(4624),
    [anon_sym_equals] = ACTIONS(4624),
    [anon_sym_let] = ACTIONS(4624),
    [anon_sym_orderby] = ACTIONS(4624),
    [anon_sym_ascending] = ACTIONS(4624),
    [anon_sym_descending] = ACTIONS(4624),
    [anon_sym_group] = ACTIONS(4624),
    [anon_sym_by] = ACTIONS(4624),
    [anon_sym_select] = ACTIONS(4624),
    [anon_sym_as] = ACTIONS(4624),
    [anon_sym_is] = ACTIONS(4624),
    [anon_sym_DASH_GT] = ACTIONS(4626),
    [anon_sym_with] = ACTIONS(4624),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4626),
  },
  [3235] = {
    [sym_preproc_region] = STATE(3235),
    [sym_preproc_endregion] = STATE(3235),
    [sym_preproc_line] = STATE(3235),
    [sym_preproc_pragma] = STATE(3235),
    [sym_preproc_nullable] = STATE(3235),
    [sym_preproc_error] = STATE(3235),
    [sym_preproc_warning] = STATE(3235),
    [sym_preproc_define] = STATE(3235),
    [sym_preproc_undef] = STATE(3235),
    [sym__identifier_token] = ACTIONS(3761),
    [anon_sym_extern] = ACTIONS(3761),
    [anon_sym_alias] = ACTIONS(3761),
    [anon_sym_global] = ACTIONS(3761),
    [anon_sym_using] = ACTIONS(3761),
    [anon_sym_unsafe] = ACTIONS(3761),
    [anon_sym_static] = ACTIONS(3761),
    [anon_sym_LBRACK] = ACTIONS(3763),
    [anon_sym_LPAREN] = ACTIONS(3763),
    [anon_sym_event] = ACTIONS(3761),
    [anon_sym_namespace] = ACTIONS(3761),
    [anon_sym_class] = ACTIONS(3761),
    [anon_sym_ref] = ACTIONS(3761),
    [anon_sym_struct] = ACTIONS(3761),
    [anon_sym_enum] = ACTIONS(3761),
    [anon_sym_RBRACE] = ACTIONS(3763),
    [anon_sym_interface] = ACTIONS(3761),
    [anon_sym_delegate] = ACTIONS(3761),
    [anon_sym_record] = ACTIONS(3761),
    [anon_sym_abstract] = ACTIONS(3761),
    [anon_sym_async] = ACTIONS(3761),
    [anon_sym_const] = ACTIONS(3761),
    [anon_sym_file] = ACTIONS(3761),
    [anon_sym_fixed] = ACTIONS(3761),
    [anon_sym_internal] = ACTIONS(3761),
    [anon_sym_new] = ACTIONS(3761),
    [anon_sym_override] = ACTIONS(3761),
    [anon_sym_partial] = ACTIONS(3761),
    [anon_sym_private] = ACTIONS(3761),
    [anon_sym_protected] = ACTIONS(3761),
    [anon_sym_public] = ACTIONS(3761),
    [anon_sym_readonly] = ACTIONS(3761),
    [anon_sym_required] = ACTIONS(3761),
    [anon_sym_sealed] = ACTIONS(3761),
    [anon_sym_virtual] = ACTIONS(3761),
    [anon_sym_volatile] = ACTIONS(3761),
    [anon_sym_where] = ACTIONS(3761),
    [anon_sym_notnull] = ACTIONS(3761),
    [anon_sym_unmanaged] = ACTIONS(3761),
    [anon_sym_TILDE] = ACTIONS(3763),
    [anon_sym_implicit] = ACTIONS(3761),
    [anon_sym_explicit] = ACTIONS(3761),
    [anon_sym_scoped] = ACTIONS(3761),
    [anon_sym_var] = ACTIONS(3761),
    [sym_predefined_type] = ACTIONS(3761),
    [anon_sym_yield] = ACTIONS(3761),
    [anon_sym_when] = ACTIONS(3761),
    [anon_sym_from] = ACTIONS(3761),
    [anon_sym_into] = ACTIONS(3761),
    [anon_sym_join] = ACTIONS(3761),
    [anon_sym_on] = ACTIONS(3761),
    [anon_sym_equals] = ACTIONS(3761),
    [anon_sym_let] = ACTIONS(3761),
    [anon_sym_orderby] = ACTIONS(3761),
    [anon_sym_ascending] = ACTIONS(3761),
    [anon_sym_descending] = ACTIONS(3761),
    [anon_sym_group] = ACTIONS(3761),
    [anon_sym_by] = ACTIONS(3761),
    [anon_sym_select] = ACTIONS(3761),
    [aux_sym_preproc_if_token1] = ACTIONS(3763),
    [aux_sym_preproc_if_token3] = ACTIONS(3763),
    [aux_sym_preproc_else_token1] = ACTIONS(3763),
    [aux_sym_preproc_elif_token1] = ACTIONS(3763),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3236] = {
    [sym_preproc_region] = STATE(3236),
    [sym_preproc_endregion] = STATE(3236),
    [sym_preproc_line] = STATE(3236),
    [sym_preproc_pragma] = STATE(3236),
    [sym_preproc_nullable] = STATE(3236),
    [sym_preproc_error] = STATE(3236),
    [sym_preproc_warning] = STATE(3236),
    [sym_preproc_define] = STATE(3236),
    [sym_preproc_undef] = STATE(3236),
    [sym__identifier_token] = ACTIONS(4179),
    [anon_sym_alias] = ACTIONS(4179),
    [anon_sym_global] = ACTIONS(4179),
    [anon_sym_LBRACK] = ACTIONS(4181),
    [anon_sym_COLON] = ACTIONS(4181),
    [anon_sym_COMMA] = ACTIONS(4181),
    [anon_sym_LPAREN] = ACTIONS(4181),
    [anon_sym_LBRACE] = ACTIONS(4181),
    [anon_sym_file] = ACTIONS(4179),
    [anon_sym_LT] = ACTIONS(4179),
    [anon_sym_GT] = ACTIONS(4179),
    [anon_sym_where] = ACTIONS(4179),
    [anon_sym_QMARK] = ACTIONS(4179),
    [anon_sym_notnull] = ACTIONS(4179),
    [anon_sym_unmanaged] = ACTIONS(4179),
    [anon_sym_BANG] = ACTIONS(4179),
    [anon_sym_PLUS_PLUS] = ACTIONS(4181),
    [anon_sym_DASH_DASH] = ACTIONS(4181),
    [anon_sym_PLUS] = ACTIONS(4179),
    [anon_sym_DASH] = ACTIONS(4179),
    [anon_sym_STAR] = ACTIONS(4181),
    [anon_sym_SLASH] = ACTIONS(4179),
    [anon_sym_PERCENT] = ACTIONS(4181),
    [anon_sym_CARET] = ACTIONS(4181),
    [anon_sym_PIPE] = ACTIONS(4179),
    [anon_sym_AMP] = ACTIONS(4179),
    [anon_sym_LT_LT] = ACTIONS(4181),
    [anon_sym_GT_GT] = ACTIONS(4179),
    [anon_sym_GT_GT_GT] = ACTIONS(4181),
    [anon_sym_EQ_EQ] = ACTIONS(4181),
    [anon_sym_BANG_EQ] = ACTIONS(4181),
    [anon_sym_GT_EQ] = ACTIONS(4181),
    [anon_sym_LT_EQ] = ACTIONS(4181),
    [anon_sym_DOT] = ACTIONS(4179),
    [anon_sym_scoped] = ACTIONS(4179),
    [anon_sym_var] = ACTIONS(4179),
    [anon_sym_yield] = ACTIONS(4179),
    [anon_sym_switch] = ACTIONS(4179),
    [anon_sym_when] = ACTIONS(4179),
    [sym_discard] = ACTIONS(4179),
    [anon_sym_DOT_DOT] = ACTIONS(4181),
    [anon_sym_and] = ACTIONS(4179),
    [anon_sym_or] = ACTIONS(4179),
    [anon_sym_AMP_AMP] = ACTIONS(4181),
    [anon_sym_PIPE_PIPE] = ACTIONS(4181),
    [anon_sym_QMARK_QMARK] = ACTIONS(4181),
    [anon_sym_from] = ACTIONS(4179),
    [anon_sym_into] = ACTIONS(4179),
    [anon_sym_join] = ACTIONS(4179),
    [anon_sym_on] = ACTIONS(4179),
    [anon_sym_equals] = ACTIONS(4179),
    [anon_sym_let] = ACTIONS(4179),
    [anon_sym_orderby] = ACTIONS(4179),
    [anon_sym_ascending] = ACTIONS(4179),
    [anon_sym_descending] = ACTIONS(4179),
    [anon_sym_group] = ACTIONS(4179),
    [anon_sym_by] = ACTIONS(4179),
    [anon_sym_select] = ACTIONS(4179),
    [anon_sym_as] = ACTIONS(4179),
    [anon_sym_is] = ACTIONS(4179),
    [anon_sym_DASH_GT] = ACTIONS(4181),
    [anon_sym_with] = ACTIONS(4179),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4181),
  },
  [3237] = {
    [sym_preproc_region] = STATE(3237),
    [sym_preproc_endregion] = STATE(3237),
    [sym_preproc_line] = STATE(3237),
    [sym_preproc_pragma] = STATE(3237),
    [sym_preproc_nullable] = STATE(3237),
    [sym_preproc_error] = STATE(3237),
    [sym_preproc_warning] = STATE(3237),
    [sym_preproc_define] = STATE(3237),
    [sym_preproc_undef] = STATE(3237),
    [anon_sym_SEMI] = ACTIONS(4707),
    [anon_sym_EQ] = ACTIONS(4709),
    [anon_sym_LBRACK] = ACTIONS(4707),
    [anon_sym_COLON] = ACTIONS(4707),
    [anon_sym_COMMA] = ACTIONS(4707),
    [anon_sym_RBRACK] = ACTIONS(4707),
    [anon_sym_LPAREN] = ACTIONS(4707),
    [anon_sym_RPAREN] = ACTIONS(4707),
    [anon_sym_RBRACE] = ACTIONS(4707),
    [anon_sym_LT] = ACTIONS(4709),
    [anon_sym_GT] = ACTIONS(4709),
    [anon_sym_in] = ACTIONS(4707),
    [anon_sym_QMARK] = ACTIONS(4709),
    [anon_sym_BANG] = ACTIONS(4709),
    [anon_sym_PLUS_PLUS] = ACTIONS(4707),
    [anon_sym_DASH_DASH] = ACTIONS(4707),
    [anon_sym_PLUS] = ACTIONS(4709),
    [anon_sym_DASH] = ACTIONS(4709),
    [anon_sym_STAR] = ACTIONS(4709),
    [anon_sym_SLASH] = ACTIONS(4709),
    [anon_sym_PERCENT] = ACTIONS(4709),
    [anon_sym_CARET] = ACTIONS(4709),
    [anon_sym_PIPE] = ACTIONS(4709),
    [anon_sym_AMP] = ACTIONS(4709),
    [anon_sym_LT_LT] = ACTIONS(4709),
    [anon_sym_GT_GT] = ACTIONS(4709),
    [anon_sym_GT_GT_GT] = ACTIONS(4709),
    [anon_sym_EQ_EQ] = ACTIONS(4707),
    [anon_sym_BANG_EQ] = ACTIONS(4707),
    [anon_sym_GT_EQ] = ACTIONS(4707),
    [anon_sym_LT_EQ] = ACTIONS(4707),
    [anon_sym_DOT] = ACTIONS(4709),
    [anon_sym_EQ_GT] = ACTIONS(4707),
    [anon_sym_switch] = ACTIONS(4707),
    [anon_sym_when] = ACTIONS(4707),
    [anon_sym_DOT_DOT] = ACTIONS(4707),
    [anon_sym_and] = ACTIONS(4707),
    [anon_sym_or] = ACTIONS(4707),
    [anon_sym_PLUS_EQ] = ACTIONS(4707),
    [anon_sym_DASH_EQ] = ACTIONS(4707),
    [anon_sym_STAR_EQ] = ACTIONS(4707),
    [anon_sym_SLASH_EQ] = ACTIONS(4707),
    [anon_sym_PERCENT_EQ] = ACTIONS(4707),
    [anon_sym_AMP_EQ] = ACTIONS(4707),
    [anon_sym_CARET_EQ] = ACTIONS(4707),
    [anon_sym_PIPE_EQ] = ACTIONS(4707),
    [anon_sym_LT_LT_EQ] = ACTIONS(4707),
    [anon_sym_GT_GT_EQ] = ACTIONS(4707),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4707),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4707),
    [anon_sym_AMP_AMP] = ACTIONS(4707),
    [anon_sym_PIPE_PIPE] = ACTIONS(4707),
    [anon_sym_QMARK_QMARK] = ACTIONS(4709),
    [anon_sym_on] = ACTIONS(4707),
    [anon_sym_equals] = ACTIONS(4707),
    [anon_sym_by] = ACTIONS(4707),
    [anon_sym_as] = ACTIONS(4707),
    [anon_sym_is] = ACTIONS(4707),
    [anon_sym_DASH_GT] = ACTIONS(4707),
    [anon_sym_with] = ACTIONS(4707),
    [aux_sym_preproc_if_token3] = ACTIONS(4707),
    [aux_sym_preproc_else_token1] = ACTIONS(4707),
    [aux_sym_preproc_elif_token1] = ACTIONS(4707),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3238] = {
    [sym_preproc_region] = STATE(3238),
    [sym_preproc_endregion] = STATE(3238),
    [sym_preproc_line] = STATE(3238),
    [sym_preproc_pragma] = STATE(3238),
    [sym_preproc_nullable] = STATE(3238),
    [sym_preproc_error] = STATE(3238),
    [sym_preproc_warning] = STATE(3238),
    [sym_preproc_define] = STATE(3238),
    [sym_preproc_undef] = STATE(3238),
    [sym__identifier_token] = ACTIONS(3765),
    [anon_sym_extern] = ACTIONS(3765),
    [anon_sym_alias] = ACTIONS(3765),
    [anon_sym_global] = ACTIONS(3765),
    [anon_sym_using] = ACTIONS(3765),
    [anon_sym_unsafe] = ACTIONS(3765),
    [anon_sym_static] = ACTIONS(3765),
    [anon_sym_LBRACK] = ACTIONS(3767),
    [anon_sym_LPAREN] = ACTIONS(3767),
    [anon_sym_event] = ACTIONS(3765),
    [anon_sym_namespace] = ACTIONS(3765),
    [anon_sym_class] = ACTIONS(3765),
    [anon_sym_ref] = ACTIONS(3765),
    [anon_sym_struct] = ACTIONS(3765),
    [anon_sym_enum] = ACTIONS(3765),
    [anon_sym_RBRACE] = ACTIONS(3767),
    [anon_sym_interface] = ACTIONS(3765),
    [anon_sym_delegate] = ACTIONS(3765),
    [anon_sym_record] = ACTIONS(3765),
    [anon_sym_abstract] = ACTIONS(3765),
    [anon_sym_async] = ACTIONS(3765),
    [anon_sym_const] = ACTIONS(3765),
    [anon_sym_file] = ACTIONS(3765),
    [anon_sym_fixed] = ACTIONS(3765),
    [anon_sym_internal] = ACTIONS(3765),
    [anon_sym_new] = ACTIONS(3765),
    [anon_sym_override] = ACTIONS(3765),
    [anon_sym_partial] = ACTIONS(3765),
    [anon_sym_private] = ACTIONS(3765),
    [anon_sym_protected] = ACTIONS(3765),
    [anon_sym_public] = ACTIONS(3765),
    [anon_sym_readonly] = ACTIONS(3765),
    [anon_sym_required] = ACTIONS(3765),
    [anon_sym_sealed] = ACTIONS(3765),
    [anon_sym_virtual] = ACTIONS(3765),
    [anon_sym_volatile] = ACTIONS(3765),
    [anon_sym_where] = ACTIONS(3765),
    [anon_sym_notnull] = ACTIONS(3765),
    [anon_sym_unmanaged] = ACTIONS(3765),
    [anon_sym_TILDE] = ACTIONS(3767),
    [anon_sym_implicit] = ACTIONS(3765),
    [anon_sym_explicit] = ACTIONS(3765),
    [anon_sym_scoped] = ACTIONS(3765),
    [anon_sym_var] = ACTIONS(3765),
    [sym_predefined_type] = ACTIONS(3765),
    [anon_sym_yield] = ACTIONS(3765),
    [anon_sym_when] = ACTIONS(3765),
    [anon_sym_from] = ACTIONS(3765),
    [anon_sym_into] = ACTIONS(3765),
    [anon_sym_join] = ACTIONS(3765),
    [anon_sym_on] = ACTIONS(3765),
    [anon_sym_equals] = ACTIONS(3765),
    [anon_sym_let] = ACTIONS(3765),
    [anon_sym_orderby] = ACTIONS(3765),
    [anon_sym_ascending] = ACTIONS(3765),
    [anon_sym_descending] = ACTIONS(3765),
    [anon_sym_group] = ACTIONS(3765),
    [anon_sym_by] = ACTIONS(3765),
    [anon_sym_select] = ACTIONS(3765),
    [aux_sym_preproc_if_token1] = ACTIONS(3767),
    [aux_sym_preproc_if_token3] = ACTIONS(3767),
    [aux_sym_preproc_else_token1] = ACTIONS(3767),
    [aux_sym_preproc_elif_token1] = ACTIONS(3767),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3239] = {
    [sym_preproc_region] = STATE(3239),
    [sym_preproc_endregion] = STATE(3239),
    [sym_preproc_line] = STATE(3239),
    [sym_preproc_pragma] = STATE(3239),
    [sym_preproc_nullable] = STATE(3239),
    [sym_preproc_error] = STATE(3239),
    [sym_preproc_warning] = STATE(3239),
    [sym_preproc_define] = STATE(3239),
    [sym_preproc_undef] = STATE(3239),
    [sym__identifier_token] = ACTIONS(4628),
    [anon_sym_alias] = ACTIONS(4628),
    [anon_sym_global] = ACTIONS(4628),
    [anon_sym_LBRACK] = ACTIONS(4630),
    [anon_sym_COLON] = ACTIONS(4630),
    [anon_sym_COMMA] = ACTIONS(4630),
    [anon_sym_LPAREN] = ACTIONS(4630),
    [anon_sym_LBRACE] = ACTIONS(4630),
    [anon_sym_file] = ACTIONS(4628),
    [anon_sym_LT] = ACTIONS(4628),
    [anon_sym_GT] = ACTIONS(4628),
    [anon_sym_where] = ACTIONS(4628),
    [anon_sym_QMARK] = ACTIONS(4628),
    [anon_sym_notnull] = ACTIONS(4628),
    [anon_sym_unmanaged] = ACTIONS(4628),
    [anon_sym_BANG] = ACTIONS(4628),
    [anon_sym_PLUS_PLUS] = ACTIONS(4630),
    [anon_sym_DASH_DASH] = ACTIONS(4630),
    [anon_sym_PLUS] = ACTIONS(4628),
    [anon_sym_DASH] = ACTIONS(4628),
    [anon_sym_STAR] = ACTIONS(4630),
    [anon_sym_SLASH] = ACTIONS(4628),
    [anon_sym_PERCENT] = ACTIONS(4630),
    [anon_sym_CARET] = ACTIONS(4630),
    [anon_sym_PIPE] = ACTIONS(4628),
    [anon_sym_AMP] = ACTIONS(4628),
    [anon_sym_LT_LT] = ACTIONS(4630),
    [anon_sym_GT_GT] = ACTIONS(4628),
    [anon_sym_GT_GT_GT] = ACTIONS(4630),
    [anon_sym_EQ_EQ] = ACTIONS(4630),
    [anon_sym_BANG_EQ] = ACTIONS(4630),
    [anon_sym_GT_EQ] = ACTIONS(4630),
    [anon_sym_LT_EQ] = ACTIONS(4630),
    [anon_sym_DOT] = ACTIONS(4628),
    [anon_sym_scoped] = ACTIONS(4628),
    [anon_sym_var] = ACTIONS(4628),
    [anon_sym_yield] = ACTIONS(4628),
    [anon_sym_switch] = ACTIONS(4628),
    [anon_sym_when] = ACTIONS(4628),
    [sym_discard] = ACTIONS(4628),
    [anon_sym_DOT_DOT] = ACTIONS(4630),
    [anon_sym_and] = ACTIONS(4628),
    [anon_sym_or] = ACTIONS(4628),
    [anon_sym_AMP_AMP] = ACTIONS(4630),
    [anon_sym_PIPE_PIPE] = ACTIONS(4630),
    [anon_sym_QMARK_QMARK] = ACTIONS(4630),
    [anon_sym_from] = ACTIONS(4628),
    [anon_sym_into] = ACTIONS(4628),
    [anon_sym_join] = ACTIONS(4628),
    [anon_sym_on] = ACTIONS(4628),
    [anon_sym_equals] = ACTIONS(4628),
    [anon_sym_let] = ACTIONS(4628),
    [anon_sym_orderby] = ACTIONS(4628),
    [anon_sym_ascending] = ACTIONS(4628),
    [anon_sym_descending] = ACTIONS(4628),
    [anon_sym_group] = ACTIONS(4628),
    [anon_sym_by] = ACTIONS(4628),
    [anon_sym_select] = ACTIONS(4628),
    [anon_sym_as] = ACTIONS(4628),
    [anon_sym_is] = ACTIONS(4628),
    [anon_sym_DASH_GT] = ACTIONS(4630),
    [anon_sym_with] = ACTIONS(4628),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4630),
  },
  [3240] = {
    [sym_preproc_region] = STATE(3240),
    [sym_preproc_endregion] = STATE(3240),
    [sym_preproc_line] = STATE(3240),
    [sym_preproc_pragma] = STATE(3240),
    [sym_preproc_nullable] = STATE(3240),
    [sym_preproc_error] = STATE(3240),
    [sym_preproc_warning] = STATE(3240),
    [sym_preproc_define] = STATE(3240),
    [sym_preproc_undef] = STATE(3240),
    [sym__identifier_token] = ACTIONS(4544),
    [anon_sym_alias] = ACTIONS(4544),
    [anon_sym_global] = ACTIONS(4544),
    [anon_sym_LBRACK] = ACTIONS(4546),
    [anon_sym_COLON] = ACTIONS(4546),
    [anon_sym_COMMA] = ACTIONS(4546),
    [anon_sym_LPAREN] = ACTIONS(4546),
    [anon_sym_LBRACE] = ACTIONS(4546),
    [anon_sym_file] = ACTIONS(4544),
    [anon_sym_LT] = ACTIONS(4544),
    [anon_sym_GT] = ACTIONS(4544),
    [anon_sym_where] = ACTIONS(4544),
    [anon_sym_QMARK] = ACTIONS(4544),
    [anon_sym_notnull] = ACTIONS(4544),
    [anon_sym_unmanaged] = ACTIONS(4544),
    [anon_sym_BANG] = ACTIONS(4544),
    [anon_sym_PLUS_PLUS] = ACTIONS(4546),
    [anon_sym_DASH_DASH] = ACTIONS(4546),
    [anon_sym_PLUS] = ACTIONS(4544),
    [anon_sym_DASH] = ACTIONS(4544),
    [anon_sym_STAR] = ACTIONS(4546),
    [anon_sym_SLASH] = ACTIONS(4544),
    [anon_sym_PERCENT] = ACTIONS(4546),
    [anon_sym_CARET] = ACTIONS(4546),
    [anon_sym_PIPE] = ACTIONS(4544),
    [anon_sym_AMP] = ACTIONS(4544),
    [anon_sym_LT_LT] = ACTIONS(4546),
    [anon_sym_GT_GT] = ACTIONS(4544),
    [anon_sym_GT_GT_GT] = ACTIONS(4546),
    [anon_sym_EQ_EQ] = ACTIONS(4546),
    [anon_sym_BANG_EQ] = ACTIONS(4546),
    [anon_sym_GT_EQ] = ACTIONS(4546),
    [anon_sym_LT_EQ] = ACTIONS(4546),
    [anon_sym_DOT] = ACTIONS(4544),
    [anon_sym_scoped] = ACTIONS(4544),
    [anon_sym_var] = ACTIONS(4544),
    [anon_sym_yield] = ACTIONS(4544),
    [anon_sym_switch] = ACTIONS(4544),
    [anon_sym_when] = ACTIONS(4544),
    [sym_discard] = ACTIONS(4544),
    [anon_sym_DOT_DOT] = ACTIONS(4546),
    [anon_sym_and] = ACTIONS(4544),
    [anon_sym_or] = ACTIONS(4544),
    [anon_sym_AMP_AMP] = ACTIONS(4546),
    [anon_sym_PIPE_PIPE] = ACTIONS(4546),
    [anon_sym_QMARK_QMARK] = ACTIONS(4546),
    [anon_sym_from] = ACTIONS(4544),
    [anon_sym_into] = ACTIONS(4544),
    [anon_sym_join] = ACTIONS(4544),
    [anon_sym_on] = ACTIONS(4544),
    [anon_sym_equals] = ACTIONS(4544),
    [anon_sym_let] = ACTIONS(4544),
    [anon_sym_orderby] = ACTIONS(4544),
    [anon_sym_ascending] = ACTIONS(4544),
    [anon_sym_descending] = ACTIONS(4544),
    [anon_sym_group] = ACTIONS(4544),
    [anon_sym_by] = ACTIONS(4544),
    [anon_sym_select] = ACTIONS(4544),
    [anon_sym_as] = ACTIONS(4544),
    [anon_sym_is] = ACTIONS(4544),
    [anon_sym_DASH_GT] = ACTIONS(4546),
    [anon_sym_with] = ACTIONS(4544),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4546),
  },
  [3241] = {
    [sym_preproc_region] = STATE(3241),
    [sym_preproc_endregion] = STATE(3241),
    [sym_preproc_line] = STATE(3241),
    [sym_preproc_pragma] = STATE(3241),
    [sym_preproc_nullable] = STATE(3241),
    [sym_preproc_error] = STATE(3241),
    [sym_preproc_warning] = STATE(3241),
    [sym_preproc_define] = STATE(3241),
    [sym_preproc_undef] = STATE(3241),
    [sym__identifier_token] = ACTIONS(3769),
    [anon_sym_extern] = ACTIONS(3769),
    [anon_sym_alias] = ACTIONS(3769),
    [anon_sym_global] = ACTIONS(3769),
    [anon_sym_using] = ACTIONS(3769),
    [anon_sym_unsafe] = ACTIONS(3769),
    [anon_sym_static] = ACTIONS(3769),
    [anon_sym_LBRACK] = ACTIONS(3771),
    [anon_sym_LPAREN] = ACTIONS(3771),
    [anon_sym_event] = ACTIONS(3769),
    [anon_sym_namespace] = ACTIONS(3769),
    [anon_sym_class] = ACTIONS(3769),
    [anon_sym_ref] = ACTIONS(3769),
    [anon_sym_struct] = ACTIONS(3769),
    [anon_sym_enum] = ACTIONS(3769),
    [anon_sym_RBRACE] = ACTIONS(3771),
    [anon_sym_interface] = ACTIONS(3769),
    [anon_sym_delegate] = ACTIONS(3769),
    [anon_sym_record] = ACTIONS(3769),
    [anon_sym_abstract] = ACTIONS(3769),
    [anon_sym_async] = ACTIONS(3769),
    [anon_sym_const] = ACTIONS(3769),
    [anon_sym_file] = ACTIONS(3769),
    [anon_sym_fixed] = ACTIONS(3769),
    [anon_sym_internal] = ACTIONS(3769),
    [anon_sym_new] = ACTIONS(3769),
    [anon_sym_override] = ACTIONS(3769),
    [anon_sym_partial] = ACTIONS(3769),
    [anon_sym_private] = ACTIONS(3769),
    [anon_sym_protected] = ACTIONS(3769),
    [anon_sym_public] = ACTIONS(3769),
    [anon_sym_readonly] = ACTIONS(3769),
    [anon_sym_required] = ACTIONS(3769),
    [anon_sym_sealed] = ACTIONS(3769),
    [anon_sym_virtual] = ACTIONS(3769),
    [anon_sym_volatile] = ACTIONS(3769),
    [anon_sym_where] = ACTIONS(3769),
    [anon_sym_notnull] = ACTIONS(3769),
    [anon_sym_unmanaged] = ACTIONS(3769),
    [anon_sym_TILDE] = ACTIONS(3771),
    [anon_sym_implicit] = ACTIONS(3769),
    [anon_sym_explicit] = ACTIONS(3769),
    [anon_sym_scoped] = ACTIONS(3769),
    [anon_sym_var] = ACTIONS(3769),
    [sym_predefined_type] = ACTIONS(3769),
    [anon_sym_yield] = ACTIONS(3769),
    [anon_sym_when] = ACTIONS(3769),
    [anon_sym_from] = ACTIONS(3769),
    [anon_sym_into] = ACTIONS(3769),
    [anon_sym_join] = ACTIONS(3769),
    [anon_sym_on] = ACTIONS(3769),
    [anon_sym_equals] = ACTIONS(3769),
    [anon_sym_let] = ACTIONS(3769),
    [anon_sym_orderby] = ACTIONS(3769),
    [anon_sym_ascending] = ACTIONS(3769),
    [anon_sym_descending] = ACTIONS(3769),
    [anon_sym_group] = ACTIONS(3769),
    [anon_sym_by] = ACTIONS(3769),
    [anon_sym_select] = ACTIONS(3769),
    [aux_sym_preproc_if_token1] = ACTIONS(3771),
    [aux_sym_preproc_if_token3] = ACTIONS(3771),
    [aux_sym_preproc_else_token1] = ACTIONS(3771),
    [aux_sym_preproc_elif_token1] = ACTIONS(3771),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3242] = {
    [sym_preproc_region] = STATE(3242),
    [sym_preproc_endregion] = STATE(3242),
    [sym_preproc_line] = STATE(3242),
    [sym_preproc_pragma] = STATE(3242),
    [sym_preproc_nullable] = STATE(3242),
    [sym_preproc_error] = STATE(3242),
    [sym_preproc_warning] = STATE(3242),
    [sym_preproc_define] = STATE(3242),
    [sym_preproc_undef] = STATE(3242),
    [sym__identifier_token] = ACTIONS(3773),
    [anon_sym_extern] = ACTIONS(3773),
    [anon_sym_alias] = ACTIONS(3773),
    [anon_sym_global] = ACTIONS(3773),
    [anon_sym_using] = ACTIONS(3773),
    [anon_sym_unsafe] = ACTIONS(3773),
    [anon_sym_static] = ACTIONS(3773),
    [anon_sym_LBRACK] = ACTIONS(3775),
    [anon_sym_LPAREN] = ACTIONS(3775),
    [anon_sym_event] = ACTIONS(3773),
    [anon_sym_namespace] = ACTIONS(3773),
    [anon_sym_class] = ACTIONS(3773),
    [anon_sym_ref] = ACTIONS(3773),
    [anon_sym_struct] = ACTIONS(3773),
    [anon_sym_enum] = ACTIONS(3773),
    [anon_sym_RBRACE] = ACTIONS(3775),
    [anon_sym_interface] = ACTIONS(3773),
    [anon_sym_delegate] = ACTIONS(3773),
    [anon_sym_record] = ACTIONS(3773),
    [anon_sym_abstract] = ACTIONS(3773),
    [anon_sym_async] = ACTIONS(3773),
    [anon_sym_const] = ACTIONS(3773),
    [anon_sym_file] = ACTIONS(3773),
    [anon_sym_fixed] = ACTIONS(3773),
    [anon_sym_internal] = ACTIONS(3773),
    [anon_sym_new] = ACTIONS(3773),
    [anon_sym_override] = ACTIONS(3773),
    [anon_sym_partial] = ACTIONS(3773),
    [anon_sym_private] = ACTIONS(3773),
    [anon_sym_protected] = ACTIONS(3773),
    [anon_sym_public] = ACTIONS(3773),
    [anon_sym_readonly] = ACTIONS(3773),
    [anon_sym_required] = ACTIONS(3773),
    [anon_sym_sealed] = ACTIONS(3773),
    [anon_sym_virtual] = ACTIONS(3773),
    [anon_sym_volatile] = ACTIONS(3773),
    [anon_sym_where] = ACTIONS(3773),
    [anon_sym_notnull] = ACTIONS(3773),
    [anon_sym_unmanaged] = ACTIONS(3773),
    [anon_sym_TILDE] = ACTIONS(3775),
    [anon_sym_implicit] = ACTIONS(3773),
    [anon_sym_explicit] = ACTIONS(3773),
    [anon_sym_scoped] = ACTIONS(3773),
    [anon_sym_var] = ACTIONS(3773),
    [sym_predefined_type] = ACTIONS(3773),
    [anon_sym_yield] = ACTIONS(3773),
    [anon_sym_when] = ACTIONS(3773),
    [anon_sym_from] = ACTIONS(3773),
    [anon_sym_into] = ACTIONS(3773),
    [anon_sym_join] = ACTIONS(3773),
    [anon_sym_on] = ACTIONS(3773),
    [anon_sym_equals] = ACTIONS(3773),
    [anon_sym_let] = ACTIONS(3773),
    [anon_sym_orderby] = ACTIONS(3773),
    [anon_sym_ascending] = ACTIONS(3773),
    [anon_sym_descending] = ACTIONS(3773),
    [anon_sym_group] = ACTIONS(3773),
    [anon_sym_by] = ACTIONS(3773),
    [anon_sym_select] = ACTIONS(3773),
    [aux_sym_preproc_if_token1] = ACTIONS(3775),
    [aux_sym_preproc_if_token3] = ACTIONS(3775),
    [aux_sym_preproc_else_token1] = ACTIONS(3775),
    [aux_sym_preproc_elif_token1] = ACTIONS(3775),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3243] = {
    [sym_preproc_region] = STATE(3243),
    [sym_preproc_endregion] = STATE(3243),
    [sym_preproc_line] = STATE(3243),
    [sym_preproc_pragma] = STATE(3243),
    [sym_preproc_nullable] = STATE(3243),
    [sym_preproc_error] = STATE(3243),
    [sym_preproc_warning] = STATE(3243),
    [sym_preproc_define] = STATE(3243),
    [sym_preproc_undef] = STATE(3243),
    [sym__identifier_token] = ACTIONS(3777),
    [anon_sym_extern] = ACTIONS(3777),
    [anon_sym_alias] = ACTIONS(3777),
    [anon_sym_global] = ACTIONS(3777),
    [anon_sym_using] = ACTIONS(3777),
    [anon_sym_unsafe] = ACTIONS(3777),
    [anon_sym_static] = ACTIONS(3777),
    [anon_sym_LBRACK] = ACTIONS(3779),
    [anon_sym_LPAREN] = ACTIONS(3779),
    [anon_sym_event] = ACTIONS(3777),
    [anon_sym_namespace] = ACTIONS(3777),
    [anon_sym_class] = ACTIONS(3777),
    [anon_sym_ref] = ACTIONS(3777),
    [anon_sym_struct] = ACTIONS(3777),
    [anon_sym_enum] = ACTIONS(3777),
    [anon_sym_RBRACE] = ACTIONS(3779),
    [anon_sym_interface] = ACTIONS(3777),
    [anon_sym_delegate] = ACTIONS(3777),
    [anon_sym_record] = ACTIONS(3777),
    [anon_sym_abstract] = ACTIONS(3777),
    [anon_sym_async] = ACTIONS(3777),
    [anon_sym_const] = ACTIONS(3777),
    [anon_sym_file] = ACTIONS(3777),
    [anon_sym_fixed] = ACTIONS(3777),
    [anon_sym_internal] = ACTIONS(3777),
    [anon_sym_new] = ACTIONS(3777),
    [anon_sym_override] = ACTIONS(3777),
    [anon_sym_partial] = ACTIONS(3777),
    [anon_sym_private] = ACTIONS(3777),
    [anon_sym_protected] = ACTIONS(3777),
    [anon_sym_public] = ACTIONS(3777),
    [anon_sym_readonly] = ACTIONS(3777),
    [anon_sym_required] = ACTIONS(3777),
    [anon_sym_sealed] = ACTIONS(3777),
    [anon_sym_virtual] = ACTIONS(3777),
    [anon_sym_volatile] = ACTIONS(3777),
    [anon_sym_where] = ACTIONS(3777),
    [anon_sym_notnull] = ACTIONS(3777),
    [anon_sym_unmanaged] = ACTIONS(3777),
    [anon_sym_TILDE] = ACTIONS(3779),
    [anon_sym_implicit] = ACTIONS(3777),
    [anon_sym_explicit] = ACTIONS(3777),
    [anon_sym_scoped] = ACTIONS(3777),
    [anon_sym_var] = ACTIONS(3777),
    [sym_predefined_type] = ACTIONS(3777),
    [anon_sym_yield] = ACTIONS(3777),
    [anon_sym_when] = ACTIONS(3777),
    [anon_sym_from] = ACTIONS(3777),
    [anon_sym_into] = ACTIONS(3777),
    [anon_sym_join] = ACTIONS(3777),
    [anon_sym_on] = ACTIONS(3777),
    [anon_sym_equals] = ACTIONS(3777),
    [anon_sym_let] = ACTIONS(3777),
    [anon_sym_orderby] = ACTIONS(3777),
    [anon_sym_ascending] = ACTIONS(3777),
    [anon_sym_descending] = ACTIONS(3777),
    [anon_sym_group] = ACTIONS(3777),
    [anon_sym_by] = ACTIONS(3777),
    [anon_sym_select] = ACTIONS(3777),
    [aux_sym_preproc_if_token1] = ACTIONS(3779),
    [aux_sym_preproc_if_token3] = ACTIONS(3779),
    [aux_sym_preproc_else_token1] = ACTIONS(3779),
    [aux_sym_preproc_elif_token1] = ACTIONS(3779),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3244] = {
    [sym_preproc_region] = STATE(3244),
    [sym_preproc_endregion] = STATE(3244),
    [sym_preproc_line] = STATE(3244),
    [sym_preproc_pragma] = STATE(3244),
    [sym_preproc_nullable] = STATE(3244),
    [sym_preproc_error] = STATE(3244),
    [sym_preproc_warning] = STATE(3244),
    [sym_preproc_define] = STATE(3244),
    [sym_preproc_undef] = STATE(3244),
    [anon_sym_SEMI] = ACTIONS(4640),
    [anon_sym_EQ] = ACTIONS(4642),
    [anon_sym_LBRACK] = ACTIONS(4640),
    [anon_sym_COLON] = ACTIONS(4640),
    [anon_sym_COMMA] = ACTIONS(4640),
    [anon_sym_RBRACK] = ACTIONS(4640),
    [anon_sym_LPAREN] = ACTIONS(4640),
    [anon_sym_RPAREN] = ACTIONS(4640),
    [anon_sym_RBRACE] = ACTIONS(4640),
    [anon_sym_LT] = ACTIONS(4642),
    [anon_sym_GT] = ACTIONS(4642),
    [anon_sym_in] = ACTIONS(4640),
    [anon_sym_QMARK] = ACTIONS(4642),
    [anon_sym_BANG] = ACTIONS(4642),
    [anon_sym_PLUS_PLUS] = ACTIONS(4640),
    [anon_sym_DASH_DASH] = ACTIONS(4640),
    [anon_sym_PLUS] = ACTIONS(4642),
    [anon_sym_DASH] = ACTIONS(4642),
    [anon_sym_STAR] = ACTIONS(4642),
    [anon_sym_SLASH] = ACTIONS(4642),
    [anon_sym_PERCENT] = ACTIONS(4642),
    [anon_sym_CARET] = ACTIONS(4642),
    [anon_sym_PIPE] = ACTIONS(4642),
    [anon_sym_AMP] = ACTIONS(4642),
    [anon_sym_LT_LT] = ACTIONS(4642),
    [anon_sym_GT_GT] = ACTIONS(4642),
    [anon_sym_GT_GT_GT] = ACTIONS(4642),
    [anon_sym_EQ_EQ] = ACTIONS(4640),
    [anon_sym_BANG_EQ] = ACTIONS(4640),
    [anon_sym_GT_EQ] = ACTIONS(4640),
    [anon_sym_LT_EQ] = ACTIONS(4640),
    [anon_sym_DOT] = ACTIONS(4642),
    [anon_sym_EQ_GT] = ACTIONS(4640),
    [anon_sym_switch] = ACTIONS(4640),
    [anon_sym_when] = ACTIONS(4640),
    [anon_sym_DOT_DOT] = ACTIONS(4640),
    [anon_sym_and] = ACTIONS(4640),
    [anon_sym_or] = ACTIONS(4640),
    [anon_sym_PLUS_EQ] = ACTIONS(4640),
    [anon_sym_DASH_EQ] = ACTIONS(4640),
    [anon_sym_STAR_EQ] = ACTIONS(4640),
    [anon_sym_SLASH_EQ] = ACTIONS(4640),
    [anon_sym_PERCENT_EQ] = ACTIONS(4640),
    [anon_sym_AMP_EQ] = ACTIONS(4640),
    [anon_sym_CARET_EQ] = ACTIONS(4640),
    [anon_sym_PIPE_EQ] = ACTIONS(4640),
    [anon_sym_LT_LT_EQ] = ACTIONS(4640),
    [anon_sym_GT_GT_EQ] = ACTIONS(4640),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4640),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4640),
    [anon_sym_AMP_AMP] = ACTIONS(4640),
    [anon_sym_PIPE_PIPE] = ACTIONS(4640),
    [anon_sym_QMARK_QMARK] = ACTIONS(4642),
    [anon_sym_on] = ACTIONS(4640),
    [anon_sym_equals] = ACTIONS(4640),
    [anon_sym_by] = ACTIONS(4640),
    [anon_sym_as] = ACTIONS(4640),
    [anon_sym_is] = ACTIONS(4640),
    [anon_sym_DASH_GT] = ACTIONS(4640),
    [anon_sym_with] = ACTIONS(4640),
    [aux_sym_preproc_if_token3] = ACTIONS(4640),
    [aux_sym_preproc_else_token1] = ACTIONS(4640),
    [aux_sym_preproc_elif_token1] = ACTIONS(4640),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3245] = {
    [sym_preproc_region] = STATE(3245),
    [sym_preproc_endregion] = STATE(3245),
    [sym_preproc_line] = STATE(3245),
    [sym_preproc_pragma] = STATE(3245),
    [sym_preproc_nullable] = STATE(3245),
    [sym_preproc_error] = STATE(3245),
    [sym_preproc_warning] = STATE(3245),
    [sym_preproc_define] = STATE(3245),
    [sym_preproc_undef] = STATE(3245),
    [sym__identifier_token] = ACTIONS(4583),
    [anon_sym_alias] = ACTIONS(4583),
    [anon_sym_global] = ACTIONS(4583),
    [anon_sym_LBRACK] = ACTIONS(4585),
    [anon_sym_COLON] = ACTIONS(4585),
    [anon_sym_COMMA] = ACTIONS(4585),
    [anon_sym_LPAREN] = ACTIONS(4585),
    [anon_sym_LBRACE] = ACTIONS(4585),
    [anon_sym_file] = ACTIONS(4583),
    [anon_sym_LT] = ACTIONS(4583),
    [anon_sym_GT] = ACTIONS(4583),
    [anon_sym_where] = ACTIONS(4583),
    [anon_sym_QMARK] = ACTIONS(4583),
    [anon_sym_notnull] = ACTIONS(4583),
    [anon_sym_unmanaged] = ACTIONS(4583),
    [anon_sym_BANG] = ACTIONS(4583),
    [anon_sym_PLUS_PLUS] = ACTIONS(4585),
    [anon_sym_DASH_DASH] = ACTIONS(4585),
    [anon_sym_PLUS] = ACTIONS(4583),
    [anon_sym_DASH] = ACTIONS(4583),
    [anon_sym_STAR] = ACTIONS(4585),
    [anon_sym_SLASH] = ACTIONS(4583),
    [anon_sym_PERCENT] = ACTIONS(4585),
    [anon_sym_CARET] = ACTIONS(4585),
    [anon_sym_PIPE] = ACTIONS(4583),
    [anon_sym_AMP] = ACTIONS(4583),
    [anon_sym_LT_LT] = ACTIONS(4585),
    [anon_sym_GT_GT] = ACTIONS(4583),
    [anon_sym_GT_GT_GT] = ACTIONS(4585),
    [anon_sym_EQ_EQ] = ACTIONS(4585),
    [anon_sym_BANG_EQ] = ACTIONS(4585),
    [anon_sym_GT_EQ] = ACTIONS(4585),
    [anon_sym_LT_EQ] = ACTIONS(4585),
    [anon_sym_DOT] = ACTIONS(4583),
    [anon_sym_scoped] = ACTIONS(4583),
    [anon_sym_var] = ACTIONS(4583),
    [anon_sym_yield] = ACTIONS(4583),
    [anon_sym_switch] = ACTIONS(4583),
    [anon_sym_when] = ACTIONS(4583),
    [sym_discard] = ACTIONS(4583),
    [anon_sym_DOT_DOT] = ACTIONS(4585),
    [anon_sym_and] = ACTIONS(4583),
    [anon_sym_or] = ACTIONS(4583),
    [anon_sym_AMP_AMP] = ACTIONS(4585),
    [anon_sym_PIPE_PIPE] = ACTIONS(4585),
    [anon_sym_QMARK_QMARK] = ACTIONS(4585),
    [anon_sym_from] = ACTIONS(4583),
    [anon_sym_into] = ACTIONS(4583),
    [anon_sym_join] = ACTIONS(4583),
    [anon_sym_on] = ACTIONS(4583),
    [anon_sym_equals] = ACTIONS(4583),
    [anon_sym_let] = ACTIONS(4583),
    [anon_sym_orderby] = ACTIONS(4583),
    [anon_sym_ascending] = ACTIONS(4583),
    [anon_sym_descending] = ACTIONS(4583),
    [anon_sym_group] = ACTIONS(4583),
    [anon_sym_by] = ACTIONS(4583),
    [anon_sym_select] = ACTIONS(4583),
    [anon_sym_as] = ACTIONS(4583),
    [anon_sym_is] = ACTIONS(4583),
    [anon_sym_DASH_GT] = ACTIONS(4585),
    [anon_sym_with] = ACTIONS(4583),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4585),
  },
  [3246] = {
    [sym_preproc_region] = STATE(3246),
    [sym_preproc_endregion] = STATE(3246),
    [sym_preproc_line] = STATE(3246),
    [sym_preproc_pragma] = STATE(3246),
    [sym_preproc_nullable] = STATE(3246),
    [sym_preproc_error] = STATE(3246),
    [sym_preproc_warning] = STATE(3246),
    [sym_preproc_define] = STATE(3246),
    [sym_preproc_undef] = STATE(3246),
    [sym__identifier_token] = ACTIONS(4834),
    [anon_sym_extern] = ACTIONS(4834),
    [anon_sym_alias] = ACTIONS(4834),
    [anon_sym_global] = ACTIONS(4834),
    [anon_sym_using] = ACTIONS(4834),
    [anon_sym_unsafe] = ACTIONS(4834),
    [anon_sym_static] = ACTIONS(4834),
    [anon_sym_LBRACK] = ACTIONS(4836),
    [anon_sym_LPAREN] = ACTIONS(4836),
    [anon_sym_event] = ACTIONS(4834),
    [anon_sym_namespace] = ACTIONS(4834),
    [anon_sym_class] = ACTIONS(4834),
    [anon_sym_ref] = ACTIONS(4834),
    [anon_sym_struct] = ACTIONS(4834),
    [anon_sym_enum] = ACTIONS(4834),
    [anon_sym_RBRACE] = ACTIONS(4836),
    [anon_sym_interface] = ACTIONS(4834),
    [anon_sym_delegate] = ACTIONS(4834),
    [anon_sym_record] = ACTIONS(4834),
    [anon_sym_abstract] = ACTIONS(4834),
    [anon_sym_async] = ACTIONS(4834),
    [anon_sym_const] = ACTIONS(4834),
    [anon_sym_file] = ACTIONS(4834),
    [anon_sym_fixed] = ACTIONS(4834),
    [anon_sym_internal] = ACTIONS(4834),
    [anon_sym_new] = ACTIONS(4834),
    [anon_sym_override] = ACTIONS(4834),
    [anon_sym_partial] = ACTIONS(4834),
    [anon_sym_private] = ACTIONS(4834),
    [anon_sym_protected] = ACTIONS(4834),
    [anon_sym_public] = ACTIONS(4834),
    [anon_sym_readonly] = ACTIONS(4834),
    [anon_sym_required] = ACTIONS(4834),
    [anon_sym_sealed] = ACTIONS(4834),
    [anon_sym_virtual] = ACTIONS(4834),
    [anon_sym_volatile] = ACTIONS(4834),
    [anon_sym_where] = ACTIONS(4834),
    [anon_sym_notnull] = ACTIONS(4834),
    [anon_sym_unmanaged] = ACTIONS(4834),
    [anon_sym_TILDE] = ACTIONS(4836),
    [anon_sym_implicit] = ACTIONS(4834),
    [anon_sym_explicit] = ACTIONS(4834),
    [anon_sym_scoped] = ACTIONS(4834),
    [anon_sym_var] = ACTIONS(4834),
    [sym_predefined_type] = ACTIONS(4834),
    [anon_sym_yield] = ACTIONS(4834),
    [anon_sym_when] = ACTIONS(4834),
    [anon_sym_from] = ACTIONS(4834),
    [anon_sym_into] = ACTIONS(4834),
    [anon_sym_join] = ACTIONS(4834),
    [anon_sym_on] = ACTIONS(4834),
    [anon_sym_equals] = ACTIONS(4834),
    [anon_sym_let] = ACTIONS(4834),
    [anon_sym_orderby] = ACTIONS(4834),
    [anon_sym_ascending] = ACTIONS(4834),
    [anon_sym_descending] = ACTIONS(4834),
    [anon_sym_group] = ACTIONS(4834),
    [anon_sym_by] = ACTIONS(4834),
    [anon_sym_select] = ACTIONS(4834),
    [aux_sym_preproc_if_token1] = ACTIONS(4836),
    [aux_sym_preproc_if_token3] = ACTIONS(4836),
    [aux_sym_preproc_else_token1] = ACTIONS(4836),
    [aux_sym_preproc_elif_token1] = ACTIONS(4836),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3247] = {
    [sym_preproc_region] = STATE(3247),
    [sym_preproc_endregion] = STATE(3247),
    [sym_preproc_line] = STATE(3247),
    [sym_preproc_pragma] = STATE(3247),
    [sym_preproc_nullable] = STATE(3247),
    [sym_preproc_error] = STATE(3247),
    [sym_preproc_warning] = STATE(3247),
    [sym_preproc_define] = STATE(3247),
    [sym_preproc_undef] = STATE(3247),
    [sym__identifier_token] = ACTIONS(4838),
    [anon_sym_extern] = ACTIONS(4838),
    [anon_sym_alias] = ACTIONS(4838),
    [anon_sym_global] = ACTIONS(4838),
    [anon_sym_using] = ACTIONS(4838),
    [anon_sym_unsafe] = ACTIONS(4838),
    [anon_sym_static] = ACTIONS(4838),
    [anon_sym_LBRACK] = ACTIONS(4840),
    [anon_sym_LPAREN] = ACTIONS(4840),
    [anon_sym_event] = ACTIONS(4838),
    [anon_sym_namespace] = ACTIONS(4838),
    [anon_sym_class] = ACTIONS(4838),
    [anon_sym_ref] = ACTIONS(4838),
    [anon_sym_struct] = ACTIONS(4838),
    [anon_sym_enum] = ACTIONS(4838),
    [anon_sym_RBRACE] = ACTIONS(4840),
    [anon_sym_interface] = ACTIONS(4838),
    [anon_sym_delegate] = ACTIONS(4838),
    [anon_sym_record] = ACTIONS(4838),
    [anon_sym_abstract] = ACTIONS(4838),
    [anon_sym_async] = ACTIONS(4838),
    [anon_sym_const] = ACTIONS(4838),
    [anon_sym_file] = ACTIONS(4838),
    [anon_sym_fixed] = ACTIONS(4838),
    [anon_sym_internal] = ACTIONS(4838),
    [anon_sym_new] = ACTIONS(4838),
    [anon_sym_override] = ACTIONS(4838),
    [anon_sym_partial] = ACTIONS(4838),
    [anon_sym_private] = ACTIONS(4838),
    [anon_sym_protected] = ACTIONS(4838),
    [anon_sym_public] = ACTIONS(4838),
    [anon_sym_readonly] = ACTIONS(4838),
    [anon_sym_required] = ACTIONS(4838),
    [anon_sym_sealed] = ACTIONS(4838),
    [anon_sym_virtual] = ACTIONS(4838),
    [anon_sym_volatile] = ACTIONS(4838),
    [anon_sym_where] = ACTIONS(4838),
    [anon_sym_notnull] = ACTIONS(4838),
    [anon_sym_unmanaged] = ACTIONS(4838),
    [anon_sym_TILDE] = ACTIONS(4840),
    [anon_sym_implicit] = ACTIONS(4838),
    [anon_sym_explicit] = ACTIONS(4838),
    [anon_sym_scoped] = ACTIONS(4838),
    [anon_sym_var] = ACTIONS(4838),
    [sym_predefined_type] = ACTIONS(4838),
    [anon_sym_yield] = ACTIONS(4838),
    [anon_sym_when] = ACTIONS(4838),
    [anon_sym_from] = ACTIONS(4838),
    [anon_sym_into] = ACTIONS(4838),
    [anon_sym_join] = ACTIONS(4838),
    [anon_sym_on] = ACTIONS(4838),
    [anon_sym_equals] = ACTIONS(4838),
    [anon_sym_let] = ACTIONS(4838),
    [anon_sym_orderby] = ACTIONS(4838),
    [anon_sym_ascending] = ACTIONS(4838),
    [anon_sym_descending] = ACTIONS(4838),
    [anon_sym_group] = ACTIONS(4838),
    [anon_sym_by] = ACTIONS(4838),
    [anon_sym_select] = ACTIONS(4838),
    [aux_sym_preproc_if_token1] = ACTIONS(4840),
    [aux_sym_preproc_if_token3] = ACTIONS(4840),
    [aux_sym_preproc_else_token1] = ACTIONS(4840),
    [aux_sym_preproc_elif_token1] = ACTIONS(4840),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3248] = {
    [sym_preproc_region] = STATE(3248),
    [sym_preproc_endregion] = STATE(3248),
    [sym_preproc_line] = STATE(3248),
    [sym_preproc_pragma] = STATE(3248),
    [sym_preproc_nullable] = STATE(3248),
    [sym_preproc_error] = STATE(3248),
    [sym_preproc_warning] = STATE(3248),
    [sym_preproc_define] = STATE(3248),
    [sym_preproc_undef] = STATE(3248),
    [sym__identifier_token] = ACTIONS(3469),
    [anon_sym_extern] = ACTIONS(3469),
    [anon_sym_alias] = ACTIONS(3469),
    [anon_sym_global] = ACTIONS(3469),
    [anon_sym_using] = ACTIONS(3469),
    [anon_sym_unsafe] = ACTIONS(3469),
    [anon_sym_static] = ACTIONS(3469),
    [anon_sym_LBRACK] = ACTIONS(3471),
    [anon_sym_LPAREN] = ACTIONS(3471),
    [anon_sym_event] = ACTIONS(3469),
    [anon_sym_namespace] = ACTIONS(3469),
    [anon_sym_class] = ACTIONS(3469),
    [anon_sym_ref] = ACTIONS(3469),
    [anon_sym_struct] = ACTIONS(3469),
    [anon_sym_enum] = ACTIONS(3469),
    [anon_sym_RBRACE] = ACTIONS(3471),
    [anon_sym_interface] = ACTIONS(3469),
    [anon_sym_delegate] = ACTIONS(3469),
    [anon_sym_record] = ACTIONS(3469),
    [anon_sym_abstract] = ACTIONS(3469),
    [anon_sym_async] = ACTIONS(3469),
    [anon_sym_const] = ACTIONS(3469),
    [anon_sym_file] = ACTIONS(3469),
    [anon_sym_fixed] = ACTIONS(3469),
    [anon_sym_internal] = ACTIONS(3469),
    [anon_sym_new] = ACTIONS(3469),
    [anon_sym_override] = ACTIONS(3469),
    [anon_sym_partial] = ACTIONS(3469),
    [anon_sym_private] = ACTIONS(3469),
    [anon_sym_protected] = ACTIONS(3469),
    [anon_sym_public] = ACTIONS(3469),
    [anon_sym_readonly] = ACTIONS(3469),
    [anon_sym_required] = ACTIONS(3469),
    [anon_sym_sealed] = ACTIONS(3469),
    [anon_sym_virtual] = ACTIONS(3469),
    [anon_sym_volatile] = ACTIONS(3469),
    [anon_sym_where] = ACTIONS(3469),
    [anon_sym_notnull] = ACTIONS(3469),
    [anon_sym_unmanaged] = ACTIONS(3469),
    [anon_sym_TILDE] = ACTIONS(3471),
    [anon_sym_implicit] = ACTIONS(3469),
    [anon_sym_explicit] = ACTIONS(3469),
    [anon_sym_scoped] = ACTIONS(3469),
    [anon_sym_var] = ACTIONS(3469),
    [sym_predefined_type] = ACTIONS(3469),
    [anon_sym_yield] = ACTIONS(3469),
    [anon_sym_when] = ACTIONS(3469),
    [anon_sym_from] = ACTIONS(3469),
    [anon_sym_into] = ACTIONS(3469),
    [anon_sym_join] = ACTIONS(3469),
    [anon_sym_on] = ACTIONS(3469),
    [anon_sym_equals] = ACTIONS(3469),
    [anon_sym_let] = ACTIONS(3469),
    [anon_sym_orderby] = ACTIONS(3469),
    [anon_sym_ascending] = ACTIONS(3469),
    [anon_sym_descending] = ACTIONS(3469),
    [anon_sym_group] = ACTIONS(3469),
    [anon_sym_by] = ACTIONS(3469),
    [anon_sym_select] = ACTIONS(3469),
    [aux_sym_preproc_if_token1] = ACTIONS(3471),
    [aux_sym_preproc_if_token3] = ACTIONS(3471),
    [aux_sym_preproc_else_token1] = ACTIONS(3471),
    [aux_sym_preproc_elif_token1] = ACTIONS(3471),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3249] = {
    [sym_preproc_region] = STATE(3249),
    [sym_preproc_endregion] = STATE(3249),
    [sym_preproc_line] = STATE(3249),
    [sym_preproc_pragma] = STATE(3249),
    [sym_preproc_nullable] = STATE(3249),
    [sym_preproc_error] = STATE(3249),
    [sym_preproc_warning] = STATE(3249),
    [sym_preproc_define] = STATE(3249),
    [sym_preproc_undef] = STATE(3249),
    [sym__identifier_token] = ACTIONS(3781),
    [anon_sym_extern] = ACTIONS(3781),
    [anon_sym_alias] = ACTIONS(3781),
    [anon_sym_global] = ACTIONS(3781),
    [anon_sym_using] = ACTIONS(3781),
    [anon_sym_unsafe] = ACTIONS(3781),
    [anon_sym_static] = ACTIONS(3781),
    [anon_sym_LBRACK] = ACTIONS(3783),
    [anon_sym_LPAREN] = ACTIONS(3783),
    [anon_sym_event] = ACTIONS(3781),
    [anon_sym_namespace] = ACTIONS(3781),
    [anon_sym_class] = ACTIONS(3781),
    [anon_sym_ref] = ACTIONS(3781),
    [anon_sym_struct] = ACTIONS(3781),
    [anon_sym_enum] = ACTIONS(3781),
    [anon_sym_RBRACE] = ACTIONS(3783),
    [anon_sym_interface] = ACTIONS(3781),
    [anon_sym_delegate] = ACTIONS(3781),
    [anon_sym_record] = ACTIONS(3781),
    [anon_sym_abstract] = ACTIONS(3781),
    [anon_sym_async] = ACTIONS(3781),
    [anon_sym_const] = ACTIONS(3781),
    [anon_sym_file] = ACTIONS(3781),
    [anon_sym_fixed] = ACTIONS(3781),
    [anon_sym_internal] = ACTIONS(3781),
    [anon_sym_new] = ACTIONS(3781),
    [anon_sym_override] = ACTIONS(3781),
    [anon_sym_partial] = ACTIONS(3781),
    [anon_sym_private] = ACTIONS(3781),
    [anon_sym_protected] = ACTIONS(3781),
    [anon_sym_public] = ACTIONS(3781),
    [anon_sym_readonly] = ACTIONS(3781),
    [anon_sym_required] = ACTIONS(3781),
    [anon_sym_sealed] = ACTIONS(3781),
    [anon_sym_virtual] = ACTIONS(3781),
    [anon_sym_volatile] = ACTIONS(3781),
    [anon_sym_where] = ACTIONS(3781),
    [anon_sym_notnull] = ACTIONS(3781),
    [anon_sym_unmanaged] = ACTIONS(3781),
    [anon_sym_TILDE] = ACTIONS(3783),
    [anon_sym_implicit] = ACTIONS(3781),
    [anon_sym_explicit] = ACTIONS(3781),
    [anon_sym_scoped] = ACTIONS(3781),
    [anon_sym_var] = ACTIONS(3781),
    [sym_predefined_type] = ACTIONS(3781),
    [anon_sym_yield] = ACTIONS(3781),
    [anon_sym_when] = ACTIONS(3781),
    [anon_sym_from] = ACTIONS(3781),
    [anon_sym_into] = ACTIONS(3781),
    [anon_sym_join] = ACTIONS(3781),
    [anon_sym_on] = ACTIONS(3781),
    [anon_sym_equals] = ACTIONS(3781),
    [anon_sym_let] = ACTIONS(3781),
    [anon_sym_orderby] = ACTIONS(3781),
    [anon_sym_ascending] = ACTIONS(3781),
    [anon_sym_descending] = ACTIONS(3781),
    [anon_sym_group] = ACTIONS(3781),
    [anon_sym_by] = ACTIONS(3781),
    [anon_sym_select] = ACTIONS(3781),
    [aux_sym_preproc_if_token1] = ACTIONS(3783),
    [aux_sym_preproc_if_token3] = ACTIONS(3783),
    [aux_sym_preproc_else_token1] = ACTIONS(3783),
    [aux_sym_preproc_elif_token1] = ACTIONS(3783),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3250] = {
    [sym_preproc_region] = STATE(3250),
    [sym_preproc_endregion] = STATE(3250),
    [sym_preproc_line] = STATE(3250),
    [sym_preproc_pragma] = STATE(3250),
    [sym_preproc_nullable] = STATE(3250),
    [sym_preproc_error] = STATE(3250),
    [sym_preproc_warning] = STATE(3250),
    [sym_preproc_define] = STATE(3250),
    [sym_preproc_undef] = STATE(3250),
    [sym__identifier_token] = ACTIONS(3785),
    [anon_sym_extern] = ACTIONS(3785),
    [anon_sym_alias] = ACTIONS(3785),
    [anon_sym_global] = ACTIONS(3785),
    [anon_sym_using] = ACTIONS(3785),
    [anon_sym_unsafe] = ACTIONS(3785),
    [anon_sym_static] = ACTIONS(3785),
    [anon_sym_LBRACK] = ACTIONS(3787),
    [anon_sym_LPAREN] = ACTIONS(3787),
    [anon_sym_event] = ACTIONS(3785),
    [anon_sym_namespace] = ACTIONS(3785),
    [anon_sym_class] = ACTIONS(3785),
    [anon_sym_ref] = ACTIONS(3785),
    [anon_sym_struct] = ACTIONS(3785),
    [anon_sym_enum] = ACTIONS(3785),
    [anon_sym_RBRACE] = ACTIONS(3787),
    [anon_sym_interface] = ACTIONS(3785),
    [anon_sym_delegate] = ACTIONS(3785),
    [anon_sym_record] = ACTIONS(3785),
    [anon_sym_abstract] = ACTIONS(3785),
    [anon_sym_async] = ACTIONS(3785),
    [anon_sym_const] = ACTIONS(3785),
    [anon_sym_file] = ACTIONS(3785),
    [anon_sym_fixed] = ACTIONS(3785),
    [anon_sym_internal] = ACTIONS(3785),
    [anon_sym_new] = ACTIONS(3785),
    [anon_sym_override] = ACTIONS(3785),
    [anon_sym_partial] = ACTIONS(3785),
    [anon_sym_private] = ACTIONS(3785),
    [anon_sym_protected] = ACTIONS(3785),
    [anon_sym_public] = ACTIONS(3785),
    [anon_sym_readonly] = ACTIONS(3785),
    [anon_sym_required] = ACTIONS(3785),
    [anon_sym_sealed] = ACTIONS(3785),
    [anon_sym_virtual] = ACTIONS(3785),
    [anon_sym_volatile] = ACTIONS(3785),
    [anon_sym_where] = ACTIONS(3785),
    [anon_sym_notnull] = ACTIONS(3785),
    [anon_sym_unmanaged] = ACTIONS(3785),
    [anon_sym_TILDE] = ACTIONS(3787),
    [anon_sym_implicit] = ACTIONS(3785),
    [anon_sym_explicit] = ACTIONS(3785),
    [anon_sym_scoped] = ACTIONS(3785),
    [anon_sym_var] = ACTIONS(3785),
    [sym_predefined_type] = ACTIONS(3785),
    [anon_sym_yield] = ACTIONS(3785),
    [anon_sym_when] = ACTIONS(3785),
    [anon_sym_from] = ACTIONS(3785),
    [anon_sym_into] = ACTIONS(3785),
    [anon_sym_join] = ACTIONS(3785),
    [anon_sym_on] = ACTIONS(3785),
    [anon_sym_equals] = ACTIONS(3785),
    [anon_sym_let] = ACTIONS(3785),
    [anon_sym_orderby] = ACTIONS(3785),
    [anon_sym_ascending] = ACTIONS(3785),
    [anon_sym_descending] = ACTIONS(3785),
    [anon_sym_group] = ACTIONS(3785),
    [anon_sym_by] = ACTIONS(3785),
    [anon_sym_select] = ACTIONS(3785),
    [aux_sym_preproc_if_token1] = ACTIONS(3787),
    [aux_sym_preproc_if_token3] = ACTIONS(3787),
    [aux_sym_preproc_else_token1] = ACTIONS(3787),
    [aux_sym_preproc_elif_token1] = ACTIONS(3787),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3251] = {
    [sym_preproc_region] = STATE(3251),
    [sym_preproc_endregion] = STATE(3251),
    [sym_preproc_line] = STATE(3251),
    [sym_preproc_pragma] = STATE(3251),
    [sym_preproc_nullable] = STATE(3251),
    [sym_preproc_error] = STATE(3251),
    [sym_preproc_warning] = STATE(3251),
    [sym_preproc_define] = STATE(3251),
    [sym_preproc_undef] = STATE(3251),
    [sym__identifier_token] = ACTIONS(3789),
    [anon_sym_extern] = ACTIONS(3789),
    [anon_sym_alias] = ACTIONS(3789),
    [anon_sym_global] = ACTIONS(3789),
    [anon_sym_using] = ACTIONS(3789),
    [anon_sym_unsafe] = ACTIONS(3789),
    [anon_sym_static] = ACTIONS(3789),
    [anon_sym_LBRACK] = ACTIONS(3791),
    [anon_sym_LPAREN] = ACTIONS(3791),
    [anon_sym_event] = ACTIONS(3789),
    [anon_sym_namespace] = ACTIONS(3789),
    [anon_sym_class] = ACTIONS(3789),
    [anon_sym_ref] = ACTIONS(3789),
    [anon_sym_struct] = ACTIONS(3789),
    [anon_sym_enum] = ACTIONS(3789),
    [anon_sym_RBRACE] = ACTIONS(3791),
    [anon_sym_interface] = ACTIONS(3789),
    [anon_sym_delegate] = ACTIONS(3789),
    [anon_sym_record] = ACTIONS(3789),
    [anon_sym_abstract] = ACTIONS(3789),
    [anon_sym_async] = ACTIONS(3789),
    [anon_sym_const] = ACTIONS(3789),
    [anon_sym_file] = ACTIONS(3789),
    [anon_sym_fixed] = ACTIONS(3789),
    [anon_sym_internal] = ACTIONS(3789),
    [anon_sym_new] = ACTIONS(3789),
    [anon_sym_override] = ACTIONS(3789),
    [anon_sym_partial] = ACTIONS(3789),
    [anon_sym_private] = ACTIONS(3789),
    [anon_sym_protected] = ACTIONS(3789),
    [anon_sym_public] = ACTIONS(3789),
    [anon_sym_readonly] = ACTIONS(3789),
    [anon_sym_required] = ACTIONS(3789),
    [anon_sym_sealed] = ACTIONS(3789),
    [anon_sym_virtual] = ACTIONS(3789),
    [anon_sym_volatile] = ACTIONS(3789),
    [anon_sym_where] = ACTIONS(3789),
    [anon_sym_notnull] = ACTIONS(3789),
    [anon_sym_unmanaged] = ACTIONS(3789),
    [anon_sym_TILDE] = ACTIONS(3791),
    [anon_sym_implicit] = ACTIONS(3789),
    [anon_sym_explicit] = ACTIONS(3789),
    [anon_sym_scoped] = ACTIONS(3789),
    [anon_sym_var] = ACTIONS(3789),
    [sym_predefined_type] = ACTIONS(3789),
    [anon_sym_yield] = ACTIONS(3789),
    [anon_sym_when] = ACTIONS(3789),
    [anon_sym_from] = ACTIONS(3789),
    [anon_sym_into] = ACTIONS(3789),
    [anon_sym_join] = ACTIONS(3789),
    [anon_sym_on] = ACTIONS(3789),
    [anon_sym_equals] = ACTIONS(3789),
    [anon_sym_let] = ACTIONS(3789),
    [anon_sym_orderby] = ACTIONS(3789),
    [anon_sym_ascending] = ACTIONS(3789),
    [anon_sym_descending] = ACTIONS(3789),
    [anon_sym_group] = ACTIONS(3789),
    [anon_sym_by] = ACTIONS(3789),
    [anon_sym_select] = ACTIONS(3789),
    [aux_sym_preproc_if_token1] = ACTIONS(3791),
    [aux_sym_preproc_if_token3] = ACTIONS(3791),
    [aux_sym_preproc_else_token1] = ACTIONS(3791),
    [aux_sym_preproc_elif_token1] = ACTIONS(3791),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3252] = {
    [sym_preproc_region] = STATE(3252),
    [sym_preproc_endregion] = STATE(3252),
    [sym_preproc_line] = STATE(3252),
    [sym_preproc_pragma] = STATE(3252),
    [sym_preproc_nullable] = STATE(3252),
    [sym_preproc_error] = STATE(3252),
    [sym_preproc_warning] = STATE(3252),
    [sym_preproc_define] = STATE(3252),
    [sym_preproc_undef] = STATE(3252),
    [sym__identifier_token] = ACTIONS(3793),
    [anon_sym_extern] = ACTIONS(3793),
    [anon_sym_alias] = ACTIONS(3793),
    [anon_sym_global] = ACTIONS(3793),
    [anon_sym_using] = ACTIONS(3793),
    [anon_sym_unsafe] = ACTIONS(3793),
    [anon_sym_static] = ACTIONS(3793),
    [anon_sym_LBRACK] = ACTIONS(3795),
    [anon_sym_LPAREN] = ACTIONS(3795),
    [anon_sym_event] = ACTIONS(3793),
    [anon_sym_namespace] = ACTIONS(3793),
    [anon_sym_class] = ACTIONS(3793),
    [anon_sym_ref] = ACTIONS(3793),
    [anon_sym_struct] = ACTIONS(3793),
    [anon_sym_enum] = ACTIONS(3793),
    [anon_sym_RBRACE] = ACTIONS(3795),
    [anon_sym_interface] = ACTIONS(3793),
    [anon_sym_delegate] = ACTIONS(3793),
    [anon_sym_record] = ACTIONS(3793),
    [anon_sym_abstract] = ACTIONS(3793),
    [anon_sym_async] = ACTIONS(3793),
    [anon_sym_const] = ACTIONS(3793),
    [anon_sym_file] = ACTIONS(3793),
    [anon_sym_fixed] = ACTIONS(3793),
    [anon_sym_internal] = ACTIONS(3793),
    [anon_sym_new] = ACTIONS(3793),
    [anon_sym_override] = ACTIONS(3793),
    [anon_sym_partial] = ACTIONS(3793),
    [anon_sym_private] = ACTIONS(3793),
    [anon_sym_protected] = ACTIONS(3793),
    [anon_sym_public] = ACTIONS(3793),
    [anon_sym_readonly] = ACTIONS(3793),
    [anon_sym_required] = ACTIONS(3793),
    [anon_sym_sealed] = ACTIONS(3793),
    [anon_sym_virtual] = ACTIONS(3793),
    [anon_sym_volatile] = ACTIONS(3793),
    [anon_sym_where] = ACTIONS(3793),
    [anon_sym_notnull] = ACTIONS(3793),
    [anon_sym_unmanaged] = ACTIONS(3793),
    [anon_sym_TILDE] = ACTIONS(3795),
    [anon_sym_implicit] = ACTIONS(3793),
    [anon_sym_explicit] = ACTIONS(3793),
    [anon_sym_scoped] = ACTIONS(3793),
    [anon_sym_var] = ACTIONS(3793),
    [sym_predefined_type] = ACTIONS(3793),
    [anon_sym_yield] = ACTIONS(3793),
    [anon_sym_when] = ACTIONS(3793),
    [anon_sym_from] = ACTIONS(3793),
    [anon_sym_into] = ACTIONS(3793),
    [anon_sym_join] = ACTIONS(3793),
    [anon_sym_on] = ACTIONS(3793),
    [anon_sym_equals] = ACTIONS(3793),
    [anon_sym_let] = ACTIONS(3793),
    [anon_sym_orderby] = ACTIONS(3793),
    [anon_sym_ascending] = ACTIONS(3793),
    [anon_sym_descending] = ACTIONS(3793),
    [anon_sym_group] = ACTIONS(3793),
    [anon_sym_by] = ACTIONS(3793),
    [anon_sym_select] = ACTIONS(3793),
    [aux_sym_preproc_if_token1] = ACTIONS(3795),
    [aux_sym_preproc_if_token3] = ACTIONS(3795),
    [aux_sym_preproc_else_token1] = ACTIONS(3795),
    [aux_sym_preproc_elif_token1] = ACTIONS(3795),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3253] = {
    [sym_preproc_region] = STATE(3253),
    [sym_preproc_endregion] = STATE(3253),
    [sym_preproc_line] = STATE(3253),
    [sym_preproc_pragma] = STATE(3253),
    [sym_preproc_nullable] = STATE(3253),
    [sym_preproc_error] = STATE(3253),
    [sym_preproc_warning] = STATE(3253),
    [sym_preproc_define] = STATE(3253),
    [sym_preproc_undef] = STATE(3253),
    [sym__identifier_token] = ACTIONS(3797),
    [anon_sym_extern] = ACTIONS(3797),
    [anon_sym_alias] = ACTIONS(3797),
    [anon_sym_global] = ACTIONS(3797),
    [anon_sym_using] = ACTIONS(3797),
    [anon_sym_unsafe] = ACTIONS(3797),
    [anon_sym_static] = ACTIONS(3797),
    [anon_sym_LBRACK] = ACTIONS(3799),
    [anon_sym_LPAREN] = ACTIONS(3799),
    [anon_sym_event] = ACTIONS(3797),
    [anon_sym_namespace] = ACTIONS(3797),
    [anon_sym_class] = ACTIONS(3797),
    [anon_sym_ref] = ACTIONS(3797),
    [anon_sym_struct] = ACTIONS(3797),
    [anon_sym_enum] = ACTIONS(3797),
    [anon_sym_RBRACE] = ACTIONS(3799),
    [anon_sym_interface] = ACTIONS(3797),
    [anon_sym_delegate] = ACTIONS(3797),
    [anon_sym_record] = ACTIONS(3797),
    [anon_sym_abstract] = ACTIONS(3797),
    [anon_sym_async] = ACTIONS(3797),
    [anon_sym_const] = ACTIONS(3797),
    [anon_sym_file] = ACTIONS(3797),
    [anon_sym_fixed] = ACTIONS(3797),
    [anon_sym_internal] = ACTIONS(3797),
    [anon_sym_new] = ACTIONS(3797),
    [anon_sym_override] = ACTIONS(3797),
    [anon_sym_partial] = ACTIONS(3797),
    [anon_sym_private] = ACTIONS(3797),
    [anon_sym_protected] = ACTIONS(3797),
    [anon_sym_public] = ACTIONS(3797),
    [anon_sym_readonly] = ACTIONS(3797),
    [anon_sym_required] = ACTIONS(3797),
    [anon_sym_sealed] = ACTIONS(3797),
    [anon_sym_virtual] = ACTIONS(3797),
    [anon_sym_volatile] = ACTIONS(3797),
    [anon_sym_where] = ACTIONS(3797),
    [anon_sym_notnull] = ACTIONS(3797),
    [anon_sym_unmanaged] = ACTIONS(3797),
    [anon_sym_TILDE] = ACTIONS(3799),
    [anon_sym_implicit] = ACTIONS(3797),
    [anon_sym_explicit] = ACTIONS(3797),
    [anon_sym_scoped] = ACTIONS(3797),
    [anon_sym_var] = ACTIONS(3797),
    [sym_predefined_type] = ACTIONS(3797),
    [anon_sym_yield] = ACTIONS(3797),
    [anon_sym_when] = ACTIONS(3797),
    [anon_sym_from] = ACTIONS(3797),
    [anon_sym_into] = ACTIONS(3797),
    [anon_sym_join] = ACTIONS(3797),
    [anon_sym_on] = ACTIONS(3797),
    [anon_sym_equals] = ACTIONS(3797),
    [anon_sym_let] = ACTIONS(3797),
    [anon_sym_orderby] = ACTIONS(3797),
    [anon_sym_ascending] = ACTIONS(3797),
    [anon_sym_descending] = ACTIONS(3797),
    [anon_sym_group] = ACTIONS(3797),
    [anon_sym_by] = ACTIONS(3797),
    [anon_sym_select] = ACTIONS(3797),
    [aux_sym_preproc_if_token1] = ACTIONS(3799),
    [aux_sym_preproc_if_token3] = ACTIONS(3799),
    [aux_sym_preproc_else_token1] = ACTIONS(3799),
    [aux_sym_preproc_elif_token1] = ACTIONS(3799),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3254] = {
    [sym_preproc_region] = STATE(3254),
    [sym_preproc_endregion] = STATE(3254),
    [sym_preproc_line] = STATE(3254),
    [sym_preproc_pragma] = STATE(3254),
    [sym_preproc_nullable] = STATE(3254),
    [sym_preproc_error] = STATE(3254),
    [sym_preproc_warning] = STATE(3254),
    [sym_preproc_define] = STATE(3254),
    [sym_preproc_undef] = STATE(3254),
    [sym__identifier_token] = ACTIONS(3801),
    [anon_sym_extern] = ACTIONS(3801),
    [anon_sym_alias] = ACTIONS(3801),
    [anon_sym_global] = ACTIONS(3801),
    [anon_sym_using] = ACTIONS(3801),
    [anon_sym_unsafe] = ACTIONS(3801),
    [anon_sym_static] = ACTIONS(3801),
    [anon_sym_LBRACK] = ACTIONS(3803),
    [anon_sym_LPAREN] = ACTIONS(3803),
    [anon_sym_event] = ACTIONS(3801),
    [anon_sym_namespace] = ACTIONS(3801),
    [anon_sym_class] = ACTIONS(3801),
    [anon_sym_ref] = ACTIONS(3801),
    [anon_sym_struct] = ACTIONS(3801),
    [anon_sym_enum] = ACTIONS(3801),
    [anon_sym_RBRACE] = ACTIONS(3803),
    [anon_sym_interface] = ACTIONS(3801),
    [anon_sym_delegate] = ACTIONS(3801),
    [anon_sym_record] = ACTIONS(3801),
    [anon_sym_abstract] = ACTIONS(3801),
    [anon_sym_async] = ACTIONS(3801),
    [anon_sym_const] = ACTIONS(3801),
    [anon_sym_file] = ACTIONS(3801),
    [anon_sym_fixed] = ACTIONS(3801),
    [anon_sym_internal] = ACTIONS(3801),
    [anon_sym_new] = ACTIONS(3801),
    [anon_sym_override] = ACTIONS(3801),
    [anon_sym_partial] = ACTIONS(3801),
    [anon_sym_private] = ACTIONS(3801),
    [anon_sym_protected] = ACTIONS(3801),
    [anon_sym_public] = ACTIONS(3801),
    [anon_sym_readonly] = ACTIONS(3801),
    [anon_sym_required] = ACTIONS(3801),
    [anon_sym_sealed] = ACTIONS(3801),
    [anon_sym_virtual] = ACTIONS(3801),
    [anon_sym_volatile] = ACTIONS(3801),
    [anon_sym_where] = ACTIONS(3801),
    [anon_sym_notnull] = ACTIONS(3801),
    [anon_sym_unmanaged] = ACTIONS(3801),
    [anon_sym_TILDE] = ACTIONS(3803),
    [anon_sym_implicit] = ACTIONS(3801),
    [anon_sym_explicit] = ACTIONS(3801),
    [anon_sym_scoped] = ACTIONS(3801),
    [anon_sym_var] = ACTIONS(3801),
    [sym_predefined_type] = ACTIONS(3801),
    [anon_sym_yield] = ACTIONS(3801),
    [anon_sym_when] = ACTIONS(3801),
    [anon_sym_from] = ACTIONS(3801),
    [anon_sym_into] = ACTIONS(3801),
    [anon_sym_join] = ACTIONS(3801),
    [anon_sym_on] = ACTIONS(3801),
    [anon_sym_equals] = ACTIONS(3801),
    [anon_sym_let] = ACTIONS(3801),
    [anon_sym_orderby] = ACTIONS(3801),
    [anon_sym_ascending] = ACTIONS(3801),
    [anon_sym_descending] = ACTIONS(3801),
    [anon_sym_group] = ACTIONS(3801),
    [anon_sym_by] = ACTIONS(3801),
    [anon_sym_select] = ACTIONS(3801),
    [aux_sym_preproc_if_token1] = ACTIONS(3803),
    [aux_sym_preproc_if_token3] = ACTIONS(3803),
    [aux_sym_preproc_else_token1] = ACTIONS(3803),
    [aux_sym_preproc_elif_token1] = ACTIONS(3803),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3255] = {
    [sym_preproc_region] = STATE(3255),
    [sym_preproc_endregion] = STATE(3255),
    [sym_preproc_line] = STATE(3255),
    [sym_preproc_pragma] = STATE(3255),
    [sym_preproc_nullable] = STATE(3255),
    [sym_preproc_error] = STATE(3255),
    [sym_preproc_warning] = STATE(3255),
    [sym_preproc_define] = STATE(3255),
    [sym_preproc_undef] = STATE(3255),
    [sym__identifier_token] = ACTIONS(3805),
    [anon_sym_extern] = ACTIONS(3805),
    [anon_sym_alias] = ACTIONS(3805),
    [anon_sym_global] = ACTIONS(3805),
    [anon_sym_using] = ACTIONS(3805),
    [anon_sym_unsafe] = ACTIONS(3805),
    [anon_sym_static] = ACTIONS(3805),
    [anon_sym_LBRACK] = ACTIONS(3807),
    [anon_sym_LPAREN] = ACTIONS(3807),
    [anon_sym_event] = ACTIONS(3805),
    [anon_sym_namespace] = ACTIONS(3805),
    [anon_sym_class] = ACTIONS(3805),
    [anon_sym_ref] = ACTIONS(3805),
    [anon_sym_struct] = ACTIONS(3805),
    [anon_sym_enum] = ACTIONS(3805),
    [anon_sym_RBRACE] = ACTIONS(3807),
    [anon_sym_interface] = ACTIONS(3805),
    [anon_sym_delegate] = ACTIONS(3805),
    [anon_sym_record] = ACTIONS(3805),
    [anon_sym_abstract] = ACTIONS(3805),
    [anon_sym_async] = ACTIONS(3805),
    [anon_sym_const] = ACTIONS(3805),
    [anon_sym_file] = ACTIONS(3805),
    [anon_sym_fixed] = ACTIONS(3805),
    [anon_sym_internal] = ACTIONS(3805),
    [anon_sym_new] = ACTIONS(3805),
    [anon_sym_override] = ACTIONS(3805),
    [anon_sym_partial] = ACTIONS(3805),
    [anon_sym_private] = ACTIONS(3805),
    [anon_sym_protected] = ACTIONS(3805),
    [anon_sym_public] = ACTIONS(3805),
    [anon_sym_readonly] = ACTIONS(3805),
    [anon_sym_required] = ACTIONS(3805),
    [anon_sym_sealed] = ACTIONS(3805),
    [anon_sym_virtual] = ACTIONS(3805),
    [anon_sym_volatile] = ACTIONS(3805),
    [anon_sym_where] = ACTIONS(3805),
    [anon_sym_notnull] = ACTIONS(3805),
    [anon_sym_unmanaged] = ACTIONS(3805),
    [anon_sym_TILDE] = ACTIONS(3807),
    [anon_sym_implicit] = ACTIONS(3805),
    [anon_sym_explicit] = ACTIONS(3805),
    [anon_sym_scoped] = ACTIONS(3805),
    [anon_sym_var] = ACTIONS(3805),
    [sym_predefined_type] = ACTIONS(3805),
    [anon_sym_yield] = ACTIONS(3805),
    [anon_sym_when] = ACTIONS(3805),
    [anon_sym_from] = ACTIONS(3805),
    [anon_sym_into] = ACTIONS(3805),
    [anon_sym_join] = ACTIONS(3805),
    [anon_sym_on] = ACTIONS(3805),
    [anon_sym_equals] = ACTIONS(3805),
    [anon_sym_let] = ACTIONS(3805),
    [anon_sym_orderby] = ACTIONS(3805),
    [anon_sym_ascending] = ACTIONS(3805),
    [anon_sym_descending] = ACTIONS(3805),
    [anon_sym_group] = ACTIONS(3805),
    [anon_sym_by] = ACTIONS(3805),
    [anon_sym_select] = ACTIONS(3805),
    [aux_sym_preproc_if_token1] = ACTIONS(3807),
    [aux_sym_preproc_if_token3] = ACTIONS(3807),
    [aux_sym_preproc_else_token1] = ACTIONS(3807),
    [aux_sym_preproc_elif_token1] = ACTIONS(3807),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3256] = {
    [sym_preproc_region] = STATE(3256),
    [sym_preproc_endregion] = STATE(3256),
    [sym_preproc_line] = STATE(3256),
    [sym_preproc_pragma] = STATE(3256),
    [sym_preproc_nullable] = STATE(3256),
    [sym_preproc_error] = STATE(3256),
    [sym_preproc_warning] = STATE(3256),
    [sym_preproc_define] = STATE(3256),
    [sym_preproc_undef] = STATE(3256),
    [sym__identifier_token] = ACTIONS(3809),
    [anon_sym_extern] = ACTIONS(3809),
    [anon_sym_alias] = ACTIONS(3809),
    [anon_sym_global] = ACTIONS(3809),
    [anon_sym_using] = ACTIONS(3809),
    [anon_sym_unsafe] = ACTIONS(3809),
    [anon_sym_static] = ACTIONS(3809),
    [anon_sym_LBRACK] = ACTIONS(3811),
    [anon_sym_LPAREN] = ACTIONS(3811),
    [anon_sym_event] = ACTIONS(3809),
    [anon_sym_namespace] = ACTIONS(3809),
    [anon_sym_class] = ACTIONS(3809),
    [anon_sym_ref] = ACTIONS(3809),
    [anon_sym_struct] = ACTIONS(3809),
    [anon_sym_enum] = ACTIONS(3809),
    [anon_sym_RBRACE] = ACTIONS(3811),
    [anon_sym_interface] = ACTIONS(3809),
    [anon_sym_delegate] = ACTIONS(3809),
    [anon_sym_record] = ACTIONS(3809),
    [anon_sym_abstract] = ACTIONS(3809),
    [anon_sym_async] = ACTIONS(3809),
    [anon_sym_const] = ACTIONS(3809),
    [anon_sym_file] = ACTIONS(3809),
    [anon_sym_fixed] = ACTIONS(3809),
    [anon_sym_internal] = ACTIONS(3809),
    [anon_sym_new] = ACTIONS(3809),
    [anon_sym_override] = ACTIONS(3809),
    [anon_sym_partial] = ACTIONS(3809),
    [anon_sym_private] = ACTIONS(3809),
    [anon_sym_protected] = ACTIONS(3809),
    [anon_sym_public] = ACTIONS(3809),
    [anon_sym_readonly] = ACTIONS(3809),
    [anon_sym_required] = ACTIONS(3809),
    [anon_sym_sealed] = ACTIONS(3809),
    [anon_sym_virtual] = ACTIONS(3809),
    [anon_sym_volatile] = ACTIONS(3809),
    [anon_sym_where] = ACTIONS(3809),
    [anon_sym_notnull] = ACTIONS(3809),
    [anon_sym_unmanaged] = ACTIONS(3809),
    [anon_sym_TILDE] = ACTIONS(3811),
    [anon_sym_implicit] = ACTIONS(3809),
    [anon_sym_explicit] = ACTIONS(3809),
    [anon_sym_scoped] = ACTIONS(3809),
    [anon_sym_var] = ACTIONS(3809),
    [sym_predefined_type] = ACTIONS(3809),
    [anon_sym_yield] = ACTIONS(3809),
    [anon_sym_when] = ACTIONS(3809),
    [anon_sym_from] = ACTIONS(3809),
    [anon_sym_into] = ACTIONS(3809),
    [anon_sym_join] = ACTIONS(3809),
    [anon_sym_on] = ACTIONS(3809),
    [anon_sym_equals] = ACTIONS(3809),
    [anon_sym_let] = ACTIONS(3809),
    [anon_sym_orderby] = ACTIONS(3809),
    [anon_sym_ascending] = ACTIONS(3809),
    [anon_sym_descending] = ACTIONS(3809),
    [anon_sym_group] = ACTIONS(3809),
    [anon_sym_by] = ACTIONS(3809),
    [anon_sym_select] = ACTIONS(3809),
    [aux_sym_preproc_if_token1] = ACTIONS(3811),
    [aux_sym_preproc_if_token3] = ACTIONS(3811),
    [aux_sym_preproc_else_token1] = ACTIONS(3811),
    [aux_sym_preproc_elif_token1] = ACTIONS(3811),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3257] = {
    [sym_preproc_region] = STATE(3257),
    [sym_preproc_endregion] = STATE(3257),
    [sym_preproc_line] = STATE(3257),
    [sym_preproc_pragma] = STATE(3257),
    [sym_preproc_nullable] = STATE(3257),
    [sym_preproc_error] = STATE(3257),
    [sym_preproc_warning] = STATE(3257),
    [sym_preproc_define] = STATE(3257),
    [sym_preproc_undef] = STATE(3257),
    [sym__identifier_token] = ACTIONS(3813),
    [anon_sym_extern] = ACTIONS(3813),
    [anon_sym_alias] = ACTIONS(3813),
    [anon_sym_global] = ACTIONS(3813),
    [anon_sym_using] = ACTIONS(3813),
    [anon_sym_unsafe] = ACTIONS(3813),
    [anon_sym_static] = ACTIONS(3813),
    [anon_sym_LBRACK] = ACTIONS(3815),
    [anon_sym_LPAREN] = ACTIONS(3815),
    [anon_sym_event] = ACTIONS(3813),
    [anon_sym_namespace] = ACTIONS(3813),
    [anon_sym_class] = ACTIONS(3813),
    [anon_sym_ref] = ACTIONS(3813),
    [anon_sym_struct] = ACTIONS(3813),
    [anon_sym_enum] = ACTIONS(3813),
    [anon_sym_RBRACE] = ACTIONS(3815),
    [anon_sym_interface] = ACTIONS(3813),
    [anon_sym_delegate] = ACTIONS(3813),
    [anon_sym_record] = ACTIONS(3813),
    [anon_sym_abstract] = ACTIONS(3813),
    [anon_sym_async] = ACTIONS(3813),
    [anon_sym_const] = ACTIONS(3813),
    [anon_sym_file] = ACTIONS(3813),
    [anon_sym_fixed] = ACTIONS(3813),
    [anon_sym_internal] = ACTIONS(3813),
    [anon_sym_new] = ACTIONS(3813),
    [anon_sym_override] = ACTIONS(3813),
    [anon_sym_partial] = ACTIONS(3813),
    [anon_sym_private] = ACTIONS(3813),
    [anon_sym_protected] = ACTIONS(3813),
    [anon_sym_public] = ACTIONS(3813),
    [anon_sym_readonly] = ACTIONS(3813),
    [anon_sym_required] = ACTIONS(3813),
    [anon_sym_sealed] = ACTIONS(3813),
    [anon_sym_virtual] = ACTIONS(3813),
    [anon_sym_volatile] = ACTIONS(3813),
    [anon_sym_where] = ACTIONS(3813),
    [anon_sym_notnull] = ACTIONS(3813),
    [anon_sym_unmanaged] = ACTIONS(3813),
    [anon_sym_TILDE] = ACTIONS(3815),
    [anon_sym_implicit] = ACTIONS(3813),
    [anon_sym_explicit] = ACTIONS(3813),
    [anon_sym_scoped] = ACTIONS(3813),
    [anon_sym_var] = ACTIONS(3813),
    [sym_predefined_type] = ACTIONS(3813),
    [anon_sym_yield] = ACTIONS(3813),
    [anon_sym_when] = ACTIONS(3813),
    [anon_sym_from] = ACTIONS(3813),
    [anon_sym_into] = ACTIONS(3813),
    [anon_sym_join] = ACTIONS(3813),
    [anon_sym_on] = ACTIONS(3813),
    [anon_sym_equals] = ACTIONS(3813),
    [anon_sym_let] = ACTIONS(3813),
    [anon_sym_orderby] = ACTIONS(3813),
    [anon_sym_ascending] = ACTIONS(3813),
    [anon_sym_descending] = ACTIONS(3813),
    [anon_sym_group] = ACTIONS(3813),
    [anon_sym_by] = ACTIONS(3813),
    [anon_sym_select] = ACTIONS(3813),
    [aux_sym_preproc_if_token1] = ACTIONS(3815),
    [aux_sym_preproc_if_token3] = ACTIONS(3815),
    [aux_sym_preproc_else_token1] = ACTIONS(3815),
    [aux_sym_preproc_elif_token1] = ACTIONS(3815),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3258] = {
    [sym_preproc_region] = STATE(3258),
    [sym_preproc_endregion] = STATE(3258),
    [sym_preproc_line] = STATE(3258),
    [sym_preproc_pragma] = STATE(3258),
    [sym_preproc_nullable] = STATE(3258),
    [sym_preproc_error] = STATE(3258),
    [sym_preproc_warning] = STATE(3258),
    [sym_preproc_define] = STATE(3258),
    [sym_preproc_undef] = STATE(3258),
    [sym__identifier_token] = ACTIONS(3817),
    [anon_sym_extern] = ACTIONS(3817),
    [anon_sym_alias] = ACTIONS(3817),
    [anon_sym_global] = ACTIONS(3817),
    [anon_sym_using] = ACTIONS(3817),
    [anon_sym_unsafe] = ACTIONS(3817),
    [anon_sym_static] = ACTIONS(3817),
    [anon_sym_LBRACK] = ACTIONS(3819),
    [anon_sym_LPAREN] = ACTIONS(3819),
    [anon_sym_event] = ACTIONS(3817),
    [anon_sym_namespace] = ACTIONS(3817),
    [anon_sym_class] = ACTIONS(3817),
    [anon_sym_ref] = ACTIONS(3817),
    [anon_sym_struct] = ACTIONS(3817),
    [anon_sym_enum] = ACTIONS(3817),
    [anon_sym_RBRACE] = ACTIONS(3819),
    [anon_sym_interface] = ACTIONS(3817),
    [anon_sym_delegate] = ACTIONS(3817),
    [anon_sym_record] = ACTIONS(3817),
    [anon_sym_abstract] = ACTIONS(3817),
    [anon_sym_async] = ACTIONS(3817),
    [anon_sym_const] = ACTIONS(3817),
    [anon_sym_file] = ACTIONS(3817),
    [anon_sym_fixed] = ACTIONS(3817),
    [anon_sym_internal] = ACTIONS(3817),
    [anon_sym_new] = ACTIONS(3817),
    [anon_sym_override] = ACTIONS(3817),
    [anon_sym_partial] = ACTIONS(3817),
    [anon_sym_private] = ACTIONS(3817),
    [anon_sym_protected] = ACTIONS(3817),
    [anon_sym_public] = ACTIONS(3817),
    [anon_sym_readonly] = ACTIONS(3817),
    [anon_sym_required] = ACTIONS(3817),
    [anon_sym_sealed] = ACTIONS(3817),
    [anon_sym_virtual] = ACTIONS(3817),
    [anon_sym_volatile] = ACTIONS(3817),
    [anon_sym_where] = ACTIONS(3817),
    [anon_sym_notnull] = ACTIONS(3817),
    [anon_sym_unmanaged] = ACTIONS(3817),
    [anon_sym_TILDE] = ACTIONS(3819),
    [anon_sym_implicit] = ACTIONS(3817),
    [anon_sym_explicit] = ACTIONS(3817),
    [anon_sym_scoped] = ACTIONS(3817),
    [anon_sym_var] = ACTIONS(3817),
    [sym_predefined_type] = ACTIONS(3817),
    [anon_sym_yield] = ACTIONS(3817),
    [anon_sym_when] = ACTIONS(3817),
    [anon_sym_from] = ACTIONS(3817),
    [anon_sym_into] = ACTIONS(3817),
    [anon_sym_join] = ACTIONS(3817),
    [anon_sym_on] = ACTIONS(3817),
    [anon_sym_equals] = ACTIONS(3817),
    [anon_sym_let] = ACTIONS(3817),
    [anon_sym_orderby] = ACTIONS(3817),
    [anon_sym_ascending] = ACTIONS(3817),
    [anon_sym_descending] = ACTIONS(3817),
    [anon_sym_group] = ACTIONS(3817),
    [anon_sym_by] = ACTIONS(3817),
    [anon_sym_select] = ACTIONS(3817),
    [aux_sym_preproc_if_token1] = ACTIONS(3819),
    [aux_sym_preproc_if_token3] = ACTIONS(3819),
    [aux_sym_preproc_else_token1] = ACTIONS(3819),
    [aux_sym_preproc_elif_token1] = ACTIONS(3819),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3259] = {
    [sym_preproc_region] = STATE(3259),
    [sym_preproc_endregion] = STATE(3259),
    [sym_preproc_line] = STATE(3259),
    [sym_preproc_pragma] = STATE(3259),
    [sym_preproc_nullable] = STATE(3259),
    [sym_preproc_error] = STATE(3259),
    [sym_preproc_warning] = STATE(3259),
    [sym_preproc_define] = STATE(3259),
    [sym_preproc_undef] = STATE(3259),
    [sym__identifier_token] = ACTIONS(3473),
    [anon_sym_extern] = ACTIONS(3473),
    [anon_sym_alias] = ACTIONS(3473),
    [anon_sym_global] = ACTIONS(3473),
    [anon_sym_using] = ACTIONS(3473),
    [anon_sym_unsafe] = ACTIONS(3473),
    [anon_sym_static] = ACTIONS(3473),
    [anon_sym_LBRACK] = ACTIONS(3475),
    [anon_sym_LPAREN] = ACTIONS(3475),
    [anon_sym_event] = ACTIONS(3473),
    [anon_sym_namespace] = ACTIONS(3473),
    [anon_sym_class] = ACTIONS(3473),
    [anon_sym_ref] = ACTIONS(3473),
    [anon_sym_struct] = ACTIONS(3473),
    [anon_sym_enum] = ACTIONS(3473),
    [anon_sym_RBRACE] = ACTIONS(3475),
    [anon_sym_interface] = ACTIONS(3473),
    [anon_sym_delegate] = ACTIONS(3473),
    [anon_sym_record] = ACTIONS(3473),
    [anon_sym_abstract] = ACTIONS(3473),
    [anon_sym_async] = ACTIONS(3473),
    [anon_sym_const] = ACTIONS(3473),
    [anon_sym_file] = ACTIONS(3473),
    [anon_sym_fixed] = ACTIONS(3473),
    [anon_sym_internal] = ACTIONS(3473),
    [anon_sym_new] = ACTIONS(3473),
    [anon_sym_override] = ACTIONS(3473),
    [anon_sym_partial] = ACTIONS(3473),
    [anon_sym_private] = ACTIONS(3473),
    [anon_sym_protected] = ACTIONS(3473),
    [anon_sym_public] = ACTIONS(3473),
    [anon_sym_readonly] = ACTIONS(3473),
    [anon_sym_required] = ACTIONS(3473),
    [anon_sym_sealed] = ACTIONS(3473),
    [anon_sym_virtual] = ACTIONS(3473),
    [anon_sym_volatile] = ACTIONS(3473),
    [anon_sym_where] = ACTIONS(3473),
    [anon_sym_notnull] = ACTIONS(3473),
    [anon_sym_unmanaged] = ACTIONS(3473),
    [anon_sym_TILDE] = ACTIONS(3475),
    [anon_sym_implicit] = ACTIONS(3473),
    [anon_sym_explicit] = ACTIONS(3473),
    [anon_sym_scoped] = ACTIONS(3473),
    [anon_sym_var] = ACTIONS(3473),
    [sym_predefined_type] = ACTIONS(3473),
    [anon_sym_yield] = ACTIONS(3473),
    [anon_sym_when] = ACTIONS(3473),
    [anon_sym_from] = ACTIONS(3473),
    [anon_sym_into] = ACTIONS(3473),
    [anon_sym_join] = ACTIONS(3473),
    [anon_sym_on] = ACTIONS(3473),
    [anon_sym_equals] = ACTIONS(3473),
    [anon_sym_let] = ACTIONS(3473),
    [anon_sym_orderby] = ACTIONS(3473),
    [anon_sym_ascending] = ACTIONS(3473),
    [anon_sym_descending] = ACTIONS(3473),
    [anon_sym_group] = ACTIONS(3473),
    [anon_sym_by] = ACTIONS(3473),
    [anon_sym_select] = ACTIONS(3473),
    [aux_sym_preproc_if_token1] = ACTIONS(3475),
    [aux_sym_preproc_if_token3] = ACTIONS(3475),
    [aux_sym_preproc_else_token1] = ACTIONS(3475),
    [aux_sym_preproc_elif_token1] = ACTIONS(3475),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3260] = {
    [sym_preproc_region] = STATE(3260),
    [sym_preproc_endregion] = STATE(3260),
    [sym_preproc_line] = STATE(3260),
    [sym_preproc_pragma] = STATE(3260),
    [sym_preproc_nullable] = STATE(3260),
    [sym_preproc_error] = STATE(3260),
    [sym_preproc_warning] = STATE(3260),
    [sym_preproc_define] = STATE(3260),
    [sym_preproc_undef] = STATE(3260),
    [sym__identifier_token] = ACTIONS(3477),
    [anon_sym_extern] = ACTIONS(3477),
    [anon_sym_alias] = ACTIONS(3477),
    [anon_sym_global] = ACTIONS(3477),
    [anon_sym_using] = ACTIONS(3477),
    [anon_sym_unsafe] = ACTIONS(3477),
    [anon_sym_static] = ACTIONS(3477),
    [anon_sym_LBRACK] = ACTIONS(3479),
    [anon_sym_LPAREN] = ACTIONS(3479),
    [anon_sym_event] = ACTIONS(3477),
    [anon_sym_namespace] = ACTIONS(3477),
    [anon_sym_class] = ACTIONS(3477),
    [anon_sym_ref] = ACTIONS(3477),
    [anon_sym_struct] = ACTIONS(3477),
    [anon_sym_enum] = ACTIONS(3477),
    [anon_sym_RBRACE] = ACTIONS(3479),
    [anon_sym_interface] = ACTIONS(3477),
    [anon_sym_delegate] = ACTIONS(3477),
    [anon_sym_record] = ACTIONS(3477),
    [anon_sym_abstract] = ACTIONS(3477),
    [anon_sym_async] = ACTIONS(3477),
    [anon_sym_const] = ACTIONS(3477),
    [anon_sym_file] = ACTIONS(3477),
    [anon_sym_fixed] = ACTIONS(3477),
    [anon_sym_internal] = ACTIONS(3477),
    [anon_sym_new] = ACTIONS(3477),
    [anon_sym_override] = ACTIONS(3477),
    [anon_sym_partial] = ACTIONS(3477),
    [anon_sym_private] = ACTIONS(3477),
    [anon_sym_protected] = ACTIONS(3477),
    [anon_sym_public] = ACTIONS(3477),
    [anon_sym_readonly] = ACTIONS(3477),
    [anon_sym_required] = ACTIONS(3477),
    [anon_sym_sealed] = ACTIONS(3477),
    [anon_sym_virtual] = ACTIONS(3477),
    [anon_sym_volatile] = ACTIONS(3477),
    [anon_sym_where] = ACTIONS(3477),
    [anon_sym_notnull] = ACTIONS(3477),
    [anon_sym_unmanaged] = ACTIONS(3477),
    [anon_sym_TILDE] = ACTIONS(3479),
    [anon_sym_implicit] = ACTIONS(3477),
    [anon_sym_explicit] = ACTIONS(3477),
    [anon_sym_scoped] = ACTIONS(3477),
    [anon_sym_var] = ACTIONS(3477),
    [sym_predefined_type] = ACTIONS(3477),
    [anon_sym_yield] = ACTIONS(3477),
    [anon_sym_when] = ACTIONS(3477),
    [anon_sym_from] = ACTIONS(3477),
    [anon_sym_into] = ACTIONS(3477),
    [anon_sym_join] = ACTIONS(3477),
    [anon_sym_on] = ACTIONS(3477),
    [anon_sym_equals] = ACTIONS(3477),
    [anon_sym_let] = ACTIONS(3477),
    [anon_sym_orderby] = ACTIONS(3477),
    [anon_sym_ascending] = ACTIONS(3477),
    [anon_sym_descending] = ACTIONS(3477),
    [anon_sym_group] = ACTIONS(3477),
    [anon_sym_by] = ACTIONS(3477),
    [anon_sym_select] = ACTIONS(3477),
    [aux_sym_preproc_if_token1] = ACTIONS(3479),
    [aux_sym_preproc_if_token3] = ACTIONS(3479),
    [aux_sym_preproc_else_token1] = ACTIONS(3479),
    [aux_sym_preproc_elif_token1] = ACTIONS(3479),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3261] = {
    [sym_preproc_region] = STATE(3261),
    [sym_preproc_endregion] = STATE(3261),
    [sym_preproc_line] = STATE(3261),
    [sym_preproc_pragma] = STATE(3261),
    [sym_preproc_nullable] = STATE(3261),
    [sym_preproc_error] = STATE(3261),
    [sym_preproc_warning] = STATE(3261),
    [sym_preproc_define] = STATE(3261),
    [sym_preproc_undef] = STATE(3261),
    [sym__identifier_token] = ACTIONS(3821),
    [anon_sym_extern] = ACTIONS(3821),
    [anon_sym_alias] = ACTIONS(3821),
    [anon_sym_global] = ACTIONS(3821),
    [anon_sym_using] = ACTIONS(3821),
    [anon_sym_unsafe] = ACTIONS(3821),
    [anon_sym_static] = ACTIONS(3821),
    [anon_sym_LBRACK] = ACTIONS(3823),
    [anon_sym_LPAREN] = ACTIONS(3823),
    [anon_sym_event] = ACTIONS(3821),
    [anon_sym_namespace] = ACTIONS(3821),
    [anon_sym_class] = ACTIONS(3821),
    [anon_sym_ref] = ACTIONS(3821),
    [anon_sym_struct] = ACTIONS(3821),
    [anon_sym_enum] = ACTIONS(3821),
    [anon_sym_RBRACE] = ACTIONS(3823),
    [anon_sym_interface] = ACTIONS(3821),
    [anon_sym_delegate] = ACTIONS(3821),
    [anon_sym_record] = ACTIONS(3821),
    [anon_sym_abstract] = ACTIONS(3821),
    [anon_sym_async] = ACTIONS(3821),
    [anon_sym_const] = ACTIONS(3821),
    [anon_sym_file] = ACTIONS(3821),
    [anon_sym_fixed] = ACTIONS(3821),
    [anon_sym_internal] = ACTIONS(3821),
    [anon_sym_new] = ACTIONS(3821),
    [anon_sym_override] = ACTIONS(3821),
    [anon_sym_partial] = ACTIONS(3821),
    [anon_sym_private] = ACTIONS(3821),
    [anon_sym_protected] = ACTIONS(3821),
    [anon_sym_public] = ACTIONS(3821),
    [anon_sym_readonly] = ACTIONS(3821),
    [anon_sym_required] = ACTIONS(3821),
    [anon_sym_sealed] = ACTIONS(3821),
    [anon_sym_virtual] = ACTIONS(3821),
    [anon_sym_volatile] = ACTIONS(3821),
    [anon_sym_where] = ACTIONS(3821),
    [anon_sym_notnull] = ACTIONS(3821),
    [anon_sym_unmanaged] = ACTIONS(3821),
    [anon_sym_TILDE] = ACTIONS(3823),
    [anon_sym_implicit] = ACTIONS(3821),
    [anon_sym_explicit] = ACTIONS(3821),
    [anon_sym_scoped] = ACTIONS(3821),
    [anon_sym_var] = ACTIONS(3821),
    [sym_predefined_type] = ACTIONS(3821),
    [anon_sym_yield] = ACTIONS(3821),
    [anon_sym_when] = ACTIONS(3821),
    [anon_sym_from] = ACTIONS(3821),
    [anon_sym_into] = ACTIONS(3821),
    [anon_sym_join] = ACTIONS(3821),
    [anon_sym_on] = ACTIONS(3821),
    [anon_sym_equals] = ACTIONS(3821),
    [anon_sym_let] = ACTIONS(3821),
    [anon_sym_orderby] = ACTIONS(3821),
    [anon_sym_ascending] = ACTIONS(3821),
    [anon_sym_descending] = ACTIONS(3821),
    [anon_sym_group] = ACTIONS(3821),
    [anon_sym_by] = ACTIONS(3821),
    [anon_sym_select] = ACTIONS(3821),
    [aux_sym_preproc_if_token1] = ACTIONS(3823),
    [aux_sym_preproc_if_token3] = ACTIONS(3823),
    [aux_sym_preproc_else_token1] = ACTIONS(3823),
    [aux_sym_preproc_elif_token1] = ACTIONS(3823),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3262] = {
    [sym_preproc_region] = STATE(3262),
    [sym_preproc_endregion] = STATE(3262),
    [sym_preproc_line] = STATE(3262),
    [sym_preproc_pragma] = STATE(3262),
    [sym_preproc_nullable] = STATE(3262),
    [sym_preproc_error] = STATE(3262),
    [sym_preproc_warning] = STATE(3262),
    [sym_preproc_define] = STATE(3262),
    [sym_preproc_undef] = STATE(3262),
    [sym__identifier_token] = ACTIONS(3825),
    [anon_sym_extern] = ACTIONS(3825),
    [anon_sym_alias] = ACTIONS(3825),
    [anon_sym_global] = ACTIONS(3825),
    [anon_sym_using] = ACTIONS(3825),
    [anon_sym_unsafe] = ACTIONS(3825),
    [anon_sym_static] = ACTIONS(3825),
    [anon_sym_LBRACK] = ACTIONS(3827),
    [anon_sym_LPAREN] = ACTIONS(3827),
    [anon_sym_event] = ACTIONS(3825),
    [anon_sym_namespace] = ACTIONS(3825),
    [anon_sym_class] = ACTIONS(3825),
    [anon_sym_ref] = ACTIONS(3825),
    [anon_sym_struct] = ACTIONS(3825),
    [anon_sym_enum] = ACTIONS(3825),
    [anon_sym_RBRACE] = ACTIONS(3827),
    [anon_sym_interface] = ACTIONS(3825),
    [anon_sym_delegate] = ACTIONS(3825),
    [anon_sym_record] = ACTIONS(3825),
    [anon_sym_abstract] = ACTIONS(3825),
    [anon_sym_async] = ACTIONS(3825),
    [anon_sym_const] = ACTIONS(3825),
    [anon_sym_file] = ACTIONS(3825),
    [anon_sym_fixed] = ACTIONS(3825),
    [anon_sym_internal] = ACTIONS(3825),
    [anon_sym_new] = ACTIONS(3825),
    [anon_sym_override] = ACTIONS(3825),
    [anon_sym_partial] = ACTIONS(3825),
    [anon_sym_private] = ACTIONS(3825),
    [anon_sym_protected] = ACTIONS(3825),
    [anon_sym_public] = ACTIONS(3825),
    [anon_sym_readonly] = ACTIONS(3825),
    [anon_sym_required] = ACTIONS(3825),
    [anon_sym_sealed] = ACTIONS(3825),
    [anon_sym_virtual] = ACTIONS(3825),
    [anon_sym_volatile] = ACTIONS(3825),
    [anon_sym_where] = ACTIONS(3825),
    [anon_sym_notnull] = ACTIONS(3825),
    [anon_sym_unmanaged] = ACTIONS(3825),
    [anon_sym_TILDE] = ACTIONS(3827),
    [anon_sym_implicit] = ACTIONS(3825),
    [anon_sym_explicit] = ACTIONS(3825),
    [anon_sym_scoped] = ACTIONS(3825),
    [anon_sym_var] = ACTIONS(3825),
    [sym_predefined_type] = ACTIONS(3825),
    [anon_sym_yield] = ACTIONS(3825),
    [anon_sym_when] = ACTIONS(3825),
    [anon_sym_from] = ACTIONS(3825),
    [anon_sym_into] = ACTIONS(3825),
    [anon_sym_join] = ACTIONS(3825),
    [anon_sym_on] = ACTIONS(3825),
    [anon_sym_equals] = ACTIONS(3825),
    [anon_sym_let] = ACTIONS(3825),
    [anon_sym_orderby] = ACTIONS(3825),
    [anon_sym_ascending] = ACTIONS(3825),
    [anon_sym_descending] = ACTIONS(3825),
    [anon_sym_group] = ACTIONS(3825),
    [anon_sym_by] = ACTIONS(3825),
    [anon_sym_select] = ACTIONS(3825),
    [aux_sym_preproc_if_token1] = ACTIONS(3827),
    [aux_sym_preproc_if_token3] = ACTIONS(3827),
    [aux_sym_preproc_else_token1] = ACTIONS(3827),
    [aux_sym_preproc_elif_token1] = ACTIONS(3827),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3263] = {
    [sym_preproc_region] = STATE(3263),
    [sym_preproc_endregion] = STATE(3263),
    [sym_preproc_line] = STATE(3263),
    [sym_preproc_pragma] = STATE(3263),
    [sym_preproc_nullable] = STATE(3263),
    [sym_preproc_error] = STATE(3263),
    [sym_preproc_warning] = STATE(3263),
    [sym_preproc_define] = STATE(3263),
    [sym_preproc_undef] = STATE(3263),
    [sym__identifier_token] = ACTIONS(3829),
    [anon_sym_extern] = ACTIONS(3829),
    [anon_sym_alias] = ACTIONS(3829),
    [anon_sym_global] = ACTIONS(3829),
    [anon_sym_using] = ACTIONS(3829),
    [anon_sym_unsafe] = ACTIONS(3829),
    [anon_sym_static] = ACTIONS(3829),
    [anon_sym_LBRACK] = ACTIONS(3831),
    [anon_sym_LPAREN] = ACTIONS(3831),
    [anon_sym_event] = ACTIONS(3829),
    [anon_sym_namespace] = ACTIONS(3829),
    [anon_sym_class] = ACTIONS(3829),
    [anon_sym_ref] = ACTIONS(3829),
    [anon_sym_struct] = ACTIONS(3829),
    [anon_sym_enum] = ACTIONS(3829),
    [anon_sym_RBRACE] = ACTIONS(3831),
    [anon_sym_interface] = ACTIONS(3829),
    [anon_sym_delegate] = ACTIONS(3829),
    [anon_sym_record] = ACTIONS(3829),
    [anon_sym_abstract] = ACTIONS(3829),
    [anon_sym_async] = ACTIONS(3829),
    [anon_sym_const] = ACTIONS(3829),
    [anon_sym_file] = ACTIONS(3829),
    [anon_sym_fixed] = ACTIONS(3829),
    [anon_sym_internal] = ACTIONS(3829),
    [anon_sym_new] = ACTIONS(3829),
    [anon_sym_override] = ACTIONS(3829),
    [anon_sym_partial] = ACTIONS(3829),
    [anon_sym_private] = ACTIONS(3829),
    [anon_sym_protected] = ACTIONS(3829),
    [anon_sym_public] = ACTIONS(3829),
    [anon_sym_readonly] = ACTIONS(3829),
    [anon_sym_required] = ACTIONS(3829),
    [anon_sym_sealed] = ACTIONS(3829),
    [anon_sym_virtual] = ACTIONS(3829),
    [anon_sym_volatile] = ACTIONS(3829),
    [anon_sym_where] = ACTIONS(3829),
    [anon_sym_notnull] = ACTIONS(3829),
    [anon_sym_unmanaged] = ACTIONS(3829),
    [anon_sym_TILDE] = ACTIONS(3831),
    [anon_sym_implicit] = ACTIONS(3829),
    [anon_sym_explicit] = ACTIONS(3829),
    [anon_sym_scoped] = ACTIONS(3829),
    [anon_sym_var] = ACTIONS(3829),
    [sym_predefined_type] = ACTIONS(3829),
    [anon_sym_yield] = ACTIONS(3829),
    [anon_sym_when] = ACTIONS(3829),
    [anon_sym_from] = ACTIONS(3829),
    [anon_sym_into] = ACTIONS(3829),
    [anon_sym_join] = ACTIONS(3829),
    [anon_sym_on] = ACTIONS(3829),
    [anon_sym_equals] = ACTIONS(3829),
    [anon_sym_let] = ACTIONS(3829),
    [anon_sym_orderby] = ACTIONS(3829),
    [anon_sym_ascending] = ACTIONS(3829),
    [anon_sym_descending] = ACTIONS(3829),
    [anon_sym_group] = ACTIONS(3829),
    [anon_sym_by] = ACTIONS(3829),
    [anon_sym_select] = ACTIONS(3829),
    [aux_sym_preproc_if_token1] = ACTIONS(3831),
    [aux_sym_preproc_if_token3] = ACTIONS(3831),
    [aux_sym_preproc_else_token1] = ACTIONS(3831),
    [aux_sym_preproc_elif_token1] = ACTIONS(3831),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3264] = {
    [sym_preproc_region] = STATE(3264),
    [sym_preproc_endregion] = STATE(3264),
    [sym_preproc_line] = STATE(3264),
    [sym_preproc_pragma] = STATE(3264),
    [sym_preproc_nullable] = STATE(3264),
    [sym_preproc_error] = STATE(3264),
    [sym_preproc_warning] = STATE(3264),
    [sym_preproc_define] = STATE(3264),
    [sym_preproc_undef] = STATE(3264),
    [sym__identifier_token] = ACTIONS(3833),
    [anon_sym_extern] = ACTIONS(3833),
    [anon_sym_alias] = ACTIONS(3833),
    [anon_sym_global] = ACTIONS(3833),
    [anon_sym_using] = ACTIONS(3833),
    [anon_sym_unsafe] = ACTIONS(3833),
    [anon_sym_static] = ACTIONS(3833),
    [anon_sym_LBRACK] = ACTIONS(3835),
    [anon_sym_LPAREN] = ACTIONS(3835),
    [anon_sym_event] = ACTIONS(3833),
    [anon_sym_namespace] = ACTIONS(3833),
    [anon_sym_class] = ACTIONS(3833),
    [anon_sym_ref] = ACTIONS(3833),
    [anon_sym_struct] = ACTIONS(3833),
    [anon_sym_enum] = ACTIONS(3833),
    [anon_sym_RBRACE] = ACTIONS(3835),
    [anon_sym_interface] = ACTIONS(3833),
    [anon_sym_delegate] = ACTIONS(3833),
    [anon_sym_record] = ACTIONS(3833),
    [anon_sym_abstract] = ACTIONS(3833),
    [anon_sym_async] = ACTIONS(3833),
    [anon_sym_const] = ACTIONS(3833),
    [anon_sym_file] = ACTIONS(3833),
    [anon_sym_fixed] = ACTIONS(3833),
    [anon_sym_internal] = ACTIONS(3833),
    [anon_sym_new] = ACTIONS(3833),
    [anon_sym_override] = ACTIONS(3833),
    [anon_sym_partial] = ACTIONS(3833),
    [anon_sym_private] = ACTIONS(3833),
    [anon_sym_protected] = ACTIONS(3833),
    [anon_sym_public] = ACTIONS(3833),
    [anon_sym_readonly] = ACTIONS(3833),
    [anon_sym_required] = ACTIONS(3833),
    [anon_sym_sealed] = ACTIONS(3833),
    [anon_sym_virtual] = ACTIONS(3833),
    [anon_sym_volatile] = ACTIONS(3833),
    [anon_sym_where] = ACTIONS(3833),
    [anon_sym_notnull] = ACTIONS(3833),
    [anon_sym_unmanaged] = ACTIONS(3833),
    [anon_sym_TILDE] = ACTIONS(3835),
    [anon_sym_implicit] = ACTIONS(3833),
    [anon_sym_explicit] = ACTIONS(3833),
    [anon_sym_scoped] = ACTIONS(3833),
    [anon_sym_var] = ACTIONS(3833),
    [sym_predefined_type] = ACTIONS(3833),
    [anon_sym_yield] = ACTIONS(3833),
    [anon_sym_when] = ACTIONS(3833),
    [anon_sym_from] = ACTIONS(3833),
    [anon_sym_into] = ACTIONS(3833),
    [anon_sym_join] = ACTIONS(3833),
    [anon_sym_on] = ACTIONS(3833),
    [anon_sym_equals] = ACTIONS(3833),
    [anon_sym_let] = ACTIONS(3833),
    [anon_sym_orderby] = ACTIONS(3833),
    [anon_sym_ascending] = ACTIONS(3833),
    [anon_sym_descending] = ACTIONS(3833),
    [anon_sym_group] = ACTIONS(3833),
    [anon_sym_by] = ACTIONS(3833),
    [anon_sym_select] = ACTIONS(3833),
    [aux_sym_preproc_if_token1] = ACTIONS(3835),
    [aux_sym_preproc_if_token3] = ACTIONS(3835),
    [aux_sym_preproc_else_token1] = ACTIONS(3835),
    [aux_sym_preproc_elif_token1] = ACTIONS(3835),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3265] = {
    [sym_preproc_region] = STATE(3265),
    [sym_preproc_endregion] = STATE(3265),
    [sym_preproc_line] = STATE(3265),
    [sym_preproc_pragma] = STATE(3265),
    [sym_preproc_nullable] = STATE(3265),
    [sym_preproc_error] = STATE(3265),
    [sym_preproc_warning] = STATE(3265),
    [sym_preproc_define] = STATE(3265),
    [sym_preproc_undef] = STATE(3265),
    [sym__identifier_token] = ACTIONS(3837),
    [anon_sym_extern] = ACTIONS(3837),
    [anon_sym_alias] = ACTIONS(3837),
    [anon_sym_global] = ACTIONS(3837),
    [anon_sym_using] = ACTIONS(3837),
    [anon_sym_unsafe] = ACTIONS(3837),
    [anon_sym_static] = ACTIONS(3837),
    [anon_sym_LBRACK] = ACTIONS(3839),
    [anon_sym_LPAREN] = ACTIONS(3839),
    [anon_sym_event] = ACTIONS(3837),
    [anon_sym_namespace] = ACTIONS(3837),
    [anon_sym_class] = ACTIONS(3837),
    [anon_sym_ref] = ACTIONS(3837),
    [anon_sym_struct] = ACTIONS(3837),
    [anon_sym_enum] = ACTIONS(3837),
    [anon_sym_RBRACE] = ACTIONS(3839),
    [anon_sym_interface] = ACTIONS(3837),
    [anon_sym_delegate] = ACTIONS(3837),
    [anon_sym_record] = ACTIONS(3837),
    [anon_sym_abstract] = ACTIONS(3837),
    [anon_sym_async] = ACTIONS(3837),
    [anon_sym_const] = ACTIONS(3837),
    [anon_sym_file] = ACTIONS(3837),
    [anon_sym_fixed] = ACTIONS(3837),
    [anon_sym_internal] = ACTIONS(3837),
    [anon_sym_new] = ACTIONS(3837),
    [anon_sym_override] = ACTIONS(3837),
    [anon_sym_partial] = ACTIONS(3837),
    [anon_sym_private] = ACTIONS(3837),
    [anon_sym_protected] = ACTIONS(3837),
    [anon_sym_public] = ACTIONS(3837),
    [anon_sym_readonly] = ACTIONS(3837),
    [anon_sym_required] = ACTIONS(3837),
    [anon_sym_sealed] = ACTIONS(3837),
    [anon_sym_virtual] = ACTIONS(3837),
    [anon_sym_volatile] = ACTIONS(3837),
    [anon_sym_where] = ACTIONS(3837),
    [anon_sym_notnull] = ACTIONS(3837),
    [anon_sym_unmanaged] = ACTIONS(3837),
    [anon_sym_TILDE] = ACTIONS(3839),
    [anon_sym_implicit] = ACTIONS(3837),
    [anon_sym_explicit] = ACTIONS(3837),
    [anon_sym_scoped] = ACTIONS(3837),
    [anon_sym_var] = ACTIONS(3837),
    [sym_predefined_type] = ACTIONS(3837),
    [anon_sym_yield] = ACTIONS(3837),
    [anon_sym_when] = ACTIONS(3837),
    [anon_sym_from] = ACTIONS(3837),
    [anon_sym_into] = ACTIONS(3837),
    [anon_sym_join] = ACTIONS(3837),
    [anon_sym_on] = ACTIONS(3837),
    [anon_sym_equals] = ACTIONS(3837),
    [anon_sym_let] = ACTIONS(3837),
    [anon_sym_orderby] = ACTIONS(3837),
    [anon_sym_ascending] = ACTIONS(3837),
    [anon_sym_descending] = ACTIONS(3837),
    [anon_sym_group] = ACTIONS(3837),
    [anon_sym_by] = ACTIONS(3837),
    [anon_sym_select] = ACTIONS(3837),
    [aux_sym_preproc_if_token1] = ACTIONS(3839),
    [aux_sym_preproc_if_token3] = ACTIONS(3839),
    [aux_sym_preproc_else_token1] = ACTIONS(3839),
    [aux_sym_preproc_elif_token1] = ACTIONS(3839),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3266] = {
    [sym_preproc_region] = STATE(3266),
    [sym_preproc_endregion] = STATE(3266),
    [sym_preproc_line] = STATE(3266),
    [sym_preproc_pragma] = STATE(3266),
    [sym_preproc_nullable] = STATE(3266),
    [sym_preproc_error] = STATE(3266),
    [sym_preproc_warning] = STATE(3266),
    [sym_preproc_define] = STATE(3266),
    [sym_preproc_undef] = STATE(3266),
    [sym__identifier_token] = ACTIONS(3841),
    [anon_sym_extern] = ACTIONS(3841),
    [anon_sym_alias] = ACTIONS(3841),
    [anon_sym_global] = ACTIONS(3841),
    [anon_sym_using] = ACTIONS(3841),
    [anon_sym_unsafe] = ACTIONS(3841),
    [anon_sym_static] = ACTIONS(3841),
    [anon_sym_LBRACK] = ACTIONS(3843),
    [anon_sym_LPAREN] = ACTIONS(3843),
    [anon_sym_event] = ACTIONS(3841),
    [anon_sym_namespace] = ACTIONS(3841),
    [anon_sym_class] = ACTIONS(3841),
    [anon_sym_ref] = ACTIONS(3841),
    [anon_sym_struct] = ACTIONS(3841),
    [anon_sym_enum] = ACTIONS(3841),
    [anon_sym_RBRACE] = ACTIONS(3843),
    [anon_sym_interface] = ACTIONS(3841),
    [anon_sym_delegate] = ACTIONS(3841),
    [anon_sym_record] = ACTIONS(3841),
    [anon_sym_abstract] = ACTIONS(3841),
    [anon_sym_async] = ACTIONS(3841),
    [anon_sym_const] = ACTIONS(3841),
    [anon_sym_file] = ACTIONS(3841),
    [anon_sym_fixed] = ACTIONS(3841),
    [anon_sym_internal] = ACTIONS(3841),
    [anon_sym_new] = ACTIONS(3841),
    [anon_sym_override] = ACTIONS(3841),
    [anon_sym_partial] = ACTIONS(3841),
    [anon_sym_private] = ACTIONS(3841),
    [anon_sym_protected] = ACTIONS(3841),
    [anon_sym_public] = ACTIONS(3841),
    [anon_sym_readonly] = ACTIONS(3841),
    [anon_sym_required] = ACTIONS(3841),
    [anon_sym_sealed] = ACTIONS(3841),
    [anon_sym_virtual] = ACTIONS(3841),
    [anon_sym_volatile] = ACTIONS(3841),
    [anon_sym_where] = ACTIONS(3841),
    [anon_sym_notnull] = ACTIONS(3841),
    [anon_sym_unmanaged] = ACTIONS(3841),
    [anon_sym_TILDE] = ACTIONS(3843),
    [anon_sym_implicit] = ACTIONS(3841),
    [anon_sym_explicit] = ACTIONS(3841),
    [anon_sym_scoped] = ACTIONS(3841),
    [anon_sym_var] = ACTIONS(3841),
    [sym_predefined_type] = ACTIONS(3841),
    [anon_sym_yield] = ACTIONS(3841),
    [anon_sym_when] = ACTIONS(3841),
    [anon_sym_from] = ACTIONS(3841),
    [anon_sym_into] = ACTIONS(3841),
    [anon_sym_join] = ACTIONS(3841),
    [anon_sym_on] = ACTIONS(3841),
    [anon_sym_equals] = ACTIONS(3841),
    [anon_sym_let] = ACTIONS(3841),
    [anon_sym_orderby] = ACTIONS(3841),
    [anon_sym_ascending] = ACTIONS(3841),
    [anon_sym_descending] = ACTIONS(3841),
    [anon_sym_group] = ACTIONS(3841),
    [anon_sym_by] = ACTIONS(3841),
    [anon_sym_select] = ACTIONS(3841),
    [aux_sym_preproc_if_token1] = ACTIONS(3843),
    [aux_sym_preproc_if_token3] = ACTIONS(3843),
    [aux_sym_preproc_else_token1] = ACTIONS(3843),
    [aux_sym_preproc_elif_token1] = ACTIONS(3843),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3267] = {
    [sym_preproc_region] = STATE(3267),
    [sym_preproc_endregion] = STATE(3267),
    [sym_preproc_line] = STATE(3267),
    [sym_preproc_pragma] = STATE(3267),
    [sym_preproc_nullable] = STATE(3267),
    [sym_preproc_error] = STATE(3267),
    [sym_preproc_warning] = STATE(3267),
    [sym_preproc_define] = STATE(3267),
    [sym_preproc_undef] = STATE(3267),
    [anon_sym_SEMI] = ACTIONS(4703),
    [anon_sym_EQ] = ACTIONS(4672),
    [anon_sym_LBRACK] = ACTIONS(4703),
    [anon_sym_COLON] = ACTIONS(4670),
    [anon_sym_COMMA] = ACTIONS(4703),
    [anon_sym_RBRACK] = ACTIONS(4703),
    [anon_sym_LPAREN] = ACTIONS(4703),
    [anon_sym_RPAREN] = ACTIONS(4703),
    [anon_sym_RBRACE] = ACTIONS(4703),
    [anon_sym_LT] = ACTIONS(4705),
    [anon_sym_GT] = ACTIONS(4705),
    [anon_sym_in] = ACTIONS(4703),
    [anon_sym_QMARK] = ACTIONS(4705),
    [anon_sym_BANG] = ACTIONS(4705),
    [anon_sym_PLUS_PLUS] = ACTIONS(4703),
    [anon_sym_DASH_DASH] = ACTIONS(4703),
    [anon_sym_PLUS] = ACTIONS(4705),
    [anon_sym_DASH] = ACTIONS(4705),
    [anon_sym_STAR] = ACTIONS(4705),
    [anon_sym_SLASH] = ACTIONS(4705),
    [anon_sym_PERCENT] = ACTIONS(4705),
    [anon_sym_CARET] = ACTIONS(4705),
    [anon_sym_PIPE] = ACTIONS(4705),
    [anon_sym_AMP] = ACTIONS(4705),
    [anon_sym_LT_LT] = ACTIONS(4705),
    [anon_sym_GT_GT] = ACTIONS(4705),
    [anon_sym_GT_GT_GT] = ACTIONS(4705),
    [anon_sym_EQ_EQ] = ACTIONS(4703),
    [anon_sym_BANG_EQ] = ACTIONS(4703),
    [anon_sym_GT_EQ] = ACTIONS(4703),
    [anon_sym_LT_EQ] = ACTIONS(4703),
    [anon_sym_DOT] = ACTIONS(4705),
    [anon_sym_EQ_GT] = ACTIONS(4703),
    [anon_sym_switch] = ACTIONS(4703),
    [anon_sym_when] = ACTIONS(4703),
    [anon_sym_DOT_DOT] = ACTIONS(4703),
    [anon_sym_and] = ACTIONS(4703),
    [anon_sym_or] = ACTIONS(4703),
    [anon_sym_PLUS_EQ] = ACTIONS(4670),
    [anon_sym_DASH_EQ] = ACTIONS(4670),
    [anon_sym_STAR_EQ] = ACTIONS(4670),
    [anon_sym_SLASH_EQ] = ACTIONS(4670),
    [anon_sym_PERCENT_EQ] = ACTIONS(4670),
    [anon_sym_AMP_EQ] = ACTIONS(4670),
    [anon_sym_CARET_EQ] = ACTIONS(4670),
    [anon_sym_PIPE_EQ] = ACTIONS(4670),
    [anon_sym_LT_LT_EQ] = ACTIONS(4670),
    [anon_sym_GT_GT_EQ] = ACTIONS(4670),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4670),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4670),
    [anon_sym_AMP_AMP] = ACTIONS(4703),
    [anon_sym_PIPE_PIPE] = ACTIONS(4703),
    [anon_sym_QMARK_QMARK] = ACTIONS(4705),
    [anon_sym_on] = ACTIONS(4703),
    [anon_sym_equals] = ACTIONS(4703),
    [anon_sym_by] = ACTIONS(4703),
    [anon_sym_as] = ACTIONS(4703),
    [anon_sym_is] = ACTIONS(4703),
    [anon_sym_DASH_GT] = ACTIONS(4703),
    [anon_sym_with] = ACTIONS(4703),
    [aux_sym_preproc_if_token3] = ACTIONS(4703),
    [aux_sym_preproc_else_token1] = ACTIONS(4703),
    [aux_sym_preproc_elif_token1] = ACTIONS(4703),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3268] = {
    [sym_preproc_region] = STATE(3268),
    [sym_preproc_endregion] = STATE(3268),
    [sym_preproc_line] = STATE(3268),
    [sym_preproc_pragma] = STATE(3268),
    [sym_preproc_nullable] = STATE(3268),
    [sym_preproc_error] = STATE(3268),
    [sym_preproc_warning] = STATE(3268),
    [sym_preproc_define] = STATE(3268),
    [sym_preproc_undef] = STATE(3268),
    [sym__identifier_token] = ACTIONS(3849),
    [anon_sym_extern] = ACTIONS(3849),
    [anon_sym_alias] = ACTIONS(3849),
    [anon_sym_global] = ACTIONS(3849),
    [anon_sym_using] = ACTIONS(3849),
    [anon_sym_unsafe] = ACTIONS(3849),
    [anon_sym_static] = ACTIONS(3849),
    [anon_sym_LBRACK] = ACTIONS(3851),
    [anon_sym_LPAREN] = ACTIONS(3851),
    [anon_sym_event] = ACTIONS(3849),
    [anon_sym_namespace] = ACTIONS(3849),
    [anon_sym_class] = ACTIONS(3849),
    [anon_sym_ref] = ACTIONS(3849),
    [anon_sym_struct] = ACTIONS(3849),
    [anon_sym_enum] = ACTIONS(3849),
    [anon_sym_RBRACE] = ACTIONS(3851),
    [anon_sym_interface] = ACTIONS(3849),
    [anon_sym_delegate] = ACTIONS(3849),
    [anon_sym_record] = ACTIONS(3849),
    [anon_sym_abstract] = ACTIONS(3849),
    [anon_sym_async] = ACTIONS(3849),
    [anon_sym_const] = ACTIONS(3849),
    [anon_sym_file] = ACTIONS(3849),
    [anon_sym_fixed] = ACTIONS(3849),
    [anon_sym_internal] = ACTIONS(3849),
    [anon_sym_new] = ACTIONS(3849),
    [anon_sym_override] = ACTIONS(3849),
    [anon_sym_partial] = ACTIONS(3849),
    [anon_sym_private] = ACTIONS(3849),
    [anon_sym_protected] = ACTIONS(3849),
    [anon_sym_public] = ACTIONS(3849),
    [anon_sym_readonly] = ACTIONS(3849),
    [anon_sym_required] = ACTIONS(3849),
    [anon_sym_sealed] = ACTIONS(3849),
    [anon_sym_virtual] = ACTIONS(3849),
    [anon_sym_volatile] = ACTIONS(3849),
    [anon_sym_where] = ACTIONS(3849),
    [anon_sym_notnull] = ACTIONS(3849),
    [anon_sym_unmanaged] = ACTIONS(3849),
    [anon_sym_TILDE] = ACTIONS(3851),
    [anon_sym_implicit] = ACTIONS(3849),
    [anon_sym_explicit] = ACTIONS(3849),
    [anon_sym_scoped] = ACTIONS(3849),
    [anon_sym_var] = ACTIONS(3849),
    [sym_predefined_type] = ACTIONS(3849),
    [anon_sym_yield] = ACTIONS(3849),
    [anon_sym_when] = ACTIONS(3849),
    [anon_sym_from] = ACTIONS(3849),
    [anon_sym_into] = ACTIONS(3849),
    [anon_sym_join] = ACTIONS(3849),
    [anon_sym_on] = ACTIONS(3849),
    [anon_sym_equals] = ACTIONS(3849),
    [anon_sym_let] = ACTIONS(3849),
    [anon_sym_orderby] = ACTIONS(3849),
    [anon_sym_ascending] = ACTIONS(3849),
    [anon_sym_descending] = ACTIONS(3849),
    [anon_sym_group] = ACTIONS(3849),
    [anon_sym_by] = ACTIONS(3849),
    [anon_sym_select] = ACTIONS(3849),
    [aux_sym_preproc_if_token1] = ACTIONS(3851),
    [aux_sym_preproc_if_token3] = ACTIONS(3851),
    [aux_sym_preproc_else_token1] = ACTIONS(3851),
    [aux_sym_preproc_elif_token1] = ACTIONS(3851),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3269] = {
    [sym_preproc_region] = STATE(3269),
    [sym_preproc_endregion] = STATE(3269),
    [sym_preproc_line] = STATE(3269),
    [sym_preproc_pragma] = STATE(3269),
    [sym_preproc_nullable] = STATE(3269),
    [sym_preproc_error] = STATE(3269),
    [sym_preproc_warning] = STATE(3269),
    [sym_preproc_define] = STATE(3269),
    [sym_preproc_undef] = STATE(3269),
    [sym__identifier_token] = ACTIONS(3853),
    [anon_sym_extern] = ACTIONS(3853),
    [anon_sym_alias] = ACTIONS(3853),
    [anon_sym_global] = ACTIONS(3853),
    [anon_sym_using] = ACTIONS(3853),
    [anon_sym_unsafe] = ACTIONS(3853),
    [anon_sym_static] = ACTIONS(3853),
    [anon_sym_LBRACK] = ACTIONS(3855),
    [anon_sym_LPAREN] = ACTIONS(3855),
    [anon_sym_event] = ACTIONS(3853),
    [anon_sym_namespace] = ACTIONS(3853),
    [anon_sym_class] = ACTIONS(3853),
    [anon_sym_ref] = ACTIONS(3853),
    [anon_sym_struct] = ACTIONS(3853),
    [anon_sym_enum] = ACTIONS(3853),
    [anon_sym_RBRACE] = ACTIONS(3855),
    [anon_sym_interface] = ACTIONS(3853),
    [anon_sym_delegate] = ACTIONS(3853),
    [anon_sym_record] = ACTIONS(3853),
    [anon_sym_abstract] = ACTIONS(3853),
    [anon_sym_async] = ACTIONS(3853),
    [anon_sym_const] = ACTIONS(3853),
    [anon_sym_file] = ACTIONS(3853),
    [anon_sym_fixed] = ACTIONS(3853),
    [anon_sym_internal] = ACTIONS(3853),
    [anon_sym_new] = ACTIONS(3853),
    [anon_sym_override] = ACTIONS(3853),
    [anon_sym_partial] = ACTIONS(3853),
    [anon_sym_private] = ACTIONS(3853),
    [anon_sym_protected] = ACTIONS(3853),
    [anon_sym_public] = ACTIONS(3853),
    [anon_sym_readonly] = ACTIONS(3853),
    [anon_sym_required] = ACTIONS(3853),
    [anon_sym_sealed] = ACTIONS(3853),
    [anon_sym_virtual] = ACTIONS(3853),
    [anon_sym_volatile] = ACTIONS(3853),
    [anon_sym_where] = ACTIONS(3853),
    [anon_sym_notnull] = ACTIONS(3853),
    [anon_sym_unmanaged] = ACTIONS(3853),
    [anon_sym_TILDE] = ACTIONS(3855),
    [anon_sym_implicit] = ACTIONS(3853),
    [anon_sym_explicit] = ACTIONS(3853),
    [anon_sym_scoped] = ACTIONS(3853),
    [anon_sym_var] = ACTIONS(3853),
    [sym_predefined_type] = ACTIONS(3853),
    [anon_sym_yield] = ACTIONS(3853),
    [anon_sym_when] = ACTIONS(3853),
    [anon_sym_from] = ACTIONS(3853),
    [anon_sym_into] = ACTIONS(3853),
    [anon_sym_join] = ACTIONS(3853),
    [anon_sym_on] = ACTIONS(3853),
    [anon_sym_equals] = ACTIONS(3853),
    [anon_sym_let] = ACTIONS(3853),
    [anon_sym_orderby] = ACTIONS(3853),
    [anon_sym_ascending] = ACTIONS(3853),
    [anon_sym_descending] = ACTIONS(3853),
    [anon_sym_group] = ACTIONS(3853),
    [anon_sym_by] = ACTIONS(3853),
    [anon_sym_select] = ACTIONS(3853),
    [aux_sym_preproc_if_token1] = ACTIONS(3855),
    [aux_sym_preproc_if_token3] = ACTIONS(3855),
    [aux_sym_preproc_else_token1] = ACTIONS(3855),
    [aux_sym_preproc_elif_token1] = ACTIONS(3855),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3270] = {
    [sym_preproc_region] = STATE(3270),
    [sym_preproc_endregion] = STATE(3270),
    [sym_preproc_line] = STATE(3270),
    [sym_preproc_pragma] = STATE(3270),
    [sym_preproc_nullable] = STATE(3270),
    [sym_preproc_error] = STATE(3270),
    [sym_preproc_warning] = STATE(3270),
    [sym_preproc_define] = STATE(3270),
    [sym_preproc_undef] = STATE(3270),
    [sym__identifier_token] = ACTIONS(3857),
    [anon_sym_extern] = ACTIONS(3857),
    [anon_sym_alias] = ACTIONS(3857),
    [anon_sym_global] = ACTIONS(3857),
    [anon_sym_using] = ACTIONS(3857),
    [anon_sym_unsafe] = ACTIONS(3857),
    [anon_sym_static] = ACTIONS(3857),
    [anon_sym_LBRACK] = ACTIONS(3859),
    [anon_sym_LPAREN] = ACTIONS(3859),
    [anon_sym_event] = ACTIONS(3857),
    [anon_sym_namespace] = ACTIONS(3857),
    [anon_sym_class] = ACTIONS(3857),
    [anon_sym_ref] = ACTIONS(3857),
    [anon_sym_struct] = ACTIONS(3857),
    [anon_sym_enum] = ACTIONS(3857),
    [anon_sym_RBRACE] = ACTIONS(3859),
    [anon_sym_interface] = ACTIONS(3857),
    [anon_sym_delegate] = ACTIONS(3857),
    [anon_sym_record] = ACTIONS(3857),
    [anon_sym_abstract] = ACTIONS(3857),
    [anon_sym_async] = ACTIONS(3857),
    [anon_sym_const] = ACTIONS(3857),
    [anon_sym_file] = ACTIONS(3857),
    [anon_sym_fixed] = ACTIONS(3857),
    [anon_sym_internal] = ACTIONS(3857),
    [anon_sym_new] = ACTIONS(3857),
    [anon_sym_override] = ACTIONS(3857),
    [anon_sym_partial] = ACTIONS(3857),
    [anon_sym_private] = ACTIONS(3857),
    [anon_sym_protected] = ACTIONS(3857),
    [anon_sym_public] = ACTIONS(3857),
    [anon_sym_readonly] = ACTIONS(3857),
    [anon_sym_required] = ACTIONS(3857),
    [anon_sym_sealed] = ACTIONS(3857),
    [anon_sym_virtual] = ACTIONS(3857),
    [anon_sym_volatile] = ACTIONS(3857),
    [anon_sym_where] = ACTIONS(3857),
    [anon_sym_notnull] = ACTIONS(3857),
    [anon_sym_unmanaged] = ACTIONS(3857),
    [anon_sym_TILDE] = ACTIONS(3859),
    [anon_sym_implicit] = ACTIONS(3857),
    [anon_sym_explicit] = ACTIONS(3857),
    [anon_sym_scoped] = ACTIONS(3857),
    [anon_sym_var] = ACTIONS(3857),
    [sym_predefined_type] = ACTIONS(3857),
    [anon_sym_yield] = ACTIONS(3857),
    [anon_sym_when] = ACTIONS(3857),
    [anon_sym_from] = ACTIONS(3857),
    [anon_sym_into] = ACTIONS(3857),
    [anon_sym_join] = ACTIONS(3857),
    [anon_sym_on] = ACTIONS(3857),
    [anon_sym_equals] = ACTIONS(3857),
    [anon_sym_let] = ACTIONS(3857),
    [anon_sym_orderby] = ACTIONS(3857),
    [anon_sym_ascending] = ACTIONS(3857),
    [anon_sym_descending] = ACTIONS(3857),
    [anon_sym_group] = ACTIONS(3857),
    [anon_sym_by] = ACTIONS(3857),
    [anon_sym_select] = ACTIONS(3857),
    [aux_sym_preproc_if_token1] = ACTIONS(3859),
    [aux_sym_preproc_if_token3] = ACTIONS(3859),
    [aux_sym_preproc_else_token1] = ACTIONS(3859),
    [aux_sym_preproc_elif_token1] = ACTIONS(3859),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3271] = {
    [sym_preproc_region] = STATE(3271),
    [sym_preproc_endregion] = STATE(3271),
    [sym_preproc_line] = STATE(3271),
    [sym_preproc_pragma] = STATE(3271),
    [sym_preproc_nullable] = STATE(3271),
    [sym_preproc_error] = STATE(3271),
    [sym_preproc_warning] = STATE(3271),
    [sym_preproc_define] = STATE(3271),
    [sym_preproc_undef] = STATE(3271),
    [sym__identifier_token] = ACTIONS(3861),
    [anon_sym_extern] = ACTIONS(3861),
    [anon_sym_alias] = ACTIONS(3861),
    [anon_sym_global] = ACTIONS(3861),
    [anon_sym_using] = ACTIONS(3861),
    [anon_sym_unsafe] = ACTIONS(3861),
    [anon_sym_static] = ACTIONS(3861),
    [anon_sym_LBRACK] = ACTIONS(3863),
    [anon_sym_LPAREN] = ACTIONS(3863),
    [anon_sym_event] = ACTIONS(3861),
    [anon_sym_namespace] = ACTIONS(3861),
    [anon_sym_class] = ACTIONS(3861),
    [anon_sym_ref] = ACTIONS(3861),
    [anon_sym_struct] = ACTIONS(3861),
    [anon_sym_enum] = ACTIONS(3861),
    [anon_sym_RBRACE] = ACTIONS(3863),
    [anon_sym_interface] = ACTIONS(3861),
    [anon_sym_delegate] = ACTIONS(3861),
    [anon_sym_record] = ACTIONS(3861),
    [anon_sym_abstract] = ACTIONS(3861),
    [anon_sym_async] = ACTIONS(3861),
    [anon_sym_const] = ACTIONS(3861),
    [anon_sym_file] = ACTIONS(3861),
    [anon_sym_fixed] = ACTIONS(3861),
    [anon_sym_internal] = ACTIONS(3861),
    [anon_sym_new] = ACTIONS(3861),
    [anon_sym_override] = ACTIONS(3861),
    [anon_sym_partial] = ACTIONS(3861),
    [anon_sym_private] = ACTIONS(3861),
    [anon_sym_protected] = ACTIONS(3861),
    [anon_sym_public] = ACTIONS(3861),
    [anon_sym_readonly] = ACTIONS(3861),
    [anon_sym_required] = ACTIONS(3861),
    [anon_sym_sealed] = ACTIONS(3861),
    [anon_sym_virtual] = ACTIONS(3861),
    [anon_sym_volatile] = ACTIONS(3861),
    [anon_sym_where] = ACTIONS(3861),
    [anon_sym_notnull] = ACTIONS(3861),
    [anon_sym_unmanaged] = ACTIONS(3861),
    [anon_sym_TILDE] = ACTIONS(3863),
    [anon_sym_implicit] = ACTIONS(3861),
    [anon_sym_explicit] = ACTIONS(3861),
    [anon_sym_scoped] = ACTIONS(3861),
    [anon_sym_var] = ACTIONS(3861),
    [sym_predefined_type] = ACTIONS(3861),
    [anon_sym_yield] = ACTIONS(3861),
    [anon_sym_when] = ACTIONS(3861),
    [anon_sym_from] = ACTIONS(3861),
    [anon_sym_into] = ACTIONS(3861),
    [anon_sym_join] = ACTIONS(3861),
    [anon_sym_on] = ACTIONS(3861),
    [anon_sym_equals] = ACTIONS(3861),
    [anon_sym_let] = ACTIONS(3861),
    [anon_sym_orderby] = ACTIONS(3861),
    [anon_sym_ascending] = ACTIONS(3861),
    [anon_sym_descending] = ACTIONS(3861),
    [anon_sym_group] = ACTIONS(3861),
    [anon_sym_by] = ACTIONS(3861),
    [anon_sym_select] = ACTIONS(3861),
    [aux_sym_preproc_if_token1] = ACTIONS(3863),
    [aux_sym_preproc_if_token3] = ACTIONS(3863),
    [aux_sym_preproc_else_token1] = ACTIONS(3863),
    [aux_sym_preproc_elif_token1] = ACTIONS(3863),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3272] = {
    [sym_preproc_region] = STATE(3272),
    [sym_preproc_endregion] = STATE(3272),
    [sym_preproc_line] = STATE(3272),
    [sym_preproc_pragma] = STATE(3272),
    [sym_preproc_nullable] = STATE(3272),
    [sym_preproc_error] = STATE(3272),
    [sym_preproc_warning] = STATE(3272),
    [sym_preproc_define] = STATE(3272),
    [sym_preproc_undef] = STATE(3272),
    [sym__identifier_token] = ACTIONS(4620),
    [anon_sym_alias] = ACTIONS(4620),
    [anon_sym_global] = ACTIONS(4620),
    [anon_sym_LBRACK] = ACTIONS(4622),
    [anon_sym_COLON] = ACTIONS(4622),
    [anon_sym_COMMA] = ACTIONS(4622),
    [anon_sym_LPAREN] = ACTIONS(4622),
    [anon_sym_LBRACE] = ACTIONS(4622),
    [anon_sym_file] = ACTIONS(4620),
    [anon_sym_LT] = ACTIONS(4620),
    [anon_sym_GT] = ACTIONS(4620),
    [anon_sym_where] = ACTIONS(4620),
    [anon_sym_QMARK] = ACTIONS(4620),
    [anon_sym_notnull] = ACTIONS(4620),
    [anon_sym_unmanaged] = ACTIONS(4620),
    [anon_sym_BANG] = ACTIONS(4620),
    [anon_sym_PLUS_PLUS] = ACTIONS(4622),
    [anon_sym_DASH_DASH] = ACTIONS(4622),
    [anon_sym_PLUS] = ACTIONS(4620),
    [anon_sym_DASH] = ACTIONS(4620),
    [anon_sym_STAR] = ACTIONS(4622),
    [anon_sym_SLASH] = ACTIONS(4620),
    [anon_sym_PERCENT] = ACTIONS(4622),
    [anon_sym_CARET] = ACTIONS(4622),
    [anon_sym_PIPE] = ACTIONS(4620),
    [anon_sym_AMP] = ACTIONS(4620),
    [anon_sym_LT_LT] = ACTIONS(4622),
    [anon_sym_GT_GT] = ACTIONS(4620),
    [anon_sym_GT_GT_GT] = ACTIONS(4622),
    [anon_sym_EQ_EQ] = ACTIONS(4622),
    [anon_sym_BANG_EQ] = ACTIONS(4622),
    [anon_sym_GT_EQ] = ACTIONS(4622),
    [anon_sym_LT_EQ] = ACTIONS(4622),
    [anon_sym_DOT] = ACTIONS(4620),
    [anon_sym_scoped] = ACTIONS(4620),
    [anon_sym_var] = ACTIONS(4620),
    [anon_sym_yield] = ACTIONS(4620),
    [anon_sym_switch] = ACTIONS(4620),
    [anon_sym_when] = ACTIONS(4620),
    [sym_discard] = ACTIONS(4620),
    [anon_sym_DOT_DOT] = ACTIONS(4622),
    [anon_sym_and] = ACTIONS(4620),
    [anon_sym_or] = ACTIONS(4620),
    [anon_sym_AMP_AMP] = ACTIONS(4622),
    [anon_sym_PIPE_PIPE] = ACTIONS(4622),
    [anon_sym_QMARK_QMARK] = ACTIONS(4622),
    [anon_sym_from] = ACTIONS(4620),
    [anon_sym_into] = ACTIONS(4620),
    [anon_sym_join] = ACTIONS(4620),
    [anon_sym_on] = ACTIONS(4620),
    [anon_sym_equals] = ACTIONS(4620),
    [anon_sym_let] = ACTIONS(4620),
    [anon_sym_orderby] = ACTIONS(4620),
    [anon_sym_ascending] = ACTIONS(4620),
    [anon_sym_descending] = ACTIONS(4620),
    [anon_sym_group] = ACTIONS(4620),
    [anon_sym_by] = ACTIONS(4620),
    [anon_sym_select] = ACTIONS(4620),
    [anon_sym_as] = ACTIONS(4620),
    [anon_sym_is] = ACTIONS(4620),
    [anon_sym_DASH_GT] = ACTIONS(4622),
    [anon_sym_with] = ACTIONS(4620),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4622),
  },
  [3273] = {
    [sym__variable_designation] = STATE(4167),
    [sym_parenthesized_variable_designation] = STATE(4153),
    [sym_identifier] = STATE(4156),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3273),
    [sym_preproc_endregion] = STATE(3273),
    [sym_preproc_line] = STATE(3273),
    [sym_preproc_pragma] = STATE(3273),
    [sym_preproc_nullable] = STATE(3273),
    [sym_preproc_error] = STATE(3273),
    [sym_preproc_warning] = STATE(3273),
    [sym_preproc_define] = STATE(3273),
    [sym_preproc_undef] = STATE(3273),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4399),
    [anon_sym_LPAREN] = ACTIONS(4399),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4401),
    [anon_sym_GT] = ACTIONS(4401),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4401),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4401),
    [anon_sym_PLUS_PLUS] = ACTIONS(4399),
    [anon_sym_DASH_DASH] = ACTIONS(4399),
    [anon_sym_PLUS] = ACTIONS(4401),
    [anon_sym_DASH] = ACTIONS(4401),
    [anon_sym_STAR] = ACTIONS(4399),
    [anon_sym_SLASH] = ACTIONS(4401),
    [anon_sym_PERCENT] = ACTIONS(4399),
    [anon_sym_CARET] = ACTIONS(4399),
    [anon_sym_PIPE] = ACTIONS(4401),
    [anon_sym_AMP] = ACTIONS(4401),
    [anon_sym_LT_LT] = ACTIONS(4399),
    [anon_sym_GT_GT] = ACTIONS(4401),
    [anon_sym_GT_GT_GT] = ACTIONS(4399),
    [anon_sym_EQ_EQ] = ACTIONS(4399),
    [anon_sym_BANG_EQ] = ACTIONS(4399),
    [anon_sym_GT_EQ] = ACTIONS(4399),
    [anon_sym_LT_EQ] = ACTIONS(4399),
    [anon_sym_DOT] = ACTIONS(4401),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4401),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4359),
    [anon_sym_DOT_DOT] = ACTIONS(4399),
    [anon_sym_and] = ACTIONS(4401),
    [anon_sym_or] = ACTIONS(4401),
    [anon_sym_AMP_AMP] = ACTIONS(4399),
    [anon_sym_PIPE_PIPE] = ACTIONS(4399),
    [anon_sym_QMARK_QMARK] = ACTIONS(4399),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4339),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4401),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4401),
    [anon_sym_is] = ACTIONS(4401),
    [anon_sym_DASH_GT] = ACTIONS(4399),
    [anon_sym_with] = ACTIONS(4401),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3274] = {
    [sym_preproc_region] = STATE(3274),
    [sym_preproc_endregion] = STATE(3274),
    [sym_preproc_line] = STATE(3274),
    [sym_preproc_pragma] = STATE(3274),
    [sym_preproc_nullable] = STATE(3274),
    [sym_preproc_error] = STATE(3274),
    [sym_preproc_warning] = STATE(3274),
    [sym_preproc_define] = STATE(3274),
    [sym_preproc_undef] = STATE(3274),
    [sym__identifier_token] = ACTIONS(4842),
    [anon_sym_extern] = ACTIONS(4842),
    [anon_sym_alias] = ACTIONS(4842),
    [anon_sym_global] = ACTIONS(4842),
    [anon_sym_using] = ACTIONS(4842),
    [anon_sym_unsafe] = ACTIONS(4842),
    [anon_sym_static] = ACTIONS(4842),
    [anon_sym_LBRACK] = ACTIONS(4844),
    [anon_sym_LPAREN] = ACTIONS(4844),
    [anon_sym_event] = ACTIONS(4842),
    [anon_sym_namespace] = ACTIONS(4842),
    [anon_sym_class] = ACTIONS(4842),
    [anon_sym_ref] = ACTIONS(4842),
    [anon_sym_struct] = ACTIONS(4842),
    [anon_sym_enum] = ACTIONS(4842),
    [anon_sym_RBRACE] = ACTIONS(4844),
    [anon_sym_interface] = ACTIONS(4842),
    [anon_sym_delegate] = ACTIONS(4842),
    [anon_sym_record] = ACTIONS(4842),
    [anon_sym_abstract] = ACTIONS(4842),
    [anon_sym_async] = ACTIONS(4842),
    [anon_sym_const] = ACTIONS(4842),
    [anon_sym_file] = ACTIONS(4842),
    [anon_sym_fixed] = ACTIONS(4842),
    [anon_sym_internal] = ACTIONS(4842),
    [anon_sym_new] = ACTIONS(4842),
    [anon_sym_override] = ACTIONS(4842),
    [anon_sym_partial] = ACTIONS(4842),
    [anon_sym_private] = ACTIONS(4842),
    [anon_sym_protected] = ACTIONS(4842),
    [anon_sym_public] = ACTIONS(4842),
    [anon_sym_readonly] = ACTIONS(4842),
    [anon_sym_required] = ACTIONS(4842),
    [anon_sym_sealed] = ACTIONS(4842),
    [anon_sym_virtual] = ACTIONS(4842),
    [anon_sym_volatile] = ACTIONS(4842),
    [anon_sym_where] = ACTIONS(4842),
    [anon_sym_notnull] = ACTIONS(4842),
    [anon_sym_unmanaged] = ACTIONS(4842),
    [anon_sym_TILDE] = ACTIONS(4844),
    [anon_sym_implicit] = ACTIONS(4842),
    [anon_sym_explicit] = ACTIONS(4842),
    [anon_sym_scoped] = ACTIONS(4842),
    [anon_sym_var] = ACTIONS(4842),
    [sym_predefined_type] = ACTIONS(4842),
    [anon_sym_yield] = ACTIONS(4842),
    [anon_sym_when] = ACTIONS(4842),
    [anon_sym_from] = ACTIONS(4842),
    [anon_sym_into] = ACTIONS(4842),
    [anon_sym_join] = ACTIONS(4842),
    [anon_sym_on] = ACTIONS(4842),
    [anon_sym_equals] = ACTIONS(4842),
    [anon_sym_let] = ACTIONS(4842),
    [anon_sym_orderby] = ACTIONS(4842),
    [anon_sym_ascending] = ACTIONS(4842),
    [anon_sym_descending] = ACTIONS(4842),
    [anon_sym_group] = ACTIONS(4842),
    [anon_sym_by] = ACTIONS(4842),
    [anon_sym_select] = ACTIONS(4842),
    [aux_sym_preproc_if_token1] = ACTIONS(4844),
    [aux_sym_preproc_if_token3] = ACTIONS(4844),
    [aux_sym_preproc_else_token1] = ACTIONS(4844),
    [aux_sym_preproc_elif_token1] = ACTIONS(4844),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3275] = {
    [sym_preproc_region] = STATE(3275),
    [sym_preproc_endregion] = STATE(3275),
    [sym_preproc_line] = STATE(3275),
    [sym_preproc_pragma] = STATE(3275),
    [sym_preproc_nullable] = STATE(3275),
    [sym_preproc_error] = STATE(3275),
    [sym_preproc_warning] = STATE(3275),
    [sym_preproc_define] = STATE(3275),
    [sym_preproc_undef] = STATE(3275),
    [sym__identifier_token] = ACTIONS(4846),
    [anon_sym_extern] = ACTIONS(4846),
    [anon_sym_alias] = ACTIONS(4846),
    [anon_sym_global] = ACTIONS(4846),
    [anon_sym_using] = ACTIONS(4846),
    [anon_sym_unsafe] = ACTIONS(4846),
    [anon_sym_static] = ACTIONS(4846),
    [anon_sym_LBRACK] = ACTIONS(4848),
    [anon_sym_LPAREN] = ACTIONS(4848),
    [anon_sym_event] = ACTIONS(4846),
    [anon_sym_namespace] = ACTIONS(4846),
    [anon_sym_class] = ACTIONS(4846),
    [anon_sym_ref] = ACTIONS(4846),
    [anon_sym_struct] = ACTIONS(4846),
    [anon_sym_enum] = ACTIONS(4846),
    [anon_sym_RBRACE] = ACTIONS(4848),
    [anon_sym_interface] = ACTIONS(4846),
    [anon_sym_delegate] = ACTIONS(4846),
    [anon_sym_record] = ACTIONS(4846),
    [anon_sym_abstract] = ACTIONS(4846),
    [anon_sym_async] = ACTIONS(4846),
    [anon_sym_const] = ACTIONS(4846),
    [anon_sym_file] = ACTIONS(4846),
    [anon_sym_fixed] = ACTIONS(4846),
    [anon_sym_internal] = ACTIONS(4846),
    [anon_sym_new] = ACTIONS(4846),
    [anon_sym_override] = ACTIONS(4846),
    [anon_sym_partial] = ACTIONS(4846),
    [anon_sym_private] = ACTIONS(4846),
    [anon_sym_protected] = ACTIONS(4846),
    [anon_sym_public] = ACTIONS(4846),
    [anon_sym_readonly] = ACTIONS(4846),
    [anon_sym_required] = ACTIONS(4846),
    [anon_sym_sealed] = ACTIONS(4846),
    [anon_sym_virtual] = ACTIONS(4846),
    [anon_sym_volatile] = ACTIONS(4846),
    [anon_sym_where] = ACTIONS(4846),
    [anon_sym_notnull] = ACTIONS(4846),
    [anon_sym_unmanaged] = ACTIONS(4846),
    [anon_sym_TILDE] = ACTIONS(4848),
    [anon_sym_implicit] = ACTIONS(4846),
    [anon_sym_explicit] = ACTIONS(4846),
    [anon_sym_scoped] = ACTIONS(4846),
    [anon_sym_var] = ACTIONS(4846),
    [sym_predefined_type] = ACTIONS(4846),
    [anon_sym_yield] = ACTIONS(4846),
    [anon_sym_when] = ACTIONS(4846),
    [anon_sym_from] = ACTIONS(4846),
    [anon_sym_into] = ACTIONS(4846),
    [anon_sym_join] = ACTIONS(4846),
    [anon_sym_on] = ACTIONS(4846),
    [anon_sym_equals] = ACTIONS(4846),
    [anon_sym_let] = ACTIONS(4846),
    [anon_sym_orderby] = ACTIONS(4846),
    [anon_sym_ascending] = ACTIONS(4846),
    [anon_sym_descending] = ACTIONS(4846),
    [anon_sym_group] = ACTIONS(4846),
    [anon_sym_by] = ACTIONS(4846),
    [anon_sym_select] = ACTIONS(4846),
    [aux_sym_preproc_if_token1] = ACTIONS(4848),
    [aux_sym_preproc_if_token3] = ACTIONS(4848),
    [aux_sym_preproc_else_token1] = ACTIONS(4848),
    [aux_sym_preproc_elif_token1] = ACTIONS(4848),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3276] = {
    [sym_preproc_region] = STATE(3276),
    [sym_preproc_endregion] = STATE(3276),
    [sym_preproc_line] = STATE(3276),
    [sym_preproc_pragma] = STATE(3276),
    [sym_preproc_nullable] = STATE(3276),
    [sym_preproc_error] = STATE(3276),
    [sym_preproc_warning] = STATE(3276),
    [sym_preproc_define] = STATE(3276),
    [sym_preproc_undef] = STATE(3276),
    [sym__identifier_token] = ACTIONS(4850),
    [anon_sym_extern] = ACTIONS(4850),
    [anon_sym_alias] = ACTIONS(4850),
    [anon_sym_global] = ACTIONS(4850),
    [anon_sym_using] = ACTIONS(4850),
    [anon_sym_unsafe] = ACTIONS(4850),
    [anon_sym_static] = ACTIONS(4850),
    [anon_sym_LBRACK] = ACTIONS(4852),
    [anon_sym_LPAREN] = ACTIONS(4852),
    [anon_sym_event] = ACTIONS(4850),
    [anon_sym_namespace] = ACTIONS(4850),
    [anon_sym_class] = ACTIONS(4850),
    [anon_sym_ref] = ACTIONS(4850),
    [anon_sym_struct] = ACTIONS(4850),
    [anon_sym_enum] = ACTIONS(4850),
    [anon_sym_RBRACE] = ACTIONS(4852),
    [anon_sym_interface] = ACTIONS(4850),
    [anon_sym_delegate] = ACTIONS(4850),
    [anon_sym_record] = ACTIONS(4850),
    [anon_sym_abstract] = ACTIONS(4850),
    [anon_sym_async] = ACTIONS(4850),
    [anon_sym_const] = ACTIONS(4850),
    [anon_sym_file] = ACTIONS(4850),
    [anon_sym_fixed] = ACTIONS(4850),
    [anon_sym_internal] = ACTIONS(4850),
    [anon_sym_new] = ACTIONS(4850),
    [anon_sym_override] = ACTIONS(4850),
    [anon_sym_partial] = ACTIONS(4850),
    [anon_sym_private] = ACTIONS(4850),
    [anon_sym_protected] = ACTIONS(4850),
    [anon_sym_public] = ACTIONS(4850),
    [anon_sym_readonly] = ACTIONS(4850),
    [anon_sym_required] = ACTIONS(4850),
    [anon_sym_sealed] = ACTIONS(4850),
    [anon_sym_virtual] = ACTIONS(4850),
    [anon_sym_volatile] = ACTIONS(4850),
    [anon_sym_where] = ACTIONS(4850),
    [anon_sym_notnull] = ACTIONS(4850),
    [anon_sym_unmanaged] = ACTIONS(4850),
    [anon_sym_TILDE] = ACTIONS(4852),
    [anon_sym_implicit] = ACTIONS(4850),
    [anon_sym_explicit] = ACTIONS(4850),
    [anon_sym_scoped] = ACTIONS(4850),
    [anon_sym_var] = ACTIONS(4850),
    [sym_predefined_type] = ACTIONS(4850),
    [anon_sym_yield] = ACTIONS(4850),
    [anon_sym_when] = ACTIONS(4850),
    [anon_sym_from] = ACTIONS(4850),
    [anon_sym_into] = ACTIONS(4850),
    [anon_sym_join] = ACTIONS(4850),
    [anon_sym_on] = ACTIONS(4850),
    [anon_sym_equals] = ACTIONS(4850),
    [anon_sym_let] = ACTIONS(4850),
    [anon_sym_orderby] = ACTIONS(4850),
    [anon_sym_ascending] = ACTIONS(4850),
    [anon_sym_descending] = ACTIONS(4850),
    [anon_sym_group] = ACTIONS(4850),
    [anon_sym_by] = ACTIONS(4850),
    [anon_sym_select] = ACTIONS(4850),
    [aux_sym_preproc_if_token1] = ACTIONS(4852),
    [aux_sym_preproc_if_token3] = ACTIONS(4852),
    [aux_sym_preproc_else_token1] = ACTIONS(4852),
    [aux_sym_preproc_elif_token1] = ACTIONS(4852),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3277] = {
    [sym_preproc_region] = STATE(3277),
    [sym_preproc_endregion] = STATE(3277),
    [sym_preproc_line] = STATE(3277),
    [sym_preproc_pragma] = STATE(3277),
    [sym_preproc_nullable] = STATE(3277),
    [sym_preproc_error] = STATE(3277),
    [sym_preproc_warning] = STATE(3277),
    [sym_preproc_define] = STATE(3277),
    [sym_preproc_undef] = STATE(3277),
    [sym__identifier_token] = ACTIONS(4854),
    [anon_sym_extern] = ACTIONS(4854),
    [anon_sym_alias] = ACTIONS(4854),
    [anon_sym_global] = ACTIONS(4854),
    [anon_sym_using] = ACTIONS(4854),
    [anon_sym_unsafe] = ACTIONS(4854),
    [anon_sym_static] = ACTIONS(4854),
    [anon_sym_LBRACK] = ACTIONS(4856),
    [anon_sym_LPAREN] = ACTIONS(4856),
    [anon_sym_event] = ACTIONS(4854),
    [anon_sym_namespace] = ACTIONS(4854),
    [anon_sym_class] = ACTIONS(4854),
    [anon_sym_ref] = ACTIONS(4854),
    [anon_sym_struct] = ACTIONS(4854),
    [anon_sym_enum] = ACTIONS(4854),
    [anon_sym_RBRACE] = ACTIONS(4856),
    [anon_sym_interface] = ACTIONS(4854),
    [anon_sym_delegate] = ACTIONS(4854),
    [anon_sym_record] = ACTIONS(4854),
    [anon_sym_abstract] = ACTIONS(4854),
    [anon_sym_async] = ACTIONS(4854),
    [anon_sym_const] = ACTIONS(4854),
    [anon_sym_file] = ACTIONS(4854),
    [anon_sym_fixed] = ACTIONS(4854),
    [anon_sym_internal] = ACTIONS(4854),
    [anon_sym_new] = ACTIONS(4854),
    [anon_sym_override] = ACTIONS(4854),
    [anon_sym_partial] = ACTIONS(4854),
    [anon_sym_private] = ACTIONS(4854),
    [anon_sym_protected] = ACTIONS(4854),
    [anon_sym_public] = ACTIONS(4854),
    [anon_sym_readonly] = ACTIONS(4854),
    [anon_sym_required] = ACTIONS(4854),
    [anon_sym_sealed] = ACTIONS(4854),
    [anon_sym_virtual] = ACTIONS(4854),
    [anon_sym_volatile] = ACTIONS(4854),
    [anon_sym_where] = ACTIONS(4854),
    [anon_sym_notnull] = ACTIONS(4854),
    [anon_sym_unmanaged] = ACTIONS(4854),
    [anon_sym_TILDE] = ACTIONS(4856),
    [anon_sym_implicit] = ACTIONS(4854),
    [anon_sym_explicit] = ACTIONS(4854),
    [anon_sym_scoped] = ACTIONS(4854),
    [anon_sym_var] = ACTIONS(4854),
    [sym_predefined_type] = ACTIONS(4854),
    [anon_sym_yield] = ACTIONS(4854),
    [anon_sym_when] = ACTIONS(4854),
    [anon_sym_from] = ACTIONS(4854),
    [anon_sym_into] = ACTIONS(4854),
    [anon_sym_join] = ACTIONS(4854),
    [anon_sym_on] = ACTIONS(4854),
    [anon_sym_equals] = ACTIONS(4854),
    [anon_sym_let] = ACTIONS(4854),
    [anon_sym_orderby] = ACTIONS(4854),
    [anon_sym_ascending] = ACTIONS(4854),
    [anon_sym_descending] = ACTIONS(4854),
    [anon_sym_group] = ACTIONS(4854),
    [anon_sym_by] = ACTIONS(4854),
    [anon_sym_select] = ACTIONS(4854),
    [aux_sym_preproc_if_token1] = ACTIONS(4856),
    [aux_sym_preproc_if_token3] = ACTIONS(4856),
    [aux_sym_preproc_else_token1] = ACTIONS(4856),
    [aux_sym_preproc_elif_token1] = ACTIONS(4856),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3278] = {
    [sym__variable_designation] = STATE(4182),
    [sym_parenthesized_variable_designation] = STATE(4153),
    [sym_identifier] = STATE(4156),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3278),
    [sym_preproc_endregion] = STATE(3278),
    [sym_preproc_line] = STATE(3278),
    [sym_preproc_pragma] = STATE(3278),
    [sym_preproc_nullable] = STATE(3278),
    [sym_preproc_error] = STATE(3278),
    [sym_preproc_warning] = STATE(3278),
    [sym_preproc_define] = STATE(3278),
    [sym_preproc_undef] = STATE(3278),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4405),
    [anon_sym_LPAREN] = ACTIONS(4405),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4407),
    [anon_sym_GT] = ACTIONS(4407),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4407),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4407),
    [anon_sym_PLUS_PLUS] = ACTIONS(4405),
    [anon_sym_DASH_DASH] = ACTIONS(4405),
    [anon_sym_PLUS] = ACTIONS(4407),
    [anon_sym_DASH] = ACTIONS(4407),
    [anon_sym_STAR] = ACTIONS(4405),
    [anon_sym_SLASH] = ACTIONS(4407),
    [anon_sym_PERCENT] = ACTIONS(4405),
    [anon_sym_CARET] = ACTIONS(4405),
    [anon_sym_PIPE] = ACTIONS(4407),
    [anon_sym_AMP] = ACTIONS(4407),
    [anon_sym_LT_LT] = ACTIONS(4405),
    [anon_sym_GT_GT] = ACTIONS(4407),
    [anon_sym_GT_GT_GT] = ACTIONS(4405),
    [anon_sym_EQ_EQ] = ACTIONS(4405),
    [anon_sym_BANG_EQ] = ACTIONS(4405),
    [anon_sym_GT_EQ] = ACTIONS(4405),
    [anon_sym_LT_EQ] = ACTIONS(4405),
    [anon_sym_DOT] = ACTIONS(4407),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4407),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4359),
    [anon_sym_DOT_DOT] = ACTIONS(4405),
    [anon_sym_and] = ACTIONS(4407),
    [anon_sym_or] = ACTIONS(4407),
    [anon_sym_AMP_AMP] = ACTIONS(4405),
    [anon_sym_PIPE_PIPE] = ACTIONS(4405),
    [anon_sym_QMARK_QMARK] = ACTIONS(4405),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4339),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4407),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4407),
    [anon_sym_is] = ACTIONS(4407),
    [anon_sym_DASH_GT] = ACTIONS(4405),
    [anon_sym_with] = ACTIONS(4407),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3279] = {
    [sym__variable_designation] = STATE(4207),
    [sym_parenthesized_variable_designation] = STATE(4153),
    [sym_identifier] = STATE(4156),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3279),
    [sym_preproc_endregion] = STATE(3279),
    [sym_preproc_line] = STATE(3279),
    [sym_preproc_pragma] = STATE(3279),
    [sym_preproc_nullable] = STATE(3279),
    [sym_preproc_error] = STATE(3279),
    [sym_preproc_warning] = STATE(3279),
    [sym_preproc_define] = STATE(3279),
    [sym_preproc_undef] = STATE(3279),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4437),
    [anon_sym_LPAREN] = ACTIONS(4437),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4439),
    [anon_sym_GT] = ACTIONS(4439),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4439),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4439),
    [anon_sym_PLUS_PLUS] = ACTIONS(4437),
    [anon_sym_DASH_DASH] = ACTIONS(4437),
    [anon_sym_PLUS] = ACTIONS(4439),
    [anon_sym_DASH] = ACTIONS(4439),
    [anon_sym_STAR] = ACTIONS(4437),
    [anon_sym_SLASH] = ACTIONS(4439),
    [anon_sym_PERCENT] = ACTIONS(4437),
    [anon_sym_CARET] = ACTIONS(4437),
    [anon_sym_PIPE] = ACTIONS(4439),
    [anon_sym_AMP] = ACTIONS(4439),
    [anon_sym_LT_LT] = ACTIONS(4437),
    [anon_sym_GT_GT] = ACTIONS(4439),
    [anon_sym_GT_GT_GT] = ACTIONS(4437),
    [anon_sym_EQ_EQ] = ACTIONS(4437),
    [anon_sym_BANG_EQ] = ACTIONS(4437),
    [anon_sym_GT_EQ] = ACTIONS(4437),
    [anon_sym_LT_EQ] = ACTIONS(4437),
    [anon_sym_DOT] = ACTIONS(4439),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4439),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4359),
    [anon_sym_DOT_DOT] = ACTIONS(4437),
    [anon_sym_and] = ACTIONS(4439),
    [anon_sym_or] = ACTIONS(4439),
    [anon_sym_AMP_AMP] = ACTIONS(4437),
    [anon_sym_PIPE_PIPE] = ACTIONS(4437),
    [anon_sym_QMARK_QMARK] = ACTIONS(4437),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4339),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4439),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4439),
    [anon_sym_is] = ACTIONS(4439),
    [anon_sym_DASH_GT] = ACTIONS(4437),
    [anon_sym_with] = ACTIONS(4439),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3280] = {
    [sym_preproc_region] = STATE(3280),
    [sym_preproc_endregion] = STATE(3280),
    [sym_preproc_line] = STATE(3280),
    [sym_preproc_pragma] = STATE(3280),
    [sym_preproc_nullable] = STATE(3280),
    [sym_preproc_error] = STATE(3280),
    [sym_preproc_warning] = STATE(3280),
    [sym_preproc_define] = STATE(3280),
    [sym_preproc_undef] = STATE(3280),
    [sym__identifier_token] = ACTIONS(4858),
    [anon_sym_extern] = ACTIONS(4858),
    [anon_sym_alias] = ACTIONS(4858),
    [anon_sym_global] = ACTIONS(4858),
    [anon_sym_using] = ACTIONS(4858),
    [anon_sym_unsafe] = ACTIONS(4858),
    [anon_sym_static] = ACTIONS(4858),
    [anon_sym_LBRACK] = ACTIONS(4860),
    [anon_sym_LPAREN] = ACTIONS(4860),
    [anon_sym_event] = ACTIONS(4858),
    [anon_sym_namespace] = ACTIONS(4858),
    [anon_sym_class] = ACTIONS(4858),
    [anon_sym_ref] = ACTIONS(4858),
    [anon_sym_struct] = ACTIONS(4858),
    [anon_sym_enum] = ACTIONS(4858),
    [anon_sym_RBRACE] = ACTIONS(4860),
    [anon_sym_interface] = ACTIONS(4858),
    [anon_sym_delegate] = ACTIONS(4858),
    [anon_sym_record] = ACTIONS(4858),
    [anon_sym_abstract] = ACTIONS(4858),
    [anon_sym_async] = ACTIONS(4858),
    [anon_sym_const] = ACTIONS(4858),
    [anon_sym_file] = ACTIONS(4858),
    [anon_sym_fixed] = ACTIONS(4858),
    [anon_sym_internal] = ACTIONS(4858),
    [anon_sym_new] = ACTIONS(4858),
    [anon_sym_override] = ACTIONS(4858),
    [anon_sym_partial] = ACTIONS(4858),
    [anon_sym_private] = ACTIONS(4858),
    [anon_sym_protected] = ACTIONS(4858),
    [anon_sym_public] = ACTIONS(4858),
    [anon_sym_readonly] = ACTIONS(4858),
    [anon_sym_required] = ACTIONS(4858),
    [anon_sym_sealed] = ACTIONS(4858),
    [anon_sym_virtual] = ACTIONS(4858),
    [anon_sym_volatile] = ACTIONS(4858),
    [anon_sym_where] = ACTIONS(4858),
    [anon_sym_notnull] = ACTIONS(4858),
    [anon_sym_unmanaged] = ACTIONS(4858),
    [anon_sym_TILDE] = ACTIONS(4860),
    [anon_sym_implicit] = ACTIONS(4858),
    [anon_sym_explicit] = ACTIONS(4858),
    [anon_sym_scoped] = ACTIONS(4858),
    [anon_sym_var] = ACTIONS(4858),
    [sym_predefined_type] = ACTIONS(4858),
    [anon_sym_yield] = ACTIONS(4858),
    [anon_sym_when] = ACTIONS(4858),
    [anon_sym_from] = ACTIONS(4858),
    [anon_sym_into] = ACTIONS(4858),
    [anon_sym_join] = ACTIONS(4858),
    [anon_sym_on] = ACTIONS(4858),
    [anon_sym_equals] = ACTIONS(4858),
    [anon_sym_let] = ACTIONS(4858),
    [anon_sym_orderby] = ACTIONS(4858),
    [anon_sym_ascending] = ACTIONS(4858),
    [anon_sym_descending] = ACTIONS(4858),
    [anon_sym_group] = ACTIONS(4858),
    [anon_sym_by] = ACTIONS(4858),
    [anon_sym_select] = ACTIONS(4858),
    [aux_sym_preproc_if_token1] = ACTIONS(4860),
    [aux_sym_preproc_if_token3] = ACTIONS(4860),
    [aux_sym_preproc_else_token1] = ACTIONS(4860),
    [aux_sym_preproc_elif_token1] = ACTIONS(4860),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3281] = {
    [sym_preproc_region] = STATE(3281),
    [sym_preproc_endregion] = STATE(3281),
    [sym_preproc_line] = STATE(3281),
    [sym_preproc_pragma] = STATE(3281),
    [sym_preproc_nullable] = STATE(3281),
    [sym_preproc_error] = STATE(3281),
    [sym_preproc_warning] = STATE(3281),
    [sym_preproc_define] = STATE(3281),
    [sym_preproc_undef] = STATE(3281),
    [sym__identifier_token] = ACTIONS(4862),
    [anon_sym_extern] = ACTIONS(4862),
    [anon_sym_alias] = ACTIONS(4862),
    [anon_sym_global] = ACTIONS(4862),
    [anon_sym_using] = ACTIONS(4862),
    [anon_sym_unsafe] = ACTIONS(4862),
    [anon_sym_static] = ACTIONS(4862),
    [anon_sym_LBRACK] = ACTIONS(4864),
    [anon_sym_LPAREN] = ACTIONS(4864),
    [anon_sym_event] = ACTIONS(4862),
    [anon_sym_namespace] = ACTIONS(4862),
    [anon_sym_class] = ACTIONS(4862),
    [anon_sym_ref] = ACTIONS(4862),
    [anon_sym_struct] = ACTIONS(4862),
    [anon_sym_enum] = ACTIONS(4862),
    [anon_sym_RBRACE] = ACTIONS(4864),
    [anon_sym_interface] = ACTIONS(4862),
    [anon_sym_delegate] = ACTIONS(4862),
    [anon_sym_record] = ACTIONS(4862),
    [anon_sym_abstract] = ACTIONS(4862),
    [anon_sym_async] = ACTIONS(4862),
    [anon_sym_const] = ACTIONS(4862),
    [anon_sym_file] = ACTIONS(4862),
    [anon_sym_fixed] = ACTIONS(4862),
    [anon_sym_internal] = ACTIONS(4862),
    [anon_sym_new] = ACTIONS(4862),
    [anon_sym_override] = ACTIONS(4862),
    [anon_sym_partial] = ACTIONS(4862),
    [anon_sym_private] = ACTIONS(4862),
    [anon_sym_protected] = ACTIONS(4862),
    [anon_sym_public] = ACTIONS(4862),
    [anon_sym_readonly] = ACTIONS(4862),
    [anon_sym_required] = ACTIONS(4862),
    [anon_sym_sealed] = ACTIONS(4862),
    [anon_sym_virtual] = ACTIONS(4862),
    [anon_sym_volatile] = ACTIONS(4862),
    [anon_sym_where] = ACTIONS(4862),
    [anon_sym_notnull] = ACTIONS(4862),
    [anon_sym_unmanaged] = ACTIONS(4862),
    [anon_sym_TILDE] = ACTIONS(4864),
    [anon_sym_implicit] = ACTIONS(4862),
    [anon_sym_explicit] = ACTIONS(4862),
    [anon_sym_scoped] = ACTIONS(4862),
    [anon_sym_var] = ACTIONS(4862),
    [sym_predefined_type] = ACTIONS(4862),
    [anon_sym_yield] = ACTIONS(4862),
    [anon_sym_when] = ACTIONS(4862),
    [anon_sym_from] = ACTIONS(4862),
    [anon_sym_into] = ACTIONS(4862),
    [anon_sym_join] = ACTIONS(4862),
    [anon_sym_on] = ACTIONS(4862),
    [anon_sym_equals] = ACTIONS(4862),
    [anon_sym_let] = ACTIONS(4862),
    [anon_sym_orderby] = ACTIONS(4862),
    [anon_sym_ascending] = ACTIONS(4862),
    [anon_sym_descending] = ACTIONS(4862),
    [anon_sym_group] = ACTIONS(4862),
    [anon_sym_by] = ACTIONS(4862),
    [anon_sym_select] = ACTIONS(4862),
    [aux_sym_preproc_if_token1] = ACTIONS(4864),
    [aux_sym_preproc_if_token3] = ACTIONS(4864),
    [aux_sym_preproc_else_token1] = ACTIONS(4864),
    [aux_sym_preproc_elif_token1] = ACTIONS(4864),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3282] = {
    [sym_preproc_region] = STATE(3282),
    [sym_preproc_endregion] = STATE(3282),
    [sym_preproc_line] = STATE(3282),
    [sym_preproc_pragma] = STATE(3282),
    [sym_preproc_nullable] = STATE(3282),
    [sym_preproc_error] = STATE(3282),
    [sym_preproc_warning] = STATE(3282),
    [sym_preproc_define] = STATE(3282),
    [sym_preproc_undef] = STATE(3282),
    [sym__identifier_token] = ACTIONS(4866),
    [anon_sym_extern] = ACTIONS(4866),
    [anon_sym_alias] = ACTIONS(4866),
    [anon_sym_global] = ACTIONS(4866),
    [anon_sym_using] = ACTIONS(4866),
    [anon_sym_unsafe] = ACTIONS(4866),
    [anon_sym_static] = ACTIONS(4866),
    [anon_sym_LBRACK] = ACTIONS(4868),
    [anon_sym_LPAREN] = ACTIONS(4868),
    [anon_sym_event] = ACTIONS(4866),
    [anon_sym_namespace] = ACTIONS(4866),
    [anon_sym_class] = ACTIONS(4866),
    [anon_sym_ref] = ACTIONS(4866),
    [anon_sym_struct] = ACTIONS(4866),
    [anon_sym_enum] = ACTIONS(4866),
    [anon_sym_RBRACE] = ACTIONS(4868),
    [anon_sym_interface] = ACTIONS(4866),
    [anon_sym_delegate] = ACTIONS(4866),
    [anon_sym_record] = ACTIONS(4866),
    [anon_sym_abstract] = ACTIONS(4866),
    [anon_sym_async] = ACTIONS(4866),
    [anon_sym_const] = ACTIONS(4866),
    [anon_sym_file] = ACTIONS(4866),
    [anon_sym_fixed] = ACTIONS(4866),
    [anon_sym_internal] = ACTIONS(4866),
    [anon_sym_new] = ACTIONS(4866),
    [anon_sym_override] = ACTIONS(4866),
    [anon_sym_partial] = ACTIONS(4866),
    [anon_sym_private] = ACTIONS(4866),
    [anon_sym_protected] = ACTIONS(4866),
    [anon_sym_public] = ACTIONS(4866),
    [anon_sym_readonly] = ACTIONS(4866),
    [anon_sym_required] = ACTIONS(4866),
    [anon_sym_sealed] = ACTIONS(4866),
    [anon_sym_virtual] = ACTIONS(4866),
    [anon_sym_volatile] = ACTIONS(4866),
    [anon_sym_where] = ACTIONS(4866),
    [anon_sym_notnull] = ACTIONS(4866),
    [anon_sym_unmanaged] = ACTIONS(4866),
    [anon_sym_TILDE] = ACTIONS(4868),
    [anon_sym_implicit] = ACTIONS(4866),
    [anon_sym_explicit] = ACTIONS(4866),
    [anon_sym_scoped] = ACTIONS(4866),
    [anon_sym_var] = ACTIONS(4866),
    [sym_predefined_type] = ACTIONS(4866),
    [anon_sym_yield] = ACTIONS(4866),
    [anon_sym_when] = ACTIONS(4866),
    [anon_sym_from] = ACTIONS(4866),
    [anon_sym_into] = ACTIONS(4866),
    [anon_sym_join] = ACTIONS(4866),
    [anon_sym_on] = ACTIONS(4866),
    [anon_sym_equals] = ACTIONS(4866),
    [anon_sym_let] = ACTIONS(4866),
    [anon_sym_orderby] = ACTIONS(4866),
    [anon_sym_ascending] = ACTIONS(4866),
    [anon_sym_descending] = ACTIONS(4866),
    [anon_sym_group] = ACTIONS(4866),
    [anon_sym_by] = ACTIONS(4866),
    [anon_sym_select] = ACTIONS(4866),
    [aux_sym_preproc_if_token1] = ACTIONS(4868),
    [aux_sym_preproc_if_token3] = ACTIONS(4868),
    [aux_sym_preproc_else_token1] = ACTIONS(4868),
    [aux_sym_preproc_elif_token1] = ACTIONS(4868),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3283] = {
    [sym_preproc_region] = STATE(3283),
    [sym_preproc_endregion] = STATE(3283),
    [sym_preproc_line] = STATE(3283),
    [sym_preproc_pragma] = STATE(3283),
    [sym_preproc_nullable] = STATE(3283),
    [sym_preproc_error] = STATE(3283),
    [sym_preproc_warning] = STATE(3283),
    [sym_preproc_define] = STATE(3283),
    [sym_preproc_undef] = STATE(3283),
    [sym__identifier_token] = ACTIONS(4870),
    [anon_sym_extern] = ACTIONS(4870),
    [anon_sym_alias] = ACTIONS(4870),
    [anon_sym_global] = ACTIONS(4870),
    [anon_sym_using] = ACTIONS(4870),
    [anon_sym_unsafe] = ACTIONS(4870),
    [anon_sym_static] = ACTIONS(4870),
    [anon_sym_LBRACK] = ACTIONS(4872),
    [anon_sym_LPAREN] = ACTIONS(4872),
    [anon_sym_event] = ACTIONS(4870),
    [anon_sym_namespace] = ACTIONS(4870),
    [anon_sym_class] = ACTIONS(4870),
    [anon_sym_ref] = ACTIONS(4870),
    [anon_sym_struct] = ACTIONS(4870),
    [anon_sym_enum] = ACTIONS(4870),
    [anon_sym_RBRACE] = ACTIONS(4872),
    [anon_sym_interface] = ACTIONS(4870),
    [anon_sym_delegate] = ACTIONS(4870),
    [anon_sym_record] = ACTIONS(4870),
    [anon_sym_abstract] = ACTIONS(4870),
    [anon_sym_async] = ACTIONS(4870),
    [anon_sym_const] = ACTIONS(4870),
    [anon_sym_file] = ACTIONS(4870),
    [anon_sym_fixed] = ACTIONS(4870),
    [anon_sym_internal] = ACTIONS(4870),
    [anon_sym_new] = ACTIONS(4870),
    [anon_sym_override] = ACTIONS(4870),
    [anon_sym_partial] = ACTIONS(4870),
    [anon_sym_private] = ACTIONS(4870),
    [anon_sym_protected] = ACTIONS(4870),
    [anon_sym_public] = ACTIONS(4870),
    [anon_sym_readonly] = ACTIONS(4870),
    [anon_sym_required] = ACTIONS(4870),
    [anon_sym_sealed] = ACTIONS(4870),
    [anon_sym_virtual] = ACTIONS(4870),
    [anon_sym_volatile] = ACTIONS(4870),
    [anon_sym_where] = ACTIONS(4870),
    [anon_sym_notnull] = ACTIONS(4870),
    [anon_sym_unmanaged] = ACTIONS(4870),
    [anon_sym_TILDE] = ACTIONS(4872),
    [anon_sym_implicit] = ACTIONS(4870),
    [anon_sym_explicit] = ACTIONS(4870),
    [anon_sym_scoped] = ACTIONS(4870),
    [anon_sym_var] = ACTIONS(4870),
    [sym_predefined_type] = ACTIONS(4870),
    [anon_sym_yield] = ACTIONS(4870),
    [anon_sym_when] = ACTIONS(4870),
    [anon_sym_from] = ACTIONS(4870),
    [anon_sym_into] = ACTIONS(4870),
    [anon_sym_join] = ACTIONS(4870),
    [anon_sym_on] = ACTIONS(4870),
    [anon_sym_equals] = ACTIONS(4870),
    [anon_sym_let] = ACTIONS(4870),
    [anon_sym_orderby] = ACTIONS(4870),
    [anon_sym_ascending] = ACTIONS(4870),
    [anon_sym_descending] = ACTIONS(4870),
    [anon_sym_group] = ACTIONS(4870),
    [anon_sym_by] = ACTIONS(4870),
    [anon_sym_select] = ACTIONS(4870),
    [aux_sym_preproc_if_token1] = ACTIONS(4872),
    [aux_sym_preproc_if_token3] = ACTIONS(4872),
    [aux_sym_preproc_else_token1] = ACTIONS(4872),
    [aux_sym_preproc_elif_token1] = ACTIONS(4872),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3284] = {
    [sym_preproc_region] = STATE(3284),
    [sym_preproc_endregion] = STATE(3284),
    [sym_preproc_line] = STATE(3284),
    [sym_preproc_pragma] = STATE(3284),
    [sym_preproc_nullable] = STATE(3284),
    [sym_preproc_error] = STATE(3284),
    [sym_preproc_warning] = STATE(3284),
    [sym_preproc_define] = STATE(3284),
    [sym_preproc_undef] = STATE(3284),
    [sym__identifier_token] = ACTIONS(4874),
    [anon_sym_extern] = ACTIONS(4874),
    [anon_sym_alias] = ACTIONS(4874),
    [anon_sym_global] = ACTIONS(4874),
    [anon_sym_using] = ACTIONS(4874),
    [anon_sym_unsafe] = ACTIONS(4874),
    [anon_sym_static] = ACTIONS(4874),
    [anon_sym_LBRACK] = ACTIONS(4876),
    [anon_sym_LPAREN] = ACTIONS(4876),
    [anon_sym_event] = ACTIONS(4874),
    [anon_sym_namespace] = ACTIONS(4874),
    [anon_sym_class] = ACTIONS(4874),
    [anon_sym_ref] = ACTIONS(4874),
    [anon_sym_struct] = ACTIONS(4874),
    [anon_sym_enum] = ACTIONS(4874),
    [anon_sym_RBRACE] = ACTIONS(4876),
    [anon_sym_interface] = ACTIONS(4874),
    [anon_sym_delegate] = ACTIONS(4874),
    [anon_sym_record] = ACTIONS(4874),
    [anon_sym_abstract] = ACTIONS(4874),
    [anon_sym_async] = ACTIONS(4874),
    [anon_sym_const] = ACTIONS(4874),
    [anon_sym_file] = ACTIONS(4874),
    [anon_sym_fixed] = ACTIONS(4874),
    [anon_sym_internal] = ACTIONS(4874),
    [anon_sym_new] = ACTIONS(4874),
    [anon_sym_override] = ACTIONS(4874),
    [anon_sym_partial] = ACTIONS(4874),
    [anon_sym_private] = ACTIONS(4874),
    [anon_sym_protected] = ACTIONS(4874),
    [anon_sym_public] = ACTIONS(4874),
    [anon_sym_readonly] = ACTIONS(4874),
    [anon_sym_required] = ACTIONS(4874),
    [anon_sym_sealed] = ACTIONS(4874),
    [anon_sym_virtual] = ACTIONS(4874),
    [anon_sym_volatile] = ACTIONS(4874),
    [anon_sym_where] = ACTIONS(4874),
    [anon_sym_notnull] = ACTIONS(4874),
    [anon_sym_unmanaged] = ACTIONS(4874),
    [anon_sym_TILDE] = ACTIONS(4876),
    [anon_sym_implicit] = ACTIONS(4874),
    [anon_sym_explicit] = ACTIONS(4874),
    [anon_sym_scoped] = ACTIONS(4874),
    [anon_sym_var] = ACTIONS(4874),
    [sym_predefined_type] = ACTIONS(4874),
    [anon_sym_yield] = ACTIONS(4874),
    [anon_sym_when] = ACTIONS(4874),
    [anon_sym_from] = ACTIONS(4874),
    [anon_sym_into] = ACTIONS(4874),
    [anon_sym_join] = ACTIONS(4874),
    [anon_sym_on] = ACTIONS(4874),
    [anon_sym_equals] = ACTIONS(4874),
    [anon_sym_let] = ACTIONS(4874),
    [anon_sym_orderby] = ACTIONS(4874),
    [anon_sym_ascending] = ACTIONS(4874),
    [anon_sym_descending] = ACTIONS(4874),
    [anon_sym_group] = ACTIONS(4874),
    [anon_sym_by] = ACTIONS(4874),
    [anon_sym_select] = ACTIONS(4874),
    [aux_sym_preproc_if_token1] = ACTIONS(4876),
    [aux_sym_preproc_if_token3] = ACTIONS(4876),
    [aux_sym_preproc_else_token1] = ACTIONS(4876),
    [aux_sym_preproc_elif_token1] = ACTIONS(4876),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3285] = {
    [sym_preproc_region] = STATE(3285),
    [sym_preproc_endregion] = STATE(3285),
    [sym_preproc_line] = STATE(3285),
    [sym_preproc_pragma] = STATE(3285),
    [sym_preproc_nullable] = STATE(3285),
    [sym_preproc_error] = STATE(3285),
    [sym_preproc_warning] = STATE(3285),
    [sym_preproc_define] = STATE(3285),
    [sym_preproc_undef] = STATE(3285),
    [sym__identifier_token] = ACTIONS(4878),
    [anon_sym_extern] = ACTIONS(4878),
    [anon_sym_alias] = ACTIONS(4878),
    [anon_sym_global] = ACTIONS(4878),
    [anon_sym_using] = ACTIONS(4878),
    [anon_sym_unsafe] = ACTIONS(4878),
    [anon_sym_static] = ACTIONS(4878),
    [anon_sym_LBRACK] = ACTIONS(4880),
    [anon_sym_LPAREN] = ACTIONS(4880),
    [anon_sym_event] = ACTIONS(4878),
    [anon_sym_namespace] = ACTIONS(4878),
    [anon_sym_class] = ACTIONS(4878),
    [anon_sym_ref] = ACTIONS(4878),
    [anon_sym_struct] = ACTIONS(4878),
    [anon_sym_enum] = ACTIONS(4878),
    [anon_sym_RBRACE] = ACTIONS(4880),
    [anon_sym_interface] = ACTIONS(4878),
    [anon_sym_delegate] = ACTIONS(4878),
    [anon_sym_record] = ACTIONS(4878),
    [anon_sym_abstract] = ACTIONS(4878),
    [anon_sym_async] = ACTIONS(4878),
    [anon_sym_const] = ACTIONS(4878),
    [anon_sym_file] = ACTIONS(4878),
    [anon_sym_fixed] = ACTIONS(4878),
    [anon_sym_internal] = ACTIONS(4878),
    [anon_sym_new] = ACTIONS(4878),
    [anon_sym_override] = ACTIONS(4878),
    [anon_sym_partial] = ACTIONS(4878),
    [anon_sym_private] = ACTIONS(4878),
    [anon_sym_protected] = ACTIONS(4878),
    [anon_sym_public] = ACTIONS(4878),
    [anon_sym_readonly] = ACTIONS(4878),
    [anon_sym_required] = ACTIONS(4878),
    [anon_sym_sealed] = ACTIONS(4878),
    [anon_sym_virtual] = ACTIONS(4878),
    [anon_sym_volatile] = ACTIONS(4878),
    [anon_sym_where] = ACTIONS(4878),
    [anon_sym_notnull] = ACTIONS(4878),
    [anon_sym_unmanaged] = ACTIONS(4878),
    [anon_sym_TILDE] = ACTIONS(4880),
    [anon_sym_implicit] = ACTIONS(4878),
    [anon_sym_explicit] = ACTIONS(4878),
    [anon_sym_scoped] = ACTIONS(4878),
    [anon_sym_var] = ACTIONS(4878),
    [sym_predefined_type] = ACTIONS(4878),
    [anon_sym_yield] = ACTIONS(4878),
    [anon_sym_when] = ACTIONS(4878),
    [anon_sym_from] = ACTIONS(4878),
    [anon_sym_into] = ACTIONS(4878),
    [anon_sym_join] = ACTIONS(4878),
    [anon_sym_on] = ACTIONS(4878),
    [anon_sym_equals] = ACTIONS(4878),
    [anon_sym_let] = ACTIONS(4878),
    [anon_sym_orderby] = ACTIONS(4878),
    [anon_sym_ascending] = ACTIONS(4878),
    [anon_sym_descending] = ACTIONS(4878),
    [anon_sym_group] = ACTIONS(4878),
    [anon_sym_by] = ACTIONS(4878),
    [anon_sym_select] = ACTIONS(4878),
    [aux_sym_preproc_if_token1] = ACTIONS(4880),
    [aux_sym_preproc_if_token3] = ACTIONS(4880),
    [aux_sym_preproc_else_token1] = ACTIONS(4880),
    [aux_sym_preproc_elif_token1] = ACTIONS(4880),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3286] = {
    [sym_preproc_region] = STATE(3286),
    [sym_preproc_endregion] = STATE(3286),
    [sym_preproc_line] = STATE(3286),
    [sym_preproc_pragma] = STATE(3286),
    [sym_preproc_nullable] = STATE(3286),
    [sym_preproc_error] = STATE(3286),
    [sym_preproc_warning] = STATE(3286),
    [sym_preproc_define] = STATE(3286),
    [sym_preproc_undef] = STATE(3286),
    [sym__identifier_token] = ACTIONS(4882),
    [anon_sym_extern] = ACTIONS(4882),
    [anon_sym_alias] = ACTIONS(4882),
    [anon_sym_global] = ACTIONS(4882),
    [anon_sym_using] = ACTIONS(4882),
    [anon_sym_unsafe] = ACTIONS(4882),
    [anon_sym_static] = ACTIONS(4882),
    [anon_sym_LBRACK] = ACTIONS(4884),
    [anon_sym_LPAREN] = ACTIONS(4884),
    [anon_sym_event] = ACTIONS(4882),
    [anon_sym_namespace] = ACTIONS(4882),
    [anon_sym_class] = ACTIONS(4882),
    [anon_sym_ref] = ACTIONS(4882),
    [anon_sym_struct] = ACTIONS(4882),
    [anon_sym_enum] = ACTIONS(4882),
    [anon_sym_RBRACE] = ACTIONS(4884),
    [anon_sym_interface] = ACTIONS(4882),
    [anon_sym_delegate] = ACTIONS(4882),
    [anon_sym_record] = ACTIONS(4882),
    [anon_sym_abstract] = ACTIONS(4882),
    [anon_sym_async] = ACTIONS(4882),
    [anon_sym_const] = ACTIONS(4882),
    [anon_sym_file] = ACTIONS(4882),
    [anon_sym_fixed] = ACTIONS(4882),
    [anon_sym_internal] = ACTIONS(4882),
    [anon_sym_new] = ACTIONS(4882),
    [anon_sym_override] = ACTIONS(4882),
    [anon_sym_partial] = ACTIONS(4882),
    [anon_sym_private] = ACTIONS(4882),
    [anon_sym_protected] = ACTIONS(4882),
    [anon_sym_public] = ACTIONS(4882),
    [anon_sym_readonly] = ACTIONS(4882),
    [anon_sym_required] = ACTIONS(4882),
    [anon_sym_sealed] = ACTIONS(4882),
    [anon_sym_virtual] = ACTIONS(4882),
    [anon_sym_volatile] = ACTIONS(4882),
    [anon_sym_where] = ACTIONS(4882),
    [anon_sym_notnull] = ACTIONS(4882),
    [anon_sym_unmanaged] = ACTIONS(4882),
    [anon_sym_TILDE] = ACTIONS(4884),
    [anon_sym_implicit] = ACTIONS(4882),
    [anon_sym_explicit] = ACTIONS(4882),
    [anon_sym_scoped] = ACTIONS(4882),
    [anon_sym_var] = ACTIONS(4882),
    [sym_predefined_type] = ACTIONS(4882),
    [anon_sym_yield] = ACTIONS(4882),
    [anon_sym_when] = ACTIONS(4882),
    [anon_sym_from] = ACTIONS(4882),
    [anon_sym_into] = ACTIONS(4882),
    [anon_sym_join] = ACTIONS(4882),
    [anon_sym_on] = ACTIONS(4882),
    [anon_sym_equals] = ACTIONS(4882),
    [anon_sym_let] = ACTIONS(4882),
    [anon_sym_orderby] = ACTIONS(4882),
    [anon_sym_ascending] = ACTIONS(4882),
    [anon_sym_descending] = ACTIONS(4882),
    [anon_sym_group] = ACTIONS(4882),
    [anon_sym_by] = ACTIONS(4882),
    [anon_sym_select] = ACTIONS(4882),
    [aux_sym_preproc_if_token1] = ACTIONS(4884),
    [aux_sym_preproc_if_token3] = ACTIONS(4884),
    [aux_sym_preproc_else_token1] = ACTIONS(4884),
    [aux_sym_preproc_elif_token1] = ACTIONS(4884),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3287] = {
    [sym__variable_designation] = STATE(4190),
    [sym_parenthesized_variable_designation] = STATE(4153),
    [sym_identifier] = STATE(4156),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3287),
    [sym_preproc_endregion] = STATE(3287),
    [sym_preproc_line] = STATE(3287),
    [sym_preproc_pragma] = STATE(3287),
    [sym_preproc_nullable] = STATE(3287),
    [sym_preproc_error] = STATE(3287),
    [sym_preproc_warning] = STATE(3287),
    [sym_preproc_define] = STATE(3287),
    [sym_preproc_undef] = STATE(3287),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4441),
    [anon_sym_LPAREN] = ACTIONS(4441),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4443),
    [anon_sym_GT] = ACTIONS(4443),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4443),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4443),
    [anon_sym_PLUS_PLUS] = ACTIONS(4441),
    [anon_sym_DASH_DASH] = ACTIONS(4441),
    [anon_sym_PLUS] = ACTIONS(4443),
    [anon_sym_DASH] = ACTIONS(4443),
    [anon_sym_STAR] = ACTIONS(4441),
    [anon_sym_SLASH] = ACTIONS(4443),
    [anon_sym_PERCENT] = ACTIONS(4441),
    [anon_sym_CARET] = ACTIONS(4441),
    [anon_sym_PIPE] = ACTIONS(4443),
    [anon_sym_AMP] = ACTIONS(4443),
    [anon_sym_LT_LT] = ACTIONS(4441),
    [anon_sym_GT_GT] = ACTIONS(4443),
    [anon_sym_GT_GT_GT] = ACTIONS(4441),
    [anon_sym_EQ_EQ] = ACTIONS(4441),
    [anon_sym_BANG_EQ] = ACTIONS(4441),
    [anon_sym_GT_EQ] = ACTIONS(4441),
    [anon_sym_LT_EQ] = ACTIONS(4441),
    [anon_sym_DOT] = ACTIONS(4443),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4443),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4359),
    [anon_sym_DOT_DOT] = ACTIONS(4441),
    [anon_sym_and] = ACTIONS(4443),
    [anon_sym_or] = ACTIONS(4443),
    [anon_sym_AMP_AMP] = ACTIONS(4441),
    [anon_sym_PIPE_PIPE] = ACTIONS(4441),
    [anon_sym_QMARK_QMARK] = ACTIONS(4441),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4339),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4443),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4443),
    [anon_sym_is] = ACTIONS(4443),
    [anon_sym_DASH_GT] = ACTIONS(4441),
    [anon_sym_with] = ACTIONS(4443),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3288] = {
    [sym_preproc_region] = STATE(3288),
    [sym_preproc_endregion] = STATE(3288),
    [sym_preproc_line] = STATE(3288),
    [sym_preproc_pragma] = STATE(3288),
    [sym_preproc_nullable] = STATE(3288),
    [sym_preproc_error] = STATE(3288),
    [sym_preproc_warning] = STATE(3288),
    [sym_preproc_define] = STATE(3288),
    [sym_preproc_undef] = STATE(3288),
    [sym__identifier_token] = ACTIONS(3537),
    [anon_sym_extern] = ACTIONS(3537),
    [anon_sym_alias] = ACTIONS(3537),
    [anon_sym_global] = ACTIONS(3537),
    [anon_sym_using] = ACTIONS(3537),
    [anon_sym_unsafe] = ACTIONS(3537),
    [anon_sym_static] = ACTIONS(3537),
    [anon_sym_LBRACK] = ACTIONS(3539),
    [anon_sym_LPAREN] = ACTIONS(3539),
    [anon_sym_event] = ACTIONS(3537),
    [anon_sym_namespace] = ACTIONS(3537),
    [anon_sym_class] = ACTIONS(3537),
    [anon_sym_ref] = ACTIONS(3537),
    [anon_sym_struct] = ACTIONS(3537),
    [anon_sym_enum] = ACTIONS(3537),
    [anon_sym_RBRACE] = ACTIONS(3539),
    [anon_sym_interface] = ACTIONS(3537),
    [anon_sym_delegate] = ACTIONS(3537),
    [anon_sym_record] = ACTIONS(3537),
    [anon_sym_abstract] = ACTIONS(3537),
    [anon_sym_async] = ACTIONS(3537),
    [anon_sym_const] = ACTIONS(3537),
    [anon_sym_file] = ACTIONS(3537),
    [anon_sym_fixed] = ACTIONS(3537),
    [anon_sym_internal] = ACTIONS(3537),
    [anon_sym_new] = ACTIONS(3537),
    [anon_sym_override] = ACTIONS(3537),
    [anon_sym_partial] = ACTIONS(3537),
    [anon_sym_private] = ACTIONS(3537),
    [anon_sym_protected] = ACTIONS(3537),
    [anon_sym_public] = ACTIONS(3537),
    [anon_sym_readonly] = ACTIONS(3537),
    [anon_sym_required] = ACTIONS(3537),
    [anon_sym_sealed] = ACTIONS(3537),
    [anon_sym_virtual] = ACTIONS(3537),
    [anon_sym_volatile] = ACTIONS(3537),
    [anon_sym_where] = ACTIONS(3537),
    [anon_sym_notnull] = ACTIONS(3537),
    [anon_sym_unmanaged] = ACTIONS(3537),
    [anon_sym_TILDE] = ACTIONS(3539),
    [anon_sym_implicit] = ACTIONS(3537),
    [anon_sym_explicit] = ACTIONS(3537),
    [anon_sym_scoped] = ACTIONS(3537),
    [anon_sym_var] = ACTIONS(3537),
    [sym_predefined_type] = ACTIONS(3537),
    [anon_sym_yield] = ACTIONS(3537),
    [anon_sym_when] = ACTIONS(3537),
    [anon_sym_from] = ACTIONS(3537),
    [anon_sym_into] = ACTIONS(3537),
    [anon_sym_join] = ACTIONS(3537),
    [anon_sym_on] = ACTIONS(3537),
    [anon_sym_equals] = ACTIONS(3537),
    [anon_sym_let] = ACTIONS(3537),
    [anon_sym_orderby] = ACTIONS(3537),
    [anon_sym_ascending] = ACTIONS(3537),
    [anon_sym_descending] = ACTIONS(3537),
    [anon_sym_group] = ACTIONS(3537),
    [anon_sym_by] = ACTIONS(3537),
    [anon_sym_select] = ACTIONS(3537),
    [aux_sym_preproc_if_token1] = ACTIONS(3539),
    [aux_sym_preproc_if_token3] = ACTIONS(3539),
    [aux_sym_preproc_else_token1] = ACTIONS(3539),
    [aux_sym_preproc_elif_token1] = ACTIONS(3539),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3289] = {
    [sym_preproc_region] = STATE(3289),
    [sym_preproc_endregion] = STATE(3289),
    [sym_preproc_line] = STATE(3289),
    [sym_preproc_pragma] = STATE(3289),
    [sym_preproc_nullable] = STATE(3289),
    [sym_preproc_error] = STATE(3289),
    [sym_preproc_warning] = STATE(3289),
    [sym_preproc_define] = STATE(3289),
    [sym_preproc_undef] = STATE(3289),
    [sym__identifier_token] = ACTIONS(3541),
    [anon_sym_extern] = ACTIONS(3541),
    [anon_sym_alias] = ACTIONS(3541),
    [anon_sym_global] = ACTIONS(3541),
    [anon_sym_using] = ACTIONS(3541),
    [anon_sym_unsafe] = ACTIONS(3541),
    [anon_sym_static] = ACTIONS(3541),
    [anon_sym_LBRACK] = ACTIONS(3543),
    [anon_sym_LPAREN] = ACTIONS(3543),
    [anon_sym_event] = ACTIONS(3541),
    [anon_sym_namespace] = ACTIONS(3541),
    [anon_sym_class] = ACTIONS(3541),
    [anon_sym_ref] = ACTIONS(3541),
    [anon_sym_struct] = ACTIONS(3541),
    [anon_sym_enum] = ACTIONS(3541),
    [anon_sym_RBRACE] = ACTIONS(3543),
    [anon_sym_interface] = ACTIONS(3541),
    [anon_sym_delegate] = ACTIONS(3541),
    [anon_sym_record] = ACTIONS(3541),
    [anon_sym_abstract] = ACTIONS(3541),
    [anon_sym_async] = ACTIONS(3541),
    [anon_sym_const] = ACTIONS(3541),
    [anon_sym_file] = ACTIONS(3541),
    [anon_sym_fixed] = ACTIONS(3541),
    [anon_sym_internal] = ACTIONS(3541),
    [anon_sym_new] = ACTIONS(3541),
    [anon_sym_override] = ACTIONS(3541),
    [anon_sym_partial] = ACTIONS(3541),
    [anon_sym_private] = ACTIONS(3541),
    [anon_sym_protected] = ACTIONS(3541),
    [anon_sym_public] = ACTIONS(3541),
    [anon_sym_readonly] = ACTIONS(3541),
    [anon_sym_required] = ACTIONS(3541),
    [anon_sym_sealed] = ACTIONS(3541),
    [anon_sym_virtual] = ACTIONS(3541),
    [anon_sym_volatile] = ACTIONS(3541),
    [anon_sym_where] = ACTIONS(3541),
    [anon_sym_notnull] = ACTIONS(3541),
    [anon_sym_unmanaged] = ACTIONS(3541),
    [anon_sym_TILDE] = ACTIONS(3543),
    [anon_sym_implicit] = ACTIONS(3541),
    [anon_sym_explicit] = ACTIONS(3541),
    [anon_sym_scoped] = ACTIONS(3541),
    [anon_sym_var] = ACTIONS(3541),
    [sym_predefined_type] = ACTIONS(3541),
    [anon_sym_yield] = ACTIONS(3541),
    [anon_sym_when] = ACTIONS(3541),
    [anon_sym_from] = ACTIONS(3541),
    [anon_sym_into] = ACTIONS(3541),
    [anon_sym_join] = ACTIONS(3541),
    [anon_sym_on] = ACTIONS(3541),
    [anon_sym_equals] = ACTIONS(3541),
    [anon_sym_let] = ACTIONS(3541),
    [anon_sym_orderby] = ACTIONS(3541),
    [anon_sym_ascending] = ACTIONS(3541),
    [anon_sym_descending] = ACTIONS(3541),
    [anon_sym_group] = ACTIONS(3541),
    [anon_sym_by] = ACTIONS(3541),
    [anon_sym_select] = ACTIONS(3541),
    [aux_sym_preproc_if_token1] = ACTIONS(3543),
    [aux_sym_preproc_if_token3] = ACTIONS(3543),
    [aux_sym_preproc_else_token1] = ACTIONS(3543),
    [aux_sym_preproc_elif_token1] = ACTIONS(3543),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3290] = {
    [sym_preproc_region] = STATE(3290),
    [sym_preproc_endregion] = STATE(3290),
    [sym_preproc_line] = STATE(3290),
    [sym_preproc_pragma] = STATE(3290),
    [sym_preproc_nullable] = STATE(3290),
    [sym_preproc_error] = STATE(3290),
    [sym_preproc_warning] = STATE(3290),
    [sym_preproc_define] = STATE(3290),
    [sym_preproc_undef] = STATE(3290),
    [sym__identifier_token] = ACTIONS(3545),
    [anon_sym_extern] = ACTIONS(3545),
    [anon_sym_alias] = ACTIONS(3545),
    [anon_sym_global] = ACTIONS(3545),
    [anon_sym_using] = ACTIONS(3545),
    [anon_sym_unsafe] = ACTIONS(3545),
    [anon_sym_static] = ACTIONS(3545),
    [anon_sym_LBRACK] = ACTIONS(3547),
    [anon_sym_LPAREN] = ACTIONS(3547),
    [anon_sym_event] = ACTIONS(3545),
    [anon_sym_namespace] = ACTIONS(3545),
    [anon_sym_class] = ACTIONS(3545),
    [anon_sym_ref] = ACTIONS(3545),
    [anon_sym_struct] = ACTIONS(3545),
    [anon_sym_enum] = ACTIONS(3545),
    [anon_sym_RBRACE] = ACTIONS(3547),
    [anon_sym_interface] = ACTIONS(3545),
    [anon_sym_delegate] = ACTIONS(3545),
    [anon_sym_record] = ACTIONS(3545),
    [anon_sym_abstract] = ACTIONS(3545),
    [anon_sym_async] = ACTIONS(3545),
    [anon_sym_const] = ACTIONS(3545),
    [anon_sym_file] = ACTIONS(3545),
    [anon_sym_fixed] = ACTIONS(3545),
    [anon_sym_internal] = ACTIONS(3545),
    [anon_sym_new] = ACTIONS(3545),
    [anon_sym_override] = ACTIONS(3545),
    [anon_sym_partial] = ACTIONS(3545),
    [anon_sym_private] = ACTIONS(3545),
    [anon_sym_protected] = ACTIONS(3545),
    [anon_sym_public] = ACTIONS(3545),
    [anon_sym_readonly] = ACTIONS(3545),
    [anon_sym_required] = ACTIONS(3545),
    [anon_sym_sealed] = ACTIONS(3545),
    [anon_sym_virtual] = ACTIONS(3545),
    [anon_sym_volatile] = ACTIONS(3545),
    [anon_sym_where] = ACTIONS(3545),
    [anon_sym_notnull] = ACTIONS(3545),
    [anon_sym_unmanaged] = ACTIONS(3545),
    [anon_sym_TILDE] = ACTIONS(3547),
    [anon_sym_implicit] = ACTIONS(3545),
    [anon_sym_explicit] = ACTIONS(3545),
    [anon_sym_scoped] = ACTIONS(3545),
    [anon_sym_var] = ACTIONS(3545),
    [sym_predefined_type] = ACTIONS(3545),
    [anon_sym_yield] = ACTIONS(3545),
    [anon_sym_when] = ACTIONS(3545),
    [anon_sym_from] = ACTIONS(3545),
    [anon_sym_into] = ACTIONS(3545),
    [anon_sym_join] = ACTIONS(3545),
    [anon_sym_on] = ACTIONS(3545),
    [anon_sym_equals] = ACTIONS(3545),
    [anon_sym_let] = ACTIONS(3545),
    [anon_sym_orderby] = ACTIONS(3545),
    [anon_sym_ascending] = ACTIONS(3545),
    [anon_sym_descending] = ACTIONS(3545),
    [anon_sym_group] = ACTIONS(3545),
    [anon_sym_by] = ACTIONS(3545),
    [anon_sym_select] = ACTIONS(3545),
    [aux_sym_preproc_if_token1] = ACTIONS(3547),
    [aux_sym_preproc_if_token3] = ACTIONS(3547),
    [aux_sym_preproc_else_token1] = ACTIONS(3547),
    [aux_sym_preproc_elif_token1] = ACTIONS(3547),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3291] = {
    [sym_preproc_region] = STATE(3291),
    [sym_preproc_endregion] = STATE(3291),
    [sym_preproc_line] = STATE(3291),
    [sym_preproc_pragma] = STATE(3291),
    [sym_preproc_nullable] = STATE(3291),
    [sym_preproc_error] = STATE(3291),
    [sym_preproc_warning] = STATE(3291),
    [sym_preproc_define] = STATE(3291),
    [sym_preproc_undef] = STATE(3291),
    [sym__identifier_token] = ACTIONS(3549),
    [anon_sym_extern] = ACTIONS(3549),
    [anon_sym_alias] = ACTIONS(3549),
    [anon_sym_global] = ACTIONS(3549),
    [anon_sym_using] = ACTIONS(3549),
    [anon_sym_unsafe] = ACTIONS(3549),
    [anon_sym_static] = ACTIONS(3549),
    [anon_sym_LBRACK] = ACTIONS(3551),
    [anon_sym_LPAREN] = ACTIONS(3551),
    [anon_sym_event] = ACTIONS(3549),
    [anon_sym_namespace] = ACTIONS(3549),
    [anon_sym_class] = ACTIONS(3549),
    [anon_sym_ref] = ACTIONS(3549),
    [anon_sym_struct] = ACTIONS(3549),
    [anon_sym_enum] = ACTIONS(3549),
    [anon_sym_RBRACE] = ACTIONS(3551),
    [anon_sym_interface] = ACTIONS(3549),
    [anon_sym_delegate] = ACTIONS(3549),
    [anon_sym_record] = ACTIONS(3549),
    [anon_sym_abstract] = ACTIONS(3549),
    [anon_sym_async] = ACTIONS(3549),
    [anon_sym_const] = ACTIONS(3549),
    [anon_sym_file] = ACTIONS(3549),
    [anon_sym_fixed] = ACTIONS(3549),
    [anon_sym_internal] = ACTIONS(3549),
    [anon_sym_new] = ACTIONS(3549),
    [anon_sym_override] = ACTIONS(3549),
    [anon_sym_partial] = ACTIONS(3549),
    [anon_sym_private] = ACTIONS(3549),
    [anon_sym_protected] = ACTIONS(3549),
    [anon_sym_public] = ACTIONS(3549),
    [anon_sym_readonly] = ACTIONS(3549),
    [anon_sym_required] = ACTIONS(3549),
    [anon_sym_sealed] = ACTIONS(3549),
    [anon_sym_virtual] = ACTIONS(3549),
    [anon_sym_volatile] = ACTIONS(3549),
    [anon_sym_where] = ACTIONS(3549),
    [anon_sym_notnull] = ACTIONS(3549),
    [anon_sym_unmanaged] = ACTIONS(3549),
    [anon_sym_TILDE] = ACTIONS(3551),
    [anon_sym_implicit] = ACTIONS(3549),
    [anon_sym_explicit] = ACTIONS(3549),
    [anon_sym_scoped] = ACTIONS(3549),
    [anon_sym_var] = ACTIONS(3549),
    [sym_predefined_type] = ACTIONS(3549),
    [anon_sym_yield] = ACTIONS(3549),
    [anon_sym_when] = ACTIONS(3549),
    [anon_sym_from] = ACTIONS(3549),
    [anon_sym_into] = ACTIONS(3549),
    [anon_sym_join] = ACTIONS(3549),
    [anon_sym_on] = ACTIONS(3549),
    [anon_sym_equals] = ACTIONS(3549),
    [anon_sym_let] = ACTIONS(3549),
    [anon_sym_orderby] = ACTIONS(3549),
    [anon_sym_ascending] = ACTIONS(3549),
    [anon_sym_descending] = ACTIONS(3549),
    [anon_sym_group] = ACTIONS(3549),
    [anon_sym_by] = ACTIONS(3549),
    [anon_sym_select] = ACTIONS(3549),
    [aux_sym_preproc_if_token1] = ACTIONS(3551),
    [aux_sym_preproc_if_token3] = ACTIONS(3551),
    [aux_sym_preproc_else_token1] = ACTIONS(3551),
    [aux_sym_preproc_elif_token1] = ACTIONS(3551),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3292] = {
    [sym_preproc_region] = STATE(3292),
    [sym_preproc_endregion] = STATE(3292),
    [sym_preproc_line] = STATE(3292),
    [sym_preproc_pragma] = STATE(3292),
    [sym_preproc_nullable] = STATE(3292),
    [sym_preproc_error] = STATE(3292),
    [sym_preproc_warning] = STATE(3292),
    [sym_preproc_define] = STATE(3292),
    [sym_preproc_undef] = STATE(3292),
    [sym__identifier_token] = ACTIONS(3553),
    [anon_sym_extern] = ACTIONS(3553),
    [anon_sym_alias] = ACTIONS(3553),
    [anon_sym_global] = ACTIONS(3553),
    [anon_sym_using] = ACTIONS(3553),
    [anon_sym_unsafe] = ACTIONS(3553),
    [anon_sym_static] = ACTIONS(3553),
    [anon_sym_LBRACK] = ACTIONS(3555),
    [anon_sym_LPAREN] = ACTIONS(3555),
    [anon_sym_event] = ACTIONS(3553),
    [anon_sym_namespace] = ACTIONS(3553),
    [anon_sym_class] = ACTIONS(3553),
    [anon_sym_ref] = ACTIONS(3553),
    [anon_sym_struct] = ACTIONS(3553),
    [anon_sym_enum] = ACTIONS(3553),
    [anon_sym_RBRACE] = ACTIONS(3555),
    [anon_sym_interface] = ACTIONS(3553),
    [anon_sym_delegate] = ACTIONS(3553),
    [anon_sym_record] = ACTIONS(3553),
    [anon_sym_abstract] = ACTIONS(3553),
    [anon_sym_async] = ACTIONS(3553),
    [anon_sym_const] = ACTIONS(3553),
    [anon_sym_file] = ACTIONS(3553),
    [anon_sym_fixed] = ACTIONS(3553),
    [anon_sym_internal] = ACTIONS(3553),
    [anon_sym_new] = ACTIONS(3553),
    [anon_sym_override] = ACTIONS(3553),
    [anon_sym_partial] = ACTIONS(3553),
    [anon_sym_private] = ACTIONS(3553),
    [anon_sym_protected] = ACTIONS(3553),
    [anon_sym_public] = ACTIONS(3553),
    [anon_sym_readonly] = ACTIONS(3553),
    [anon_sym_required] = ACTIONS(3553),
    [anon_sym_sealed] = ACTIONS(3553),
    [anon_sym_virtual] = ACTIONS(3553),
    [anon_sym_volatile] = ACTIONS(3553),
    [anon_sym_where] = ACTIONS(3553),
    [anon_sym_notnull] = ACTIONS(3553),
    [anon_sym_unmanaged] = ACTIONS(3553),
    [anon_sym_TILDE] = ACTIONS(3555),
    [anon_sym_implicit] = ACTIONS(3553),
    [anon_sym_explicit] = ACTIONS(3553),
    [anon_sym_scoped] = ACTIONS(3553),
    [anon_sym_var] = ACTIONS(3553),
    [sym_predefined_type] = ACTIONS(3553),
    [anon_sym_yield] = ACTIONS(3553),
    [anon_sym_when] = ACTIONS(3553),
    [anon_sym_from] = ACTIONS(3553),
    [anon_sym_into] = ACTIONS(3553),
    [anon_sym_join] = ACTIONS(3553),
    [anon_sym_on] = ACTIONS(3553),
    [anon_sym_equals] = ACTIONS(3553),
    [anon_sym_let] = ACTIONS(3553),
    [anon_sym_orderby] = ACTIONS(3553),
    [anon_sym_ascending] = ACTIONS(3553),
    [anon_sym_descending] = ACTIONS(3553),
    [anon_sym_group] = ACTIONS(3553),
    [anon_sym_by] = ACTIONS(3553),
    [anon_sym_select] = ACTIONS(3553),
    [aux_sym_preproc_if_token1] = ACTIONS(3555),
    [aux_sym_preproc_if_token3] = ACTIONS(3555),
    [aux_sym_preproc_else_token1] = ACTIONS(3555),
    [aux_sym_preproc_elif_token1] = ACTIONS(3555),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3293] = {
    [sym_preproc_region] = STATE(3293),
    [sym_preproc_endregion] = STATE(3293),
    [sym_preproc_line] = STATE(3293),
    [sym_preproc_pragma] = STATE(3293),
    [sym_preproc_nullable] = STATE(3293),
    [sym_preproc_error] = STATE(3293),
    [sym_preproc_warning] = STATE(3293),
    [sym_preproc_define] = STATE(3293),
    [sym_preproc_undef] = STATE(3293),
    [sym__identifier_token] = ACTIONS(3557),
    [anon_sym_extern] = ACTIONS(3557),
    [anon_sym_alias] = ACTIONS(3557),
    [anon_sym_global] = ACTIONS(3557),
    [anon_sym_using] = ACTIONS(3557),
    [anon_sym_unsafe] = ACTIONS(3557),
    [anon_sym_static] = ACTIONS(3557),
    [anon_sym_LBRACK] = ACTIONS(3559),
    [anon_sym_LPAREN] = ACTIONS(3559),
    [anon_sym_event] = ACTIONS(3557),
    [anon_sym_namespace] = ACTIONS(3557),
    [anon_sym_class] = ACTIONS(3557),
    [anon_sym_ref] = ACTIONS(3557),
    [anon_sym_struct] = ACTIONS(3557),
    [anon_sym_enum] = ACTIONS(3557),
    [anon_sym_RBRACE] = ACTIONS(3559),
    [anon_sym_interface] = ACTIONS(3557),
    [anon_sym_delegate] = ACTIONS(3557),
    [anon_sym_record] = ACTIONS(3557),
    [anon_sym_abstract] = ACTIONS(3557),
    [anon_sym_async] = ACTIONS(3557),
    [anon_sym_const] = ACTIONS(3557),
    [anon_sym_file] = ACTIONS(3557),
    [anon_sym_fixed] = ACTIONS(3557),
    [anon_sym_internal] = ACTIONS(3557),
    [anon_sym_new] = ACTIONS(3557),
    [anon_sym_override] = ACTIONS(3557),
    [anon_sym_partial] = ACTIONS(3557),
    [anon_sym_private] = ACTIONS(3557),
    [anon_sym_protected] = ACTIONS(3557),
    [anon_sym_public] = ACTIONS(3557),
    [anon_sym_readonly] = ACTIONS(3557),
    [anon_sym_required] = ACTIONS(3557),
    [anon_sym_sealed] = ACTIONS(3557),
    [anon_sym_virtual] = ACTIONS(3557),
    [anon_sym_volatile] = ACTIONS(3557),
    [anon_sym_where] = ACTIONS(3557),
    [anon_sym_notnull] = ACTIONS(3557),
    [anon_sym_unmanaged] = ACTIONS(3557),
    [anon_sym_TILDE] = ACTIONS(3559),
    [anon_sym_implicit] = ACTIONS(3557),
    [anon_sym_explicit] = ACTIONS(3557),
    [anon_sym_scoped] = ACTIONS(3557),
    [anon_sym_var] = ACTIONS(3557),
    [sym_predefined_type] = ACTIONS(3557),
    [anon_sym_yield] = ACTIONS(3557),
    [anon_sym_when] = ACTIONS(3557),
    [anon_sym_from] = ACTIONS(3557),
    [anon_sym_into] = ACTIONS(3557),
    [anon_sym_join] = ACTIONS(3557),
    [anon_sym_on] = ACTIONS(3557),
    [anon_sym_equals] = ACTIONS(3557),
    [anon_sym_let] = ACTIONS(3557),
    [anon_sym_orderby] = ACTIONS(3557),
    [anon_sym_ascending] = ACTIONS(3557),
    [anon_sym_descending] = ACTIONS(3557),
    [anon_sym_group] = ACTIONS(3557),
    [anon_sym_by] = ACTIONS(3557),
    [anon_sym_select] = ACTIONS(3557),
    [aux_sym_preproc_if_token1] = ACTIONS(3559),
    [aux_sym_preproc_if_token3] = ACTIONS(3559),
    [aux_sym_preproc_else_token1] = ACTIONS(3559),
    [aux_sym_preproc_elif_token1] = ACTIONS(3559),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3294] = {
    [sym_preproc_region] = STATE(3294),
    [sym_preproc_endregion] = STATE(3294),
    [sym_preproc_line] = STATE(3294),
    [sym_preproc_pragma] = STATE(3294),
    [sym_preproc_nullable] = STATE(3294),
    [sym_preproc_error] = STATE(3294),
    [sym_preproc_warning] = STATE(3294),
    [sym_preproc_define] = STATE(3294),
    [sym_preproc_undef] = STATE(3294),
    [sym__identifier_token] = ACTIONS(2995),
    [anon_sym_extern] = ACTIONS(2995),
    [anon_sym_alias] = ACTIONS(2995),
    [anon_sym_global] = ACTIONS(2995),
    [anon_sym_using] = ACTIONS(2995),
    [anon_sym_unsafe] = ACTIONS(2995),
    [anon_sym_static] = ACTIONS(2995),
    [anon_sym_LBRACK] = ACTIONS(2997),
    [anon_sym_LPAREN] = ACTIONS(2997),
    [anon_sym_event] = ACTIONS(2995),
    [anon_sym_namespace] = ACTIONS(2995),
    [anon_sym_class] = ACTIONS(2995),
    [anon_sym_ref] = ACTIONS(2995),
    [anon_sym_struct] = ACTIONS(2995),
    [anon_sym_enum] = ACTIONS(2995),
    [anon_sym_RBRACE] = ACTIONS(2997),
    [anon_sym_interface] = ACTIONS(2995),
    [anon_sym_delegate] = ACTIONS(2995),
    [anon_sym_record] = ACTIONS(2995),
    [anon_sym_abstract] = ACTIONS(2995),
    [anon_sym_async] = ACTIONS(2995),
    [anon_sym_const] = ACTIONS(2995),
    [anon_sym_file] = ACTIONS(2995),
    [anon_sym_fixed] = ACTIONS(2995),
    [anon_sym_internal] = ACTIONS(2995),
    [anon_sym_new] = ACTIONS(2995),
    [anon_sym_override] = ACTIONS(2995),
    [anon_sym_partial] = ACTIONS(2995),
    [anon_sym_private] = ACTIONS(2995),
    [anon_sym_protected] = ACTIONS(2995),
    [anon_sym_public] = ACTIONS(2995),
    [anon_sym_readonly] = ACTIONS(2995),
    [anon_sym_required] = ACTIONS(2995),
    [anon_sym_sealed] = ACTIONS(2995),
    [anon_sym_virtual] = ACTIONS(2995),
    [anon_sym_volatile] = ACTIONS(2995),
    [anon_sym_where] = ACTIONS(2995),
    [anon_sym_notnull] = ACTIONS(2995),
    [anon_sym_unmanaged] = ACTIONS(2995),
    [anon_sym_TILDE] = ACTIONS(2997),
    [anon_sym_implicit] = ACTIONS(2995),
    [anon_sym_explicit] = ACTIONS(2995),
    [anon_sym_scoped] = ACTIONS(2995),
    [anon_sym_var] = ACTIONS(2995),
    [sym_predefined_type] = ACTIONS(2995),
    [anon_sym_yield] = ACTIONS(2995),
    [anon_sym_when] = ACTIONS(2995),
    [anon_sym_from] = ACTIONS(2995),
    [anon_sym_into] = ACTIONS(2995),
    [anon_sym_join] = ACTIONS(2995),
    [anon_sym_on] = ACTIONS(2995),
    [anon_sym_equals] = ACTIONS(2995),
    [anon_sym_let] = ACTIONS(2995),
    [anon_sym_orderby] = ACTIONS(2995),
    [anon_sym_ascending] = ACTIONS(2995),
    [anon_sym_descending] = ACTIONS(2995),
    [anon_sym_group] = ACTIONS(2995),
    [anon_sym_by] = ACTIONS(2995),
    [anon_sym_select] = ACTIONS(2995),
    [aux_sym_preproc_if_token1] = ACTIONS(2997),
    [aux_sym_preproc_if_token3] = ACTIONS(2997),
    [aux_sym_preproc_else_token1] = ACTIONS(2997),
    [aux_sym_preproc_elif_token1] = ACTIONS(2997),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3295] = {
    [sym_preproc_region] = STATE(3295),
    [sym_preproc_endregion] = STATE(3295),
    [sym_preproc_line] = STATE(3295),
    [sym_preproc_pragma] = STATE(3295),
    [sym_preproc_nullable] = STATE(3295),
    [sym_preproc_error] = STATE(3295),
    [sym_preproc_warning] = STATE(3295),
    [sym_preproc_define] = STATE(3295),
    [sym_preproc_undef] = STATE(3295),
    [sym__identifier_token] = ACTIONS(3037),
    [anon_sym_extern] = ACTIONS(3037),
    [anon_sym_alias] = ACTIONS(3037),
    [anon_sym_global] = ACTIONS(3037),
    [anon_sym_using] = ACTIONS(3037),
    [anon_sym_unsafe] = ACTIONS(3037),
    [anon_sym_static] = ACTIONS(3037),
    [anon_sym_LBRACK] = ACTIONS(3039),
    [anon_sym_LPAREN] = ACTIONS(3039),
    [anon_sym_event] = ACTIONS(3037),
    [anon_sym_namespace] = ACTIONS(3037),
    [anon_sym_class] = ACTIONS(3037),
    [anon_sym_ref] = ACTIONS(3037),
    [anon_sym_struct] = ACTIONS(3037),
    [anon_sym_enum] = ACTIONS(3037),
    [anon_sym_RBRACE] = ACTIONS(3039),
    [anon_sym_interface] = ACTIONS(3037),
    [anon_sym_delegate] = ACTIONS(3037),
    [anon_sym_record] = ACTIONS(3037),
    [anon_sym_abstract] = ACTIONS(3037),
    [anon_sym_async] = ACTIONS(3037),
    [anon_sym_const] = ACTIONS(3037),
    [anon_sym_file] = ACTIONS(3037),
    [anon_sym_fixed] = ACTIONS(3037),
    [anon_sym_internal] = ACTIONS(3037),
    [anon_sym_new] = ACTIONS(3037),
    [anon_sym_override] = ACTIONS(3037),
    [anon_sym_partial] = ACTIONS(3037),
    [anon_sym_private] = ACTIONS(3037),
    [anon_sym_protected] = ACTIONS(3037),
    [anon_sym_public] = ACTIONS(3037),
    [anon_sym_readonly] = ACTIONS(3037),
    [anon_sym_required] = ACTIONS(3037),
    [anon_sym_sealed] = ACTIONS(3037),
    [anon_sym_virtual] = ACTIONS(3037),
    [anon_sym_volatile] = ACTIONS(3037),
    [anon_sym_where] = ACTIONS(3037),
    [anon_sym_notnull] = ACTIONS(3037),
    [anon_sym_unmanaged] = ACTIONS(3037),
    [anon_sym_TILDE] = ACTIONS(3039),
    [anon_sym_implicit] = ACTIONS(3037),
    [anon_sym_explicit] = ACTIONS(3037),
    [anon_sym_scoped] = ACTIONS(3037),
    [anon_sym_var] = ACTIONS(3037),
    [sym_predefined_type] = ACTIONS(3037),
    [anon_sym_yield] = ACTIONS(3037),
    [anon_sym_when] = ACTIONS(3037),
    [anon_sym_from] = ACTIONS(3037),
    [anon_sym_into] = ACTIONS(3037),
    [anon_sym_join] = ACTIONS(3037),
    [anon_sym_on] = ACTIONS(3037),
    [anon_sym_equals] = ACTIONS(3037),
    [anon_sym_let] = ACTIONS(3037),
    [anon_sym_orderby] = ACTIONS(3037),
    [anon_sym_ascending] = ACTIONS(3037),
    [anon_sym_descending] = ACTIONS(3037),
    [anon_sym_group] = ACTIONS(3037),
    [anon_sym_by] = ACTIONS(3037),
    [anon_sym_select] = ACTIONS(3037),
    [aux_sym_preproc_if_token1] = ACTIONS(3039),
    [aux_sym_preproc_if_token3] = ACTIONS(3039),
    [aux_sym_preproc_else_token1] = ACTIONS(3039),
    [aux_sym_preproc_elif_token1] = ACTIONS(3039),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3296] = {
    [sym_preproc_region] = STATE(3296),
    [sym_preproc_endregion] = STATE(3296),
    [sym_preproc_line] = STATE(3296),
    [sym_preproc_pragma] = STATE(3296),
    [sym_preproc_nullable] = STATE(3296),
    [sym_preproc_error] = STATE(3296),
    [sym_preproc_warning] = STATE(3296),
    [sym_preproc_define] = STATE(3296),
    [sym_preproc_undef] = STATE(3296),
    [sym__identifier_token] = ACTIONS(3561),
    [anon_sym_extern] = ACTIONS(3561),
    [anon_sym_alias] = ACTIONS(3561),
    [anon_sym_global] = ACTIONS(3561),
    [anon_sym_using] = ACTIONS(3561),
    [anon_sym_unsafe] = ACTIONS(3561),
    [anon_sym_static] = ACTIONS(3561),
    [anon_sym_LBRACK] = ACTIONS(3563),
    [anon_sym_LPAREN] = ACTIONS(3563),
    [anon_sym_event] = ACTIONS(3561),
    [anon_sym_namespace] = ACTIONS(3561),
    [anon_sym_class] = ACTIONS(3561),
    [anon_sym_ref] = ACTIONS(3561),
    [anon_sym_struct] = ACTIONS(3561),
    [anon_sym_enum] = ACTIONS(3561),
    [anon_sym_RBRACE] = ACTIONS(3563),
    [anon_sym_interface] = ACTIONS(3561),
    [anon_sym_delegate] = ACTIONS(3561),
    [anon_sym_record] = ACTIONS(3561),
    [anon_sym_abstract] = ACTIONS(3561),
    [anon_sym_async] = ACTIONS(3561),
    [anon_sym_const] = ACTIONS(3561),
    [anon_sym_file] = ACTIONS(3561),
    [anon_sym_fixed] = ACTIONS(3561),
    [anon_sym_internal] = ACTIONS(3561),
    [anon_sym_new] = ACTIONS(3561),
    [anon_sym_override] = ACTIONS(3561),
    [anon_sym_partial] = ACTIONS(3561),
    [anon_sym_private] = ACTIONS(3561),
    [anon_sym_protected] = ACTIONS(3561),
    [anon_sym_public] = ACTIONS(3561),
    [anon_sym_readonly] = ACTIONS(3561),
    [anon_sym_required] = ACTIONS(3561),
    [anon_sym_sealed] = ACTIONS(3561),
    [anon_sym_virtual] = ACTIONS(3561),
    [anon_sym_volatile] = ACTIONS(3561),
    [anon_sym_where] = ACTIONS(3561),
    [anon_sym_notnull] = ACTIONS(3561),
    [anon_sym_unmanaged] = ACTIONS(3561),
    [anon_sym_TILDE] = ACTIONS(3563),
    [anon_sym_implicit] = ACTIONS(3561),
    [anon_sym_explicit] = ACTIONS(3561),
    [anon_sym_scoped] = ACTIONS(3561),
    [anon_sym_var] = ACTIONS(3561),
    [sym_predefined_type] = ACTIONS(3561),
    [anon_sym_yield] = ACTIONS(3561),
    [anon_sym_when] = ACTIONS(3561),
    [anon_sym_from] = ACTIONS(3561),
    [anon_sym_into] = ACTIONS(3561),
    [anon_sym_join] = ACTIONS(3561),
    [anon_sym_on] = ACTIONS(3561),
    [anon_sym_equals] = ACTIONS(3561),
    [anon_sym_let] = ACTIONS(3561),
    [anon_sym_orderby] = ACTIONS(3561),
    [anon_sym_ascending] = ACTIONS(3561),
    [anon_sym_descending] = ACTIONS(3561),
    [anon_sym_group] = ACTIONS(3561),
    [anon_sym_by] = ACTIONS(3561),
    [anon_sym_select] = ACTIONS(3561),
    [aux_sym_preproc_if_token1] = ACTIONS(3563),
    [aux_sym_preproc_if_token3] = ACTIONS(3563),
    [aux_sym_preproc_else_token1] = ACTIONS(3563),
    [aux_sym_preproc_elif_token1] = ACTIONS(3563),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3297] = {
    [sym_preproc_region] = STATE(3297),
    [sym_preproc_endregion] = STATE(3297),
    [sym_preproc_line] = STATE(3297),
    [sym_preproc_pragma] = STATE(3297),
    [sym_preproc_nullable] = STATE(3297),
    [sym_preproc_error] = STATE(3297),
    [sym_preproc_warning] = STATE(3297),
    [sym_preproc_define] = STATE(3297),
    [sym_preproc_undef] = STATE(3297),
    [sym__identifier_token] = ACTIONS(3565),
    [anon_sym_extern] = ACTIONS(3565),
    [anon_sym_alias] = ACTIONS(3565),
    [anon_sym_global] = ACTIONS(3565),
    [anon_sym_using] = ACTIONS(3565),
    [anon_sym_unsafe] = ACTIONS(3565),
    [anon_sym_static] = ACTIONS(3565),
    [anon_sym_LBRACK] = ACTIONS(3567),
    [anon_sym_LPAREN] = ACTIONS(3567),
    [anon_sym_event] = ACTIONS(3565),
    [anon_sym_namespace] = ACTIONS(3565),
    [anon_sym_class] = ACTIONS(3565),
    [anon_sym_ref] = ACTIONS(3565),
    [anon_sym_struct] = ACTIONS(3565),
    [anon_sym_enum] = ACTIONS(3565),
    [anon_sym_RBRACE] = ACTIONS(3567),
    [anon_sym_interface] = ACTIONS(3565),
    [anon_sym_delegate] = ACTIONS(3565),
    [anon_sym_record] = ACTIONS(3565),
    [anon_sym_abstract] = ACTIONS(3565),
    [anon_sym_async] = ACTIONS(3565),
    [anon_sym_const] = ACTIONS(3565),
    [anon_sym_file] = ACTIONS(3565),
    [anon_sym_fixed] = ACTIONS(3565),
    [anon_sym_internal] = ACTIONS(3565),
    [anon_sym_new] = ACTIONS(3565),
    [anon_sym_override] = ACTIONS(3565),
    [anon_sym_partial] = ACTIONS(3565),
    [anon_sym_private] = ACTIONS(3565),
    [anon_sym_protected] = ACTIONS(3565),
    [anon_sym_public] = ACTIONS(3565),
    [anon_sym_readonly] = ACTIONS(3565),
    [anon_sym_required] = ACTIONS(3565),
    [anon_sym_sealed] = ACTIONS(3565),
    [anon_sym_virtual] = ACTIONS(3565),
    [anon_sym_volatile] = ACTIONS(3565),
    [anon_sym_where] = ACTIONS(3565),
    [anon_sym_notnull] = ACTIONS(3565),
    [anon_sym_unmanaged] = ACTIONS(3565),
    [anon_sym_TILDE] = ACTIONS(3567),
    [anon_sym_implicit] = ACTIONS(3565),
    [anon_sym_explicit] = ACTIONS(3565),
    [anon_sym_scoped] = ACTIONS(3565),
    [anon_sym_var] = ACTIONS(3565),
    [sym_predefined_type] = ACTIONS(3565),
    [anon_sym_yield] = ACTIONS(3565),
    [anon_sym_when] = ACTIONS(3565),
    [anon_sym_from] = ACTIONS(3565),
    [anon_sym_into] = ACTIONS(3565),
    [anon_sym_join] = ACTIONS(3565),
    [anon_sym_on] = ACTIONS(3565),
    [anon_sym_equals] = ACTIONS(3565),
    [anon_sym_let] = ACTIONS(3565),
    [anon_sym_orderby] = ACTIONS(3565),
    [anon_sym_ascending] = ACTIONS(3565),
    [anon_sym_descending] = ACTIONS(3565),
    [anon_sym_group] = ACTIONS(3565),
    [anon_sym_by] = ACTIONS(3565),
    [anon_sym_select] = ACTIONS(3565),
    [aux_sym_preproc_if_token1] = ACTIONS(3567),
    [aux_sym_preproc_if_token3] = ACTIONS(3567),
    [aux_sym_preproc_else_token1] = ACTIONS(3567),
    [aux_sym_preproc_elif_token1] = ACTIONS(3567),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3298] = {
    [sym_preproc_region] = STATE(3298),
    [sym_preproc_endregion] = STATE(3298),
    [sym_preproc_line] = STATE(3298),
    [sym_preproc_pragma] = STATE(3298),
    [sym_preproc_nullable] = STATE(3298),
    [sym_preproc_error] = STATE(3298),
    [sym_preproc_warning] = STATE(3298),
    [sym_preproc_define] = STATE(3298),
    [sym_preproc_undef] = STATE(3298),
    [anon_sym_SEMI] = ACTIONS(4191),
    [anon_sym_EQ] = ACTIONS(4183),
    [anon_sym_LBRACK] = ACTIONS(4191),
    [anon_sym_COLON] = ACTIONS(4191),
    [anon_sym_COMMA] = ACTIONS(4191),
    [anon_sym_RBRACK] = ACTIONS(4191),
    [anon_sym_LPAREN] = ACTIONS(4191),
    [anon_sym_RPAREN] = ACTIONS(4191),
    [anon_sym_RBRACE] = ACTIONS(4191),
    [anon_sym_LT] = ACTIONS(4183),
    [anon_sym_GT] = ACTIONS(4183),
    [anon_sym_in] = ACTIONS(4191),
    [anon_sym_QMARK] = ACTIONS(4183),
    [anon_sym_BANG] = ACTIONS(4183),
    [anon_sym_PLUS_PLUS] = ACTIONS(4191),
    [anon_sym_DASH_DASH] = ACTIONS(4191),
    [anon_sym_PLUS] = ACTIONS(4183),
    [anon_sym_DASH] = ACTIONS(4183),
    [anon_sym_STAR] = ACTIONS(4183),
    [anon_sym_SLASH] = ACTIONS(4183),
    [anon_sym_PERCENT] = ACTIONS(4183),
    [anon_sym_CARET] = ACTIONS(4183),
    [anon_sym_PIPE] = ACTIONS(4183),
    [anon_sym_AMP] = ACTIONS(4183),
    [anon_sym_LT_LT] = ACTIONS(4183),
    [anon_sym_GT_GT] = ACTIONS(4183),
    [anon_sym_GT_GT_GT] = ACTIONS(4183),
    [anon_sym_EQ_EQ] = ACTIONS(4191),
    [anon_sym_BANG_EQ] = ACTIONS(4191),
    [anon_sym_GT_EQ] = ACTIONS(4191),
    [anon_sym_LT_EQ] = ACTIONS(4191),
    [anon_sym_DOT] = ACTIONS(4183),
    [anon_sym_EQ_GT] = ACTIONS(4191),
    [anon_sym_switch] = ACTIONS(4191),
    [anon_sym_when] = ACTIONS(4191),
    [anon_sym_DOT_DOT] = ACTIONS(4191),
    [anon_sym_and] = ACTIONS(4191),
    [anon_sym_or] = ACTIONS(4191),
    [anon_sym_PLUS_EQ] = ACTIONS(4191),
    [anon_sym_DASH_EQ] = ACTIONS(4191),
    [anon_sym_STAR_EQ] = ACTIONS(4191),
    [anon_sym_SLASH_EQ] = ACTIONS(4191),
    [anon_sym_PERCENT_EQ] = ACTIONS(4191),
    [anon_sym_AMP_EQ] = ACTIONS(4191),
    [anon_sym_CARET_EQ] = ACTIONS(4191),
    [anon_sym_PIPE_EQ] = ACTIONS(4191),
    [anon_sym_LT_LT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4191),
    [anon_sym_AMP_AMP] = ACTIONS(4191),
    [anon_sym_PIPE_PIPE] = ACTIONS(4191),
    [anon_sym_QMARK_QMARK] = ACTIONS(4183),
    [anon_sym_on] = ACTIONS(4191),
    [anon_sym_equals] = ACTIONS(4191),
    [anon_sym_by] = ACTIONS(4191),
    [anon_sym_as] = ACTIONS(4191),
    [anon_sym_is] = ACTIONS(4191),
    [anon_sym_DASH_GT] = ACTIONS(4191),
    [anon_sym_with] = ACTIONS(4191),
    [aux_sym_preproc_if_token3] = ACTIONS(4191),
    [aux_sym_preproc_else_token1] = ACTIONS(4191),
    [aux_sym_preproc_elif_token1] = ACTIONS(4191),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3299] = {
    [sym_preproc_region] = STATE(3299),
    [sym_preproc_endregion] = STATE(3299),
    [sym_preproc_line] = STATE(3299),
    [sym_preproc_pragma] = STATE(3299),
    [sym_preproc_nullable] = STATE(3299),
    [sym_preproc_error] = STATE(3299),
    [sym_preproc_warning] = STATE(3299),
    [sym_preproc_define] = STATE(3299),
    [sym_preproc_undef] = STATE(3299),
    [sym__identifier_token] = ACTIONS(4886),
    [anon_sym_extern] = ACTIONS(4886),
    [anon_sym_alias] = ACTIONS(4886),
    [anon_sym_global] = ACTIONS(4886),
    [anon_sym_using] = ACTIONS(4886),
    [anon_sym_unsafe] = ACTIONS(4886),
    [anon_sym_static] = ACTIONS(4886),
    [anon_sym_LBRACK] = ACTIONS(4888),
    [anon_sym_LPAREN] = ACTIONS(4888),
    [anon_sym_event] = ACTIONS(4886),
    [anon_sym_namespace] = ACTIONS(4886),
    [anon_sym_class] = ACTIONS(4886),
    [anon_sym_ref] = ACTIONS(4886),
    [anon_sym_struct] = ACTIONS(4886),
    [anon_sym_enum] = ACTIONS(4886),
    [anon_sym_RBRACE] = ACTIONS(4888),
    [anon_sym_interface] = ACTIONS(4886),
    [anon_sym_delegate] = ACTIONS(4886),
    [anon_sym_record] = ACTIONS(4886),
    [anon_sym_abstract] = ACTIONS(4886),
    [anon_sym_async] = ACTIONS(4886),
    [anon_sym_const] = ACTIONS(4886),
    [anon_sym_file] = ACTIONS(4886),
    [anon_sym_fixed] = ACTIONS(4886),
    [anon_sym_internal] = ACTIONS(4886),
    [anon_sym_new] = ACTIONS(4886),
    [anon_sym_override] = ACTIONS(4886),
    [anon_sym_partial] = ACTIONS(4886),
    [anon_sym_private] = ACTIONS(4886),
    [anon_sym_protected] = ACTIONS(4886),
    [anon_sym_public] = ACTIONS(4886),
    [anon_sym_readonly] = ACTIONS(4886),
    [anon_sym_required] = ACTIONS(4886),
    [anon_sym_sealed] = ACTIONS(4886),
    [anon_sym_virtual] = ACTIONS(4886),
    [anon_sym_volatile] = ACTIONS(4886),
    [anon_sym_where] = ACTIONS(4886),
    [anon_sym_notnull] = ACTIONS(4886),
    [anon_sym_unmanaged] = ACTIONS(4886),
    [anon_sym_TILDE] = ACTIONS(4888),
    [anon_sym_implicit] = ACTIONS(4886),
    [anon_sym_explicit] = ACTIONS(4886),
    [anon_sym_scoped] = ACTIONS(4886),
    [anon_sym_var] = ACTIONS(4886),
    [sym_predefined_type] = ACTIONS(4886),
    [anon_sym_yield] = ACTIONS(4886),
    [anon_sym_when] = ACTIONS(4886),
    [anon_sym_from] = ACTIONS(4886),
    [anon_sym_into] = ACTIONS(4886),
    [anon_sym_join] = ACTIONS(4886),
    [anon_sym_on] = ACTIONS(4886),
    [anon_sym_equals] = ACTIONS(4886),
    [anon_sym_let] = ACTIONS(4886),
    [anon_sym_orderby] = ACTIONS(4886),
    [anon_sym_ascending] = ACTIONS(4886),
    [anon_sym_descending] = ACTIONS(4886),
    [anon_sym_group] = ACTIONS(4886),
    [anon_sym_by] = ACTIONS(4886),
    [anon_sym_select] = ACTIONS(4886),
    [aux_sym_preproc_if_token1] = ACTIONS(4888),
    [aux_sym_preproc_if_token3] = ACTIONS(4888),
    [aux_sym_preproc_else_token1] = ACTIONS(4888),
    [aux_sym_preproc_elif_token1] = ACTIONS(4888),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3300] = {
    [sym_preproc_region] = STATE(3300),
    [sym_preproc_endregion] = STATE(3300),
    [sym_preproc_line] = STATE(3300),
    [sym_preproc_pragma] = STATE(3300),
    [sym_preproc_nullable] = STATE(3300),
    [sym_preproc_error] = STATE(3300),
    [sym_preproc_warning] = STATE(3300),
    [sym_preproc_define] = STATE(3300),
    [sym_preproc_undef] = STATE(3300),
    [sym__identifier_token] = ACTIONS(4890),
    [anon_sym_extern] = ACTIONS(4890),
    [anon_sym_alias] = ACTIONS(4890),
    [anon_sym_global] = ACTIONS(4890),
    [anon_sym_using] = ACTIONS(4890),
    [anon_sym_unsafe] = ACTIONS(4890),
    [anon_sym_static] = ACTIONS(4890),
    [anon_sym_LBRACK] = ACTIONS(4892),
    [anon_sym_LPAREN] = ACTIONS(4892),
    [anon_sym_event] = ACTIONS(4890),
    [anon_sym_namespace] = ACTIONS(4890),
    [anon_sym_class] = ACTIONS(4890),
    [anon_sym_ref] = ACTIONS(4890),
    [anon_sym_struct] = ACTIONS(4890),
    [anon_sym_enum] = ACTIONS(4890),
    [anon_sym_RBRACE] = ACTIONS(4892),
    [anon_sym_interface] = ACTIONS(4890),
    [anon_sym_delegate] = ACTIONS(4890),
    [anon_sym_record] = ACTIONS(4890),
    [anon_sym_abstract] = ACTIONS(4890),
    [anon_sym_async] = ACTIONS(4890),
    [anon_sym_const] = ACTIONS(4890),
    [anon_sym_file] = ACTIONS(4890),
    [anon_sym_fixed] = ACTIONS(4890),
    [anon_sym_internal] = ACTIONS(4890),
    [anon_sym_new] = ACTIONS(4890),
    [anon_sym_override] = ACTIONS(4890),
    [anon_sym_partial] = ACTIONS(4890),
    [anon_sym_private] = ACTIONS(4890),
    [anon_sym_protected] = ACTIONS(4890),
    [anon_sym_public] = ACTIONS(4890),
    [anon_sym_readonly] = ACTIONS(4890),
    [anon_sym_required] = ACTIONS(4890),
    [anon_sym_sealed] = ACTIONS(4890),
    [anon_sym_virtual] = ACTIONS(4890),
    [anon_sym_volatile] = ACTIONS(4890),
    [anon_sym_where] = ACTIONS(4890),
    [anon_sym_notnull] = ACTIONS(4890),
    [anon_sym_unmanaged] = ACTIONS(4890),
    [anon_sym_TILDE] = ACTIONS(4892),
    [anon_sym_implicit] = ACTIONS(4890),
    [anon_sym_explicit] = ACTIONS(4890),
    [anon_sym_scoped] = ACTIONS(4890),
    [anon_sym_var] = ACTIONS(4890),
    [sym_predefined_type] = ACTIONS(4890),
    [anon_sym_yield] = ACTIONS(4890),
    [anon_sym_when] = ACTIONS(4890),
    [anon_sym_from] = ACTIONS(4890),
    [anon_sym_into] = ACTIONS(4890),
    [anon_sym_join] = ACTIONS(4890),
    [anon_sym_on] = ACTIONS(4890),
    [anon_sym_equals] = ACTIONS(4890),
    [anon_sym_let] = ACTIONS(4890),
    [anon_sym_orderby] = ACTIONS(4890),
    [anon_sym_ascending] = ACTIONS(4890),
    [anon_sym_descending] = ACTIONS(4890),
    [anon_sym_group] = ACTIONS(4890),
    [anon_sym_by] = ACTIONS(4890),
    [anon_sym_select] = ACTIONS(4890),
    [aux_sym_preproc_if_token1] = ACTIONS(4892),
    [aux_sym_preproc_if_token3] = ACTIONS(4892),
    [aux_sym_preproc_else_token1] = ACTIONS(4892),
    [aux_sym_preproc_elif_token1] = ACTIONS(4892),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3301] = {
    [sym_preproc_region] = STATE(3301),
    [sym_preproc_endregion] = STATE(3301),
    [sym_preproc_line] = STATE(3301),
    [sym_preproc_pragma] = STATE(3301),
    [sym_preproc_nullable] = STATE(3301),
    [sym_preproc_error] = STATE(3301),
    [sym_preproc_warning] = STATE(3301),
    [sym_preproc_define] = STATE(3301),
    [sym_preproc_undef] = STATE(3301),
    [sym__identifier_token] = ACTIONS(4894),
    [anon_sym_extern] = ACTIONS(4894),
    [anon_sym_alias] = ACTIONS(4894),
    [anon_sym_global] = ACTIONS(4894),
    [anon_sym_using] = ACTIONS(4894),
    [anon_sym_unsafe] = ACTIONS(4894),
    [anon_sym_static] = ACTIONS(4894),
    [anon_sym_LBRACK] = ACTIONS(4896),
    [anon_sym_LPAREN] = ACTIONS(4896),
    [anon_sym_event] = ACTIONS(4894),
    [anon_sym_namespace] = ACTIONS(4894),
    [anon_sym_class] = ACTIONS(4894),
    [anon_sym_ref] = ACTIONS(4894),
    [anon_sym_struct] = ACTIONS(4894),
    [anon_sym_enum] = ACTIONS(4894),
    [anon_sym_RBRACE] = ACTIONS(4896),
    [anon_sym_interface] = ACTIONS(4894),
    [anon_sym_delegate] = ACTIONS(4894),
    [anon_sym_record] = ACTIONS(4894),
    [anon_sym_abstract] = ACTIONS(4894),
    [anon_sym_async] = ACTIONS(4894),
    [anon_sym_const] = ACTIONS(4894),
    [anon_sym_file] = ACTIONS(4894),
    [anon_sym_fixed] = ACTIONS(4894),
    [anon_sym_internal] = ACTIONS(4894),
    [anon_sym_new] = ACTIONS(4894),
    [anon_sym_override] = ACTIONS(4894),
    [anon_sym_partial] = ACTIONS(4894),
    [anon_sym_private] = ACTIONS(4894),
    [anon_sym_protected] = ACTIONS(4894),
    [anon_sym_public] = ACTIONS(4894),
    [anon_sym_readonly] = ACTIONS(4894),
    [anon_sym_required] = ACTIONS(4894),
    [anon_sym_sealed] = ACTIONS(4894),
    [anon_sym_virtual] = ACTIONS(4894),
    [anon_sym_volatile] = ACTIONS(4894),
    [anon_sym_where] = ACTIONS(4894),
    [anon_sym_notnull] = ACTIONS(4894),
    [anon_sym_unmanaged] = ACTIONS(4894),
    [anon_sym_TILDE] = ACTIONS(4896),
    [anon_sym_implicit] = ACTIONS(4894),
    [anon_sym_explicit] = ACTIONS(4894),
    [anon_sym_scoped] = ACTIONS(4894),
    [anon_sym_var] = ACTIONS(4894),
    [sym_predefined_type] = ACTIONS(4894),
    [anon_sym_yield] = ACTIONS(4894),
    [anon_sym_when] = ACTIONS(4894),
    [anon_sym_from] = ACTIONS(4894),
    [anon_sym_into] = ACTIONS(4894),
    [anon_sym_join] = ACTIONS(4894),
    [anon_sym_on] = ACTIONS(4894),
    [anon_sym_equals] = ACTIONS(4894),
    [anon_sym_let] = ACTIONS(4894),
    [anon_sym_orderby] = ACTIONS(4894),
    [anon_sym_ascending] = ACTIONS(4894),
    [anon_sym_descending] = ACTIONS(4894),
    [anon_sym_group] = ACTIONS(4894),
    [anon_sym_by] = ACTIONS(4894),
    [anon_sym_select] = ACTIONS(4894),
    [aux_sym_preproc_if_token1] = ACTIONS(4896),
    [aux_sym_preproc_if_token3] = ACTIONS(4896),
    [aux_sym_preproc_else_token1] = ACTIONS(4896),
    [aux_sym_preproc_elif_token1] = ACTIONS(4896),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3302] = {
    [sym_preproc_region] = STATE(3302),
    [sym_preproc_endregion] = STATE(3302),
    [sym_preproc_line] = STATE(3302),
    [sym_preproc_pragma] = STATE(3302),
    [sym_preproc_nullable] = STATE(3302),
    [sym_preproc_error] = STATE(3302),
    [sym_preproc_warning] = STATE(3302),
    [sym_preproc_define] = STATE(3302),
    [sym_preproc_undef] = STATE(3302),
    [sym__identifier_token] = ACTIONS(4898),
    [anon_sym_extern] = ACTIONS(4898),
    [anon_sym_alias] = ACTIONS(4898),
    [anon_sym_global] = ACTIONS(4898),
    [anon_sym_using] = ACTIONS(4898),
    [anon_sym_unsafe] = ACTIONS(4898),
    [anon_sym_static] = ACTIONS(4898),
    [anon_sym_LBRACK] = ACTIONS(4900),
    [anon_sym_LPAREN] = ACTIONS(4900),
    [anon_sym_event] = ACTIONS(4898),
    [anon_sym_namespace] = ACTIONS(4898),
    [anon_sym_class] = ACTIONS(4898),
    [anon_sym_ref] = ACTIONS(4898),
    [anon_sym_struct] = ACTIONS(4898),
    [anon_sym_enum] = ACTIONS(4898),
    [anon_sym_RBRACE] = ACTIONS(4900),
    [anon_sym_interface] = ACTIONS(4898),
    [anon_sym_delegate] = ACTIONS(4898),
    [anon_sym_record] = ACTIONS(4898),
    [anon_sym_abstract] = ACTIONS(4898),
    [anon_sym_async] = ACTIONS(4898),
    [anon_sym_const] = ACTIONS(4898),
    [anon_sym_file] = ACTIONS(4898),
    [anon_sym_fixed] = ACTIONS(4898),
    [anon_sym_internal] = ACTIONS(4898),
    [anon_sym_new] = ACTIONS(4898),
    [anon_sym_override] = ACTIONS(4898),
    [anon_sym_partial] = ACTIONS(4898),
    [anon_sym_private] = ACTIONS(4898),
    [anon_sym_protected] = ACTIONS(4898),
    [anon_sym_public] = ACTIONS(4898),
    [anon_sym_readonly] = ACTIONS(4898),
    [anon_sym_required] = ACTIONS(4898),
    [anon_sym_sealed] = ACTIONS(4898),
    [anon_sym_virtual] = ACTIONS(4898),
    [anon_sym_volatile] = ACTIONS(4898),
    [anon_sym_where] = ACTIONS(4898),
    [anon_sym_notnull] = ACTIONS(4898),
    [anon_sym_unmanaged] = ACTIONS(4898),
    [anon_sym_TILDE] = ACTIONS(4900),
    [anon_sym_implicit] = ACTIONS(4898),
    [anon_sym_explicit] = ACTIONS(4898),
    [anon_sym_scoped] = ACTIONS(4898),
    [anon_sym_var] = ACTIONS(4898),
    [sym_predefined_type] = ACTIONS(4898),
    [anon_sym_yield] = ACTIONS(4898),
    [anon_sym_when] = ACTIONS(4898),
    [anon_sym_from] = ACTIONS(4898),
    [anon_sym_into] = ACTIONS(4898),
    [anon_sym_join] = ACTIONS(4898),
    [anon_sym_on] = ACTIONS(4898),
    [anon_sym_equals] = ACTIONS(4898),
    [anon_sym_let] = ACTIONS(4898),
    [anon_sym_orderby] = ACTIONS(4898),
    [anon_sym_ascending] = ACTIONS(4898),
    [anon_sym_descending] = ACTIONS(4898),
    [anon_sym_group] = ACTIONS(4898),
    [anon_sym_by] = ACTIONS(4898),
    [anon_sym_select] = ACTIONS(4898),
    [aux_sym_preproc_if_token1] = ACTIONS(4900),
    [aux_sym_preproc_if_token3] = ACTIONS(4900),
    [aux_sym_preproc_else_token1] = ACTIONS(4900),
    [aux_sym_preproc_elif_token1] = ACTIONS(4900),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3303] = {
    [sym_preproc_region] = STATE(3303),
    [sym_preproc_endregion] = STATE(3303),
    [sym_preproc_line] = STATE(3303),
    [sym_preproc_pragma] = STATE(3303),
    [sym_preproc_nullable] = STATE(3303),
    [sym_preproc_error] = STATE(3303),
    [sym_preproc_warning] = STATE(3303),
    [sym_preproc_define] = STATE(3303),
    [sym_preproc_undef] = STATE(3303),
    [sym__identifier_token] = ACTIONS(4902),
    [anon_sym_extern] = ACTIONS(4902),
    [anon_sym_alias] = ACTIONS(4902),
    [anon_sym_global] = ACTIONS(4902),
    [anon_sym_using] = ACTIONS(4902),
    [anon_sym_unsafe] = ACTIONS(4902),
    [anon_sym_static] = ACTIONS(4902),
    [anon_sym_LBRACK] = ACTIONS(4904),
    [anon_sym_LPAREN] = ACTIONS(4904),
    [anon_sym_event] = ACTIONS(4902),
    [anon_sym_namespace] = ACTIONS(4902),
    [anon_sym_class] = ACTIONS(4902),
    [anon_sym_ref] = ACTIONS(4902),
    [anon_sym_struct] = ACTIONS(4902),
    [anon_sym_enum] = ACTIONS(4902),
    [anon_sym_RBRACE] = ACTIONS(4904),
    [anon_sym_interface] = ACTIONS(4902),
    [anon_sym_delegate] = ACTIONS(4902),
    [anon_sym_record] = ACTIONS(4902),
    [anon_sym_abstract] = ACTIONS(4902),
    [anon_sym_async] = ACTIONS(4902),
    [anon_sym_const] = ACTIONS(4902),
    [anon_sym_file] = ACTIONS(4902),
    [anon_sym_fixed] = ACTIONS(4902),
    [anon_sym_internal] = ACTIONS(4902),
    [anon_sym_new] = ACTIONS(4902),
    [anon_sym_override] = ACTIONS(4902),
    [anon_sym_partial] = ACTIONS(4902),
    [anon_sym_private] = ACTIONS(4902),
    [anon_sym_protected] = ACTIONS(4902),
    [anon_sym_public] = ACTIONS(4902),
    [anon_sym_readonly] = ACTIONS(4902),
    [anon_sym_required] = ACTIONS(4902),
    [anon_sym_sealed] = ACTIONS(4902),
    [anon_sym_virtual] = ACTIONS(4902),
    [anon_sym_volatile] = ACTIONS(4902),
    [anon_sym_where] = ACTIONS(4902),
    [anon_sym_notnull] = ACTIONS(4902),
    [anon_sym_unmanaged] = ACTIONS(4902),
    [anon_sym_TILDE] = ACTIONS(4904),
    [anon_sym_implicit] = ACTIONS(4902),
    [anon_sym_explicit] = ACTIONS(4902),
    [anon_sym_scoped] = ACTIONS(4902),
    [anon_sym_var] = ACTIONS(4902),
    [sym_predefined_type] = ACTIONS(4902),
    [anon_sym_yield] = ACTIONS(4902),
    [anon_sym_when] = ACTIONS(4902),
    [anon_sym_from] = ACTIONS(4902),
    [anon_sym_into] = ACTIONS(4902),
    [anon_sym_join] = ACTIONS(4902),
    [anon_sym_on] = ACTIONS(4902),
    [anon_sym_equals] = ACTIONS(4902),
    [anon_sym_let] = ACTIONS(4902),
    [anon_sym_orderby] = ACTIONS(4902),
    [anon_sym_ascending] = ACTIONS(4902),
    [anon_sym_descending] = ACTIONS(4902),
    [anon_sym_group] = ACTIONS(4902),
    [anon_sym_by] = ACTIONS(4902),
    [anon_sym_select] = ACTIONS(4902),
    [aux_sym_preproc_if_token1] = ACTIONS(4904),
    [aux_sym_preproc_if_token3] = ACTIONS(4904),
    [aux_sym_preproc_else_token1] = ACTIONS(4904),
    [aux_sym_preproc_elif_token1] = ACTIONS(4904),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3304] = {
    [sym_preproc_region] = STATE(3304),
    [sym_preproc_endregion] = STATE(3304),
    [sym_preproc_line] = STATE(3304),
    [sym_preproc_pragma] = STATE(3304),
    [sym_preproc_nullable] = STATE(3304),
    [sym_preproc_error] = STATE(3304),
    [sym_preproc_warning] = STATE(3304),
    [sym_preproc_define] = STATE(3304),
    [sym_preproc_undef] = STATE(3304),
    [sym__identifier_token] = ACTIONS(4906),
    [anon_sym_extern] = ACTIONS(4906),
    [anon_sym_alias] = ACTIONS(4906),
    [anon_sym_global] = ACTIONS(4906),
    [anon_sym_using] = ACTIONS(4906),
    [anon_sym_unsafe] = ACTIONS(4906),
    [anon_sym_static] = ACTIONS(4906),
    [anon_sym_LBRACK] = ACTIONS(4908),
    [anon_sym_LPAREN] = ACTIONS(4908),
    [anon_sym_event] = ACTIONS(4906),
    [anon_sym_namespace] = ACTIONS(4906),
    [anon_sym_class] = ACTIONS(4906),
    [anon_sym_ref] = ACTIONS(4906),
    [anon_sym_struct] = ACTIONS(4906),
    [anon_sym_enum] = ACTIONS(4906),
    [anon_sym_RBRACE] = ACTIONS(4908),
    [anon_sym_interface] = ACTIONS(4906),
    [anon_sym_delegate] = ACTIONS(4906),
    [anon_sym_record] = ACTIONS(4906),
    [anon_sym_abstract] = ACTIONS(4906),
    [anon_sym_async] = ACTIONS(4906),
    [anon_sym_const] = ACTIONS(4906),
    [anon_sym_file] = ACTIONS(4906),
    [anon_sym_fixed] = ACTIONS(4906),
    [anon_sym_internal] = ACTIONS(4906),
    [anon_sym_new] = ACTIONS(4906),
    [anon_sym_override] = ACTIONS(4906),
    [anon_sym_partial] = ACTIONS(4906),
    [anon_sym_private] = ACTIONS(4906),
    [anon_sym_protected] = ACTIONS(4906),
    [anon_sym_public] = ACTIONS(4906),
    [anon_sym_readonly] = ACTIONS(4906),
    [anon_sym_required] = ACTIONS(4906),
    [anon_sym_sealed] = ACTIONS(4906),
    [anon_sym_virtual] = ACTIONS(4906),
    [anon_sym_volatile] = ACTIONS(4906),
    [anon_sym_where] = ACTIONS(4906),
    [anon_sym_notnull] = ACTIONS(4906),
    [anon_sym_unmanaged] = ACTIONS(4906),
    [anon_sym_TILDE] = ACTIONS(4908),
    [anon_sym_implicit] = ACTIONS(4906),
    [anon_sym_explicit] = ACTIONS(4906),
    [anon_sym_scoped] = ACTIONS(4906),
    [anon_sym_var] = ACTIONS(4906),
    [sym_predefined_type] = ACTIONS(4906),
    [anon_sym_yield] = ACTIONS(4906),
    [anon_sym_when] = ACTIONS(4906),
    [anon_sym_from] = ACTIONS(4906),
    [anon_sym_into] = ACTIONS(4906),
    [anon_sym_join] = ACTIONS(4906),
    [anon_sym_on] = ACTIONS(4906),
    [anon_sym_equals] = ACTIONS(4906),
    [anon_sym_let] = ACTIONS(4906),
    [anon_sym_orderby] = ACTIONS(4906),
    [anon_sym_ascending] = ACTIONS(4906),
    [anon_sym_descending] = ACTIONS(4906),
    [anon_sym_group] = ACTIONS(4906),
    [anon_sym_by] = ACTIONS(4906),
    [anon_sym_select] = ACTIONS(4906),
    [aux_sym_preproc_if_token1] = ACTIONS(4908),
    [aux_sym_preproc_if_token3] = ACTIONS(4908),
    [aux_sym_preproc_else_token1] = ACTIONS(4908),
    [aux_sym_preproc_elif_token1] = ACTIONS(4908),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3305] = {
    [sym_preproc_region] = STATE(3305),
    [sym_preproc_endregion] = STATE(3305),
    [sym_preproc_line] = STATE(3305),
    [sym_preproc_pragma] = STATE(3305),
    [sym_preproc_nullable] = STATE(3305),
    [sym_preproc_error] = STATE(3305),
    [sym_preproc_warning] = STATE(3305),
    [sym_preproc_define] = STATE(3305),
    [sym_preproc_undef] = STATE(3305),
    [sym__identifier_token] = ACTIONS(4910),
    [anon_sym_extern] = ACTIONS(4910),
    [anon_sym_alias] = ACTIONS(4910),
    [anon_sym_global] = ACTIONS(4910),
    [anon_sym_using] = ACTIONS(4910),
    [anon_sym_unsafe] = ACTIONS(4910),
    [anon_sym_static] = ACTIONS(4910),
    [anon_sym_LBRACK] = ACTIONS(4912),
    [anon_sym_LPAREN] = ACTIONS(4912),
    [anon_sym_event] = ACTIONS(4910),
    [anon_sym_namespace] = ACTIONS(4910),
    [anon_sym_class] = ACTIONS(4910),
    [anon_sym_ref] = ACTIONS(4910),
    [anon_sym_struct] = ACTIONS(4910),
    [anon_sym_enum] = ACTIONS(4910),
    [anon_sym_RBRACE] = ACTIONS(4912),
    [anon_sym_interface] = ACTIONS(4910),
    [anon_sym_delegate] = ACTIONS(4910),
    [anon_sym_record] = ACTIONS(4910),
    [anon_sym_abstract] = ACTIONS(4910),
    [anon_sym_async] = ACTIONS(4910),
    [anon_sym_const] = ACTIONS(4910),
    [anon_sym_file] = ACTIONS(4910),
    [anon_sym_fixed] = ACTIONS(4910),
    [anon_sym_internal] = ACTIONS(4910),
    [anon_sym_new] = ACTIONS(4910),
    [anon_sym_override] = ACTIONS(4910),
    [anon_sym_partial] = ACTIONS(4910),
    [anon_sym_private] = ACTIONS(4910),
    [anon_sym_protected] = ACTIONS(4910),
    [anon_sym_public] = ACTIONS(4910),
    [anon_sym_readonly] = ACTIONS(4910),
    [anon_sym_required] = ACTIONS(4910),
    [anon_sym_sealed] = ACTIONS(4910),
    [anon_sym_virtual] = ACTIONS(4910),
    [anon_sym_volatile] = ACTIONS(4910),
    [anon_sym_where] = ACTIONS(4910),
    [anon_sym_notnull] = ACTIONS(4910),
    [anon_sym_unmanaged] = ACTIONS(4910),
    [anon_sym_TILDE] = ACTIONS(4912),
    [anon_sym_implicit] = ACTIONS(4910),
    [anon_sym_explicit] = ACTIONS(4910),
    [anon_sym_scoped] = ACTIONS(4910),
    [anon_sym_var] = ACTIONS(4910),
    [sym_predefined_type] = ACTIONS(4910),
    [anon_sym_yield] = ACTIONS(4910),
    [anon_sym_when] = ACTIONS(4910),
    [anon_sym_from] = ACTIONS(4910),
    [anon_sym_into] = ACTIONS(4910),
    [anon_sym_join] = ACTIONS(4910),
    [anon_sym_on] = ACTIONS(4910),
    [anon_sym_equals] = ACTIONS(4910),
    [anon_sym_let] = ACTIONS(4910),
    [anon_sym_orderby] = ACTIONS(4910),
    [anon_sym_ascending] = ACTIONS(4910),
    [anon_sym_descending] = ACTIONS(4910),
    [anon_sym_group] = ACTIONS(4910),
    [anon_sym_by] = ACTIONS(4910),
    [anon_sym_select] = ACTIONS(4910),
    [aux_sym_preproc_if_token1] = ACTIONS(4912),
    [aux_sym_preproc_if_token3] = ACTIONS(4912),
    [aux_sym_preproc_else_token1] = ACTIONS(4912),
    [aux_sym_preproc_elif_token1] = ACTIONS(4912),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3306] = {
    [sym_preproc_region] = STATE(3306),
    [sym_preproc_endregion] = STATE(3306),
    [sym_preproc_line] = STATE(3306),
    [sym_preproc_pragma] = STATE(3306),
    [sym_preproc_nullable] = STATE(3306),
    [sym_preproc_error] = STATE(3306),
    [sym_preproc_warning] = STATE(3306),
    [sym_preproc_define] = STATE(3306),
    [sym_preproc_undef] = STATE(3306),
    [sym__identifier_token] = ACTIONS(4914),
    [anon_sym_extern] = ACTIONS(4914),
    [anon_sym_alias] = ACTIONS(4914),
    [anon_sym_global] = ACTIONS(4914),
    [anon_sym_using] = ACTIONS(4914),
    [anon_sym_unsafe] = ACTIONS(4914),
    [anon_sym_static] = ACTIONS(4914),
    [anon_sym_LBRACK] = ACTIONS(4916),
    [anon_sym_LPAREN] = ACTIONS(4916),
    [anon_sym_event] = ACTIONS(4914),
    [anon_sym_namespace] = ACTIONS(4914),
    [anon_sym_class] = ACTIONS(4914),
    [anon_sym_ref] = ACTIONS(4914),
    [anon_sym_struct] = ACTIONS(4914),
    [anon_sym_enum] = ACTIONS(4914),
    [anon_sym_RBRACE] = ACTIONS(4916),
    [anon_sym_interface] = ACTIONS(4914),
    [anon_sym_delegate] = ACTIONS(4914),
    [anon_sym_record] = ACTIONS(4914),
    [anon_sym_abstract] = ACTIONS(4914),
    [anon_sym_async] = ACTIONS(4914),
    [anon_sym_const] = ACTIONS(4914),
    [anon_sym_file] = ACTIONS(4914),
    [anon_sym_fixed] = ACTIONS(4914),
    [anon_sym_internal] = ACTIONS(4914),
    [anon_sym_new] = ACTIONS(4914),
    [anon_sym_override] = ACTIONS(4914),
    [anon_sym_partial] = ACTIONS(4914),
    [anon_sym_private] = ACTIONS(4914),
    [anon_sym_protected] = ACTIONS(4914),
    [anon_sym_public] = ACTIONS(4914),
    [anon_sym_readonly] = ACTIONS(4914),
    [anon_sym_required] = ACTIONS(4914),
    [anon_sym_sealed] = ACTIONS(4914),
    [anon_sym_virtual] = ACTIONS(4914),
    [anon_sym_volatile] = ACTIONS(4914),
    [anon_sym_where] = ACTIONS(4914),
    [anon_sym_notnull] = ACTIONS(4914),
    [anon_sym_unmanaged] = ACTIONS(4914),
    [anon_sym_TILDE] = ACTIONS(4916),
    [anon_sym_implicit] = ACTIONS(4914),
    [anon_sym_explicit] = ACTIONS(4914),
    [anon_sym_scoped] = ACTIONS(4914),
    [anon_sym_var] = ACTIONS(4914),
    [sym_predefined_type] = ACTIONS(4914),
    [anon_sym_yield] = ACTIONS(4914),
    [anon_sym_when] = ACTIONS(4914),
    [anon_sym_from] = ACTIONS(4914),
    [anon_sym_into] = ACTIONS(4914),
    [anon_sym_join] = ACTIONS(4914),
    [anon_sym_on] = ACTIONS(4914),
    [anon_sym_equals] = ACTIONS(4914),
    [anon_sym_let] = ACTIONS(4914),
    [anon_sym_orderby] = ACTIONS(4914),
    [anon_sym_ascending] = ACTIONS(4914),
    [anon_sym_descending] = ACTIONS(4914),
    [anon_sym_group] = ACTIONS(4914),
    [anon_sym_by] = ACTIONS(4914),
    [anon_sym_select] = ACTIONS(4914),
    [aux_sym_preproc_if_token1] = ACTIONS(4916),
    [aux_sym_preproc_if_token3] = ACTIONS(4916),
    [aux_sym_preproc_else_token1] = ACTIONS(4916),
    [aux_sym_preproc_elif_token1] = ACTIONS(4916),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3307] = {
    [sym_preproc_region] = STATE(3307),
    [sym_preproc_endregion] = STATE(3307),
    [sym_preproc_line] = STATE(3307),
    [sym_preproc_pragma] = STATE(3307),
    [sym_preproc_nullable] = STATE(3307),
    [sym_preproc_error] = STATE(3307),
    [sym_preproc_warning] = STATE(3307),
    [sym_preproc_define] = STATE(3307),
    [sym_preproc_undef] = STATE(3307),
    [sym__identifier_token] = ACTIONS(4918),
    [anon_sym_extern] = ACTIONS(4918),
    [anon_sym_alias] = ACTIONS(4918),
    [anon_sym_global] = ACTIONS(4918),
    [anon_sym_using] = ACTIONS(4918),
    [anon_sym_unsafe] = ACTIONS(4918),
    [anon_sym_static] = ACTIONS(4918),
    [anon_sym_LBRACK] = ACTIONS(4920),
    [anon_sym_LPAREN] = ACTIONS(4920),
    [anon_sym_event] = ACTIONS(4918),
    [anon_sym_namespace] = ACTIONS(4918),
    [anon_sym_class] = ACTIONS(4918),
    [anon_sym_ref] = ACTIONS(4918),
    [anon_sym_struct] = ACTIONS(4918),
    [anon_sym_enum] = ACTIONS(4918),
    [anon_sym_RBRACE] = ACTIONS(4920),
    [anon_sym_interface] = ACTIONS(4918),
    [anon_sym_delegate] = ACTIONS(4918),
    [anon_sym_record] = ACTIONS(4918),
    [anon_sym_abstract] = ACTIONS(4918),
    [anon_sym_async] = ACTIONS(4918),
    [anon_sym_const] = ACTIONS(4918),
    [anon_sym_file] = ACTIONS(4918),
    [anon_sym_fixed] = ACTIONS(4918),
    [anon_sym_internal] = ACTIONS(4918),
    [anon_sym_new] = ACTIONS(4918),
    [anon_sym_override] = ACTIONS(4918),
    [anon_sym_partial] = ACTIONS(4918),
    [anon_sym_private] = ACTIONS(4918),
    [anon_sym_protected] = ACTIONS(4918),
    [anon_sym_public] = ACTIONS(4918),
    [anon_sym_readonly] = ACTIONS(4918),
    [anon_sym_required] = ACTIONS(4918),
    [anon_sym_sealed] = ACTIONS(4918),
    [anon_sym_virtual] = ACTIONS(4918),
    [anon_sym_volatile] = ACTIONS(4918),
    [anon_sym_where] = ACTIONS(4918),
    [anon_sym_notnull] = ACTIONS(4918),
    [anon_sym_unmanaged] = ACTIONS(4918),
    [anon_sym_TILDE] = ACTIONS(4920),
    [anon_sym_implicit] = ACTIONS(4918),
    [anon_sym_explicit] = ACTIONS(4918),
    [anon_sym_scoped] = ACTIONS(4918),
    [anon_sym_var] = ACTIONS(4918),
    [sym_predefined_type] = ACTIONS(4918),
    [anon_sym_yield] = ACTIONS(4918),
    [anon_sym_when] = ACTIONS(4918),
    [anon_sym_from] = ACTIONS(4918),
    [anon_sym_into] = ACTIONS(4918),
    [anon_sym_join] = ACTIONS(4918),
    [anon_sym_on] = ACTIONS(4918),
    [anon_sym_equals] = ACTIONS(4918),
    [anon_sym_let] = ACTIONS(4918),
    [anon_sym_orderby] = ACTIONS(4918),
    [anon_sym_ascending] = ACTIONS(4918),
    [anon_sym_descending] = ACTIONS(4918),
    [anon_sym_group] = ACTIONS(4918),
    [anon_sym_by] = ACTIONS(4918),
    [anon_sym_select] = ACTIONS(4918),
    [aux_sym_preproc_if_token1] = ACTIONS(4920),
    [aux_sym_preproc_if_token3] = ACTIONS(4920),
    [aux_sym_preproc_else_token1] = ACTIONS(4920),
    [aux_sym_preproc_elif_token1] = ACTIONS(4920),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3308] = {
    [sym_preproc_region] = STATE(3308),
    [sym_preproc_endregion] = STATE(3308),
    [sym_preproc_line] = STATE(3308),
    [sym_preproc_pragma] = STATE(3308),
    [sym_preproc_nullable] = STATE(3308),
    [sym_preproc_error] = STATE(3308),
    [sym_preproc_warning] = STATE(3308),
    [sym_preproc_define] = STATE(3308),
    [sym_preproc_undef] = STATE(3308),
    [sym__identifier_token] = ACTIONS(4922),
    [anon_sym_extern] = ACTIONS(4922),
    [anon_sym_alias] = ACTIONS(4922),
    [anon_sym_global] = ACTIONS(4922),
    [anon_sym_using] = ACTIONS(4922),
    [anon_sym_unsafe] = ACTIONS(4922),
    [anon_sym_static] = ACTIONS(4922),
    [anon_sym_LBRACK] = ACTIONS(4924),
    [anon_sym_LPAREN] = ACTIONS(4924),
    [anon_sym_event] = ACTIONS(4922),
    [anon_sym_namespace] = ACTIONS(4922),
    [anon_sym_class] = ACTIONS(4922),
    [anon_sym_ref] = ACTIONS(4922),
    [anon_sym_struct] = ACTIONS(4922),
    [anon_sym_enum] = ACTIONS(4922),
    [anon_sym_RBRACE] = ACTIONS(4924),
    [anon_sym_interface] = ACTIONS(4922),
    [anon_sym_delegate] = ACTIONS(4922),
    [anon_sym_record] = ACTIONS(4922),
    [anon_sym_abstract] = ACTIONS(4922),
    [anon_sym_async] = ACTIONS(4922),
    [anon_sym_const] = ACTIONS(4922),
    [anon_sym_file] = ACTIONS(4922),
    [anon_sym_fixed] = ACTIONS(4922),
    [anon_sym_internal] = ACTIONS(4922),
    [anon_sym_new] = ACTIONS(4922),
    [anon_sym_override] = ACTIONS(4922),
    [anon_sym_partial] = ACTIONS(4922),
    [anon_sym_private] = ACTIONS(4922),
    [anon_sym_protected] = ACTIONS(4922),
    [anon_sym_public] = ACTIONS(4922),
    [anon_sym_readonly] = ACTIONS(4922),
    [anon_sym_required] = ACTIONS(4922),
    [anon_sym_sealed] = ACTIONS(4922),
    [anon_sym_virtual] = ACTIONS(4922),
    [anon_sym_volatile] = ACTIONS(4922),
    [anon_sym_where] = ACTIONS(4922),
    [anon_sym_notnull] = ACTIONS(4922),
    [anon_sym_unmanaged] = ACTIONS(4922),
    [anon_sym_TILDE] = ACTIONS(4924),
    [anon_sym_implicit] = ACTIONS(4922),
    [anon_sym_explicit] = ACTIONS(4922),
    [anon_sym_scoped] = ACTIONS(4922),
    [anon_sym_var] = ACTIONS(4922),
    [sym_predefined_type] = ACTIONS(4922),
    [anon_sym_yield] = ACTIONS(4922),
    [anon_sym_when] = ACTIONS(4922),
    [anon_sym_from] = ACTIONS(4922),
    [anon_sym_into] = ACTIONS(4922),
    [anon_sym_join] = ACTIONS(4922),
    [anon_sym_on] = ACTIONS(4922),
    [anon_sym_equals] = ACTIONS(4922),
    [anon_sym_let] = ACTIONS(4922),
    [anon_sym_orderby] = ACTIONS(4922),
    [anon_sym_ascending] = ACTIONS(4922),
    [anon_sym_descending] = ACTIONS(4922),
    [anon_sym_group] = ACTIONS(4922),
    [anon_sym_by] = ACTIONS(4922),
    [anon_sym_select] = ACTIONS(4922),
    [aux_sym_preproc_if_token1] = ACTIONS(4924),
    [aux_sym_preproc_if_token3] = ACTIONS(4924),
    [aux_sym_preproc_else_token1] = ACTIONS(4924),
    [aux_sym_preproc_elif_token1] = ACTIONS(4924),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3309] = {
    [sym_preproc_region] = STATE(3309),
    [sym_preproc_endregion] = STATE(3309),
    [sym_preproc_line] = STATE(3309),
    [sym_preproc_pragma] = STATE(3309),
    [sym_preproc_nullable] = STATE(3309),
    [sym_preproc_error] = STATE(3309),
    [sym_preproc_warning] = STATE(3309),
    [sym_preproc_define] = STATE(3309),
    [sym_preproc_undef] = STATE(3309),
    [sym__identifier_token] = ACTIONS(4926),
    [anon_sym_extern] = ACTIONS(4926),
    [anon_sym_alias] = ACTIONS(4926),
    [anon_sym_global] = ACTIONS(4926),
    [anon_sym_using] = ACTIONS(4926),
    [anon_sym_unsafe] = ACTIONS(4926),
    [anon_sym_static] = ACTIONS(4926),
    [anon_sym_LBRACK] = ACTIONS(4928),
    [anon_sym_LPAREN] = ACTIONS(4928),
    [anon_sym_event] = ACTIONS(4926),
    [anon_sym_namespace] = ACTIONS(4926),
    [anon_sym_class] = ACTIONS(4926),
    [anon_sym_ref] = ACTIONS(4926),
    [anon_sym_struct] = ACTIONS(4926),
    [anon_sym_enum] = ACTIONS(4926),
    [anon_sym_RBRACE] = ACTIONS(4928),
    [anon_sym_interface] = ACTIONS(4926),
    [anon_sym_delegate] = ACTIONS(4926),
    [anon_sym_record] = ACTIONS(4926),
    [anon_sym_abstract] = ACTIONS(4926),
    [anon_sym_async] = ACTIONS(4926),
    [anon_sym_const] = ACTIONS(4926),
    [anon_sym_file] = ACTIONS(4926),
    [anon_sym_fixed] = ACTIONS(4926),
    [anon_sym_internal] = ACTIONS(4926),
    [anon_sym_new] = ACTIONS(4926),
    [anon_sym_override] = ACTIONS(4926),
    [anon_sym_partial] = ACTIONS(4926),
    [anon_sym_private] = ACTIONS(4926),
    [anon_sym_protected] = ACTIONS(4926),
    [anon_sym_public] = ACTIONS(4926),
    [anon_sym_readonly] = ACTIONS(4926),
    [anon_sym_required] = ACTIONS(4926),
    [anon_sym_sealed] = ACTIONS(4926),
    [anon_sym_virtual] = ACTIONS(4926),
    [anon_sym_volatile] = ACTIONS(4926),
    [anon_sym_where] = ACTIONS(4926),
    [anon_sym_notnull] = ACTIONS(4926),
    [anon_sym_unmanaged] = ACTIONS(4926),
    [anon_sym_TILDE] = ACTIONS(4928),
    [anon_sym_implicit] = ACTIONS(4926),
    [anon_sym_explicit] = ACTIONS(4926),
    [anon_sym_scoped] = ACTIONS(4926),
    [anon_sym_var] = ACTIONS(4926),
    [sym_predefined_type] = ACTIONS(4926),
    [anon_sym_yield] = ACTIONS(4926),
    [anon_sym_when] = ACTIONS(4926),
    [anon_sym_from] = ACTIONS(4926),
    [anon_sym_into] = ACTIONS(4926),
    [anon_sym_join] = ACTIONS(4926),
    [anon_sym_on] = ACTIONS(4926),
    [anon_sym_equals] = ACTIONS(4926),
    [anon_sym_let] = ACTIONS(4926),
    [anon_sym_orderby] = ACTIONS(4926),
    [anon_sym_ascending] = ACTIONS(4926),
    [anon_sym_descending] = ACTIONS(4926),
    [anon_sym_group] = ACTIONS(4926),
    [anon_sym_by] = ACTIONS(4926),
    [anon_sym_select] = ACTIONS(4926),
    [aux_sym_preproc_if_token1] = ACTIONS(4928),
    [aux_sym_preproc_if_token3] = ACTIONS(4928),
    [aux_sym_preproc_else_token1] = ACTIONS(4928),
    [aux_sym_preproc_elif_token1] = ACTIONS(4928),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3310] = {
    [sym_preproc_region] = STATE(3310),
    [sym_preproc_endregion] = STATE(3310),
    [sym_preproc_line] = STATE(3310),
    [sym_preproc_pragma] = STATE(3310),
    [sym_preproc_nullable] = STATE(3310),
    [sym_preproc_error] = STATE(3310),
    [sym_preproc_warning] = STATE(3310),
    [sym_preproc_define] = STATE(3310),
    [sym_preproc_undef] = STATE(3310),
    [sym__identifier_token] = ACTIONS(4930),
    [anon_sym_extern] = ACTIONS(4930),
    [anon_sym_alias] = ACTIONS(4930),
    [anon_sym_global] = ACTIONS(4930),
    [anon_sym_using] = ACTIONS(4930),
    [anon_sym_unsafe] = ACTIONS(4930),
    [anon_sym_static] = ACTIONS(4930),
    [anon_sym_LBRACK] = ACTIONS(4932),
    [anon_sym_LPAREN] = ACTIONS(4932),
    [anon_sym_event] = ACTIONS(4930),
    [anon_sym_namespace] = ACTIONS(4930),
    [anon_sym_class] = ACTIONS(4930),
    [anon_sym_ref] = ACTIONS(4930),
    [anon_sym_struct] = ACTIONS(4930),
    [anon_sym_enum] = ACTIONS(4930),
    [anon_sym_RBRACE] = ACTIONS(4932),
    [anon_sym_interface] = ACTIONS(4930),
    [anon_sym_delegate] = ACTIONS(4930),
    [anon_sym_record] = ACTIONS(4930),
    [anon_sym_abstract] = ACTIONS(4930),
    [anon_sym_async] = ACTIONS(4930),
    [anon_sym_const] = ACTIONS(4930),
    [anon_sym_file] = ACTIONS(4930),
    [anon_sym_fixed] = ACTIONS(4930),
    [anon_sym_internal] = ACTIONS(4930),
    [anon_sym_new] = ACTIONS(4930),
    [anon_sym_override] = ACTIONS(4930),
    [anon_sym_partial] = ACTIONS(4930),
    [anon_sym_private] = ACTIONS(4930),
    [anon_sym_protected] = ACTIONS(4930),
    [anon_sym_public] = ACTIONS(4930),
    [anon_sym_readonly] = ACTIONS(4930),
    [anon_sym_required] = ACTIONS(4930),
    [anon_sym_sealed] = ACTIONS(4930),
    [anon_sym_virtual] = ACTIONS(4930),
    [anon_sym_volatile] = ACTIONS(4930),
    [anon_sym_where] = ACTIONS(4930),
    [anon_sym_notnull] = ACTIONS(4930),
    [anon_sym_unmanaged] = ACTIONS(4930),
    [anon_sym_TILDE] = ACTIONS(4932),
    [anon_sym_implicit] = ACTIONS(4930),
    [anon_sym_explicit] = ACTIONS(4930),
    [anon_sym_scoped] = ACTIONS(4930),
    [anon_sym_var] = ACTIONS(4930),
    [sym_predefined_type] = ACTIONS(4930),
    [anon_sym_yield] = ACTIONS(4930),
    [anon_sym_when] = ACTIONS(4930),
    [anon_sym_from] = ACTIONS(4930),
    [anon_sym_into] = ACTIONS(4930),
    [anon_sym_join] = ACTIONS(4930),
    [anon_sym_on] = ACTIONS(4930),
    [anon_sym_equals] = ACTIONS(4930),
    [anon_sym_let] = ACTIONS(4930),
    [anon_sym_orderby] = ACTIONS(4930),
    [anon_sym_ascending] = ACTIONS(4930),
    [anon_sym_descending] = ACTIONS(4930),
    [anon_sym_group] = ACTIONS(4930),
    [anon_sym_by] = ACTIONS(4930),
    [anon_sym_select] = ACTIONS(4930),
    [aux_sym_preproc_if_token1] = ACTIONS(4932),
    [aux_sym_preproc_if_token3] = ACTIONS(4932),
    [aux_sym_preproc_else_token1] = ACTIONS(4932),
    [aux_sym_preproc_elif_token1] = ACTIONS(4932),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3311] = {
    [sym_preproc_region] = STATE(3311),
    [sym_preproc_endregion] = STATE(3311),
    [sym_preproc_line] = STATE(3311),
    [sym_preproc_pragma] = STATE(3311),
    [sym_preproc_nullable] = STATE(3311),
    [sym_preproc_error] = STATE(3311),
    [sym_preproc_warning] = STATE(3311),
    [sym_preproc_define] = STATE(3311),
    [sym_preproc_undef] = STATE(3311),
    [sym__identifier_token] = ACTIONS(4934),
    [anon_sym_extern] = ACTIONS(4934),
    [anon_sym_alias] = ACTIONS(4934),
    [anon_sym_global] = ACTIONS(4934),
    [anon_sym_using] = ACTIONS(4934),
    [anon_sym_unsafe] = ACTIONS(4934),
    [anon_sym_static] = ACTIONS(4934),
    [anon_sym_LBRACK] = ACTIONS(4936),
    [anon_sym_LPAREN] = ACTIONS(4936),
    [anon_sym_event] = ACTIONS(4934),
    [anon_sym_namespace] = ACTIONS(4934),
    [anon_sym_class] = ACTIONS(4934),
    [anon_sym_ref] = ACTIONS(4934),
    [anon_sym_struct] = ACTIONS(4934),
    [anon_sym_enum] = ACTIONS(4934),
    [anon_sym_RBRACE] = ACTIONS(4936),
    [anon_sym_interface] = ACTIONS(4934),
    [anon_sym_delegate] = ACTIONS(4934),
    [anon_sym_record] = ACTIONS(4934),
    [anon_sym_abstract] = ACTIONS(4934),
    [anon_sym_async] = ACTIONS(4934),
    [anon_sym_const] = ACTIONS(4934),
    [anon_sym_file] = ACTIONS(4934),
    [anon_sym_fixed] = ACTIONS(4934),
    [anon_sym_internal] = ACTIONS(4934),
    [anon_sym_new] = ACTIONS(4934),
    [anon_sym_override] = ACTIONS(4934),
    [anon_sym_partial] = ACTIONS(4934),
    [anon_sym_private] = ACTIONS(4934),
    [anon_sym_protected] = ACTIONS(4934),
    [anon_sym_public] = ACTIONS(4934),
    [anon_sym_readonly] = ACTIONS(4934),
    [anon_sym_required] = ACTIONS(4934),
    [anon_sym_sealed] = ACTIONS(4934),
    [anon_sym_virtual] = ACTIONS(4934),
    [anon_sym_volatile] = ACTIONS(4934),
    [anon_sym_where] = ACTIONS(4934),
    [anon_sym_notnull] = ACTIONS(4934),
    [anon_sym_unmanaged] = ACTIONS(4934),
    [anon_sym_TILDE] = ACTIONS(4936),
    [anon_sym_implicit] = ACTIONS(4934),
    [anon_sym_explicit] = ACTIONS(4934),
    [anon_sym_scoped] = ACTIONS(4934),
    [anon_sym_var] = ACTIONS(4934),
    [sym_predefined_type] = ACTIONS(4934),
    [anon_sym_yield] = ACTIONS(4934),
    [anon_sym_when] = ACTIONS(4934),
    [anon_sym_from] = ACTIONS(4934),
    [anon_sym_into] = ACTIONS(4934),
    [anon_sym_join] = ACTIONS(4934),
    [anon_sym_on] = ACTIONS(4934),
    [anon_sym_equals] = ACTIONS(4934),
    [anon_sym_let] = ACTIONS(4934),
    [anon_sym_orderby] = ACTIONS(4934),
    [anon_sym_ascending] = ACTIONS(4934),
    [anon_sym_descending] = ACTIONS(4934),
    [anon_sym_group] = ACTIONS(4934),
    [anon_sym_by] = ACTIONS(4934),
    [anon_sym_select] = ACTIONS(4934),
    [aux_sym_preproc_if_token1] = ACTIONS(4936),
    [aux_sym_preproc_if_token3] = ACTIONS(4936),
    [aux_sym_preproc_else_token1] = ACTIONS(4936),
    [aux_sym_preproc_elif_token1] = ACTIONS(4936),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3312] = {
    [sym_preproc_region] = STATE(3312),
    [sym_preproc_endregion] = STATE(3312),
    [sym_preproc_line] = STATE(3312),
    [sym_preproc_pragma] = STATE(3312),
    [sym_preproc_nullable] = STATE(3312),
    [sym_preproc_error] = STATE(3312),
    [sym_preproc_warning] = STATE(3312),
    [sym_preproc_define] = STATE(3312),
    [sym_preproc_undef] = STATE(3312),
    [sym__identifier_token] = ACTIONS(4938),
    [anon_sym_extern] = ACTIONS(4938),
    [anon_sym_alias] = ACTIONS(4938),
    [anon_sym_global] = ACTIONS(4938),
    [anon_sym_using] = ACTIONS(4938),
    [anon_sym_unsafe] = ACTIONS(4938),
    [anon_sym_static] = ACTIONS(4938),
    [anon_sym_LBRACK] = ACTIONS(4940),
    [anon_sym_LPAREN] = ACTIONS(4940),
    [anon_sym_event] = ACTIONS(4938),
    [anon_sym_namespace] = ACTIONS(4938),
    [anon_sym_class] = ACTIONS(4938),
    [anon_sym_ref] = ACTIONS(4938),
    [anon_sym_struct] = ACTIONS(4938),
    [anon_sym_enum] = ACTIONS(4938),
    [anon_sym_RBRACE] = ACTIONS(4940),
    [anon_sym_interface] = ACTIONS(4938),
    [anon_sym_delegate] = ACTIONS(4938),
    [anon_sym_record] = ACTIONS(4938),
    [anon_sym_abstract] = ACTIONS(4938),
    [anon_sym_async] = ACTIONS(4938),
    [anon_sym_const] = ACTIONS(4938),
    [anon_sym_file] = ACTIONS(4938),
    [anon_sym_fixed] = ACTIONS(4938),
    [anon_sym_internal] = ACTIONS(4938),
    [anon_sym_new] = ACTIONS(4938),
    [anon_sym_override] = ACTIONS(4938),
    [anon_sym_partial] = ACTIONS(4938),
    [anon_sym_private] = ACTIONS(4938),
    [anon_sym_protected] = ACTIONS(4938),
    [anon_sym_public] = ACTIONS(4938),
    [anon_sym_readonly] = ACTIONS(4938),
    [anon_sym_required] = ACTIONS(4938),
    [anon_sym_sealed] = ACTIONS(4938),
    [anon_sym_virtual] = ACTIONS(4938),
    [anon_sym_volatile] = ACTIONS(4938),
    [anon_sym_where] = ACTIONS(4938),
    [anon_sym_notnull] = ACTIONS(4938),
    [anon_sym_unmanaged] = ACTIONS(4938),
    [anon_sym_TILDE] = ACTIONS(4940),
    [anon_sym_implicit] = ACTIONS(4938),
    [anon_sym_explicit] = ACTIONS(4938),
    [anon_sym_scoped] = ACTIONS(4938),
    [anon_sym_var] = ACTIONS(4938),
    [sym_predefined_type] = ACTIONS(4938),
    [anon_sym_yield] = ACTIONS(4938),
    [anon_sym_when] = ACTIONS(4938),
    [anon_sym_from] = ACTIONS(4938),
    [anon_sym_into] = ACTIONS(4938),
    [anon_sym_join] = ACTIONS(4938),
    [anon_sym_on] = ACTIONS(4938),
    [anon_sym_equals] = ACTIONS(4938),
    [anon_sym_let] = ACTIONS(4938),
    [anon_sym_orderby] = ACTIONS(4938),
    [anon_sym_ascending] = ACTIONS(4938),
    [anon_sym_descending] = ACTIONS(4938),
    [anon_sym_group] = ACTIONS(4938),
    [anon_sym_by] = ACTIONS(4938),
    [anon_sym_select] = ACTIONS(4938),
    [aux_sym_preproc_if_token1] = ACTIONS(4940),
    [aux_sym_preproc_if_token3] = ACTIONS(4940),
    [aux_sym_preproc_else_token1] = ACTIONS(4940),
    [aux_sym_preproc_elif_token1] = ACTIONS(4940),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3313] = {
    [sym_preproc_region] = STATE(3313),
    [sym_preproc_endregion] = STATE(3313),
    [sym_preproc_line] = STATE(3313),
    [sym_preproc_pragma] = STATE(3313),
    [sym_preproc_nullable] = STATE(3313),
    [sym_preproc_error] = STATE(3313),
    [sym_preproc_warning] = STATE(3313),
    [sym_preproc_define] = STATE(3313),
    [sym_preproc_undef] = STATE(3313),
    [sym__identifier_token] = ACTIONS(4942),
    [anon_sym_extern] = ACTIONS(4942),
    [anon_sym_alias] = ACTIONS(4942),
    [anon_sym_global] = ACTIONS(4942),
    [anon_sym_using] = ACTIONS(4942),
    [anon_sym_unsafe] = ACTIONS(4942),
    [anon_sym_static] = ACTIONS(4942),
    [anon_sym_LBRACK] = ACTIONS(4944),
    [anon_sym_LPAREN] = ACTIONS(4944),
    [anon_sym_event] = ACTIONS(4942),
    [anon_sym_namespace] = ACTIONS(4942),
    [anon_sym_class] = ACTIONS(4942),
    [anon_sym_ref] = ACTIONS(4942),
    [anon_sym_struct] = ACTIONS(4942),
    [anon_sym_enum] = ACTIONS(4942),
    [anon_sym_RBRACE] = ACTIONS(4944),
    [anon_sym_interface] = ACTIONS(4942),
    [anon_sym_delegate] = ACTIONS(4942),
    [anon_sym_record] = ACTIONS(4942),
    [anon_sym_abstract] = ACTIONS(4942),
    [anon_sym_async] = ACTIONS(4942),
    [anon_sym_const] = ACTIONS(4942),
    [anon_sym_file] = ACTIONS(4942),
    [anon_sym_fixed] = ACTIONS(4942),
    [anon_sym_internal] = ACTIONS(4942),
    [anon_sym_new] = ACTIONS(4942),
    [anon_sym_override] = ACTIONS(4942),
    [anon_sym_partial] = ACTIONS(4942),
    [anon_sym_private] = ACTIONS(4942),
    [anon_sym_protected] = ACTIONS(4942),
    [anon_sym_public] = ACTIONS(4942),
    [anon_sym_readonly] = ACTIONS(4942),
    [anon_sym_required] = ACTIONS(4942),
    [anon_sym_sealed] = ACTIONS(4942),
    [anon_sym_virtual] = ACTIONS(4942),
    [anon_sym_volatile] = ACTIONS(4942),
    [anon_sym_where] = ACTIONS(4942),
    [anon_sym_notnull] = ACTIONS(4942),
    [anon_sym_unmanaged] = ACTIONS(4942),
    [anon_sym_TILDE] = ACTIONS(4944),
    [anon_sym_implicit] = ACTIONS(4942),
    [anon_sym_explicit] = ACTIONS(4942),
    [anon_sym_scoped] = ACTIONS(4942),
    [anon_sym_var] = ACTIONS(4942),
    [sym_predefined_type] = ACTIONS(4942),
    [anon_sym_yield] = ACTIONS(4942),
    [anon_sym_when] = ACTIONS(4942),
    [anon_sym_from] = ACTIONS(4942),
    [anon_sym_into] = ACTIONS(4942),
    [anon_sym_join] = ACTIONS(4942),
    [anon_sym_on] = ACTIONS(4942),
    [anon_sym_equals] = ACTIONS(4942),
    [anon_sym_let] = ACTIONS(4942),
    [anon_sym_orderby] = ACTIONS(4942),
    [anon_sym_ascending] = ACTIONS(4942),
    [anon_sym_descending] = ACTIONS(4942),
    [anon_sym_group] = ACTIONS(4942),
    [anon_sym_by] = ACTIONS(4942),
    [anon_sym_select] = ACTIONS(4942),
    [aux_sym_preproc_if_token1] = ACTIONS(4944),
    [aux_sym_preproc_if_token3] = ACTIONS(4944),
    [aux_sym_preproc_else_token1] = ACTIONS(4944),
    [aux_sym_preproc_elif_token1] = ACTIONS(4944),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3314] = {
    [sym_preproc_region] = STATE(3314),
    [sym_preproc_endregion] = STATE(3314),
    [sym_preproc_line] = STATE(3314),
    [sym_preproc_pragma] = STATE(3314),
    [sym_preproc_nullable] = STATE(3314),
    [sym_preproc_error] = STATE(3314),
    [sym_preproc_warning] = STATE(3314),
    [sym_preproc_define] = STATE(3314),
    [sym_preproc_undef] = STATE(3314),
    [sym__identifier_token] = ACTIONS(4946),
    [anon_sym_extern] = ACTIONS(4946),
    [anon_sym_alias] = ACTIONS(4946),
    [anon_sym_global] = ACTIONS(4946),
    [anon_sym_using] = ACTIONS(4946),
    [anon_sym_unsafe] = ACTIONS(4946),
    [anon_sym_static] = ACTIONS(4946),
    [anon_sym_LBRACK] = ACTIONS(4948),
    [anon_sym_LPAREN] = ACTIONS(4948),
    [anon_sym_event] = ACTIONS(4946),
    [anon_sym_namespace] = ACTIONS(4946),
    [anon_sym_class] = ACTIONS(4946),
    [anon_sym_ref] = ACTIONS(4946),
    [anon_sym_struct] = ACTIONS(4946),
    [anon_sym_enum] = ACTIONS(4946),
    [anon_sym_RBRACE] = ACTIONS(4948),
    [anon_sym_interface] = ACTIONS(4946),
    [anon_sym_delegate] = ACTIONS(4946),
    [anon_sym_record] = ACTIONS(4946),
    [anon_sym_abstract] = ACTIONS(4946),
    [anon_sym_async] = ACTIONS(4946),
    [anon_sym_const] = ACTIONS(4946),
    [anon_sym_file] = ACTIONS(4946),
    [anon_sym_fixed] = ACTIONS(4946),
    [anon_sym_internal] = ACTIONS(4946),
    [anon_sym_new] = ACTIONS(4946),
    [anon_sym_override] = ACTIONS(4946),
    [anon_sym_partial] = ACTIONS(4946),
    [anon_sym_private] = ACTIONS(4946),
    [anon_sym_protected] = ACTIONS(4946),
    [anon_sym_public] = ACTIONS(4946),
    [anon_sym_readonly] = ACTIONS(4946),
    [anon_sym_required] = ACTIONS(4946),
    [anon_sym_sealed] = ACTIONS(4946),
    [anon_sym_virtual] = ACTIONS(4946),
    [anon_sym_volatile] = ACTIONS(4946),
    [anon_sym_where] = ACTIONS(4946),
    [anon_sym_notnull] = ACTIONS(4946),
    [anon_sym_unmanaged] = ACTIONS(4946),
    [anon_sym_TILDE] = ACTIONS(4948),
    [anon_sym_implicit] = ACTIONS(4946),
    [anon_sym_explicit] = ACTIONS(4946),
    [anon_sym_scoped] = ACTIONS(4946),
    [anon_sym_var] = ACTIONS(4946),
    [sym_predefined_type] = ACTIONS(4946),
    [anon_sym_yield] = ACTIONS(4946),
    [anon_sym_when] = ACTIONS(4946),
    [anon_sym_from] = ACTIONS(4946),
    [anon_sym_into] = ACTIONS(4946),
    [anon_sym_join] = ACTIONS(4946),
    [anon_sym_on] = ACTIONS(4946),
    [anon_sym_equals] = ACTIONS(4946),
    [anon_sym_let] = ACTIONS(4946),
    [anon_sym_orderby] = ACTIONS(4946),
    [anon_sym_ascending] = ACTIONS(4946),
    [anon_sym_descending] = ACTIONS(4946),
    [anon_sym_group] = ACTIONS(4946),
    [anon_sym_by] = ACTIONS(4946),
    [anon_sym_select] = ACTIONS(4946),
    [aux_sym_preproc_if_token1] = ACTIONS(4948),
    [aux_sym_preproc_if_token3] = ACTIONS(4948),
    [aux_sym_preproc_else_token1] = ACTIONS(4948),
    [aux_sym_preproc_elif_token1] = ACTIONS(4948),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3315] = {
    [sym_preproc_region] = STATE(3315),
    [sym_preproc_endregion] = STATE(3315),
    [sym_preproc_line] = STATE(3315),
    [sym_preproc_pragma] = STATE(3315),
    [sym_preproc_nullable] = STATE(3315),
    [sym_preproc_error] = STATE(3315),
    [sym_preproc_warning] = STATE(3315),
    [sym_preproc_define] = STATE(3315),
    [sym_preproc_undef] = STATE(3315),
    [sym__identifier_token] = ACTIONS(4950),
    [anon_sym_extern] = ACTIONS(4950),
    [anon_sym_alias] = ACTIONS(4950),
    [anon_sym_global] = ACTIONS(4950),
    [anon_sym_using] = ACTIONS(4950),
    [anon_sym_unsafe] = ACTIONS(4950),
    [anon_sym_static] = ACTIONS(4950),
    [anon_sym_LBRACK] = ACTIONS(4952),
    [anon_sym_LPAREN] = ACTIONS(4952),
    [anon_sym_event] = ACTIONS(4950),
    [anon_sym_namespace] = ACTIONS(4950),
    [anon_sym_class] = ACTIONS(4950),
    [anon_sym_ref] = ACTIONS(4950),
    [anon_sym_struct] = ACTIONS(4950),
    [anon_sym_enum] = ACTIONS(4950),
    [anon_sym_RBRACE] = ACTIONS(4952),
    [anon_sym_interface] = ACTIONS(4950),
    [anon_sym_delegate] = ACTIONS(4950),
    [anon_sym_record] = ACTIONS(4950),
    [anon_sym_abstract] = ACTIONS(4950),
    [anon_sym_async] = ACTIONS(4950),
    [anon_sym_const] = ACTIONS(4950),
    [anon_sym_file] = ACTIONS(4950),
    [anon_sym_fixed] = ACTIONS(4950),
    [anon_sym_internal] = ACTIONS(4950),
    [anon_sym_new] = ACTIONS(4950),
    [anon_sym_override] = ACTIONS(4950),
    [anon_sym_partial] = ACTIONS(4950),
    [anon_sym_private] = ACTIONS(4950),
    [anon_sym_protected] = ACTIONS(4950),
    [anon_sym_public] = ACTIONS(4950),
    [anon_sym_readonly] = ACTIONS(4950),
    [anon_sym_required] = ACTIONS(4950),
    [anon_sym_sealed] = ACTIONS(4950),
    [anon_sym_virtual] = ACTIONS(4950),
    [anon_sym_volatile] = ACTIONS(4950),
    [anon_sym_where] = ACTIONS(4950),
    [anon_sym_notnull] = ACTIONS(4950),
    [anon_sym_unmanaged] = ACTIONS(4950),
    [anon_sym_TILDE] = ACTIONS(4952),
    [anon_sym_implicit] = ACTIONS(4950),
    [anon_sym_explicit] = ACTIONS(4950),
    [anon_sym_scoped] = ACTIONS(4950),
    [anon_sym_var] = ACTIONS(4950),
    [sym_predefined_type] = ACTIONS(4950),
    [anon_sym_yield] = ACTIONS(4950),
    [anon_sym_when] = ACTIONS(4950),
    [anon_sym_from] = ACTIONS(4950),
    [anon_sym_into] = ACTIONS(4950),
    [anon_sym_join] = ACTIONS(4950),
    [anon_sym_on] = ACTIONS(4950),
    [anon_sym_equals] = ACTIONS(4950),
    [anon_sym_let] = ACTIONS(4950),
    [anon_sym_orderby] = ACTIONS(4950),
    [anon_sym_ascending] = ACTIONS(4950),
    [anon_sym_descending] = ACTIONS(4950),
    [anon_sym_group] = ACTIONS(4950),
    [anon_sym_by] = ACTIONS(4950),
    [anon_sym_select] = ACTIONS(4950),
    [aux_sym_preproc_if_token1] = ACTIONS(4952),
    [aux_sym_preproc_if_token3] = ACTIONS(4952),
    [aux_sym_preproc_else_token1] = ACTIONS(4952),
    [aux_sym_preproc_elif_token1] = ACTIONS(4952),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3316] = {
    [sym_preproc_region] = STATE(3316),
    [sym_preproc_endregion] = STATE(3316),
    [sym_preproc_line] = STATE(3316),
    [sym_preproc_pragma] = STATE(3316),
    [sym_preproc_nullable] = STATE(3316),
    [sym_preproc_error] = STATE(3316),
    [sym_preproc_warning] = STATE(3316),
    [sym_preproc_define] = STATE(3316),
    [sym_preproc_undef] = STATE(3316),
    [sym__identifier_token] = ACTIONS(4954),
    [anon_sym_extern] = ACTIONS(4954),
    [anon_sym_alias] = ACTIONS(4954),
    [anon_sym_global] = ACTIONS(4954),
    [anon_sym_using] = ACTIONS(4954),
    [anon_sym_unsafe] = ACTIONS(4954),
    [anon_sym_static] = ACTIONS(4954),
    [anon_sym_LBRACK] = ACTIONS(4956),
    [anon_sym_LPAREN] = ACTIONS(4956),
    [anon_sym_event] = ACTIONS(4954),
    [anon_sym_namespace] = ACTIONS(4954),
    [anon_sym_class] = ACTIONS(4954),
    [anon_sym_ref] = ACTIONS(4954),
    [anon_sym_struct] = ACTIONS(4954),
    [anon_sym_enum] = ACTIONS(4954),
    [anon_sym_RBRACE] = ACTIONS(4956),
    [anon_sym_interface] = ACTIONS(4954),
    [anon_sym_delegate] = ACTIONS(4954),
    [anon_sym_record] = ACTIONS(4954),
    [anon_sym_abstract] = ACTIONS(4954),
    [anon_sym_async] = ACTIONS(4954),
    [anon_sym_const] = ACTIONS(4954),
    [anon_sym_file] = ACTIONS(4954),
    [anon_sym_fixed] = ACTIONS(4954),
    [anon_sym_internal] = ACTIONS(4954),
    [anon_sym_new] = ACTIONS(4954),
    [anon_sym_override] = ACTIONS(4954),
    [anon_sym_partial] = ACTIONS(4954),
    [anon_sym_private] = ACTIONS(4954),
    [anon_sym_protected] = ACTIONS(4954),
    [anon_sym_public] = ACTIONS(4954),
    [anon_sym_readonly] = ACTIONS(4954),
    [anon_sym_required] = ACTIONS(4954),
    [anon_sym_sealed] = ACTIONS(4954),
    [anon_sym_virtual] = ACTIONS(4954),
    [anon_sym_volatile] = ACTIONS(4954),
    [anon_sym_where] = ACTIONS(4954),
    [anon_sym_notnull] = ACTIONS(4954),
    [anon_sym_unmanaged] = ACTIONS(4954),
    [anon_sym_TILDE] = ACTIONS(4956),
    [anon_sym_implicit] = ACTIONS(4954),
    [anon_sym_explicit] = ACTIONS(4954),
    [anon_sym_scoped] = ACTIONS(4954),
    [anon_sym_var] = ACTIONS(4954),
    [sym_predefined_type] = ACTIONS(4954),
    [anon_sym_yield] = ACTIONS(4954),
    [anon_sym_when] = ACTIONS(4954),
    [anon_sym_from] = ACTIONS(4954),
    [anon_sym_into] = ACTIONS(4954),
    [anon_sym_join] = ACTIONS(4954),
    [anon_sym_on] = ACTIONS(4954),
    [anon_sym_equals] = ACTIONS(4954),
    [anon_sym_let] = ACTIONS(4954),
    [anon_sym_orderby] = ACTIONS(4954),
    [anon_sym_ascending] = ACTIONS(4954),
    [anon_sym_descending] = ACTIONS(4954),
    [anon_sym_group] = ACTIONS(4954),
    [anon_sym_by] = ACTIONS(4954),
    [anon_sym_select] = ACTIONS(4954),
    [aux_sym_preproc_if_token1] = ACTIONS(4956),
    [aux_sym_preproc_if_token3] = ACTIONS(4956),
    [aux_sym_preproc_else_token1] = ACTIONS(4956),
    [aux_sym_preproc_elif_token1] = ACTIONS(4956),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3317] = {
    [sym_preproc_region] = STATE(3317),
    [sym_preproc_endregion] = STATE(3317),
    [sym_preproc_line] = STATE(3317),
    [sym_preproc_pragma] = STATE(3317),
    [sym_preproc_nullable] = STATE(3317),
    [sym_preproc_error] = STATE(3317),
    [sym_preproc_warning] = STATE(3317),
    [sym_preproc_define] = STATE(3317),
    [sym_preproc_undef] = STATE(3317),
    [sym__identifier_token] = ACTIONS(4958),
    [anon_sym_extern] = ACTIONS(4958),
    [anon_sym_alias] = ACTIONS(4958),
    [anon_sym_global] = ACTIONS(4958),
    [anon_sym_using] = ACTIONS(4958),
    [anon_sym_unsafe] = ACTIONS(4958),
    [anon_sym_static] = ACTIONS(4958),
    [anon_sym_LBRACK] = ACTIONS(4960),
    [anon_sym_LPAREN] = ACTIONS(4960),
    [anon_sym_event] = ACTIONS(4958),
    [anon_sym_namespace] = ACTIONS(4958),
    [anon_sym_class] = ACTIONS(4958),
    [anon_sym_ref] = ACTIONS(4958),
    [anon_sym_struct] = ACTIONS(4958),
    [anon_sym_enum] = ACTIONS(4958),
    [anon_sym_RBRACE] = ACTIONS(4960),
    [anon_sym_interface] = ACTIONS(4958),
    [anon_sym_delegate] = ACTIONS(4958),
    [anon_sym_record] = ACTIONS(4958),
    [anon_sym_abstract] = ACTIONS(4958),
    [anon_sym_async] = ACTIONS(4958),
    [anon_sym_const] = ACTIONS(4958),
    [anon_sym_file] = ACTIONS(4958),
    [anon_sym_fixed] = ACTIONS(4958),
    [anon_sym_internal] = ACTIONS(4958),
    [anon_sym_new] = ACTIONS(4958),
    [anon_sym_override] = ACTIONS(4958),
    [anon_sym_partial] = ACTIONS(4958),
    [anon_sym_private] = ACTIONS(4958),
    [anon_sym_protected] = ACTIONS(4958),
    [anon_sym_public] = ACTIONS(4958),
    [anon_sym_readonly] = ACTIONS(4958),
    [anon_sym_required] = ACTIONS(4958),
    [anon_sym_sealed] = ACTIONS(4958),
    [anon_sym_virtual] = ACTIONS(4958),
    [anon_sym_volatile] = ACTIONS(4958),
    [anon_sym_where] = ACTIONS(4958),
    [anon_sym_notnull] = ACTIONS(4958),
    [anon_sym_unmanaged] = ACTIONS(4958),
    [anon_sym_TILDE] = ACTIONS(4960),
    [anon_sym_implicit] = ACTIONS(4958),
    [anon_sym_explicit] = ACTIONS(4958),
    [anon_sym_scoped] = ACTIONS(4958),
    [anon_sym_var] = ACTIONS(4958),
    [sym_predefined_type] = ACTIONS(4958),
    [anon_sym_yield] = ACTIONS(4958),
    [anon_sym_when] = ACTIONS(4958),
    [anon_sym_from] = ACTIONS(4958),
    [anon_sym_into] = ACTIONS(4958),
    [anon_sym_join] = ACTIONS(4958),
    [anon_sym_on] = ACTIONS(4958),
    [anon_sym_equals] = ACTIONS(4958),
    [anon_sym_let] = ACTIONS(4958),
    [anon_sym_orderby] = ACTIONS(4958),
    [anon_sym_ascending] = ACTIONS(4958),
    [anon_sym_descending] = ACTIONS(4958),
    [anon_sym_group] = ACTIONS(4958),
    [anon_sym_by] = ACTIONS(4958),
    [anon_sym_select] = ACTIONS(4958),
    [aux_sym_preproc_if_token1] = ACTIONS(4960),
    [aux_sym_preproc_if_token3] = ACTIONS(4960),
    [aux_sym_preproc_else_token1] = ACTIONS(4960),
    [aux_sym_preproc_elif_token1] = ACTIONS(4960),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3318] = {
    [sym_preproc_region] = STATE(3318),
    [sym_preproc_endregion] = STATE(3318),
    [sym_preproc_line] = STATE(3318),
    [sym_preproc_pragma] = STATE(3318),
    [sym_preproc_nullable] = STATE(3318),
    [sym_preproc_error] = STATE(3318),
    [sym_preproc_warning] = STATE(3318),
    [sym_preproc_define] = STATE(3318),
    [sym_preproc_undef] = STATE(3318),
    [sym__identifier_token] = ACTIONS(4962),
    [anon_sym_extern] = ACTIONS(4962),
    [anon_sym_alias] = ACTIONS(4962),
    [anon_sym_global] = ACTIONS(4962),
    [anon_sym_using] = ACTIONS(4962),
    [anon_sym_unsafe] = ACTIONS(4962),
    [anon_sym_static] = ACTIONS(4962),
    [anon_sym_LBRACK] = ACTIONS(4964),
    [anon_sym_LPAREN] = ACTIONS(4964),
    [anon_sym_event] = ACTIONS(4962),
    [anon_sym_namespace] = ACTIONS(4962),
    [anon_sym_class] = ACTIONS(4962),
    [anon_sym_ref] = ACTIONS(4962),
    [anon_sym_struct] = ACTIONS(4962),
    [anon_sym_enum] = ACTIONS(4962),
    [anon_sym_RBRACE] = ACTIONS(4964),
    [anon_sym_interface] = ACTIONS(4962),
    [anon_sym_delegate] = ACTIONS(4962),
    [anon_sym_record] = ACTIONS(4962),
    [anon_sym_abstract] = ACTIONS(4962),
    [anon_sym_async] = ACTIONS(4962),
    [anon_sym_const] = ACTIONS(4962),
    [anon_sym_file] = ACTIONS(4962),
    [anon_sym_fixed] = ACTIONS(4962),
    [anon_sym_internal] = ACTIONS(4962),
    [anon_sym_new] = ACTIONS(4962),
    [anon_sym_override] = ACTIONS(4962),
    [anon_sym_partial] = ACTIONS(4962),
    [anon_sym_private] = ACTIONS(4962),
    [anon_sym_protected] = ACTIONS(4962),
    [anon_sym_public] = ACTIONS(4962),
    [anon_sym_readonly] = ACTIONS(4962),
    [anon_sym_required] = ACTIONS(4962),
    [anon_sym_sealed] = ACTIONS(4962),
    [anon_sym_virtual] = ACTIONS(4962),
    [anon_sym_volatile] = ACTIONS(4962),
    [anon_sym_where] = ACTIONS(4962),
    [anon_sym_notnull] = ACTIONS(4962),
    [anon_sym_unmanaged] = ACTIONS(4962),
    [anon_sym_TILDE] = ACTIONS(4964),
    [anon_sym_implicit] = ACTIONS(4962),
    [anon_sym_explicit] = ACTIONS(4962),
    [anon_sym_scoped] = ACTIONS(4962),
    [anon_sym_var] = ACTIONS(4962),
    [sym_predefined_type] = ACTIONS(4962),
    [anon_sym_yield] = ACTIONS(4962),
    [anon_sym_when] = ACTIONS(4962),
    [anon_sym_from] = ACTIONS(4962),
    [anon_sym_into] = ACTIONS(4962),
    [anon_sym_join] = ACTIONS(4962),
    [anon_sym_on] = ACTIONS(4962),
    [anon_sym_equals] = ACTIONS(4962),
    [anon_sym_let] = ACTIONS(4962),
    [anon_sym_orderby] = ACTIONS(4962),
    [anon_sym_ascending] = ACTIONS(4962),
    [anon_sym_descending] = ACTIONS(4962),
    [anon_sym_group] = ACTIONS(4962),
    [anon_sym_by] = ACTIONS(4962),
    [anon_sym_select] = ACTIONS(4962),
    [aux_sym_preproc_if_token1] = ACTIONS(4964),
    [aux_sym_preproc_if_token3] = ACTIONS(4964),
    [aux_sym_preproc_else_token1] = ACTIONS(4964),
    [aux_sym_preproc_elif_token1] = ACTIONS(4964),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3319] = {
    [sym_preproc_region] = STATE(3319),
    [sym_preproc_endregion] = STATE(3319),
    [sym_preproc_line] = STATE(3319),
    [sym_preproc_pragma] = STATE(3319),
    [sym_preproc_nullable] = STATE(3319),
    [sym_preproc_error] = STATE(3319),
    [sym_preproc_warning] = STATE(3319),
    [sym_preproc_define] = STATE(3319),
    [sym_preproc_undef] = STATE(3319),
    [sym__identifier_token] = ACTIONS(4966),
    [anon_sym_extern] = ACTIONS(4966),
    [anon_sym_alias] = ACTIONS(4966),
    [anon_sym_global] = ACTIONS(4966),
    [anon_sym_using] = ACTIONS(4966),
    [anon_sym_unsafe] = ACTIONS(4966),
    [anon_sym_static] = ACTIONS(4966),
    [anon_sym_LBRACK] = ACTIONS(4968),
    [anon_sym_LPAREN] = ACTIONS(4968),
    [anon_sym_event] = ACTIONS(4966),
    [anon_sym_namespace] = ACTIONS(4966),
    [anon_sym_class] = ACTIONS(4966),
    [anon_sym_ref] = ACTIONS(4966),
    [anon_sym_struct] = ACTIONS(4966),
    [anon_sym_enum] = ACTIONS(4966),
    [anon_sym_RBRACE] = ACTIONS(4968),
    [anon_sym_interface] = ACTIONS(4966),
    [anon_sym_delegate] = ACTIONS(4966),
    [anon_sym_record] = ACTIONS(4966),
    [anon_sym_abstract] = ACTIONS(4966),
    [anon_sym_async] = ACTIONS(4966),
    [anon_sym_const] = ACTIONS(4966),
    [anon_sym_file] = ACTIONS(4966),
    [anon_sym_fixed] = ACTIONS(4966),
    [anon_sym_internal] = ACTIONS(4966),
    [anon_sym_new] = ACTIONS(4966),
    [anon_sym_override] = ACTIONS(4966),
    [anon_sym_partial] = ACTIONS(4966),
    [anon_sym_private] = ACTIONS(4966),
    [anon_sym_protected] = ACTIONS(4966),
    [anon_sym_public] = ACTIONS(4966),
    [anon_sym_readonly] = ACTIONS(4966),
    [anon_sym_required] = ACTIONS(4966),
    [anon_sym_sealed] = ACTIONS(4966),
    [anon_sym_virtual] = ACTIONS(4966),
    [anon_sym_volatile] = ACTIONS(4966),
    [anon_sym_where] = ACTIONS(4966),
    [anon_sym_notnull] = ACTIONS(4966),
    [anon_sym_unmanaged] = ACTIONS(4966),
    [anon_sym_TILDE] = ACTIONS(4968),
    [anon_sym_implicit] = ACTIONS(4966),
    [anon_sym_explicit] = ACTIONS(4966),
    [anon_sym_scoped] = ACTIONS(4966),
    [anon_sym_var] = ACTIONS(4966),
    [sym_predefined_type] = ACTIONS(4966),
    [anon_sym_yield] = ACTIONS(4966),
    [anon_sym_when] = ACTIONS(4966),
    [anon_sym_from] = ACTIONS(4966),
    [anon_sym_into] = ACTIONS(4966),
    [anon_sym_join] = ACTIONS(4966),
    [anon_sym_on] = ACTIONS(4966),
    [anon_sym_equals] = ACTIONS(4966),
    [anon_sym_let] = ACTIONS(4966),
    [anon_sym_orderby] = ACTIONS(4966),
    [anon_sym_ascending] = ACTIONS(4966),
    [anon_sym_descending] = ACTIONS(4966),
    [anon_sym_group] = ACTIONS(4966),
    [anon_sym_by] = ACTIONS(4966),
    [anon_sym_select] = ACTIONS(4966),
    [aux_sym_preproc_if_token1] = ACTIONS(4968),
    [aux_sym_preproc_if_token3] = ACTIONS(4968),
    [aux_sym_preproc_else_token1] = ACTIONS(4968),
    [aux_sym_preproc_elif_token1] = ACTIONS(4968),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3320] = {
    [sym_preproc_region] = STATE(3320),
    [sym_preproc_endregion] = STATE(3320),
    [sym_preproc_line] = STATE(3320),
    [sym_preproc_pragma] = STATE(3320),
    [sym_preproc_nullable] = STATE(3320),
    [sym_preproc_error] = STATE(3320),
    [sym_preproc_warning] = STATE(3320),
    [sym_preproc_define] = STATE(3320),
    [sym_preproc_undef] = STATE(3320),
    [sym__identifier_token] = ACTIONS(3569),
    [anon_sym_extern] = ACTIONS(3569),
    [anon_sym_alias] = ACTIONS(3569),
    [anon_sym_global] = ACTIONS(3569),
    [anon_sym_using] = ACTIONS(3569),
    [anon_sym_unsafe] = ACTIONS(3569),
    [anon_sym_static] = ACTIONS(3569),
    [anon_sym_LBRACK] = ACTIONS(3571),
    [anon_sym_LPAREN] = ACTIONS(3571),
    [anon_sym_event] = ACTIONS(3569),
    [anon_sym_namespace] = ACTIONS(3569),
    [anon_sym_class] = ACTIONS(3569),
    [anon_sym_ref] = ACTIONS(3569),
    [anon_sym_struct] = ACTIONS(3569),
    [anon_sym_enum] = ACTIONS(3569),
    [anon_sym_RBRACE] = ACTIONS(3571),
    [anon_sym_interface] = ACTIONS(3569),
    [anon_sym_delegate] = ACTIONS(3569),
    [anon_sym_record] = ACTIONS(3569),
    [anon_sym_abstract] = ACTIONS(3569),
    [anon_sym_async] = ACTIONS(3569),
    [anon_sym_const] = ACTIONS(3569),
    [anon_sym_file] = ACTIONS(3569),
    [anon_sym_fixed] = ACTIONS(3569),
    [anon_sym_internal] = ACTIONS(3569),
    [anon_sym_new] = ACTIONS(3569),
    [anon_sym_override] = ACTIONS(3569),
    [anon_sym_partial] = ACTIONS(3569),
    [anon_sym_private] = ACTIONS(3569),
    [anon_sym_protected] = ACTIONS(3569),
    [anon_sym_public] = ACTIONS(3569),
    [anon_sym_readonly] = ACTIONS(3569),
    [anon_sym_required] = ACTIONS(3569),
    [anon_sym_sealed] = ACTIONS(3569),
    [anon_sym_virtual] = ACTIONS(3569),
    [anon_sym_volatile] = ACTIONS(3569),
    [anon_sym_where] = ACTIONS(3569),
    [anon_sym_notnull] = ACTIONS(3569),
    [anon_sym_unmanaged] = ACTIONS(3569),
    [anon_sym_TILDE] = ACTIONS(3571),
    [anon_sym_implicit] = ACTIONS(3569),
    [anon_sym_explicit] = ACTIONS(3569),
    [anon_sym_scoped] = ACTIONS(3569),
    [anon_sym_var] = ACTIONS(3569),
    [sym_predefined_type] = ACTIONS(3569),
    [anon_sym_yield] = ACTIONS(3569),
    [anon_sym_when] = ACTIONS(3569),
    [anon_sym_from] = ACTIONS(3569),
    [anon_sym_into] = ACTIONS(3569),
    [anon_sym_join] = ACTIONS(3569),
    [anon_sym_on] = ACTIONS(3569),
    [anon_sym_equals] = ACTIONS(3569),
    [anon_sym_let] = ACTIONS(3569),
    [anon_sym_orderby] = ACTIONS(3569),
    [anon_sym_ascending] = ACTIONS(3569),
    [anon_sym_descending] = ACTIONS(3569),
    [anon_sym_group] = ACTIONS(3569),
    [anon_sym_by] = ACTIONS(3569),
    [anon_sym_select] = ACTIONS(3569),
    [aux_sym_preproc_if_token1] = ACTIONS(3571),
    [aux_sym_preproc_if_token3] = ACTIONS(3571),
    [aux_sym_preproc_else_token1] = ACTIONS(3571),
    [aux_sym_preproc_elif_token1] = ACTIONS(3571),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3321] = {
    [sym_preproc_region] = STATE(3321),
    [sym_preproc_endregion] = STATE(3321),
    [sym_preproc_line] = STATE(3321),
    [sym_preproc_pragma] = STATE(3321),
    [sym_preproc_nullable] = STATE(3321),
    [sym_preproc_error] = STATE(3321),
    [sym_preproc_warning] = STATE(3321),
    [sym_preproc_define] = STATE(3321),
    [sym_preproc_undef] = STATE(3321),
    [sym__identifier_token] = ACTIONS(4039),
    [anon_sym_extern] = ACTIONS(4042),
    [anon_sym_alias] = ACTIONS(4039),
    [anon_sym_global] = ACTIONS(4039),
    [anon_sym_unsafe] = ACTIONS(4042),
    [anon_sym_static] = ACTIONS(4042),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_LPAREN] = ACTIONS(4044),
    [anon_sym_event] = ACTIONS(4042),
    [anon_sym_class] = ACTIONS(4042),
    [anon_sym_ref] = ACTIONS(4042),
    [anon_sym_struct] = ACTIONS(4042),
    [anon_sym_enum] = ACTIONS(4042),
    [anon_sym_interface] = ACTIONS(4042),
    [anon_sym_delegate] = ACTIONS(4042),
    [anon_sym_record] = ACTIONS(4042),
    [anon_sym_abstract] = ACTIONS(4042),
    [anon_sym_async] = ACTIONS(4042),
    [anon_sym_const] = ACTIONS(4042),
    [anon_sym_file] = ACTIONS(4039),
    [anon_sym_fixed] = ACTIONS(4042),
    [anon_sym_internal] = ACTIONS(4042),
    [anon_sym_new] = ACTIONS(4042),
    [anon_sym_override] = ACTIONS(4042),
    [anon_sym_partial] = ACTIONS(4042),
    [anon_sym_private] = ACTIONS(4042),
    [anon_sym_protected] = ACTIONS(4042),
    [anon_sym_public] = ACTIONS(4042),
    [anon_sym_readonly] = ACTIONS(4042),
    [anon_sym_required] = ACTIONS(4042),
    [anon_sym_sealed] = ACTIONS(4042),
    [anon_sym_virtual] = ACTIONS(4042),
    [anon_sym_volatile] = ACTIONS(4042),
    [anon_sym_LT] = ACTIONS(3993),
    [anon_sym_where] = ACTIONS(4039),
    [anon_sym_QMARK] = ACTIONS(3993),
    [anon_sym_notnull] = ACTIONS(4039),
    [anon_sym_unmanaged] = ACTIONS(4039),
    [anon_sym_operator] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3993),
    [anon_sym_implicit] = ACTIONS(4042),
    [anon_sym_explicit] = ACTIONS(4042),
    [anon_sym_this] = ACTIONS(3995),
    [anon_sym_DOT] = ACTIONS(3993),
    [anon_sym_scoped] = ACTIONS(4039),
    [anon_sym_EQ_GT] = ACTIONS(3993),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(4039),
    [sym_predefined_type] = ACTIONS(4042),
    [anon_sym_yield] = ACTIONS(4039),
    [anon_sym_when] = ACTIONS(4039),
    [anon_sym_from] = ACTIONS(4039),
    [anon_sym_into] = ACTIONS(4039),
    [anon_sym_join] = ACTIONS(4039),
    [anon_sym_on] = ACTIONS(4039),
    [anon_sym_equals] = ACTIONS(4039),
    [anon_sym_let] = ACTIONS(4039),
    [anon_sym_orderby] = ACTIONS(4039),
    [anon_sym_ascending] = ACTIONS(4039),
    [anon_sym_descending] = ACTIONS(4039),
    [anon_sym_group] = ACTIONS(4039),
    [anon_sym_by] = ACTIONS(4039),
    [anon_sym_select] = ACTIONS(4039),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3322] = {
    [sym_preproc_region] = STATE(3322),
    [sym_preproc_endregion] = STATE(3322),
    [sym_preproc_line] = STATE(3322),
    [sym_preproc_pragma] = STATE(3322),
    [sym_preproc_nullable] = STATE(3322),
    [sym_preproc_error] = STATE(3322),
    [sym_preproc_warning] = STATE(3322),
    [sym_preproc_define] = STATE(3322),
    [sym_preproc_undef] = STATE(3322),
    [sym__identifier_token] = ACTIONS(3573),
    [anon_sym_extern] = ACTIONS(3573),
    [anon_sym_alias] = ACTIONS(3573),
    [anon_sym_global] = ACTIONS(3573),
    [anon_sym_using] = ACTIONS(3573),
    [anon_sym_unsafe] = ACTIONS(3573),
    [anon_sym_static] = ACTIONS(3573),
    [anon_sym_LBRACK] = ACTIONS(3575),
    [anon_sym_LPAREN] = ACTIONS(3575),
    [anon_sym_event] = ACTIONS(3573),
    [anon_sym_namespace] = ACTIONS(3573),
    [anon_sym_class] = ACTIONS(3573),
    [anon_sym_ref] = ACTIONS(3573),
    [anon_sym_struct] = ACTIONS(3573),
    [anon_sym_enum] = ACTIONS(3573),
    [anon_sym_RBRACE] = ACTIONS(3575),
    [anon_sym_interface] = ACTIONS(3573),
    [anon_sym_delegate] = ACTIONS(3573),
    [anon_sym_record] = ACTIONS(3573),
    [anon_sym_abstract] = ACTIONS(3573),
    [anon_sym_async] = ACTIONS(3573),
    [anon_sym_const] = ACTIONS(3573),
    [anon_sym_file] = ACTIONS(3573),
    [anon_sym_fixed] = ACTIONS(3573),
    [anon_sym_internal] = ACTIONS(3573),
    [anon_sym_new] = ACTIONS(3573),
    [anon_sym_override] = ACTIONS(3573),
    [anon_sym_partial] = ACTIONS(3573),
    [anon_sym_private] = ACTIONS(3573),
    [anon_sym_protected] = ACTIONS(3573),
    [anon_sym_public] = ACTIONS(3573),
    [anon_sym_readonly] = ACTIONS(3573),
    [anon_sym_required] = ACTIONS(3573),
    [anon_sym_sealed] = ACTIONS(3573),
    [anon_sym_virtual] = ACTIONS(3573),
    [anon_sym_volatile] = ACTIONS(3573),
    [anon_sym_where] = ACTIONS(3573),
    [anon_sym_notnull] = ACTIONS(3573),
    [anon_sym_unmanaged] = ACTIONS(3573),
    [anon_sym_TILDE] = ACTIONS(3575),
    [anon_sym_implicit] = ACTIONS(3573),
    [anon_sym_explicit] = ACTIONS(3573),
    [anon_sym_scoped] = ACTIONS(3573),
    [anon_sym_var] = ACTIONS(3573),
    [sym_predefined_type] = ACTIONS(3573),
    [anon_sym_yield] = ACTIONS(3573),
    [anon_sym_when] = ACTIONS(3573),
    [anon_sym_from] = ACTIONS(3573),
    [anon_sym_into] = ACTIONS(3573),
    [anon_sym_join] = ACTIONS(3573),
    [anon_sym_on] = ACTIONS(3573),
    [anon_sym_equals] = ACTIONS(3573),
    [anon_sym_let] = ACTIONS(3573),
    [anon_sym_orderby] = ACTIONS(3573),
    [anon_sym_ascending] = ACTIONS(3573),
    [anon_sym_descending] = ACTIONS(3573),
    [anon_sym_group] = ACTIONS(3573),
    [anon_sym_by] = ACTIONS(3573),
    [anon_sym_select] = ACTIONS(3573),
    [aux_sym_preproc_if_token1] = ACTIONS(3575),
    [aux_sym_preproc_if_token3] = ACTIONS(3575),
    [aux_sym_preproc_else_token1] = ACTIONS(3575),
    [aux_sym_preproc_elif_token1] = ACTIONS(3575),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3323] = {
    [sym_preproc_region] = STATE(3323),
    [sym_preproc_endregion] = STATE(3323),
    [sym_preproc_line] = STATE(3323),
    [sym_preproc_pragma] = STATE(3323),
    [sym_preproc_nullable] = STATE(3323),
    [sym_preproc_error] = STATE(3323),
    [sym_preproc_warning] = STATE(3323),
    [sym_preproc_define] = STATE(3323),
    [sym_preproc_undef] = STATE(3323),
    [sym__identifier_token] = ACTIONS(4492),
    [anon_sym_alias] = ACTIONS(4492),
    [anon_sym_global] = ACTIONS(4492),
    [anon_sym_LBRACK] = ACTIONS(4593),
    [anon_sym_COLON] = ACTIONS(4494),
    [anon_sym_COMMA] = ACTIONS(4494),
    [anon_sym_LPAREN] = ACTIONS(4494),
    [anon_sym_LBRACE] = ACTIONS(4494),
    [anon_sym_file] = ACTIONS(4492),
    [anon_sym_LT] = ACTIONS(4492),
    [anon_sym_GT] = ACTIONS(4492),
    [anon_sym_where] = ACTIONS(4492),
    [anon_sym_QMARK] = ACTIONS(4970),
    [anon_sym_notnull] = ACTIONS(4492),
    [anon_sym_unmanaged] = ACTIONS(4492),
    [anon_sym_BANG] = ACTIONS(4492),
    [anon_sym_PLUS_PLUS] = ACTIONS(4494),
    [anon_sym_DASH_DASH] = ACTIONS(4494),
    [anon_sym_PLUS] = ACTIONS(4492),
    [anon_sym_DASH] = ACTIONS(4492),
    [anon_sym_STAR] = ACTIONS(4599),
    [anon_sym_SLASH] = ACTIONS(4492),
    [anon_sym_PERCENT] = ACTIONS(4494),
    [anon_sym_CARET] = ACTIONS(4494),
    [anon_sym_PIPE] = ACTIONS(4492),
    [anon_sym_AMP] = ACTIONS(4492),
    [anon_sym_LT_LT] = ACTIONS(4494),
    [anon_sym_GT_GT] = ACTIONS(4492),
    [anon_sym_GT_GT_GT] = ACTIONS(4494),
    [anon_sym_EQ_EQ] = ACTIONS(4494),
    [anon_sym_BANG_EQ] = ACTIONS(4494),
    [anon_sym_GT_EQ] = ACTIONS(4494),
    [anon_sym_LT_EQ] = ACTIONS(4494),
    [anon_sym_DOT] = ACTIONS(4973),
    [anon_sym_scoped] = ACTIONS(4492),
    [anon_sym_var] = ACTIONS(4492),
    [anon_sym_yield] = ACTIONS(4492),
    [anon_sym_switch] = ACTIONS(4492),
    [anon_sym_when] = ACTIONS(4492),
    [sym_discard] = ACTIONS(4492),
    [anon_sym_DOT_DOT] = ACTIONS(4494),
    [anon_sym_and] = ACTIONS(4492),
    [anon_sym_or] = ACTIONS(4492),
    [anon_sym_AMP_AMP] = ACTIONS(4494),
    [anon_sym_PIPE_PIPE] = ACTIONS(4494),
    [anon_sym_QMARK_QMARK] = ACTIONS(4494),
    [anon_sym_from] = ACTIONS(4492),
    [anon_sym_into] = ACTIONS(4492),
    [anon_sym_join] = ACTIONS(4492),
    [anon_sym_on] = ACTIONS(4492),
    [anon_sym_equals] = ACTIONS(4492),
    [anon_sym_let] = ACTIONS(4492),
    [anon_sym_orderby] = ACTIONS(4492),
    [anon_sym_ascending] = ACTIONS(4492),
    [anon_sym_descending] = ACTIONS(4492),
    [anon_sym_group] = ACTIONS(4492),
    [anon_sym_by] = ACTIONS(4492),
    [anon_sym_select] = ACTIONS(4492),
    [anon_sym_as] = ACTIONS(4492),
    [anon_sym_is] = ACTIONS(4492),
    [anon_sym_DASH_GT] = ACTIONS(4975),
    [anon_sym_with] = ACTIONS(4492),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4494),
  },
  [3324] = {
    [sym_preproc_region] = STATE(3324),
    [sym_preproc_endregion] = STATE(3324),
    [sym_preproc_line] = STATE(3324),
    [sym_preproc_pragma] = STATE(3324),
    [sym_preproc_nullable] = STATE(3324),
    [sym_preproc_error] = STATE(3324),
    [sym_preproc_warning] = STATE(3324),
    [sym_preproc_define] = STATE(3324),
    [sym_preproc_undef] = STATE(3324),
    [sym__identifier_token] = ACTIONS(4977),
    [anon_sym_extern] = ACTIONS(4977),
    [anon_sym_alias] = ACTIONS(4977),
    [anon_sym_global] = ACTIONS(4977),
    [anon_sym_using] = ACTIONS(4977),
    [anon_sym_unsafe] = ACTIONS(4977),
    [anon_sym_static] = ACTIONS(4977),
    [anon_sym_LBRACK] = ACTIONS(4979),
    [anon_sym_LPAREN] = ACTIONS(4979),
    [anon_sym_event] = ACTIONS(4977),
    [anon_sym_namespace] = ACTIONS(4977),
    [anon_sym_class] = ACTIONS(4977),
    [anon_sym_ref] = ACTIONS(4977),
    [anon_sym_struct] = ACTIONS(4977),
    [anon_sym_enum] = ACTIONS(4977),
    [anon_sym_RBRACE] = ACTIONS(4979),
    [anon_sym_interface] = ACTIONS(4977),
    [anon_sym_delegate] = ACTIONS(4977),
    [anon_sym_record] = ACTIONS(4977),
    [anon_sym_abstract] = ACTIONS(4977),
    [anon_sym_async] = ACTIONS(4977),
    [anon_sym_const] = ACTIONS(4977),
    [anon_sym_file] = ACTIONS(4977),
    [anon_sym_fixed] = ACTIONS(4977),
    [anon_sym_internal] = ACTIONS(4977),
    [anon_sym_new] = ACTIONS(4977),
    [anon_sym_override] = ACTIONS(4977),
    [anon_sym_partial] = ACTIONS(4977),
    [anon_sym_private] = ACTIONS(4977),
    [anon_sym_protected] = ACTIONS(4977),
    [anon_sym_public] = ACTIONS(4977),
    [anon_sym_readonly] = ACTIONS(4977),
    [anon_sym_required] = ACTIONS(4977),
    [anon_sym_sealed] = ACTIONS(4977),
    [anon_sym_virtual] = ACTIONS(4977),
    [anon_sym_volatile] = ACTIONS(4977),
    [anon_sym_where] = ACTIONS(4977),
    [anon_sym_notnull] = ACTIONS(4977),
    [anon_sym_unmanaged] = ACTIONS(4977),
    [anon_sym_TILDE] = ACTIONS(4979),
    [anon_sym_implicit] = ACTIONS(4977),
    [anon_sym_explicit] = ACTIONS(4977),
    [anon_sym_scoped] = ACTIONS(4977),
    [anon_sym_var] = ACTIONS(4977),
    [sym_predefined_type] = ACTIONS(4977),
    [anon_sym_yield] = ACTIONS(4977),
    [anon_sym_when] = ACTIONS(4977),
    [anon_sym_from] = ACTIONS(4977),
    [anon_sym_into] = ACTIONS(4977),
    [anon_sym_join] = ACTIONS(4977),
    [anon_sym_on] = ACTIONS(4977),
    [anon_sym_equals] = ACTIONS(4977),
    [anon_sym_let] = ACTIONS(4977),
    [anon_sym_orderby] = ACTIONS(4977),
    [anon_sym_ascending] = ACTIONS(4977),
    [anon_sym_descending] = ACTIONS(4977),
    [anon_sym_group] = ACTIONS(4977),
    [anon_sym_by] = ACTIONS(4977),
    [anon_sym_select] = ACTIONS(4977),
    [aux_sym_preproc_if_token1] = ACTIONS(4979),
    [aux_sym_preproc_if_token3] = ACTIONS(4979),
    [aux_sym_preproc_else_token1] = ACTIONS(4979),
    [aux_sym_preproc_elif_token1] = ACTIONS(4979),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3325] = {
    [sym_preproc_region] = STATE(3325),
    [sym_preproc_endregion] = STATE(3325),
    [sym_preproc_line] = STATE(3325),
    [sym_preproc_pragma] = STATE(3325),
    [sym_preproc_nullable] = STATE(3325),
    [sym_preproc_error] = STATE(3325),
    [sym_preproc_warning] = STATE(3325),
    [sym_preproc_define] = STATE(3325),
    [sym_preproc_undef] = STATE(3325),
    [sym__identifier_token] = ACTIONS(3577),
    [anon_sym_extern] = ACTIONS(3577),
    [anon_sym_alias] = ACTIONS(3577),
    [anon_sym_global] = ACTIONS(3577),
    [anon_sym_using] = ACTIONS(3577),
    [anon_sym_unsafe] = ACTIONS(3577),
    [anon_sym_static] = ACTIONS(3577),
    [anon_sym_LBRACK] = ACTIONS(3579),
    [anon_sym_LPAREN] = ACTIONS(3579),
    [anon_sym_event] = ACTIONS(3577),
    [anon_sym_namespace] = ACTIONS(3577),
    [anon_sym_class] = ACTIONS(3577),
    [anon_sym_ref] = ACTIONS(3577),
    [anon_sym_struct] = ACTIONS(3577),
    [anon_sym_enum] = ACTIONS(3577),
    [anon_sym_RBRACE] = ACTIONS(3579),
    [anon_sym_interface] = ACTIONS(3577),
    [anon_sym_delegate] = ACTIONS(3577),
    [anon_sym_record] = ACTIONS(3577),
    [anon_sym_abstract] = ACTIONS(3577),
    [anon_sym_async] = ACTIONS(3577),
    [anon_sym_const] = ACTIONS(3577),
    [anon_sym_file] = ACTIONS(3577),
    [anon_sym_fixed] = ACTIONS(3577),
    [anon_sym_internal] = ACTIONS(3577),
    [anon_sym_new] = ACTIONS(3577),
    [anon_sym_override] = ACTIONS(3577),
    [anon_sym_partial] = ACTIONS(3577),
    [anon_sym_private] = ACTIONS(3577),
    [anon_sym_protected] = ACTIONS(3577),
    [anon_sym_public] = ACTIONS(3577),
    [anon_sym_readonly] = ACTIONS(3577),
    [anon_sym_required] = ACTIONS(3577),
    [anon_sym_sealed] = ACTIONS(3577),
    [anon_sym_virtual] = ACTIONS(3577),
    [anon_sym_volatile] = ACTIONS(3577),
    [anon_sym_where] = ACTIONS(3577),
    [anon_sym_notnull] = ACTIONS(3577),
    [anon_sym_unmanaged] = ACTIONS(3577),
    [anon_sym_TILDE] = ACTIONS(3579),
    [anon_sym_implicit] = ACTIONS(3577),
    [anon_sym_explicit] = ACTIONS(3577),
    [anon_sym_scoped] = ACTIONS(3577),
    [anon_sym_var] = ACTIONS(3577),
    [sym_predefined_type] = ACTIONS(3577),
    [anon_sym_yield] = ACTIONS(3577),
    [anon_sym_when] = ACTIONS(3577),
    [anon_sym_from] = ACTIONS(3577),
    [anon_sym_into] = ACTIONS(3577),
    [anon_sym_join] = ACTIONS(3577),
    [anon_sym_on] = ACTIONS(3577),
    [anon_sym_equals] = ACTIONS(3577),
    [anon_sym_let] = ACTIONS(3577),
    [anon_sym_orderby] = ACTIONS(3577),
    [anon_sym_ascending] = ACTIONS(3577),
    [anon_sym_descending] = ACTIONS(3577),
    [anon_sym_group] = ACTIONS(3577),
    [anon_sym_by] = ACTIONS(3577),
    [anon_sym_select] = ACTIONS(3577),
    [aux_sym_preproc_if_token1] = ACTIONS(3579),
    [aux_sym_preproc_if_token3] = ACTIONS(3579),
    [aux_sym_preproc_else_token1] = ACTIONS(3579),
    [aux_sym_preproc_elif_token1] = ACTIONS(3579),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3326] = {
    [sym_preproc_region] = STATE(3326),
    [sym_preproc_endregion] = STATE(3326),
    [sym_preproc_line] = STATE(3326),
    [sym_preproc_pragma] = STATE(3326),
    [sym_preproc_nullable] = STATE(3326),
    [sym_preproc_error] = STATE(3326),
    [sym_preproc_warning] = STATE(3326),
    [sym_preproc_define] = STATE(3326),
    [sym_preproc_undef] = STATE(3326),
    [sym__identifier_token] = ACTIONS(4138),
    [anon_sym_alias] = ACTIONS(4138),
    [anon_sym_global] = ACTIONS(4138),
    [anon_sym_LBRACK] = ACTIONS(4140),
    [anon_sym_COLON] = ACTIONS(4140),
    [anon_sym_COMMA] = ACTIONS(4140),
    [anon_sym_LPAREN] = ACTIONS(4140),
    [anon_sym_LBRACE] = ACTIONS(4140),
    [anon_sym_file] = ACTIONS(4138),
    [anon_sym_LT] = ACTIONS(4138),
    [anon_sym_GT] = ACTIONS(4138),
    [anon_sym_where] = ACTIONS(4138),
    [anon_sym_QMARK] = ACTIONS(4138),
    [anon_sym_notnull] = ACTIONS(4138),
    [anon_sym_unmanaged] = ACTIONS(4138),
    [anon_sym_BANG] = ACTIONS(4138),
    [anon_sym_PLUS_PLUS] = ACTIONS(4140),
    [anon_sym_DASH_DASH] = ACTIONS(4140),
    [anon_sym_PLUS] = ACTIONS(4138),
    [anon_sym_DASH] = ACTIONS(4138),
    [anon_sym_STAR] = ACTIONS(4140),
    [anon_sym_SLASH] = ACTIONS(4138),
    [anon_sym_PERCENT] = ACTIONS(4140),
    [anon_sym_CARET] = ACTIONS(4140),
    [anon_sym_PIPE] = ACTIONS(4138),
    [anon_sym_AMP] = ACTIONS(4138),
    [anon_sym_LT_LT] = ACTIONS(4140),
    [anon_sym_GT_GT] = ACTIONS(4138),
    [anon_sym_GT_GT_GT] = ACTIONS(4140),
    [anon_sym_EQ_EQ] = ACTIONS(4140),
    [anon_sym_BANG_EQ] = ACTIONS(4140),
    [anon_sym_GT_EQ] = ACTIONS(4140),
    [anon_sym_LT_EQ] = ACTIONS(4140),
    [anon_sym_DOT] = ACTIONS(4138),
    [anon_sym_scoped] = ACTIONS(4138),
    [anon_sym_var] = ACTIONS(4138),
    [anon_sym_yield] = ACTIONS(4138),
    [anon_sym_switch] = ACTIONS(4138),
    [anon_sym_when] = ACTIONS(4138),
    [sym_discard] = ACTIONS(4138),
    [anon_sym_DOT_DOT] = ACTIONS(4140),
    [anon_sym_and] = ACTIONS(4138),
    [anon_sym_or] = ACTIONS(4138),
    [anon_sym_AMP_AMP] = ACTIONS(4140),
    [anon_sym_PIPE_PIPE] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK] = ACTIONS(4140),
    [anon_sym_from] = ACTIONS(4138),
    [anon_sym_into] = ACTIONS(4138),
    [anon_sym_join] = ACTIONS(4138),
    [anon_sym_on] = ACTIONS(4138),
    [anon_sym_equals] = ACTIONS(4138),
    [anon_sym_let] = ACTIONS(4138),
    [anon_sym_orderby] = ACTIONS(4138),
    [anon_sym_ascending] = ACTIONS(4138),
    [anon_sym_descending] = ACTIONS(4138),
    [anon_sym_group] = ACTIONS(4138),
    [anon_sym_by] = ACTIONS(4138),
    [anon_sym_select] = ACTIONS(4138),
    [anon_sym_as] = ACTIONS(4138),
    [anon_sym_is] = ACTIONS(4138),
    [anon_sym_DASH_GT] = ACTIONS(4140),
    [anon_sym_with] = ACTIONS(4138),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4140),
  },
  [3327] = {
    [sym_preproc_region] = STATE(3327),
    [sym_preproc_endregion] = STATE(3327),
    [sym_preproc_line] = STATE(3327),
    [sym_preproc_pragma] = STATE(3327),
    [sym_preproc_nullable] = STATE(3327),
    [sym_preproc_error] = STATE(3327),
    [sym_preproc_warning] = STATE(3327),
    [sym_preproc_define] = STATE(3327),
    [sym_preproc_undef] = STATE(3327),
    [sym__identifier_token] = ACTIONS(4981),
    [anon_sym_extern] = ACTIONS(4981),
    [anon_sym_alias] = ACTIONS(4981),
    [anon_sym_global] = ACTIONS(4981),
    [anon_sym_using] = ACTIONS(4981),
    [anon_sym_unsafe] = ACTIONS(4981),
    [anon_sym_static] = ACTIONS(4981),
    [anon_sym_LBRACK] = ACTIONS(4983),
    [anon_sym_LPAREN] = ACTIONS(4983),
    [anon_sym_event] = ACTIONS(4981),
    [anon_sym_namespace] = ACTIONS(4981),
    [anon_sym_class] = ACTIONS(4981),
    [anon_sym_ref] = ACTIONS(4981),
    [anon_sym_struct] = ACTIONS(4981),
    [anon_sym_enum] = ACTIONS(4981),
    [anon_sym_RBRACE] = ACTIONS(4983),
    [anon_sym_interface] = ACTIONS(4981),
    [anon_sym_delegate] = ACTIONS(4981),
    [anon_sym_record] = ACTIONS(4981),
    [anon_sym_abstract] = ACTIONS(4981),
    [anon_sym_async] = ACTIONS(4981),
    [anon_sym_const] = ACTIONS(4981),
    [anon_sym_file] = ACTIONS(4981),
    [anon_sym_fixed] = ACTIONS(4981),
    [anon_sym_internal] = ACTIONS(4981),
    [anon_sym_new] = ACTIONS(4981),
    [anon_sym_override] = ACTIONS(4981),
    [anon_sym_partial] = ACTIONS(4981),
    [anon_sym_private] = ACTIONS(4981),
    [anon_sym_protected] = ACTIONS(4981),
    [anon_sym_public] = ACTIONS(4981),
    [anon_sym_readonly] = ACTIONS(4981),
    [anon_sym_required] = ACTIONS(4981),
    [anon_sym_sealed] = ACTIONS(4981),
    [anon_sym_virtual] = ACTIONS(4981),
    [anon_sym_volatile] = ACTIONS(4981),
    [anon_sym_where] = ACTIONS(4981),
    [anon_sym_notnull] = ACTIONS(4981),
    [anon_sym_unmanaged] = ACTIONS(4981),
    [anon_sym_TILDE] = ACTIONS(4983),
    [anon_sym_implicit] = ACTIONS(4981),
    [anon_sym_explicit] = ACTIONS(4981),
    [anon_sym_scoped] = ACTIONS(4981),
    [anon_sym_var] = ACTIONS(4981),
    [sym_predefined_type] = ACTIONS(4981),
    [anon_sym_yield] = ACTIONS(4981),
    [anon_sym_when] = ACTIONS(4981),
    [anon_sym_from] = ACTIONS(4981),
    [anon_sym_into] = ACTIONS(4981),
    [anon_sym_join] = ACTIONS(4981),
    [anon_sym_on] = ACTIONS(4981),
    [anon_sym_equals] = ACTIONS(4981),
    [anon_sym_let] = ACTIONS(4981),
    [anon_sym_orderby] = ACTIONS(4981),
    [anon_sym_ascending] = ACTIONS(4981),
    [anon_sym_descending] = ACTIONS(4981),
    [anon_sym_group] = ACTIONS(4981),
    [anon_sym_by] = ACTIONS(4981),
    [anon_sym_select] = ACTIONS(4981),
    [aux_sym_preproc_if_token1] = ACTIONS(4983),
    [aux_sym_preproc_if_token3] = ACTIONS(4983),
    [aux_sym_preproc_else_token1] = ACTIONS(4983),
    [aux_sym_preproc_elif_token1] = ACTIONS(4983),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3328] = {
    [sym_preproc_region] = STATE(3328),
    [sym_preproc_endregion] = STATE(3328),
    [sym_preproc_line] = STATE(3328),
    [sym_preproc_pragma] = STATE(3328),
    [sym_preproc_nullable] = STATE(3328),
    [sym_preproc_error] = STATE(3328),
    [sym_preproc_warning] = STATE(3328),
    [sym_preproc_define] = STATE(3328),
    [sym_preproc_undef] = STATE(3328),
    [sym__identifier_token] = ACTIONS(4130),
    [anon_sym_alias] = ACTIONS(4130),
    [anon_sym_global] = ACTIONS(4130),
    [anon_sym_LBRACK] = ACTIONS(4132),
    [anon_sym_COLON] = ACTIONS(4132),
    [anon_sym_COMMA] = ACTIONS(4132),
    [anon_sym_LPAREN] = ACTIONS(4132),
    [anon_sym_LBRACE] = ACTIONS(4132),
    [anon_sym_file] = ACTIONS(4130),
    [anon_sym_LT] = ACTIONS(4130),
    [anon_sym_GT] = ACTIONS(4130),
    [anon_sym_where] = ACTIONS(4130),
    [anon_sym_QMARK] = ACTIONS(4130),
    [anon_sym_notnull] = ACTIONS(4130),
    [anon_sym_unmanaged] = ACTIONS(4130),
    [anon_sym_BANG] = ACTIONS(4130),
    [anon_sym_PLUS_PLUS] = ACTIONS(4132),
    [anon_sym_DASH_DASH] = ACTIONS(4132),
    [anon_sym_PLUS] = ACTIONS(4130),
    [anon_sym_DASH] = ACTIONS(4130),
    [anon_sym_STAR] = ACTIONS(4132),
    [anon_sym_SLASH] = ACTIONS(4130),
    [anon_sym_PERCENT] = ACTIONS(4132),
    [anon_sym_CARET] = ACTIONS(4132),
    [anon_sym_PIPE] = ACTIONS(4130),
    [anon_sym_AMP] = ACTIONS(4130),
    [anon_sym_LT_LT] = ACTIONS(4132),
    [anon_sym_GT_GT] = ACTIONS(4130),
    [anon_sym_GT_GT_GT] = ACTIONS(4132),
    [anon_sym_EQ_EQ] = ACTIONS(4132),
    [anon_sym_BANG_EQ] = ACTIONS(4132),
    [anon_sym_GT_EQ] = ACTIONS(4132),
    [anon_sym_LT_EQ] = ACTIONS(4132),
    [anon_sym_DOT] = ACTIONS(4130),
    [anon_sym_scoped] = ACTIONS(4130),
    [anon_sym_var] = ACTIONS(4130),
    [anon_sym_yield] = ACTIONS(4130),
    [anon_sym_switch] = ACTIONS(4130),
    [anon_sym_when] = ACTIONS(4130),
    [sym_discard] = ACTIONS(4130),
    [anon_sym_DOT_DOT] = ACTIONS(4132),
    [anon_sym_and] = ACTIONS(4130),
    [anon_sym_or] = ACTIONS(4130),
    [anon_sym_AMP_AMP] = ACTIONS(4132),
    [anon_sym_PIPE_PIPE] = ACTIONS(4132),
    [anon_sym_QMARK_QMARK] = ACTIONS(4132),
    [anon_sym_from] = ACTIONS(4130),
    [anon_sym_into] = ACTIONS(4130),
    [anon_sym_join] = ACTIONS(4130),
    [anon_sym_on] = ACTIONS(4130),
    [anon_sym_equals] = ACTIONS(4130),
    [anon_sym_let] = ACTIONS(4130),
    [anon_sym_orderby] = ACTIONS(4130),
    [anon_sym_ascending] = ACTIONS(4130),
    [anon_sym_descending] = ACTIONS(4130),
    [anon_sym_group] = ACTIONS(4130),
    [anon_sym_by] = ACTIONS(4130),
    [anon_sym_select] = ACTIONS(4130),
    [anon_sym_as] = ACTIONS(4130),
    [anon_sym_is] = ACTIONS(4130),
    [anon_sym_DASH_GT] = ACTIONS(4132),
    [anon_sym_with] = ACTIONS(4130),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4132),
  },
  [3329] = {
    [sym_preproc_region] = STATE(3329),
    [sym_preproc_endregion] = STATE(3329),
    [sym_preproc_line] = STATE(3329),
    [sym_preproc_pragma] = STATE(3329),
    [sym_preproc_nullable] = STATE(3329),
    [sym_preproc_error] = STATE(3329),
    [sym_preproc_warning] = STATE(3329),
    [sym_preproc_define] = STATE(3329),
    [sym_preproc_undef] = STATE(3329),
    [anon_sym_SEMI] = ACTIONS(4140),
    [anon_sym_EQ] = ACTIONS(4138),
    [anon_sym_LBRACK] = ACTIONS(4140),
    [anon_sym_COLON] = ACTIONS(4140),
    [anon_sym_COMMA] = ACTIONS(4140),
    [anon_sym_RBRACK] = ACTIONS(4140),
    [anon_sym_LPAREN] = ACTIONS(4140),
    [anon_sym_RPAREN] = ACTIONS(4140),
    [anon_sym_RBRACE] = ACTIONS(4140),
    [anon_sym_LT] = ACTIONS(4138),
    [anon_sym_GT] = ACTIONS(4138),
    [anon_sym_in] = ACTIONS(4140),
    [anon_sym_QMARK] = ACTIONS(4138),
    [anon_sym_BANG] = ACTIONS(4138),
    [anon_sym_PLUS_PLUS] = ACTIONS(4140),
    [anon_sym_DASH_DASH] = ACTIONS(4140),
    [anon_sym_PLUS] = ACTIONS(4138),
    [anon_sym_DASH] = ACTIONS(4138),
    [anon_sym_STAR] = ACTIONS(4138),
    [anon_sym_SLASH] = ACTIONS(4138),
    [anon_sym_PERCENT] = ACTIONS(4138),
    [anon_sym_CARET] = ACTIONS(4138),
    [anon_sym_PIPE] = ACTIONS(4138),
    [anon_sym_AMP] = ACTIONS(4138),
    [anon_sym_LT_LT] = ACTIONS(4138),
    [anon_sym_GT_GT] = ACTIONS(4138),
    [anon_sym_GT_GT_GT] = ACTIONS(4138),
    [anon_sym_EQ_EQ] = ACTIONS(4140),
    [anon_sym_BANG_EQ] = ACTIONS(4140),
    [anon_sym_GT_EQ] = ACTIONS(4140),
    [anon_sym_LT_EQ] = ACTIONS(4140),
    [anon_sym_DOT] = ACTIONS(4138),
    [anon_sym_EQ_GT] = ACTIONS(4140),
    [anon_sym_switch] = ACTIONS(4140),
    [anon_sym_when] = ACTIONS(4140),
    [anon_sym_DOT_DOT] = ACTIONS(4140),
    [anon_sym_and] = ACTIONS(4140),
    [anon_sym_or] = ACTIONS(4140),
    [anon_sym_PLUS_EQ] = ACTIONS(4140),
    [anon_sym_DASH_EQ] = ACTIONS(4140),
    [anon_sym_STAR_EQ] = ACTIONS(4140),
    [anon_sym_SLASH_EQ] = ACTIONS(4140),
    [anon_sym_PERCENT_EQ] = ACTIONS(4140),
    [anon_sym_AMP_EQ] = ACTIONS(4140),
    [anon_sym_CARET_EQ] = ACTIONS(4140),
    [anon_sym_PIPE_EQ] = ACTIONS(4140),
    [anon_sym_LT_LT_EQ] = ACTIONS(4140),
    [anon_sym_GT_GT_EQ] = ACTIONS(4140),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4140),
    [anon_sym_AMP_AMP] = ACTIONS(4140),
    [anon_sym_PIPE_PIPE] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK] = ACTIONS(4138),
    [anon_sym_on] = ACTIONS(4140),
    [anon_sym_equals] = ACTIONS(4140),
    [anon_sym_by] = ACTIONS(4140),
    [anon_sym_as] = ACTIONS(4140),
    [anon_sym_is] = ACTIONS(4140),
    [anon_sym_DASH_GT] = ACTIONS(4140),
    [anon_sym_with] = ACTIONS(4140),
    [aux_sym_preproc_if_token3] = ACTIONS(4140),
    [aux_sym_preproc_else_token1] = ACTIONS(4140),
    [aux_sym_preproc_elif_token1] = ACTIONS(4140),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3330] = {
    [sym_preproc_region] = STATE(3330),
    [sym_preproc_endregion] = STATE(3330),
    [sym_preproc_line] = STATE(3330),
    [sym_preproc_pragma] = STATE(3330),
    [sym_preproc_nullable] = STATE(3330),
    [sym_preproc_error] = STATE(3330),
    [sym_preproc_warning] = STATE(3330),
    [sym_preproc_define] = STATE(3330),
    [sym_preproc_undef] = STATE(3330),
    [sym__identifier_token] = ACTIONS(4492),
    [anon_sym_alias] = ACTIONS(4492),
    [anon_sym_global] = ACTIONS(4492),
    [anon_sym_LBRACK] = ACTIONS(4494),
    [anon_sym_COLON] = ACTIONS(4494),
    [anon_sym_COMMA] = ACTIONS(4494),
    [anon_sym_LPAREN] = ACTIONS(4494),
    [anon_sym_LBRACE] = ACTIONS(4494),
    [anon_sym_file] = ACTIONS(4492),
    [anon_sym_LT] = ACTIONS(4492),
    [anon_sym_GT] = ACTIONS(4492),
    [anon_sym_where] = ACTIONS(4492),
    [anon_sym_QMARK] = ACTIONS(4492),
    [anon_sym_notnull] = ACTIONS(4492),
    [anon_sym_unmanaged] = ACTIONS(4492),
    [anon_sym_BANG] = ACTIONS(4492),
    [anon_sym_PLUS_PLUS] = ACTIONS(4494),
    [anon_sym_DASH_DASH] = ACTIONS(4494),
    [anon_sym_PLUS] = ACTIONS(4492),
    [anon_sym_DASH] = ACTIONS(4492),
    [anon_sym_STAR] = ACTIONS(4494),
    [anon_sym_SLASH] = ACTIONS(4492),
    [anon_sym_PERCENT] = ACTIONS(4494),
    [anon_sym_CARET] = ACTIONS(4494),
    [anon_sym_PIPE] = ACTIONS(4492),
    [anon_sym_AMP] = ACTIONS(4492),
    [anon_sym_LT_LT] = ACTIONS(4494),
    [anon_sym_GT_GT] = ACTIONS(4492),
    [anon_sym_GT_GT_GT] = ACTIONS(4494),
    [anon_sym_EQ_EQ] = ACTIONS(4494),
    [anon_sym_BANG_EQ] = ACTIONS(4494),
    [anon_sym_GT_EQ] = ACTIONS(4494),
    [anon_sym_LT_EQ] = ACTIONS(4494),
    [anon_sym_DOT] = ACTIONS(4492),
    [anon_sym_scoped] = ACTIONS(4492),
    [anon_sym_var] = ACTIONS(4492),
    [anon_sym_yield] = ACTIONS(4492),
    [anon_sym_switch] = ACTIONS(4492),
    [anon_sym_when] = ACTIONS(4492),
    [sym_discard] = ACTIONS(4492),
    [anon_sym_DOT_DOT] = ACTIONS(4494),
    [anon_sym_and] = ACTIONS(4492),
    [anon_sym_or] = ACTIONS(4492),
    [anon_sym_AMP_AMP] = ACTIONS(4494),
    [anon_sym_PIPE_PIPE] = ACTIONS(4494),
    [anon_sym_QMARK_QMARK] = ACTIONS(4494),
    [anon_sym_from] = ACTIONS(4492),
    [anon_sym_into] = ACTIONS(4492),
    [anon_sym_join] = ACTIONS(4492),
    [anon_sym_on] = ACTIONS(4492),
    [anon_sym_equals] = ACTIONS(4492),
    [anon_sym_let] = ACTIONS(4492),
    [anon_sym_orderby] = ACTIONS(4492),
    [anon_sym_ascending] = ACTIONS(4492),
    [anon_sym_descending] = ACTIONS(4492),
    [anon_sym_group] = ACTIONS(4492),
    [anon_sym_by] = ACTIONS(4492),
    [anon_sym_select] = ACTIONS(4492),
    [anon_sym_as] = ACTIONS(4492),
    [anon_sym_is] = ACTIONS(4492),
    [anon_sym_DASH_GT] = ACTIONS(4494),
    [anon_sym_with] = ACTIONS(4492),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4494),
  },
  [3331] = {
    [sym_preproc_region] = STATE(3331),
    [sym_preproc_endregion] = STATE(3331),
    [sym_preproc_line] = STATE(3331),
    [sym_preproc_pragma] = STATE(3331),
    [sym_preproc_nullable] = STATE(3331),
    [sym_preproc_error] = STATE(3331),
    [sym_preproc_warning] = STATE(3331),
    [sym_preproc_define] = STATE(3331),
    [sym_preproc_undef] = STATE(3331),
    [sym__identifier_token] = ACTIONS(4149),
    [anon_sym_alias] = ACTIONS(4149),
    [anon_sym_global] = ACTIONS(4149),
    [anon_sym_LBRACK] = ACTIONS(4151),
    [anon_sym_COLON] = ACTIONS(4151),
    [anon_sym_COMMA] = ACTIONS(4151),
    [anon_sym_LPAREN] = ACTIONS(4151),
    [anon_sym_LBRACE] = ACTIONS(4151),
    [anon_sym_file] = ACTIONS(4149),
    [anon_sym_LT] = ACTIONS(4149),
    [anon_sym_GT] = ACTIONS(4149),
    [anon_sym_where] = ACTIONS(4149),
    [anon_sym_QMARK] = ACTIONS(4149),
    [anon_sym_notnull] = ACTIONS(4149),
    [anon_sym_unmanaged] = ACTIONS(4149),
    [anon_sym_BANG] = ACTIONS(4149),
    [anon_sym_PLUS_PLUS] = ACTIONS(4151),
    [anon_sym_DASH_DASH] = ACTIONS(4151),
    [anon_sym_PLUS] = ACTIONS(4149),
    [anon_sym_DASH] = ACTIONS(4149),
    [anon_sym_STAR] = ACTIONS(4151),
    [anon_sym_SLASH] = ACTIONS(4149),
    [anon_sym_PERCENT] = ACTIONS(4151),
    [anon_sym_CARET] = ACTIONS(4151),
    [anon_sym_PIPE] = ACTIONS(4149),
    [anon_sym_AMP] = ACTIONS(4149),
    [anon_sym_LT_LT] = ACTIONS(4151),
    [anon_sym_GT_GT] = ACTIONS(4149),
    [anon_sym_GT_GT_GT] = ACTIONS(4151),
    [anon_sym_EQ_EQ] = ACTIONS(4151),
    [anon_sym_BANG_EQ] = ACTIONS(4151),
    [anon_sym_GT_EQ] = ACTIONS(4151),
    [anon_sym_LT_EQ] = ACTIONS(4151),
    [anon_sym_DOT] = ACTIONS(4149),
    [anon_sym_scoped] = ACTIONS(4149),
    [anon_sym_var] = ACTIONS(4149),
    [anon_sym_yield] = ACTIONS(4149),
    [anon_sym_switch] = ACTIONS(4149),
    [anon_sym_when] = ACTIONS(4149),
    [sym_discard] = ACTIONS(4149),
    [anon_sym_DOT_DOT] = ACTIONS(4151),
    [anon_sym_and] = ACTIONS(4149),
    [anon_sym_or] = ACTIONS(4149),
    [anon_sym_AMP_AMP] = ACTIONS(4151),
    [anon_sym_PIPE_PIPE] = ACTIONS(4151),
    [anon_sym_QMARK_QMARK] = ACTIONS(4151),
    [anon_sym_from] = ACTIONS(4149),
    [anon_sym_into] = ACTIONS(4149),
    [anon_sym_join] = ACTIONS(4149),
    [anon_sym_on] = ACTIONS(4149),
    [anon_sym_equals] = ACTIONS(4149),
    [anon_sym_let] = ACTIONS(4149),
    [anon_sym_orderby] = ACTIONS(4149),
    [anon_sym_ascending] = ACTIONS(4149),
    [anon_sym_descending] = ACTIONS(4149),
    [anon_sym_group] = ACTIONS(4149),
    [anon_sym_by] = ACTIONS(4149),
    [anon_sym_select] = ACTIONS(4149),
    [anon_sym_as] = ACTIONS(4149),
    [anon_sym_is] = ACTIONS(4149),
    [anon_sym_DASH_GT] = ACTIONS(4151),
    [anon_sym_with] = ACTIONS(4149),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4151),
  },
  [3332] = {
    [sym_preproc_region] = STATE(3332),
    [sym_preproc_endregion] = STATE(3332),
    [sym_preproc_line] = STATE(3332),
    [sym_preproc_pragma] = STATE(3332),
    [sym_preproc_nullable] = STATE(3332),
    [sym_preproc_error] = STATE(3332),
    [sym_preproc_warning] = STATE(3332),
    [sym_preproc_define] = STATE(3332),
    [sym_preproc_undef] = STATE(3332),
    [sym__identifier_token] = ACTIONS(4985),
    [anon_sym_extern] = ACTIONS(4985),
    [anon_sym_alias] = ACTIONS(4985),
    [anon_sym_global] = ACTIONS(4985),
    [anon_sym_using] = ACTIONS(4985),
    [anon_sym_unsafe] = ACTIONS(4985),
    [anon_sym_static] = ACTIONS(4985),
    [anon_sym_LBRACK] = ACTIONS(4987),
    [anon_sym_LPAREN] = ACTIONS(4987),
    [anon_sym_event] = ACTIONS(4985),
    [anon_sym_namespace] = ACTIONS(4985),
    [anon_sym_class] = ACTIONS(4985),
    [anon_sym_ref] = ACTIONS(4985),
    [anon_sym_struct] = ACTIONS(4985),
    [anon_sym_enum] = ACTIONS(4985),
    [anon_sym_RBRACE] = ACTIONS(4987),
    [anon_sym_interface] = ACTIONS(4985),
    [anon_sym_delegate] = ACTIONS(4985),
    [anon_sym_record] = ACTIONS(4985),
    [anon_sym_abstract] = ACTIONS(4985),
    [anon_sym_async] = ACTIONS(4985),
    [anon_sym_const] = ACTIONS(4985),
    [anon_sym_file] = ACTIONS(4985),
    [anon_sym_fixed] = ACTIONS(4985),
    [anon_sym_internal] = ACTIONS(4985),
    [anon_sym_new] = ACTIONS(4985),
    [anon_sym_override] = ACTIONS(4985),
    [anon_sym_partial] = ACTIONS(4985),
    [anon_sym_private] = ACTIONS(4985),
    [anon_sym_protected] = ACTIONS(4985),
    [anon_sym_public] = ACTIONS(4985),
    [anon_sym_readonly] = ACTIONS(4985),
    [anon_sym_required] = ACTIONS(4985),
    [anon_sym_sealed] = ACTIONS(4985),
    [anon_sym_virtual] = ACTIONS(4985),
    [anon_sym_volatile] = ACTIONS(4985),
    [anon_sym_where] = ACTIONS(4985),
    [anon_sym_notnull] = ACTIONS(4985),
    [anon_sym_unmanaged] = ACTIONS(4985),
    [anon_sym_TILDE] = ACTIONS(4987),
    [anon_sym_implicit] = ACTIONS(4985),
    [anon_sym_explicit] = ACTIONS(4985),
    [anon_sym_scoped] = ACTIONS(4985),
    [anon_sym_var] = ACTIONS(4985),
    [sym_predefined_type] = ACTIONS(4985),
    [anon_sym_yield] = ACTIONS(4985),
    [anon_sym_when] = ACTIONS(4985),
    [anon_sym_from] = ACTIONS(4985),
    [anon_sym_into] = ACTIONS(4985),
    [anon_sym_join] = ACTIONS(4985),
    [anon_sym_on] = ACTIONS(4985),
    [anon_sym_equals] = ACTIONS(4985),
    [anon_sym_let] = ACTIONS(4985),
    [anon_sym_orderby] = ACTIONS(4985),
    [anon_sym_ascending] = ACTIONS(4985),
    [anon_sym_descending] = ACTIONS(4985),
    [anon_sym_group] = ACTIONS(4985),
    [anon_sym_by] = ACTIONS(4985),
    [anon_sym_select] = ACTIONS(4985),
    [aux_sym_preproc_if_token1] = ACTIONS(4987),
    [aux_sym_preproc_if_token3] = ACTIONS(4987),
    [aux_sym_preproc_else_token1] = ACTIONS(4987),
    [aux_sym_preproc_elif_token1] = ACTIONS(4987),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3333] = {
    [sym_preproc_region] = STATE(3333),
    [sym_preproc_endregion] = STATE(3333),
    [sym_preproc_line] = STATE(3333),
    [sym_preproc_pragma] = STATE(3333),
    [sym_preproc_nullable] = STATE(3333),
    [sym_preproc_error] = STATE(3333),
    [sym_preproc_warning] = STATE(3333),
    [sym_preproc_define] = STATE(3333),
    [sym_preproc_undef] = STATE(3333),
    [sym__identifier_token] = ACTIONS(4989),
    [anon_sym_extern] = ACTIONS(4989),
    [anon_sym_alias] = ACTIONS(4989),
    [anon_sym_global] = ACTIONS(4989),
    [anon_sym_using] = ACTIONS(4989),
    [anon_sym_unsafe] = ACTIONS(4989),
    [anon_sym_static] = ACTIONS(4989),
    [anon_sym_LBRACK] = ACTIONS(4991),
    [anon_sym_LPAREN] = ACTIONS(4991),
    [anon_sym_event] = ACTIONS(4989),
    [anon_sym_namespace] = ACTIONS(4989),
    [anon_sym_class] = ACTIONS(4989),
    [anon_sym_ref] = ACTIONS(4989),
    [anon_sym_struct] = ACTIONS(4989),
    [anon_sym_enum] = ACTIONS(4989),
    [anon_sym_RBRACE] = ACTIONS(4991),
    [anon_sym_interface] = ACTIONS(4989),
    [anon_sym_delegate] = ACTIONS(4989),
    [anon_sym_record] = ACTIONS(4989),
    [anon_sym_abstract] = ACTIONS(4989),
    [anon_sym_async] = ACTIONS(4989),
    [anon_sym_const] = ACTIONS(4989),
    [anon_sym_file] = ACTIONS(4989),
    [anon_sym_fixed] = ACTIONS(4989),
    [anon_sym_internal] = ACTIONS(4989),
    [anon_sym_new] = ACTIONS(4989),
    [anon_sym_override] = ACTIONS(4989),
    [anon_sym_partial] = ACTIONS(4989),
    [anon_sym_private] = ACTIONS(4989),
    [anon_sym_protected] = ACTIONS(4989),
    [anon_sym_public] = ACTIONS(4989),
    [anon_sym_readonly] = ACTIONS(4989),
    [anon_sym_required] = ACTIONS(4989),
    [anon_sym_sealed] = ACTIONS(4989),
    [anon_sym_virtual] = ACTIONS(4989),
    [anon_sym_volatile] = ACTIONS(4989),
    [anon_sym_where] = ACTIONS(4989),
    [anon_sym_notnull] = ACTIONS(4989),
    [anon_sym_unmanaged] = ACTIONS(4989),
    [anon_sym_TILDE] = ACTIONS(4991),
    [anon_sym_implicit] = ACTIONS(4989),
    [anon_sym_explicit] = ACTIONS(4989),
    [anon_sym_scoped] = ACTIONS(4989),
    [anon_sym_var] = ACTIONS(4989),
    [sym_predefined_type] = ACTIONS(4989),
    [anon_sym_yield] = ACTIONS(4989),
    [anon_sym_when] = ACTIONS(4989),
    [anon_sym_from] = ACTIONS(4989),
    [anon_sym_into] = ACTIONS(4989),
    [anon_sym_join] = ACTIONS(4989),
    [anon_sym_on] = ACTIONS(4989),
    [anon_sym_equals] = ACTIONS(4989),
    [anon_sym_let] = ACTIONS(4989),
    [anon_sym_orderby] = ACTIONS(4989),
    [anon_sym_ascending] = ACTIONS(4989),
    [anon_sym_descending] = ACTIONS(4989),
    [anon_sym_group] = ACTIONS(4989),
    [anon_sym_by] = ACTIONS(4989),
    [anon_sym_select] = ACTIONS(4989),
    [aux_sym_preproc_if_token1] = ACTIONS(4991),
    [aux_sym_preproc_if_token3] = ACTIONS(4991),
    [aux_sym_preproc_else_token1] = ACTIONS(4991),
    [aux_sym_preproc_elif_token1] = ACTIONS(4991),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3334] = {
    [sym_preproc_region] = STATE(3334),
    [sym_preproc_endregion] = STATE(3334),
    [sym_preproc_line] = STATE(3334),
    [sym_preproc_pragma] = STATE(3334),
    [sym_preproc_nullable] = STATE(3334),
    [sym_preproc_error] = STATE(3334),
    [sym_preproc_warning] = STATE(3334),
    [sym_preproc_define] = STATE(3334),
    [sym_preproc_undef] = STATE(3334),
    [sym__identifier_token] = ACTIONS(4993),
    [anon_sym_extern] = ACTIONS(4993),
    [anon_sym_alias] = ACTIONS(4993),
    [anon_sym_global] = ACTIONS(4993),
    [anon_sym_using] = ACTIONS(4993),
    [anon_sym_unsafe] = ACTIONS(4993),
    [anon_sym_static] = ACTIONS(4993),
    [anon_sym_LBRACK] = ACTIONS(4995),
    [anon_sym_LPAREN] = ACTIONS(4995),
    [anon_sym_event] = ACTIONS(4993),
    [anon_sym_namespace] = ACTIONS(4993),
    [anon_sym_class] = ACTIONS(4993),
    [anon_sym_ref] = ACTIONS(4993),
    [anon_sym_struct] = ACTIONS(4993),
    [anon_sym_enum] = ACTIONS(4993),
    [anon_sym_RBRACE] = ACTIONS(4995),
    [anon_sym_interface] = ACTIONS(4993),
    [anon_sym_delegate] = ACTIONS(4993),
    [anon_sym_record] = ACTIONS(4993),
    [anon_sym_abstract] = ACTIONS(4993),
    [anon_sym_async] = ACTIONS(4993),
    [anon_sym_const] = ACTIONS(4993),
    [anon_sym_file] = ACTIONS(4993),
    [anon_sym_fixed] = ACTIONS(4993),
    [anon_sym_internal] = ACTIONS(4993),
    [anon_sym_new] = ACTIONS(4993),
    [anon_sym_override] = ACTIONS(4993),
    [anon_sym_partial] = ACTIONS(4993),
    [anon_sym_private] = ACTIONS(4993),
    [anon_sym_protected] = ACTIONS(4993),
    [anon_sym_public] = ACTIONS(4993),
    [anon_sym_readonly] = ACTIONS(4993),
    [anon_sym_required] = ACTIONS(4993),
    [anon_sym_sealed] = ACTIONS(4993),
    [anon_sym_virtual] = ACTIONS(4993),
    [anon_sym_volatile] = ACTIONS(4993),
    [anon_sym_where] = ACTIONS(4993),
    [anon_sym_notnull] = ACTIONS(4993),
    [anon_sym_unmanaged] = ACTIONS(4993),
    [anon_sym_TILDE] = ACTIONS(4995),
    [anon_sym_implicit] = ACTIONS(4993),
    [anon_sym_explicit] = ACTIONS(4993),
    [anon_sym_scoped] = ACTIONS(4993),
    [anon_sym_var] = ACTIONS(4993),
    [sym_predefined_type] = ACTIONS(4993),
    [anon_sym_yield] = ACTIONS(4993),
    [anon_sym_when] = ACTIONS(4993),
    [anon_sym_from] = ACTIONS(4993),
    [anon_sym_into] = ACTIONS(4993),
    [anon_sym_join] = ACTIONS(4993),
    [anon_sym_on] = ACTIONS(4993),
    [anon_sym_equals] = ACTIONS(4993),
    [anon_sym_let] = ACTIONS(4993),
    [anon_sym_orderby] = ACTIONS(4993),
    [anon_sym_ascending] = ACTIONS(4993),
    [anon_sym_descending] = ACTIONS(4993),
    [anon_sym_group] = ACTIONS(4993),
    [anon_sym_by] = ACTIONS(4993),
    [anon_sym_select] = ACTIONS(4993),
    [aux_sym_preproc_if_token1] = ACTIONS(4995),
    [aux_sym_preproc_if_token3] = ACTIONS(4995),
    [aux_sym_preproc_else_token1] = ACTIONS(4995),
    [aux_sym_preproc_elif_token1] = ACTIONS(4995),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3335] = {
    [sym_preproc_region] = STATE(3335),
    [sym_preproc_endregion] = STATE(3335),
    [sym_preproc_line] = STATE(3335),
    [sym_preproc_pragma] = STATE(3335),
    [sym_preproc_nullable] = STATE(3335),
    [sym_preproc_error] = STATE(3335),
    [sym_preproc_warning] = STATE(3335),
    [sym_preproc_define] = STATE(3335),
    [sym_preproc_undef] = STATE(3335),
    [sym__identifier_token] = ACTIONS(4997),
    [anon_sym_extern] = ACTIONS(4997),
    [anon_sym_alias] = ACTIONS(4997),
    [anon_sym_global] = ACTIONS(4997),
    [anon_sym_using] = ACTIONS(4997),
    [anon_sym_unsafe] = ACTIONS(4997),
    [anon_sym_static] = ACTIONS(4997),
    [anon_sym_LBRACK] = ACTIONS(4999),
    [anon_sym_LPAREN] = ACTIONS(4999),
    [anon_sym_event] = ACTIONS(4997),
    [anon_sym_namespace] = ACTIONS(4997),
    [anon_sym_class] = ACTIONS(4997),
    [anon_sym_ref] = ACTIONS(4997),
    [anon_sym_struct] = ACTIONS(4997),
    [anon_sym_enum] = ACTIONS(4997),
    [anon_sym_RBRACE] = ACTIONS(4999),
    [anon_sym_interface] = ACTIONS(4997),
    [anon_sym_delegate] = ACTIONS(4997),
    [anon_sym_record] = ACTIONS(4997),
    [anon_sym_abstract] = ACTIONS(4997),
    [anon_sym_async] = ACTIONS(4997),
    [anon_sym_const] = ACTIONS(4997),
    [anon_sym_file] = ACTIONS(4997),
    [anon_sym_fixed] = ACTIONS(4997),
    [anon_sym_internal] = ACTIONS(4997),
    [anon_sym_new] = ACTIONS(4997),
    [anon_sym_override] = ACTIONS(4997),
    [anon_sym_partial] = ACTIONS(4997),
    [anon_sym_private] = ACTIONS(4997),
    [anon_sym_protected] = ACTIONS(4997),
    [anon_sym_public] = ACTIONS(4997),
    [anon_sym_readonly] = ACTIONS(4997),
    [anon_sym_required] = ACTIONS(4997),
    [anon_sym_sealed] = ACTIONS(4997),
    [anon_sym_virtual] = ACTIONS(4997),
    [anon_sym_volatile] = ACTIONS(4997),
    [anon_sym_where] = ACTIONS(4997),
    [anon_sym_notnull] = ACTIONS(4997),
    [anon_sym_unmanaged] = ACTIONS(4997),
    [anon_sym_TILDE] = ACTIONS(4999),
    [anon_sym_implicit] = ACTIONS(4997),
    [anon_sym_explicit] = ACTIONS(4997),
    [anon_sym_scoped] = ACTIONS(4997),
    [anon_sym_var] = ACTIONS(4997),
    [sym_predefined_type] = ACTIONS(4997),
    [anon_sym_yield] = ACTIONS(4997),
    [anon_sym_when] = ACTIONS(4997),
    [anon_sym_from] = ACTIONS(4997),
    [anon_sym_into] = ACTIONS(4997),
    [anon_sym_join] = ACTIONS(4997),
    [anon_sym_on] = ACTIONS(4997),
    [anon_sym_equals] = ACTIONS(4997),
    [anon_sym_let] = ACTIONS(4997),
    [anon_sym_orderby] = ACTIONS(4997),
    [anon_sym_ascending] = ACTIONS(4997),
    [anon_sym_descending] = ACTIONS(4997),
    [anon_sym_group] = ACTIONS(4997),
    [anon_sym_by] = ACTIONS(4997),
    [anon_sym_select] = ACTIONS(4997),
    [aux_sym_preproc_if_token1] = ACTIONS(4999),
    [aux_sym_preproc_if_token3] = ACTIONS(4999),
    [aux_sym_preproc_else_token1] = ACTIONS(4999),
    [aux_sym_preproc_elif_token1] = ACTIONS(4999),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3336] = {
    [sym_preproc_region] = STATE(3336),
    [sym_preproc_endregion] = STATE(3336),
    [sym_preproc_line] = STATE(3336),
    [sym_preproc_pragma] = STATE(3336),
    [sym_preproc_nullable] = STATE(3336),
    [sym_preproc_error] = STATE(3336),
    [sym_preproc_warning] = STATE(3336),
    [sym_preproc_define] = STATE(3336),
    [sym_preproc_undef] = STATE(3336),
    [sym__identifier_token] = ACTIONS(5001),
    [anon_sym_extern] = ACTIONS(5001),
    [anon_sym_alias] = ACTIONS(5001),
    [anon_sym_global] = ACTIONS(5001),
    [anon_sym_using] = ACTIONS(5001),
    [anon_sym_unsafe] = ACTIONS(5001),
    [anon_sym_static] = ACTIONS(5001),
    [anon_sym_LBRACK] = ACTIONS(5003),
    [anon_sym_LPAREN] = ACTIONS(5003),
    [anon_sym_event] = ACTIONS(5001),
    [anon_sym_namespace] = ACTIONS(5001),
    [anon_sym_class] = ACTIONS(5001),
    [anon_sym_ref] = ACTIONS(5001),
    [anon_sym_struct] = ACTIONS(5001),
    [anon_sym_enum] = ACTIONS(5001),
    [anon_sym_RBRACE] = ACTIONS(5003),
    [anon_sym_interface] = ACTIONS(5001),
    [anon_sym_delegate] = ACTIONS(5001),
    [anon_sym_record] = ACTIONS(5001),
    [anon_sym_abstract] = ACTIONS(5001),
    [anon_sym_async] = ACTIONS(5001),
    [anon_sym_const] = ACTIONS(5001),
    [anon_sym_file] = ACTIONS(5001),
    [anon_sym_fixed] = ACTIONS(5001),
    [anon_sym_internal] = ACTIONS(5001),
    [anon_sym_new] = ACTIONS(5001),
    [anon_sym_override] = ACTIONS(5001),
    [anon_sym_partial] = ACTIONS(5001),
    [anon_sym_private] = ACTIONS(5001),
    [anon_sym_protected] = ACTIONS(5001),
    [anon_sym_public] = ACTIONS(5001),
    [anon_sym_readonly] = ACTIONS(5001),
    [anon_sym_required] = ACTIONS(5001),
    [anon_sym_sealed] = ACTIONS(5001),
    [anon_sym_virtual] = ACTIONS(5001),
    [anon_sym_volatile] = ACTIONS(5001),
    [anon_sym_where] = ACTIONS(5001),
    [anon_sym_notnull] = ACTIONS(5001),
    [anon_sym_unmanaged] = ACTIONS(5001),
    [anon_sym_TILDE] = ACTIONS(5003),
    [anon_sym_implicit] = ACTIONS(5001),
    [anon_sym_explicit] = ACTIONS(5001),
    [anon_sym_scoped] = ACTIONS(5001),
    [anon_sym_var] = ACTIONS(5001),
    [sym_predefined_type] = ACTIONS(5001),
    [anon_sym_yield] = ACTIONS(5001),
    [anon_sym_when] = ACTIONS(5001),
    [anon_sym_from] = ACTIONS(5001),
    [anon_sym_into] = ACTIONS(5001),
    [anon_sym_join] = ACTIONS(5001),
    [anon_sym_on] = ACTIONS(5001),
    [anon_sym_equals] = ACTIONS(5001),
    [anon_sym_let] = ACTIONS(5001),
    [anon_sym_orderby] = ACTIONS(5001),
    [anon_sym_ascending] = ACTIONS(5001),
    [anon_sym_descending] = ACTIONS(5001),
    [anon_sym_group] = ACTIONS(5001),
    [anon_sym_by] = ACTIONS(5001),
    [anon_sym_select] = ACTIONS(5001),
    [aux_sym_preproc_if_token1] = ACTIONS(5003),
    [aux_sym_preproc_if_token3] = ACTIONS(5003),
    [aux_sym_preproc_else_token1] = ACTIONS(5003),
    [aux_sym_preproc_elif_token1] = ACTIONS(5003),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3337] = {
    [sym_preproc_region] = STATE(3337),
    [sym_preproc_endregion] = STATE(3337),
    [sym_preproc_line] = STATE(3337),
    [sym_preproc_pragma] = STATE(3337),
    [sym_preproc_nullable] = STATE(3337),
    [sym_preproc_error] = STATE(3337),
    [sym_preproc_warning] = STATE(3337),
    [sym_preproc_define] = STATE(3337),
    [sym_preproc_undef] = STATE(3337),
    [sym__identifier_token] = ACTIONS(5005),
    [anon_sym_extern] = ACTIONS(5005),
    [anon_sym_alias] = ACTIONS(5005),
    [anon_sym_global] = ACTIONS(5005),
    [anon_sym_using] = ACTIONS(5005),
    [anon_sym_unsafe] = ACTIONS(5005),
    [anon_sym_static] = ACTIONS(5005),
    [anon_sym_LBRACK] = ACTIONS(5007),
    [anon_sym_LPAREN] = ACTIONS(5007),
    [anon_sym_event] = ACTIONS(5005),
    [anon_sym_namespace] = ACTIONS(5005),
    [anon_sym_class] = ACTIONS(5005),
    [anon_sym_ref] = ACTIONS(5005),
    [anon_sym_struct] = ACTIONS(5005),
    [anon_sym_enum] = ACTIONS(5005),
    [anon_sym_RBRACE] = ACTIONS(5007),
    [anon_sym_interface] = ACTIONS(5005),
    [anon_sym_delegate] = ACTIONS(5005),
    [anon_sym_record] = ACTIONS(5005),
    [anon_sym_abstract] = ACTIONS(5005),
    [anon_sym_async] = ACTIONS(5005),
    [anon_sym_const] = ACTIONS(5005),
    [anon_sym_file] = ACTIONS(5005),
    [anon_sym_fixed] = ACTIONS(5005),
    [anon_sym_internal] = ACTIONS(5005),
    [anon_sym_new] = ACTIONS(5005),
    [anon_sym_override] = ACTIONS(5005),
    [anon_sym_partial] = ACTIONS(5005),
    [anon_sym_private] = ACTIONS(5005),
    [anon_sym_protected] = ACTIONS(5005),
    [anon_sym_public] = ACTIONS(5005),
    [anon_sym_readonly] = ACTIONS(5005),
    [anon_sym_required] = ACTIONS(5005),
    [anon_sym_sealed] = ACTIONS(5005),
    [anon_sym_virtual] = ACTIONS(5005),
    [anon_sym_volatile] = ACTIONS(5005),
    [anon_sym_where] = ACTIONS(5005),
    [anon_sym_notnull] = ACTIONS(5005),
    [anon_sym_unmanaged] = ACTIONS(5005),
    [anon_sym_TILDE] = ACTIONS(5007),
    [anon_sym_implicit] = ACTIONS(5005),
    [anon_sym_explicit] = ACTIONS(5005),
    [anon_sym_scoped] = ACTIONS(5005),
    [anon_sym_var] = ACTIONS(5005),
    [sym_predefined_type] = ACTIONS(5005),
    [anon_sym_yield] = ACTIONS(5005),
    [anon_sym_when] = ACTIONS(5005),
    [anon_sym_from] = ACTIONS(5005),
    [anon_sym_into] = ACTIONS(5005),
    [anon_sym_join] = ACTIONS(5005),
    [anon_sym_on] = ACTIONS(5005),
    [anon_sym_equals] = ACTIONS(5005),
    [anon_sym_let] = ACTIONS(5005),
    [anon_sym_orderby] = ACTIONS(5005),
    [anon_sym_ascending] = ACTIONS(5005),
    [anon_sym_descending] = ACTIONS(5005),
    [anon_sym_group] = ACTIONS(5005),
    [anon_sym_by] = ACTIONS(5005),
    [anon_sym_select] = ACTIONS(5005),
    [aux_sym_preproc_if_token1] = ACTIONS(5007),
    [aux_sym_preproc_if_token3] = ACTIONS(5007),
    [aux_sym_preproc_else_token1] = ACTIONS(5007),
    [aux_sym_preproc_elif_token1] = ACTIONS(5007),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3338] = {
    [sym_preproc_region] = STATE(3338),
    [sym_preproc_endregion] = STATE(3338),
    [sym_preproc_line] = STATE(3338),
    [sym_preproc_pragma] = STATE(3338),
    [sym_preproc_nullable] = STATE(3338),
    [sym_preproc_error] = STATE(3338),
    [sym_preproc_warning] = STATE(3338),
    [sym_preproc_define] = STATE(3338),
    [sym_preproc_undef] = STATE(3338),
    [sym__identifier_token] = ACTIONS(5009),
    [anon_sym_extern] = ACTIONS(5009),
    [anon_sym_alias] = ACTIONS(5009),
    [anon_sym_global] = ACTIONS(5009),
    [anon_sym_using] = ACTIONS(5009),
    [anon_sym_unsafe] = ACTIONS(5009),
    [anon_sym_static] = ACTIONS(5009),
    [anon_sym_LBRACK] = ACTIONS(5011),
    [anon_sym_LPAREN] = ACTIONS(5011),
    [anon_sym_event] = ACTIONS(5009),
    [anon_sym_namespace] = ACTIONS(5009),
    [anon_sym_class] = ACTIONS(5009),
    [anon_sym_ref] = ACTIONS(5009),
    [anon_sym_struct] = ACTIONS(5009),
    [anon_sym_enum] = ACTIONS(5009),
    [anon_sym_RBRACE] = ACTIONS(5011),
    [anon_sym_interface] = ACTIONS(5009),
    [anon_sym_delegate] = ACTIONS(5009),
    [anon_sym_record] = ACTIONS(5009),
    [anon_sym_abstract] = ACTIONS(5009),
    [anon_sym_async] = ACTIONS(5009),
    [anon_sym_const] = ACTIONS(5009),
    [anon_sym_file] = ACTIONS(5009),
    [anon_sym_fixed] = ACTIONS(5009),
    [anon_sym_internal] = ACTIONS(5009),
    [anon_sym_new] = ACTIONS(5009),
    [anon_sym_override] = ACTIONS(5009),
    [anon_sym_partial] = ACTIONS(5009),
    [anon_sym_private] = ACTIONS(5009),
    [anon_sym_protected] = ACTIONS(5009),
    [anon_sym_public] = ACTIONS(5009),
    [anon_sym_readonly] = ACTIONS(5009),
    [anon_sym_required] = ACTIONS(5009),
    [anon_sym_sealed] = ACTIONS(5009),
    [anon_sym_virtual] = ACTIONS(5009),
    [anon_sym_volatile] = ACTIONS(5009),
    [anon_sym_where] = ACTIONS(5009),
    [anon_sym_notnull] = ACTIONS(5009),
    [anon_sym_unmanaged] = ACTIONS(5009),
    [anon_sym_TILDE] = ACTIONS(5011),
    [anon_sym_implicit] = ACTIONS(5009),
    [anon_sym_explicit] = ACTIONS(5009),
    [anon_sym_scoped] = ACTIONS(5009),
    [anon_sym_var] = ACTIONS(5009),
    [sym_predefined_type] = ACTIONS(5009),
    [anon_sym_yield] = ACTIONS(5009),
    [anon_sym_when] = ACTIONS(5009),
    [anon_sym_from] = ACTIONS(5009),
    [anon_sym_into] = ACTIONS(5009),
    [anon_sym_join] = ACTIONS(5009),
    [anon_sym_on] = ACTIONS(5009),
    [anon_sym_equals] = ACTIONS(5009),
    [anon_sym_let] = ACTIONS(5009),
    [anon_sym_orderby] = ACTIONS(5009),
    [anon_sym_ascending] = ACTIONS(5009),
    [anon_sym_descending] = ACTIONS(5009),
    [anon_sym_group] = ACTIONS(5009),
    [anon_sym_by] = ACTIONS(5009),
    [anon_sym_select] = ACTIONS(5009),
    [aux_sym_preproc_if_token1] = ACTIONS(5011),
    [aux_sym_preproc_if_token3] = ACTIONS(5011),
    [aux_sym_preproc_else_token1] = ACTIONS(5011),
    [aux_sym_preproc_elif_token1] = ACTIONS(5011),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3339] = {
    [sym_preproc_region] = STATE(3339),
    [sym_preproc_endregion] = STATE(3339),
    [sym_preproc_line] = STATE(3339),
    [sym_preproc_pragma] = STATE(3339),
    [sym_preproc_nullable] = STATE(3339),
    [sym_preproc_error] = STATE(3339),
    [sym_preproc_warning] = STATE(3339),
    [sym_preproc_define] = STATE(3339),
    [sym_preproc_undef] = STATE(3339),
    [sym__identifier_token] = ACTIONS(5013),
    [anon_sym_extern] = ACTIONS(5013),
    [anon_sym_alias] = ACTIONS(5013),
    [anon_sym_global] = ACTIONS(5013),
    [anon_sym_using] = ACTIONS(5013),
    [anon_sym_unsafe] = ACTIONS(5013),
    [anon_sym_static] = ACTIONS(5013),
    [anon_sym_LBRACK] = ACTIONS(5015),
    [anon_sym_LPAREN] = ACTIONS(5015),
    [anon_sym_event] = ACTIONS(5013),
    [anon_sym_namespace] = ACTIONS(5013),
    [anon_sym_class] = ACTIONS(5013),
    [anon_sym_ref] = ACTIONS(5013),
    [anon_sym_struct] = ACTIONS(5013),
    [anon_sym_enum] = ACTIONS(5013),
    [anon_sym_RBRACE] = ACTIONS(5015),
    [anon_sym_interface] = ACTIONS(5013),
    [anon_sym_delegate] = ACTIONS(5013),
    [anon_sym_record] = ACTIONS(5013),
    [anon_sym_abstract] = ACTIONS(5013),
    [anon_sym_async] = ACTIONS(5013),
    [anon_sym_const] = ACTIONS(5013),
    [anon_sym_file] = ACTIONS(5013),
    [anon_sym_fixed] = ACTIONS(5013),
    [anon_sym_internal] = ACTIONS(5013),
    [anon_sym_new] = ACTIONS(5013),
    [anon_sym_override] = ACTIONS(5013),
    [anon_sym_partial] = ACTIONS(5013),
    [anon_sym_private] = ACTIONS(5013),
    [anon_sym_protected] = ACTIONS(5013),
    [anon_sym_public] = ACTIONS(5013),
    [anon_sym_readonly] = ACTIONS(5013),
    [anon_sym_required] = ACTIONS(5013),
    [anon_sym_sealed] = ACTIONS(5013),
    [anon_sym_virtual] = ACTIONS(5013),
    [anon_sym_volatile] = ACTIONS(5013),
    [anon_sym_where] = ACTIONS(5013),
    [anon_sym_notnull] = ACTIONS(5013),
    [anon_sym_unmanaged] = ACTIONS(5013),
    [anon_sym_TILDE] = ACTIONS(5015),
    [anon_sym_implicit] = ACTIONS(5013),
    [anon_sym_explicit] = ACTIONS(5013),
    [anon_sym_scoped] = ACTIONS(5013),
    [anon_sym_var] = ACTIONS(5013),
    [sym_predefined_type] = ACTIONS(5013),
    [anon_sym_yield] = ACTIONS(5013),
    [anon_sym_when] = ACTIONS(5013),
    [anon_sym_from] = ACTIONS(5013),
    [anon_sym_into] = ACTIONS(5013),
    [anon_sym_join] = ACTIONS(5013),
    [anon_sym_on] = ACTIONS(5013),
    [anon_sym_equals] = ACTIONS(5013),
    [anon_sym_let] = ACTIONS(5013),
    [anon_sym_orderby] = ACTIONS(5013),
    [anon_sym_ascending] = ACTIONS(5013),
    [anon_sym_descending] = ACTIONS(5013),
    [anon_sym_group] = ACTIONS(5013),
    [anon_sym_by] = ACTIONS(5013),
    [anon_sym_select] = ACTIONS(5013),
    [aux_sym_preproc_if_token1] = ACTIONS(5015),
    [aux_sym_preproc_if_token3] = ACTIONS(5015),
    [aux_sym_preproc_else_token1] = ACTIONS(5015),
    [aux_sym_preproc_elif_token1] = ACTIONS(5015),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3340] = {
    [sym_preproc_region] = STATE(3340),
    [sym_preproc_endregion] = STATE(3340),
    [sym_preproc_line] = STATE(3340),
    [sym_preproc_pragma] = STATE(3340),
    [sym_preproc_nullable] = STATE(3340),
    [sym_preproc_error] = STATE(3340),
    [sym_preproc_warning] = STATE(3340),
    [sym_preproc_define] = STATE(3340),
    [sym_preproc_undef] = STATE(3340),
    [sym__identifier_token] = ACTIONS(5017),
    [anon_sym_extern] = ACTIONS(5017),
    [anon_sym_alias] = ACTIONS(5017),
    [anon_sym_global] = ACTIONS(5017),
    [anon_sym_using] = ACTIONS(5017),
    [anon_sym_unsafe] = ACTIONS(5017),
    [anon_sym_static] = ACTIONS(5017),
    [anon_sym_LBRACK] = ACTIONS(5019),
    [anon_sym_LPAREN] = ACTIONS(5019),
    [anon_sym_event] = ACTIONS(5017),
    [anon_sym_namespace] = ACTIONS(5017),
    [anon_sym_class] = ACTIONS(5017),
    [anon_sym_ref] = ACTIONS(5017),
    [anon_sym_struct] = ACTIONS(5017),
    [anon_sym_enum] = ACTIONS(5017),
    [anon_sym_RBRACE] = ACTIONS(5019),
    [anon_sym_interface] = ACTIONS(5017),
    [anon_sym_delegate] = ACTIONS(5017),
    [anon_sym_record] = ACTIONS(5017),
    [anon_sym_abstract] = ACTIONS(5017),
    [anon_sym_async] = ACTIONS(5017),
    [anon_sym_const] = ACTIONS(5017),
    [anon_sym_file] = ACTIONS(5017),
    [anon_sym_fixed] = ACTIONS(5017),
    [anon_sym_internal] = ACTIONS(5017),
    [anon_sym_new] = ACTIONS(5017),
    [anon_sym_override] = ACTIONS(5017),
    [anon_sym_partial] = ACTIONS(5017),
    [anon_sym_private] = ACTIONS(5017),
    [anon_sym_protected] = ACTIONS(5017),
    [anon_sym_public] = ACTIONS(5017),
    [anon_sym_readonly] = ACTIONS(5017),
    [anon_sym_required] = ACTIONS(5017),
    [anon_sym_sealed] = ACTIONS(5017),
    [anon_sym_virtual] = ACTIONS(5017),
    [anon_sym_volatile] = ACTIONS(5017),
    [anon_sym_where] = ACTIONS(5017),
    [anon_sym_notnull] = ACTIONS(5017),
    [anon_sym_unmanaged] = ACTIONS(5017),
    [anon_sym_TILDE] = ACTIONS(5019),
    [anon_sym_implicit] = ACTIONS(5017),
    [anon_sym_explicit] = ACTIONS(5017),
    [anon_sym_scoped] = ACTIONS(5017),
    [anon_sym_var] = ACTIONS(5017),
    [sym_predefined_type] = ACTIONS(5017),
    [anon_sym_yield] = ACTIONS(5017),
    [anon_sym_when] = ACTIONS(5017),
    [anon_sym_from] = ACTIONS(5017),
    [anon_sym_into] = ACTIONS(5017),
    [anon_sym_join] = ACTIONS(5017),
    [anon_sym_on] = ACTIONS(5017),
    [anon_sym_equals] = ACTIONS(5017),
    [anon_sym_let] = ACTIONS(5017),
    [anon_sym_orderby] = ACTIONS(5017),
    [anon_sym_ascending] = ACTIONS(5017),
    [anon_sym_descending] = ACTIONS(5017),
    [anon_sym_group] = ACTIONS(5017),
    [anon_sym_by] = ACTIONS(5017),
    [anon_sym_select] = ACTIONS(5017),
    [aux_sym_preproc_if_token1] = ACTIONS(5019),
    [aux_sym_preproc_if_token3] = ACTIONS(5019),
    [aux_sym_preproc_else_token1] = ACTIONS(5019),
    [aux_sym_preproc_elif_token1] = ACTIONS(5019),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3341] = {
    [sym_preproc_region] = STATE(3341),
    [sym_preproc_endregion] = STATE(3341),
    [sym_preproc_line] = STATE(3341),
    [sym_preproc_pragma] = STATE(3341),
    [sym_preproc_nullable] = STATE(3341),
    [sym_preproc_error] = STATE(3341),
    [sym_preproc_warning] = STATE(3341),
    [sym_preproc_define] = STATE(3341),
    [sym_preproc_undef] = STATE(3341),
    [sym__identifier_token] = ACTIONS(3581),
    [anon_sym_extern] = ACTIONS(3581),
    [anon_sym_alias] = ACTIONS(3581),
    [anon_sym_global] = ACTIONS(3581),
    [anon_sym_using] = ACTIONS(3581),
    [anon_sym_unsafe] = ACTIONS(3581),
    [anon_sym_static] = ACTIONS(3581),
    [anon_sym_LBRACK] = ACTIONS(3583),
    [anon_sym_LPAREN] = ACTIONS(3583),
    [anon_sym_event] = ACTIONS(3581),
    [anon_sym_namespace] = ACTIONS(3581),
    [anon_sym_class] = ACTIONS(3581),
    [anon_sym_ref] = ACTIONS(3581),
    [anon_sym_struct] = ACTIONS(3581),
    [anon_sym_enum] = ACTIONS(3581),
    [anon_sym_RBRACE] = ACTIONS(3583),
    [anon_sym_interface] = ACTIONS(3581),
    [anon_sym_delegate] = ACTIONS(3581),
    [anon_sym_record] = ACTIONS(3581),
    [anon_sym_abstract] = ACTIONS(3581),
    [anon_sym_async] = ACTIONS(3581),
    [anon_sym_const] = ACTIONS(3581),
    [anon_sym_file] = ACTIONS(3581),
    [anon_sym_fixed] = ACTIONS(3581),
    [anon_sym_internal] = ACTIONS(3581),
    [anon_sym_new] = ACTIONS(3581),
    [anon_sym_override] = ACTIONS(3581),
    [anon_sym_partial] = ACTIONS(3581),
    [anon_sym_private] = ACTIONS(3581),
    [anon_sym_protected] = ACTIONS(3581),
    [anon_sym_public] = ACTIONS(3581),
    [anon_sym_readonly] = ACTIONS(3581),
    [anon_sym_required] = ACTIONS(3581),
    [anon_sym_sealed] = ACTIONS(3581),
    [anon_sym_virtual] = ACTIONS(3581),
    [anon_sym_volatile] = ACTIONS(3581),
    [anon_sym_where] = ACTIONS(3581),
    [anon_sym_notnull] = ACTIONS(3581),
    [anon_sym_unmanaged] = ACTIONS(3581),
    [anon_sym_TILDE] = ACTIONS(3583),
    [anon_sym_implicit] = ACTIONS(3581),
    [anon_sym_explicit] = ACTIONS(3581),
    [anon_sym_scoped] = ACTIONS(3581),
    [anon_sym_var] = ACTIONS(3581),
    [sym_predefined_type] = ACTIONS(3581),
    [anon_sym_yield] = ACTIONS(3581),
    [anon_sym_when] = ACTIONS(3581),
    [anon_sym_from] = ACTIONS(3581),
    [anon_sym_into] = ACTIONS(3581),
    [anon_sym_join] = ACTIONS(3581),
    [anon_sym_on] = ACTIONS(3581),
    [anon_sym_equals] = ACTIONS(3581),
    [anon_sym_let] = ACTIONS(3581),
    [anon_sym_orderby] = ACTIONS(3581),
    [anon_sym_ascending] = ACTIONS(3581),
    [anon_sym_descending] = ACTIONS(3581),
    [anon_sym_group] = ACTIONS(3581),
    [anon_sym_by] = ACTIONS(3581),
    [anon_sym_select] = ACTIONS(3581),
    [aux_sym_preproc_if_token1] = ACTIONS(3583),
    [aux_sym_preproc_if_token3] = ACTIONS(3583),
    [aux_sym_preproc_else_token1] = ACTIONS(3583),
    [aux_sym_preproc_elif_token1] = ACTIONS(3583),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3342] = {
    [sym_preproc_region] = STATE(3342),
    [sym_preproc_endregion] = STATE(3342),
    [sym_preproc_line] = STATE(3342),
    [sym_preproc_pragma] = STATE(3342),
    [sym_preproc_nullable] = STATE(3342),
    [sym_preproc_error] = STATE(3342),
    [sym_preproc_warning] = STATE(3342),
    [sym_preproc_define] = STATE(3342),
    [sym_preproc_undef] = STATE(3342),
    [sym__identifier_token] = ACTIONS(5021),
    [anon_sym_extern] = ACTIONS(5021),
    [anon_sym_alias] = ACTIONS(5021),
    [anon_sym_global] = ACTIONS(5021),
    [anon_sym_using] = ACTIONS(5021),
    [anon_sym_unsafe] = ACTIONS(5021),
    [anon_sym_static] = ACTIONS(5021),
    [anon_sym_LBRACK] = ACTIONS(5023),
    [anon_sym_LPAREN] = ACTIONS(5023),
    [anon_sym_event] = ACTIONS(5021),
    [anon_sym_namespace] = ACTIONS(5021),
    [anon_sym_class] = ACTIONS(5021),
    [anon_sym_ref] = ACTIONS(5021),
    [anon_sym_struct] = ACTIONS(5021),
    [anon_sym_enum] = ACTIONS(5021),
    [anon_sym_RBRACE] = ACTIONS(5023),
    [anon_sym_interface] = ACTIONS(5021),
    [anon_sym_delegate] = ACTIONS(5021),
    [anon_sym_record] = ACTIONS(5021),
    [anon_sym_abstract] = ACTIONS(5021),
    [anon_sym_async] = ACTIONS(5021),
    [anon_sym_const] = ACTIONS(5021),
    [anon_sym_file] = ACTIONS(5021),
    [anon_sym_fixed] = ACTIONS(5021),
    [anon_sym_internal] = ACTIONS(5021),
    [anon_sym_new] = ACTIONS(5021),
    [anon_sym_override] = ACTIONS(5021),
    [anon_sym_partial] = ACTIONS(5021),
    [anon_sym_private] = ACTIONS(5021),
    [anon_sym_protected] = ACTIONS(5021),
    [anon_sym_public] = ACTIONS(5021),
    [anon_sym_readonly] = ACTIONS(5021),
    [anon_sym_required] = ACTIONS(5021),
    [anon_sym_sealed] = ACTIONS(5021),
    [anon_sym_virtual] = ACTIONS(5021),
    [anon_sym_volatile] = ACTIONS(5021),
    [anon_sym_where] = ACTIONS(5021),
    [anon_sym_notnull] = ACTIONS(5021),
    [anon_sym_unmanaged] = ACTIONS(5021),
    [anon_sym_TILDE] = ACTIONS(5023),
    [anon_sym_implicit] = ACTIONS(5021),
    [anon_sym_explicit] = ACTIONS(5021),
    [anon_sym_scoped] = ACTIONS(5021),
    [anon_sym_var] = ACTIONS(5021),
    [sym_predefined_type] = ACTIONS(5021),
    [anon_sym_yield] = ACTIONS(5021),
    [anon_sym_when] = ACTIONS(5021),
    [anon_sym_from] = ACTIONS(5021),
    [anon_sym_into] = ACTIONS(5021),
    [anon_sym_join] = ACTIONS(5021),
    [anon_sym_on] = ACTIONS(5021),
    [anon_sym_equals] = ACTIONS(5021),
    [anon_sym_let] = ACTIONS(5021),
    [anon_sym_orderby] = ACTIONS(5021),
    [anon_sym_ascending] = ACTIONS(5021),
    [anon_sym_descending] = ACTIONS(5021),
    [anon_sym_group] = ACTIONS(5021),
    [anon_sym_by] = ACTIONS(5021),
    [anon_sym_select] = ACTIONS(5021),
    [aux_sym_preproc_if_token1] = ACTIONS(5023),
    [aux_sym_preproc_if_token3] = ACTIONS(5023),
    [aux_sym_preproc_else_token1] = ACTIONS(5023),
    [aux_sym_preproc_elif_token1] = ACTIONS(5023),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3343] = {
    [sym_preproc_region] = STATE(3343),
    [sym_preproc_endregion] = STATE(3343),
    [sym_preproc_line] = STATE(3343),
    [sym_preproc_pragma] = STATE(3343),
    [sym_preproc_nullable] = STATE(3343),
    [sym_preproc_error] = STATE(3343),
    [sym_preproc_warning] = STATE(3343),
    [sym_preproc_define] = STATE(3343),
    [sym_preproc_undef] = STATE(3343),
    [sym__identifier_token] = ACTIONS(4126),
    [anon_sym_alias] = ACTIONS(4126),
    [anon_sym_global] = ACTIONS(4126),
    [anon_sym_LBRACK] = ACTIONS(4128),
    [anon_sym_COLON] = ACTIONS(4128),
    [anon_sym_COMMA] = ACTIONS(4128),
    [anon_sym_LPAREN] = ACTIONS(4128),
    [anon_sym_LBRACE] = ACTIONS(4128),
    [anon_sym_file] = ACTIONS(4126),
    [anon_sym_LT] = ACTIONS(4126),
    [anon_sym_GT] = ACTIONS(4126),
    [anon_sym_where] = ACTIONS(4126),
    [anon_sym_QMARK] = ACTIONS(4126),
    [anon_sym_notnull] = ACTIONS(4126),
    [anon_sym_unmanaged] = ACTIONS(4126),
    [anon_sym_BANG] = ACTIONS(4126),
    [anon_sym_PLUS_PLUS] = ACTIONS(4128),
    [anon_sym_DASH_DASH] = ACTIONS(4128),
    [anon_sym_PLUS] = ACTIONS(4126),
    [anon_sym_DASH] = ACTIONS(4126),
    [anon_sym_STAR] = ACTIONS(4128),
    [anon_sym_SLASH] = ACTIONS(4126),
    [anon_sym_PERCENT] = ACTIONS(4128),
    [anon_sym_CARET] = ACTIONS(4128),
    [anon_sym_PIPE] = ACTIONS(4126),
    [anon_sym_AMP] = ACTIONS(4126),
    [anon_sym_LT_LT] = ACTIONS(4128),
    [anon_sym_GT_GT] = ACTIONS(4126),
    [anon_sym_GT_GT_GT] = ACTIONS(4128),
    [anon_sym_EQ_EQ] = ACTIONS(4128),
    [anon_sym_BANG_EQ] = ACTIONS(4128),
    [anon_sym_GT_EQ] = ACTIONS(4128),
    [anon_sym_LT_EQ] = ACTIONS(4128),
    [anon_sym_DOT] = ACTIONS(4126),
    [anon_sym_scoped] = ACTIONS(4126),
    [anon_sym_var] = ACTIONS(4126),
    [anon_sym_yield] = ACTIONS(4126),
    [anon_sym_switch] = ACTIONS(4126),
    [anon_sym_when] = ACTIONS(4126),
    [sym_discard] = ACTIONS(4126),
    [anon_sym_DOT_DOT] = ACTIONS(4128),
    [anon_sym_and] = ACTIONS(4126),
    [anon_sym_or] = ACTIONS(4126),
    [anon_sym_AMP_AMP] = ACTIONS(4128),
    [anon_sym_PIPE_PIPE] = ACTIONS(4128),
    [anon_sym_QMARK_QMARK] = ACTIONS(4128),
    [anon_sym_from] = ACTIONS(4126),
    [anon_sym_into] = ACTIONS(4126),
    [anon_sym_join] = ACTIONS(4126),
    [anon_sym_on] = ACTIONS(4126),
    [anon_sym_equals] = ACTIONS(4126),
    [anon_sym_let] = ACTIONS(4126),
    [anon_sym_orderby] = ACTIONS(4126),
    [anon_sym_ascending] = ACTIONS(4126),
    [anon_sym_descending] = ACTIONS(4126),
    [anon_sym_group] = ACTIONS(4126),
    [anon_sym_by] = ACTIONS(4126),
    [anon_sym_select] = ACTIONS(4126),
    [anon_sym_as] = ACTIONS(4126),
    [anon_sym_is] = ACTIONS(4126),
    [anon_sym_DASH_GT] = ACTIONS(4128),
    [anon_sym_with] = ACTIONS(4126),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4128),
  },
  [3344] = {
    [sym_preproc_region] = STATE(3344),
    [sym_preproc_endregion] = STATE(3344),
    [sym_preproc_line] = STATE(3344),
    [sym_preproc_pragma] = STATE(3344),
    [sym_preproc_nullable] = STATE(3344),
    [sym_preproc_error] = STATE(3344),
    [sym_preproc_warning] = STATE(3344),
    [sym_preproc_define] = STATE(3344),
    [sym_preproc_undef] = STATE(3344),
    [sym__identifier_token] = ACTIONS(4134),
    [anon_sym_alias] = ACTIONS(4134),
    [anon_sym_global] = ACTIONS(4134),
    [anon_sym_LBRACK] = ACTIONS(4136),
    [anon_sym_COLON] = ACTIONS(4136),
    [anon_sym_COMMA] = ACTIONS(4136),
    [anon_sym_LPAREN] = ACTIONS(4136),
    [anon_sym_LBRACE] = ACTIONS(4136),
    [anon_sym_file] = ACTIONS(4134),
    [anon_sym_LT] = ACTIONS(4134),
    [anon_sym_GT] = ACTIONS(4134),
    [anon_sym_where] = ACTIONS(4134),
    [anon_sym_QMARK] = ACTIONS(4134),
    [anon_sym_notnull] = ACTIONS(4134),
    [anon_sym_unmanaged] = ACTIONS(4134),
    [anon_sym_BANG] = ACTIONS(4134),
    [anon_sym_PLUS_PLUS] = ACTIONS(4136),
    [anon_sym_DASH_DASH] = ACTIONS(4136),
    [anon_sym_PLUS] = ACTIONS(4134),
    [anon_sym_DASH] = ACTIONS(4134),
    [anon_sym_STAR] = ACTIONS(4136),
    [anon_sym_SLASH] = ACTIONS(4134),
    [anon_sym_PERCENT] = ACTIONS(4136),
    [anon_sym_CARET] = ACTIONS(4136),
    [anon_sym_PIPE] = ACTIONS(4134),
    [anon_sym_AMP] = ACTIONS(4134),
    [anon_sym_LT_LT] = ACTIONS(4136),
    [anon_sym_GT_GT] = ACTIONS(4134),
    [anon_sym_GT_GT_GT] = ACTIONS(4136),
    [anon_sym_EQ_EQ] = ACTIONS(4136),
    [anon_sym_BANG_EQ] = ACTIONS(4136),
    [anon_sym_GT_EQ] = ACTIONS(4136),
    [anon_sym_LT_EQ] = ACTIONS(4136),
    [anon_sym_DOT] = ACTIONS(4134),
    [anon_sym_scoped] = ACTIONS(4134),
    [anon_sym_var] = ACTIONS(4134),
    [anon_sym_yield] = ACTIONS(4134),
    [anon_sym_switch] = ACTIONS(4134),
    [anon_sym_when] = ACTIONS(4134),
    [sym_discard] = ACTIONS(4134),
    [anon_sym_DOT_DOT] = ACTIONS(4136),
    [anon_sym_and] = ACTIONS(4134),
    [anon_sym_or] = ACTIONS(4134),
    [anon_sym_AMP_AMP] = ACTIONS(4136),
    [anon_sym_PIPE_PIPE] = ACTIONS(4136),
    [anon_sym_QMARK_QMARK] = ACTIONS(4136),
    [anon_sym_from] = ACTIONS(4134),
    [anon_sym_into] = ACTIONS(4134),
    [anon_sym_join] = ACTIONS(4134),
    [anon_sym_on] = ACTIONS(4134),
    [anon_sym_equals] = ACTIONS(4134),
    [anon_sym_let] = ACTIONS(4134),
    [anon_sym_orderby] = ACTIONS(4134),
    [anon_sym_ascending] = ACTIONS(4134),
    [anon_sym_descending] = ACTIONS(4134),
    [anon_sym_group] = ACTIONS(4134),
    [anon_sym_by] = ACTIONS(4134),
    [anon_sym_select] = ACTIONS(4134),
    [anon_sym_as] = ACTIONS(4134),
    [anon_sym_is] = ACTIONS(4134),
    [anon_sym_DASH_GT] = ACTIONS(4136),
    [anon_sym_with] = ACTIONS(4134),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4136),
  },
  [3345] = {
    [sym_preproc_region] = STATE(3345),
    [sym_preproc_endregion] = STATE(3345),
    [sym_preproc_line] = STATE(3345),
    [sym_preproc_pragma] = STATE(3345),
    [sym_preproc_nullable] = STATE(3345),
    [sym_preproc_error] = STATE(3345),
    [sym_preproc_warning] = STATE(3345),
    [sym_preproc_define] = STATE(3345),
    [sym_preproc_undef] = STATE(3345),
    [sym__identifier_token] = ACTIONS(3585),
    [anon_sym_extern] = ACTIONS(3585),
    [anon_sym_alias] = ACTIONS(3585),
    [anon_sym_global] = ACTIONS(3585),
    [anon_sym_using] = ACTIONS(3585),
    [anon_sym_unsafe] = ACTIONS(3585),
    [anon_sym_static] = ACTIONS(3585),
    [anon_sym_LBRACK] = ACTIONS(3587),
    [anon_sym_LPAREN] = ACTIONS(3587),
    [anon_sym_event] = ACTIONS(3585),
    [anon_sym_namespace] = ACTIONS(3585),
    [anon_sym_class] = ACTIONS(3585),
    [anon_sym_ref] = ACTIONS(3585),
    [anon_sym_struct] = ACTIONS(3585),
    [anon_sym_enum] = ACTIONS(3585),
    [anon_sym_RBRACE] = ACTIONS(3587),
    [anon_sym_interface] = ACTIONS(3585),
    [anon_sym_delegate] = ACTIONS(3585),
    [anon_sym_record] = ACTIONS(3585),
    [anon_sym_abstract] = ACTIONS(3585),
    [anon_sym_async] = ACTIONS(3585),
    [anon_sym_const] = ACTIONS(3585),
    [anon_sym_file] = ACTIONS(3585),
    [anon_sym_fixed] = ACTIONS(3585),
    [anon_sym_internal] = ACTIONS(3585),
    [anon_sym_new] = ACTIONS(3585),
    [anon_sym_override] = ACTIONS(3585),
    [anon_sym_partial] = ACTIONS(3585),
    [anon_sym_private] = ACTIONS(3585),
    [anon_sym_protected] = ACTIONS(3585),
    [anon_sym_public] = ACTIONS(3585),
    [anon_sym_readonly] = ACTIONS(3585),
    [anon_sym_required] = ACTIONS(3585),
    [anon_sym_sealed] = ACTIONS(3585),
    [anon_sym_virtual] = ACTIONS(3585),
    [anon_sym_volatile] = ACTIONS(3585),
    [anon_sym_where] = ACTIONS(3585),
    [anon_sym_notnull] = ACTIONS(3585),
    [anon_sym_unmanaged] = ACTIONS(3585),
    [anon_sym_TILDE] = ACTIONS(3587),
    [anon_sym_implicit] = ACTIONS(3585),
    [anon_sym_explicit] = ACTIONS(3585),
    [anon_sym_scoped] = ACTIONS(3585),
    [anon_sym_var] = ACTIONS(3585),
    [sym_predefined_type] = ACTIONS(3585),
    [anon_sym_yield] = ACTIONS(3585),
    [anon_sym_when] = ACTIONS(3585),
    [anon_sym_from] = ACTIONS(3585),
    [anon_sym_into] = ACTIONS(3585),
    [anon_sym_join] = ACTIONS(3585),
    [anon_sym_on] = ACTIONS(3585),
    [anon_sym_equals] = ACTIONS(3585),
    [anon_sym_let] = ACTIONS(3585),
    [anon_sym_orderby] = ACTIONS(3585),
    [anon_sym_ascending] = ACTIONS(3585),
    [anon_sym_descending] = ACTIONS(3585),
    [anon_sym_group] = ACTIONS(3585),
    [anon_sym_by] = ACTIONS(3585),
    [anon_sym_select] = ACTIONS(3585),
    [aux_sym_preproc_if_token1] = ACTIONS(3587),
    [aux_sym_preproc_if_token3] = ACTIONS(3587),
    [aux_sym_preproc_else_token1] = ACTIONS(3587),
    [aux_sym_preproc_elif_token1] = ACTIONS(3587),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3346] = {
    [sym_preproc_region] = STATE(3346),
    [sym_preproc_endregion] = STATE(3346),
    [sym_preproc_line] = STATE(3346),
    [sym_preproc_pragma] = STATE(3346),
    [sym_preproc_nullable] = STATE(3346),
    [sym_preproc_error] = STATE(3346),
    [sym_preproc_warning] = STATE(3346),
    [sym_preproc_define] = STATE(3346),
    [sym_preproc_undef] = STATE(3346),
    [sym__identifier_token] = ACTIONS(3589),
    [anon_sym_extern] = ACTIONS(3589),
    [anon_sym_alias] = ACTIONS(3589),
    [anon_sym_global] = ACTIONS(3589),
    [anon_sym_using] = ACTIONS(3589),
    [anon_sym_unsafe] = ACTIONS(3589),
    [anon_sym_static] = ACTIONS(3589),
    [anon_sym_LBRACK] = ACTIONS(3591),
    [anon_sym_LPAREN] = ACTIONS(3591),
    [anon_sym_event] = ACTIONS(3589),
    [anon_sym_namespace] = ACTIONS(3589),
    [anon_sym_class] = ACTIONS(3589),
    [anon_sym_ref] = ACTIONS(3589),
    [anon_sym_struct] = ACTIONS(3589),
    [anon_sym_enum] = ACTIONS(3589),
    [anon_sym_RBRACE] = ACTIONS(3591),
    [anon_sym_interface] = ACTIONS(3589),
    [anon_sym_delegate] = ACTIONS(3589),
    [anon_sym_record] = ACTIONS(3589),
    [anon_sym_abstract] = ACTIONS(3589),
    [anon_sym_async] = ACTIONS(3589),
    [anon_sym_const] = ACTIONS(3589),
    [anon_sym_file] = ACTIONS(3589),
    [anon_sym_fixed] = ACTIONS(3589),
    [anon_sym_internal] = ACTIONS(3589),
    [anon_sym_new] = ACTIONS(3589),
    [anon_sym_override] = ACTIONS(3589),
    [anon_sym_partial] = ACTIONS(3589),
    [anon_sym_private] = ACTIONS(3589),
    [anon_sym_protected] = ACTIONS(3589),
    [anon_sym_public] = ACTIONS(3589),
    [anon_sym_readonly] = ACTIONS(3589),
    [anon_sym_required] = ACTIONS(3589),
    [anon_sym_sealed] = ACTIONS(3589),
    [anon_sym_virtual] = ACTIONS(3589),
    [anon_sym_volatile] = ACTIONS(3589),
    [anon_sym_where] = ACTIONS(3589),
    [anon_sym_notnull] = ACTIONS(3589),
    [anon_sym_unmanaged] = ACTIONS(3589),
    [anon_sym_TILDE] = ACTIONS(3591),
    [anon_sym_implicit] = ACTIONS(3589),
    [anon_sym_explicit] = ACTIONS(3589),
    [anon_sym_scoped] = ACTIONS(3589),
    [anon_sym_var] = ACTIONS(3589),
    [sym_predefined_type] = ACTIONS(3589),
    [anon_sym_yield] = ACTIONS(3589),
    [anon_sym_when] = ACTIONS(3589),
    [anon_sym_from] = ACTIONS(3589),
    [anon_sym_into] = ACTIONS(3589),
    [anon_sym_join] = ACTIONS(3589),
    [anon_sym_on] = ACTIONS(3589),
    [anon_sym_equals] = ACTIONS(3589),
    [anon_sym_let] = ACTIONS(3589),
    [anon_sym_orderby] = ACTIONS(3589),
    [anon_sym_ascending] = ACTIONS(3589),
    [anon_sym_descending] = ACTIONS(3589),
    [anon_sym_group] = ACTIONS(3589),
    [anon_sym_by] = ACTIONS(3589),
    [anon_sym_select] = ACTIONS(3589),
    [aux_sym_preproc_if_token1] = ACTIONS(3591),
    [aux_sym_preproc_if_token3] = ACTIONS(3591),
    [aux_sym_preproc_else_token1] = ACTIONS(3591),
    [aux_sym_preproc_elif_token1] = ACTIONS(3591),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3347] = {
    [sym_preproc_region] = STATE(3347),
    [sym_preproc_endregion] = STATE(3347),
    [sym_preproc_line] = STATE(3347),
    [sym_preproc_pragma] = STATE(3347),
    [sym_preproc_nullable] = STATE(3347),
    [sym_preproc_error] = STATE(3347),
    [sym_preproc_warning] = STATE(3347),
    [sym_preproc_define] = STATE(3347),
    [sym_preproc_undef] = STATE(3347),
    [sym__identifier_token] = ACTIONS(3593),
    [anon_sym_extern] = ACTIONS(3593),
    [anon_sym_alias] = ACTIONS(3593),
    [anon_sym_global] = ACTIONS(3593),
    [anon_sym_using] = ACTIONS(3593),
    [anon_sym_unsafe] = ACTIONS(3593),
    [anon_sym_static] = ACTIONS(3593),
    [anon_sym_LBRACK] = ACTIONS(3595),
    [anon_sym_LPAREN] = ACTIONS(3595),
    [anon_sym_event] = ACTIONS(3593),
    [anon_sym_namespace] = ACTIONS(3593),
    [anon_sym_class] = ACTIONS(3593),
    [anon_sym_ref] = ACTIONS(3593),
    [anon_sym_struct] = ACTIONS(3593),
    [anon_sym_enum] = ACTIONS(3593),
    [anon_sym_RBRACE] = ACTIONS(3595),
    [anon_sym_interface] = ACTIONS(3593),
    [anon_sym_delegate] = ACTIONS(3593),
    [anon_sym_record] = ACTIONS(3593),
    [anon_sym_abstract] = ACTIONS(3593),
    [anon_sym_async] = ACTIONS(3593),
    [anon_sym_const] = ACTIONS(3593),
    [anon_sym_file] = ACTIONS(3593),
    [anon_sym_fixed] = ACTIONS(3593),
    [anon_sym_internal] = ACTIONS(3593),
    [anon_sym_new] = ACTIONS(3593),
    [anon_sym_override] = ACTIONS(3593),
    [anon_sym_partial] = ACTIONS(3593),
    [anon_sym_private] = ACTIONS(3593),
    [anon_sym_protected] = ACTIONS(3593),
    [anon_sym_public] = ACTIONS(3593),
    [anon_sym_readonly] = ACTIONS(3593),
    [anon_sym_required] = ACTIONS(3593),
    [anon_sym_sealed] = ACTIONS(3593),
    [anon_sym_virtual] = ACTIONS(3593),
    [anon_sym_volatile] = ACTIONS(3593),
    [anon_sym_where] = ACTIONS(3593),
    [anon_sym_notnull] = ACTIONS(3593),
    [anon_sym_unmanaged] = ACTIONS(3593),
    [anon_sym_TILDE] = ACTIONS(3595),
    [anon_sym_implicit] = ACTIONS(3593),
    [anon_sym_explicit] = ACTIONS(3593),
    [anon_sym_scoped] = ACTIONS(3593),
    [anon_sym_var] = ACTIONS(3593),
    [sym_predefined_type] = ACTIONS(3593),
    [anon_sym_yield] = ACTIONS(3593),
    [anon_sym_when] = ACTIONS(3593),
    [anon_sym_from] = ACTIONS(3593),
    [anon_sym_into] = ACTIONS(3593),
    [anon_sym_join] = ACTIONS(3593),
    [anon_sym_on] = ACTIONS(3593),
    [anon_sym_equals] = ACTIONS(3593),
    [anon_sym_let] = ACTIONS(3593),
    [anon_sym_orderby] = ACTIONS(3593),
    [anon_sym_ascending] = ACTIONS(3593),
    [anon_sym_descending] = ACTIONS(3593),
    [anon_sym_group] = ACTIONS(3593),
    [anon_sym_by] = ACTIONS(3593),
    [anon_sym_select] = ACTIONS(3593),
    [aux_sym_preproc_if_token1] = ACTIONS(3595),
    [aux_sym_preproc_if_token3] = ACTIONS(3595),
    [aux_sym_preproc_else_token1] = ACTIONS(3595),
    [aux_sym_preproc_elif_token1] = ACTIONS(3595),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3348] = {
    [sym_preproc_region] = STATE(3348),
    [sym_preproc_endregion] = STATE(3348),
    [sym_preproc_line] = STATE(3348),
    [sym_preproc_pragma] = STATE(3348),
    [sym_preproc_nullable] = STATE(3348),
    [sym_preproc_error] = STATE(3348),
    [sym_preproc_warning] = STATE(3348),
    [sym_preproc_define] = STATE(3348),
    [sym_preproc_undef] = STATE(3348),
    [sym__identifier_token] = ACTIONS(3597),
    [anon_sym_extern] = ACTIONS(3597),
    [anon_sym_alias] = ACTIONS(3597),
    [anon_sym_global] = ACTIONS(3597),
    [anon_sym_using] = ACTIONS(3597),
    [anon_sym_unsafe] = ACTIONS(3597),
    [anon_sym_static] = ACTIONS(3597),
    [anon_sym_LBRACK] = ACTIONS(3599),
    [anon_sym_LPAREN] = ACTIONS(3599),
    [anon_sym_event] = ACTIONS(3597),
    [anon_sym_namespace] = ACTIONS(3597),
    [anon_sym_class] = ACTIONS(3597),
    [anon_sym_ref] = ACTIONS(3597),
    [anon_sym_struct] = ACTIONS(3597),
    [anon_sym_enum] = ACTIONS(3597),
    [anon_sym_RBRACE] = ACTIONS(3599),
    [anon_sym_interface] = ACTIONS(3597),
    [anon_sym_delegate] = ACTIONS(3597),
    [anon_sym_record] = ACTIONS(3597),
    [anon_sym_abstract] = ACTIONS(3597),
    [anon_sym_async] = ACTIONS(3597),
    [anon_sym_const] = ACTIONS(3597),
    [anon_sym_file] = ACTIONS(3597),
    [anon_sym_fixed] = ACTIONS(3597),
    [anon_sym_internal] = ACTIONS(3597),
    [anon_sym_new] = ACTIONS(3597),
    [anon_sym_override] = ACTIONS(3597),
    [anon_sym_partial] = ACTIONS(3597),
    [anon_sym_private] = ACTIONS(3597),
    [anon_sym_protected] = ACTIONS(3597),
    [anon_sym_public] = ACTIONS(3597),
    [anon_sym_readonly] = ACTIONS(3597),
    [anon_sym_required] = ACTIONS(3597),
    [anon_sym_sealed] = ACTIONS(3597),
    [anon_sym_virtual] = ACTIONS(3597),
    [anon_sym_volatile] = ACTIONS(3597),
    [anon_sym_where] = ACTIONS(3597),
    [anon_sym_notnull] = ACTIONS(3597),
    [anon_sym_unmanaged] = ACTIONS(3597),
    [anon_sym_TILDE] = ACTIONS(3599),
    [anon_sym_implicit] = ACTIONS(3597),
    [anon_sym_explicit] = ACTIONS(3597),
    [anon_sym_scoped] = ACTIONS(3597),
    [anon_sym_var] = ACTIONS(3597),
    [sym_predefined_type] = ACTIONS(3597),
    [anon_sym_yield] = ACTIONS(3597),
    [anon_sym_when] = ACTIONS(3597),
    [anon_sym_from] = ACTIONS(3597),
    [anon_sym_into] = ACTIONS(3597),
    [anon_sym_join] = ACTIONS(3597),
    [anon_sym_on] = ACTIONS(3597),
    [anon_sym_equals] = ACTIONS(3597),
    [anon_sym_let] = ACTIONS(3597),
    [anon_sym_orderby] = ACTIONS(3597),
    [anon_sym_ascending] = ACTIONS(3597),
    [anon_sym_descending] = ACTIONS(3597),
    [anon_sym_group] = ACTIONS(3597),
    [anon_sym_by] = ACTIONS(3597),
    [anon_sym_select] = ACTIONS(3597),
    [aux_sym_preproc_if_token1] = ACTIONS(3599),
    [aux_sym_preproc_if_token3] = ACTIONS(3599),
    [aux_sym_preproc_else_token1] = ACTIONS(3599),
    [aux_sym_preproc_elif_token1] = ACTIONS(3599),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3349] = {
    [sym_preproc_region] = STATE(3349),
    [sym_preproc_endregion] = STATE(3349),
    [sym_preproc_line] = STATE(3349),
    [sym_preproc_pragma] = STATE(3349),
    [sym_preproc_nullable] = STATE(3349),
    [sym_preproc_error] = STATE(3349),
    [sym_preproc_warning] = STATE(3349),
    [sym_preproc_define] = STATE(3349),
    [sym_preproc_undef] = STATE(3349),
    [sym__identifier_token] = ACTIONS(5025),
    [anon_sym_extern] = ACTIONS(5025),
    [anon_sym_alias] = ACTIONS(5025),
    [anon_sym_global] = ACTIONS(5025),
    [anon_sym_using] = ACTIONS(5025),
    [anon_sym_unsafe] = ACTIONS(5025),
    [anon_sym_static] = ACTIONS(5025),
    [anon_sym_LBRACK] = ACTIONS(5027),
    [anon_sym_LPAREN] = ACTIONS(5027),
    [anon_sym_event] = ACTIONS(5025),
    [anon_sym_namespace] = ACTIONS(5025),
    [anon_sym_class] = ACTIONS(5025),
    [anon_sym_ref] = ACTIONS(5025),
    [anon_sym_struct] = ACTIONS(5025),
    [anon_sym_enum] = ACTIONS(5025),
    [anon_sym_RBRACE] = ACTIONS(5027),
    [anon_sym_interface] = ACTIONS(5025),
    [anon_sym_delegate] = ACTIONS(5025),
    [anon_sym_record] = ACTIONS(5025),
    [anon_sym_abstract] = ACTIONS(5025),
    [anon_sym_async] = ACTIONS(5025),
    [anon_sym_const] = ACTIONS(5025),
    [anon_sym_file] = ACTIONS(5025),
    [anon_sym_fixed] = ACTIONS(5025),
    [anon_sym_internal] = ACTIONS(5025),
    [anon_sym_new] = ACTIONS(5025),
    [anon_sym_override] = ACTIONS(5025),
    [anon_sym_partial] = ACTIONS(5025),
    [anon_sym_private] = ACTIONS(5025),
    [anon_sym_protected] = ACTIONS(5025),
    [anon_sym_public] = ACTIONS(5025),
    [anon_sym_readonly] = ACTIONS(5025),
    [anon_sym_required] = ACTIONS(5025),
    [anon_sym_sealed] = ACTIONS(5025),
    [anon_sym_virtual] = ACTIONS(5025),
    [anon_sym_volatile] = ACTIONS(5025),
    [anon_sym_where] = ACTIONS(5025),
    [anon_sym_notnull] = ACTIONS(5025),
    [anon_sym_unmanaged] = ACTIONS(5025),
    [anon_sym_TILDE] = ACTIONS(5027),
    [anon_sym_implicit] = ACTIONS(5025),
    [anon_sym_explicit] = ACTIONS(5025),
    [anon_sym_scoped] = ACTIONS(5025),
    [anon_sym_var] = ACTIONS(5025),
    [sym_predefined_type] = ACTIONS(5025),
    [anon_sym_yield] = ACTIONS(5025),
    [anon_sym_when] = ACTIONS(5025),
    [anon_sym_from] = ACTIONS(5025),
    [anon_sym_into] = ACTIONS(5025),
    [anon_sym_join] = ACTIONS(5025),
    [anon_sym_on] = ACTIONS(5025),
    [anon_sym_equals] = ACTIONS(5025),
    [anon_sym_let] = ACTIONS(5025),
    [anon_sym_orderby] = ACTIONS(5025),
    [anon_sym_ascending] = ACTIONS(5025),
    [anon_sym_descending] = ACTIONS(5025),
    [anon_sym_group] = ACTIONS(5025),
    [anon_sym_by] = ACTIONS(5025),
    [anon_sym_select] = ACTIONS(5025),
    [aux_sym_preproc_if_token1] = ACTIONS(5027),
    [aux_sym_preproc_if_token3] = ACTIONS(5027),
    [aux_sym_preproc_else_token1] = ACTIONS(5027),
    [aux_sym_preproc_elif_token1] = ACTIONS(5027),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3350] = {
    [sym_preproc_region] = STATE(3350),
    [sym_preproc_endregion] = STATE(3350),
    [sym_preproc_line] = STATE(3350),
    [sym_preproc_pragma] = STATE(3350),
    [sym_preproc_nullable] = STATE(3350),
    [sym_preproc_error] = STATE(3350),
    [sym_preproc_warning] = STATE(3350),
    [sym_preproc_define] = STATE(3350),
    [sym_preproc_undef] = STATE(3350),
    [sym__identifier_token] = ACTIONS(5029),
    [anon_sym_extern] = ACTIONS(5029),
    [anon_sym_alias] = ACTIONS(5029),
    [anon_sym_global] = ACTIONS(5029),
    [anon_sym_using] = ACTIONS(5029),
    [anon_sym_unsafe] = ACTIONS(5029),
    [anon_sym_static] = ACTIONS(5029),
    [anon_sym_LBRACK] = ACTIONS(5031),
    [anon_sym_LPAREN] = ACTIONS(5031),
    [anon_sym_event] = ACTIONS(5029),
    [anon_sym_namespace] = ACTIONS(5029),
    [anon_sym_class] = ACTIONS(5029),
    [anon_sym_ref] = ACTIONS(5029),
    [anon_sym_struct] = ACTIONS(5029),
    [anon_sym_enum] = ACTIONS(5029),
    [anon_sym_RBRACE] = ACTIONS(5031),
    [anon_sym_interface] = ACTIONS(5029),
    [anon_sym_delegate] = ACTIONS(5029),
    [anon_sym_record] = ACTIONS(5029),
    [anon_sym_abstract] = ACTIONS(5029),
    [anon_sym_async] = ACTIONS(5029),
    [anon_sym_const] = ACTIONS(5029),
    [anon_sym_file] = ACTIONS(5029),
    [anon_sym_fixed] = ACTIONS(5029),
    [anon_sym_internal] = ACTIONS(5029),
    [anon_sym_new] = ACTIONS(5029),
    [anon_sym_override] = ACTIONS(5029),
    [anon_sym_partial] = ACTIONS(5029),
    [anon_sym_private] = ACTIONS(5029),
    [anon_sym_protected] = ACTIONS(5029),
    [anon_sym_public] = ACTIONS(5029),
    [anon_sym_readonly] = ACTIONS(5029),
    [anon_sym_required] = ACTIONS(5029),
    [anon_sym_sealed] = ACTIONS(5029),
    [anon_sym_virtual] = ACTIONS(5029),
    [anon_sym_volatile] = ACTIONS(5029),
    [anon_sym_where] = ACTIONS(5029),
    [anon_sym_notnull] = ACTIONS(5029),
    [anon_sym_unmanaged] = ACTIONS(5029),
    [anon_sym_TILDE] = ACTIONS(5031),
    [anon_sym_implicit] = ACTIONS(5029),
    [anon_sym_explicit] = ACTIONS(5029),
    [anon_sym_scoped] = ACTIONS(5029),
    [anon_sym_var] = ACTIONS(5029),
    [sym_predefined_type] = ACTIONS(5029),
    [anon_sym_yield] = ACTIONS(5029),
    [anon_sym_when] = ACTIONS(5029),
    [anon_sym_from] = ACTIONS(5029),
    [anon_sym_into] = ACTIONS(5029),
    [anon_sym_join] = ACTIONS(5029),
    [anon_sym_on] = ACTIONS(5029),
    [anon_sym_equals] = ACTIONS(5029),
    [anon_sym_let] = ACTIONS(5029),
    [anon_sym_orderby] = ACTIONS(5029),
    [anon_sym_ascending] = ACTIONS(5029),
    [anon_sym_descending] = ACTIONS(5029),
    [anon_sym_group] = ACTIONS(5029),
    [anon_sym_by] = ACTIONS(5029),
    [anon_sym_select] = ACTIONS(5029),
    [aux_sym_preproc_if_token1] = ACTIONS(5031),
    [aux_sym_preproc_if_token3] = ACTIONS(5031),
    [aux_sym_preproc_else_token1] = ACTIONS(5031),
    [aux_sym_preproc_elif_token1] = ACTIONS(5031),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3351] = {
    [sym_preproc_region] = STATE(3351),
    [sym_preproc_endregion] = STATE(3351),
    [sym_preproc_line] = STATE(3351),
    [sym_preproc_pragma] = STATE(3351),
    [sym_preproc_nullable] = STATE(3351),
    [sym_preproc_error] = STATE(3351),
    [sym_preproc_warning] = STATE(3351),
    [sym_preproc_define] = STATE(3351),
    [sym_preproc_undef] = STATE(3351),
    [sym__identifier_token] = ACTIONS(5033),
    [anon_sym_extern] = ACTIONS(5033),
    [anon_sym_alias] = ACTIONS(5033),
    [anon_sym_global] = ACTIONS(5033),
    [anon_sym_using] = ACTIONS(5033),
    [anon_sym_unsafe] = ACTIONS(5033),
    [anon_sym_static] = ACTIONS(5033),
    [anon_sym_LBRACK] = ACTIONS(5035),
    [anon_sym_LPAREN] = ACTIONS(5035),
    [anon_sym_event] = ACTIONS(5033),
    [anon_sym_namespace] = ACTIONS(5033),
    [anon_sym_class] = ACTIONS(5033),
    [anon_sym_ref] = ACTIONS(5033),
    [anon_sym_struct] = ACTIONS(5033),
    [anon_sym_enum] = ACTIONS(5033),
    [anon_sym_RBRACE] = ACTIONS(5035),
    [anon_sym_interface] = ACTIONS(5033),
    [anon_sym_delegate] = ACTIONS(5033),
    [anon_sym_record] = ACTIONS(5033),
    [anon_sym_abstract] = ACTIONS(5033),
    [anon_sym_async] = ACTIONS(5033),
    [anon_sym_const] = ACTIONS(5033),
    [anon_sym_file] = ACTIONS(5033),
    [anon_sym_fixed] = ACTIONS(5033),
    [anon_sym_internal] = ACTIONS(5033),
    [anon_sym_new] = ACTIONS(5033),
    [anon_sym_override] = ACTIONS(5033),
    [anon_sym_partial] = ACTIONS(5033),
    [anon_sym_private] = ACTIONS(5033),
    [anon_sym_protected] = ACTIONS(5033),
    [anon_sym_public] = ACTIONS(5033),
    [anon_sym_readonly] = ACTIONS(5033),
    [anon_sym_required] = ACTIONS(5033),
    [anon_sym_sealed] = ACTIONS(5033),
    [anon_sym_virtual] = ACTIONS(5033),
    [anon_sym_volatile] = ACTIONS(5033),
    [anon_sym_where] = ACTIONS(5033),
    [anon_sym_notnull] = ACTIONS(5033),
    [anon_sym_unmanaged] = ACTIONS(5033),
    [anon_sym_TILDE] = ACTIONS(5035),
    [anon_sym_implicit] = ACTIONS(5033),
    [anon_sym_explicit] = ACTIONS(5033),
    [anon_sym_scoped] = ACTIONS(5033),
    [anon_sym_var] = ACTIONS(5033),
    [sym_predefined_type] = ACTIONS(5033),
    [anon_sym_yield] = ACTIONS(5033),
    [anon_sym_when] = ACTIONS(5033),
    [anon_sym_from] = ACTIONS(5033),
    [anon_sym_into] = ACTIONS(5033),
    [anon_sym_join] = ACTIONS(5033),
    [anon_sym_on] = ACTIONS(5033),
    [anon_sym_equals] = ACTIONS(5033),
    [anon_sym_let] = ACTIONS(5033),
    [anon_sym_orderby] = ACTIONS(5033),
    [anon_sym_ascending] = ACTIONS(5033),
    [anon_sym_descending] = ACTIONS(5033),
    [anon_sym_group] = ACTIONS(5033),
    [anon_sym_by] = ACTIONS(5033),
    [anon_sym_select] = ACTIONS(5033),
    [aux_sym_preproc_if_token1] = ACTIONS(5035),
    [aux_sym_preproc_if_token3] = ACTIONS(5035),
    [aux_sym_preproc_else_token1] = ACTIONS(5035),
    [aux_sym_preproc_elif_token1] = ACTIONS(5035),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3352] = {
    [sym_preproc_region] = STATE(3352),
    [sym_preproc_endregion] = STATE(3352),
    [sym_preproc_line] = STATE(3352),
    [sym_preproc_pragma] = STATE(3352),
    [sym_preproc_nullable] = STATE(3352),
    [sym_preproc_error] = STATE(3352),
    [sym_preproc_warning] = STATE(3352),
    [sym_preproc_define] = STATE(3352),
    [sym_preproc_undef] = STATE(3352),
    [sym__identifier_token] = ACTIONS(5037),
    [anon_sym_extern] = ACTIONS(5037),
    [anon_sym_alias] = ACTIONS(5037),
    [anon_sym_global] = ACTIONS(5037),
    [anon_sym_using] = ACTIONS(5037),
    [anon_sym_unsafe] = ACTIONS(5037),
    [anon_sym_static] = ACTIONS(5037),
    [anon_sym_LBRACK] = ACTIONS(5039),
    [anon_sym_LPAREN] = ACTIONS(5039),
    [anon_sym_event] = ACTIONS(5037),
    [anon_sym_namespace] = ACTIONS(5037),
    [anon_sym_class] = ACTIONS(5037),
    [anon_sym_ref] = ACTIONS(5037),
    [anon_sym_struct] = ACTIONS(5037),
    [anon_sym_enum] = ACTIONS(5037),
    [anon_sym_RBRACE] = ACTIONS(5039),
    [anon_sym_interface] = ACTIONS(5037),
    [anon_sym_delegate] = ACTIONS(5037),
    [anon_sym_record] = ACTIONS(5037),
    [anon_sym_abstract] = ACTIONS(5037),
    [anon_sym_async] = ACTIONS(5037),
    [anon_sym_const] = ACTIONS(5037),
    [anon_sym_file] = ACTIONS(5037),
    [anon_sym_fixed] = ACTIONS(5037),
    [anon_sym_internal] = ACTIONS(5037),
    [anon_sym_new] = ACTIONS(5037),
    [anon_sym_override] = ACTIONS(5037),
    [anon_sym_partial] = ACTIONS(5037),
    [anon_sym_private] = ACTIONS(5037),
    [anon_sym_protected] = ACTIONS(5037),
    [anon_sym_public] = ACTIONS(5037),
    [anon_sym_readonly] = ACTIONS(5037),
    [anon_sym_required] = ACTIONS(5037),
    [anon_sym_sealed] = ACTIONS(5037),
    [anon_sym_virtual] = ACTIONS(5037),
    [anon_sym_volatile] = ACTIONS(5037),
    [anon_sym_where] = ACTIONS(5037),
    [anon_sym_notnull] = ACTIONS(5037),
    [anon_sym_unmanaged] = ACTIONS(5037),
    [anon_sym_TILDE] = ACTIONS(5039),
    [anon_sym_implicit] = ACTIONS(5037),
    [anon_sym_explicit] = ACTIONS(5037),
    [anon_sym_scoped] = ACTIONS(5037),
    [anon_sym_var] = ACTIONS(5037),
    [sym_predefined_type] = ACTIONS(5037),
    [anon_sym_yield] = ACTIONS(5037),
    [anon_sym_when] = ACTIONS(5037),
    [anon_sym_from] = ACTIONS(5037),
    [anon_sym_into] = ACTIONS(5037),
    [anon_sym_join] = ACTIONS(5037),
    [anon_sym_on] = ACTIONS(5037),
    [anon_sym_equals] = ACTIONS(5037),
    [anon_sym_let] = ACTIONS(5037),
    [anon_sym_orderby] = ACTIONS(5037),
    [anon_sym_ascending] = ACTIONS(5037),
    [anon_sym_descending] = ACTIONS(5037),
    [anon_sym_group] = ACTIONS(5037),
    [anon_sym_by] = ACTIONS(5037),
    [anon_sym_select] = ACTIONS(5037),
    [aux_sym_preproc_if_token1] = ACTIONS(5039),
    [aux_sym_preproc_if_token3] = ACTIONS(5039),
    [aux_sym_preproc_else_token1] = ACTIONS(5039),
    [aux_sym_preproc_elif_token1] = ACTIONS(5039),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3353] = {
    [sym_preproc_region] = STATE(3353),
    [sym_preproc_endregion] = STATE(3353),
    [sym_preproc_line] = STATE(3353),
    [sym_preproc_pragma] = STATE(3353),
    [sym_preproc_nullable] = STATE(3353),
    [sym_preproc_error] = STATE(3353),
    [sym_preproc_warning] = STATE(3353),
    [sym_preproc_define] = STATE(3353),
    [sym_preproc_undef] = STATE(3353),
    [sym__identifier_token] = ACTIONS(5041),
    [anon_sym_extern] = ACTIONS(5041),
    [anon_sym_alias] = ACTIONS(5041),
    [anon_sym_global] = ACTIONS(5041),
    [anon_sym_using] = ACTIONS(5041),
    [anon_sym_unsafe] = ACTIONS(5041),
    [anon_sym_static] = ACTIONS(5041),
    [anon_sym_LBRACK] = ACTIONS(5043),
    [anon_sym_LPAREN] = ACTIONS(5043),
    [anon_sym_event] = ACTIONS(5041),
    [anon_sym_namespace] = ACTIONS(5041),
    [anon_sym_class] = ACTIONS(5041),
    [anon_sym_ref] = ACTIONS(5041),
    [anon_sym_struct] = ACTIONS(5041),
    [anon_sym_enum] = ACTIONS(5041),
    [anon_sym_RBRACE] = ACTIONS(5043),
    [anon_sym_interface] = ACTIONS(5041),
    [anon_sym_delegate] = ACTIONS(5041),
    [anon_sym_record] = ACTIONS(5041),
    [anon_sym_abstract] = ACTIONS(5041),
    [anon_sym_async] = ACTIONS(5041),
    [anon_sym_const] = ACTIONS(5041),
    [anon_sym_file] = ACTIONS(5041),
    [anon_sym_fixed] = ACTIONS(5041),
    [anon_sym_internal] = ACTIONS(5041),
    [anon_sym_new] = ACTIONS(5041),
    [anon_sym_override] = ACTIONS(5041),
    [anon_sym_partial] = ACTIONS(5041),
    [anon_sym_private] = ACTIONS(5041),
    [anon_sym_protected] = ACTIONS(5041),
    [anon_sym_public] = ACTIONS(5041),
    [anon_sym_readonly] = ACTIONS(5041),
    [anon_sym_required] = ACTIONS(5041),
    [anon_sym_sealed] = ACTIONS(5041),
    [anon_sym_virtual] = ACTIONS(5041),
    [anon_sym_volatile] = ACTIONS(5041),
    [anon_sym_where] = ACTIONS(5041),
    [anon_sym_notnull] = ACTIONS(5041),
    [anon_sym_unmanaged] = ACTIONS(5041),
    [anon_sym_TILDE] = ACTIONS(5043),
    [anon_sym_implicit] = ACTIONS(5041),
    [anon_sym_explicit] = ACTIONS(5041),
    [anon_sym_scoped] = ACTIONS(5041),
    [anon_sym_var] = ACTIONS(5041),
    [sym_predefined_type] = ACTIONS(5041),
    [anon_sym_yield] = ACTIONS(5041),
    [anon_sym_when] = ACTIONS(5041),
    [anon_sym_from] = ACTIONS(5041),
    [anon_sym_into] = ACTIONS(5041),
    [anon_sym_join] = ACTIONS(5041),
    [anon_sym_on] = ACTIONS(5041),
    [anon_sym_equals] = ACTIONS(5041),
    [anon_sym_let] = ACTIONS(5041),
    [anon_sym_orderby] = ACTIONS(5041),
    [anon_sym_ascending] = ACTIONS(5041),
    [anon_sym_descending] = ACTIONS(5041),
    [anon_sym_group] = ACTIONS(5041),
    [anon_sym_by] = ACTIONS(5041),
    [anon_sym_select] = ACTIONS(5041),
    [aux_sym_preproc_if_token1] = ACTIONS(5043),
    [aux_sym_preproc_if_token3] = ACTIONS(5043),
    [aux_sym_preproc_else_token1] = ACTIONS(5043),
    [aux_sym_preproc_elif_token1] = ACTIONS(5043),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3354] = {
    [sym_preproc_region] = STATE(3354),
    [sym_preproc_endregion] = STATE(3354),
    [sym_preproc_line] = STATE(3354),
    [sym_preproc_pragma] = STATE(3354),
    [sym_preproc_nullable] = STATE(3354),
    [sym_preproc_error] = STATE(3354),
    [sym_preproc_warning] = STATE(3354),
    [sym_preproc_define] = STATE(3354),
    [sym_preproc_undef] = STATE(3354),
    [sym__identifier_token] = ACTIONS(5045),
    [anon_sym_extern] = ACTIONS(5045),
    [anon_sym_alias] = ACTIONS(5045),
    [anon_sym_global] = ACTIONS(5045),
    [anon_sym_using] = ACTIONS(5045),
    [anon_sym_unsafe] = ACTIONS(5045),
    [anon_sym_static] = ACTIONS(5045),
    [anon_sym_LBRACK] = ACTIONS(5047),
    [anon_sym_LPAREN] = ACTIONS(5047),
    [anon_sym_event] = ACTIONS(5045),
    [anon_sym_namespace] = ACTIONS(5045),
    [anon_sym_class] = ACTIONS(5045),
    [anon_sym_ref] = ACTIONS(5045),
    [anon_sym_struct] = ACTIONS(5045),
    [anon_sym_enum] = ACTIONS(5045),
    [anon_sym_RBRACE] = ACTIONS(5047),
    [anon_sym_interface] = ACTIONS(5045),
    [anon_sym_delegate] = ACTIONS(5045),
    [anon_sym_record] = ACTIONS(5045),
    [anon_sym_abstract] = ACTIONS(5045),
    [anon_sym_async] = ACTIONS(5045),
    [anon_sym_const] = ACTIONS(5045),
    [anon_sym_file] = ACTIONS(5045),
    [anon_sym_fixed] = ACTIONS(5045),
    [anon_sym_internal] = ACTIONS(5045),
    [anon_sym_new] = ACTIONS(5045),
    [anon_sym_override] = ACTIONS(5045),
    [anon_sym_partial] = ACTIONS(5045),
    [anon_sym_private] = ACTIONS(5045),
    [anon_sym_protected] = ACTIONS(5045),
    [anon_sym_public] = ACTIONS(5045),
    [anon_sym_readonly] = ACTIONS(5045),
    [anon_sym_required] = ACTIONS(5045),
    [anon_sym_sealed] = ACTIONS(5045),
    [anon_sym_virtual] = ACTIONS(5045),
    [anon_sym_volatile] = ACTIONS(5045),
    [anon_sym_where] = ACTIONS(5045),
    [anon_sym_notnull] = ACTIONS(5045),
    [anon_sym_unmanaged] = ACTIONS(5045),
    [anon_sym_TILDE] = ACTIONS(5047),
    [anon_sym_implicit] = ACTIONS(5045),
    [anon_sym_explicit] = ACTIONS(5045),
    [anon_sym_scoped] = ACTIONS(5045),
    [anon_sym_var] = ACTIONS(5045),
    [sym_predefined_type] = ACTIONS(5045),
    [anon_sym_yield] = ACTIONS(5045),
    [anon_sym_when] = ACTIONS(5045),
    [anon_sym_from] = ACTIONS(5045),
    [anon_sym_into] = ACTIONS(5045),
    [anon_sym_join] = ACTIONS(5045),
    [anon_sym_on] = ACTIONS(5045),
    [anon_sym_equals] = ACTIONS(5045),
    [anon_sym_let] = ACTIONS(5045),
    [anon_sym_orderby] = ACTIONS(5045),
    [anon_sym_ascending] = ACTIONS(5045),
    [anon_sym_descending] = ACTIONS(5045),
    [anon_sym_group] = ACTIONS(5045),
    [anon_sym_by] = ACTIONS(5045),
    [anon_sym_select] = ACTIONS(5045),
    [aux_sym_preproc_if_token1] = ACTIONS(5047),
    [aux_sym_preproc_if_token3] = ACTIONS(5047),
    [aux_sym_preproc_else_token1] = ACTIONS(5047),
    [aux_sym_preproc_elif_token1] = ACTIONS(5047),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3355] = {
    [sym_preproc_region] = STATE(3355),
    [sym_preproc_endregion] = STATE(3355),
    [sym_preproc_line] = STATE(3355),
    [sym_preproc_pragma] = STATE(3355),
    [sym_preproc_nullable] = STATE(3355),
    [sym_preproc_error] = STATE(3355),
    [sym_preproc_warning] = STATE(3355),
    [sym_preproc_define] = STATE(3355),
    [sym_preproc_undef] = STATE(3355),
    [sym__identifier_token] = ACTIONS(5049),
    [anon_sym_extern] = ACTIONS(5049),
    [anon_sym_alias] = ACTIONS(5049),
    [anon_sym_global] = ACTIONS(5049),
    [anon_sym_using] = ACTIONS(5049),
    [anon_sym_unsafe] = ACTIONS(5049),
    [anon_sym_static] = ACTIONS(5049),
    [anon_sym_LBRACK] = ACTIONS(5051),
    [anon_sym_LPAREN] = ACTIONS(5051),
    [anon_sym_event] = ACTIONS(5049),
    [anon_sym_namespace] = ACTIONS(5049),
    [anon_sym_class] = ACTIONS(5049),
    [anon_sym_ref] = ACTIONS(5049),
    [anon_sym_struct] = ACTIONS(5049),
    [anon_sym_enum] = ACTIONS(5049),
    [anon_sym_RBRACE] = ACTIONS(5051),
    [anon_sym_interface] = ACTIONS(5049),
    [anon_sym_delegate] = ACTIONS(5049),
    [anon_sym_record] = ACTIONS(5049),
    [anon_sym_abstract] = ACTIONS(5049),
    [anon_sym_async] = ACTIONS(5049),
    [anon_sym_const] = ACTIONS(5049),
    [anon_sym_file] = ACTIONS(5049),
    [anon_sym_fixed] = ACTIONS(5049),
    [anon_sym_internal] = ACTIONS(5049),
    [anon_sym_new] = ACTIONS(5049),
    [anon_sym_override] = ACTIONS(5049),
    [anon_sym_partial] = ACTIONS(5049),
    [anon_sym_private] = ACTIONS(5049),
    [anon_sym_protected] = ACTIONS(5049),
    [anon_sym_public] = ACTIONS(5049),
    [anon_sym_readonly] = ACTIONS(5049),
    [anon_sym_required] = ACTIONS(5049),
    [anon_sym_sealed] = ACTIONS(5049),
    [anon_sym_virtual] = ACTIONS(5049),
    [anon_sym_volatile] = ACTIONS(5049),
    [anon_sym_where] = ACTIONS(5049),
    [anon_sym_notnull] = ACTIONS(5049),
    [anon_sym_unmanaged] = ACTIONS(5049),
    [anon_sym_TILDE] = ACTIONS(5051),
    [anon_sym_implicit] = ACTIONS(5049),
    [anon_sym_explicit] = ACTIONS(5049),
    [anon_sym_scoped] = ACTIONS(5049),
    [anon_sym_var] = ACTIONS(5049),
    [sym_predefined_type] = ACTIONS(5049),
    [anon_sym_yield] = ACTIONS(5049),
    [anon_sym_when] = ACTIONS(5049),
    [anon_sym_from] = ACTIONS(5049),
    [anon_sym_into] = ACTIONS(5049),
    [anon_sym_join] = ACTIONS(5049),
    [anon_sym_on] = ACTIONS(5049),
    [anon_sym_equals] = ACTIONS(5049),
    [anon_sym_let] = ACTIONS(5049),
    [anon_sym_orderby] = ACTIONS(5049),
    [anon_sym_ascending] = ACTIONS(5049),
    [anon_sym_descending] = ACTIONS(5049),
    [anon_sym_group] = ACTIONS(5049),
    [anon_sym_by] = ACTIONS(5049),
    [anon_sym_select] = ACTIONS(5049),
    [aux_sym_preproc_if_token1] = ACTIONS(5051),
    [aux_sym_preproc_if_token3] = ACTIONS(5051),
    [aux_sym_preproc_else_token1] = ACTIONS(5051),
    [aux_sym_preproc_elif_token1] = ACTIONS(5051),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3356] = {
    [sym_preproc_region] = STATE(3356),
    [sym_preproc_endregion] = STATE(3356),
    [sym_preproc_line] = STATE(3356),
    [sym_preproc_pragma] = STATE(3356),
    [sym_preproc_nullable] = STATE(3356),
    [sym_preproc_error] = STATE(3356),
    [sym_preproc_warning] = STATE(3356),
    [sym_preproc_define] = STATE(3356),
    [sym_preproc_undef] = STATE(3356),
    [sym__identifier_token] = ACTIONS(5053),
    [anon_sym_extern] = ACTIONS(5053),
    [anon_sym_alias] = ACTIONS(5053),
    [anon_sym_global] = ACTIONS(5053),
    [anon_sym_using] = ACTIONS(5053),
    [anon_sym_unsafe] = ACTIONS(5053),
    [anon_sym_static] = ACTIONS(5053),
    [anon_sym_LBRACK] = ACTIONS(5055),
    [anon_sym_LPAREN] = ACTIONS(5055),
    [anon_sym_event] = ACTIONS(5053),
    [anon_sym_namespace] = ACTIONS(5053),
    [anon_sym_class] = ACTIONS(5053),
    [anon_sym_ref] = ACTIONS(5053),
    [anon_sym_struct] = ACTIONS(5053),
    [anon_sym_enum] = ACTIONS(5053),
    [anon_sym_RBRACE] = ACTIONS(5055),
    [anon_sym_interface] = ACTIONS(5053),
    [anon_sym_delegate] = ACTIONS(5053),
    [anon_sym_record] = ACTIONS(5053),
    [anon_sym_abstract] = ACTIONS(5053),
    [anon_sym_async] = ACTIONS(5053),
    [anon_sym_const] = ACTIONS(5053),
    [anon_sym_file] = ACTIONS(5053),
    [anon_sym_fixed] = ACTIONS(5053),
    [anon_sym_internal] = ACTIONS(5053),
    [anon_sym_new] = ACTIONS(5053),
    [anon_sym_override] = ACTIONS(5053),
    [anon_sym_partial] = ACTIONS(5053),
    [anon_sym_private] = ACTIONS(5053),
    [anon_sym_protected] = ACTIONS(5053),
    [anon_sym_public] = ACTIONS(5053),
    [anon_sym_readonly] = ACTIONS(5053),
    [anon_sym_required] = ACTIONS(5053),
    [anon_sym_sealed] = ACTIONS(5053),
    [anon_sym_virtual] = ACTIONS(5053),
    [anon_sym_volatile] = ACTIONS(5053),
    [anon_sym_where] = ACTIONS(5053),
    [anon_sym_notnull] = ACTIONS(5053),
    [anon_sym_unmanaged] = ACTIONS(5053),
    [anon_sym_TILDE] = ACTIONS(5055),
    [anon_sym_implicit] = ACTIONS(5053),
    [anon_sym_explicit] = ACTIONS(5053),
    [anon_sym_scoped] = ACTIONS(5053),
    [anon_sym_var] = ACTIONS(5053),
    [sym_predefined_type] = ACTIONS(5053),
    [anon_sym_yield] = ACTIONS(5053),
    [anon_sym_when] = ACTIONS(5053),
    [anon_sym_from] = ACTIONS(5053),
    [anon_sym_into] = ACTIONS(5053),
    [anon_sym_join] = ACTIONS(5053),
    [anon_sym_on] = ACTIONS(5053),
    [anon_sym_equals] = ACTIONS(5053),
    [anon_sym_let] = ACTIONS(5053),
    [anon_sym_orderby] = ACTIONS(5053),
    [anon_sym_ascending] = ACTIONS(5053),
    [anon_sym_descending] = ACTIONS(5053),
    [anon_sym_group] = ACTIONS(5053),
    [anon_sym_by] = ACTIONS(5053),
    [anon_sym_select] = ACTIONS(5053),
    [aux_sym_preproc_if_token1] = ACTIONS(5055),
    [aux_sym_preproc_if_token3] = ACTIONS(5055),
    [aux_sym_preproc_else_token1] = ACTIONS(5055),
    [aux_sym_preproc_elif_token1] = ACTIONS(5055),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3357] = {
    [sym_preproc_region] = STATE(3357),
    [sym_preproc_endregion] = STATE(3357),
    [sym_preproc_line] = STATE(3357),
    [sym_preproc_pragma] = STATE(3357),
    [sym_preproc_nullable] = STATE(3357),
    [sym_preproc_error] = STATE(3357),
    [sym_preproc_warning] = STATE(3357),
    [sym_preproc_define] = STATE(3357),
    [sym_preproc_undef] = STATE(3357),
    [sym__identifier_token] = ACTIONS(5057),
    [anon_sym_extern] = ACTIONS(5057),
    [anon_sym_alias] = ACTIONS(5057),
    [anon_sym_global] = ACTIONS(5057),
    [anon_sym_using] = ACTIONS(5057),
    [anon_sym_unsafe] = ACTIONS(5057),
    [anon_sym_static] = ACTIONS(5057),
    [anon_sym_LBRACK] = ACTIONS(5059),
    [anon_sym_LPAREN] = ACTIONS(5059),
    [anon_sym_event] = ACTIONS(5057),
    [anon_sym_namespace] = ACTIONS(5057),
    [anon_sym_class] = ACTIONS(5057),
    [anon_sym_ref] = ACTIONS(5057),
    [anon_sym_struct] = ACTIONS(5057),
    [anon_sym_enum] = ACTIONS(5057),
    [anon_sym_RBRACE] = ACTIONS(5059),
    [anon_sym_interface] = ACTIONS(5057),
    [anon_sym_delegate] = ACTIONS(5057),
    [anon_sym_record] = ACTIONS(5057),
    [anon_sym_abstract] = ACTIONS(5057),
    [anon_sym_async] = ACTIONS(5057),
    [anon_sym_const] = ACTIONS(5057),
    [anon_sym_file] = ACTIONS(5057),
    [anon_sym_fixed] = ACTIONS(5057),
    [anon_sym_internal] = ACTIONS(5057),
    [anon_sym_new] = ACTIONS(5057),
    [anon_sym_override] = ACTIONS(5057),
    [anon_sym_partial] = ACTIONS(5057),
    [anon_sym_private] = ACTIONS(5057),
    [anon_sym_protected] = ACTIONS(5057),
    [anon_sym_public] = ACTIONS(5057),
    [anon_sym_readonly] = ACTIONS(5057),
    [anon_sym_required] = ACTIONS(5057),
    [anon_sym_sealed] = ACTIONS(5057),
    [anon_sym_virtual] = ACTIONS(5057),
    [anon_sym_volatile] = ACTIONS(5057),
    [anon_sym_where] = ACTIONS(5057),
    [anon_sym_notnull] = ACTIONS(5057),
    [anon_sym_unmanaged] = ACTIONS(5057),
    [anon_sym_TILDE] = ACTIONS(5059),
    [anon_sym_implicit] = ACTIONS(5057),
    [anon_sym_explicit] = ACTIONS(5057),
    [anon_sym_scoped] = ACTIONS(5057),
    [anon_sym_var] = ACTIONS(5057),
    [sym_predefined_type] = ACTIONS(5057),
    [anon_sym_yield] = ACTIONS(5057),
    [anon_sym_when] = ACTIONS(5057),
    [anon_sym_from] = ACTIONS(5057),
    [anon_sym_into] = ACTIONS(5057),
    [anon_sym_join] = ACTIONS(5057),
    [anon_sym_on] = ACTIONS(5057),
    [anon_sym_equals] = ACTIONS(5057),
    [anon_sym_let] = ACTIONS(5057),
    [anon_sym_orderby] = ACTIONS(5057),
    [anon_sym_ascending] = ACTIONS(5057),
    [anon_sym_descending] = ACTIONS(5057),
    [anon_sym_group] = ACTIONS(5057),
    [anon_sym_by] = ACTIONS(5057),
    [anon_sym_select] = ACTIONS(5057),
    [aux_sym_preproc_if_token1] = ACTIONS(5059),
    [aux_sym_preproc_if_token3] = ACTIONS(5059),
    [aux_sym_preproc_else_token1] = ACTIONS(5059),
    [aux_sym_preproc_elif_token1] = ACTIONS(5059),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3358] = {
    [sym_preproc_region] = STATE(3358),
    [sym_preproc_endregion] = STATE(3358),
    [sym_preproc_line] = STATE(3358),
    [sym_preproc_pragma] = STATE(3358),
    [sym_preproc_nullable] = STATE(3358),
    [sym_preproc_error] = STATE(3358),
    [sym_preproc_warning] = STATE(3358),
    [sym_preproc_define] = STATE(3358),
    [sym_preproc_undef] = STATE(3358),
    [sym__identifier_token] = ACTIONS(5061),
    [anon_sym_extern] = ACTIONS(5061),
    [anon_sym_alias] = ACTIONS(5061),
    [anon_sym_global] = ACTIONS(5061),
    [anon_sym_using] = ACTIONS(5061),
    [anon_sym_unsafe] = ACTIONS(5061),
    [anon_sym_static] = ACTIONS(5061),
    [anon_sym_LBRACK] = ACTIONS(5063),
    [anon_sym_LPAREN] = ACTIONS(5063),
    [anon_sym_event] = ACTIONS(5061),
    [anon_sym_namespace] = ACTIONS(5061),
    [anon_sym_class] = ACTIONS(5061),
    [anon_sym_ref] = ACTIONS(5061),
    [anon_sym_struct] = ACTIONS(5061),
    [anon_sym_enum] = ACTIONS(5061),
    [anon_sym_RBRACE] = ACTIONS(5063),
    [anon_sym_interface] = ACTIONS(5061),
    [anon_sym_delegate] = ACTIONS(5061),
    [anon_sym_record] = ACTIONS(5061),
    [anon_sym_abstract] = ACTIONS(5061),
    [anon_sym_async] = ACTIONS(5061),
    [anon_sym_const] = ACTIONS(5061),
    [anon_sym_file] = ACTIONS(5061),
    [anon_sym_fixed] = ACTIONS(5061),
    [anon_sym_internal] = ACTIONS(5061),
    [anon_sym_new] = ACTIONS(5061),
    [anon_sym_override] = ACTIONS(5061),
    [anon_sym_partial] = ACTIONS(5061),
    [anon_sym_private] = ACTIONS(5061),
    [anon_sym_protected] = ACTIONS(5061),
    [anon_sym_public] = ACTIONS(5061),
    [anon_sym_readonly] = ACTIONS(5061),
    [anon_sym_required] = ACTIONS(5061),
    [anon_sym_sealed] = ACTIONS(5061),
    [anon_sym_virtual] = ACTIONS(5061),
    [anon_sym_volatile] = ACTIONS(5061),
    [anon_sym_where] = ACTIONS(5061),
    [anon_sym_notnull] = ACTIONS(5061),
    [anon_sym_unmanaged] = ACTIONS(5061),
    [anon_sym_TILDE] = ACTIONS(5063),
    [anon_sym_implicit] = ACTIONS(5061),
    [anon_sym_explicit] = ACTIONS(5061),
    [anon_sym_scoped] = ACTIONS(5061),
    [anon_sym_var] = ACTIONS(5061),
    [sym_predefined_type] = ACTIONS(5061),
    [anon_sym_yield] = ACTIONS(5061),
    [anon_sym_when] = ACTIONS(5061),
    [anon_sym_from] = ACTIONS(5061),
    [anon_sym_into] = ACTIONS(5061),
    [anon_sym_join] = ACTIONS(5061),
    [anon_sym_on] = ACTIONS(5061),
    [anon_sym_equals] = ACTIONS(5061),
    [anon_sym_let] = ACTIONS(5061),
    [anon_sym_orderby] = ACTIONS(5061),
    [anon_sym_ascending] = ACTIONS(5061),
    [anon_sym_descending] = ACTIONS(5061),
    [anon_sym_group] = ACTIONS(5061),
    [anon_sym_by] = ACTIONS(5061),
    [anon_sym_select] = ACTIONS(5061),
    [aux_sym_preproc_if_token1] = ACTIONS(5063),
    [aux_sym_preproc_if_token3] = ACTIONS(5063),
    [aux_sym_preproc_else_token1] = ACTIONS(5063),
    [aux_sym_preproc_elif_token1] = ACTIONS(5063),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3359] = {
    [sym_preproc_region] = STATE(3359),
    [sym_preproc_endregion] = STATE(3359),
    [sym_preproc_line] = STATE(3359),
    [sym_preproc_pragma] = STATE(3359),
    [sym_preproc_nullable] = STATE(3359),
    [sym_preproc_error] = STATE(3359),
    [sym_preproc_warning] = STATE(3359),
    [sym_preproc_define] = STATE(3359),
    [sym_preproc_undef] = STATE(3359),
    [sym__identifier_token] = ACTIONS(5065),
    [anon_sym_extern] = ACTIONS(5065),
    [anon_sym_alias] = ACTIONS(5065),
    [anon_sym_global] = ACTIONS(5065),
    [anon_sym_using] = ACTIONS(5065),
    [anon_sym_unsafe] = ACTIONS(5065),
    [anon_sym_static] = ACTIONS(5065),
    [anon_sym_LBRACK] = ACTIONS(5067),
    [anon_sym_LPAREN] = ACTIONS(5067),
    [anon_sym_event] = ACTIONS(5065),
    [anon_sym_namespace] = ACTIONS(5065),
    [anon_sym_class] = ACTIONS(5065),
    [anon_sym_ref] = ACTIONS(5065),
    [anon_sym_struct] = ACTIONS(5065),
    [anon_sym_enum] = ACTIONS(5065),
    [anon_sym_RBRACE] = ACTIONS(5067),
    [anon_sym_interface] = ACTIONS(5065),
    [anon_sym_delegate] = ACTIONS(5065),
    [anon_sym_record] = ACTIONS(5065),
    [anon_sym_abstract] = ACTIONS(5065),
    [anon_sym_async] = ACTIONS(5065),
    [anon_sym_const] = ACTIONS(5065),
    [anon_sym_file] = ACTIONS(5065),
    [anon_sym_fixed] = ACTIONS(5065),
    [anon_sym_internal] = ACTIONS(5065),
    [anon_sym_new] = ACTIONS(5065),
    [anon_sym_override] = ACTIONS(5065),
    [anon_sym_partial] = ACTIONS(5065),
    [anon_sym_private] = ACTIONS(5065),
    [anon_sym_protected] = ACTIONS(5065),
    [anon_sym_public] = ACTIONS(5065),
    [anon_sym_readonly] = ACTIONS(5065),
    [anon_sym_required] = ACTIONS(5065),
    [anon_sym_sealed] = ACTIONS(5065),
    [anon_sym_virtual] = ACTIONS(5065),
    [anon_sym_volatile] = ACTIONS(5065),
    [anon_sym_where] = ACTIONS(5065),
    [anon_sym_notnull] = ACTIONS(5065),
    [anon_sym_unmanaged] = ACTIONS(5065),
    [anon_sym_TILDE] = ACTIONS(5067),
    [anon_sym_implicit] = ACTIONS(5065),
    [anon_sym_explicit] = ACTIONS(5065),
    [anon_sym_scoped] = ACTIONS(5065),
    [anon_sym_var] = ACTIONS(5065),
    [sym_predefined_type] = ACTIONS(5065),
    [anon_sym_yield] = ACTIONS(5065),
    [anon_sym_when] = ACTIONS(5065),
    [anon_sym_from] = ACTIONS(5065),
    [anon_sym_into] = ACTIONS(5065),
    [anon_sym_join] = ACTIONS(5065),
    [anon_sym_on] = ACTIONS(5065),
    [anon_sym_equals] = ACTIONS(5065),
    [anon_sym_let] = ACTIONS(5065),
    [anon_sym_orderby] = ACTIONS(5065),
    [anon_sym_ascending] = ACTIONS(5065),
    [anon_sym_descending] = ACTIONS(5065),
    [anon_sym_group] = ACTIONS(5065),
    [anon_sym_by] = ACTIONS(5065),
    [anon_sym_select] = ACTIONS(5065),
    [aux_sym_preproc_if_token1] = ACTIONS(5067),
    [aux_sym_preproc_if_token3] = ACTIONS(5067),
    [aux_sym_preproc_else_token1] = ACTIONS(5067),
    [aux_sym_preproc_elif_token1] = ACTIONS(5067),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3360] = {
    [sym__variable_designation] = STATE(4993),
    [sym_parenthesized_variable_designation] = STATE(5027),
    [sym_identifier] = STATE(5034),
    [sym__reserved_identifier] = STATE(3572),
    [sym_preproc_region] = STATE(3360),
    [sym_preproc_endregion] = STATE(3360),
    [sym_preproc_line] = STATE(3360),
    [sym_preproc_pragma] = STATE(3360),
    [sym_preproc_nullable] = STATE(3360),
    [sym_preproc_error] = STATE(3360),
    [sym_preproc_warning] = STATE(3360),
    [sym_preproc_define] = STATE(3360),
    [sym_preproc_undef] = STATE(3360),
    [sym__identifier_token] = ACTIONS(4328),
    [anon_sym_alias] = ACTIONS(4330),
    [anon_sym_global] = ACTIONS(4330),
    [anon_sym_LBRACK] = ACTIONS(4399),
    [anon_sym_LPAREN] = ACTIONS(4399),
    [anon_sym_file] = ACTIONS(4330),
    [anon_sym_LT] = ACTIONS(4401),
    [anon_sym_GT] = ACTIONS(4401),
    [anon_sym_where] = ACTIONS(4401),
    [anon_sym_QMARK] = ACTIONS(4401),
    [anon_sym_notnull] = ACTIONS(4330),
    [anon_sym_unmanaged] = ACTIONS(4330),
    [anon_sym_BANG] = ACTIONS(4401),
    [anon_sym_PLUS_PLUS] = ACTIONS(4399),
    [anon_sym_DASH_DASH] = ACTIONS(4399),
    [anon_sym_PLUS] = ACTIONS(4401),
    [anon_sym_DASH] = ACTIONS(4401),
    [anon_sym_STAR] = ACTIONS(4399),
    [anon_sym_SLASH] = ACTIONS(4401),
    [anon_sym_PERCENT] = ACTIONS(4399),
    [anon_sym_CARET] = ACTIONS(4399),
    [anon_sym_PIPE] = ACTIONS(4401),
    [anon_sym_AMP] = ACTIONS(4401),
    [anon_sym_LT_LT] = ACTIONS(4399),
    [anon_sym_GT_GT] = ACTIONS(4401),
    [anon_sym_GT_GT_GT] = ACTIONS(4399),
    [anon_sym_EQ_EQ] = ACTIONS(4399),
    [anon_sym_BANG_EQ] = ACTIONS(4399),
    [anon_sym_GT_EQ] = ACTIONS(4399),
    [anon_sym_LT_EQ] = ACTIONS(4399),
    [anon_sym_DOT] = ACTIONS(4401),
    [anon_sym_scoped] = ACTIONS(4330),
    [anon_sym_var] = ACTIONS(4330),
    [anon_sym_yield] = ACTIONS(4330),
    [anon_sym_switch] = ACTIONS(4401),
    [anon_sym_when] = ACTIONS(4330),
    [sym_discard] = ACTIONS(4719),
    [anon_sym_DOT_DOT] = ACTIONS(4399),
    [anon_sym_and] = ACTIONS(4401),
    [anon_sym_or] = ACTIONS(4401),
    [anon_sym_AMP_AMP] = ACTIONS(4399),
    [anon_sym_PIPE_PIPE] = ACTIONS(4399),
    [anon_sym_QMARK_QMARK] = ACTIONS(4399),
    [anon_sym_from] = ACTIONS(4401),
    [anon_sym_into] = ACTIONS(4401),
    [anon_sym_join] = ACTIONS(4401),
    [anon_sym_on] = ACTIONS(4330),
    [anon_sym_equals] = ACTIONS(4330),
    [anon_sym_let] = ACTIONS(4401),
    [anon_sym_orderby] = ACTIONS(4401),
    [anon_sym_ascending] = ACTIONS(4330),
    [anon_sym_descending] = ACTIONS(4330),
    [anon_sym_group] = ACTIONS(4401),
    [anon_sym_by] = ACTIONS(4330),
    [anon_sym_select] = ACTIONS(4401),
    [anon_sym_as] = ACTIONS(4401),
    [anon_sym_is] = ACTIONS(4401),
    [anon_sym_DASH_GT] = ACTIONS(4399),
    [anon_sym_with] = ACTIONS(4401),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3361] = {
    [sym__variable_designation] = STATE(5036),
    [sym_parenthesized_variable_designation] = STATE(5027),
    [sym_identifier] = STATE(5034),
    [sym__reserved_identifier] = STATE(3572),
    [sym_preproc_region] = STATE(3361),
    [sym_preproc_endregion] = STATE(3361),
    [sym_preproc_line] = STATE(3361),
    [sym_preproc_pragma] = STATE(3361),
    [sym_preproc_nullable] = STATE(3361),
    [sym_preproc_error] = STATE(3361),
    [sym_preproc_warning] = STATE(3361),
    [sym_preproc_define] = STATE(3361),
    [sym_preproc_undef] = STATE(3361),
    [sym__identifier_token] = ACTIONS(4328),
    [anon_sym_alias] = ACTIONS(4330),
    [anon_sym_global] = ACTIONS(4330),
    [anon_sym_LBRACK] = ACTIONS(4405),
    [anon_sym_LPAREN] = ACTIONS(4405),
    [anon_sym_file] = ACTIONS(4330),
    [anon_sym_LT] = ACTIONS(4407),
    [anon_sym_GT] = ACTIONS(4407),
    [anon_sym_where] = ACTIONS(4407),
    [anon_sym_QMARK] = ACTIONS(4407),
    [anon_sym_notnull] = ACTIONS(4330),
    [anon_sym_unmanaged] = ACTIONS(4330),
    [anon_sym_BANG] = ACTIONS(4407),
    [anon_sym_PLUS_PLUS] = ACTIONS(4405),
    [anon_sym_DASH_DASH] = ACTIONS(4405),
    [anon_sym_PLUS] = ACTIONS(4407),
    [anon_sym_DASH] = ACTIONS(4407),
    [anon_sym_STAR] = ACTIONS(4405),
    [anon_sym_SLASH] = ACTIONS(4407),
    [anon_sym_PERCENT] = ACTIONS(4405),
    [anon_sym_CARET] = ACTIONS(4405),
    [anon_sym_PIPE] = ACTIONS(4407),
    [anon_sym_AMP] = ACTIONS(4407),
    [anon_sym_LT_LT] = ACTIONS(4405),
    [anon_sym_GT_GT] = ACTIONS(4407),
    [anon_sym_GT_GT_GT] = ACTIONS(4405),
    [anon_sym_EQ_EQ] = ACTIONS(4405),
    [anon_sym_BANG_EQ] = ACTIONS(4405),
    [anon_sym_GT_EQ] = ACTIONS(4405),
    [anon_sym_LT_EQ] = ACTIONS(4405),
    [anon_sym_DOT] = ACTIONS(4407),
    [anon_sym_scoped] = ACTIONS(4330),
    [anon_sym_var] = ACTIONS(4330),
    [anon_sym_yield] = ACTIONS(4330),
    [anon_sym_switch] = ACTIONS(4407),
    [anon_sym_when] = ACTIONS(4330),
    [sym_discard] = ACTIONS(4719),
    [anon_sym_DOT_DOT] = ACTIONS(4405),
    [anon_sym_and] = ACTIONS(4407),
    [anon_sym_or] = ACTIONS(4407),
    [anon_sym_AMP_AMP] = ACTIONS(4405),
    [anon_sym_PIPE_PIPE] = ACTIONS(4405),
    [anon_sym_QMARK_QMARK] = ACTIONS(4405),
    [anon_sym_from] = ACTIONS(4407),
    [anon_sym_into] = ACTIONS(4407),
    [anon_sym_join] = ACTIONS(4407),
    [anon_sym_on] = ACTIONS(4330),
    [anon_sym_equals] = ACTIONS(4330),
    [anon_sym_let] = ACTIONS(4407),
    [anon_sym_orderby] = ACTIONS(4407),
    [anon_sym_ascending] = ACTIONS(4330),
    [anon_sym_descending] = ACTIONS(4330),
    [anon_sym_group] = ACTIONS(4407),
    [anon_sym_by] = ACTIONS(4330),
    [anon_sym_select] = ACTIONS(4407),
    [anon_sym_as] = ACTIONS(4407),
    [anon_sym_is] = ACTIONS(4407),
    [anon_sym_DASH_GT] = ACTIONS(4405),
    [anon_sym_with] = ACTIONS(4407),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3362] = {
    [sym__variable_designation] = STATE(5021),
    [sym_parenthesized_variable_designation] = STATE(5027),
    [sym_identifier] = STATE(5034),
    [sym__reserved_identifier] = STATE(3572),
    [sym_preproc_region] = STATE(3362),
    [sym_preproc_endregion] = STATE(3362),
    [sym_preproc_line] = STATE(3362),
    [sym_preproc_pragma] = STATE(3362),
    [sym_preproc_nullable] = STATE(3362),
    [sym_preproc_error] = STATE(3362),
    [sym_preproc_warning] = STATE(3362),
    [sym_preproc_define] = STATE(3362),
    [sym_preproc_undef] = STATE(3362),
    [sym__identifier_token] = ACTIONS(4328),
    [anon_sym_alias] = ACTIONS(4330),
    [anon_sym_global] = ACTIONS(4330),
    [anon_sym_LBRACK] = ACTIONS(4437),
    [anon_sym_LPAREN] = ACTIONS(4437),
    [anon_sym_file] = ACTIONS(4330),
    [anon_sym_LT] = ACTIONS(4439),
    [anon_sym_GT] = ACTIONS(4439),
    [anon_sym_where] = ACTIONS(4439),
    [anon_sym_QMARK] = ACTIONS(4439),
    [anon_sym_notnull] = ACTIONS(4330),
    [anon_sym_unmanaged] = ACTIONS(4330),
    [anon_sym_BANG] = ACTIONS(4439),
    [anon_sym_PLUS_PLUS] = ACTIONS(4437),
    [anon_sym_DASH_DASH] = ACTIONS(4437),
    [anon_sym_PLUS] = ACTIONS(4439),
    [anon_sym_DASH] = ACTIONS(4439),
    [anon_sym_STAR] = ACTIONS(4437),
    [anon_sym_SLASH] = ACTIONS(4439),
    [anon_sym_PERCENT] = ACTIONS(4437),
    [anon_sym_CARET] = ACTIONS(4437),
    [anon_sym_PIPE] = ACTIONS(4439),
    [anon_sym_AMP] = ACTIONS(4439),
    [anon_sym_LT_LT] = ACTIONS(4437),
    [anon_sym_GT_GT] = ACTIONS(4439),
    [anon_sym_GT_GT_GT] = ACTIONS(4437),
    [anon_sym_EQ_EQ] = ACTIONS(4437),
    [anon_sym_BANG_EQ] = ACTIONS(4437),
    [anon_sym_GT_EQ] = ACTIONS(4437),
    [anon_sym_LT_EQ] = ACTIONS(4437),
    [anon_sym_DOT] = ACTIONS(4439),
    [anon_sym_scoped] = ACTIONS(4330),
    [anon_sym_var] = ACTIONS(4330),
    [anon_sym_yield] = ACTIONS(4330),
    [anon_sym_switch] = ACTIONS(4439),
    [anon_sym_when] = ACTIONS(4330),
    [sym_discard] = ACTIONS(4719),
    [anon_sym_DOT_DOT] = ACTIONS(4437),
    [anon_sym_and] = ACTIONS(4439),
    [anon_sym_or] = ACTIONS(4439),
    [anon_sym_AMP_AMP] = ACTIONS(4437),
    [anon_sym_PIPE_PIPE] = ACTIONS(4437),
    [anon_sym_QMARK_QMARK] = ACTIONS(4437),
    [anon_sym_from] = ACTIONS(4439),
    [anon_sym_into] = ACTIONS(4439),
    [anon_sym_join] = ACTIONS(4439),
    [anon_sym_on] = ACTIONS(4330),
    [anon_sym_equals] = ACTIONS(4330),
    [anon_sym_let] = ACTIONS(4439),
    [anon_sym_orderby] = ACTIONS(4439),
    [anon_sym_ascending] = ACTIONS(4330),
    [anon_sym_descending] = ACTIONS(4330),
    [anon_sym_group] = ACTIONS(4439),
    [anon_sym_by] = ACTIONS(4330),
    [anon_sym_select] = ACTIONS(4439),
    [anon_sym_as] = ACTIONS(4439),
    [anon_sym_is] = ACTIONS(4439),
    [anon_sym_DASH_GT] = ACTIONS(4437),
    [anon_sym_with] = ACTIONS(4439),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3363] = {
    [sym__variable_designation] = STATE(5005),
    [sym_parenthesized_variable_designation] = STATE(5027),
    [sym_identifier] = STATE(5034),
    [sym__reserved_identifier] = STATE(3572),
    [sym_preproc_region] = STATE(3363),
    [sym_preproc_endregion] = STATE(3363),
    [sym_preproc_line] = STATE(3363),
    [sym_preproc_pragma] = STATE(3363),
    [sym_preproc_nullable] = STATE(3363),
    [sym_preproc_error] = STATE(3363),
    [sym_preproc_warning] = STATE(3363),
    [sym_preproc_define] = STATE(3363),
    [sym_preproc_undef] = STATE(3363),
    [sym__identifier_token] = ACTIONS(4328),
    [anon_sym_alias] = ACTIONS(4330),
    [anon_sym_global] = ACTIONS(4330),
    [anon_sym_LBRACK] = ACTIONS(4441),
    [anon_sym_LPAREN] = ACTIONS(4441),
    [anon_sym_file] = ACTIONS(4330),
    [anon_sym_LT] = ACTIONS(4443),
    [anon_sym_GT] = ACTIONS(4443),
    [anon_sym_where] = ACTIONS(4443),
    [anon_sym_QMARK] = ACTIONS(4443),
    [anon_sym_notnull] = ACTIONS(4330),
    [anon_sym_unmanaged] = ACTIONS(4330),
    [anon_sym_BANG] = ACTIONS(4443),
    [anon_sym_PLUS_PLUS] = ACTIONS(4441),
    [anon_sym_DASH_DASH] = ACTIONS(4441),
    [anon_sym_PLUS] = ACTIONS(4443),
    [anon_sym_DASH] = ACTIONS(4443),
    [anon_sym_STAR] = ACTIONS(4441),
    [anon_sym_SLASH] = ACTIONS(4443),
    [anon_sym_PERCENT] = ACTIONS(4441),
    [anon_sym_CARET] = ACTIONS(4441),
    [anon_sym_PIPE] = ACTIONS(4443),
    [anon_sym_AMP] = ACTIONS(4443),
    [anon_sym_LT_LT] = ACTIONS(4441),
    [anon_sym_GT_GT] = ACTIONS(4443),
    [anon_sym_GT_GT_GT] = ACTIONS(4441),
    [anon_sym_EQ_EQ] = ACTIONS(4441),
    [anon_sym_BANG_EQ] = ACTIONS(4441),
    [anon_sym_GT_EQ] = ACTIONS(4441),
    [anon_sym_LT_EQ] = ACTIONS(4441),
    [anon_sym_DOT] = ACTIONS(4443),
    [anon_sym_scoped] = ACTIONS(4330),
    [anon_sym_var] = ACTIONS(4330),
    [anon_sym_yield] = ACTIONS(4330),
    [anon_sym_switch] = ACTIONS(4443),
    [anon_sym_when] = ACTIONS(4330),
    [sym_discard] = ACTIONS(4719),
    [anon_sym_DOT_DOT] = ACTIONS(4441),
    [anon_sym_and] = ACTIONS(4443),
    [anon_sym_or] = ACTIONS(4443),
    [anon_sym_AMP_AMP] = ACTIONS(4441),
    [anon_sym_PIPE_PIPE] = ACTIONS(4441),
    [anon_sym_QMARK_QMARK] = ACTIONS(4441),
    [anon_sym_from] = ACTIONS(4443),
    [anon_sym_into] = ACTIONS(4443),
    [anon_sym_join] = ACTIONS(4443),
    [anon_sym_on] = ACTIONS(4330),
    [anon_sym_equals] = ACTIONS(4330),
    [anon_sym_let] = ACTIONS(4443),
    [anon_sym_orderby] = ACTIONS(4443),
    [anon_sym_ascending] = ACTIONS(4330),
    [anon_sym_descending] = ACTIONS(4330),
    [anon_sym_group] = ACTIONS(4443),
    [anon_sym_by] = ACTIONS(4330),
    [anon_sym_select] = ACTIONS(4443),
    [anon_sym_as] = ACTIONS(4443),
    [anon_sym_is] = ACTIONS(4443),
    [anon_sym_DASH_GT] = ACTIONS(4441),
    [anon_sym_with] = ACTIONS(4443),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3364] = {
    [sym_preproc_region] = STATE(3364),
    [sym_preproc_endregion] = STATE(3364),
    [sym_preproc_line] = STATE(3364),
    [sym_preproc_pragma] = STATE(3364),
    [sym_preproc_nullable] = STATE(3364),
    [sym_preproc_error] = STATE(3364),
    [sym_preproc_warning] = STATE(3364),
    [sym_preproc_define] = STATE(3364),
    [sym_preproc_undef] = STATE(3364),
    [sym__identifier_token] = ACTIONS(5069),
    [anon_sym_extern] = ACTIONS(5069),
    [anon_sym_alias] = ACTIONS(5069),
    [anon_sym_global] = ACTIONS(5069),
    [anon_sym_using] = ACTIONS(5069),
    [anon_sym_unsafe] = ACTIONS(5069),
    [anon_sym_static] = ACTIONS(5069),
    [anon_sym_LBRACK] = ACTIONS(5071),
    [anon_sym_LPAREN] = ACTIONS(5071),
    [anon_sym_event] = ACTIONS(5069),
    [anon_sym_namespace] = ACTIONS(5069),
    [anon_sym_class] = ACTIONS(5069),
    [anon_sym_ref] = ACTIONS(5069),
    [anon_sym_struct] = ACTIONS(5069),
    [anon_sym_enum] = ACTIONS(5069),
    [anon_sym_RBRACE] = ACTIONS(5071),
    [anon_sym_interface] = ACTIONS(5069),
    [anon_sym_delegate] = ACTIONS(5069),
    [anon_sym_record] = ACTIONS(5069),
    [anon_sym_abstract] = ACTIONS(5069),
    [anon_sym_async] = ACTIONS(5069),
    [anon_sym_const] = ACTIONS(5069),
    [anon_sym_file] = ACTIONS(5069),
    [anon_sym_fixed] = ACTIONS(5069),
    [anon_sym_internal] = ACTIONS(5069),
    [anon_sym_new] = ACTIONS(5069),
    [anon_sym_override] = ACTIONS(5069),
    [anon_sym_partial] = ACTIONS(5069),
    [anon_sym_private] = ACTIONS(5069),
    [anon_sym_protected] = ACTIONS(5069),
    [anon_sym_public] = ACTIONS(5069),
    [anon_sym_readonly] = ACTIONS(5069),
    [anon_sym_required] = ACTIONS(5069),
    [anon_sym_sealed] = ACTIONS(5069),
    [anon_sym_virtual] = ACTIONS(5069),
    [anon_sym_volatile] = ACTIONS(5069),
    [anon_sym_where] = ACTIONS(5069),
    [anon_sym_notnull] = ACTIONS(5069),
    [anon_sym_unmanaged] = ACTIONS(5069),
    [anon_sym_TILDE] = ACTIONS(5071),
    [anon_sym_implicit] = ACTIONS(5069),
    [anon_sym_explicit] = ACTIONS(5069),
    [anon_sym_scoped] = ACTIONS(5069),
    [anon_sym_var] = ACTIONS(5069),
    [sym_predefined_type] = ACTIONS(5069),
    [anon_sym_yield] = ACTIONS(5069),
    [anon_sym_when] = ACTIONS(5069),
    [anon_sym_from] = ACTIONS(5069),
    [anon_sym_into] = ACTIONS(5069),
    [anon_sym_join] = ACTIONS(5069),
    [anon_sym_on] = ACTIONS(5069),
    [anon_sym_equals] = ACTIONS(5069),
    [anon_sym_let] = ACTIONS(5069),
    [anon_sym_orderby] = ACTIONS(5069),
    [anon_sym_ascending] = ACTIONS(5069),
    [anon_sym_descending] = ACTIONS(5069),
    [anon_sym_group] = ACTIONS(5069),
    [anon_sym_by] = ACTIONS(5069),
    [anon_sym_select] = ACTIONS(5069),
    [aux_sym_preproc_if_token1] = ACTIONS(5071),
    [aux_sym_preproc_if_token3] = ACTIONS(5071),
    [aux_sym_preproc_else_token1] = ACTIONS(5071),
    [aux_sym_preproc_elif_token1] = ACTIONS(5071),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3365] = {
    [sym_preproc_region] = STATE(3365),
    [sym_preproc_endregion] = STATE(3365),
    [sym_preproc_line] = STATE(3365),
    [sym_preproc_pragma] = STATE(3365),
    [sym_preproc_nullable] = STATE(3365),
    [sym_preproc_error] = STATE(3365),
    [sym_preproc_warning] = STATE(3365),
    [sym_preproc_define] = STATE(3365),
    [sym_preproc_undef] = STATE(3365),
    [sym__identifier_token] = ACTIONS(4453),
    [anon_sym_alias] = ACTIONS(4453),
    [anon_sym_global] = ACTIONS(4453),
    [anon_sym_LBRACK] = ACTIONS(4455),
    [anon_sym_COLON] = ACTIONS(4455),
    [anon_sym_COMMA] = ACTIONS(4455),
    [anon_sym_LPAREN] = ACTIONS(4455),
    [anon_sym_LBRACE] = ACTIONS(4455),
    [anon_sym_file] = ACTIONS(4453),
    [anon_sym_LT] = ACTIONS(4453),
    [anon_sym_GT] = ACTIONS(4453),
    [anon_sym_where] = ACTIONS(4453),
    [anon_sym_QMARK] = ACTIONS(4453),
    [anon_sym_notnull] = ACTIONS(4453),
    [anon_sym_unmanaged] = ACTIONS(4453),
    [anon_sym_BANG] = ACTIONS(4453),
    [anon_sym_PLUS_PLUS] = ACTIONS(4455),
    [anon_sym_DASH_DASH] = ACTIONS(4455),
    [anon_sym_PLUS] = ACTIONS(4453),
    [anon_sym_DASH] = ACTIONS(4453),
    [anon_sym_STAR] = ACTIONS(4455),
    [anon_sym_SLASH] = ACTIONS(4453),
    [anon_sym_PERCENT] = ACTIONS(4455),
    [anon_sym_CARET] = ACTIONS(4455),
    [anon_sym_PIPE] = ACTIONS(4453),
    [anon_sym_AMP] = ACTIONS(4453),
    [anon_sym_LT_LT] = ACTIONS(4455),
    [anon_sym_GT_GT] = ACTIONS(4453),
    [anon_sym_GT_GT_GT] = ACTIONS(4455),
    [anon_sym_EQ_EQ] = ACTIONS(4455),
    [anon_sym_BANG_EQ] = ACTIONS(4455),
    [anon_sym_GT_EQ] = ACTIONS(4455),
    [anon_sym_LT_EQ] = ACTIONS(4455),
    [anon_sym_DOT] = ACTIONS(5073),
    [anon_sym_scoped] = ACTIONS(4453),
    [anon_sym_var] = ACTIONS(4453),
    [anon_sym_yield] = ACTIONS(4453),
    [anon_sym_switch] = ACTIONS(4453),
    [anon_sym_when] = ACTIONS(4453),
    [sym_discard] = ACTIONS(4453),
    [anon_sym_DOT_DOT] = ACTIONS(4455),
    [anon_sym_and] = ACTIONS(4453),
    [anon_sym_or] = ACTIONS(4453),
    [anon_sym_AMP_AMP] = ACTIONS(4455),
    [anon_sym_PIPE_PIPE] = ACTIONS(4455),
    [anon_sym_QMARK_QMARK] = ACTIONS(4455),
    [anon_sym_from] = ACTIONS(4453),
    [anon_sym_into] = ACTIONS(4453),
    [anon_sym_join] = ACTIONS(4453),
    [anon_sym_on] = ACTIONS(4453),
    [anon_sym_equals] = ACTIONS(4453),
    [anon_sym_let] = ACTIONS(4453),
    [anon_sym_orderby] = ACTIONS(4453),
    [anon_sym_ascending] = ACTIONS(4453),
    [anon_sym_descending] = ACTIONS(4453),
    [anon_sym_group] = ACTIONS(4453),
    [anon_sym_by] = ACTIONS(4453),
    [anon_sym_select] = ACTIONS(4453),
    [anon_sym_as] = ACTIONS(4453),
    [anon_sym_is] = ACTIONS(4453),
    [anon_sym_DASH_GT] = ACTIONS(4455),
    [anon_sym_with] = ACTIONS(4453),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4455),
  },
  [3366] = {
    [sym_preproc_region] = STATE(3366),
    [sym_preproc_endregion] = STATE(3366),
    [sym_preproc_line] = STATE(3366),
    [sym_preproc_pragma] = STATE(3366),
    [sym_preproc_nullable] = STATE(3366),
    [sym_preproc_error] = STATE(3366),
    [sym_preproc_warning] = STATE(3366),
    [sym_preproc_define] = STATE(3366),
    [sym_preproc_undef] = STATE(3366),
    [sym__identifier_token] = ACTIONS(5075),
    [anon_sym_extern] = ACTIONS(5075),
    [anon_sym_alias] = ACTIONS(5075),
    [anon_sym_global] = ACTIONS(5075),
    [anon_sym_using] = ACTIONS(5075),
    [anon_sym_unsafe] = ACTIONS(5075),
    [anon_sym_static] = ACTIONS(5075),
    [anon_sym_LBRACK] = ACTIONS(5077),
    [anon_sym_LPAREN] = ACTIONS(5077),
    [anon_sym_event] = ACTIONS(5075),
    [anon_sym_namespace] = ACTIONS(5075),
    [anon_sym_class] = ACTIONS(5075),
    [anon_sym_ref] = ACTIONS(5075),
    [anon_sym_struct] = ACTIONS(5075),
    [anon_sym_enum] = ACTIONS(5075),
    [anon_sym_RBRACE] = ACTIONS(5077),
    [anon_sym_interface] = ACTIONS(5075),
    [anon_sym_delegate] = ACTIONS(5075),
    [anon_sym_record] = ACTIONS(5075),
    [anon_sym_abstract] = ACTIONS(5075),
    [anon_sym_async] = ACTIONS(5075),
    [anon_sym_const] = ACTIONS(5075),
    [anon_sym_file] = ACTIONS(5075),
    [anon_sym_fixed] = ACTIONS(5075),
    [anon_sym_internal] = ACTIONS(5075),
    [anon_sym_new] = ACTIONS(5075),
    [anon_sym_override] = ACTIONS(5075),
    [anon_sym_partial] = ACTIONS(5075),
    [anon_sym_private] = ACTIONS(5075),
    [anon_sym_protected] = ACTIONS(5075),
    [anon_sym_public] = ACTIONS(5075),
    [anon_sym_readonly] = ACTIONS(5075),
    [anon_sym_required] = ACTIONS(5075),
    [anon_sym_sealed] = ACTIONS(5075),
    [anon_sym_virtual] = ACTIONS(5075),
    [anon_sym_volatile] = ACTIONS(5075),
    [anon_sym_where] = ACTIONS(5075),
    [anon_sym_notnull] = ACTIONS(5075),
    [anon_sym_unmanaged] = ACTIONS(5075),
    [anon_sym_TILDE] = ACTIONS(5077),
    [anon_sym_implicit] = ACTIONS(5075),
    [anon_sym_explicit] = ACTIONS(5075),
    [anon_sym_scoped] = ACTIONS(5075),
    [anon_sym_var] = ACTIONS(5075),
    [sym_predefined_type] = ACTIONS(5075),
    [anon_sym_yield] = ACTIONS(5075),
    [anon_sym_when] = ACTIONS(5075),
    [anon_sym_from] = ACTIONS(5075),
    [anon_sym_into] = ACTIONS(5075),
    [anon_sym_join] = ACTIONS(5075),
    [anon_sym_on] = ACTIONS(5075),
    [anon_sym_equals] = ACTIONS(5075),
    [anon_sym_let] = ACTIONS(5075),
    [anon_sym_orderby] = ACTIONS(5075),
    [anon_sym_ascending] = ACTIONS(5075),
    [anon_sym_descending] = ACTIONS(5075),
    [anon_sym_group] = ACTIONS(5075),
    [anon_sym_by] = ACTIONS(5075),
    [anon_sym_select] = ACTIONS(5075),
    [aux_sym_preproc_if_token1] = ACTIONS(5077),
    [aux_sym_preproc_if_token3] = ACTIONS(5077),
    [aux_sym_preproc_else_token1] = ACTIONS(5077),
    [aux_sym_preproc_elif_token1] = ACTIONS(5077),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3367] = {
    [sym_preproc_region] = STATE(3367),
    [sym_preproc_endregion] = STATE(3367),
    [sym_preproc_line] = STATE(3367),
    [sym_preproc_pragma] = STATE(3367),
    [sym_preproc_nullable] = STATE(3367),
    [sym_preproc_error] = STATE(3367),
    [sym_preproc_warning] = STATE(3367),
    [sym_preproc_define] = STATE(3367),
    [sym_preproc_undef] = STATE(3367),
    [sym__identifier_token] = ACTIONS(5079),
    [anon_sym_extern] = ACTIONS(5079),
    [anon_sym_alias] = ACTIONS(5079),
    [anon_sym_global] = ACTIONS(5079),
    [anon_sym_using] = ACTIONS(5079),
    [anon_sym_unsafe] = ACTIONS(5079),
    [anon_sym_static] = ACTIONS(5079),
    [anon_sym_LBRACK] = ACTIONS(5081),
    [anon_sym_LPAREN] = ACTIONS(5081),
    [anon_sym_event] = ACTIONS(5079),
    [anon_sym_namespace] = ACTIONS(5079),
    [anon_sym_class] = ACTIONS(5079),
    [anon_sym_ref] = ACTIONS(5079),
    [anon_sym_struct] = ACTIONS(5079),
    [anon_sym_enum] = ACTIONS(5079),
    [anon_sym_RBRACE] = ACTIONS(5081),
    [anon_sym_interface] = ACTIONS(5079),
    [anon_sym_delegate] = ACTIONS(5079),
    [anon_sym_record] = ACTIONS(5079),
    [anon_sym_abstract] = ACTIONS(5079),
    [anon_sym_async] = ACTIONS(5079),
    [anon_sym_const] = ACTIONS(5079),
    [anon_sym_file] = ACTIONS(5079),
    [anon_sym_fixed] = ACTIONS(5079),
    [anon_sym_internal] = ACTIONS(5079),
    [anon_sym_new] = ACTIONS(5079),
    [anon_sym_override] = ACTIONS(5079),
    [anon_sym_partial] = ACTIONS(5079),
    [anon_sym_private] = ACTIONS(5079),
    [anon_sym_protected] = ACTIONS(5079),
    [anon_sym_public] = ACTIONS(5079),
    [anon_sym_readonly] = ACTIONS(5079),
    [anon_sym_required] = ACTIONS(5079),
    [anon_sym_sealed] = ACTIONS(5079),
    [anon_sym_virtual] = ACTIONS(5079),
    [anon_sym_volatile] = ACTIONS(5079),
    [anon_sym_where] = ACTIONS(5079),
    [anon_sym_notnull] = ACTIONS(5079),
    [anon_sym_unmanaged] = ACTIONS(5079),
    [anon_sym_TILDE] = ACTIONS(5081),
    [anon_sym_implicit] = ACTIONS(5079),
    [anon_sym_explicit] = ACTIONS(5079),
    [anon_sym_scoped] = ACTIONS(5079),
    [anon_sym_var] = ACTIONS(5079),
    [sym_predefined_type] = ACTIONS(5079),
    [anon_sym_yield] = ACTIONS(5079),
    [anon_sym_when] = ACTIONS(5079),
    [anon_sym_from] = ACTIONS(5079),
    [anon_sym_into] = ACTIONS(5079),
    [anon_sym_join] = ACTIONS(5079),
    [anon_sym_on] = ACTIONS(5079),
    [anon_sym_equals] = ACTIONS(5079),
    [anon_sym_let] = ACTIONS(5079),
    [anon_sym_orderby] = ACTIONS(5079),
    [anon_sym_ascending] = ACTIONS(5079),
    [anon_sym_descending] = ACTIONS(5079),
    [anon_sym_group] = ACTIONS(5079),
    [anon_sym_by] = ACTIONS(5079),
    [anon_sym_select] = ACTIONS(5079),
    [aux_sym_preproc_if_token1] = ACTIONS(5081),
    [aux_sym_preproc_if_token3] = ACTIONS(5081),
    [aux_sym_preproc_else_token1] = ACTIONS(5081),
    [aux_sym_preproc_elif_token1] = ACTIONS(5081),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3368] = {
    [sym_preproc_region] = STATE(3368),
    [sym_preproc_endregion] = STATE(3368),
    [sym_preproc_line] = STATE(3368),
    [sym_preproc_pragma] = STATE(3368),
    [sym_preproc_nullable] = STATE(3368),
    [sym_preproc_error] = STATE(3368),
    [sym_preproc_warning] = STATE(3368),
    [sym_preproc_define] = STATE(3368),
    [sym_preproc_undef] = STATE(3368),
    [sym__identifier_token] = ACTIONS(4453),
    [anon_sym_alias] = ACTIONS(4453),
    [anon_sym_global] = ACTIONS(4453),
    [anon_sym_LBRACK] = ACTIONS(4455),
    [anon_sym_COLON] = ACTIONS(4455),
    [anon_sym_COMMA] = ACTIONS(4455),
    [anon_sym_LPAREN] = ACTIONS(4455),
    [anon_sym_LBRACE] = ACTIONS(4455),
    [anon_sym_file] = ACTIONS(4453),
    [anon_sym_LT] = ACTIONS(4453),
    [anon_sym_GT] = ACTIONS(4453),
    [anon_sym_where] = ACTIONS(4453),
    [anon_sym_QMARK] = ACTIONS(4453),
    [anon_sym_notnull] = ACTIONS(4453),
    [anon_sym_unmanaged] = ACTIONS(4453),
    [anon_sym_BANG] = ACTIONS(4453),
    [anon_sym_PLUS_PLUS] = ACTIONS(4455),
    [anon_sym_DASH_DASH] = ACTIONS(4455),
    [anon_sym_PLUS] = ACTIONS(4453),
    [anon_sym_DASH] = ACTIONS(4453),
    [anon_sym_STAR] = ACTIONS(4455),
    [anon_sym_SLASH] = ACTIONS(4453),
    [anon_sym_PERCENT] = ACTIONS(4455),
    [anon_sym_CARET] = ACTIONS(4455),
    [anon_sym_PIPE] = ACTIONS(4453),
    [anon_sym_AMP] = ACTIONS(4453),
    [anon_sym_LT_LT] = ACTIONS(4455),
    [anon_sym_GT_GT] = ACTIONS(4453),
    [anon_sym_GT_GT_GT] = ACTIONS(4455),
    [anon_sym_EQ_EQ] = ACTIONS(4455),
    [anon_sym_BANG_EQ] = ACTIONS(4455),
    [anon_sym_GT_EQ] = ACTIONS(4455),
    [anon_sym_LT_EQ] = ACTIONS(4455),
    [anon_sym_DOT] = ACTIONS(4453),
    [anon_sym_scoped] = ACTIONS(4453),
    [anon_sym_var] = ACTIONS(4453),
    [anon_sym_yield] = ACTIONS(4453),
    [anon_sym_switch] = ACTIONS(4453),
    [anon_sym_when] = ACTIONS(4453),
    [sym_discard] = ACTIONS(4453),
    [anon_sym_DOT_DOT] = ACTIONS(4455),
    [anon_sym_and] = ACTIONS(4453),
    [anon_sym_or] = ACTIONS(4453),
    [anon_sym_AMP_AMP] = ACTIONS(4455),
    [anon_sym_PIPE_PIPE] = ACTIONS(4455),
    [anon_sym_QMARK_QMARK] = ACTIONS(4455),
    [anon_sym_from] = ACTIONS(4453),
    [anon_sym_into] = ACTIONS(4453),
    [anon_sym_join] = ACTIONS(4453),
    [anon_sym_on] = ACTIONS(4453),
    [anon_sym_equals] = ACTIONS(4453),
    [anon_sym_let] = ACTIONS(4453),
    [anon_sym_orderby] = ACTIONS(4453),
    [anon_sym_ascending] = ACTIONS(4453),
    [anon_sym_descending] = ACTIONS(4453),
    [anon_sym_group] = ACTIONS(4453),
    [anon_sym_by] = ACTIONS(4453),
    [anon_sym_select] = ACTIONS(4453),
    [anon_sym_as] = ACTIONS(4453),
    [anon_sym_is] = ACTIONS(4453),
    [anon_sym_DASH_GT] = ACTIONS(4455),
    [anon_sym_with] = ACTIONS(4453),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4455),
  },
  [3369] = {
    [sym_preproc_region] = STATE(3369),
    [sym_preproc_endregion] = STATE(3369),
    [sym_preproc_line] = STATE(3369),
    [sym_preproc_pragma] = STATE(3369),
    [sym_preproc_nullable] = STATE(3369),
    [sym_preproc_error] = STATE(3369),
    [sym_preproc_warning] = STATE(3369),
    [sym_preproc_define] = STATE(3369),
    [sym_preproc_undef] = STATE(3369),
    [sym__identifier_token] = ACTIONS(4466),
    [anon_sym_alias] = ACTIONS(4466),
    [anon_sym_global] = ACTIONS(4466),
    [anon_sym_LBRACK] = ACTIONS(4468),
    [anon_sym_COLON] = ACTIONS(4468),
    [anon_sym_COMMA] = ACTIONS(4468),
    [anon_sym_LPAREN] = ACTIONS(4468),
    [anon_sym_LBRACE] = ACTIONS(4468),
    [anon_sym_file] = ACTIONS(4466),
    [anon_sym_LT] = ACTIONS(4466),
    [anon_sym_GT] = ACTIONS(4466),
    [anon_sym_where] = ACTIONS(4466),
    [anon_sym_QMARK] = ACTIONS(4466),
    [anon_sym_notnull] = ACTIONS(4466),
    [anon_sym_unmanaged] = ACTIONS(4466),
    [anon_sym_BANG] = ACTIONS(4466),
    [anon_sym_PLUS_PLUS] = ACTIONS(4468),
    [anon_sym_DASH_DASH] = ACTIONS(4468),
    [anon_sym_PLUS] = ACTIONS(4466),
    [anon_sym_DASH] = ACTIONS(4466),
    [anon_sym_STAR] = ACTIONS(4468),
    [anon_sym_SLASH] = ACTIONS(4466),
    [anon_sym_PERCENT] = ACTIONS(4468),
    [anon_sym_CARET] = ACTIONS(4468),
    [anon_sym_PIPE] = ACTIONS(4466),
    [anon_sym_AMP] = ACTIONS(4466),
    [anon_sym_LT_LT] = ACTIONS(4468),
    [anon_sym_GT_GT] = ACTIONS(4466),
    [anon_sym_GT_GT_GT] = ACTIONS(4468),
    [anon_sym_EQ_EQ] = ACTIONS(4468),
    [anon_sym_BANG_EQ] = ACTIONS(4468),
    [anon_sym_GT_EQ] = ACTIONS(4468),
    [anon_sym_LT_EQ] = ACTIONS(4468),
    [anon_sym_DOT] = ACTIONS(4466),
    [anon_sym_scoped] = ACTIONS(4466),
    [anon_sym_var] = ACTIONS(4466),
    [anon_sym_yield] = ACTIONS(4466),
    [anon_sym_switch] = ACTIONS(4466),
    [anon_sym_when] = ACTIONS(4466),
    [sym_discard] = ACTIONS(4466),
    [anon_sym_DOT_DOT] = ACTIONS(4468),
    [anon_sym_and] = ACTIONS(4466),
    [anon_sym_or] = ACTIONS(4466),
    [anon_sym_AMP_AMP] = ACTIONS(4468),
    [anon_sym_PIPE_PIPE] = ACTIONS(4468),
    [anon_sym_QMARK_QMARK] = ACTIONS(4468),
    [anon_sym_from] = ACTIONS(4466),
    [anon_sym_into] = ACTIONS(4466),
    [anon_sym_join] = ACTIONS(4466),
    [anon_sym_on] = ACTIONS(4466),
    [anon_sym_equals] = ACTIONS(4466),
    [anon_sym_let] = ACTIONS(4466),
    [anon_sym_orderby] = ACTIONS(4466),
    [anon_sym_ascending] = ACTIONS(4466),
    [anon_sym_descending] = ACTIONS(4466),
    [anon_sym_group] = ACTIONS(4466),
    [anon_sym_by] = ACTIONS(4466),
    [anon_sym_select] = ACTIONS(4466),
    [anon_sym_as] = ACTIONS(4466),
    [anon_sym_is] = ACTIONS(4466),
    [anon_sym_DASH_GT] = ACTIONS(4468),
    [anon_sym_with] = ACTIONS(4466),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4468),
  },
  [3370] = {
    [sym_preproc_region] = STATE(3370),
    [sym_preproc_endregion] = STATE(3370),
    [sym_preproc_line] = STATE(3370),
    [sym_preproc_pragma] = STATE(3370),
    [sym_preproc_nullable] = STATE(3370),
    [sym_preproc_error] = STATE(3370),
    [sym_preproc_warning] = STATE(3370),
    [sym_preproc_define] = STATE(3370),
    [sym_preproc_undef] = STATE(3370),
    [sym__identifier_token] = ACTIONS(4478),
    [anon_sym_alias] = ACTIONS(4478),
    [anon_sym_global] = ACTIONS(4478),
    [anon_sym_LBRACK] = ACTIONS(4480),
    [anon_sym_COLON] = ACTIONS(4480),
    [anon_sym_COMMA] = ACTIONS(4480),
    [anon_sym_LPAREN] = ACTIONS(4480),
    [anon_sym_LBRACE] = ACTIONS(4480),
    [anon_sym_file] = ACTIONS(4478),
    [anon_sym_LT] = ACTIONS(4478),
    [anon_sym_GT] = ACTIONS(4478),
    [anon_sym_where] = ACTIONS(4478),
    [anon_sym_QMARK] = ACTIONS(4478),
    [anon_sym_notnull] = ACTIONS(4478),
    [anon_sym_unmanaged] = ACTIONS(4478),
    [anon_sym_BANG] = ACTIONS(4478),
    [anon_sym_PLUS_PLUS] = ACTIONS(4480),
    [anon_sym_DASH_DASH] = ACTIONS(4480),
    [anon_sym_PLUS] = ACTIONS(4478),
    [anon_sym_DASH] = ACTIONS(4478),
    [anon_sym_STAR] = ACTIONS(4480),
    [anon_sym_SLASH] = ACTIONS(4478),
    [anon_sym_PERCENT] = ACTIONS(4480),
    [anon_sym_CARET] = ACTIONS(4480),
    [anon_sym_PIPE] = ACTIONS(4478),
    [anon_sym_AMP] = ACTIONS(4478),
    [anon_sym_LT_LT] = ACTIONS(4480),
    [anon_sym_GT_GT] = ACTIONS(4478),
    [anon_sym_GT_GT_GT] = ACTIONS(4480),
    [anon_sym_EQ_EQ] = ACTIONS(4480),
    [anon_sym_BANG_EQ] = ACTIONS(4480),
    [anon_sym_GT_EQ] = ACTIONS(4480),
    [anon_sym_LT_EQ] = ACTIONS(4480),
    [anon_sym_DOT] = ACTIONS(4478),
    [anon_sym_scoped] = ACTIONS(4478),
    [anon_sym_var] = ACTIONS(4478),
    [anon_sym_yield] = ACTIONS(4478),
    [anon_sym_switch] = ACTIONS(4478),
    [anon_sym_when] = ACTIONS(4478),
    [sym_discard] = ACTIONS(4478),
    [anon_sym_DOT_DOT] = ACTIONS(4480),
    [anon_sym_and] = ACTIONS(4478),
    [anon_sym_or] = ACTIONS(4478),
    [anon_sym_AMP_AMP] = ACTIONS(4480),
    [anon_sym_PIPE_PIPE] = ACTIONS(4480),
    [anon_sym_QMARK_QMARK] = ACTIONS(4480),
    [anon_sym_from] = ACTIONS(4478),
    [anon_sym_into] = ACTIONS(4478),
    [anon_sym_join] = ACTIONS(4478),
    [anon_sym_on] = ACTIONS(4478),
    [anon_sym_equals] = ACTIONS(4478),
    [anon_sym_let] = ACTIONS(4478),
    [anon_sym_orderby] = ACTIONS(4478),
    [anon_sym_ascending] = ACTIONS(4478),
    [anon_sym_descending] = ACTIONS(4478),
    [anon_sym_group] = ACTIONS(4478),
    [anon_sym_by] = ACTIONS(4478),
    [anon_sym_select] = ACTIONS(4478),
    [anon_sym_as] = ACTIONS(4478),
    [anon_sym_is] = ACTIONS(4478),
    [anon_sym_DASH_GT] = ACTIONS(4480),
    [anon_sym_with] = ACTIONS(4478),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4480),
  },
  [3371] = {
    [sym_preproc_region] = STATE(3371),
    [sym_preproc_endregion] = STATE(3371),
    [sym_preproc_line] = STATE(3371),
    [sym_preproc_pragma] = STATE(3371),
    [sym_preproc_nullable] = STATE(3371),
    [sym_preproc_error] = STATE(3371),
    [sym_preproc_warning] = STATE(3371),
    [sym_preproc_define] = STATE(3371),
    [sym_preproc_undef] = STATE(3371),
    [sym__identifier_token] = ACTIONS(3601),
    [anon_sym_extern] = ACTIONS(3601),
    [anon_sym_alias] = ACTIONS(3601),
    [anon_sym_global] = ACTIONS(3601),
    [anon_sym_using] = ACTIONS(3601),
    [anon_sym_unsafe] = ACTIONS(3601),
    [anon_sym_static] = ACTIONS(3601),
    [anon_sym_LBRACK] = ACTIONS(3603),
    [anon_sym_LPAREN] = ACTIONS(3603),
    [anon_sym_event] = ACTIONS(3601),
    [anon_sym_namespace] = ACTIONS(3601),
    [anon_sym_class] = ACTIONS(3601),
    [anon_sym_ref] = ACTIONS(3601),
    [anon_sym_struct] = ACTIONS(3601),
    [anon_sym_enum] = ACTIONS(3601),
    [anon_sym_RBRACE] = ACTIONS(3603),
    [anon_sym_interface] = ACTIONS(3601),
    [anon_sym_delegate] = ACTIONS(3601),
    [anon_sym_record] = ACTIONS(3601),
    [anon_sym_abstract] = ACTIONS(3601),
    [anon_sym_async] = ACTIONS(3601),
    [anon_sym_const] = ACTIONS(3601),
    [anon_sym_file] = ACTIONS(3601),
    [anon_sym_fixed] = ACTIONS(3601),
    [anon_sym_internal] = ACTIONS(3601),
    [anon_sym_new] = ACTIONS(3601),
    [anon_sym_override] = ACTIONS(3601),
    [anon_sym_partial] = ACTIONS(3601),
    [anon_sym_private] = ACTIONS(3601),
    [anon_sym_protected] = ACTIONS(3601),
    [anon_sym_public] = ACTIONS(3601),
    [anon_sym_readonly] = ACTIONS(3601),
    [anon_sym_required] = ACTIONS(3601),
    [anon_sym_sealed] = ACTIONS(3601),
    [anon_sym_virtual] = ACTIONS(3601),
    [anon_sym_volatile] = ACTIONS(3601),
    [anon_sym_where] = ACTIONS(3601),
    [anon_sym_notnull] = ACTIONS(3601),
    [anon_sym_unmanaged] = ACTIONS(3601),
    [anon_sym_TILDE] = ACTIONS(3603),
    [anon_sym_implicit] = ACTIONS(3601),
    [anon_sym_explicit] = ACTIONS(3601),
    [anon_sym_scoped] = ACTIONS(3601),
    [anon_sym_var] = ACTIONS(3601),
    [sym_predefined_type] = ACTIONS(3601),
    [anon_sym_yield] = ACTIONS(3601),
    [anon_sym_when] = ACTIONS(3601),
    [anon_sym_from] = ACTIONS(3601),
    [anon_sym_into] = ACTIONS(3601),
    [anon_sym_join] = ACTIONS(3601),
    [anon_sym_on] = ACTIONS(3601),
    [anon_sym_equals] = ACTIONS(3601),
    [anon_sym_let] = ACTIONS(3601),
    [anon_sym_orderby] = ACTIONS(3601),
    [anon_sym_ascending] = ACTIONS(3601),
    [anon_sym_descending] = ACTIONS(3601),
    [anon_sym_group] = ACTIONS(3601),
    [anon_sym_by] = ACTIONS(3601),
    [anon_sym_select] = ACTIONS(3601),
    [aux_sym_preproc_if_token1] = ACTIONS(3603),
    [aux_sym_preproc_if_token3] = ACTIONS(3603),
    [aux_sym_preproc_else_token1] = ACTIONS(3603),
    [aux_sym_preproc_elif_token1] = ACTIONS(3603),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3372] = {
    [sym_preproc_region] = STATE(3372),
    [sym_preproc_endregion] = STATE(3372),
    [sym_preproc_line] = STATE(3372),
    [sym_preproc_pragma] = STATE(3372),
    [sym_preproc_nullable] = STATE(3372),
    [sym_preproc_error] = STATE(3372),
    [sym_preproc_warning] = STATE(3372),
    [sym_preproc_define] = STATE(3372),
    [sym_preproc_undef] = STATE(3372),
    [sym__identifier_token] = ACTIONS(3605),
    [anon_sym_extern] = ACTIONS(3605),
    [anon_sym_alias] = ACTIONS(3605),
    [anon_sym_global] = ACTIONS(3605),
    [anon_sym_using] = ACTIONS(3605),
    [anon_sym_unsafe] = ACTIONS(3605),
    [anon_sym_static] = ACTIONS(3605),
    [anon_sym_LBRACK] = ACTIONS(3607),
    [anon_sym_LPAREN] = ACTIONS(3607),
    [anon_sym_event] = ACTIONS(3605),
    [anon_sym_namespace] = ACTIONS(3605),
    [anon_sym_class] = ACTIONS(3605),
    [anon_sym_ref] = ACTIONS(3605),
    [anon_sym_struct] = ACTIONS(3605),
    [anon_sym_enum] = ACTIONS(3605),
    [anon_sym_RBRACE] = ACTIONS(3607),
    [anon_sym_interface] = ACTIONS(3605),
    [anon_sym_delegate] = ACTIONS(3605),
    [anon_sym_record] = ACTIONS(3605),
    [anon_sym_abstract] = ACTIONS(3605),
    [anon_sym_async] = ACTIONS(3605),
    [anon_sym_const] = ACTIONS(3605),
    [anon_sym_file] = ACTIONS(3605),
    [anon_sym_fixed] = ACTIONS(3605),
    [anon_sym_internal] = ACTIONS(3605),
    [anon_sym_new] = ACTIONS(3605),
    [anon_sym_override] = ACTIONS(3605),
    [anon_sym_partial] = ACTIONS(3605),
    [anon_sym_private] = ACTIONS(3605),
    [anon_sym_protected] = ACTIONS(3605),
    [anon_sym_public] = ACTIONS(3605),
    [anon_sym_readonly] = ACTIONS(3605),
    [anon_sym_required] = ACTIONS(3605),
    [anon_sym_sealed] = ACTIONS(3605),
    [anon_sym_virtual] = ACTIONS(3605),
    [anon_sym_volatile] = ACTIONS(3605),
    [anon_sym_where] = ACTIONS(3605),
    [anon_sym_notnull] = ACTIONS(3605),
    [anon_sym_unmanaged] = ACTIONS(3605),
    [anon_sym_TILDE] = ACTIONS(3607),
    [anon_sym_implicit] = ACTIONS(3605),
    [anon_sym_explicit] = ACTIONS(3605),
    [anon_sym_scoped] = ACTIONS(3605),
    [anon_sym_var] = ACTIONS(3605),
    [sym_predefined_type] = ACTIONS(3605),
    [anon_sym_yield] = ACTIONS(3605),
    [anon_sym_when] = ACTIONS(3605),
    [anon_sym_from] = ACTIONS(3605),
    [anon_sym_into] = ACTIONS(3605),
    [anon_sym_join] = ACTIONS(3605),
    [anon_sym_on] = ACTIONS(3605),
    [anon_sym_equals] = ACTIONS(3605),
    [anon_sym_let] = ACTIONS(3605),
    [anon_sym_orderby] = ACTIONS(3605),
    [anon_sym_ascending] = ACTIONS(3605),
    [anon_sym_descending] = ACTIONS(3605),
    [anon_sym_group] = ACTIONS(3605),
    [anon_sym_by] = ACTIONS(3605),
    [anon_sym_select] = ACTIONS(3605),
    [aux_sym_preproc_if_token1] = ACTIONS(3607),
    [aux_sym_preproc_if_token3] = ACTIONS(3607),
    [aux_sym_preproc_else_token1] = ACTIONS(3607),
    [aux_sym_preproc_elif_token1] = ACTIONS(3607),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3373] = {
    [sym__variable_designation] = STATE(4167),
    [sym_parenthesized_variable_designation] = STATE(4153),
    [sym_identifier] = STATE(4156),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3373),
    [sym_preproc_endregion] = STATE(3373),
    [sym_preproc_line] = STATE(3373),
    [sym_preproc_pragma] = STATE(3373),
    [sym_preproc_nullable] = STATE(3373),
    [sym_preproc_error] = STATE(3373),
    [sym_preproc_warning] = STATE(3373),
    [sym_preproc_define] = STATE(3373),
    [sym_preproc_undef] = STATE(3373),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4399),
    [anon_sym_LPAREN] = ACTIONS(4399),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4401),
    [anon_sym_GT] = ACTIONS(4401),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4401),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4401),
    [anon_sym_PLUS_PLUS] = ACTIONS(4399),
    [anon_sym_DASH_DASH] = ACTIONS(4399),
    [anon_sym_PLUS] = ACTIONS(4401),
    [anon_sym_DASH] = ACTIONS(4401),
    [anon_sym_STAR] = ACTIONS(4399),
    [anon_sym_SLASH] = ACTIONS(4401),
    [anon_sym_PERCENT] = ACTIONS(4399),
    [anon_sym_CARET] = ACTIONS(4399),
    [anon_sym_PIPE] = ACTIONS(4401),
    [anon_sym_AMP] = ACTIONS(4401),
    [anon_sym_LT_LT] = ACTIONS(4399),
    [anon_sym_GT_GT] = ACTIONS(4401),
    [anon_sym_GT_GT_GT] = ACTIONS(4399),
    [anon_sym_EQ_EQ] = ACTIONS(4399),
    [anon_sym_BANG_EQ] = ACTIONS(4399),
    [anon_sym_GT_EQ] = ACTIONS(4399),
    [anon_sym_LT_EQ] = ACTIONS(4399),
    [anon_sym_DOT] = ACTIONS(4401),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4401),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4359),
    [anon_sym_DOT_DOT] = ACTIONS(4399),
    [anon_sym_and] = ACTIONS(4401),
    [anon_sym_or] = ACTIONS(4401),
    [anon_sym_AMP_AMP] = ACTIONS(4399),
    [anon_sym_PIPE_PIPE] = ACTIONS(4399),
    [anon_sym_QMARK_QMARK] = ACTIONS(4399),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4339),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4401),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4401),
    [anon_sym_is] = ACTIONS(4401),
    [anon_sym_DASH_GT] = ACTIONS(4399),
    [anon_sym_with] = ACTIONS(4401),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3374] = {
    [sym__variable_designation] = STATE(4182),
    [sym_parenthesized_variable_designation] = STATE(4153),
    [sym_identifier] = STATE(4156),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3374),
    [sym_preproc_endregion] = STATE(3374),
    [sym_preproc_line] = STATE(3374),
    [sym_preproc_pragma] = STATE(3374),
    [sym_preproc_nullable] = STATE(3374),
    [sym_preproc_error] = STATE(3374),
    [sym_preproc_warning] = STATE(3374),
    [sym_preproc_define] = STATE(3374),
    [sym_preproc_undef] = STATE(3374),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4405),
    [anon_sym_LPAREN] = ACTIONS(4405),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4407),
    [anon_sym_GT] = ACTIONS(4407),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4407),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4407),
    [anon_sym_PLUS_PLUS] = ACTIONS(4405),
    [anon_sym_DASH_DASH] = ACTIONS(4405),
    [anon_sym_PLUS] = ACTIONS(4407),
    [anon_sym_DASH] = ACTIONS(4407),
    [anon_sym_STAR] = ACTIONS(4405),
    [anon_sym_SLASH] = ACTIONS(4407),
    [anon_sym_PERCENT] = ACTIONS(4405),
    [anon_sym_CARET] = ACTIONS(4405),
    [anon_sym_PIPE] = ACTIONS(4407),
    [anon_sym_AMP] = ACTIONS(4407),
    [anon_sym_LT_LT] = ACTIONS(4405),
    [anon_sym_GT_GT] = ACTIONS(4407),
    [anon_sym_GT_GT_GT] = ACTIONS(4405),
    [anon_sym_EQ_EQ] = ACTIONS(4405),
    [anon_sym_BANG_EQ] = ACTIONS(4405),
    [anon_sym_GT_EQ] = ACTIONS(4405),
    [anon_sym_LT_EQ] = ACTIONS(4405),
    [anon_sym_DOT] = ACTIONS(4407),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4407),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4359),
    [anon_sym_DOT_DOT] = ACTIONS(4405),
    [anon_sym_and] = ACTIONS(4407),
    [anon_sym_or] = ACTIONS(4407),
    [anon_sym_AMP_AMP] = ACTIONS(4405),
    [anon_sym_PIPE_PIPE] = ACTIONS(4405),
    [anon_sym_QMARK_QMARK] = ACTIONS(4405),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4339),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4407),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4407),
    [anon_sym_is] = ACTIONS(4407),
    [anon_sym_DASH_GT] = ACTIONS(4405),
    [anon_sym_with] = ACTIONS(4407),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3375] = {
    [sym__variable_designation] = STATE(4207),
    [sym_parenthesized_variable_designation] = STATE(4153),
    [sym_identifier] = STATE(4156),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3375),
    [sym_preproc_endregion] = STATE(3375),
    [sym_preproc_line] = STATE(3375),
    [sym_preproc_pragma] = STATE(3375),
    [sym_preproc_nullable] = STATE(3375),
    [sym_preproc_error] = STATE(3375),
    [sym_preproc_warning] = STATE(3375),
    [sym_preproc_define] = STATE(3375),
    [sym_preproc_undef] = STATE(3375),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4437),
    [anon_sym_LPAREN] = ACTIONS(4437),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4439),
    [anon_sym_GT] = ACTIONS(4439),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4439),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4439),
    [anon_sym_PLUS_PLUS] = ACTIONS(4437),
    [anon_sym_DASH_DASH] = ACTIONS(4437),
    [anon_sym_PLUS] = ACTIONS(4439),
    [anon_sym_DASH] = ACTIONS(4439),
    [anon_sym_STAR] = ACTIONS(4437),
    [anon_sym_SLASH] = ACTIONS(4439),
    [anon_sym_PERCENT] = ACTIONS(4437),
    [anon_sym_CARET] = ACTIONS(4437),
    [anon_sym_PIPE] = ACTIONS(4439),
    [anon_sym_AMP] = ACTIONS(4439),
    [anon_sym_LT_LT] = ACTIONS(4437),
    [anon_sym_GT_GT] = ACTIONS(4439),
    [anon_sym_GT_GT_GT] = ACTIONS(4437),
    [anon_sym_EQ_EQ] = ACTIONS(4437),
    [anon_sym_BANG_EQ] = ACTIONS(4437),
    [anon_sym_GT_EQ] = ACTIONS(4437),
    [anon_sym_LT_EQ] = ACTIONS(4437),
    [anon_sym_DOT] = ACTIONS(4439),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4439),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4359),
    [anon_sym_DOT_DOT] = ACTIONS(4437),
    [anon_sym_and] = ACTIONS(4439),
    [anon_sym_or] = ACTIONS(4439),
    [anon_sym_AMP_AMP] = ACTIONS(4437),
    [anon_sym_PIPE_PIPE] = ACTIONS(4437),
    [anon_sym_QMARK_QMARK] = ACTIONS(4437),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4339),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4439),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4439),
    [anon_sym_is] = ACTIONS(4439),
    [anon_sym_DASH_GT] = ACTIONS(4437),
    [anon_sym_with] = ACTIONS(4439),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3376] = {
    [sym__variable_designation] = STATE(4190),
    [sym_parenthesized_variable_designation] = STATE(4153),
    [sym_identifier] = STATE(4156),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3376),
    [sym_preproc_endregion] = STATE(3376),
    [sym_preproc_line] = STATE(3376),
    [sym_preproc_pragma] = STATE(3376),
    [sym_preproc_nullable] = STATE(3376),
    [sym_preproc_error] = STATE(3376),
    [sym_preproc_warning] = STATE(3376),
    [sym_preproc_define] = STATE(3376),
    [sym_preproc_undef] = STATE(3376),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4441),
    [anon_sym_LPAREN] = ACTIONS(4441),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4443),
    [anon_sym_GT] = ACTIONS(4443),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4443),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4443),
    [anon_sym_PLUS_PLUS] = ACTIONS(4441),
    [anon_sym_DASH_DASH] = ACTIONS(4441),
    [anon_sym_PLUS] = ACTIONS(4443),
    [anon_sym_DASH] = ACTIONS(4443),
    [anon_sym_STAR] = ACTIONS(4441),
    [anon_sym_SLASH] = ACTIONS(4443),
    [anon_sym_PERCENT] = ACTIONS(4441),
    [anon_sym_CARET] = ACTIONS(4441),
    [anon_sym_PIPE] = ACTIONS(4443),
    [anon_sym_AMP] = ACTIONS(4443),
    [anon_sym_LT_LT] = ACTIONS(4441),
    [anon_sym_GT_GT] = ACTIONS(4443),
    [anon_sym_GT_GT_GT] = ACTIONS(4441),
    [anon_sym_EQ_EQ] = ACTIONS(4441),
    [anon_sym_BANG_EQ] = ACTIONS(4441),
    [anon_sym_GT_EQ] = ACTIONS(4441),
    [anon_sym_LT_EQ] = ACTIONS(4441),
    [anon_sym_DOT] = ACTIONS(4443),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4443),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4359),
    [anon_sym_DOT_DOT] = ACTIONS(4441),
    [anon_sym_and] = ACTIONS(4443),
    [anon_sym_or] = ACTIONS(4443),
    [anon_sym_AMP_AMP] = ACTIONS(4441),
    [anon_sym_PIPE_PIPE] = ACTIONS(4441),
    [anon_sym_QMARK_QMARK] = ACTIONS(4441),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4339),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4443),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4443),
    [anon_sym_is] = ACTIONS(4443),
    [anon_sym_DASH_GT] = ACTIONS(4441),
    [anon_sym_with] = ACTIONS(4443),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3377] = {
    [sym_preproc_region] = STATE(3377),
    [sym_preproc_endregion] = STATE(3377),
    [sym_preproc_line] = STATE(3377),
    [sym_preproc_pragma] = STATE(3377),
    [sym_preproc_nullable] = STATE(3377),
    [sym_preproc_error] = STATE(3377),
    [sym_preproc_warning] = STATE(3377),
    [sym_preproc_define] = STATE(3377),
    [sym_preproc_undef] = STATE(3377),
    [sym__identifier_token] = ACTIONS(4486),
    [anon_sym_alias] = ACTIONS(4486),
    [anon_sym_global] = ACTIONS(4486),
    [anon_sym_LBRACK] = ACTIONS(4488),
    [anon_sym_COLON] = ACTIONS(4488),
    [anon_sym_COMMA] = ACTIONS(4488),
    [anon_sym_LPAREN] = ACTIONS(4488),
    [anon_sym_LBRACE] = ACTIONS(4488),
    [anon_sym_file] = ACTIONS(4486),
    [anon_sym_LT] = ACTIONS(4486),
    [anon_sym_GT] = ACTIONS(4486),
    [anon_sym_where] = ACTIONS(4486),
    [anon_sym_QMARK] = ACTIONS(4486),
    [anon_sym_notnull] = ACTIONS(4486),
    [anon_sym_unmanaged] = ACTIONS(4486),
    [anon_sym_BANG] = ACTIONS(4486),
    [anon_sym_PLUS_PLUS] = ACTIONS(4488),
    [anon_sym_DASH_DASH] = ACTIONS(4488),
    [anon_sym_PLUS] = ACTIONS(4486),
    [anon_sym_DASH] = ACTIONS(4486),
    [anon_sym_STAR] = ACTIONS(4488),
    [anon_sym_SLASH] = ACTIONS(4486),
    [anon_sym_PERCENT] = ACTIONS(4488),
    [anon_sym_CARET] = ACTIONS(4488),
    [anon_sym_PIPE] = ACTIONS(4486),
    [anon_sym_AMP] = ACTIONS(4486),
    [anon_sym_LT_LT] = ACTIONS(4488),
    [anon_sym_GT_GT] = ACTIONS(4486),
    [anon_sym_GT_GT_GT] = ACTIONS(4488),
    [anon_sym_EQ_EQ] = ACTIONS(4488),
    [anon_sym_BANG_EQ] = ACTIONS(4488),
    [anon_sym_GT_EQ] = ACTIONS(4488),
    [anon_sym_LT_EQ] = ACTIONS(4488),
    [anon_sym_DOT] = ACTIONS(4486),
    [anon_sym_scoped] = ACTIONS(4486),
    [anon_sym_var] = ACTIONS(4486),
    [anon_sym_yield] = ACTIONS(4486),
    [anon_sym_switch] = ACTIONS(4486),
    [anon_sym_when] = ACTIONS(4486),
    [sym_discard] = ACTIONS(4486),
    [anon_sym_DOT_DOT] = ACTIONS(4488),
    [anon_sym_and] = ACTIONS(4486),
    [anon_sym_or] = ACTIONS(4486),
    [anon_sym_AMP_AMP] = ACTIONS(4488),
    [anon_sym_PIPE_PIPE] = ACTIONS(4488),
    [anon_sym_QMARK_QMARK] = ACTIONS(4488),
    [anon_sym_from] = ACTIONS(4486),
    [anon_sym_into] = ACTIONS(4486),
    [anon_sym_join] = ACTIONS(4486),
    [anon_sym_on] = ACTIONS(4486),
    [anon_sym_equals] = ACTIONS(4486),
    [anon_sym_let] = ACTIONS(4486),
    [anon_sym_orderby] = ACTIONS(4486),
    [anon_sym_ascending] = ACTIONS(4486),
    [anon_sym_descending] = ACTIONS(4486),
    [anon_sym_group] = ACTIONS(4486),
    [anon_sym_by] = ACTIONS(4486),
    [anon_sym_select] = ACTIONS(4486),
    [anon_sym_as] = ACTIONS(4486),
    [anon_sym_is] = ACTIONS(4486),
    [anon_sym_DASH_GT] = ACTIONS(4488),
    [anon_sym_with] = ACTIONS(4486),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4488),
  },
  [3378] = {
    [sym_preproc_region] = STATE(3378),
    [sym_preproc_endregion] = STATE(3378),
    [sym_preproc_line] = STATE(3378),
    [sym_preproc_pragma] = STATE(3378),
    [sym_preproc_nullable] = STATE(3378),
    [sym_preproc_error] = STATE(3378),
    [sym_preproc_warning] = STATE(3378),
    [sym_preproc_define] = STATE(3378),
    [sym_preproc_undef] = STATE(3378),
    [sym__identifier_token] = ACTIONS(3609),
    [anon_sym_extern] = ACTIONS(3609),
    [anon_sym_alias] = ACTIONS(3609),
    [anon_sym_global] = ACTIONS(3609),
    [anon_sym_using] = ACTIONS(3609),
    [anon_sym_unsafe] = ACTIONS(3609),
    [anon_sym_static] = ACTIONS(3609),
    [anon_sym_LBRACK] = ACTIONS(3611),
    [anon_sym_LPAREN] = ACTIONS(3611),
    [anon_sym_event] = ACTIONS(3609),
    [anon_sym_namespace] = ACTIONS(3609),
    [anon_sym_class] = ACTIONS(3609),
    [anon_sym_ref] = ACTIONS(3609),
    [anon_sym_struct] = ACTIONS(3609),
    [anon_sym_enum] = ACTIONS(3609),
    [anon_sym_RBRACE] = ACTIONS(3611),
    [anon_sym_interface] = ACTIONS(3609),
    [anon_sym_delegate] = ACTIONS(3609),
    [anon_sym_record] = ACTIONS(3609),
    [anon_sym_abstract] = ACTIONS(3609),
    [anon_sym_async] = ACTIONS(3609),
    [anon_sym_const] = ACTIONS(3609),
    [anon_sym_file] = ACTIONS(3609),
    [anon_sym_fixed] = ACTIONS(3609),
    [anon_sym_internal] = ACTIONS(3609),
    [anon_sym_new] = ACTIONS(3609),
    [anon_sym_override] = ACTIONS(3609),
    [anon_sym_partial] = ACTIONS(3609),
    [anon_sym_private] = ACTIONS(3609),
    [anon_sym_protected] = ACTIONS(3609),
    [anon_sym_public] = ACTIONS(3609),
    [anon_sym_readonly] = ACTIONS(3609),
    [anon_sym_required] = ACTIONS(3609),
    [anon_sym_sealed] = ACTIONS(3609),
    [anon_sym_virtual] = ACTIONS(3609),
    [anon_sym_volatile] = ACTIONS(3609),
    [anon_sym_where] = ACTIONS(3609),
    [anon_sym_notnull] = ACTIONS(3609),
    [anon_sym_unmanaged] = ACTIONS(3609),
    [anon_sym_TILDE] = ACTIONS(3611),
    [anon_sym_implicit] = ACTIONS(3609),
    [anon_sym_explicit] = ACTIONS(3609),
    [anon_sym_scoped] = ACTIONS(3609),
    [anon_sym_var] = ACTIONS(3609),
    [sym_predefined_type] = ACTIONS(3609),
    [anon_sym_yield] = ACTIONS(3609),
    [anon_sym_when] = ACTIONS(3609),
    [anon_sym_from] = ACTIONS(3609),
    [anon_sym_into] = ACTIONS(3609),
    [anon_sym_join] = ACTIONS(3609),
    [anon_sym_on] = ACTIONS(3609),
    [anon_sym_equals] = ACTIONS(3609),
    [anon_sym_let] = ACTIONS(3609),
    [anon_sym_orderby] = ACTIONS(3609),
    [anon_sym_ascending] = ACTIONS(3609),
    [anon_sym_descending] = ACTIONS(3609),
    [anon_sym_group] = ACTIONS(3609),
    [anon_sym_by] = ACTIONS(3609),
    [anon_sym_select] = ACTIONS(3609),
    [aux_sym_preproc_if_token1] = ACTIONS(3611),
    [aux_sym_preproc_if_token3] = ACTIONS(3611),
    [aux_sym_preproc_else_token1] = ACTIONS(3611),
    [aux_sym_preproc_elif_token1] = ACTIONS(3611),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3379] = {
    [sym_preproc_region] = STATE(3379),
    [sym_preproc_endregion] = STATE(3379),
    [sym_preproc_line] = STATE(3379),
    [sym_preproc_pragma] = STATE(3379),
    [sym_preproc_nullable] = STATE(3379),
    [sym_preproc_error] = STATE(3379),
    [sym_preproc_warning] = STATE(3379),
    [sym_preproc_define] = STATE(3379),
    [sym_preproc_undef] = STATE(3379),
    [sym__identifier_token] = ACTIONS(3613),
    [anon_sym_extern] = ACTIONS(3613),
    [anon_sym_alias] = ACTIONS(3613),
    [anon_sym_global] = ACTIONS(3613),
    [anon_sym_using] = ACTIONS(3613),
    [anon_sym_unsafe] = ACTIONS(3613),
    [anon_sym_static] = ACTIONS(3613),
    [anon_sym_LBRACK] = ACTIONS(3615),
    [anon_sym_LPAREN] = ACTIONS(3615),
    [anon_sym_event] = ACTIONS(3613),
    [anon_sym_namespace] = ACTIONS(3613),
    [anon_sym_class] = ACTIONS(3613),
    [anon_sym_ref] = ACTIONS(3613),
    [anon_sym_struct] = ACTIONS(3613),
    [anon_sym_enum] = ACTIONS(3613),
    [anon_sym_RBRACE] = ACTIONS(3615),
    [anon_sym_interface] = ACTIONS(3613),
    [anon_sym_delegate] = ACTIONS(3613),
    [anon_sym_record] = ACTIONS(3613),
    [anon_sym_abstract] = ACTIONS(3613),
    [anon_sym_async] = ACTIONS(3613),
    [anon_sym_const] = ACTIONS(3613),
    [anon_sym_file] = ACTIONS(3613),
    [anon_sym_fixed] = ACTIONS(3613),
    [anon_sym_internal] = ACTIONS(3613),
    [anon_sym_new] = ACTIONS(3613),
    [anon_sym_override] = ACTIONS(3613),
    [anon_sym_partial] = ACTIONS(3613),
    [anon_sym_private] = ACTIONS(3613),
    [anon_sym_protected] = ACTIONS(3613),
    [anon_sym_public] = ACTIONS(3613),
    [anon_sym_readonly] = ACTIONS(3613),
    [anon_sym_required] = ACTIONS(3613),
    [anon_sym_sealed] = ACTIONS(3613),
    [anon_sym_virtual] = ACTIONS(3613),
    [anon_sym_volatile] = ACTIONS(3613),
    [anon_sym_where] = ACTIONS(3613),
    [anon_sym_notnull] = ACTIONS(3613),
    [anon_sym_unmanaged] = ACTIONS(3613),
    [anon_sym_TILDE] = ACTIONS(3615),
    [anon_sym_implicit] = ACTIONS(3613),
    [anon_sym_explicit] = ACTIONS(3613),
    [anon_sym_scoped] = ACTIONS(3613),
    [anon_sym_var] = ACTIONS(3613),
    [sym_predefined_type] = ACTIONS(3613),
    [anon_sym_yield] = ACTIONS(3613),
    [anon_sym_when] = ACTIONS(3613),
    [anon_sym_from] = ACTIONS(3613),
    [anon_sym_into] = ACTIONS(3613),
    [anon_sym_join] = ACTIONS(3613),
    [anon_sym_on] = ACTIONS(3613),
    [anon_sym_equals] = ACTIONS(3613),
    [anon_sym_let] = ACTIONS(3613),
    [anon_sym_orderby] = ACTIONS(3613),
    [anon_sym_ascending] = ACTIONS(3613),
    [anon_sym_descending] = ACTIONS(3613),
    [anon_sym_group] = ACTIONS(3613),
    [anon_sym_by] = ACTIONS(3613),
    [anon_sym_select] = ACTIONS(3613),
    [aux_sym_preproc_if_token1] = ACTIONS(3615),
    [aux_sym_preproc_if_token3] = ACTIONS(3615),
    [aux_sym_preproc_else_token1] = ACTIONS(3615),
    [aux_sym_preproc_elif_token1] = ACTIONS(3615),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3380] = {
    [sym__variable_designation] = STATE(4167),
    [sym_parenthesized_variable_designation] = STATE(4153),
    [sym_identifier] = STATE(4156),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3380),
    [sym_preproc_endregion] = STATE(3380),
    [sym_preproc_line] = STATE(3380),
    [sym_preproc_pragma] = STATE(3380),
    [sym_preproc_nullable] = STATE(3380),
    [sym_preproc_error] = STATE(3380),
    [sym_preproc_warning] = STATE(3380),
    [sym_preproc_define] = STATE(3380),
    [sym_preproc_undef] = STATE(3380),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4399),
    [anon_sym_LPAREN] = ACTIONS(4399),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4401),
    [anon_sym_GT] = ACTIONS(4401),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4401),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4401),
    [anon_sym_PLUS_PLUS] = ACTIONS(4399),
    [anon_sym_DASH_DASH] = ACTIONS(4399),
    [anon_sym_PLUS] = ACTIONS(4401),
    [anon_sym_DASH] = ACTIONS(4401),
    [anon_sym_STAR] = ACTIONS(4399),
    [anon_sym_SLASH] = ACTIONS(4401),
    [anon_sym_PERCENT] = ACTIONS(4399),
    [anon_sym_CARET] = ACTIONS(4399),
    [anon_sym_PIPE] = ACTIONS(4401),
    [anon_sym_AMP] = ACTIONS(4401),
    [anon_sym_LT_LT] = ACTIONS(4399),
    [anon_sym_GT_GT] = ACTIONS(4401),
    [anon_sym_GT_GT_GT] = ACTIONS(4399),
    [anon_sym_EQ_EQ] = ACTIONS(4399),
    [anon_sym_BANG_EQ] = ACTIONS(4399),
    [anon_sym_GT_EQ] = ACTIONS(4399),
    [anon_sym_LT_EQ] = ACTIONS(4399),
    [anon_sym_DOT] = ACTIONS(4401),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4401),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4359),
    [anon_sym_DOT_DOT] = ACTIONS(4399),
    [anon_sym_and] = ACTIONS(4401),
    [anon_sym_or] = ACTIONS(4401),
    [anon_sym_AMP_AMP] = ACTIONS(4399),
    [anon_sym_PIPE_PIPE] = ACTIONS(4399),
    [anon_sym_QMARK_QMARK] = ACTIONS(4399),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4339),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4401),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4401),
    [anon_sym_is] = ACTIONS(4401),
    [anon_sym_DASH_GT] = ACTIONS(4399),
    [anon_sym_with] = ACTIONS(4401),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3381] = {
    [sym__variable_designation] = STATE(4182),
    [sym_parenthesized_variable_designation] = STATE(4153),
    [sym_identifier] = STATE(4156),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3381),
    [sym_preproc_endregion] = STATE(3381),
    [sym_preproc_line] = STATE(3381),
    [sym_preproc_pragma] = STATE(3381),
    [sym_preproc_nullable] = STATE(3381),
    [sym_preproc_error] = STATE(3381),
    [sym_preproc_warning] = STATE(3381),
    [sym_preproc_define] = STATE(3381),
    [sym_preproc_undef] = STATE(3381),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4405),
    [anon_sym_LPAREN] = ACTIONS(4405),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4407),
    [anon_sym_GT] = ACTIONS(4407),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4407),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4407),
    [anon_sym_PLUS_PLUS] = ACTIONS(4405),
    [anon_sym_DASH_DASH] = ACTIONS(4405),
    [anon_sym_PLUS] = ACTIONS(4407),
    [anon_sym_DASH] = ACTIONS(4407),
    [anon_sym_STAR] = ACTIONS(4405),
    [anon_sym_SLASH] = ACTIONS(4407),
    [anon_sym_PERCENT] = ACTIONS(4405),
    [anon_sym_CARET] = ACTIONS(4405),
    [anon_sym_PIPE] = ACTIONS(4407),
    [anon_sym_AMP] = ACTIONS(4407),
    [anon_sym_LT_LT] = ACTIONS(4405),
    [anon_sym_GT_GT] = ACTIONS(4407),
    [anon_sym_GT_GT_GT] = ACTIONS(4405),
    [anon_sym_EQ_EQ] = ACTIONS(4405),
    [anon_sym_BANG_EQ] = ACTIONS(4405),
    [anon_sym_GT_EQ] = ACTIONS(4405),
    [anon_sym_LT_EQ] = ACTIONS(4405),
    [anon_sym_DOT] = ACTIONS(4407),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4407),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4359),
    [anon_sym_DOT_DOT] = ACTIONS(4405),
    [anon_sym_and] = ACTIONS(4407),
    [anon_sym_or] = ACTIONS(4407),
    [anon_sym_AMP_AMP] = ACTIONS(4405),
    [anon_sym_PIPE_PIPE] = ACTIONS(4405),
    [anon_sym_QMARK_QMARK] = ACTIONS(4405),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4339),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4407),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4407),
    [anon_sym_is] = ACTIONS(4407),
    [anon_sym_DASH_GT] = ACTIONS(4405),
    [anon_sym_with] = ACTIONS(4407),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3382] = {
    [sym__variable_designation] = STATE(4207),
    [sym_parenthesized_variable_designation] = STATE(4153),
    [sym_identifier] = STATE(4156),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3382),
    [sym_preproc_endregion] = STATE(3382),
    [sym_preproc_line] = STATE(3382),
    [sym_preproc_pragma] = STATE(3382),
    [sym_preproc_nullable] = STATE(3382),
    [sym_preproc_error] = STATE(3382),
    [sym_preproc_warning] = STATE(3382),
    [sym_preproc_define] = STATE(3382),
    [sym_preproc_undef] = STATE(3382),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4437),
    [anon_sym_LPAREN] = ACTIONS(4437),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4439),
    [anon_sym_GT] = ACTIONS(4439),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4439),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4439),
    [anon_sym_PLUS_PLUS] = ACTIONS(4437),
    [anon_sym_DASH_DASH] = ACTIONS(4437),
    [anon_sym_PLUS] = ACTIONS(4439),
    [anon_sym_DASH] = ACTIONS(4439),
    [anon_sym_STAR] = ACTIONS(4437),
    [anon_sym_SLASH] = ACTIONS(4439),
    [anon_sym_PERCENT] = ACTIONS(4437),
    [anon_sym_CARET] = ACTIONS(4437),
    [anon_sym_PIPE] = ACTIONS(4439),
    [anon_sym_AMP] = ACTIONS(4439),
    [anon_sym_LT_LT] = ACTIONS(4437),
    [anon_sym_GT_GT] = ACTIONS(4439),
    [anon_sym_GT_GT_GT] = ACTIONS(4437),
    [anon_sym_EQ_EQ] = ACTIONS(4437),
    [anon_sym_BANG_EQ] = ACTIONS(4437),
    [anon_sym_GT_EQ] = ACTIONS(4437),
    [anon_sym_LT_EQ] = ACTIONS(4437),
    [anon_sym_DOT] = ACTIONS(4439),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4439),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4359),
    [anon_sym_DOT_DOT] = ACTIONS(4437),
    [anon_sym_and] = ACTIONS(4439),
    [anon_sym_or] = ACTIONS(4439),
    [anon_sym_AMP_AMP] = ACTIONS(4437),
    [anon_sym_PIPE_PIPE] = ACTIONS(4437),
    [anon_sym_QMARK_QMARK] = ACTIONS(4437),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4339),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4439),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4439),
    [anon_sym_is] = ACTIONS(4439),
    [anon_sym_DASH_GT] = ACTIONS(4437),
    [anon_sym_with] = ACTIONS(4439),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3383] = {
    [sym_preproc_region] = STATE(3383),
    [sym_preproc_endregion] = STATE(3383),
    [sym_preproc_line] = STATE(3383),
    [sym_preproc_pragma] = STATE(3383),
    [sym_preproc_nullable] = STATE(3383),
    [sym_preproc_error] = STATE(3383),
    [sym_preproc_warning] = STATE(3383),
    [sym_preproc_define] = STATE(3383),
    [sym_preproc_undef] = STATE(3383),
    [sym__identifier_token] = ACTIONS(3617),
    [anon_sym_extern] = ACTIONS(3617),
    [anon_sym_alias] = ACTIONS(3617),
    [anon_sym_global] = ACTIONS(3617),
    [anon_sym_using] = ACTIONS(3617),
    [anon_sym_unsafe] = ACTIONS(3617),
    [anon_sym_static] = ACTIONS(3617),
    [anon_sym_LBRACK] = ACTIONS(3619),
    [anon_sym_LPAREN] = ACTIONS(3619),
    [anon_sym_event] = ACTIONS(3617),
    [anon_sym_namespace] = ACTIONS(3617),
    [anon_sym_class] = ACTIONS(3617),
    [anon_sym_ref] = ACTIONS(3617),
    [anon_sym_struct] = ACTIONS(3617),
    [anon_sym_enum] = ACTIONS(3617),
    [anon_sym_RBRACE] = ACTIONS(3619),
    [anon_sym_interface] = ACTIONS(3617),
    [anon_sym_delegate] = ACTIONS(3617),
    [anon_sym_record] = ACTIONS(3617),
    [anon_sym_abstract] = ACTIONS(3617),
    [anon_sym_async] = ACTIONS(3617),
    [anon_sym_const] = ACTIONS(3617),
    [anon_sym_file] = ACTIONS(3617),
    [anon_sym_fixed] = ACTIONS(3617),
    [anon_sym_internal] = ACTIONS(3617),
    [anon_sym_new] = ACTIONS(3617),
    [anon_sym_override] = ACTIONS(3617),
    [anon_sym_partial] = ACTIONS(3617),
    [anon_sym_private] = ACTIONS(3617),
    [anon_sym_protected] = ACTIONS(3617),
    [anon_sym_public] = ACTIONS(3617),
    [anon_sym_readonly] = ACTIONS(3617),
    [anon_sym_required] = ACTIONS(3617),
    [anon_sym_sealed] = ACTIONS(3617),
    [anon_sym_virtual] = ACTIONS(3617),
    [anon_sym_volatile] = ACTIONS(3617),
    [anon_sym_where] = ACTIONS(3617),
    [anon_sym_notnull] = ACTIONS(3617),
    [anon_sym_unmanaged] = ACTIONS(3617),
    [anon_sym_TILDE] = ACTIONS(3619),
    [anon_sym_implicit] = ACTIONS(3617),
    [anon_sym_explicit] = ACTIONS(3617),
    [anon_sym_scoped] = ACTIONS(3617),
    [anon_sym_var] = ACTIONS(3617),
    [sym_predefined_type] = ACTIONS(3617),
    [anon_sym_yield] = ACTIONS(3617),
    [anon_sym_when] = ACTIONS(3617),
    [anon_sym_from] = ACTIONS(3617),
    [anon_sym_into] = ACTIONS(3617),
    [anon_sym_join] = ACTIONS(3617),
    [anon_sym_on] = ACTIONS(3617),
    [anon_sym_equals] = ACTIONS(3617),
    [anon_sym_let] = ACTIONS(3617),
    [anon_sym_orderby] = ACTIONS(3617),
    [anon_sym_ascending] = ACTIONS(3617),
    [anon_sym_descending] = ACTIONS(3617),
    [anon_sym_group] = ACTIONS(3617),
    [anon_sym_by] = ACTIONS(3617),
    [anon_sym_select] = ACTIONS(3617),
    [aux_sym_preproc_if_token1] = ACTIONS(3619),
    [aux_sym_preproc_if_token3] = ACTIONS(3619),
    [aux_sym_preproc_else_token1] = ACTIONS(3619),
    [aux_sym_preproc_elif_token1] = ACTIONS(3619),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3384] = {
    [sym__variable_designation] = STATE(4190),
    [sym_parenthesized_variable_designation] = STATE(4153),
    [sym_identifier] = STATE(4156),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3384),
    [sym_preproc_endregion] = STATE(3384),
    [sym_preproc_line] = STATE(3384),
    [sym_preproc_pragma] = STATE(3384),
    [sym_preproc_nullable] = STATE(3384),
    [sym_preproc_error] = STATE(3384),
    [sym_preproc_warning] = STATE(3384),
    [sym_preproc_define] = STATE(3384),
    [sym_preproc_undef] = STATE(3384),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4441),
    [anon_sym_LPAREN] = ACTIONS(4441),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4443),
    [anon_sym_GT] = ACTIONS(4443),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4443),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4443),
    [anon_sym_PLUS_PLUS] = ACTIONS(4441),
    [anon_sym_DASH_DASH] = ACTIONS(4441),
    [anon_sym_PLUS] = ACTIONS(4443),
    [anon_sym_DASH] = ACTIONS(4443),
    [anon_sym_STAR] = ACTIONS(4441),
    [anon_sym_SLASH] = ACTIONS(4443),
    [anon_sym_PERCENT] = ACTIONS(4441),
    [anon_sym_CARET] = ACTIONS(4441),
    [anon_sym_PIPE] = ACTIONS(4443),
    [anon_sym_AMP] = ACTIONS(4443),
    [anon_sym_LT_LT] = ACTIONS(4441),
    [anon_sym_GT_GT] = ACTIONS(4443),
    [anon_sym_GT_GT_GT] = ACTIONS(4441),
    [anon_sym_EQ_EQ] = ACTIONS(4441),
    [anon_sym_BANG_EQ] = ACTIONS(4441),
    [anon_sym_GT_EQ] = ACTIONS(4441),
    [anon_sym_LT_EQ] = ACTIONS(4441),
    [anon_sym_DOT] = ACTIONS(4443),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4443),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4359),
    [anon_sym_DOT_DOT] = ACTIONS(4441),
    [anon_sym_and] = ACTIONS(4443),
    [anon_sym_or] = ACTIONS(4443),
    [anon_sym_AMP_AMP] = ACTIONS(4441),
    [anon_sym_PIPE_PIPE] = ACTIONS(4441),
    [anon_sym_QMARK_QMARK] = ACTIONS(4441),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4339),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4443),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4443),
    [anon_sym_is] = ACTIONS(4443),
    [anon_sym_DASH_GT] = ACTIONS(4441),
    [anon_sym_with] = ACTIONS(4443),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3385] = {
    [sym_preproc_region] = STATE(3385),
    [sym_preproc_endregion] = STATE(3385),
    [sym_preproc_line] = STATE(3385),
    [sym_preproc_pragma] = STATE(3385),
    [sym_preproc_nullable] = STATE(3385),
    [sym_preproc_error] = STATE(3385),
    [sym_preproc_warning] = STATE(3385),
    [sym_preproc_define] = STATE(3385),
    [sym_preproc_undef] = STATE(3385),
    [sym__identifier_token] = ACTIONS(3995),
    [anon_sym_alias] = ACTIONS(3995),
    [anon_sym_global] = ACTIONS(3995),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_COLON] = ACTIONS(3993),
    [anon_sym_COMMA] = ACTIONS(3993),
    [anon_sym_LPAREN] = ACTIONS(3993),
    [anon_sym_LBRACE] = ACTIONS(3993),
    [anon_sym_file] = ACTIONS(3995),
    [anon_sym_LT] = ACTIONS(3995),
    [anon_sym_GT] = ACTIONS(3995),
    [anon_sym_where] = ACTIONS(3995),
    [anon_sym_QMARK] = ACTIONS(3995),
    [anon_sym_notnull] = ACTIONS(3995),
    [anon_sym_unmanaged] = ACTIONS(3995),
    [anon_sym_BANG] = ACTIONS(3995),
    [anon_sym_PLUS_PLUS] = ACTIONS(3993),
    [anon_sym_DASH_DASH] = ACTIONS(3993),
    [anon_sym_PLUS] = ACTIONS(3995),
    [anon_sym_DASH] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3993),
    [anon_sym_SLASH] = ACTIONS(3995),
    [anon_sym_PERCENT] = ACTIONS(3993),
    [anon_sym_CARET] = ACTIONS(3993),
    [anon_sym_PIPE] = ACTIONS(3995),
    [anon_sym_AMP] = ACTIONS(3995),
    [anon_sym_LT_LT] = ACTIONS(3993),
    [anon_sym_GT_GT] = ACTIONS(3995),
    [anon_sym_GT_GT_GT] = ACTIONS(3993),
    [anon_sym_EQ_EQ] = ACTIONS(3993),
    [anon_sym_BANG_EQ] = ACTIONS(3993),
    [anon_sym_GT_EQ] = ACTIONS(3993),
    [anon_sym_LT_EQ] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3995),
    [anon_sym_scoped] = ACTIONS(3995),
    [anon_sym_var] = ACTIONS(3995),
    [anon_sym_yield] = ACTIONS(3995),
    [anon_sym_switch] = ACTIONS(3995),
    [anon_sym_when] = ACTIONS(3995),
    [sym_discard] = ACTIONS(3995),
    [anon_sym_DOT_DOT] = ACTIONS(3993),
    [anon_sym_and] = ACTIONS(3995),
    [anon_sym_or] = ACTIONS(3995),
    [anon_sym_AMP_AMP] = ACTIONS(3993),
    [anon_sym_PIPE_PIPE] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK] = ACTIONS(3993),
    [anon_sym_from] = ACTIONS(3995),
    [anon_sym_into] = ACTIONS(3995),
    [anon_sym_join] = ACTIONS(3995),
    [anon_sym_on] = ACTIONS(3995),
    [anon_sym_equals] = ACTIONS(3995),
    [anon_sym_let] = ACTIONS(3995),
    [anon_sym_orderby] = ACTIONS(3995),
    [anon_sym_ascending] = ACTIONS(3995),
    [anon_sym_descending] = ACTIONS(3995),
    [anon_sym_group] = ACTIONS(3995),
    [anon_sym_by] = ACTIONS(3995),
    [anon_sym_select] = ACTIONS(3995),
    [anon_sym_as] = ACTIONS(3995),
    [anon_sym_is] = ACTIONS(3995),
    [anon_sym_DASH_GT] = ACTIONS(3993),
    [anon_sym_with] = ACTIONS(3995),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(3993),
  },
  [3386] = {
    [sym_preproc_region] = STATE(3386),
    [sym_preproc_endregion] = STATE(3386),
    [sym_preproc_line] = STATE(3386),
    [sym_preproc_pragma] = STATE(3386),
    [sym_preproc_nullable] = STATE(3386),
    [sym_preproc_error] = STATE(3386),
    [sym_preproc_warning] = STATE(3386),
    [sym_preproc_define] = STATE(3386),
    [sym_preproc_undef] = STATE(3386),
    [sym__identifier_token] = ACTIONS(4122),
    [anon_sym_alias] = ACTIONS(4122),
    [anon_sym_global] = ACTIONS(4122),
    [anon_sym_LBRACK] = ACTIONS(4124),
    [anon_sym_COLON] = ACTIONS(4124),
    [anon_sym_COMMA] = ACTIONS(4124),
    [anon_sym_LPAREN] = ACTIONS(4124),
    [anon_sym_LBRACE] = ACTIONS(4124),
    [anon_sym_file] = ACTIONS(4122),
    [anon_sym_LT] = ACTIONS(4122),
    [anon_sym_GT] = ACTIONS(4122),
    [anon_sym_where] = ACTIONS(4122),
    [anon_sym_QMARK] = ACTIONS(4122),
    [anon_sym_notnull] = ACTIONS(4122),
    [anon_sym_unmanaged] = ACTIONS(4122),
    [anon_sym_BANG] = ACTIONS(4122),
    [anon_sym_PLUS_PLUS] = ACTIONS(4124),
    [anon_sym_DASH_DASH] = ACTIONS(4124),
    [anon_sym_PLUS] = ACTIONS(4122),
    [anon_sym_DASH] = ACTIONS(4122),
    [anon_sym_STAR] = ACTIONS(4124),
    [anon_sym_SLASH] = ACTIONS(4122),
    [anon_sym_PERCENT] = ACTIONS(4124),
    [anon_sym_CARET] = ACTIONS(4124),
    [anon_sym_PIPE] = ACTIONS(4122),
    [anon_sym_AMP] = ACTIONS(4122),
    [anon_sym_LT_LT] = ACTIONS(4124),
    [anon_sym_GT_GT] = ACTIONS(4122),
    [anon_sym_GT_GT_GT] = ACTIONS(4124),
    [anon_sym_EQ_EQ] = ACTIONS(4124),
    [anon_sym_BANG_EQ] = ACTIONS(4124),
    [anon_sym_GT_EQ] = ACTIONS(4124),
    [anon_sym_LT_EQ] = ACTIONS(4124),
    [anon_sym_DOT] = ACTIONS(4122),
    [anon_sym_scoped] = ACTIONS(4122),
    [anon_sym_var] = ACTIONS(4122),
    [anon_sym_yield] = ACTIONS(4122),
    [anon_sym_switch] = ACTIONS(4122),
    [anon_sym_when] = ACTIONS(4122),
    [sym_discard] = ACTIONS(4122),
    [anon_sym_DOT_DOT] = ACTIONS(4124),
    [anon_sym_and] = ACTIONS(4122),
    [anon_sym_or] = ACTIONS(4122),
    [anon_sym_AMP_AMP] = ACTIONS(4124),
    [anon_sym_PIPE_PIPE] = ACTIONS(4124),
    [anon_sym_QMARK_QMARK] = ACTIONS(4124),
    [anon_sym_from] = ACTIONS(4122),
    [anon_sym_into] = ACTIONS(4122),
    [anon_sym_join] = ACTIONS(4122),
    [anon_sym_on] = ACTIONS(4122),
    [anon_sym_equals] = ACTIONS(4122),
    [anon_sym_let] = ACTIONS(4122),
    [anon_sym_orderby] = ACTIONS(4122),
    [anon_sym_ascending] = ACTIONS(4122),
    [anon_sym_descending] = ACTIONS(4122),
    [anon_sym_group] = ACTIONS(4122),
    [anon_sym_by] = ACTIONS(4122),
    [anon_sym_select] = ACTIONS(4122),
    [anon_sym_as] = ACTIONS(4122),
    [anon_sym_is] = ACTIONS(4122),
    [anon_sym_DASH_GT] = ACTIONS(4124),
    [anon_sym_with] = ACTIONS(4122),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4124),
  },
  [3387] = {
    [sym_preproc_region] = STATE(3387),
    [sym_preproc_endregion] = STATE(3387),
    [sym_preproc_line] = STATE(3387),
    [sym_preproc_pragma] = STATE(3387),
    [sym_preproc_nullable] = STATE(3387),
    [sym_preproc_error] = STATE(3387),
    [sym_preproc_warning] = STATE(3387),
    [sym_preproc_define] = STATE(3387),
    [sym_preproc_undef] = STATE(3387),
    [sym__identifier_token] = ACTIONS(5083),
    [anon_sym_extern] = ACTIONS(5083),
    [anon_sym_alias] = ACTIONS(5083),
    [anon_sym_global] = ACTIONS(5083),
    [anon_sym_using] = ACTIONS(5083),
    [anon_sym_unsafe] = ACTIONS(5083),
    [anon_sym_static] = ACTIONS(5083),
    [anon_sym_LBRACK] = ACTIONS(5085),
    [anon_sym_LPAREN] = ACTIONS(5085),
    [anon_sym_event] = ACTIONS(5083),
    [anon_sym_namespace] = ACTIONS(5083),
    [anon_sym_class] = ACTIONS(5083),
    [anon_sym_ref] = ACTIONS(5083),
    [anon_sym_struct] = ACTIONS(5083),
    [anon_sym_enum] = ACTIONS(5083),
    [anon_sym_RBRACE] = ACTIONS(5085),
    [anon_sym_interface] = ACTIONS(5083),
    [anon_sym_delegate] = ACTIONS(5083),
    [anon_sym_record] = ACTIONS(5083),
    [anon_sym_abstract] = ACTIONS(5083),
    [anon_sym_async] = ACTIONS(5083),
    [anon_sym_const] = ACTIONS(5083),
    [anon_sym_file] = ACTIONS(5083),
    [anon_sym_fixed] = ACTIONS(5083),
    [anon_sym_internal] = ACTIONS(5083),
    [anon_sym_new] = ACTIONS(5083),
    [anon_sym_override] = ACTIONS(5083),
    [anon_sym_partial] = ACTIONS(5083),
    [anon_sym_private] = ACTIONS(5083),
    [anon_sym_protected] = ACTIONS(5083),
    [anon_sym_public] = ACTIONS(5083),
    [anon_sym_readonly] = ACTIONS(5083),
    [anon_sym_required] = ACTIONS(5083),
    [anon_sym_sealed] = ACTIONS(5083),
    [anon_sym_virtual] = ACTIONS(5083),
    [anon_sym_volatile] = ACTIONS(5083),
    [anon_sym_where] = ACTIONS(5083),
    [anon_sym_notnull] = ACTIONS(5083),
    [anon_sym_unmanaged] = ACTIONS(5083),
    [anon_sym_TILDE] = ACTIONS(5085),
    [anon_sym_implicit] = ACTIONS(5083),
    [anon_sym_explicit] = ACTIONS(5083),
    [anon_sym_scoped] = ACTIONS(5083),
    [anon_sym_var] = ACTIONS(5083),
    [sym_predefined_type] = ACTIONS(5083),
    [anon_sym_yield] = ACTIONS(5083),
    [anon_sym_when] = ACTIONS(5083),
    [anon_sym_from] = ACTIONS(5083),
    [anon_sym_into] = ACTIONS(5083),
    [anon_sym_join] = ACTIONS(5083),
    [anon_sym_on] = ACTIONS(5083),
    [anon_sym_equals] = ACTIONS(5083),
    [anon_sym_let] = ACTIONS(5083),
    [anon_sym_orderby] = ACTIONS(5083),
    [anon_sym_ascending] = ACTIONS(5083),
    [anon_sym_descending] = ACTIONS(5083),
    [anon_sym_group] = ACTIONS(5083),
    [anon_sym_by] = ACTIONS(5083),
    [anon_sym_select] = ACTIONS(5083),
    [aux_sym_preproc_if_token1] = ACTIONS(5085),
    [aux_sym_preproc_if_token3] = ACTIONS(5085),
    [aux_sym_preproc_else_token1] = ACTIONS(5085),
    [aux_sym_preproc_elif_token1] = ACTIONS(5085),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3388] = {
    [sym_preproc_region] = STATE(3388),
    [sym_preproc_endregion] = STATE(3388),
    [sym_preproc_line] = STATE(3388),
    [sym_preproc_pragma] = STATE(3388),
    [sym_preproc_nullable] = STATE(3388),
    [sym_preproc_error] = STATE(3388),
    [sym_preproc_warning] = STATE(3388),
    [sym_preproc_define] = STATE(3388),
    [sym_preproc_undef] = STATE(3388),
    [sym__identifier_token] = ACTIONS(5087),
    [anon_sym_extern] = ACTIONS(5087),
    [anon_sym_alias] = ACTIONS(5087),
    [anon_sym_global] = ACTIONS(5087),
    [anon_sym_using] = ACTIONS(5087),
    [anon_sym_unsafe] = ACTIONS(5087),
    [anon_sym_static] = ACTIONS(5087),
    [anon_sym_LBRACK] = ACTIONS(5089),
    [anon_sym_LPAREN] = ACTIONS(5089),
    [anon_sym_event] = ACTIONS(5087),
    [anon_sym_namespace] = ACTIONS(5087),
    [anon_sym_class] = ACTIONS(5087),
    [anon_sym_ref] = ACTIONS(5087),
    [anon_sym_struct] = ACTIONS(5087),
    [anon_sym_enum] = ACTIONS(5087),
    [anon_sym_RBRACE] = ACTIONS(5089),
    [anon_sym_interface] = ACTIONS(5087),
    [anon_sym_delegate] = ACTIONS(5087),
    [anon_sym_record] = ACTIONS(5087),
    [anon_sym_abstract] = ACTIONS(5087),
    [anon_sym_async] = ACTIONS(5087),
    [anon_sym_const] = ACTIONS(5087),
    [anon_sym_file] = ACTIONS(5087),
    [anon_sym_fixed] = ACTIONS(5087),
    [anon_sym_internal] = ACTIONS(5087),
    [anon_sym_new] = ACTIONS(5087),
    [anon_sym_override] = ACTIONS(5087),
    [anon_sym_partial] = ACTIONS(5087),
    [anon_sym_private] = ACTIONS(5087),
    [anon_sym_protected] = ACTIONS(5087),
    [anon_sym_public] = ACTIONS(5087),
    [anon_sym_readonly] = ACTIONS(5087),
    [anon_sym_required] = ACTIONS(5087),
    [anon_sym_sealed] = ACTIONS(5087),
    [anon_sym_virtual] = ACTIONS(5087),
    [anon_sym_volatile] = ACTIONS(5087),
    [anon_sym_where] = ACTIONS(5087),
    [anon_sym_notnull] = ACTIONS(5087),
    [anon_sym_unmanaged] = ACTIONS(5087),
    [anon_sym_TILDE] = ACTIONS(5089),
    [anon_sym_implicit] = ACTIONS(5087),
    [anon_sym_explicit] = ACTIONS(5087),
    [anon_sym_scoped] = ACTIONS(5087),
    [anon_sym_var] = ACTIONS(5087),
    [sym_predefined_type] = ACTIONS(5087),
    [anon_sym_yield] = ACTIONS(5087),
    [anon_sym_when] = ACTIONS(5087),
    [anon_sym_from] = ACTIONS(5087),
    [anon_sym_into] = ACTIONS(5087),
    [anon_sym_join] = ACTIONS(5087),
    [anon_sym_on] = ACTIONS(5087),
    [anon_sym_equals] = ACTIONS(5087),
    [anon_sym_let] = ACTIONS(5087),
    [anon_sym_orderby] = ACTIONS(5087),
    [anon_sym_ascending] = ACTIONS(5087),
    [anon_sym_descending] = ACTIONS(5087),
    [anon_sym_group] = ACTIONS(5087),
    [anon_sym_by] = ACTIONS(5087),
    [anon_sym_select] = ACTIONS(5087),
    [aux_sym_preproc_if_token1] = ACTIONS(5089),
    [aux_sym_preproc_if_token3] = ACTIONS(5089),
    [aux_sym_preproc_else_token1] = ACTIONS(5089),
    [aux_sym_preproc_elif_token1] = ACTIONS(5089),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3389] = {
    [sym_preproc_region] = STATE(3389),
    [sym_preproc_endregion] = STATE(3389),
    [sym_preproc_line] = STATE(3389),
    [sym_preproc_pragma] = STATE(3389),
    [sym_preproc_nullable] = STATE(3389),
    [sym_preproc_error] = STATE(3389),
    [sym_preproc_warning] = STATE(3389),
    [sym_preproc_define] = STATE(3389),
    [sym_preproc_undef] = STATE(3389),
    [sym__identifier_token] = ACTIONS(5091),
    [anon_sym_extern] = ACTIONS(5091),
    [anon_sym_alias] = ACTIONS(5091),
    [anon_sym_global] = ACTIONS(5091),
    [anon_sym_using] = ACTIONS(5091),
    [anon_sym_unsafe] = ACTIONS(5091),
    [anon_sym_static] = ACTIONS(5091),
    [anon_sym_LBRACK] = ACTIONS(5093),
    [anon_sym_LPAREN] = ACTIONS(5093),
    [anon_sym_event] = ACTIONS(5091),
    [anon_sym_namespace] = ACTIONS(5091),
    [anon_sym_class] = ACTIONS(5091),
    [anon_sym_ref] = ACTIONS(5091),
    [anon_sym_struct] = ACTIONS(5091),
    [anon_sym_enum] = ACTIONS(5091),
    [anon_sym_RBRACE] = ACTIONS(5093),
    [anon_sym_interface] = ACTIONS(5091),
    [anon_sym_delegate] = ACTIONS(5091),
    [anon_sym_record] = ACTIONS(5091),
    [anon_sym_abstract] = ACTIONS(5091),
    [anon_sym_async] = ACTIONS(5091),
    [anon_sym_const] = ACTIONS(5091),
    [anon_sym_file] = ACTIONS(5091),
    [anon_sym_fixed] = ACTIONS(5091),
    [anon_sym_internal] = ACTIONS(5091),
    [anon_sym_new] = ACTIONS(5091),
    [anon_sym_override] = ACTIONS(5091),
    [anon_sym_partial] = ACTIONS(5091),
    [anon_sym_private] = ACTIONS(5091),
    [anon_sym_protected] = ACTIONS(5091),
    [anon_sym_public] = ACTIONS(5091),
    [anon_sym_readonly] = ACTIONS(5091),
    [anon_sym_required] = ACTIONS(5091),
    [anon_sym_sealed] = ACTIONS(5091),
    [anon_sym_virtual] = ACTIONS(5091),
    [anon_sym_volatile] = ACTIONS(5091),
    [anon_sym_where] = ACTIONS(5091),
    [anon_sym_notnull] = ACTIONS(5091),
    [anon_sym_unmanaged] = ACTIONS(5091),
    [anon_sym_TILDE] = ACTIONS(5093),
    [anon_sym_implicit] = ACTIONS(5091),
    [anon_sym_explicit] = ACTIONS(5091),
    [anon_sym_scoped] = ACTIONS(5091),
    [anon_sym_var] = ACTIONS(5091),
    [sym_predefined_type] = ACTIONS(5091),
    [anon_sym_yield] = ACTIONS(5091),
    [anon_sym_when] = ACTIONS(5091),
    [anon_sym_from] = ACTIONS(5091),
    [anon_sym_into] = ACTIONS(5091),
    [anon_sym_join] = ACTIONS(5091),
    [anon_sym_on] = ACTIONS(5091),
    [anon_sym_equals] = ACTIONS(5091),
    [anon_sym_let] = ACTIONS(5091),
    [anon_sym_orderby] = ACTIONS(5091),
    [anon_sym_ascending] = ACTIONS(5091),
    [anon_sym_descending] = ACTIONS(5091),
    [anon_sym_group] = ACTIONS(5091),
    [anon_sym_by] = ACTIONS(5091),
    [anon_sym_select] = ACTIONS(5091),
    [aux_sym_preproc_if_token1] = ACTIONS(5093),
    [aux_sym_preproc_if_token3] = ACTIONS(5093),
    [aux_sym_preproc_else_token1] = ACTIONS(5093),
    [aux_sym_preproc_elif_token1] = ACTIONS(5093),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3390] = {
    [sym_preproc_region] = STATE(3390),
    [sym_preproc_endregion] = STATE(3390),
    [sym_preproc_line] = STATE(3390),
    [sym_preproc_pragma] = STATE(3390),
    [sym_preproc_nullable] = STATE(3390),
    [sym_preproc_error] = STATE(3390),
    [sym_preproc_warning] = STATE(3390),
    [sym_preproc_define] = STATE(3390),
    [sym_preproc_undef] = STATE(3390),
    [sym__identifier_token] = ACTIONS(5095),
    [anon_sym_extern] = ACTIONS(5095),
    [anon_sym_alias] = ACTIONS(5095),
    [anon_sym_global] = ACTIONS(5095),
    [anon_sym_using] = ACTIONS(5095),
    [anon_sym_unsafe] = ACTIONS(5095),
    [anon_sym_static] = ACTIONS(5095),
    [anon_sym_LBRACK] = ACTIONS(5097),
    [anon_sym_LPAREN] = ACTIONS(5097),
    [anon_sym_event] = ACTIONS(5095),
    [anon_sym_namespace] = ACTIONS(5095),
    [anon_sym_class] = ACTIONS(5095),
    [anon_sym_ref] = ACTIONS(5095),
    [anon_sym_struct] = ACTIONS(5095),
    [anon_sym_enum] = ACTIONS(5095),
    [anon_sym_RBRACE] = ACTIONS(5097),
    [anon_sym_interface] = ACTIONS(5095),
    [anon_sym_delegate] = ACTIONS(5095),
    [anon_sym_record] = ACTIONS(5095),
    [anon_sym_abstract] = ACTIONS(5095),
    [anon_sym_async] = ACTIONS(5095),
    [anon_sym_const] = ACTIONS(5095),
    [anon_sym_file] = ACTIONS(5095),
    [anon_sym_fixed] = ACTIONS(5095),
    [anon_sym_internal] = ACTIONS(5095),
    [anon_sym_new] = ACTIONS(5095),
    [anon_sym_override] = ACTIONS(5095),
    [anon_sym_partial] = ACTIONS(5095),
    [anon_sym_private] = ACTIONS(5095),
    [anon_sym_protected] = ACTIONS(5095),
    [anon_sym_public] = ACTIONS(5095),
    [anon_sym_readonly] = ACTIONS(5095),
    [anon_sym_required] = ACTIONS(5095),
    [anon_sym_sealed] = ACTIONS(5095),
    [anon_sym_virtual] = ACTIONS(5095),
    [anon_sym_volatile] = ACTIONS(5095),
    [anon_sym_where] = ACTIONS(5095),
    [anon_sym_notnull] = ACTIONS(5095),
    [anon_sym_unmanaged] = ACTIONS(5095),
    [anon_sym_TILDE] = ACTIONS(5097),
    [anon_sym_implicit] = ACTIONS(5095),
    [anon_sym_explicit] = ACTIONS(5095),
    [anon_sym_scoped] = ACTIONS(5095),
    [anon_sym_var] = ACTIONS(5095),
    [sym_predefined_type] = ACTIONS(5095),
    [anon_sym_yield] = ACTIONS(5095),
    [anon_sym_when] = ACTIONS(5095),
    [anon_sym_from] = ACTIONS(5095),
    [anon_sym_into] = ACTIONS(5095),
    [anon_sym_join] = ACTIONS(5095),
    [anon_sym_on] = ACTIONS(5095),
    [anon_sym_equals] = ACTIONS(5095),
    [anon_sym_let] = ACTIONS(5095),
    [anon_sym_orderby] = ACTIONS(5095),
    [anon_sym_ascending] = ACTIONS(5095),
    [anon_sym_descending] = ACTIONS(5095),
    [anon_sym_group] = ACTIONS(5095),
    [anon_sym_by] = ACTIONS(5095),
    [anon_sym_select] = ACTIONS(5095),
    [aux_sym_preproc_if_token1] = ACTIONS(5097),
    [aux_sym_preproc_if_token3] = ACTIONS(5097),
    [aux_sym_preproc_else_token1] = ACTIONS(5097),
    [aux_sym_preproc_elif_token1] = ACTIONS(5097),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3391] = {
    [sym_preproc_region] = STATE(3391),
    [sym_preproc_endregion] = STATE(3391),
    [sym_preproc_line] = STATE(3391),
    [sym_preproc_pragma] = STATE(3391),
    [sym_preproc_nullable] = STATE(3391),
    [sym_preproc_error] = STATE(3391),
    [sym_preproc_warning] = STATE(3391),
    [sym_preproc_define] = STATE(3391),
    [sym_preproc_undef] = STATE(3391),
    [sym__identifier_token] = ACTIONS(5099),
    [anon_sym_extern] = ACTIONS(5099),
    [anon_sym_alias] = ACTIONS(5099),
    [anon_sym_global] = ACTIONS(5099),
    [anon_sym_using] = ACTIONS(5099),
    [anon_sym_unsafe] = ACTIONS(5099),
    [anon_sym_static] = ACTIONS(5099),
    [anon_sym_LBRACK] = ACTIONS(5101),
    [anon_sym_LPAREN] = ACTIONS(5101),
    [anon_sym_event] = ACTIONS(5099),
    [anon_sym_namespace] = ACTIONS(5099),
    [anon_sym_class] = ACTIONS(5099),
    [anon_sym_ref] = ACTIONS(5099),
    [anon_sym_struct] = ACTIONS(5099),
    [anon_sym_enum] = ACTIONS(5099),
    [anon_sym_RBRACE] = ACTIONS(5101),
    [anon_sym_interface] = ACTIONS(5099),
    [anon_sym_delegate] = ACTIONS(5099),
    [anon_sym_record] = ACTIONS(5099),
    [anon_sym_abstract] = ACTIONS(5099),
    [anon_sym_async] = ACTIONS(5099),
    [anon_sym_const] = ACTIONS(5099),
    [anon_sym_file] = ACTIONS(5099),
    [anon_sym_fixed] = ACTIONS(5099),
    [anon_sym_internal] = ACTIONS(5099),
    [anon_sym_new] = ACTIONS(5099),
    [anon_sym_override] = ACTIONS(5099),
    [anon_sym_partial] = ACTIONS(5099),
    [anon_sym_private] = ACTIONS(5099),
    [anon_sym_protected] = ACTIONS(5099),
    [anon_sym_public] = ACTIONS(5099),
    [anon_sym_readonly] = ACTIONS(5099),
    [anon_sym_required] = ACTIONS(5099),
    [anon_sym_sealed] = ACTIONS(5099),
    [anon_sym_virtual] = ACTIONS(5099),
    [anon_sym_volatile] = ACTIONS(5099),
    [anon_sym_where] = ACTIONS(5099),
    [anon_sym_notnull] = ACTIONS(5099),
    [anon_sym_unmanaged] = ACTIONS(5099),
    [anon_sym_TILDE] = ACTIONS(5101),
    [anon_sym_implicit] = ACTIONS(5099),
    [anon_sym_explicit] = ACTIONS(5099),
    [anon_sym_scoped] = ACTIONS(5099),
    [anon_sym_var] = ACTIONS(5099),
    [sym_predefined_type] = ACTIONS(5099),
    [anon_sym_yield] = ACTIONS(5099),
    [anon_sym_when] = ACTIONS(5099),
    [anon_sym_from] = ACTIONS(5099),
    [anon_sym_into] = ACTIONS(5099),
    [anon_sym_join] = ACTIONS(5099),
    [anon_sym_on] = ACTIONS(5099),
    [anon_sym_equals] = ACTIONS(5099),
    [anon_sym_let] = ACTIONS(5099),
    [anon_sym_orderby] = ACTIONS(5099),
    [anon_sym_ascending] = ACTIONS(5099),
    [anon_sym_descending] = ACTIONS(5099),
    [anon_sym_group] = ACTIONS(5099),
    [anon_sym_by] = ACTIONS(5099),
    [anon_sym_select] = ACTIONS(5099),
    [aux_sym_preproc_if_token1] = ACTIONS(5101),
    [aux_sym_preproc_if_token3] = ACTIONS(5101),
    [aux_sym_preproc_else_token1] = ACTIONS(5101),
    [aux_sym_preproc_elif_token1] = ACTIONS(5101),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3392] = {
    [sym_preproc_region] = STATE(3392),
    [sym_preproc_endregion] = STATE(3392),
    [sym_preproc_line] = STATE(3392),
    [sym_preproc_pragma] = STATE(3392),
    [sym_preproc_nullable] = STATE(3392),
    [sym_preproc_error] = STATE(3392),
    [sym_preproc_warning] = STATE(3392),
    [sym_preproc_define] = STATE(3392),
    [sym_preproc_undef] = STATE(3392),
    [sym__identifier_token] = ACTIONS(5103),
    [anon_sym_extern] = ACTIONS(5103),
    [anon_sym_alias] = ACTIONS(5103),
    [anon_sym_global] = ACTIONS(5103),
    [anon_sym_using] = ACTIONS(5103),
    [anon_sym_unsafe] = ACTIONS(5103),
    [anon_sym_static] = ACTIONS(5103),
    [anon_sym_LBRACK] = ACTIONS(5105),
    [anon_sym_LPAREN] = ACTIONS(5105),
    [anon_sym_event] = ACTIONS(5103),
    [anon_sym_namespace] = ACTIONS(5103),
    [anon_sym_class] = ACTIONS(5103),
    [anon_sym_ref] = ACTIONS(5103),
    [anon_sym_struct] = ACTIONS(5103),
    [anon_sym_enum] = ACTIONS(5103),
    [anon_sym_RBRACE] = ACTIONS(5105),
    [anon_sym_interface] = ACTIONS(5103),
    [anon_sym_delegate] = ACTIONS(5103),
    [anon_sym_record] = ACTIONS(5103),
    [anon_sym_abstract] = ACTIONS(5103),
    [anon_sym_async] = ACTIONS(5103),
    [anon_sym_const] = ACTIONS(5103),
    [anon_sym_file] = ACTIONS(5103),
    [anon_sym_fixed] = ACTIONS(5103),
    [anon_sym_internal] = ACTIONS(5103),
    [anon_sym_new] = ACTIONS(5103),
    [anon_sym_override] = ACTIONS(5103),
    [anon_sym_partial] = ACTIONS(5103),
    [anon_sym_private] = ACTIONS(5103),
    [anon_sym_protected] = ACTIONS(5103),
    [anon_sym_public] = ACTIONS(5103),
    [anon_sym_readonly] = ACTIONS(5103),
    [anon_sym_required] = ACTIONS(5103),
    [anon_sym_sealed] = ACTIONS(5103),
    [anon_sym_virtual] = ACTIONS(5103),
    [anon_sym_volatile] = ACTIONS(5103),
    [anon_sym_where] = ACTIONS(5103),
    [anon_sym_notnull] = ACTIONS(5103),
    [anon_sym_unmanaged] = ACTIONS(5103),
    [anon_sym_TILDE] = ACTIONS(5105),
    [anon_sym_implicit] = ACTIONS(5103),
    [anon_sym_explicit] = ACTIONS(5103),
    [anon_sym_scoped] = ACTIONS(5103),
    [anon_sym_var] = ACTIONS(5103),
    [sym_predefined_type] = ACTIONS(5103),
    [anon_sym_yield] = ACTIONS(5103),
    [anon_sym_when] = ACTIONS(5103),
    [anon_sym_from] = ACTIONS(5103),
    [anon_sym_into] = ACTIONS(5103),
    [anon_sym_join] = ACTIONS(5103),
    [anon_sym_on] = ACTIONS(5103),
    [anon_sym_equals] = ACTIONS(5103),
    [anon_sym_let] = ACTIONS(5103),
    [anon_sym_orderby] = ACTIONS(5103),
    [anon_sym_ascending] = ACTIONS(5103),
    [anon_sym_descending] = ACTIONS(5103),
    [anon_sym_group] = ACTIONS(5103),
    [anon_sym_by] = ACTIONS(5103),
    [anon_sym_select] = ACTIONS(5103),
    [aux_sym_preproc_if_token1] = ACTIONS(5105),
    [aux_sym_preproc_if_token3] = ACTIONS(5105),
    [aux_sym_preproc_else_token1] = ACTIONS(5105),
    [aux_sym_preproc_elif_token1] = ACTIONS(5105),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3393] = {
    [sym_preproc_region] = STATE(3393),
    [sym_preproc_endregion] = STATE(3393),
    [sym_preproc_line] = STATE(3393),
    [sym_preproc_pragma] = STATE(3393),
    [sym_preproc_nullable] = STATE(3393),
    [sym_preproc_error] = STATE(3393),
    [sym_preproc_warning] = STATE(3393),
    [sym_preproc_define] = STATE(3393),
    [sym_preproc_undef] = STATE(3393),
    [anon_sym_SEMI] = ACTIONS(4132),
    [anon_sym_EQ] = ACTIONS(4130),
    [anon_sym_LBRACK] = ACTIONS(4132),
    [anon_sym_COLON] = ACTIONS(4132),
    [anon_sym_COMMA] = ACTIONS(4132),
    [anon_sym_RBRACK] = ACTIONS(4132),
    [anon_sym_LPAREN] = ACTIONS(4132),
    [anon_sym_RPAREN] = ACTIONS(4132),
    [anon_sym_RBRACE] = ACTIONS(4132),
    [anon_sym_LT] = ACTIONS(4130),
    [anon_sym_GT] = ACTIONS(4130),
    [anon_sym_in] = ACTIONS(4132),
    [anon_sym_QMARK] = ACTIONS(4130),
    [anon_sym_BANG] = ACTIONS(4130),
    [anon_sym_PLUS_PLUS] = ACTIONS(4132),
    [anon_sym_DASH_DASH] = ACTIONS(4132),
    [anon_sym_PLUS] = ACTIONS(4130),
    [anon_sym_DASH] = ACTIONS(4130),
    [anon_sym_STAR] = ACTIONS(4130),
    [anon_sym_SLASH] = ACTIONS(4130),
    [anon_sym_PERCENT] = ACTIONS(4130),
    [anon_sym_CARET] = ACTIONS(4130),
    [anon_sym_PIPE] = ACTIONS(4130),
    [anon_sym_AMP] = ACTIONS(4130),
    [anon_sym_LT_LT] = ACTIONS(4130),
    [anon_sym_GT_GT] = ACTIONS(4130),
    [anon_sym_GT_GT_GT] = ACTIONS(4130),
    [anon_sym_EQ_EQ] = ACTIONS(4132),
    [anon_sym_BANG_EQ] = ACTIONS(4132),
    [anon_sym_GT_EQ] = ACTIONS(4132),
    [anon_sym_LT_EQ] = ACTIONS(4132),
    [anon_sym_DOT] = ACTIONS(4130),
    [anon_sym_EQ_GT] = ACTIONS(4132),
    [anon_sym_switch] = ACTIONS(4132),
    [anon_sym_when] = ACTIONS(4132),
    [anon_sym_DOT_DOT] = ACTIONS(4132),
    [anon_sym_and] = ACTIONS(4132),
    [anon_sym_or] = ACTIONS(4132),
    [anon_sym_PLUS_EQ] = ACTIONS(4132),
    [anon_sym_DASH_EQ] = ACTIONS(4132),
    [anon_sym_STAR_EQ] = ACTIONS(4132),
    [anon_sym_SLASH_EQ] = ACTIONS(4132),
    [anon_sym_PERCENT_EQ] = ACTIONS(4132),
    [anon_sym_AMP_EQ] = ACTIONS(4132),
    [anon_sym_CARET_EQ] = ACTIONS(4132),
    [anon_sym_PIPE_EQ] = ACTIONS(4132),
    [anon_sym_LT_LT_EQ] = ACTIONS(4132),
    [anon_sym_GT_GT_EQ] = ACTIONS(4132),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4132),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4132),
    [anon_sym_AMP_AMP] = ACTIONS(4132),
    [anon_sym_PIPE_PIPE] = ACTIONS(4132),
    [anon_sym_QMARK_QMARK] = ACTIONS(4130),
    [anon_sym_on] = ACTIONS(4132),
    [anon_sym_equals] = ACTIONS(4132),
    [anon_sym_by] = ACTIONS(4132),
    [anon_sym_as] = ACTIONS(4132),
    [anon_sym_is] = ACTIONS(4132),
    [anon_sym_DASH_GT] = ACTIONS(4132),
    [anon_sym_with] = ACTIONS(4132),
    [aux_sym_preproc_if_token3] = ACTIONS(4132),
    [aux_sym_preproc_else_token1] = ACTIONS(4132),
    [aux_sym_preproc_elif_token1] = ACTIONS(4132),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3394] = {
    [sym_preproc_region] = STATE(3394),
    [sym_preproc_endregion] = STATE(3394),
    [sym_preproc_line] = STATE(3394),
    [sym_preproc_pragma] = STATE(3394),
    [sym_preproc_nullable] = STATE(3394),
    [sym_preproc_error] = STATE(3394),
    [sym_preproc_warning] = STATE(3394),
    [sym_preproc_define] = STATE(3394),
    [sym_preproc_undef] = STATE(3394),
    [sym__identifier_token] = ACTIONS(5107),
    [anon_sym_extern] = ACTIONS(5107),
    [anon_sym_alias] = ACTIONS(5107),
    [anon_sym_global] = ACTIONS(5107),
    [anon_sym_using] = ACTIONS(5107),
    [anon_sym_unsafe] = ACTIONS(5107),
    [anon_sym_static] = ACTIONS(5107),
    [anon_sym_LBRACK] = ACTIONS(5109),
    [anon_sym_LPAREN] = ACTIONS(5109),
    [anon_sym_event] = ACTIONS(5107),
    [anon_sym_namespace] = ACTIONS(5107),
    [anon_sym_class] = ACTIONS(5107),
    [anon_sym_ref] = ACTIONS(5107),
    [anon_sym_struct] = ACTIONS(5107),
    [anon_sym_enum] = ACTIONS(5107),
    [anon_sym_RBRACE] = ACTIONS(5109),
    [anon_sym_interface] = ACTIONS(5107),
    [anon_sym_delegate] = ACTIONS(5107),
    [anon_sym_record] = ACTIONS(5107),
    [anon_sym_abstract] = ACTIONS(5107),
    [anon_sym_async] = ACTIONS(5107),
    [anon_sym_const] = ACTIONS(5107),
    [anon_sym_file] = ACTIONS(5107),
    [anon_sym_fixed] = ACTIONS(5107),
    [anon_sym_internal] = ACTIONS(5107),
    [anon_sym_new] = ACTIONS(5107),
    [anon_sym_override] = ACTIONS(5107),
    [anon_sym_partial] = ACTIONS(5107),
    [anon_sym_private] = ACTIONS(5107),
    [anon_sym_protected] = ACTIONS(5107),
    [anon_sym_public] = ACTIONS(5107),
    [anon_sym_readonly] = ACTIONS(5107),
    [anon_sym_required] = ACTIONS(5107),
    [anon_sym_sealed] = ACTIONS(5107),
    [anon_sym_virtual] = ACTIONS(5107),
    [anon_sym_volatile] = ACTIONS(5107),
    [anon_sym_where] = ACTIONS(5107),
    [anon_sym_notnull] = ACTIONS(5107),
    [anon_sym_unmanaged] = ACTIONS(5107),
    [anon_sym_TILDE] = ACTIONS(5109),
    [anon_sym_implicit] = ACTIONS(5107),
    [anon_sym_explicit] = ACTIONS(5107),
    [anon_sym_scoped] = ACTIONS(5107),
    [anon_sym_var] = ACTIONS(5107),
    [sym_predefined_type] = ACTIONS(5107),
    [anon_sym_yield] = ACTIONS(5107),
    [anon_sym_when] = ACTIONS(5107),
    [anon_sym_from] = ACTIONS(5107),
    [anon_sym_into] = ACTIONS(5107),
    [anon_sym_join] = ACTIONS(5107),
    [anon_sym_on] = ACTIONS(5107),
    [anon_sym_equals] = ACTIONS(5107),
    [anon_sym_let] = ACTIONS(5107),
    [anon_sym_orderby] = ACTIONS(5107),
    [anon_sym_ascending] = ACTIONS(5107),
    [anon_sym_descending] = ACTIONS(5107),
    [anon_sym_group] = ACTIONS(5107),
    [anon_sym_by] = ACTIONS(5107),
    [anon_sym_select] = ACTIONS(5107),
    [aux_sym_preproc_if_token1] = ACTIONS(5109),
    [aux_sym_preproc_if_token3] = ACTIONS(5109),
    [aux_sym_preproc_else_token1] = ACTIONS(5109),
    [aux_sym_preproc_elif_token1] = ACTIONS(5109),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3395] = {
    [sym_preproc_region] = STATE(3395),
    [sym_preproc_endregion] = STATE(3395),
    [sym_preproc_line] = STATE(3395),
    [sym_preproc_pragma] = STATE(3395),
    [sym_preproc_nullable] = STATE(3395),
    [sym_preproc_error] = STATE(3395),
    [sym_preproc_warning] = STATE(3395),
    [sym_preproc_define] = STATE(3395),
    [sym_preproc_undef] = STATE(3395),
    [sym__identifier_token] = ACTIONS(4431),
    [anon_sym_alias] = ACTIONS(4431),
    [anon_sym_global] = ACTIONS(4431),
    [anon_sym_LBRACK] = ACTIONS(4433),
    [anon_sym_COLON] = ACTIONS(4433),
    [anon_sym_COMMA] = ACTIONS(4433),
    [anon_sym_LPAREN] = ACTIONS(4433),
    [anon_sym_LBRACE] = ACTIONS(4433),
    [anon_sym_file] = ACTIONS(4431),
    [anon_sym_LT] = ACTIONS(4431),
    [anon_sym_GT] = ACTIONS(4431),
    [anon_sym_where] = ACTIONS(4431),
    [anon_sym_QMARK] = ACTIONS(4431),
    [anon_sym_notnull] = ACTIONS(4431),
    [anon_sym_unmanaged] = ACTIONS(4431),
    [anon_sym_BANG] = ACTIONS(4431),
    [anon_sym_PLUS_PLUS] = ACTIONS(4433),
    [anon_sym_DASH_DASH] = ACTIONS(4433),
    [anon_sym_PLUS] = ACTIONS(4431),
    [anon_sym_DASH] = ACTIONS(4431),
    [anon_sym_STAR] = ACTIONS(4433),
    [anon_sym_SLASH] = ACTIONS(4431),
    [anon_sym_PERCENT] = ACTIONS(4433),
    [anon_sym_CARET] = ACTIONS(4433),
    [anon_sym_PIPE] = ACTIONS(4431),
    [anon_sym_AMP] = ACTIONS(4431),
    [anon_sym_LT_LT] = ACTIONS(4433),
    [anon_sym_GT_GT] = ACTIONS(4431),
    [anon_sym_GT_GT_GT] = ACTIONS(4433),
    [anon_sym_EQ_EQ] = ACTIONS(4433),
    [anon_sym_BANG_EQ] = ACTIONS(4433),
    [anon_sym_GT_EQ] = ACTIONS(4433),
    [anon_sym_LT_EQ] = ACTIONS(4433),
    [anon_sym_DOT] = ACTIONS(4431),
    [anon_sym_scoped] = ACTIONS(4431),
    [anon_sym_var] = ACTIONS(4431),
    [anon_sym_yield] = ACTIONS(4431),
    [anon_sym_switch] = ACTIONS(4431),
    [anon_sym_when] = ACTIONS(4431),
    [sym_discard] = ACTIONS(4431),
    [anon_sym_DOT_DOT] = ACTIONS(4433),
    [anon_sym_and] = ACTIONS(4431),
    [anon_sym_or] = ACTIONS(4431),
    [anon_sym_AMP_AMP] = ACTIONS(4433),
    [anon_sym_PIPE_PIPE] = ACTIONS(4433),
    [anon_sym_QMARK_QMARK] = ACTIONS(4433),
    [anon_sym_from] = ACTIONS(4431),
    [anon_sym_into] = ACTIONS(4431),
    [anon_sym_join] = ACTIONS(4431),
    [anon_sym_on] = ACTIONS(4431),
    [anon_sym_equals] = ACTIONS(4431),
    [anon_sym_let] = ACTIONS(4431),
    [anon_sym_orderby] = ACTIONS(4431),
    [anon_sym_ascending] = ACTIONS(4431),
    [anon_sym_descending] = ACTIONS(4431),
    [anon_sym_group] = ACTIONS(4431),
    [anon_sym_by] = ACTIONS(4431),
    [anon_sym_select] = ACTIONS(4431),
    [anon_sym_as] = ACTIONS(4431),
    [anon_sym_is] = ACTIONS(4431),
    [anon_sym_DASH_GT] = ACTIONS(4433),
    [anon_sym_with] = ACTIONS(4431),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4433),
  },
  [3396] = {
    [sym_preproc_region] = STATE(3396),
    [sym_preproc_endregion] = STATE(3396),
    [sym_preproc_line] = STATE(3396),
    [sym_preproc_pragma] = STATE(3396),
    [sym_preproc_nullable] = STATE(3396),
    [sym_preproc_error] = STATE(3396),
    [sym_preproc_warning] = STATE(3396),
    [sym_preproc_define] = STATE(3396),
    [sym_preproc_undef] = STATE(3396),
    [sym__identifier_token] = ACTIONS(5111),
    [anon_sym_extern] = ACTIONS(5111),
    [anon_sym_alias] = ACTIONS(5111),
    [anon_sym_global] = ACTIONS(5111),
    [anon_sym_using] = ACTIONS(5111),
    [anon_sym_unsafe] = ACTIONS(5111),
    [anon_sym_static] = ACTIONS(5111),
    [anon_sym_LBRACK] = ACTIONS(5113),
    [anon_sym_LPAREN] = ACTIONS(5113),
    [anon_sym_event] = ACTIONS(5111),
    [anon_sym_namespace] = ACTIONS(5111),
    [anon_sym_class] = ACTIONS(5111),
    [anon_sym_ref] = ACTIONS(5111),
    [anon_sym_struct] = ACTIONS(5111),
    [anon_sym_enum] = ACTIONS(5111),
    [anon_sym_RBRACE] = ACTIONS(5113),
    [anon_sym_interface] = ACTIONS(5111),
    [anon_sym_delegate] = ACTIONS(5111),
    [anon_sym_record] = ACTIONS(5111),
    [anon_sym_abstract] = ACTIONS(5111),
    [anon_sym_async] = ACTIONS(5111),
    [anon_sym_const] = ACTIONS(5111),
    [anon_sym_file] = ACTIONS(5111),
    [anon_sym_fixed] = ACTIONS(5111),
    [anon_sym_internal] = ACTIONS(5111),
    [anon_sym_new] = ACTIONS(5111),
    [anon_sym_override] = ACTIONS(5111),
    [anon_sym_partial] = ACTIONS(5111),
    [anon_sym_private] = ACTIONS(5111),
    [anon_sym_protected] = ACTIONS(5111),
    [anon_sym_public] = ACTIONS(5111),
    [anon_sym_readonly] = ACTIONS(5111),
    [anon_sym_required] = ACTIONS(5111),
    [anon_sym_sealed] = ACTIONS(5111),
    [anon_sym_virtual] = ACTIONS(5111),
    [anon_sym_volatile] = ACTIONS(5111),
    [anon_sym_where] = ACTIONS(5111),
    [anon_sym_notnull] = ACTIONS(5111),
    [anon_sym_unmanaged] = ACTIONS(5111),
    [anon_sym_TILDE] = ACTIONS(5113),
    [anon_sym_implicit] = ACTIONS(5111),
    [anon_sym_explicit] = ACTIONS(5111),
    [anon_sym_scoped] = ACTIONS(5111),
    [anon_sym_var] = ACTIONS(5111),
    [sym_predefined_type] = ACTIONS(5111),
    [anon_sym_yield] = ACTIONS(5111),
    [anon_sym_when] = ACTIONS(5111),
    [anon_sym_from] = ACTIONS(5111),
    [anon_sym_into] = ACTIONS(5111),
    [anon_sym_join] = ACTIONS(5111),
    [anon_sym_on] = ACTIONS(5111),
    [anon_sym_equals] = ACTIONS(5111),
    [anon_sym_let] = ACTIONS(5111),
    [anon_sym_orderby] = ACTIONS(5111),
    [anon_sym_ascending] = ACTIONS(5111),
    [anon_sym_descending] = ACTIONS(5111),
    [anon_sym_group] = ACTIONS(5111),
    [anon_sym_by] = ACTIONS(5111),
    [anon_sym_select] = ACTIONS(5111),
    [aux_sym_preproc_if_token1] = ACTIONS(5113),
    [aux_sym_preproc_if_token3] = ACTIONS(5113),
    [aux_sym_preproc_else_token1] = ACTIONS(5113),
    [aux_sym_preproc_elif_token1] = ACTIONS(5113),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3397] = {
    [sym_preproc_region] = STATE(3397),
    [sym_preproc_endregion] = STATE(3397),
    [sym_preproc_line] = STATE(3397),
    [sym_preproc_pragma] = STATE(3397),
    [sym_preproc_nullable] = STATE(3397),
    [sym_preproc_error] = STATE(3397),
    [sym_preproc_warning] = STATE(3397),
    [sym_preproc_define] = STATE(3397),
    [sym_preproc_undef] = STATE(3397),
    [sym__identifier_token] = ACTIONS(5115),
    [anon_sym_extern] = ACTIONS(5115),
    [anon_sym_alias] = ACTIONS(5115),
    [anon_sym_global] = ACTIONS(5115),
    [anon_sym_using] = ACTIONS(5115),
    [anon_sym_unsafe] = ACTIONS(5115),
    [anon_sym_static] = ACTIONS(5115),
    [anon_sym_LBRACK] = ACTIONS(5117),
    [anon_sym_LPAREN] = ACTIONS(5117),
    [anon_sym_event] = ACTIONS(5115),
    [anon_sym_namespace] = ACTIONS(5115),
    [anon_sym_class] = ACTIONS(5115),
    [anon_sym_ref] = ACTIONS(5115),
    [anon_sym_struct] = ACTIONS(5115),
    [anon_sym_enum] = ACTIONS(5115),
    [anon_sym_RBRACE] = ACTIONS(5117),
    [anon_sym_interface] = ACTIONS(5115),
    [anon_sym_delegate] = ACTIONS(5115),
    [anon_sym_record] = ACTIONS(5115),
    [anon_sym_abstract] = ACTIONS(5115),
    [anon_sym_async] = ACTIONS(5115),
    [anon_sym_const] = ACTIONS(5115),
    [anon_sym_file] = ACTIONS(5115),
    [anon_sym_fixed] = ACTIONS(5115),
    [anon_sym_internal] = ACTIONS(5115),
    [anon_sym_new] = ACTIONS(5115),
    [anon_sym_override] = ACTIONS(5115),
    [anon_sym_partial] = ACTIONS(5115),
    [anon_sym_private] = ACTIONS(5115),
    [anon_sym_protected] = ACTIONS(5115),
    [anon_sym_public] = ACTIONS(5115),
    [anon_sym_readonly] = ACTIONS(5115),
    [anon_sym_required] = ACTIONS(5115),
    [anon_sym_sealed] = ACTIONS(5115),
    [anon_sym_virtual] = ACTIONS(5115),
    [anon_sym_volatile] = ACTIONS(5115),
    [anon_sym_where] = ACTIONS(5115),
    [anon_sym_notnull] = ACTIONS(5115),
    [anon_sym_unmanaged] = ACTIONS(5115),
    [anon_sym_TILDE] = ACTIONS(5117),
    [anon_sym_implicit] = ACTIONS(5115),
    [anon_sym_explicit] = ACTIONS(5115),
    [anon_sym_scoped] = ACTIONS(5115),
    [anon_sym_var] = ACTIONS(5115),
    [sym_predefined_type] = ACTIONS(5115),
    [anon_sym_yield] = ACTIONS(5115),
    [anon_sym_when] = ACTIONS(5115),
    [anon_sym_from] = ACTIONS(5115),
    [anon_sym_into] = ACTIONS(5115),
    [anon_sym_join] = ACTIONS(5115),
    [anon_sym_on] = ACTIONS(5115),
    [anon_sym_equals] = ACTIONS(5115),
    [anon_sym_let] = ACTIONS(5115),
    [anon_sym_orderby] = ACTIONS(5115),
    [anon_sym_ascending] = ACTIONS(5115),
    [anon_sym_descending] = ACTIONS(5115),
    [anon_sym_group] = ACTIONS(5115),
    [anon_sym_by] = ACTIONS(5115),
    [anon_sym_select] = ACTIONS(5115),
    [aux_sym_preproc_if_token1] = ACTIONS(5117),
    [aux_sym_preproc_if_token3] = ACTIONS(5117),
    [aux_sym_preproc_else_token1] = ACTIONS(5117),
    [aux_sym_preproc_elif_token1] = ACTIONS(5117),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3398] = {
    [sym_preproc_region] = STATE(3398),
    [sym_preproc_endregion] = STATE(3398),
    [sym_preproc_line] = STATE(3398),
    [sym_preproc_pragma] = STATE(3398),
    [sym_preproc_nullable] = STATE(3398),
    [sym_preproc_error] = STATE(3398),
    [sym_preproc_warning] = STATE(3398),
    [sym_preproc_define] = STATE(3398),
    [sym_preproc_undef] = STATE(3398),
    [sym__identifier_token] = ACTIONS(5119),
    [anon_sym_extern] = ACTIONS(5119),
    [anon_sym_alias] = ACTIONS(5119),
    [anon_sym_global] = ACTIONS(5119),
    [anon_sym_using] = ACTIONS(5119),
    [anon_sym_unsafe] = ACTIONS(5119),
    [anon_sym_static] = ACTIONS(5119),
    [anon_sym_LBRACK] = ACTIONS(5121),
    [anon_sym_LPAREN] = ACTIONS(5121),
    [anon_sym_event] = ACTIONS(5119),
    [anon_sym_namespace] = ACTIONS(5119),
    [anon_sym_class] = ACTIONS(5119),
    [anon_sym_ref] = ACTIONS(5119),
    [anon_sym_struct] = ACTIONS(5119),
    [anon_sym_enum] = ACTIONS(5119),
    [anon_sym_RBRACE] = ACTIONS(5121),
    [anon_sym_interface] = ACTIONS(5119),
    [anon_sym_delegate] = ACTIONS(5119),
    [anon_sym_record] = ACTIONS(5119),
    [anon_sym_abstract] = ACTIONS(5119),
    [anon_sym_async] = ACTIONS(5119),
    [anon_sym_const] = ACTIONS(5119),
    [anon_sym_file] = ACTIONS(5119),
    [anon_sym_fixed] = ACTIONS(5119),
    [anon_sym_internal] = ACTIONS(5119),
    [anon_sym_new] = ACTIONS(5119),
    [anon_sym_override] = ACTIONS(5119),
    [anon_sym_partial] = ACTIONS(5119),
    [anon_sym_private] = ACTIONS(5119),
    [anon_sym_protected] = ACTIONS(5119),
    [anon_sym_public] = ACTIONS(5119),
    [anon_sym_readonly] = ACTIONS(5119),
    [anon_sym_required] = ACTIONS(5119),
    [anon_sym_sealed] = ACTIONS(5119),
    [anon_sym_virtual] = ACTIONS(5119),
    [anon_sym_volatile] = ACTIONS(5119),
    [anon_sym_where] = ACTIONS(5119),
    [anon_sym_notnull] = ACTIONS(5119),
    [anon_sym_unmanaged] = ACTIONS(5119),
    [anon_sym_TILDE] = ACTIONS(5121),
    [anon_sym_implicit] = ACTIONS(5119),
    [anon_sym_explicit] = ACTIONS(5119),
    [anon_sym_scoped] = ACTIONS(5119),
    [anon_sym_var] = ACTIONS(5119),
    [sym_predefined_type] = ACTIONS(5119),
    [anon_sym_yield] = ACTIONS(5119),
    [anon_sym_when] = ACTIONS(5119),
    [anon_sym_from] = ACTIONS(5119),
    [anon_sym_into] = ACTIONS(5119),
    [anon_sym_join] = ACTIONS(5119),
    [anon_sym_on] = ACTIONS(5119),
    [anon_sym_equals] = ACTIONS(5119),
    [anon_sym_let] = ACTIONS(5119),
    [anon_sym_orderby] = ACTIONS(5119),
    [anon_sym_ascending] = ACTIONS(5119),
    [anon_sym_descending] = ACTIONS(5119),
    [anon_sym_group] = ACTIONS(5119),
    [anon_sym_by] = ACTIONS(5119),
    [anon_sym_select] = ACTIONS(5119),
    [aux_sym_preproc_if_token1] = ACTIONS(5121),
    [aux_sym_preproc_if_token3] = ACTIONS(5121),
    [aux_sym_preproc_else_token1] = ACTIONS(5121),
    [aux_sym_preproc_elif_token1] = ACTIONS(5121),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3399] = {
    [sym_preproc_region] = STATE(3399),
    [sym_preproc_endregion] = STATE(3399),
    [sym_preproc_line] = STATE(3399),
    [sym_preproc_pragma] = STATE(3399),
    [sym_preproc_nullable] = STATE(3399),
    [sym_preproc_error] = STATE(3399),
    [sym_preproc_warning] = STATE(3399),
    [sym_preproc_define] = STATE(3399),
    [sym_preproc_undef] = STATE(3399),
    [sym__identifier_token] = ACTIONS(5123),
    [anon_sym_extern] = ACTIONS(5123),
    [anon_sym_alias] = ACTIONS(5123),
    [anon_sym_global] = ACTIONS(5123),
    [anon_sym_using] = ACTIONS(5123),
    [anon_sym_unsafe] = ACTIONS(5123),
    [anon_sym_static] = ACTIONS(5123),
    [anon_sym_LBRACK] = ACTIONS(5125),
    [anon_sym_LPAREN] = ACTIONS(5125),
    [anon_sym_event] = ACTIONS(5123),
    [anon_sym_namespace] = ACTIONS(5123),
    [anon_sym_class] = ACTIONS(5123),
    [anon_sym_ref] = ACTIONS(5123),
    [anon_sym_struct] = ACTIONS(5123),
    [anon_sym_enum] = ACTIONS(5123),
    [anon_sym_RBRACE] = ACTIONS(5125),
    [anon_sym_interface] = ACTIONS(5123),
    [anon_sym_delegate] = ACTIONS(5123),
    [anon_sym_record] = ACTIONS(5123),
    [anon_sym_abstract] = ACTIONS(5123),
    [anon_sym_async] = ACTIONS(5123),
    [anon_sym_const] = ACTIONS(5123),
    [anon_sym_file] = ACTIONS(5123),
    [anon_sym_fixed] = ACTIONS(5123),
    [anon_sym_internal] = ACTIONS(5123),
    [anon_sym_new] = ACTIONS(5123),
    [anon_sym_override] = ACTIONS(5123),
    [anon_sym_partial] = ACTIONS(5123),
    [anon_sym_private] = ACTIONS(5123),
    [anon_sym_protected] = ACTIONS(5123),
    [anon_sym_public] = ACTIONS(5123),
    [anon_sym_readonly] = ACTIONS(5123),
    [anon_sym_required] = ACTIONS(5123),
    [anon_sym_sealed] = ACTIONS(5123),
    [anon_sym_virtual] = ACTIONS(5123),
    [anon_sym_volatile] = ACTIONS(5123),
    [anon_sym_where] = ACTIONS(5123),
    [anon_sym_notnull] = ACTIONS(5123),
    [anon_sym_unmanaged] = ACTIONS(5123),
    [anon_sym_TILDE] = ACTIONS(5125),
    [anon_sym_implicit] = ACTIONS(5123),
    [anon_sym_explicit] = ACTIONS(5123),
    [anon_sym_scoped] = ACTIONS(5123),
    [anon_sym_var] = ACTIONS(5123),
    [sym_predefined_type] = ACTIONS(5123),
    [anon_sym_yield] = ACTIONS(5123),
    [anon_sym_when] = ACTIONS(5123),
    [anon_sym_from] = ACTIONS(5123),
    [anon_sym_into] = ACTIONS(5123),
    [anon_sym_join] = ACTIONS(5123),
    [anon_sym_on] = ACTIONS(5123),
    [anon_sym_equals] = ACTIONS(5123),
    [anon_sym_let] = ACTIONS(5123),
    [anon_sym_orderby] = ACTIONS(5123),
    [anon_sym_ascending] = ACTIONS(5123),
    [anon_sym_descending] = ACTIONS(5123),
    [anon_sym_group] = ACTIONS(5123),
    [anon_sym_by] = ACTIONS(5123),
    [anon_sym_select] = ACTIONS(5123),
    [aux_sym_preproc_if_token1] = ACTIONS(5125),
    [aux_sym_preproc_if_token3] = ACTIONS(5125),
    [aux_sym_preproc_else_token1] = ACTIONS(5125),
    [aux_sym_preproc_elif_token1] = ACTIONS(5125),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3400] = {
    [sym_preproc_region] = STATE(3400),
    [sym_preproc_endregion] = STATE(3400),
    [sym_preproc_line] = STATE(3400),
    [sym_preproc_pragma] = STATE(3400),
    [sym_preproc_nullable] = STATE(3400),
    [sym_preproc_error] = STATE(3400),
    [sym_preproc_warning] = STATE(3400),
    [sym_preproc_define] = STATE(3400),
    [sym_preproc_undef] = STATE(3400),
    [sym__identifier_token] = ACTIONS(5127),
    [anon_sym_extern] = ACTIONS(5127),
    [anon_sym_alias] = ACTIONS(5127),
    [anon_sym_global] = ACTIONS(5127),
    [anon_sym_using] = ACTIONS(5127),
    [anon_sym_unsafe] = ACTIONS(5127),
    [anon_sym_static] = ACTIONS(5127),
    [anon_sym_LBRACK] = ACTIONS(5129),
    [anon_sym_LPAREN] = ACTIONS(5129),
    [anon_sym_event] = ACTIONS(5127),
    [anon_sym_namespace] = ACTIONS(5127),
    [anon_sym_class] = ACTIONS(5127),
    [anon_sym_ref] = ACTIONS(5127),
    [anon_sym_struct] = ACTIONS(5127),
    [anon_sym_enum] = ACTIONS(5127),
    [anon_sym_RBRACE] = ACTIONS(5129),
    [anon_sym_interface] = ACTIONS(5127),
    [anon_sym_delegate] = ACTIONS(5127),
    [anon_sym_record] = ACTIONS(5127),
    [anon_sym_abstract] = ACTIONS(5127),
    [anon_sym_async] = ACTIONS(5127),
    [anon_sym_const] = ACTIONS(5127),
    [anon_sym_file] = ACTIONS(5127),
    [anon_sym_fixed] = ACTIONS(5127),
    [anon_sym_internal] = ACTIONS(5127),
    [anon_sym_new] = ACTIONS(5127),
    [anon_sym_override] = ACTIONS(5127),
    [anon_sym_partial] = ACTIONS(5127),
    [anon_sym_private] = ACTIONS(5127),
    [anon_sym_protected] = ACTIONS(5127),
    [anon_sym_public] = ACTIONS(5127),
    [anon_sym_readonly] = ACTIONS(5127),
    [anon_sym_required] = ACTIONS(5127),
    [anon_sym_sealed] = ACTIONS(5127),
    [anon_sym_virtual] = ACTIONS(5127),
    [anon_sym_volatile] = ACTIONS(5127),
    [anon_sym_where] = ACTIONS(5127),
    [anon_sym_notnull] = ACTIONS(5127),
    [anon_sym_unmanaged] = ACTIONS(5127),
    [anon_sym_TILDE] = ACTIONS(5129),
    [anon_sym_implicit] = ACTIONS(5127),
    [anon_sym_explicit] = ACTIONS(5127),
    [anon_sym_scoped] = ACTIONS(5127),
    [anon_sym_var] = ACTIONS(5127),
    [sym_predefined_type] = ACTIONS(5127),
    [anon_sym_yield] = ACTIONS(5127),
    [anon_sym_when] = ACTIONS(5127),
    [anon_sym_from] = ACTIONS(5127),
    [anon_sym_into] = ACTIONS(5127),
    [anon_sym_join] = ACTIONS(5127),
    [anon_sym_on] = ACTIONS(5127),
    [anon_sym_equals] = ACTIONS(5127),
    [anon_sym_let] = ACTIONS(5127),
    [anon_sym_orderby] = ACTIONS(5127),
    [anon_sym_ascending] = ACTIONS(5127),
    [anon_sym_descending] = ACTIONS(5127),
    [anon_sym_group] = ACTIONS(5127),
    [anon_sym_by] = ACTIONS(5127),
    [anon_sym_select] = ACTIONS(5127),
    [aux_sym_preproc_if_token1] = ACTIONS(5129),
    [aux_sym_preproc_if_token3] = ACTIONS(5129),
    [aux_sym_preproc_else_token1] = ACTIONS(5129),
    [aux_sym_preproc_elif_token1] = ACTIONS(5129),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3401] = {
    [sym_preproc_region] = STATE(3401),
    [sym_preproc_endregion] = STATE(3401),
    [sym_preproc_line] = STATE(3401),
    [sym_preproc_pragma] = STATE(3401),
    [sym_preproc_nullable] = STATE(3401),
    [sym_preproc_error] = STATE(3401),
    [sym_preproc_warning] = STATE(3401),
    [sym_preproc_define] = STATE(3401),
    [sym_preproc_undef] = STATE(3401),
    [sym__identifier_token] = ACTIONS(5131),
    [anon_sym_extern] = ACTIONS(5131),
    [anon_sym_alias] = ACTIONS(5131),
    [anon_sym_global] = ACTIONS(5131),
    [anon_sym_using] = ACTIONS(5131),
    [anon_sym_unsafe] = ACTIONS(5131),
    [anon_sym_static] = ACTIONS(5131),
    [anon_sym_LBRACK] = ACTIONS(5133),
    [anon_sym_LPAREN] = ACTIONS(5133),
    [anon_sym_event] = ACTIONS(5131),
    [anon_sym_namespace] = ACTIONS(5131),
    [anon_sym_class] = ACTIONS(5131),
    [anon_sym_ref] = ACTIONS(5131),
    [anon_sym_struct] = ACTIONS(5131),
    [anon_sym_enum] = ACTIONS(5131),
    [anon_sym_RBRACE] = ACTIONS(5133),
    [anon_sym_interface] = ACTIONS(5131),
    [anon_sym_delegate] = ACTIONS(5131),
    [anon_sym_record] = ACTIONS(5131),
    [anon_sym_abstract] = ACTIONS(5131),
    [anon_sym_async] = ACTIONS(5131),
    [anon_sym_const] = ACTIONS(5131),
    [anon_sym_file] = ACTIONS(5131),
    [anon_sym_fixed] = ACTIONS(5131),
    [anon_sym_internal] = ACTIONS(5131),
    [anon_sym_new] = ACTIONS(5131),
    [anon_sym_override] = ACTIONS(5131),
    [anon_sym_partial] = ACTIONS(5131),
    [anon_sym_private] = ACTIONS(5131),
    [anon_sym_protected] = ACTIONS(5131),
    [anon_sym_public] = ACTIONS(5131),
    [anon_sym_readonly] = ACTIONS(5131),
    [anon_sym_required] = ACTIONS(5131),
    [anon_sym_sealed] = ACTIONS(5131),
    [anon_sym_virtual] = ACTIONS(5131),
    [anon_sym_volatile] = ACTIONS(5131),
    [anon_sym_where] = ACTIONS(5131),
    [anon_sym_notnull] = ACTIONS(5131),
    [anon_sym_unmanaged] = ACTIONS(5131),
    [anon_sym_TILDE] = ACTIONS(5133),
    [anon_sym_implicit] = ACTIONS(5131),
    [anon_sym_explicit] = ACTIONS(5131),
    [anon_sym_scoped] = ACTIONS(5131),
    [anon_sym_var] = ACTIONS(5131),
    [sym_predefined_type] = ACTIONS(5131),
    [anon_sym_yield] = ACTIONS(5131),
    [anon_sym_when] = ACTIONS(5131),
    [anon_sym_from] = ACTIONS(5131),
    [anon_sym_into] = ACTIONS(5131),
    [anon_sym_join] = ACTIONS(5131),
    [anon_sym_on] = ACTIONS(5131),
    [anon_sym_equals] = ACTIONS(5131),
    [anon_sym_let] = ACTIONS(5131),
    [anon_sym_orderby] = ACTIONS(5131),
    [anon_sym_ascending] = ACTIONS(5131),
    [anon_sym_descending] = ACTIONS(5131),
    [anon_sym_group] = ACTIONS(5131),
    [anon_sym_by] = ACTIONS(5131),
    [anon_sym_select] = ACTIONS(5131),
    [aux_sym_preproc_if_token1] = ACTIONS(5133),
    [aux_sym_preproc_if_token3] = ACTIONS(5133),
    [aux_sym_preproc_else_token1] = ACTIONS(5133),
    [aux_sym_preproc_elif_token1] = ACTIONS(5133),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3402] = {
    [sym_preproc_region] = STATE(3402),
    [sym_preproc_endregion] = STATE(3402),
    [sym_preproc_line] = STATE(3402),
    [sym_preproc_pragma] = STATE(3402),
    [sym_preproc_nullable] = STATE(3402),
    [sym_preproc_error] = STATE(3402),
    [sym_preproc_warning] = STATE(3402),
    [sym_preproc_define] = STATE(3402),
    [sym_preproc_undef] = STATE(3402),
    [sym__identifier_token] = ACTIONS(5135),
    [anon_sym_extern] = ACTIONS(5135),
    [anon_sym_alias] = ACTIONS(5135),
    [anon_sym_global] = ACTIONS(5135),
    [anon_sym_using] = ACTIONS(5135),
    [anon_sym_unsafe] = ACTIONS(5135),
    [anon_sym_static] = ACTIONS(5135),
    [anon_sym_LBRACK] = ACTIONS(5137),
    [anon_sym_LPAREN] = ACTIONS(5137),
    [anon_sym_event] = ACTIONS(5135),
    [anon_sym_namespace] = ACTIONS(5135),
    [anon_sym_class] = ACTIONS(5135),
    [anon_sym_ref] = ACTIONS(5135),
    [anon_sym_struct] = ACTIONS(5135),
    [anon_sym_enum] = ACTIONS(5135),
    [anon_sym_RBRACE] = ACTIONS(5137),
    [anon_sym_interface] = ACTIONS(5135),
    [anon_sym_delegate] = ACTIONS(5135),
    [anon_sym_record] = ACTIONS(5135),
    [anon_sym_abstract] = ACTIONS(5135),
    [anon_sym_async] = ACTIONS(5135),
    [anon_sym_const] = ACTIONS(5135),
    [anon_sym_file] = ACTIONS(5135),
    [anon_sym_fixed] = ACTIONS(5135),
    [anon_sym_internal] = ACTIONS(5135),
    [anon_sym_new] = ACTIONS(5135),
    [anon_sym_override] = ACTIONS(5135),
    [anon_sym_partial] = ACTIONS(5135),
    [anon_sym_private] = ACTIONS(5135),
    [anon_sym_protected] = ACTIONS(5135),
    [anon_sym_public] = ACTIONS(5135),
    [anon_sym_readonly] = ACTIONS(5135),
    [anon_sym_required] = ACTIONS(5135),
    [anon_sym_sealed] = ACTIONS(5135),
    [anon_sym_virtual] = ACTIONS(5135),
    [anon_sym_volatile] = ACTIONS(5135),
    [anon_sym_where] = ACTIONS(5135),
    [anon_sym_notnull] = ACTIONS(5135),
    [anon_sym_unmanaged] = ACTIONS(5135),
    [anon_sym_TILDE] = ACTIONS(5137),
    [anon_sym_implicit] = ACTIONS(5135),
    [anon_sym_explicit] = ACTIONS(5135),
    [anon_sym_scoped] = ACTIONS(5135),
    [anon_sym_var] = ACTIONS(5135),
    [sym_predefined_type] = ACTIONS(5135),
    [anon_sym_yield] = ACTIONS(5135),
    [anon_sym_when] = ACTIONS(5135),
    [anon_sym_from] = ACTIONS(5135),
    [anon_sym_into] = ACTIONS(5135),
    [anon_sym_join] = ACTIONS(5135),
    [anon_sym_on] = ACTIONS(5135),
    [anon_sym_equals] = ACTIONS(5135),
    [anon_sym_let] = ACTIONS(5135),
    [anon_sym_orderby] = ACTIONS(5135),
    [anon_sym_ascending] = ACTIONS(5135),
    [anon_sym_descending] = ACTIONS(5135),
    [anon_sym_group] = ACTIONS(5135),
    [anon_sym_by] = ACTIONS(5135),
    [anon_sym_select] = ACTIONS(5135),
    [aux_sym_preproc_if_token1] = ACTIONS(5137),
    [aux_sym_preproc_if_token3] = ACTIONS(5137),
    [aux_sym_preproc_else_token1] = ACTIONS(5137),
    [aux_sym_preproc_elif_token1] = ACTIONS(5137),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3403] = {
    [sym_preproc_region] = STATE(3403),
    [sym_preproc_endregion] = STATE(3403),
    [sym_preproc_line] = STATE(3403),
    [sym_preproc_pragma] = STATE(3403),
    [sym_preproc_nullable] = STATE(3403),
    [sym_preproc_error] = STATE(3403),
    [sym_preproc_warning] = STATE(3403),
    [sym_preproc_define] = STATE(3403),
    [sym_preproc_undef] = STATE(3403),
    [sym__identifier_token] = ACTIONS(5139),
    [anon_sym_extern] = ACTIONS(5139),
    [anon_sym_alias] = ACTIONS(5139),
    [anon_sym_global] = ACTIONS(5139),
    [anon_sym_using] = ACTIONS(5139),
    [anon_sym_unsafe] = ACTIONS(5139),
    [anon_sym_static] = ACTIONS(5139),
    [anon_sym_LBRACK] = ACTIONS(5141),
    [anon_sym_LPAREN] = ACTIONS(5141),
    [anon_sym_event] = ACTIONS(5139),
    [anon_sym_namespace] = ACTIONS(5139),
    [anon_sym_class] = ACTIONS(5139),
    [anon_sym_ref] = ACTIONS(5139),
    [anon_sym_struct] = ACTIONS(5139),
    [anon_sym_enum] = ACTIONS(5139),
    [anon_sym_RBRACE] = ACTIONS(5141),
    [anon_sym_interface] = ACTIONS(5139),
    [anon_sym_delegate] = ACTIONS(5139),
    [anon_sym_record] = ACTIONS(5139),
    [anon_sym_abstract] = ACTIONS(5139),
    [anon_sym_async] = ACTIONS(5139),
    [anon_sym_const] = ACTIONS(5139),
    [anon_sym_file] = ACTIONS(5139),
    [anon_sym_fixed] = ACTIONS(5139),
    [anon_sym_internal] = ACTIONS(5139),
    [anon_sym_new] = ACTIONS(5139),
    [anon_sym_override] = ACTIONS(5139),
    [anon_sym_partial] = ACTIONS(5139),
    [anon_sym_private] = ACTIONS(5139),
    [anon_sym_protected] = ACTIONS(5139),
    [anon_sym_public] = ACTIONS(5139),
    [anon_sym_readonly] = ACTIONS(5139),
    [anon_sym_required] = ACTIONS(5139),
    [anon_sym_sealed] = ACTIONS(5139),
    [anon_sym_virtual] = ACTIONS(5139),
    [anon_sym_volatile] = ACTIONS(5139),
    [anon_sym_where] = ACTIONS(5139),
    [anon_sym_notnull] = ACTIONS(5139),
    [anon_sym_unmanaged] = ACTIONS(5139),
    [anon_sym_TILDE] = ACTIONS(5141),
    [anon_sym_implicit] = ACTIONS(5139),
    [anon_sym_explicit] = ACTIONS(5139),
    [anon_sym_scoped] = ACTIONS(5139),
    [anon_sym_var] = ACTIONS(5139),
    [sym_predefined_type] = ACTIONS(5139),
    [anon_sym_yield] = ACTIONS(5139),
    [anon_sym_when] = ACTIONS(5139),
    [anon_sym_from] = ACTIONS(5139),
    [anon_sym_into] = ACTIONS(5139),
    [anon_sym_join] = ACTIONS(5139),
    [anon_sym_on] = ACTIONS(5139),
    [anon_sym_equals] = ACTIONS(5139),
    [anon_sym_let] = ACTIONS(5139),
    [anon_sym_orderby] = ACTIONS(5139),
    [anon_sym_ascending] = ACTIONS(5139),
    [anon_sym_descending] = ACTIONS(5139),
    [anon_sym_group] = ACTIONS(5139),
    [anon_sym_by] = ACTIONS(5139),
    [anon_sym_select] = ACTIONS(5139),
    [aux_sym_preproc_if_token1] = ACTIONS(5141),
    [aux_sym_preproc_if_token3] = ACTIONS(5141),
    [aux_sym_preproc_else_token1] = ACTIONS(5141),
    [aux_sym_preproc_elif_token1] = ACTIONS(5141),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3404] = {
    [sym_preproc_region] = STATE(3404),
    [sym_preproc_endregion] = STATE(3404),
    [sym_preproc_line] = STATE(3404),
    [sym_preproc_pragma] = STATE(3404),
    [sym_preproc_nullable] = STATE(3404),
    [sym_preproc_error] = STATE(3404),
    [sym_preproc_warning] = STATE(3404),
    [sym_preproc_define] = STATE(3404),
    [sym_preproc_undef] = STATE(3404),
    [sym__identifier_token] = ACTIONS(5143),
    [anon_sym_extern] = ACTIONS(5143),
    [anon_sym_alias] = ACTIONS(5143),
    [anon_sym_global] = ACTIONS(5143),
    [anon_sym_using] = ACTIONS(5143),
    [anon_sym_unsafe] = ACTIONS(5143),
    [anon_sym_static] = ACTIONS(5143),
    [anon_sym_LBRACK] = ACTIONS(5145),
    [anon_sym_LPAREN] = ACTIONS(5145),
    [anon_sym_event] = ACTIONS(5143),
    [anon_sym_namespace] = ACTIONS(5143),
    [anon_sym_class] = ACTIONS(5143),
    [anon_sym_ref] = ACTIONS(5143),
    [anon_sym_struct] = ACTIONS(5143),
    [anon_sym_enum] = ACTIONS(5143),
    [anon_sym_RBRACE] = ACTIONS(5145),
    [anon_sym_interface] = ACTIONS(5143),
    [anon_sym_delegate] = ACTIONS(5143),
    [anon_sym_record] = ACTIONS(5143),
    [anon_sym_abstract] = ACTIONS(5143),
    [anon_sym_async] = ACTIONS(5143),
    [anon_sym_const] = ACTIONS(5143),
    [anon_sym_file] = ACTIONS(5143),
    [anon_sym_fixed] = ACTIONS(5143),
    [anon_sym_internal] = ACTIONS(5143),
    [anon_sym_new] = ACTIONS(5143),
    [anon_sym_override] = ACTIONS(5143),
    [anon_sym_partial] = ACTIONS(5143),
    [anon_sym_private] = ACTIONS(5143),
    [anon_sym_protected] = ACTIONS(5143),
    [anon_sym_public] = ACTIONS(5143),
    [anon_sym_readonly] = ACTIONS(5143),
    [anon_sym_required] = ACTIONS(5143),
    [anon_sym_sealed] = ACTIONS(5143),
    [anon_sym_virtual] = ACTIONS(5143),
    [anon_sym_volatile] = ACTIONS(5143),
    [anon_sym_where] = ACTIONS(5143),
    [anon_sym_notnull] = ACTIONS(5143),
    [anon_sym_unmanaged] = ACTIONS(5143),
    [anon_sym_TILDE] = ACTIONS(5145),
    [anon_sym_implicit] = ACTIONS(5143),
    [anon_sym_explicit] = ACTIONS(5143),
    [anon_sym_scoped] = ACTIONS(5143),
    [anon_sym_var] = ACTIONS(5143),
    [sym_predefined_type] = ACTIONS(5143),
    [anon_sym_yield] = ACTIONS(5143),
    [anon_sym_when] = ACTIONS(5143),
    [anon_sym_from] = ACTIONS(5143),
    [anon_sym_into] = ACTIONS(5143),
    [anon_sym_join] = ACTIONS(5143),
    [anon_sym_on] = ACTIONS(5143),
    [anon_sym_equals] = ACTIONS(5143),
    [anon_sym_let] = ACTIONS(5143),
    [anon_sym_orderby] = ACTIONS(5143),
    [anon_sym_ascending] = ACTIONS(5143),
    [anon_sym_descending] = ACTIONS(5143),
    [anon_sym_group] = ACTIONS(5143),
    [anon_sym_by] = ACTIONS(5143),
    [anon_sym_select] = ACTIONS(5143),
    [aux_sym_preproc_if_token1] = ACTIONS(5145),
    [aux_sym_preproc_if_token3] = ACTIONS(5145),
    [aux_sym_preproc_else_token1] = ACTIONS(5145),
    [aux_sym_preproc_elif_token1] = ACTIONS(5145),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3405] = {
    [sym_preproc_region] = STATE(3405),
    [sym_preproc_endregion] = STATE(3405),
    [sym_preproc_line] = STATE(3405),
    [sym_preproc_pragma] = STATE(3405),
    [sym_preproc_nullable] = STATE(3405),
    [sym_preproc_error] = STATE(3405),
    [sym_preproc_warning] = STATE(3405),
    [sym_preproc_define] = STATE(3405),
    [sym_preproc_undef] = STATE(3405),
    [sym__identifier_token] = ACTIONS(5147),
    [anon_sym_extern] = ACTIONS(5147),
    [anon_sym_alias] = ACTIONS(5147),
    [anon_sym_global] = ACTIONS(5147),
    [anon_sym_using] = ACTIONS(5147),
    [anon_sym_unsafe] = ACTIONS(5147),
    [anon_sym_static] = ACTIONS(5147),
    [anon_sym_LBRACK] = ACTIONS(5149),
    [anon_sym_LPAREN] = ACTIONS(5149),
    [anon_sym_event] = ACTIONS(5147),
    [anon_sym_namespace] = ACTIONS(5147),
    [anon_sym_class] = ACTIONS(5147),
    [anon_sym_ref] = ACTIONS(5147),
    [anon_sym_struct] = ACTIONS(5147),
    [anon_sym_enum] = ACTIONS(5147),
    [anon_sym_RBRACE] = ACTIONS(5149),
    [anon_sym_interface] = ACTIONS(5147),
    [anon_sym_delegate] = ACTIONS(5147),
    [anon_sym_record] = ACTIONS(5147),
    [anon_sym_abstract] = ACTIONS(5147),
    [anon_sym_async] = ACTIONS(5147),
    [anon_sym_const] = ACTIONS(5147),
    [anon_sym_file] = ACTIONS(5147),
    [anon_sym_fixed] = ACTIONS(5147),
    [anon_sym_internal] = ACTIONS(5147),
    [anon_sym_new] = ACTIONS(5147),
    [anon_sym_override] = ACTIONS(5147),
    [anon_sym_partial] = ACTIONS(5147),
    [anon_sym_private] = ACTIONS(5147),
    [anon_sym_protected] = ACTIONS(5147),
    [anon_sym_public] = ACTIONS(5147),
    [anon_sym_readonly] = ACTIONS(5147),
    [anon_sym_required] = ACTIONS(5147),
    [anon_sym_sealed] = ACTIONS(5147),
    [anon_sym_virtual] = ACTIONS(5147),
    [anon_sym_volatile] = ACTIONS(5147),
    [anon_sym_where] = ACTIONS(5147),
    [anon_sym_notnull] = ACTIONS(5147),
    [anon_sym_unmanaged] = ACTIONS(5147),
    [anon_sym_TILDE] = ACTIONS(5149),
    [anon_sym_implicit] = ACTIONS(5147),
    [anon_sym_explicit] = ACTIONS(5147),
    [anon_sym_scoped] = ACTIONS(5147),
    [anon_sym_var] = ACTIONS(5147),
    [sym_predefined_type] = ACTIONS(5147),
    [anon_sym_yield] = ACTIONS(5147),
    [anon_sym_when] = ACTIONS(5147),
    [anon_sym_from] = ACTIONS(5147),
    [anon_sym_into] = ACTIONS(5147),
    [anon_sym_join] = ACTIONS(5147),
    [anon_sym_on] = ACTIONS(5147),
    [anon_sym_equals] = ACTIONS(5147),
    [anon_sym_let] = ACTIONS(5147),
    [anon_sym_orderby] = ACTIONS(5147),
    [anon_sym_ascending] = ACTIONS(5147),
    [anon_sym_descending] = ACTIONS(5147),
    [anon_sym_group] = ACTIONS(5147),
    [anon_sym_by] = ACTIONS(5147),
    [anon_sym_select] = ACTIONS(5147),
    [aux_sym_preproc_if_token1] = ACTIONS(5149),
    [aux_sym_preproc_if_token3] = ACTIONS(5149),
    [aux_sym_preproc_else_token1] = ACTIONS(5149),
    [aux_sym_preproc_elif_token1] = ACTIONS(5149),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3406] = {
    [sym_preproc_region] = STATE(3406),
    [sym_preproc_endregion] = STATE(3406),
    [sym_preproc_line] = STATE(3406),
    [sym_preproc_pragma] = STATE(3406),
    [sym_preproc_nullable] = STATE(3406),
    [sym_preproc_error] = STATE(3406),
    [sym_preproc_warning] = STATE(3406),
    [sym_preproc_define] = STATE(3406),
    [sym_preproc_undef] = STATE(3406),
    [sym__identifier_token] = ACTIONS(5151),
    [anon_sym_extern] = ACTIONS(5151),
    [anon_sym_alias] = ACTIONS(5151),
    [anon_sym_global] = ACTIONS(5151),
    [anon_sym_using] = ACTIONS(5151),
    [anon_sym_unsafe] = ACTIONS(5151),
    [anon_sym_static] = ACTIONS(5151),
    [anon_sym_LBRACK] = ACTIONS(5153),
    [anon_sym_LPAREN] = ACTIONS(5153),
    [anon_sym_event] = ACTIONS(5151),
    [anon_sym_namespace] = ACTIONS(5151),
    [anon_sym_class] = ACTIONS(5151),
    [anon_sym_ref] = ACTIONS(5151),
    [anon_sym_struct] = ACTIONS(5151),
    [anon_sym_enum] = ACTIONS(5151),
    [anon_sym_RBRACE] = ACTIONS(5153),
    [anon_sym_interface] = ACTIONS(5151),
    [anon_sym_delegate] = ACTIONS(5151),
    [anon_sym_record] = ACTIONS(5151),
    [anon_sym_abstract] = ACTIONS(5151),
    [anon_sym_async] = ACTIONS(5151),
    [anon_sym_const] = ACTIONS(5151),
    [anon_sym_file] = ACTIONS(5151),
    [anon_sym_fixed] = ACTIONS(5151),
    [anon_sym_internal] = ACTIONS(5151),
    [anon_sym_new] = ACTIONS(5151),
    [anon_sym_override] = ACTIONS(5151),
    [anon_sym_partial] = ACTIONS(5151),
    [anon_sym_private] = ACTIONS(5151),
    [anon_sym_protected] = ACTIONS(5151),
    [anon_sym_public] = ACTIONS(5151),
    [anon_sym_readonly] = ACTIONS(5151),
    [anon_sym_required] = ACTIONS(5151),
    [anon_sym_sealed] = ACTIONS(5151),
    [anon_sym_virtual] = ACTIONS(5151),
    [anon_sym_volatile] = ACTIONS(5151),
    [anon_sym_where] = ACTIONS(5151),
    [anon_sym_notnull] = ACTIONS(5151),
    [anon_sym_unmanaged] = ACTIONS(5151),
    [anon_sym_TILDE] = ACTIONS(5153),
    [anon_sym_implicit] = ACTIONS(5151),
    [anon_sym_explicit] = ACTIONS(5151),
    [anon_sym_scoped] = ACTIONS(5151),
    [anon_sym_var] = ACTIONS(5151),
    [sym_predefined_type] = ACTIONS(5151),
    [anon_sym_yield] = ACTIONS(5151),
    [anon_sym_when] = ACTIONS(5151),
    [anon_sym_from] = ACTIONS(5151),
    [anon_sym_into] = ACTIONS(5151),
    [anon_sym_join] = ACTIONS(5151),
    [anon_sym_on] = ACTIONS(5151),
    [anon_sym_equals] = ACTIONS(5151),
    [anon_sym_let] = ACTIONS(5151),
    [anon_sym_orderby] = ACTIONS(5151),
    [anon_sym_ascending] = ACTIONS(5151),
    [anon_sym_descending] = ACTIONS(5151),
    [anon_sym_group] = ACTIONS(5151),
    [anon_sym_by] = ACTIONS(5151),
    [anon_sym_select] = ACTIONS(5151),
    [aux_sym_preproc_if_token1] = ACTIONS(5153),
    [aux_sym_preproc_if_token3] = ACTIONS(5153),
    [aux_sym_preproc_else_token1] = ACTIONS(5153),
    [aux_sym_preproc_elif_token1] = ACTIONS(5153),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3407] = {
    [sym__variable_designation] = STATE(4040),
    [sym_parenthesized_variable_designation] = STATE(3966),
    [sym_identifier] = STATE(3983),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3407),
    [sym_preproc_endregion] = STATE(3407),
    [sym_preproc_line] = STATE(3407),
    [sym_preproc_pragma] = STATE(3407),
    [sym_preproc_nullable] = STATE(3407),
    [sym_preproc_error] = STATE(3407),
    [sym_preproc_warning] = STATE(3407),
    [sym_preproc_define] = STATE(3407),
    [sym_preproc_undef] = STATE(3407),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4399),
    [anon_sym_LPAREN] = ACTIONS(4399),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4401),
    [anon_sym_GT] = ACTIONS(4401),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4401),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4401),
    [anon_sym_PLUS_PLUS] = ACTIONS(4399),
    [anon_sym_DASH_DASH] = ACTIONS(4399),
    [anon_sym_PLUS] = ACTIONS(4401),
    [anon_sym_DASH] = ACTIONS(4401),
    [anon_sym_STAR] = ACTIONS(4399),
    [anon_sym_SLASH] = ACTIONS(4401),
    [anon_sym_PERCENT] = ACTIONS(4399),
    [anon_sym_CARET] = ACTIONS(4399),
    [anon_sym_PIPE] = ACTIONS(4401),
    [anon_sym_AMP] = ACTIONS(4401),
    [anon_sym_LT_LT] = ACTIONS(4399),
    [anon_sym_GT_GT] = ACTIONS(4401),
    [anon_sym_GT_GT_GT] = ACTIONS(4399),
    [anon_sym_EQ_EQ] = ACTIONS(4399),
    [anon_sym_BANG_EQ] = ACTIONS(4399),
    [anon_sym_GT_EQ] = ACTIONS(4399),
    [anon_sym_LT_EQ] = ACTIONS(4399),
    [anon_sym_DOT] = ACTIONS(4401),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4401),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4347),
    [anon_sym_DOT_DOT] = ACTIONS(4399),
    [anon_sym_and] = ACTIONS(4401),
    [anon_sym_or] = ACTIONS(4401),
    [anon_sym_AMP_AMP] = ACTIONS(4399),
    [anon_sym_PIPE_PIPE] = ACTIONS(4399),
    [anon_sym_QMARK_QMARK] = ACTIONS(4399),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4401),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4401),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4401),
    [anon_sym_is] = ACTIONS(4401),
    [anon_sym_DASH_GT] = ACTIONS(4399),
    [anon_sym_with] = ACTIONS(4401),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3408] = {
    [sym_preproc_region] = STATE(3408),
    [sym_preproc_endregion] = STATE(3408),
    [sym_preproc_line] = STATE(3408),
    [sym_preproc_pragma] = STATE(3408),
    [sym_preproc_nullable] = STATE(3408),
    [sym_preproc_error] = STATE(3408),
    [sym_preproc_warning] = STATE(3408),
    [sym_preproc_define] = STATE(3408),
    [sym_preproc_undef] = STATE(3408),
    [sym__identifier_token] = ACTIONS(4470),
    [anon_sym_alias] = ACTIONS(4470),
    [anon_sym_global] = ACTIONS(4470),
    [anon_sym_LBRACK] = ACTIONS(4472),
    [anon_sym_COLON] = ACTIONS(4472),
    [anon_sym_COMMA] = ACTIONS(4472),
    [anon_sym_LPAREN] = ACTIONS(4472),
    [anon_sym_LBRACE] = ACTIONS(4472),
    [anon_sym_file] = ACTIONS(4470),
    [anon_sym_LT] = ACTIONS(4470),
    [anon_sym_GT] = ACTIONS(4470),
    [anon_sym_where] = ACTIONS(4470),
    [anon_sym_QMARK] = ACTIONS(4470),
    [anon_sym_notnull] = ACTIONS(4470),
    [anon_sym_unmanaged] = ACTIONS(4470),
    [anon_sym_BANG] = ACTIONS(4470),
    [anon_sym_PLUS_PLUS] = ACTIONS(4472),
    [anon_sym_DASH_DASH] = ACTIONS(4472),
    [anon_sym_PLUS] = ACTIONS(4470),
    [anon_sym_DASH] = ACTIONS(4470),
    [anon_sym_STAR] = ACTIONS(4472),
    [anon_sym_SLASH] = ACTIONS(4470),
    [anon_sym_PERCENT] = ACTIONS(4472),
    [anon_sym_CARET] = ACTIONS(4472),
    [anon_sym_PIPE] = ACTIONS(4470),
    [anon_sym_AMP] = ACTIONS(4470),
    [anon_sym_LT_LT] = ACTIONS(4472),
    [anon_sym_GT_GT] = ACTIONS(4470),
    [anon_sym_GT_GT_GT] = ACTIONS(4472),
    [anon_sym_EQ_EQ] = ACTIONS(4472),
    [anon_sym_BANG_EQ] = ACTIONS(4472),
    [anon_sym_GT_EQ] = ACTIONS(4472),
    [anon_sym_LT_EQ] = ACTIONS(4472),
    [anon_sym_DOT] = ACTIONS(4470),
    [anon_sym_scoped] = ACTIONS(4470),
    [anon_sym_var] = ACTIONS(4470),
    [anon_sym_yield] = ACTIONS(4470),
    [anon_sym_switch] = ACTIONS(4470),
    [anon_sym_when] = ACTIONS(4470),
    [sym_discard] = ACTIONS(4470),
    [anon_sym_DOT_DOT] = ACTIONS(4472),
    [anon_sym_and] = ACTIONS(4470),
    [anon_sym_or] = ACTIONS(4470),
    [anon_sym_AMP_AMP] = ACTIONS(4472),
    [anon_sym_PIPE_PIPE] = ACTIONS(4472),
    [anon_sym_QMARK_QMARK] = ACTIONS(4472),
    [anon_sym_from] = ACTIONS(4470),
    [anon_sym_into] = ACTIONS(4470),
    [anon_sym_join] = ACTIONS(4470),
    [anon_sym_on] = ACTIONS(4470),
    [anon_sym_equals] = ACTIONS(4470),
    [anon_sym_let] = ACTIONS(4470),
    [anon_sym_orderby] = ACTIONS(4470),
    [anon_sym_ascending] = ACTIONS(4470),
    [anon_sym_descending] = ACTIONS(4470),
    [anon_sym_group] = ACTIONS(4470),
    [anon_sym_by] = ACTIONS(4470),
    [anon_sym_select] = ACTIONS(4470),
    [anon_sym_as] = ACTIONS(4470),
    [anon_sym_is] = ACTIONS(4470),
    [anon_sym_DASH_GT] = ACTIONS(4472),
    [anon_sym_with] = ACTIONS(4470),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4472),
  },
  [3409] = {
    [sym__variable_designation] = STATE(4043),
    [sym_parenthesized_variable_designation] = STATE(3966),
    [sym_identifier] = STATE(3983),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3409),
    [sym_preproc_endregion] = STATE(3409),
    [sym_preproc_line] = STATE(3409),
    [sym_preproc_pragma] = STATE(3409),
    [sym_preproc_nullable] = STATE(3409),
    [sym_preproc_error] = STATE(3409),
    [sym_preproc_warning] = STATE(3409),
    [sym_preproc_define] = STATE(3409),
    [sym_preproc_undef] = STATE(3409),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4405),
    [anon_sym_LPAREN] = ACTIONS(4405),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4407),
    [anon_sym_GT] = ACTIONS(4407),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4407),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4407),
    [anon_sym_PLUS_PLUS] = ACTIONS(4405),
    [anon_sym_DASH_DASH] = ACTIONS(4405),
    [anon_sym_PLUS] = ACTIONS(4407),
    [anon_sym_DASH] = ACTIONS(4407),
    [anon_sym_STAR] = ACTIONS(4405),
    [anon_sym_SLASH] = ACTIONS(4407),
    [anon_sym_PERCENT] = ACTIONS(4405),
    [anon_sym_CARET] = ACTIONS(4405),
    [anon_sym_PIPE] = ACTIONS(4407),
    [anon_sym_AMP] = ACTIONS(4407),
    [anon_sym_LT_LT] = ACTIONS(4405),
    [anon_sym_GT_GT] = ACTIONS(4407),
    [anon_sym_GT_GT_GT] = ACTIONS(4405),
    [anon_sym_EQ_EQ] = ACTIONS(4405),
    [anon_sym_BANG_EQ] = ACTIONS(4405),
    [anon_sym_GT_EQ] = ACTIONS(4405),
    [anon_sym_LT_EQ] = ACTIONS(4405),
    [anon_sym_DOT] = ACTIONS(4407),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4407),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4347),
    [anon_sym_DOT_DOT] = ACTIONS(4405),
    [anon_sym_and] = ACTIONS(4407),
    [anon_sym_or] = ACTIONS(4407),
    [anon_sym_AMP_AMP] = ACTIONS(4405),
    [anon_sym_PIPE_PIPE] = ACTIONS(4405),
    [anon_sym_QMARK_QMARK] = ACTIONS(4405),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4407),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4407),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4407),
    [anon_sym_is] = ACTIONS(4407),
    [anon_sym_DASH_GT] = ACTIONS(4405),
    [anon_sym_with] = ACTIONS(4407),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3410] = {
    [sym__variable_designation] = STATE(4065),
    [sym_parenthesized_variable_designation] = STATE(3966),
    [sym_identifier] = STATE(3983),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3410),
    [sym_preproc_endregion] = STATE(3410),
    [sym_preproc_line] = STATE(3410),
    [sym_preproc_pragma] = STATE(3410),
    [sym_preproc_nullable] = STATE(3410),
    [sym_preproc_error] = STATE(3410),
    [sym_preproc_warning] = STATE(3410),
    [sym_preproc_define] = STATE(3410),
    [sym_preproc_undef] = STATE(3410),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4437),
    [anon_sym_LPAREN] = ACTIONS(4437),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4439),
    [anon_sym_GT] = ACTIONS(4439),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4439),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4439),
    [anon_sym_PLUS_PLUS] = ACTIONS(4437),
    [anon_sym_DASH_DASH] = ACTIONS(4437),
    [anon_sym_PLUS] = ACTIONS(4439),
    [anon_sym_DASH] = ACTIONS(4439),
    [anon_sym_STAR] = ACTIONS(4437),
    [anon_sym_SLASH] = ACTIONS(4439),
    [anon_sym_PERCENT] = ACTIONS(4437),
    [anon_sym_CARET] = ACTIONS(4437),
    [anon_sym_PIPE] = ACTIONS(4439),
    [anon_sym_AMP] = ACTIONS(4439),
    [anon_sym_LT_LT] = ACTIONS(4437),
    [anon_sym_GT_GT] = ACTIONS(4439),
    [anon_sym_GT_GT_GT] = ACTIONS(4437),
    [anon_sym_EQ_EQ] = ACTIONS(4437),
    [anon_sym_BANG_EQ] = ACTIONS(4437),
    [anon_sym_GT_EQ] = ACTIONS(4437),
    [anon_sym_LT_EQ] = ACTIONS(4437),
    [anon_sym_DOT] = ACTIONS(4439),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4439),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4347),
    [anon_sym_DOT_DOT] = ACTIONS(4437),
    [anon_sym_and] = ACTIONS(4439),
    [anon_sym_or] = ACTIONS(4439),
    [anon_sym_AMP_AMP] = ACTIONS(4437),
    [anon_sym_PIPE_PIPE] = ACTIONS(4437),
    [anon_sym_QMARK_QMARK] = ACTIONS(4437),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4439),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4439),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4439),
    [anon_sym_is] = ACTIONS(4439),
    [anon_sym_DASH_GT] = ACTIONS(4437),
    [anon_sym_with] = ACTIONS(4439),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3411] = {
    [sym__variable_designation] = STATE(3957),
    [sym_parenthesized_variable_designation] = STATE(3966),
    [sym_identifier] = STATE(3983),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3411),
    [sym_preproc_endregion] = STATE(3411),
    [sym_preproc_line] = STATE(3411),
    [sym_preproc_pragma] = STATE(3411),
    [sym_preproc_nullable] = STATE(3411),
    [sym_preproc_error] = STATE(3411),
    [sym_preproc_warning] = STATE(3411),
    [sym_preproc_define] = STATE(3411),
    [sym_preproc_undef] = STATE(3411),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4441),
    [anon_sym_LPAREN] = ACTIONS(4441),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4443),
    [anon_sym_GT] = ACTIONS(4443),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4443),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4443),
    [anon_sym_PLUS_PLUS] = ACTIONS(4441),
    [anon_sym_DASH_DASH] = ACTIONS(4441),
    [anon_sym_PLUS] = ACTIONS(4443),
    [anon_sym_DASH] = ACTIONS(4443),
    [anon_sym_STAR] = ACTIONS(4441),
    [anon_sym_SLASH] = ACTIONS(4443),
    [anon_sym_PERCENT] = ACTIONS(4441),
    [anon_sym_CARET] = ACTIONS(4441),
    [anon_sym_PIPE] = ACTIONS(4443),
    [anon_sym_AMP] = ACTIONS(4443),
    [anon_sym_LT_LT] = ACTIONS(4441),
    [anon_sym_GT_GT] = ACTIONS(4443),
    [anon_sym_GT_GT_GT] = ACTIONS(4441),
    [anon_sym_EQ_EQ] = ACTIONS(4441),
    [anon_sym_BANG_EQ] = ACTIONS(4441),
    [anon_sym_GT_EQ] = ACTIONS(4441),
    [anon_sym_LT_EQ] = ACTIONS(4441),
    [anon_sym_DOT] = ACTIONS(4443),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4443),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4347),
    [anon_sym_DOT_DOT] = ACTIONS(4441),
    [anon_sym_and] = ACTIONS(4443),
    [anon_sym_or] = ACTIONS(4443),
    [anon_sym_AMP_AMP] = ACTIONS(4441),
    [anon_sym_PIPE_PIPE] = ACTIONS(4441),
    [anon_sym_QMARK_QMARK] = ACTIONS(4441),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4443),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4443),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4443),
    [anon_sym_is] = ACTIONS(4443),
    [anon_sym_DASH_GT] = ACTIONS(4441),
    [anon_sym_with] = ACTIONS(4443),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3412] = {
    [sym_preproc_region] = STATE(3412),
    [sym_preproc_endregion] = STATE(3412),
    [sym_preproc_line] = STATE(3412),
    [sym_preproc_pragma] = STATE(3412),
    [sym_preproc_nullable] = STATE(3412),
    [sym_preproc_error] = STATE(3412),
    [sym_preproc_warning] = STATE(3412),
    [sym_preproc_define] = STATE(3412),
    [sym_preproc_undef] = STATE(3412),
    [sym__identifier_token] = ACTIONS(5155),
    [anon_sym_extern] = ACTIONS(5155),
    [anon_sym_alias] = ACTIONS(5155),
    [anon_sym_global] = ACTIONS(5155),
    [anon_sym_using] = ACTIONS(5155),
    [anon_sym_unsafe] = ACTIONS(5155),
    [anon_sym_static] = ACTIONS(5155),
    [anon_sym_LBRACK] = ACTIONS(5157),
    [anon_sym_LPAREN] = ACTIONS(5157),
    [anon_sym_event] = ACTIONS(5155),
    [anon_sym_namespace] = ACTIONS(5155),
    [anon_sym_class] = ACTIONS(5155),
    [anon_sym_ref] = ACTIONS(5155),
    [anon_sym_struct] = ACTIONS(5155),
    [anon_sym_enum] = ACTIONS(5155),
    [anon_sym_RBRACE] = ACTIONS(5157),
    [anon_sym_interface] = ACTIONS(5155),
    [anon_sym_delegate] = ACTIONS(5155),
    [anon_sym_record] = ACTIONS(5155),
    [anon_sym_abstract] = ACTIONS(5155),
    [anon_sym_async] = ACTIONS(5155),
    [anon_sym_const] = ACTIONS(5155),
    [anon_sym_file] = ACTIONS(5155),
    [anon_sym_fixed] = ACTIONS(5155),
    [anon_sym_internal] = ACTIONS(5155),
    [anon_sym_new] = ACTIONS(5155),
    [anon_sym_override] = ACTIONS(5155),
    [anon_sym_partial] = ACTIONS(5155),
    [anon_sym_private] = ACTIONS(5155),
    [anon_sym_protected] = ACTIONS(5155),
    [anon_sym_public] = ACTIONS(5155),
    [anon_sym_readonly] = ACTIONS(5155),
    [anon_sym_required] = ACTIONS(5155),
    [anon_sym_sealed] = ACTIONS(5155),
    [anon_sym_virtual] = ACTIONS(5155),
    [anon_sym_volatile] = ACTIONS(5155),
    [anon_sym_where] = ACTIONS(5155),
    [anon_sym_notnull] = ACTIONS(5155),
    [anon_sym_unmanaged] = ACTIONS(5155),
    [anon_sym_TILDE] = ACTIONS(5157),
    [anon_sym_implicit] = ACTIONS(5155),
    [anon_sym_explicit] = ACTIONS(5155),
    [anon_sym_scoped] = ACTIONS(5155),
    [anon_sym_var] = ACTIONS(5155),
    [sym_predefined_type] = ACTIONS(5155),
    [anon_sym_yield] = ACTIONS(5155),
    [anon_sym_when] = ACTIONS(5155),
    [anon_sym_from] = ACTIONS(5155),
    [anon_sym_into] = ACTIONS(5155),
    [anon_sym_join] = ACTIONS(5155),
    [anon_sym_on] = ACTIONS(5155),
    [anon_sym_equals] = ACTIONS(5155),
    [anon_sym_let] = ACTIONS(5155),
    [anon_sym_orderby] = ACTIONS(5155),
    [anon_sym_ascending] = ACTIONS(5155),
    [anon_sym_descending] = ACTIONS(5155),
    [anon_sym_group] = ACTIONS(5155),
    [anon_sym_by] = ACTIONS(5155),
    [anon_sym_select] = ACTIONS(5155),
    [aux_sym_preproc_if_token1] = ACTIONS(5157),
    [aux_sym_preproc_if_token3] = ACTIONS(5157),
    [aux_sym_preproc_else_token1] = ACTIONS(5157),
    [aux_sym_preproc_elif_token1] = ACTIONS(5157),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3413] = {
    [sym_preproc_region] = STATE(3413),
    [sym_preproc_endregion] = STATE(3413),
    [sym_preproc_line] = STATE(3413),
    [sym_preproc_pragma] = STATE(3413),
    [sym_preproc_nullable] = STATE(3413),
    [sym_preproc_error] = STATE(3413),
    [sym_preproc_warning] = STATE(3413),
    [sym_preproc_define] = STATE(3413),
    [sym_preproc_undef] = STATE(3413),
    [sym__identifier_token] = ACTIONS(5159),
    [anon_sym_extern] = ACTIONS(5159),
    [anon_sym_alias] = ACTIONS(5159),
    [anon_sym_global] = ACTIONS(5159),
    [anon_sym_using] = ACTIONS(5159),
    [anon_sym_unsafe] = ACTIONS(5159),
    [anon_sym_static] = ACTIONS(5159),
    [anon_sym_LBRACK] = ACTIONS(5161),
    [anon_sym_LPAREN] = ACTIONS(5161),
    [anon_sym_event] = ACTIONS(5159),
    [anon_sym_namespace] = ACTIONS(5159),
    [anon_sym_class] = ACTIONS(5159),
    [anon_sym_ref] = ACTIONS(5159),
    [anon_sym_struct] = ACTIONS(5159),
    [anon_sym_enum] = ACTIONS(5159),
    [anon_sym_RBRACE] = ACTIONS(5161),
    [anon_sym_interface] = ACTIONS(5159),
    [anon_sym_delegate] = ACTIONS(5159),
    [anon_sym_record] = ACTIONS(5159),
    [anon_sym_abstract] = ACTIONS(5159),
    [anon_sym_async] = ACTIONS(5159),
    [anon_sym_const] = ACTIONS(5159),
    [anon_sym_file] = ACTIONS(5159),
    [anon_sym_fixed] = ACTIONS(5159),
    [anon_sym_internal] = ACTIONS(5159),
    [anon_sym_new] = ACTIONS(5159),
    [anon_sym_override] = ACTIONS(5159),
    [anon_sym_partial] = ACTIONS(5159),
    [anon_sym_private] = ACTIONS(5159),
    [anon_sym_protected] = ACTIONS(5159),
    [anon_sym_public] = ACTIONS(5159),
    [anon_sym_readonly] = ACTIONS(5159),
    [anon_sym_required] = ACTIONS(5159),
    [anon_sym_sealed] = ACTIONS(5159),
    [anon_sym_virtual] = ACTIONS(5159),
    [anon_sym_volatile] = ACTIONS(5159),
    [anon_sym_where] = ACTIONS(5159),
    [anon_sym_notnull] = ACTIONS(5159),
    [anon_sym_unmanaged] = ACTIONS(5159),
    [anon_sym_TILDE] = ACTIONS(5161),
    [anon_sym_implicit] = ACTIONS(5159),
    [anon_sym_explicit] = ACTIONS(5159),
    [anon_sym_scoped] = ACTIONS(5159),
    [anon_sym_var] = ACTIONS(5159),
    [sym_predefined_type] = ACTIONS(5159),
    [anon_sym_yield] = ACTIONS(5159),
    [anon_sym_when] = ACTIONS(5159),
    [anon_sym_from] = ACTIONS(5159),
    [anon_sym_into] = ACTIONS(5159),
    [anon_sym_join] = ACTIONS(5159),
    [anon_sym_on] = ACTIONS(5159),
    [anon_sym_equals] = ACTIONS(5159),
    [anon_sym_let] = ACTIONS(5159),
    [anon_sym_orderby] = ACTIONS(5159),
    [anon_sym_ascending] = ACTIONS(5159),
    [anon_sym_descending] = ACTIONS(5159),
    [anon_sym_group] = ACTIONS(5159),
    [anon_sym_by] = ACTIONS(5159),
    [anon_sym_select] = ACTIONS(5159),
    [aux_sym_preproc_if_token1] = ACTIONS(5161),
    [aux_sym_preproc_if_token3] = ACTIONS(5161),
    [aux_sym_preproc_else_token1] = ACTIONS(5161),
    [aux_sym_preproc_elif_token1] = ACTIONS(5161),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3414] = {
    [sym_preproc_region] = STATE(3414),
    [sym_preproc_endregion] = STATE(3414),
    [sym_preproc_line] = STATE(3414),
    [sym_preproc_pragma] = STATE(3414),
    [sym_preproc_nullable] = STATE(3414),
    [sym_preproc_error] = STATE(3414),
    [sym_preproc_warning] = STATE(3414),
    [sym_preproc_define] = STATE(3414),
    [sym_preproc_undef] = STATE(3414),
    [sym__identifier_token] = ACTIONS(5163),
    [anon_sym_extern] = ACTIONS(5163),
    [anon_sym_alias] = ACTIONS(5163),
    [anon_sym_global] = ACTIONS(5163),
    [anon_sym_using] = ACTIONS(5163),
    [anon_sym_unsafe] = ACTIONS(5163),
    [anon_sym_static] = ACTIONS(5163),
    [anon_sym_LBRACK] = ACTIONS(5165),
    [anon_sym_LPAREN] = ACTIONS(5165),
    [anon_sym_event] = ACTIONS(5163),
    [anon_sym_namespace] = ACTIONS(5163),
    [anon_sym_class] = ACTIONS(5163),
    [anon_sym_ref] = ACTIONS(5163),
    [anon_sym_struct] = ACTIONS(5163),
    [anon_sym_enum] = ACTIONS(5163),
    [anon_sym_RBRACE] = ACTIONS(5165),
    [anon_sym_interface] = ACTIONS(5163),
    [anon_sym_delegate] = ACTIONS(5163),
    [anon_sym_record] = ACTIONS(5163),
    [anon_sym_abstract] = ACTIONS(5163),
    [anon_sym_async] = ACTIONS(5163),
    [anon_sym_const] = ACTIONS(5163),
    [anon_sym_file] = ACTIONS(5163),
    [anon_sym_fixed] = ACTIONS(5163),
    [anon_sym_internal] = ACTIONS(5163),
    [anon_sym_new] = ACTIONS(5163),
    [anon_sym_override] = ACTIONS(5163),
    [anon_sym_partial] = ACTIONS(5163),
    [anon_sym_private] = ACTIONS(5163),
    [anon_sym_protected] = ACTIONS(5163),
    [anon_sym_public] = ACTIONS(5163),
    [anon_sym_readonly] = ACTIONS(5163),
    [anon_sym_required] = ACTIONS(5163),
    [anon_sym_sealed] = ACTIONS(5163),
    [anon_sym_virtual] = ACTIONS(5163),
    [anon_sym_volatile] = ACTIONS(5163),
    [anon_sym_where] = ACTIONS(5163),
    [anon_sym_notnull] = ACTIONS(5163),
    [anon_sym_unmanaged] = ACTIONS(5163),
    [anon_sym_TILDE] = ACTIONS(5165),
    [anon_sym_implicit] = ACTIONS(5163),
    [anon_sym_explicit] = ACTIONS(5163),
    [anon_sym_scoped] = ACTIONS(5163),
    [anon_sym_var] = ACTIONS(5163),
    [sym_predefined_type] = ACTIONS(5163),
    [anon_sym_yield] = ACTIONS(5163),
    [anon_sym_when] = ACTIONS(5163),
    [anon_sym_from] = ACTIONS(5163),
    [anon_sym_into] = ACTIONS(5163),
    [anon_sym_join] = ACTIONS(5163),
    [anon_sym_on] = ACTIONS(5163),
    [anon_sym_equals] = ACTIONS(5163),
    [anon_sym_let] = ACTIONS(5163),
    [anon_sym_orderby] = ACTIONS(5163),
    [anon_sym_ascending] = ACTIONS(5163),
    [anon_sym_descending] = ACTIONS(5163),
    [anon_sym_group] = ACTIONS(5163),
    [anon_sym_by] = ACTIONS(5163),
    [anon_sym_select] = ACTIONS(5163),
    [aux_sym_preproc_if_token1] = ACTIONS(5165),
    [aux_sym_preproc_if_token3] = ACTIONS(5165),
    [aux_sym_preproc_else_token1] = ACTIONS(5165),
    [aux_sym_preproc_elif_token1] = ACTIONS(5165),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3415] = {
    [sym_preproc_region] = STATE(3415),
    [sym_preproc_endregion] = STATE(3415),
    [sym_preproc_line] = STATE(3415),
    [sym_preproc_pragma] = STATE(3415),
    [sym_preproc_nullable] = STATE(3415),
    [sym_preproc_error] = STATE(3415),
    [sym_preproc_warning] = STATE(3415),
    [sym_preproc_define] = STATE(3415),
    [sym_preproc_undef] = STATE(3415),
    [sym__identifier_token] = ACTIONS(5167),
    [anon_sym_extern] = ACTIONS(5167),
    [anon_sym_alias] = ACTIONS(5167),
    [anon_sym_global] = ACTIONS(5167),
    [anon_sym_using] = ACTIONS(5167),
    [anon_sym_unsafe] = ACTIONS(5167),
    [anon_sym_static] = ACTIONS(5167),
    [anon_sym_LBRACK] = ACTIONS(5169),
    [anon_sym_LPAREN] = ACTIONS(5169),
    [anon_sym_event] = ACTIONS(5167),
    [anon_sym_namespace] = ACTIONS(5167),
    [anon_sym_class] = ACTIONS(5167),
    [anon_sym_ref] = ACTIONS(5167),
    [anon_sym_struct] = ACTIONS(5167),
    [anon_sym_enum] = ACTIONS(5167),
    [anon_sym_RBRACE] = ACTIONS(5169),
    [anon_sym_interface] = ACTIONS(5167),
    [anon_sym_delegate] = ACTIONS(5167),
    [anon_sym_record] = ACTIONS(5167),
    [anon_sym_abstract] = ACTIONS(5167),
    [anon_sym_async] = ACTIONS(5167),
    [anon_sym_const] = ACTIONS(5167),
    [anon_sym_file] = ACTIONS(5167),
    [anon_sym_fixed] = ACTIONS(5167),
    [anon_sym_internal] = ACTIONS(5167),
    [anon_sym_new] = ACTIONS(5167),
    [anon_sym_override] = ACTIONS(5167),
    [anon_sym_partial] = ACTIONS(5167),
    [anon_sym_private] = ACTIONS(5167),
    [anon_sym_protected] = ACTIONS(5167),
    [anon_sym_public] = ACTIONS(5167),
    [anon_sym_readonly] = ACTIONS(5167),
    [anon_sym_required] = ACTIONS(5167),
    [anon_sym_sealed] = ACTIONS(5167),
    [anon_sym_virtual] = ACTIONS(5167),
    [anon_sym_volatile] = ACTIONS(5167),
    [anon_sym_where] = ACTIONS(5167),
    [anon_sym_notnull] = ACTIONS(5167),
    [anon_sym_unmanaged] = ACTIONS(5167),
    [anon_sym_TILDE] = ACTIONS(5169),
    [anon_sym_implicit] = ACTIONS(5167),
    [anon_sym_explicit] = ACTIONS(5167),
    [anon_sym_scoped] = ACTIONS(5167),
    [anon_sym_var] = ACTIONS(5167),
    [sym_predefined_type] = ACTIONS(5167),
    [anon_sym_yield] = ACTIONS(5167),
    [anon_sym_when] = ACTIONS(5167),
    [anon_sym_from] = ACTIONS(5167),
    [anon_sym_into] = ACTIONS(5167),
    [anon_sym_join] = ACTIONS(5167),
    [anon_sym_on] = ACTIONS(5167),
    [anon_sym_equals] = ACTIONS(5167),
    [anon_sym_let] = ACTIONS(5167),
    [anon_sym_orderby] = ACTIONS(5167),
    [anon_sym_ascending] = ACTIONS(5167),
    [anon_sym_descending] = ACTIONS(5167),
    [anon_sym_group] = ACTIONS(5167),
    [anon_sym_by] = ACTIONS(5167),
    [anon_sym_select] = ACTIONS(5167),
    [aux_sym_preproc_if_token1] = ACTIONS(5169),
    [aux_sym_preproc_if_token3] = ACTIONS(5169),
    [aux_sym_preproc_else_token1] = ACTIONS(5169),
    [aux_sym_preproc_elif_token1] = ACTIONS(5169),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3416] = {
    [sym_preproc_region] = STATE(3416),
    [sym_preproc_endregion] = STATE(3416),
    [sym_preproc_line] = STATE(3416),
    [sym_preproc_pragma] = STATE(3416),
    [sym_preproc_nullable] = STATE(3416),
    [sym_preproc_error] = STATE(3416),
    [sym_preproc_warning] = STATE(3416),
    [sym_preproc_define] = STATE(3416),
    [sym_preproc_undef] = STATE(3416),
    [sym__identifier_token] = ACTIONS(5171),
    [anon_sym_extern] = ACTIONS(5171),
    [anon_sym_alias] = ACTIONS(5171),
    [anon_sym_global] = ACTIONS(5171),
    [anon_sym_using] = ACTIONS(5171),
    [anon_sym_unsafe] = ACTIONS(5171),
    [anon_sym_static] = ACTIONS(5171),
    [anon_sym_LBRACK] = ACTIONS(5173),
    [anon_sym_LPAREN] = ACTIONS(5173),
    [anon_sym_event] = ACTIONS(5171),
    [anon_sym_namespace] = ACTIONS(5171),
    [anon_sym_class] = ACTIONS(5171),
    [anon_sym_ref] = ACTIONS(5171),
    [anon_sym_struct] = ACTIONS(5171),
    [anon_sym_enum] = ACTIONS(5171),
    [anon_sym_RBRACE] = ACTIONS(5173),
    [anon_sym_interface] = ACTIONS(5171),
    [anon_sym_delegate] = ACTIONS(5171),
    [anon_sym_record] = ACTIONS(5171),
    [anon_sym_abstract] = ACTIONS(5171),
    [anon_sym_async] = ACTIONS(5171),
    [anon_sym_const] = ACTIONS(5171),
    [anon_sym_file] = ACTIONS(5171),
    [anon_sym_fixed] = ACTIONS(5171),
    [anon_sym_internal] = ACTIONS(5171),
    [anon_sym_new] = ACTIONS(5171),
    [anon_sym_override] = ACTIONS(5171),
    [anon_sym_partial] = ACTIONS(5171),
    [anon_sym_private] = ACTIONS(5171),
    [anon_sym_protected] = ACTIONS(5171),
    [anon_sym_public] = ACTIONS(5171),
    [anon_sym_readonly] = ACTIONS(5171),
    [anon_sym_required] = ACTIONS(5171),
    [anon_sym_sealed] = ACTIONS(5171),
    [anon_sym_virtual] = ACTIONS(5171),
    [anon_sym_volatile] = ACTIONS(5171),
    [anon_sym_where] = ACTIONS(5171),
    [anon_sym_notnull] = ACTIONS(5171),
    [anon_sym_unmanaged] = ACTIONS(5171),
    [anon_sym_TILDE] = ACTIONS(5173),
    [anon_sym_implicit] = ACTIONS(5171),
    [anon_sym_explicit] = ACTIONS(5171),
    [anon_sym_scoped] = ACTIONS(5171),
    [anon_sym_var] = ACTIONS(5171),
    [sym_predefined_type] = ACTIONS(5171),
    [anon_sym_yield] = ACTIONS(5171),
    [anon_sym_when] = ACTIONS(5171),
    [anon_sym_from] = ACTIONS(5171),
    [anon_sym_into] = ACTIONS(5171),
    [anon_sym_join] = ACTIONS(5171),
    [anon_sym_on] = ACTIONS(5171),
    [anon_sym_equals] = ACTIONS(5171),
    [anon_sym_let] = ACTIONS(5171),
    [anon_sym_orderby] = ACTIONS(5171),
    [anon_sym_ascending] = ACTIONS(5171),
    [anon_sym_descending] = ACTIONS(5171),
    [anon_sym_group] = ACTIONS(5171),
    [anon_sym_by] = ACTIONS(5171),
    [anon_sym_select] = ACTIONS(5171),
    [aux_sym_preproc_if_token1] = ACTIONS(5173),
    [aux_sym_preproc_if_token3] = ACTIONS(5173),
    [aux_sym_preproc_else_token1] = ACTIONS(5173),
    [aux_sym_preproc_elif_token1] = ACTIONS(5173),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3417] = {
    [sym_preproc_region] = STATE(3417),
    [sym_preproc_endregion] = STATE(3417),
    [sym_preproc_line] = STATE(3417),
    [sym_preproc_pragma] = STATE(3417),
    [sym_preproc_nullable] = STATE(3417),
    [sym_preproc_error] = STATE(3417),
    [sym_preproc_warning] = STATE(3417),
    [sym_preproc_define] = STATE(3417),
    [sym_preproc_undef] = STATE(3417),
    [sym__identifier_token] = ACTIONS(5175),
    [anon_sym_extern] = ACTIONS(5175),
    [anon_sym_alias] = ACTIONS(5175),
    [anon_sym_global] = ACTIONS(5175),
    [anon_sym_using] = ACTIONS(5175),
    [anon_sym_unsafe] = ACTIONS(5175),
    [anon_sym_static] = ACTIONS(5175),
    [anon_sym_LBRACK] = ACTIONS(5177),
    [anon_sym_LPAREN] = ACTIONS(5177),
    [anon_sym_event] = ACTIONS(5175),
    [anon_sym_namespace] = ACTIONS(5175),
    [anon_sym_class] = ACTIONS(5175),
    [anon_sym_ref] = ACTIONS(5175),
    [anon_sym_struct] = ACTIONS(5175),
    [anon_sym_enum] = ACTIONS(5175),
    [anon_sym_RBRACE] = ACTIONS(5177),
    [anon_sym_interface] = ACTIONS(5175),
    [anon_sym_delegate] = ACTIONS(5175),
    [anon_sym_record] = ACTIONS(5175),
    [anon_sym_abstract] = ACTIONS(5175),
    [anon_sym_async] = ACTIONS(5175),
    [anon_sym_const] = ACTIONS(5175),
    [anon_sym_file] = ACTIONS(5175),
    [anon_sym_fixed] = ACTIONS(5175),
    [anon_sym_internal] = ACTIONS(5175),
    [anon_sym_new] = ACTIONS(5175),
    [anon_sym_override] = ACTIONS(5175),
    [anon_sym_partial] = ACTIONS(5175),
    [anon_sym_private] = ACTIONS(5175),
    [anon_sym_protected] = ACTIONS(5175),
    [anon_sym_public] = ACTIONS(5175),
    [anon_sym_readonly] = ACTIONS(5175),
    [anon_sym_required] = ACTIONS(5175),
    [anon_sym_sealed] = ACTIONS(5175),
    [anon_sym_virtual] = ACTIONS(5175),
    [anon_sym_volatile] = ACTIONS(5175),
    [anon_sym_where] = ACTIONS(5175),
    [anon_sym_notnull] = ACTIONS(5175),
    [anon_sym_unmanaged] = ACTIONS(5175),
    [anon_sym_TILDE] = ACTIONS(5177),
    [anon_sym_implicit] = ACTIONS(5175),
    [anon_sym_explicit] = ACTIONS(5175),
    [anon_sym_scoped] = ACTIONS(5175),
    [anon_sym_var] = ACTIONS(5175),
    [sym_predefined_type] = ACTIONS(5175),
    [anon_sym_yield] = ACTIONS(5175),
    [anon_sym_when] = ACTIONS(5175),
    [anon_sym_from] = ACTIONS(5175),
    [anon_sym_into] = ACTIONS(5175),
    [anon_sym_join] = ACTIONS(5175),
    [anon_sym_on] = ACTIONS(5175),
    [anon_sym_equals] = ACTIONS(5175),
    [anon_sym_let] = ACTIONS(5175),
    [anon_sym_orderby] = ACTIONS(5175),
    [anon_sym_ascending] = ACTIONS(5175),
    [anon_sym_descending] = ACTIONS(5175),
    [anon_sym_group] = ACTIONS(5175),
    [anon_sym_by] = ACTIONS(5175),
    [anon_sym_select] = ACTIONS(5175),
    [aux_sym_preproc_if_token1] = ACTIONS(5177),
    [aux_sym_preproc_if_token3] = ACTIONS(5177),
    [aux_sym_preproc_else_token1] = ACTIONS(5177),
    [aux_sym_preproc_elif_token1] = ACTIONS(5177),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3418] = {
    [sym_preproc_region] = STATE(3418),
    [sym_preproc_endregion] = STATE(3418),
    [sym_preproc_line] = STATE(3418),
    [sym_preproc_pragma] = STATE(3418),
    [sym_preproc_nullable] = STATE(3418),
    [sym_preproc_error] = STATE(3418),
    [sym_preproc_warning] = STATE(3418),
    [sym_preproc_define] = STATE(3418),
    [sym_preproc_undef] = STATE(3418),
    [sym__identifier_token] = ACTIONS(5179),
    [anon_sym_extern] = ACTIONS(5179),
    [anon_sym_alias] = ACTIONS(5179),
    [anon_sym_global] = ACTIONS(5179),
    [anon_sym_using] = ACTIONS(5179),
    [anon_sym_unsafe] = ACTIONS(5179),
    [anon_sym_static] = ACTIONS(5179),
    [anon_sym_LBRACK] = ACTIONS(5181),
    [anon_sym_LPAREN] = ACTIONS(5181),
    [anon_sym_event] = ACTIONS(5179),
    [anon_sym_namespace] = ACTIONS(5179),
    [anon_sym_class] = ACTIONS(5179),
    [anon_sym_ref] = ACTIONS(5179),
    [anon_sym_struct] = ACTIONS(5179),
    [anon_sym_enum] = ACTIONS(5179),
    [anon_sym_RBRACE] = ACTIONS(5181),
    [anon_sym_interface] = ACTIONS(5179),
    [anon_sym_delegate] = ACTIONS(5179),
    [anon_sym_record] = ACTIONS(5179),
    [anon_sym_abstract] = ACTIONS(5179),
    [anon_sym_async] = ACTIONS(5179),
    [anon_sym_const] = ACTIONS(5179),
    [anon_sym_file] = ACTIONS(5179),
    [anon_sym_fixed] = ACTIONS(5179),
    [anon_sym_internal] = ACTIONS(5179),
    [anon_sym_new] = ACTIONS(5179),
    [anon_sym_override] = ACTIONS(5179),
    [anon_sym_partial] = ACTIONS(5179),
    [anon_sym_private] = ACTIONS(5179),
    [anon_sym_protected] = ACTIONS(5179),
    [anon_sym_public] = ACTIONS(5179),
    [anon_sym_readonly] = ACTIONS(5179),
    [anon_sym_required] = ACTIONS(5179),
    [anon_sym_sealed] = ACTIONS(5179),
    [anon_sym_virtual] = ACTIONS(5179),
    [anon_sym_volatile] = ACTIONS(5179),
    [anon_sym_where] = ACTIONS(5179),
    [anon_sym_notnull] = ACTIONS(5179),
    [anon_sym_unmanaged] = ACTIONS(5179),
    [anon_sym_TILDE] = ACTIONS(5181),
    [anon_sym_implicit] = ACTIONS(5179),
    [anon_sym_explicit] = ACTIONS(5179),
    [anon_sym_scoped] = ACTIONS(5179),
    [anon_sym_var] = ACTIONS(5179),
    [sym_predefined_type] = ACTIONS(5179),
    [anon_sym_yield] = ACTIONS(5179),
    [anon_sym_when] = ACTIONS(5179),
    [anon_sym_from] = ACTIONS(5179),
    [anon_sym_into] = ACTIONS(5179),
    [anon_sym_join] = ACTIONS(5179),
    [anon_sym_on] = ACTIONS(5179),
    [anon_sym_equals] = ACTIONS(5179),
    [anon_sym_let] = ACTIONS(5179),
    [anon_sym_orderby] = ACTIONS(5179),
    [anon_sym_ascending] = ACTIONS(5179),
    [anon_sym_descending] = ACTIONS(5179),
    [anon_sym_group] = ACTIONS(5179),
    [anon_sym_by] = ACTIONS(5179),
    [anon_sym_select] = ACTIONS(5179),
    [aux_sym_preproc_if_token1] = ACTIONS(5181),
    [aux_sym_preproc_if_token3] = ACTIONS(5181),
    [aux_sym_preproc_else_token1] = ACTIONS(5181),
    [aux_sym_preproc_elif_token1] = ACTIONS(5181),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3419] = {
    [sym_preproc_region] = STATE(3419),
    [sym_preproc_endregion] = STATE(3419),
    [sym_preproc_line] = STATE(3419),
    [sym_preproc_pragma] = STATE(3419),
    [sym_preproc_nullable] = STATE(3419),
    [sym_preproc_error] = STATE(3419),
    [sym_preproc_warning] = STATE(3419),
    [sym_preproc_define] = STATE(3419),
    [sym_preproc_undef] = STATE(3419),
    [sym__identifier_token] = ACTIONS(5183),
    [anon_sym_extern] = ACTIONS(5183),
    [anon_sym_alias] = ACTIONS(5183),
    [anon_sym_global] = ACTIONS(5183),
    [anon_sym_using] = ACTIONS(5183),
    [anon_sym_unsafe] = ACTIONS(5183),
    [anon_sym_static] = ACTIONS(5183),
    [anon_sym_LBRACK] = ACTIONS(5185),
    [anon_sym_LPAREN] = ACTIONS(5185),
    [anon_sym_event] = ACTIONS(5183),
    [anon_sym_namespace] = ACTIONS(5183),
    [anon_sym_class] = ACTIONS(5183),
    [anon_sym_ref] = ACTIONS(5183),
    [anon_sym_struct] = ACTIONS(5183),
    [anon_sym_enum] = ACTIONS(5183),
    [anon_sym_RBRACE] = ACTIONS(5185),
    [anon_sym_interface] = ACTIONS(5183),
    [anon_sym_delegate] = ACTIONS(5183),
    [anon_sym_record] = ACTIONS(5183),
    [anon_sym_abstract] = ACTIONS(5183),
    [anon_sym_async] = ACTIONS(5183),
    [anon_sym_const] = ACTIONS(5183),
    [anon_sym_file] = ACTIONS(5183),
    [anon_sym_fixed] = ACTIONS(5183),
    [anon_sym_internal] = ACTIONS(5183),
    [anon_sym_new] = ACTIONS(5183),
    [anon_sym_override] = ACTIONS(5183),
    [anon_sym_partial] = ACTIONS(5183),
    [anon_sym_private] = ACTIONS(5183),
    [anon_sym_protected] = ACTIONS(5183),
    [anon_sym_public] = ACTIONS(5183),
    [anon_sym_readonly] = ACTIONS(5183),
    [anon_sym_required] = ACTIONS(5183),
    [anon_sym_sealed] = ACTIONS(5183),
    [anon_sym_virtual] = ACTIONS(5183),
    [anon_sym_volatile] = ACTIONS(5183),
    [anon_sym_where] = ACTIONS(5183),
    [anon_sym_notnull] = ACTIONS(5183),
    [anon_sym_unmanaged] = ACTIONS(5183),
    [anon_sym_TILDE] = ACTIONS(5185),
    [anon_sym_implicit] = ACTIONS(5183),
    [anon_sym_explicit] = ACTIONS(5183),
    [anon_sym_scoped] = ACTIONS(5183),
    [anon_sym_var] = ACTIONS(5183),
    [sym_predefined_type] = ACTIONS(5183),
    [anon_sym_yield] = ACTIONS(5183),
    [anon_sym_when] = ACTIONS(5183),
    [anon_sym_from] = ACTIONS(5183),
    [anon_sym_into] = ACTIONS(5183),
    [anon_sym_join] = ACTIONS(5183),
    [anon_sym_on] = ACTIONS(5183),
    [anon_sym_equals] = ACTIONS(5183),
    [anon_sym_let] = ACTIONS(5183),
    [anon_sym_orderby] = ACTIONS(5183),
    [anon_sym_ascending] = ACTIONS(5183),
    [anon_sym_descending] = ACTIONS(5183),
    [anon_sym_group] = ACTIONS(5183),
    [anon_sym_by] = ACTIONS(5183),
    [anon_sym_select] = ACTIONS(5183),
    [aux_sym_preproc_if_token1] = ACTIONS(5185),
    [aux_sym_preproc_if_token3] = ACTIONS(5185),
    [aux_sym_preproc_else_token1] = ACTIONS(5185),
    [aux_sym_preproc_elif_token1] = ACTIONS(5185),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3420] = {
    [sym_preproc_region] = STATE(3420),
    [sym_preproc_endregion] = STATE(3420),
    [sym_preproc_line] = STATE(3420),
    [sym_preproc_pragma] = STATE(3420),
    [sym_preproc_nullable] = STATE(3420),
    [sym_preproc_error] = STATE(3420),
    [sym_preproc_warning] = STATE(3420),
    [sym_preproc_define] = STATE(3420),
    [sym_preproc_undef] = STATE(3420),
    [sym__identifier_token] = ACTIONS(5187),
    [anon_sym_extern] = ACTIONS(5187),
    [anon_sym_alias] = ACTIONS(5187),
    [anon_sym_global] = ACTIONS(5187),
    [anon_sym_using] = ACTIONS(5187),
    [anon_sym_unsafe] = ACTIONS(5187),
    [anon_sym_static] = ACTIONS(5187),
    [anon_sym_LBRACK] = ACTIONS(5189),
    [anon_sym_LPAREN] = ACTIONS(5189),
    [anon_sym_event] = ACTIONS(5187),
    [anon_sym_namespace] = ACTIONS(5187),
    [anon_sym_class] = ACTIONS(5187),
    [anon_sym_ref] = ACTIONS(5187),
    [anon_sym_struct] = ACTIONS(5187),
    [anon_sym_enum] = ACTIONS(5187),
    [anon_sym_RBRACE] = ACTIONS(5189),
    [anon_sym_interface] = ACTIONS(5187),
    [anon_sym_delegate] = ACTIONS(5187),
    [anon_sym_record] = ACTIONS(5187),
    [anon_sym_abstract] = ACTIONS(5187),
    [anon_sym_async] = ACTIONS(5187),
    [anon_sym_const] = ACTIONS(5187),
    [anon_sym_file] = ACTIONS(5187),
    [anon_sym_fixed] = ACTIONS(5187),
    [anon_sym_internal] = ACTIONS(5187),
    [anon_sym_new] = ACTIONS(5187),
    [anon_sym_override] = ACTIONS(5187),
    [anon_sym_partial] = ACTIONS(5187),
    [anon_sym_private] = ACTIONS(5187),
    [anon_sym_protected] = ACTIONS(5187),
    [anon_sym_public] = ACTIONS(5187),
    [anon_sym_readonly] = ACTIONS(5187),
    [anon_sym_required] = ACTIONS(5187),
    [anon_sym_sealed] = ACTIONS(5187),
    [anon_sym_virtual] = ACTIONS(5187),
    [anon_sym_volatile] = ACTIONS(5187),
    [anon_sym_where] = ACTIONS(5187),
    [anon_sym_notnull] = ACTIONS(5187),
    [anon_sym_unmanaged] = ACTIONS(5187),
    [anon_sym_TILDE] = ACTIONS(5189),
    [anon_sym_implicit] = ACTIONS(5187),
    [anon_sym_explicit] = ACTIONS(5187),
    [anon_sym_scoped] = ACTIONS(5187),
    [anon_sym_var] = ACTIONS(5187),
    [sym_predefined_type] = ACTIONS(5187),
    [anon_sym_yield] = ACTIONS(5187),
    [anon_sym_when] = ACTIONS(5187),
    [anon_sym_from] = ACTIONS(5187),
    [anon_sym_into] = ACTIONS(5187),
    [anon_sym_join] = ACTIONS(5187),
    [anon_sym_on] = ACTIONS(5187),
    [anon_sym_equals] = ACTIONS(5187),
    [anon_sym_let] = ACTIONS(5187),
    [anon_sym_orderby] = ACTIONS(5187),
    [anon_sym_ascending] = ACTIONS(5187),
    [anon_sym_descending] = ACTIONS(5187),
    [anon_sym_group] = ACTIONS(5187),
    [anon_sym_by] = ACTIONS(5187),
    [anon_sym_select] = ACTIONS(5187),
    [aux_sym_preproc_if_token1] = ACTIONS(5189),
    [aux_sym_preproc_if_token3] = ACTIONS(5189),
    [aux_sym_preproc_else_token1] = ACTIONS(5189),
    [aux_sym_preproc_elif_token1] = ACTIONS(5189),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3421] = {
    [sym_preproc_region] = STATE(3421),
    [sym_preproc_endregion] = STATE(3421),
    [sym_preproc_line] = STATE(3421),
    [sym_preproc_pragma] = STATE(3421),
    [sym_preproc_nullable] = STATE(3421),
    [sym_preproc_error] = STATE(3421),
    [sym_preproc_warning] = STATE(3421),
    [sym_preproc_define] = STATE(3421),
    [sym_preproc_undef] = STATE(3421),
    [sym__identifier_token] = ACTIONS(5191),
    [anon_sym_extern] = ACTIONS(5191),
    [anon_sym_alias] = ACTIONS(5191),
    [anon_sym_global] = ACTIONS(5191),
    [anon_sym_using] = ACTIONS(5191),
    [anon_sym_unsafe] = ACTIONS(5191),
    [anon_sym_static] = ACTIONS(5191),
    [anon_sym_LBRACK] = ACTIONS(5193),
    [anon_sym_LPAREN] = ACTIONS(5193),
    [anon_sym_event] = ACTIONS(5191),
    [anon_sym_namespace] = ACTIONS(5191),
    [anon_sym_class] = ACTIONS(5191),
    [anon_sym_ref] = ACTIONS(5191),
    [anon_sym_struct] = ACTIONS(5191),
    [anon_sym_enum] = ACTIONS(5191),
    [anon_sym_RBRACE] = ACTIONS(5193),
    [anon_sym_interface] = ACTIONS(5191),
    [anon_sym_delegate] = ACTIONS(5191),
    [anon_sym_record] = ACTIONS(5191),
    [anon_sym_abstract] = ACTIONS(5191),
    [anon_sym_async] = ACTIONS(5191),
    [anon_sym_const] = ACTIONS(5191),
    [anon_sym_file] = ACTIONS(5191),
    [anon_sym_fixed] = ACTIONS(5191),
    [anon_sym_internal] = ACTIONS(5191),
    [anon_sym_new] = ACTIONS(5191),
    [anon_sym_override] = ACTIONS(5191),
    [anon_sym_partial] = ACTIONS(5191),
    [anon_sym_private] = ACTIONS(5191),
    [anon_sym_protected] = ACTIONS(5191),
    [anon_sym_public] = ACTIONS(5191),
    [anon_sym_readonly] = ACTIONS(5191),
    [anon_sym_required] = ACTIONS(5191),
    [anon_sym_sealed] = ACTIONS(5191),
    [anon_sym_virtual] = ACTIONS(5191),
    [anon_sym_volatile] = ACTIONS(5191),
    [anon_sym_where] = ACTIONS(5191),
    [anon_sym_notnull] = ACTIONS(5191),
    [anon_sym_unmanaged] = ACTIONS(5191),
    [anon_sym_TILDE] = ACTIONS(5193),
    [anon_sym_implicit] = ACTIONS(5191),
    [anon_sym_explicit] = ACTIONS(5191),
    [anon_sym_scoped] = ACTIONS(5191),
    [anon_sym_var] = ACTIONS(5191),
    [sym_predefined_type] = ACTIONS(5191),
    [anon_sym_yield] = ACTIONS(5191),
    [anon_sym_when] = ACTIONS(5191),
    [anon_sym_from] = ACTIONS(5191),
    [anon_sym_into] = ACTIONS(5191),
    [anon_sym_join] = ACTIONS(5191),
    [anon_sym_on] = ACTIONS(5191),
    [anon_sym_equals] = ACTIONS(5191),
    [anon_sym_let] = ACTIONS(5191),
    [anon_sym_orderby] = ACTIONS(5191),
    [anon_sym_ascending] = ACTIONS(5191),
    [anon_sym_descending] = ACTIONS(5191),
    [anon_sym_group] = ACTIONS(5191),
    [anon_sym_by] = ACTIONS(5191),
    [anon_sym_select] = ACTIONS(5191),
    [aux_sym_preproc_if_token1] = ACTIONS(5193),
    [aux_sym_preproc_if_token3] = ACTIONS(5193),
    [aux_sym_preproc_else_token1] = ACTIONS(5193),
    [aux_sym_preproc_elif_token1] = ACTIONS(5193),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3422] = {
    [sym__variable_designation] = STATE(4040),
    [sym_parenthesized_variable_designation] = STATE(3966),
    [sym_identifier] = STATE(3983),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3422),
    [sym_preproc_endregion] = STATE(3422),
    [sym_preproc_line] = STATE(3422),
    [sym_preproc_pragma] = STATE(3422),
    [sym_preproc_nullable] = STATE(3422),
    [sym_preproc_error] = STATE(3422),
    [sym_preproc_warning] = STATE(3422),
    [sym_preproc_define] = STATE(3422),
    [sym_preproc_undef] = STATE(3422),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4399),
    [anon_sym_LPAREN] = ACTIONS(4399),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4401),
    [anon_sym_GT] = ACTIONS(4401),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4401),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4401),
    [anon_sym_PLUS_PLUS] = ACTIONS(4399),
    [anon_sym_DASH_DASH] = ACTIONS(4399),
    [anon_sym_PLUS] = ACTIONS(4401),
    [anon_sym_DASH] = ACTIONS(4401),
    [anon_sym_STAR] = ACTIONS(4399),
    [anon_sym_SLASH] = ACTIONS(4401),
    [anon_sym_PERCENT] = ACTIONS(4399),
    [anon_sym_CARET] = ACTIONS(4399),
    [anon_sym_PIPE] = ACTIONS(4401),
    [anon_sym_AMP] = ACTIONS(4401),
    [anon_sym_LT_LT] = ACTIONS(4399),
    [anon_sym_GT_GT] = ACTIONS(4401),
    [anon_sym_GT_GT_GT] = ACTIONS(4399),
    [anon_sym_EQ_EQ] = ACTIONS(4399),
    [anon_sym_BANG_EQ] = ACTIONS(4399),
    [anon_sym_GT_EQ] = ACTIONS(4399),
    [anon_sym_LT_EQ] = ACTIONS(4399),
    [anon_sym_DOT] = ACTIONS(4401),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4401),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4347),
    [anon_sym_DOT_DOT] = ACTIONS(4399),
    [anon_sym_and] = ACTIONS(4401),
    [anon_sym_or] = ACTIONS(4401),
    [anon_sym_AMP_AMP] = ACTIONS(4399),
    [anon_sym_PIPE_PIPE] = ACTIONS(4399),
    [anon_sym_QMARK_QMARK] = ACTIONS(4399),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4401),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4401),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4401),
    [anon_sym_is] = ACTIONS(4401),
    [anon_sym_DASH_GT] = ACTIONS(4399),
    [anon_sym_with] = ACTIONS(4401),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3423] = {
    [sym_preproc_region] = STATE(3423),
    [sym_preproc_endregion] = STATE(3423),
    [sym_preproc_line] = STATE(3423),
    [sym_preproc_pragma] = STATE(3423),
    [sym_preproc_nullable] = STATE(3423),
    [sym_preproc_error] = STATE(3423),
    [sym_preproc_warning] = STATE(3423),
    [sym_preproc_define] = STATE(3423),
    [sym_preproc_undef] = STATE(3423),
    [sym__identifier_token] = ACTIONS(5195),
    [anon_sym_extern] = ACTIONS(5195),
    [anon_sym_alias] = ACTIONS(5195),
    [anon_sym_global] = ACTIONS(5195),
    [anon_sym_using] = ACTIONS(5195),
    [anon_sym_unsafe] = ACTIONS(5195),
    [anon_sym_static] = ACTIONS(5195),
    [anon_sym_LBRACK] = ACTIONS(5197),
    [anon_sym_LPAREN] = ACTIONS(5197),
    [anon_sym_event] = ACTIONS(5195),
    [anon_sym_namespace] = ACTIONS(5195),
    [anon_sym_class] = ACTIONS(5195),
    [anon_sym_ref] = ACTIONS(5195),
    [anon_sym_struct] = ACTIONS(5195),
    [anon_sym_enum] = ACTIONS(5195),
    [anon_sym_RBRACE] = ACTIONS(5197),
    [anon_sym_interface] = ACTIONS(5195),
    [anon_sym_delegate] = ACTIONS(5195),
    [anon_sym_record] = ACTIONS(5195),
    [anon_sym_abstract] = ACTIONS(5195),
    [anon_sym_async] = ACTIONS(5195),
    [anon_sym_const] = ACTIONS(5195),
    [anon_sym_file] = ACTIONS(5195),
    [anon_sym_fixed] = ACTIONS(5195),
    [anon_sym_internal] = ACTIONS(5195),
    [anon_sym_new] = ACTIONS(5195),
    [anon_sym_override] = ACTIONS(5195),
    [anon_sym_partial] = ACTIONS(5195),
    [anon_sym_private] = ACTIONS(5195),
    [anon_sym_protected] = ACTIONS(5195),
    [anon_sym_public] = ACTIONS(5195),
    [anon_sym_readonly] = ACTIONS(5195),
    [anon_sym_required] = ACTIONS(5195),
    [anon_sym_sealed] = ACTIONS(5195),
    [anon_sym_virtual] = ACTIONS(5195),
    [anon_sym_volatile] = ACTIONS(5195),
    [anon_sym_where] = ACTIONS(5195),
    [anon_sym_notnull] = ACTIONS(5195),
    [anon_sym_unmanaged] = ACTIONS(5195),
    [anon_sym_TILDE] = ACTIONS(5197),
    [anon_sym_implicit] = ACTIONS(5195),
    [anon_sym_explicit] = ACTIONS(5195),
    [anon_sym_scoped] = ACTIONS(5195),
    [anon_sym_var] = ACTIONS(5195),
    [sym_predefined_type] = ACTIONS(5195),
    [anon_sym_yield] = ACTIONS(5195),
    [anon_sym_when] = ACTIONS(5195),
    [anon_sym_from] = ACTIONS(5195),
    [anon_sym_into] = ACTIONS(5195),
    [anon_sym_join] = ACTIONS(5195),
    [anon_sym_on] = ACTIONS(5195),
    [anon_sym_equals] = ACTIONS(5195),
    [anon_sym_let] = ACTIONS(5195),
    [anon_sym_orderby] = ACTIONS(5195),
    [anon_sym_ascending] = ACTIONS(5195),
    [anon_sym_descending] = ACTIONS(5195),
    [anon_sym_group] = ACTIONS(5195),
    [anon_sym_by] = ACTIONS(5195),
    [anon_sym_select] = ACTIONS(5195),
    [aux_sym_preproc_if_token1] = ACTIONS(5197),
    [aux_sym_preproc_if_token3] = ACTIONS(5197),
    [aux_sym_preproc_else_token1] = ACTIONS(5197),
    [aux_sym_preproc_elif_token1] = ACTIONS(5197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3424] = {
    [sym__variable_designation] = STATE(4043),
    [sym_parenthesized_variable_designation] = STATE(3966),
    [sym_identifier] = STATE(3983),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3424),
    [sym_preproc_endregion] = STATE(3424),
    [sym_preproc_line] = STATE(3424),
    [sym_preproc_pragma] = STATE(3424),
    [sym_preproc_nullable] = STATE(3424),
    [sym_preproc_error] = STATE(3424),
    [sym_preproc_warning] = STATE(3424),
    [sym_preproc_define] = STATE(3424),
    [sym_preproc_undef] = STATE(3424),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4405),
    [anon_sym_LPAREN] = ACTIONS(4405),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4407),
    [anon_sym_GT] = ACTIONS(4407),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4407),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4407),
    [anon_sym_PLUS_PLUS] = ACTIONS(4405),
    [anon_sym_DASH_DASH] = ACTIONS(4405),
    [anon_sym_PLUS] = ACTIONS(4407),
    [anon_sym_DASH] = ACTIONS(4407),
    [anon_sym_STAR] = ACTIONS(4405),
    [anon_sym_SLASH] = ACTIONS(4407),
    [anon_sym_PERCENT] = ACTIONS(4405),
    [anon_sym_CARET] = ACTIONS(4405),
    [anon_sym_PIPE] = ACTIONS(4407),
    [anon_sym_AMP] = ACTIONS(4407),
    [anon_sym_LT_LT] = ACTIONS(4405),
    [anon_sym_GT_GT] = ACTIONS(4407),
    [anon_sym_GT_GT_GT] = ACTIONS(4405),
    [anon_sym_EQ_EQ] = ACTIONS(4405),
    [anon_sym_BANG_EQ] = ACTIONS(4405),
    [anon_sym_GT_EQ] = ACTIONS(4405),
    [anon_sym_LT_EQ] = ACTIONS(4405),
    [anon_sym_DOT] = ACTIONS(4407),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4407),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4347),
    [anon_sym_DOT_DOT] = ACTIONS(4405),
    [anon_sym_and] = ACTIONS(4407),
    [anon_sym_or] = ACTIONS(4407),
    [anon_sym_AMP_AMP] = ACTIONS(4405),
    [anon_sym_PIPE_PIPE] = ACTIONS(4405),
    [anon_sym_QMARK_QMARK] = ACTIONS(4405),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4407),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4407),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4407),
    [anon_sym_is] = ACTIONS(4407),
    [anon_sym_DASH_GT] = ACTIONS(4405),
    [anon_sym_with] = ACTIONS(4407),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3425] = {
    [sym__variable_designation] = STATE(4065),
    [sym_parenthesized_variable_designation] = STATE(3966),
    [sym_identifier] = STATE(3983),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3425),
    [sym_preproc_endregion] = STATE(3425),
    [sym_preproc_line] = STATE(3425),
    [sym_preproc_pragma] = STATE(3425),
    [sym_preproc_nullable] = STATE(3425),
    [sym_preproc_error] = STATE(3425),
    [sym_preproc_warning] = STATE(3425),
    [sym_preproc_define] = STATE(3425),
    [sym_preproc_undef] = STATE(3425),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4437),
    [anon_sym_LPAREN] = ACTIONS(4437),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4439),
    [anon_sym_GT] = ACTIONS(4439),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4439),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4439),
    [anon_sym_PLUS_PLUS] = ACTIONS(4437),
    [anon_sym_DASH_DASH] = ACTIONS(4437),
    [anon_sym_PLUS] = ACTIONS(4439),
    [anon_sym_DASH] = ACTIONS(4439),
    [anon_sym_STAR] = ACTIONS(4437),
    [anon_sym_SLASH] = ACTIONS(4439),
    [anon_sym_PERCENT] = ACTIONS(4437),
    [anon_sym_CARET] = ACTIONS(4437),
    [anon_sym_PIPE] = ACTIONS(4439),
    [anon_sym_AMP] = ACTIONS(4439),
    [anon_sym_LT_LT] = ACTIONS(4437),
    [anon_sym_GT_GT] = ACTIONS(4439),
    [anon_sym_GT_GT_GT] = ACTIONS(4437),
    [anon_sym_EQ_EQ] = ACTIONS(4437),
    [anon_sym_BANG_EQ] = ACTIONS(4437),
    [anon_sym_GT_EQ] = ACTIONS(4437),
    [anon_sym_LT_EQ] = ACTIONS(4437),
    [anon_sym_DOT] = ACTIONS(4439),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4439),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4347),
    [anon_sym_DOT_DOT] = ACTIONS(4437),
    [anon_sym_and] = ACTIONS(4439),
    [anon_sym_or] = ACTIONS(4439),
    [anon_sym_AMP_AMP] = ACTIONS(4437),
    [anon_sym_PIPE_PIPE] = ACTIONS(4437),
    [anon_sym_QMARK_QMARK] = ACTIONS(4437),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4439),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4439),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4439),
    [anon_sym_is] = ACTIONS(4439),
    [anon_sym_DASH_GT] = ACTIONS(4437),
    [anon_sym_with] = ACTIONS(4439),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3426] = {
    [sym__variable_designation] = STATE(3957),
    [sym_parenthesized_variable_designation] = STATE(3966),
    [sym_identifier] = STATE(3983),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3426),
    [sym_preproc_endregion] = STATE(3426),
    [sym_preproc_line] = STATE(3426),
    [sym_preproc_pragma] = STATE(3426),
    [sym_preproc_nullable] = STATE(3426),
    [sym_preproc_error] = STATE(3426),
    [sym_preproc_warning] = STATE(3426),
    [sym_preproc_define] = STATE(3426),
    [sym_preproc_undef] = STATE(3426),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4441),
    [anon_sym_LPAREN] = ACTIONS(4441),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4443),
    [anon_sym_GT] = ACTIONS(4443),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4443),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4443),
    [anon_sym_PLUS_PLUS] = ACTIONS(4441),
    [anon_sym_DASH_DASH] = ACTIONS(4441),
    [anon_sym_PLUS] = ACTIONS(4443),
    [anon_sym_DASH] = ACTIONS(4443),
    [anon_sym_STAR] = ACTIONS(4441),
    [anon_sym_SLASH] = ACTIONS(4443),
    [anon_sym_PERCENT] = ACTIONS(4441),
    [anon_sym_CARET] = ACTIONS(4441),
    [anon_sym_PIPE] = ACTIONS(4443),
    [anon_sym_AMP] = ACTIONS(4443),
    [anon_sym_LT_LT] = ACTIONS(4441),
    [anon_sym_GT_GT] = ACTIONS(4443),
    [anon_sym_GT_GT_GT] = ACTIONS(4441),
    [anon_sym_EQ_EQ] = ACTIONS(4441),
    [anon_sym_BANG_EQ] = ACTIONS(4441),
    [anon_sym_GT_EQ] = ACTIONS(4441),
    [anon_sym_LT_EQ] = ACTIONS(4441),
    [anon_sym_DOT] = ACTIONS(4443),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4443),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4347),
    [anon_sym_DOT_DOT] = ACTIONS(4441),
    [anon_sym_and] = ACTIONS(4443),
    [anon_sym_or] = ACTIONS(4443),
    [anon_sym_AMP_AMP] = ACTIONS(4441),
    [anon_sym_PIPE_PIPE] = ACTIONS(4441),
    [anon_sym_QMARK_QMARK] = ACTIONS(4441),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4443),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4339),
    [anon_sym_equals] = ACTIONS(4443),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4443),
    [anon_sym_is] = ACTIONS(4443),
    [anon_sym_DASH_GT] = ACTIONS(4441),
    [anon_sym_with] = ACTIONS(4443),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3427] = {
    [sym_preproc_region] = STATE(3427),
    [sym_preproc_endregion] = STATE(3427),
    [sym_preproc_line] = STATE(3427),
    [sym_preproc_pragma] = STATE(3427),
    [sym_preproc_nullable] = STATE(3427),
    [sym_preproc_error] = STATE(3427),
    [sym_preproc_warning] = STATE(3427),
    [sym_preproc_define] = STATE(3427),
    [sym_preproc_undef] = STATE(3427),
    [sym__identifier_token] = ACTIONS(3481),
    [anon_sym_extern] = ACTIONS(3481),
    [anon_sym_alias] = ACTIONS(3481),
    [anon_sym_global] = ACTIONS(3481),
    [anon_sym_using] = ACTIONS(3481),
    [anon_sym_unsafe] = ACTIONS(3481),
    [anon_sym_static] = ACTIONS(3481),
    [anon_sym_LBRACK] = ACTIONS(3483),
    [anon_sym_LPAREN] = ACTIONS(3483),
    [anon_sym_event] = ACTIONS(3481),
    [anon_sym_namespace] = ACTIONS(3481),
    [anon_sym_class] = ACTIONS(3481),
    [anon_sym_ref] = ACTIONS(3481),
    [anon_sym_struct] = ACTIONS(3481),
    [anon_sym_enum] = ACTIONS(3481),
    [anon_sym_RBRACE] = ACTIONS(3483),
    [anon_sym_interface] = ACTIONS(3481),
    [anon_sym_delegate] = ACTIONS(3481),
    [anon_sym_record] = ACTIONS(3481),
    [anon_sym_abstract] = ACTIONS(3481),
    [anon_sym_async] = ACTIONS(3481),
    [anon_sym_const] = ACTIONS(3481),
    [anon_sym_file] = ACTIONS(3481),
    [anon_sym_fixed] = ACTIONS(3481),
    [anon_sym_internal] = ACTIONS(3481),
    [anon_sym_new] = ACTIONS(3481),
    [anon_sym_override] = ACTIONS(3481),
    [anon_sym_partial] = ACTIONS(3481),
    [anon_sym_private] = ACTIONS(3481),
    [anon_sym_protected] = ACTIONS(3481),
    [anon_sym_public] = ACTIONS(3481),
    [anon_sym_readonly] = ACTIONS(3481),
    [anon_sym_required] = ACTIONS(3481),
    [anon_sym_sealed] = ACTIONS(3481),
    [anon_sym_virtual] = ACTIONS(3481),
    [anon_sym_volatile] = ACTIONS(3481),
    [anon_sym_where] = ACTIONS(3481),
    [anon_sym_notnull] = ACTIONS(3481),
    [anon_sym_unmanaged] = ACTIONS(3481),
    [anon_sym_TILDE] = ACTIONS(3483),
    [anon_sym_implicit] = ACTIONS(3481),
    [anon_sym_explicit] = ACTIONS(3481),
    [anon_sym_scoped] = ACTIONS(3481),
    [anon_sym_var] = ACTIONS(3481),
    [sym_predefined_type] = ACTIONS(3481),
    [anon_sym_yield] = ACTIONS(3481),
    [anon_sym_when] = ACTIONS(3481),
    [anon_sym_from] = ACTIONS(3481),
    [anon_sym_into] = ACTIONS(3481),
    [anon_sym_join] = ACTIONS(3481),
    [anon_sym_on] = ACTIONS(3481),
    [anon_sym_equals] = ACTIONS(3481),
    [anon_sym_let] = ACTIONS(3481),
    [anon_sym_orderby] = ACTIONS(3481),
    [anon_sym_ascending] = ACTIONS(3481),
    [anon_sym_descending] = ACTIONS(3481),
    [anon_sym_group] = ACTIONS(3481),
    [anon_sym_by] = ACTIONS(3481),
    [anon_sym_select] = ACTIONS(3481),
    [aux_sym_preproc_if_token1] = ACTIONS(3483),
    [aux_sym_preproc_if_token3] = ACTIONS(3483),
    [aux_sym_preproc_else_token1] = ACTIONS(3483),
    [aux_sym_preproc_elif_token1] = ACTIONS(3483),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3428] = {
    [sym__variable_designation] = STATE(4993),
    [sym_parenthesized_variable_designation] = STATE(5027),
    [sym_identifier] = STATE(5034),
    [sym__reserved_identifier] = STATE(3625),
    [sym_preproc_region] = STATE(3428),
    [sym_preproc_endregion] = STATE(3428),
    [sym_preproc_line] = STATE(3428),
    [sym_preproc_pragma] = STATE(3428),
    [sym_preproc_nullable] = STATE(3428),
    [sym_preproc_error] = STATE(3428),
    [sym_preproc_warning] = STATE(3428),
    [sym_preproc_define] = STATE(3428),
    [sym_preproc_undef] = STATE(3428),
    [sym__identifier_token] = ACTIONS(4349),
    [anon_sym_alias] = ACTIONS(4351),
    [anon_sym_global] = ACTIONS(4351),
    [anon_sym_LBRACK] = ACTIONS(4399),
    [anon_sym_LPAREN] = ACTIONS(4399),
    [anon_sym_file] = ACTIONS(4351),
    [anon_sym_LT] = ACTIONS(4401),
    [anon_sym_GT] = ACTIONS(4401),
    [anon_sym_where] = ACTIONS(4401),
    [anon_sym_QMARK] = ACTIONS(4401),
    [anon_sym_notnull] = ACTIONS(4351),
    [anon_sym_unmanaged] = ACTIONS(4351),
    [anon_sym_BANG] = ACTIONS(4401),
    [anon_sym_PLUS_PLUS] = ACTIONS(4399),
    [anon_sym_DASH_DASH] = ACTIONS(4399),
    [anon_sym_PLUS] = ACTIONS(4401),
    [anon_sym_DASH] = ACTIONS(4401),
    [anon_sym_STAR] = ACTIONS(4399),
    [anon_sym_SLASH] = ACTIONS(4401),
    [anon_sym_PERCENT] = ACTIONS(4399),
    [anon_sym_CARET] = ACTIONS(4399),
    [anon_sym_PIPE] = ACTIONS(4401),
    [anon_sym_AMP] = ACTIONS(4401),
    [anon_sym_LT_LT] = ACTIONS(4399),
    [anon_sym_GT_GT] = ACTIONS(4401),
    [anon_sym_GT_GT_GT] = ACTIONS(4399),
    [anon_sym_EQ_EQ] = ACTIONS(4399),
    [anon_sym_BANG_EQ] = ACTIONS(4399),
    [anon_sym_GT_EQ] = ACTIONS(4399),
    [anon_sym_LT_EQ] = ACTIONS(4399),
    [anon_sym_DOT] = ACTIONS(4401),
    [anon_sym_scoped] = ACTIONS(4351),
    [anon_sym_var] = ACTIONS(4351),
    [anon_sym_yield] = ACTIONS(4351),
    [anon_sym_switch] = ACTIONS(4401),
    [anon_sym_when] = ACTIONS(4351),
    [sym_discard] = ACTIONS(4719),
    [anon_sym_DOT_DOT] = ACTIONS(4399),
    [anon_sym_and] = ACTIONS(4401),
    [anon_sym_or] = ACTIONS(4401),
    [anon_sym_AMP_AMP] = ACTIONS(4399),
    [anon_sym_PIPE_PIPE] = ACTIONS(4399),
    [anon_sym_QMARK_QMARK] = ACTIONS(4399),
    [anon_sym_from] = ACTIONS(4401),
    [anon_sym_into] = ACTIONS(4351),
    [anon_sym_join] = ACTIONS(4401),
    [anon_sym_on] = ACTIONS(4351),
    [anon_sym_equals] = ACTIONS(4351),
    [anon_sym_let] = ACTIONS(4401),
    [anon_sym_orderby] = ACTIONS(4401),
    [anon_sym_ascending] = ACTIONS(4351),
    [anon_sym_descending] = ACTIONS(4351),
    [anon_sym_group] = ACTIONS(4401),
    [anon_sym_by] = ACTIONS(4351),
    [anon_sym_select] = ACTIONS(4401),
    [anon_sym_as] = ACTIONS(4401),
    [anon_sym_is] = ACTIONS(4401),
    [anon_sym_DASH_GT] = ACTIONS(4399),
    [anon_sym_with] = ACTIONS(4401),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3429] = {
    [sym__variable_designation] = STATE(4040),
    [sym_parenthesized_variable_designation] = STATE(3966),
    [sym_identifier] = STATE(3983),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3429),
    [sym_preproc_endregion] = STATE(3429),
    [sym_preproc_line] = STATE(3429),
    [sym_preproc_pragma] = STATE(3429),
    [sym_preproc_nullable] = STATE(3429),
    [sym_preproc_error] = STATE(3429),
    [sym_preproc_warning] = STATE(3429),
    [sym_preproc_define] = STATE(3429),
    [sym_preproc_undef] = STATE(3429),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4399),
    [anon_sym_LPAREN] = ACTIONS(4399),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4401),
    [anon_sym_GT] = ACTIONS(4401),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4401),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4401),
    [anon_sym_PLUS_PLUS] = ACTIONS(4399),
    [anon_sym_DASH_DASH] = ACTIONS(4399),
    [anon_sym_PLUS] = ACTIONS(4401),
    [anon_sym_DASH] = ACTIONS(4401),
    [anon_sym_STAR] = ACTIONS(4399),
    [anon_sym_SLASH] = ACTIONS(4401),
    [anon_sym_PERCENT] = ACTIONS(4399),
    [anon_sym_CARET] = ACTIONS(4399),
    [anon_sym_PIPE] = ACTIONS(4401),
    [anon_sym_AMP] = ACTIONS(4401),
    [anon_sym_LT_LT] = ACTIONS(4399),
    [anon_sym_GT_GT] = ACTIONS(4401),
    [anon_sym_GT_GT_GT] = ACTIONS(4399),
    [anon_sym_EQ_EQ] = ACTIONS(4399),
    [anon_sym_BANG_EQ] = ACTIONS(4399),
    [anon_sym_GT_EQ] = ACTIONS(4399),
    [anon_sym_LT_EQ] = ACTIONS(4399),
    [anon_sym_DOT] = ACTIONS(4401),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4401),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4347),
    [anon_sym_DOT_DOT] = ACTIONS(4399),
    [anon_sym_and] = ACTIONS(4401),
    [anon_sym_or] = ACTIONS(4401),
    [anon_sym_AMP_AMP] = ACTIONS(4399),
    [anon_sym_PIPE_PIPE] = ACTIONS(4399),
    [anon_sym_QMARK_QMARK] = ACTIONS(4399),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4401),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4401),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4401),
    [anon_sym_is] = ACTIONS(4401),
    [anon_sym_DASH_GT] = ACTIONS(4399),
    [anon_sym_with] = ACTIONS(4401),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3430] = {
    [sym__variable_designation] = STATE(4043),
    [sym_parenthesized_variable_designation] = STATE(3966),
    [sym_identifier] = STATE(3983),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3430),
    [sym_preproc_endregion] = STATE(3430),
    [sym_preproc_line] = STATE(3430),
    [sym_preproc_pragma] = STATE(3430),
    [sym_preproc_nullable] = STATE(3430),
    [sym_preproc_error] = STATE(3430),
    [sym_preproc_warning] = STATE(3430),
    [sym_preproc_define] = STATE(3430),
    [sym_preproc_undef] = STATE(3430),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4405),
    [anon_sym_LPAREN] = ACTIONS(4405),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4407),
    [anon_sym_GT] = ACTIONS(4407),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4407),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4407),
    [anon_sym_PLUS_PLUS] = ACTIONS(4405),
    [anon_sym_DASH_DASH] = ACTIONS(4405),
    [anon_sym_PLUS] = ACTIONS(4407),
    [anon_sym_DASH] = ACTIONS(4407),
    [anon_sym_STAR] = ACTIONS(4405),
    [anon_sym_SLASH] = ACTIONS(4407),
    [anon_sym_PERCENT] = ACTIONS(4405),
    [anon_sym_CARET] = ACTIONS(4405),
    [anon_sym_PIPE] = ACTIONS(4407),
    [anon_sym_AMP] = ACTIONS(4407),
    [anon_sym_LT_LT] = ACTIONS(4405),
    [anon_sym_GT_GT] = ACTIONS(4407),
    [anon_sym_GT_GT_GT] = ACTIONS(4405),
    [anon_sym_EQ_EQ] = ACTIONS(4405),
    [anon_sym_BANG_EQ] = ACTIONS(4405),
    [anon_sym_GT_EQ] = ACTIONS(4405),
    [anon_sym_LT_EQ] = ACTIONS(4405),
    [anon_sym_DOT] = ACTIONS(4407),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4407),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4347),
    [anon_sym_DOT_DOT] = ACTIONS(4405),
    [anon_sym_and] = ACTIONS(4407),
    [anon_sym_or] = ACTIONS(4407),
    [anon_sym_AMP_AMP] = ACTIONS(4405),
    [anon_sym_PIPE_PIPE] = ACTIONS(4405),
    [anon_sym_QMARK_QMARK] = ACTIONS(4405),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4407),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4407),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4407),
    [anon_sym_is] = ACTIONS(4407),
    [anon_sym_DASH_GT] = ACTIONS(4405),
    [anon_sym_with] = ACTIONS(4407),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3431] = {
    [sym_preproc_region] = STATE(3431),
    [sym_preproc_endregion] = STATE(3431),
    [sym_preproc_line] = STATE(3431),
    [sym_preproc_pragma] = STATE(3431),
    [sym_preproc_nullable] = STATE(3431),
    [sym_preproc_error] = STATE(3431),
    [sym_preproc_warning] = STATE(3431),
    [sym_preproc_define] = STATE(3431),
    [sym_preproc_undef] = STATE(3431),
    [sym__identifier_token] = ACTIONS(5199),
    [anon_sym_extern] = ACTIONS(5199),
    [anon_sym_alias] = ACTIONS(5199),
    [anon_sym_global] = ACTIONS(5199),
    [anon_sym_using] = ACTIONS(5199),
    [anon_sym_unsafe] = ACTIONS(5199),
    [anon_sym_static] = ACTIONS(5199),
    [anon_sym_LBRACK] = ACTIONS(5201),
    [anon_sym_LPAREN] = ACTIONS(5201),
    [anon_sym_event] = ACTIONS(5199),
    [anon_sym_namespace] = ACTIONS(5199),
    [anon_sym_class] = ACTIONS(5199),
    [anon_sym_ref] = ACTIONS(5199),
    [anon_sym_struct] = ACTIONS(5199),
    [anon_sym_enum] = ACTIONS(5199),
    [anon_sym_RBRACE] = ACTIONS(5201),
    [anon_sym_interface] = ACTIONS(5199),
    [anon_sym_delegate] = ACTIONS(5199),
    [anon_sym_record] = ACTIONS(5199),
    [anon_sym_abstract] = ACTIONS(5199),
    [anon_sym_async] = ACTIONS(5199),
    [anon_sym_const] = ACTIONS(5199),
    [anon_sym_file] = ACTIONS(5199),
    [anon_sym_fixed] = ACTIONS(5199),
    [anon_sym_internal] = ACTIONS(5199),
    [anon_sym_new] = ACTIONS(5199),
    [anon_sym_override] = ACTIONS(5199),
    [anon_sym_partial] = ACTIONS(5199),
    [anon_sym_private] = ACTIONS(5199),
    [anon_sym_protected] = ACTIONS(5199),
    [anon_sym_public] = ACTIONS(5199),
    [anon_sym_readonly] = ACTIONS(5199),
    [anon_sym_required] = ACTIONS(5199),
    [anon_sym_sealed] = ACTIONS(5199),
    [anon_sym_virtual] = ACTIONS(5199),
    [anon_sym_volatile] = ACTIONS(5199),
    [anon_sym_where] = ACTIONS(5199),
    [anon_sym_notnull] = ACTIONS(5199),
    [anon_sym_unmanaged] = ACTIONS(5199),
    [anon_sym_TILDE] = ACTIONS(5201),
    [anon_sym_implicit] = ACTIONS(5199),
    [anon_sym_explicit] = ACTIONS(5199),
    [anon_sym_scoped] = ACTIONS(5199),
    [anon_sym_var] = ACTIONS(5199),
    [sym_predefined_type] = ACTIONS(5199),
    [anon_sym_yield] = ACTIONS(5199),
    [anon_sym_when] = ACTIONS(5199),
    [anon_sym_from] = ACTIONS(5199),
    [anon_sym_into] = ACTIONS(5199),
    [anon_sym_join] = ACTIONS(5199),
    [anon_sym_on] = ACTIONS(5199),
    [anon_sym_equals] = ACTIONS(5199),
    [anon_sym_let] = ACTIONS(5199),
    [anon_sym_orderby] = ACTIONS(5199),
    [anon_sym_ascending] = ACTIONS(5199),
    [anon_sym_descending] = ACTIONS(5199),
    [anon_sym_group] = ACTIONS(5199),
    [anon_sym_by] = ACTIONS(5199),
    [anon_sym_select] = ACTIONS(5199),
    [aux_sym_preproc_if_token1] = ACTIONS(5201),
    [aux_sym_preproc_if_token3] = ACTIONS(5201),
    [aux_sym_preproc_else_token1] = ACTIONS(5201),
    [aux_sym_preproc_elif_token1] = ACTIONS(5201),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3432] = {
    [sym__variable_designation] = STATE(4065),
    [sym_parenthesized_variable_designation] = STATE(3966),
    [sym_identifier] = STATE(3983),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3432),
    [sym_preproc_endregion] = STATE(3432),
    [sym_preproc_line] = STATE(3432),
    [sym_preproc_pragma] = STATE(3432),
    [sym_preproc_nullable] = STATE(3432),
    [sym_preproc_error] = STATE(3432),
    [sym_preproc_warning] = STATE(3432),
    [sym_preproc_define] = STATE(3432),
    [sym_preproc_undef] = STATE(3432),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4437),
    [anon_sym_LPAREN] = ACTIONS(4437),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4439),
    [anon_sym_GT] = ACTIONS(4439),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4439),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4439),
    [anon_sym_PLUS_PLUS] = ACTIONS(4437),
    [anon_sym_DASH_DASH] = ACTIONS(4437),
    [anon_sym_PLUS] = ACTIONS(4439),
    [anon_sym_DASH] = ACTIONS(4439),
    [anon_sym_STAR] = ACTIONS(4437),
    [anon_sym_SLASH] = ACTIONS(4439),
    [anon_sym_PERCENT] = ACTIONS(4437),
    [anon_sym_CARET] = ACTIONS(4437),
    [anon_sym_PIPE] = ACTIONS(4439),
    [anon_sym_AMP] = ACTIONS(4439),
    [anon_sym_LT_LT] = ACTIONS(4437),
    [anon_sym_GT_GT] = ACTIONS(4439),
    [anon_sym_GT_GT_GT] = ACTIONS(4437),
    [anon_sym_EQ_EQ] = ACTIONS(4437),
    [anon_sym_BANG_EQ] = ACTIONS(4437),
    [anon_sym_GT_EQ] = ACTIONS(4437),
    [anon_sym_LT_EQ] = ACTIONS(4437),
    [anon_sym_DOT] = ACTIONS(4439),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4439),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4347),
    [anon_sym_DOT_DOT] = ACTIONS(4437),
    [anon_sym_and] = ACTIONS(4439),
    [anon_sym_or] = ACTIONS(4439),
    [anon_sym_AMP_AMP] = ACTIONS(4437),
    [anon_sym_PIPE_PIPE] = ACTIONS(4437),
    [anon_sym_QMARK_QMARK] = ACTIONS(4437),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4439),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4439),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4439),
    [anon_sym_is] = ACTIONS(4439),
    [anon_sym_DASH_GT] = ACTIONS(4437),
    [anon_sym_with] = ACTIONS(4439),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3433] = {
    [sym_preproc_region] = STATE(3433),
    [sym_preproc_endregion] = STATE(3433),
    [sym_preproc_line] = STATE(3433),
    [sym_preproc_pragma] = STATE(3433),
    [sym_preproc_nullable] = STATE(3433),
    [sym_preproc_error] = STATE(3433),
    [sym_preproc_warning] = STATE(3433),
    [sym_preproc_define] = STATE(3433),
    [sym_preproc_undef] = STATE(3433),
    [sym__identifier_token] = ACTIONS(5203),
    [anon_sym_extern] = ACTIONS(5203),
    [anon_sym_alias] = ACTIONS(5203),
    [anon_sym_global] = ACTIONS(5203),
    [anon_sym_using] = ACTIONS(5203),
    [anon_sym_unsafe] = ACTIONS(5203),
    [anon_sym_static] = ACTIONS(5203),
    [anon_sym_LBRACK] = ACTIONS(5205),
    [anon_sym_LPAREN] = ACTIONS(5205),
    [anon_sym_event] = ACTIONS(5203),
    [anon_sym_namespace] = ACTIONS(5203),
    [anon_sym_class] = ACTIONS(5203),
    [anon_sym_ref] = ACTIONS(5203),
    [anon_sym_struct] = ACTIONS(5203),
    [anon_sym_enum] = ACTIONS(5203),
    [anon_sym_RBRACE] = ACTIONS(5205),
    [anon_sym_interface] = ACTIONS(5203),
    [anon_sym_delegate] = ACTIONS(5203),
    [anon_sym_record] = ACTIONS(5203),
    [anon_sym_abstract] = ACTIONS(5203),
    [anon_sym_async] = ACTIONS(5203),
    [anon_sym_const] = ACTIONS(5203),
    [anon_sym_file] = ACTIONS(5203),
    [anon_sym_fixed] = ACTIONS(5203),
    [anon_sym_internal] = ACTIONS(5203),
    [anon_sym_new] = ACTIONS(5203),
    [anon_sym_override] = ACTIONS(5203),
    [anon_sym_partial] = ACTIONS(5203),
    [anon_sym_private] = ACTIONS(5203),
    [anon_sym_protected] = ACTIONS(5203),
    [anon_sym_public] = ACTIONS(5203),
    [anon_sym_readonly] = ACTIONS(5203),
    [anon_sym_required] = ACTIONS(5203),
    [anon_sym_sealed] = ACTIONS(5203),
    [anon_sym_virtual] = ACTIONS(5203),
    [anon_sym_volatile] = ACTIONS(5203),
    [anon_sym_where] = ACTIONS(5203),
    [anon_sym_notnull] = ACTIONS(5203),
    [anon_sym_unmanaged] = ACTIONS(5203),
    [anon_sym_TILDE] = ACTIONS(5205),
    [anon_sym_implicit] = ACTIONS(5203),
    [anon_sym_explicit] = ACTIONS(5203),
    [anon_sym_scoped] = ACTIONS(5203),
    [anon_sym_var] = ACTIONS(5203),
    [sym_predefined_type] = ACTIONS(5203),
    [anon_sym_yield] = ACTIONS(5203),
    [anon_sym_when] = ACTIONS(5203),
    [anon_sym_from] = ACTIONS(5203),
    [anon_sym_into] = ACTIONS(5203),
    [anon_sym_join] = ACTIONS(5203),
    [anon_sym_on] = ACTIONS(5203),
    [anon_sym_equals] = ACTIONS(5203),
    [anon_sym_let] = ACTIONS(5203),
    [anon_sym_orderby] = ACTIONS(5203),
    [anon_sym_ascending] = ACTIONS(5203),
    [anon_sym_descending] = ACTIONS(5203),
    [anon_sym_group] = ACTIONS(5203),
    [anon_sym_by] = ACTIONS(5203),
    [anon_sym_select] = ACTIONS(5203),
    [aux_sym_preproc_if_token1] = ACTIONS(5205),
    [aux_sym_preproc_if_token3] = ACTIONS(5205),
    [aux_sym_preproc_else_token1] = ACTIONS(5205),
    [aux_sym_preproc_elif_token1] = ACTIONS(5205),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3434] = {
    [sym_preproc_region] = STATE(3434),
    [sym_preproc_endregion] = STATE(3434),
    [sym_preproc_line] = STATE(3434),
    [sym_preproc_pragma] = STATE(3434),
    [sym_preproc_nullable] = STATE(3434),
    [sym_preproc_error] = STATE(3434),
    [sym_preproc_warning] = STATE(3434),
    [sym_preproc_define] = STATE(3434),
    [sym_preproc_undef] = STATE(3434),
    [sym__identifier_token] = ACTIONS(5207),
    [anon_sym_extern] = ACTIONS(5207),
    [anon_sym_alias] = ACTIONS(5207),
    [anon_sym_global] = ACTIONS(5207),
    [anon_sym_using] = ACTIONS(5207),
    [anon_sym_unsafe] = ACTIONS(5207),
    [anon_sym_static] = ACTIONS(5207),
    [anon_sym_LBRACK] = ACTIONS(5209),
    [anon_sym_LPAREN] = ACTIONS(5209),
    [anon_sym_event] = ACTIONS(5207),
    [anon_sym_namespace] = ACTIONS(5207),
    [anon_sym_class] = ACTIONS(5207),
    [anon_sym_ref] = ACTIONS(5207),
    [anon_sym_struct] = ACTIONS(5207),
    [anon_sym_enum] = ACTIONS(5207),
    [anon_sym_RBRACE] = ACTIONS(5209),
    [anon_sym_interface] = ACTIONS(5207),
    [anon_sym_delegate] = ACTIONS(5207),
    [anon_sym_record] = ACTIONS(5207),
    [anon_sym_abstract] = ACTIONS(5207),
    [anon_sym_async] = ACTIONS(5207),
    [anon_sym_const] = ACTIONS(5207),
    [anon_sym_file] = ACTIONS(5207),
    [anon_sym_fixed] = ACTIONS(5207),
    [anon_sym_internal] = ACTIONS(5207),
    [anon_sym_new] = ACTIONS(5207),
    [anon_sym_override] = ACTIONS(5207),
    [anon_sym_partial] = ACTIONS(5207),
    [anon_sym_private] = ACTIONS(5207),
    [anon_sym_protected] = ACTIONS(5207),
    [anon_sym_public] = ACTIONS(5207),
    [anon_sym_readonly] = ACTIONS(5207),
    [anon_sym_required] = ACTIONS(5207),
    [anon_sym_sealed] = ACTIONS(5207),
    [anon_sym_virtual] = ACTIONS(5207),
    [anon_sym_volatile] = ACTIONS(5207),
    [anon_sym_where] = ACTIONS(5207),
    [anon_sym_notnull] = ACTIONS(5207),
    [anon_sym_unmanaged] = ACTIONS(5207),
    [anon_sym_TILDE] = ACTIONS(5209),
    [anon_sym_implicit] = ACTIONS(5207),
    [anon_sym_explicit] = ACTIONS(5207),
    [anon_sym_scoped] = ACTIONS(5207),
    [anon_sym_var] = ACTIONS(5207),
    [sym_predefined_type] = ACTIONS(5207),
    [anon_sym_yield] = ACTIONS(5207),
    [anon_sym_when] = ACTIONS(5207),
    [anon_sym_from] = ACTIONS(5207),
    [anon_sym_into] = ACTIONS(5207),
    [anon_sym_join] = ACTIONS(5207),
    [anon_sym_on] = ACTIONS(5207),
    [anon_sym_equals] = ACTIONS(5207),
    [anon_sym_let] = ACTIONS(5207),
    [anon_sym_orderby] = ACTIONS(5207),
    [anon_sym_ascending] = ACTIONS(5207),
    [anon_sym_descending] = ACTIONS(5207),
    [anon_sym_group] = ACTIONS(5207),
    [anon_sym_by] = ACTIONS(5207),
    [anon_sym_select] = ACTIONS(5207),
    [aux_sym_preproc_if_token1] = ACTIONS(5209),
    [aux_sym_preproc_if_token3] = ACTIONS(5209),
    [aux_sym_preproc_else_token1] = ACTIONS(5209),
    [aux_sym_preproc_elif_token1] = ACTIONS(5209),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3435] = {
    [sym__variable_designation] = STATE(3957),
    [sym_parenthesized_variable_designation] = STATE(3966),
    [sym_identifier] = STATE(3983),
    [sym__reserved_identifier] = STATE(3939),
    [sym_preproc_region] = STATE(3435),
    [sym_preproc_endregion] = STATE(3435),
    [sym_preproc_line] = STATE(3435),
    [sym_preproc_pragma] = STATE(3435),
    [sym_preproc_nullable] = STATE(3435),
    [sym_preproc_error] = STATE(3435),
    [sym_preproc_warning] = STATE(3435),
    [sym_preproc_define] = STATE(3435),
    [sym_preproc_undef] = STATE(3435),
    [sym__identifier_token] = ACTIONS(4337),
    [anon_sym_alias] = ACTIONS(4339),
    [anon_sym_global] = ACTIONS(4339),
    [anon_sym_LBRACK] = ACTIONS(4441),
    [anon_sym_LPAREN] = ACTIONS(4441),
    [anon_sym_file] = ACTIONS(4339),
    [anon_sym_LT] = ACTIONS(4443),
    [anon_sym_GT] = ACTIONS(4443),
    [anon_sym_where] = ACTIONS(4339),
    [anon_sym_QMARK] = ACTIONS(4443),
    [anon_sym_notnull] = ACTIONS(4339),
    [anon_sym_unmanaged] = ACTIONS(4339),
    [anon_sym_BANG] = ACTIONS(4443),
    [anon_sym_PLUS_PLUS] = ACTIONS(4441),
    [anon_sym_DASH_DASH] = ACTIONS(4441),
    [anon_sym_PLUS] = ACTIONS(4443),
    [anon_sym_DASH] = ACTIONS(4443),
    [anon_sym_STAR] = ACTIONS(4441),
    [anon_sym_SLASH] = ACTIONS(4443),
    [anon_sym_PERCENT] = ACTIONS(4441),
    [anon_sym_CARET] = ACTIONS(4441),
    [anon_sym_PIPE] = ACTIONS(4443),
    [anon_sym_AMP] = ACTIONS(4443),
    [anon_sym_LT_LT] = ACTIONS(4441),
    [anon_sym_GT_GT] = ACTIONS(4443),
    [anon_sym_GT_GT_GT] = ACTIONS(4441),
    [anon_sym_EQ_EQ] = ACTIONS(4441),
    [anon_sym_BANG_EQ] = ACTIONS(4441),
    [anon_sym_GT_EQ] = ACTIONS(4441),
    [anon_sym_LT_EQ] = ACTIONS(4441),
    [anon_sym_DOT] = ACTIONS(4443),
    [anon_sym_scoped] = ACTIONS(4339),
    [anon_sym_var] = ACTIONS(4339),
    [anon_sym_yield] = ACTIONS(4339),
    [anon_sym_switch] = ACTIONS(4443),
    [anon_sym_when] = ACTIONS(4339),
    [sym_discard] = ACTIONS(4347),
    [anon_sym_DOT_DOT] = ACTIONS(4441),
    [anon_sym_and] = ACTIONS(4443),
    [anon_sym_or] = ACTIONS(4443),
    [anon_sym_AMP_AMP] = ACTIONS(4441),
    [anon_sym_PIPE_PIPE] = ACTIONS(4441),
    [anon_sym_QMARK_QMARK] = ACTIONS(4441),
    [anon_sym_from] = ACTIONS(4339),
    [anon_sym_into] = ACTIONS(4443),
    [anon_sym_join] = ACTIONS(4339),
    [anon_sym_on] = ACTIONS(4443),
    [anon_sym_equals] = ACTIONS(4339),
    [anon_sym_let] = ACTIONS(4339),
    [anon_sym_orderby] = ACTIONS(4339),
    [anon_sym_ascending] = ACTIONS(4339),
    [anon_sym_descending] = ACTIONS(4339),
    [anon_sym_group] = ACTIONS(4339),
    [anon_sym_by] = ACTIONS(4339),
    [anon_sym_select] = ACTIONS(4339),
    [anon_sym_as] = ACTIONS(4443),
    [anon_sym_is] = ACTIONS(4443),
    [anon_sym_DASH_GT] = ACTIONS(4441),
    [anon_sym_with] = ACTIONS(4443),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3436] = {
    [sym_preproc_region] = STATE(3436),
    [sym_preproc_endregion] = STATE(3436),
    [sym_preproc_line] = STATE(3436),
    [sym_preproc_pragma] = STATE(3436),
    [sym_preproc_nullable] = STATE(3436),
    [sym_preproc_error] = STATE(3436),
    [sym_preproc_warning] = STATE(3436),
    [sym_preproc_define] = STATE(3436),
    [sym_preproc_undef] = STATE(3436),
    [sym__identifier_token] = ACTIONS(5211),
    [anon_sym_extern] = ACTIONS(5211),
    [anon_sym_alias] = ACTIONS(5211),
    [anon_sym_global] = ACTIONS(5211),
    [anon_sym_using] = ACTIONS(5211),
    [anon_sym_unsafe] = ACTIONS(5211),
    [anon_sym_static] = ACTIONS(5211),
    [anon_sym_LBRACK] = ACTIONS(5213),
    [anon_sym_LPAREN] = ACTIONS(5213),
    [anon_sym_event] = ACTIONS(5211),
    [anon_sym_namespace] = ACTIONS(5211),
    [anon_sym_class] = ACTIONS(5211),
    [anon_sym_ref] = ACTIONS(5211),
    [anon_sym_struct] = ACTIONS(5211),
    [anon_sym_enum] = ACTIONS(5211),
    [anon_sym_RBRACE] = ACTIONS(5213),
    [anon_sym_interface] = ACTIONS(5211),
    [anon_sym_delegate] = ACTIONS(5211),
    [anon_sym_record] = ACTIONS(5211),
    [anon_sym_abstract] = ACTIONS(5211),
    [anon_sym_async] = ACTIONS(5211),
    [anon_sym_const] = ACTIONS(5211),
    [anon_sym_file] = ACTIONS(5211),
    [anon_sym_fixed] = ACTIONS(5211),
    [anon_sym_internal] = ACTIONS(5211),
    [anon_sym_new] = ACTIONS(5211),
    [anon_sym_override] = ACTIONS(5211),
    [anon_sym_partial] = ACTIONS(5211),
    [anon_sym_private] = ACTIONS(5211),
    [anon_sym_protected] = ACTIONS(5211),
    [anon_sym_public] = ACTIONS(5211),
    [anon_sym_readonly] = ACTIONS(5211),
    [anon_sym_required] = ACTIONS(5211),
    [anon_sym_sealed] = ACTIONS(5211),
    [anon_sym_virtual] = ACTIONS(5211),
    [anon_sym_volatile] = ACTIONS(5211),
    [anon_sym_where] = ACTIONS(5211),
    [anon_sym_notnull] = ACTIONS(5211),
    [anon_sym_unmanaged] = ACTIONS(5211),
    [anon_sym_TILDE] = ACTIONS(5213),
    [anon_sym_implicit] = ACTIONS(5211),
    [anon_sym_explicit] = ACTIONS(5211),
    [anon_sym_scoped] = ACTIONS(5211),
    [anon_sym_var] = ACTIONS(5211),
    [sym_predefined_type] = ACTIONS(5211),
    [anon_sym_yield] = ACTIONS(5211),
    [anon_sym_when] = ACTIONS(5211),
    [anon_sym_from] = ACTIONS(5211),
    [anon_sym_into] = ACTIONS(5211),
    [anon_sym_join] = ACTIONS(5211),
    [anon_sym_on] = ACTIONS(5211),
    [anon_sym_equals] = ACTIONS(5211),
    [anon_sym_let] = ACTIONS(5211),
    [anon_sym_orderby] = ACTIONS(5211),
    [anon_sym_ascending] = ACTIONS(5211),
    [anon_sym_descending] = ACTIONS(5211),
    [anon_sym_group] = ACTIONS(5211),
    [anon_sym_by] = ACTIONS(5211),
    [anon_sym_select] = ACTIONS(5211),
    [aux_sym_preproc_if_token1] = ACTIONS(5213),
    [aux_sym_preproc_if_token3] = ACTIONS(5213),
    [aux_sym_preproc_else_token1] = ACTIONS(5213),
    [aux_sym_preproc_elif_token1] = ACTIONS(5213),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3437] = {
    [sym_preproc_region] = STATE(3437),
    [sym_preproc_endregion] = STATE(3437),
    [sym_preproc_line] = STATE(3437),
    [sym_preproc_pragma] = STATE(3437),
    [sym_preproc_nullable] = STATE(3437),
    [sym_preproc_error] = STATE(3437),
    [sym_preproc_warning] = STATE(3437),
    [sym_preproc_define] = STATE(3437),
    [sym_preproc_undef] = STATE(3437),
    [sym__identifier_token] = ACTIONS(3485),
    [anon_sym_extern] = ACTIONS(3485),
    [anon_sym_alias] = ACTIONS(3485),
    [anon_sym_global] = ACTIONS(3485),
    [anon_sym_using] = ACTIONS(3485),
    [anon_sym_unsafe] = ACTIONS(3485),
    [anon_sym_static] = ACTIONS(3485),
    [anon_sym_LBRACK] = ACTIONS(3487),
    [anon_sym_LPAREN] = ACTIONS(3487),
    [anon_sym_event] = ACTIONS(3485),
    [anon_sym_namespace] = ACTIONS(3485),
    [anon_sym_class] = ACTIONS(3485),
    [anon_sym_ref] = ACTIONS(3485),
    [anon_sym_struct] = ACTIONS(3485),
    [anon_sym_enum] = ACTIONS(3485),
    [anon_sym_RBRACE] = ACTIONS(3487),
    [anon_sym_interface] = ACTIONS(3485),
    [anon_sym_delegate] = ACTIONS(3485),
    [anon_sym_record] = ACTIONS(3485),
    [anon_sym_abstract] = ACTIONS(3485),
    [anon_sym_async] = ACTIONS(3485),
    [anon_sym_const] = ACTIONS(3485),
    [anon_sym_file] = ACTIONS(3485),
    [anon_sym_fixed] = ACTIONS(3485),
    [anon_sym_internal] = ACTIONS(3485),
    [anon_sym_new] = ACTIONS(3485),
    [anon_sym_override] = ACTIONS(3485),
    [anon_sym_partial] = ACTIONS(3485),
    [anon_sym_private] = ACTIONS(3485),
    [anon_sym_protected] = ACTIONS(3485),
    [anon_sym_public] = ACTIONS(3485),
    [anon_sym_readonly] = ACTIONS(3485),
    [anon_sym_required] = ACTIONS(3485),
    [anon_sym_sealed] = ACTIONS(3485),
    [anon_sym_virtual] = ACTIONS(3485),
    [anon_sym_volatile] = ACTIONS(3485),
    [anon_sym_where] = ACTIONS(3485),
    [anon_sym_notnull] = ACTIONS(3485),
    [anon_sym_unmanaged] = ACTIONS(3485),
    [anon_sym_TILDE] = ACTIONS(3487),
    [anon_sym_implicit] = ACTIONS(3485),
    [anon_sym_explicit] = ACTIONS(3485),
    [anon_sym_scoped] = ACTIONS(3485),
    [anon_sym_var] = ACTIONS(3485),
    [sym_predefined_type] = ACTIONS(3485),
    [anon_sym_yield] = ACTIONS(3485),
    [anon_sym_when] = ACTIONS(3485),
    [anon_sym_from] = ACTIONS(3485),
    [anon_sym_into] = ACTIONS(3485),
    [anon_sym_join] = ACTIONS(3485),
    [anon_sym_on] = ACTIONS(3485),
    [anon_sym_equals] = ACTIONS(3485),
    [anon_sym_let] = ACTIONS(3485),
    [anon_sym_orderby] = ACTIONS(3485),
    [anon_sym_ascending] = ACTIONS(3485),
    [anon_sym_descending] = ACTIONS(3485),
    [anon_sym_group] = ACTIONS(3485),
    [anon_sym_by] = ACTIONS(3485),
    [anon_sym_select] = ACTIONS(3485),
    [aux_sym_preproc_if_token1] = ACTIONS(3487),
    [aux_sym_preproc_if_token3] = ACTIONS(3487),
    [aux_sym_preproc_else_token1] = ACTIONS(3487),
    [aux_sym_preproc_elif_token1] = ACTIONS(3487),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3438] = {
    [sym_preproc_region] = STATE(3438),
    [sym_preproc_endregion] = STATE(3438),
    [sym_preproc_line] = STATE(3438),
    [sym_preproc_pragma] = STATE(3438),
    [sym_preproc_nullable] = STATE(3438),
    [sym_preproc_error] = STATE(3438),
    [sym_preproc_warning] = STATE(3438),
    [sym_preproc_define] = STATE(3438),
    [sym_preproc_undef] = STATE(3438),
    [anon_sym_SEMI] = ACTIONS(4151),
    [anon_sym_EQ] = ACTIONS(4149),
    [anon_sym_LBRACK] = ACTIONS(4151),
    [anon_sym_COLON] = ACTIONS(4151),
    [anon_sym_COMMA] = ACTIONS(4151),
    [anon_sym_RBRACK] = ACTIONS(4151),
    [anon_sym_LPAREN] = ACTIONS(4151),
    [anon_sym_RPAREN] = ACTIONS(4151),
    [anon_sym_RBRACE] = ACTIONS(4151),
    [anon_sym_LT] = ACTIONS(4149),
    [anon_sym_GT] = ACTIONS(4149),
    [anon_sym_in] = ACTIONS(4151),
    [anon_sym_QMARK] = ACTIONS(4149),
    [anon_sym_BANG] = ACTIONS(4149),
    [anon_sym_PLUS_PLUS] = ACTIONS(4151),
    [anon_sym_DASH_DASH] = ACTIONS(4151),
    [anon_sym_PLUS] = ACTIONS(4149),
    [anon_sym_DASH] = ACTIONS(4149),
    [anon_sym_STAR] = ACTIONS(4149),
    [anon_sym_SLASH] = ACTIONS(4149),
    [anon_sym_PERCENT] = ACTIONS(4149),
    [anon_sym_CARET] = ACTIONS(4149),
    [anon_sym_PIPE] = ACTIONS(4149),
    [anon_sym_AMP] = ACTIONS(4149),
    [anon_sym_LT_LT] = ACTIONS(4149),
    [anon_sym_GT_GT] = ACTIONS(4149),
    [anon_sym_GT_GT_GT] = ACTIONS(4149),
    [anon_sym_EQ_EQ] = ACTIONS(4151),
    [anon_sym_BANG_EQ] = ACTIONS(4151),
    [anon_sym_GT_EQ] = ACTIONS(4151),
    [anon_sym_LT_EQ] = ACTIONS(4151),
    [anon_sym_DOT] = ACTIONS(4149),
    [anon_sym_EQ_GT] = ACTIONS(4151),
    [anon_sym_switch] = ACTIONS(4151),
    [anon_sym_when] = ACTIONS(4151),
    [anon_sym_DOT_DOT] = ACTIONS(4151),
    [anon_sym_and] = ACTIONS(4151),
    [anon_sym_or] = ACTIONS(4151),
    [anon_sym_PLUS_EQ] = ACTIONS(4151),
    [anon_sym_DASH_EQ] = ACTIONS(4151),
    [anon_sym_STAR_EQ] = ACTIONS(4151),
    [anon_sym_SLASH_EQ] = ACTIONS(4151),
    [anon_sym_PERCENT_EQ] = ACTIONS(4151),
    [anon_sym_AMP_EQ] = ACTIONS(4151),
    [anon_sym_CARET_EQ] = ACTIONS(4151),
    [anon_sym_PIPE_EQ] = ACTIONS(4151),
    [anon_sym_LT_LT_EQ] = ACTIONS(4151),
    [anon_sym_GT_GT_EQ] = ACTIONS(4151),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4151),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4151),
    [anon_sym_AMP_AMP] = ACTIONS(4151),
    [anon_sym_PIPE_PIPE] = ACTIONS(4151),
    [anon_sym_QMARK_QMARK] = ACTIONS(4149),
    [anon_sym_on] = ACTIONS(4151),
    [anon_sym_equals] = ACTIONS(4151),
    [anon_sym_by] = ACTIONS(4151),
    [anon_sym_as] = ACTIONS(4151),
    [anon_sym_is] = ACTIONS(4151),
    [anon_sym_DASH_GT] = ACTIONS(4151),
    [anon_sym_with] = ACTIONS(4151),
    [aux_sym_preproc_if_token3] = ACTIONS(4151),
    [aux_sym_preproc_else_token1] = ACTIONS(4151),
    [aux_sym_preproc_elif_token1] = ACTIONS(4151),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3439] = {
    [sym_preproc_region] = STATE(3439),
    [sym_preproc_endregion] = STATE(3439),
    [sym_preproc_line] = STATE(3439),
    [sym_preproc_pragma] = STATE(3439),
    [sym_preproc_nullable] = STATE(3439),
    [sym_preproc_error] = STATE(3439),
    [sym_preproc_warning] = STATE(3439),
    [sym_preproc_define] = STATE(3439),
    [sym_preproc_undef] = STATE(3439),
    [sym__identifier_token] = ACTIONS(3493),
    [anon_sym_extern] = ACTIONS(3493),
    [anon_sym_alias] = ACTIONS(3493),
    [anon_sym_global] = ACTIONS(3493),
    [anon_sym_using] = ACTIONS(3493),
    [anon_sym_unsafe] = ACTIONS(3493),
    [anon_sym_static] = ACTIONS(3493),
    [anon_sym_LBRACK] = ACTIONS(3495),
    [anon_sym_LPAREN] = ACTIONS(3495),
    [anon_sym_event] = ACTIONS(3493),
    [anon_sym_namespace] = ACTIONS(3493),
    [anon_sym_class] = ACTIONS(3493),
    [anon_sym_ref] = ACTIONS(3493),
    [anon_sym_struct] = ACTIONS(3493),
    [anon_sym_enum] = ACTIONS(3493),
    [anon_sym_RBRACE] = ACTIONS(3495),
    [anon_sym_interface] = ACTIONS(3493),
    [anon_sym_delegate] = ACTIONS(3493),
    [anon_sym_record] = ACTIONS(3493),
    [anon_sym_abstract] = ACTIONS(3493),
    [anon_sym_async] = ACTIONS(3493),
    [anon_sym_const] = ACTIONS(3493),
    [anon_sym_file] = ACTIONS(3493),
    [anon_sym_fixed] = ACTIONS(3493),
    [anon_sym_internal] = ACTIONS(3493),
    [anon_sym_new] = ACTIONS(3493),
    [anon_sym_override] = ACTIONS(3493),
    [anon_sym_partial] = ACTIONS(3493),
    [anon_sym_private] = ACTIONS(3493),
    [anon_sym_protected] = ACTIONS(3493),
    [anon_sym_public] = ACTIONS(3493),
    [anon_sym_readonly] = ACTIONS(3493),
    [anon_sym_required] = ACTIONS(3493),
    [anon_sym_sealed] = ACTIONS(3493),
    [anon_sym_virtual] = ACTIONS(3493),
    [anon_sym_volatile] = ACTIONS(3493),
    [anon_sym_where] = ACTIONS(3493),
    [anon_sym_notnull] = ACTIONS(3493),
    [anon_sym_unmanaged] = ACTIONS(3493),
    [anon_sym_TILDE] = ACTIONS(3495),
    [anon_sym_implicit] = ACTIONS(3493),
    [anon_sym_explicit] = ACTIONS(3493),
    [anon_sym_scoped] = ACTIONS(3493),
    [anon_sym_var] = ACTIONS(3493),
    [sym_predefined_type] = ACTIONS(3493),
    [anon_sym_yield] = ACTIONS(3493),
    [anon_sym_when] = ACTIONS(3493),
    [anon_sym_from] = ACTIONS(3493),
    [anon_sym_into] = ACTIONS(3493),
    [anon_sym_join] = ACTIONS(3493),
    [anon_sym_on] = ACTIONS(3493),
    [anon_sym_equals] = ACTIONS(3493),
    [anon_sym_let] = ACTIONS(3493),
    [anon_sym_orderby] = ACTIONS(3493),
    [anon_sym_ascending] = ACTIONS(3493),
    [anon_sym_descending] = ACTIONS(3493),
    [anon_sym_group] = ACTIONS(3493),
    [anon_sym_by] = ACTIONS(3493),
    [anon_sym_select] = ACTIONS(3493),
    [aux_sym_preproc_if_token1] = ACTIONS(3495),
    [aux_sym_preproc_if_token3] = ACTIONS(3495),
    [aux_sym_preproc_else_token1] = ACTIONS(3495),
    [aux_sym_preproc_elif_token1] = ACTIONS(3495),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3440] = {
    [sym_preproc_region] = STATE(3440),
    [sym_preproc_endregion] = STATE(3440),
    [sym_preproc_line] = STATE(3440),
    [sym_preproc_pragma] = STATE(3440),
    [sym_preproc_nullable] = STATE(3440),
    [sym_preproc_error] = STATE(3440),
    [sym_preproc_warning] = STATE(3440),
    [sym_preproc_define] = STATE(3440),
    [sym_preproc_undef] = STATE(3440),
    [sym__identifier_token] = ACTIONS(3497),
    [anon_sym_extern] = ACTIONS(3497),
    [anon_sym_alias] = ACTIONS(3497),
    [anon_sym_global] = ACTIONS(3497),
    [anon_sym_using] = ACTIONS(3497),
    [anon_sym_unsafe] = ACTIONS(3497),
    [anon_sym_static] = ACTIONS(3497),
    [anon_sym_LBRACK] = ACTIONS(3499),
    [anon_sym_LPAREN] = ACTIONS(3499),
    [anon_sym_event] = ACTIONS(3497),
    [anon_sym_namespace] = ACTIONS(3497),
    [anon_sym_class] = ACTIONS(3497),
    [anon_sym_ref] = ACTIONS(3497),
    [anon_sym_struct] = ACTIONS(3497),
    [anon_sym_enum] = ACTIONS(3497),
    [anon_sym_RBRACE] = ACTIONS(3499),
    [anon_sym_interface] = ACTIONS(3497),
    [anon_sym_delegate] = ACTIONS(3497),
    [anon_sym_record] = ACTIONS(3497),
    [anon_sym_abstract] = ACTIONS(3497),
    [anon_sym_async] = ACTIONS(3497),
    [anon_sym_const] = ACTIONS(3497),
    [anon_sym_file] = ACTIONS(3497),
    [anon_sym_fixed] = ACTIONS(3497),
    [anon_sym_internal] = ACTIONS(3497),
    [anon_sym_new] = ACTIONS(3497),
    [anon_sym_override] = ACTIONS(3497),
    [anon_sym_partial] = ACTIONS(3497),
    [anon_sym_private] = ACTIONS(3497),
    [anon_sym_protected] = ACTIONS(3497),
    [anon_sym_public] = ACTIONS(3497),
    [anon_sym_readonly] = ACTIONS(3497),
    [anon_sym_required] = ACTIONS(3497),
    [anon_sym_sealed] = ACTIONS(3497),
    [anon_sym_virtual] = ACTIONS(3497),
    [anon_sym_volatile] = ACTIONS(3497),
    [anon_sym_where] = ACTIONS(3497),
    [anon_sym_notnull] = ACTIONS(3497),
    [anon_sym_unmanaged] = ACTIONS(3497),
    [anon_sym_TILDE] = ACTIONS(3499),
    [anon_sym_implicit] = ACTIONS(3497),
    [anon_sym_explicit] = ACTIONS(3497),
    [anon_sym_scoped] = ACTIONS(3497),
    [anon_sym_var] = ACTIONS(3497),
    [sym_predefined_type] = ACTIONS(3497),
    [anon_sym_yield] = ACTIONS(3497),
    [anon_sym_when] = ACTIONS(3497),
    [anon_sym_from] = ACTIONS(3497),
    [anon_sym_into] = ACTIONS(3497),
    [anon_sym_join] = ACTIONS(3497),
    [anon_sym_on] = ACTIONS(3497),
    [anon_sym_equals] = ACTIONS(3497),
    [anon_sym_let] = ACTIONS(3497),
    [anon_sym_orderby] = ACTIONS(3497),
    [anon_sym_ascending] = ACTIONS(3497),
    [anon_sym_descending] = ACTIONS(3497),
    [anon_sym_group] = ACTIONS(3497),
    [anon_sym_by] = ACTIONS(3497),
    [anon_sym_select] = ACTIONS(3497),
    [aux_sym_preproc_if_token1] = ACTIONS(3499),
    [aux_sym_preproc_if_token3] = ACTIONS(3499),
    [aux_sym_preproc_else_token1] = ACTIONS(3499),
    [aux_sym_preproc_elif_token1] = ACTIONS(3499),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3441] = {
    [sym_preproc_region] = STATE(3441),
    [sym_preproc_endregion] = STATE(3441),
    [sym_preproc_line] = STATE(3441),
    [sym_preproc_pragma] = STATE(3441),
    [sym_preproc_nullable] = STATE(3441),
    [sym_preproc_error] = STATE(3441),
    [sym_preproc_warning] = STATE(3441),
    [sym_preproc_define] = STATE(3441),
    [sym_preproc_undef] = STATE(3441),
    [sym__identifier_token] = ACTIONS(3501),
    [anon_sym_extern] = ACTIONS(3501),
    [anon_sym_alias] = ACTIONS(3501),
    [anon_sym_global] = ACTIONS(3501),
    [anon_sym_using] = ACTIONS(3501),
    [anon_sym_unsafe] = ACTIONS(3501),
    [anon_sym_static] = ACTIONS(3501),
    [anon_sym_LBRACK] = ACTIONS(3503),
    [anon_sym_LPAREN] = ACTIONS(3503),
    [anon_sym_event] = ACTIONS(3501),
    [anon_sym_namespace] = ACTIONS(3501),
    [anon_sym_class] = ACTIONS(3501),
    [anon_sym_ref] = ACTIONS(3501),
    [anon_sym_struct] = ACTIONS(3501),
    [anon_sym_enum] = ACTIONS(3501),
    [anon_sym_RBRACE] = ACTIONS(3503),
    [anon_sym_interface] = ACTIONS(3501),
    [anon_sym_delegate] = ACTIONS(3501),
    [anon_sym_record] = ACTIONS(3501),
    [anon_sym_abstract] = ACTIONS(3501),
    [anon_sym_async] = ACTIONS(3501),
    [anon_sym_const] = ACTIONS(3501),
    [anon_sym_file] = ACTIONS(3501),
    [anon_sym_fixed] = ACTIONS(3501),
    [anon_sym_internal] = ACTIONS(3501),
    [anon_sym_new] = ACTIONS(3501),
    [anon_sym_override] = ACTIONS(3501),
    [anon_sym_partial] = ACTIONS(3501),
    [anon_sym_private] = ACTIONS(3501),
    [anon_sym_protected] = ACTIONS(3501),
    [anon_sym_public] = ACTIONS(3501),
    [anon_sym_readonly] = ACTIONS(3501),
    [anon_sym_required] = ACTIONS(3501),
    [anon_sym_sealed] = ACTIONS(3501),
    [anon_sym_virtual] = ACTIONS(3501),
    [anon_sym_volatile] = ACTIONS(3501),
    [anon_sym_where] = ACTIONS(3501),
    [anon_sym_notnull] = ACTIONS(3501),
    [anon_sym_unmanaged] = ACTIONS(3501),
    [anon_sym_TILDE] = ACTIONS(3503),
    [anon_sym_implicit] = ACTIONS(3501),
    [anon_sym_explicit] = ACTIONS(3501),
    [anon_sym_scoped] = ACTIONS(3501),
    [anon_sym_var] = ACTIONS(3501),
    [sym_predefined_type] = ACTIONS(3501),
    [anon_sym_yield] = ACTIONS(3501),
    [anon_sym_when] = ACTIONS(3501),
    [anon_sym_from] = ACTIONS(3501),
    [anon_sym_into] = ACTIONS(3501),
    [anon_sym_join] = ACTIONS(3501),
    [anon_sym_on] = ACTIONS(3501),
    [anon_sym_equals] = ACTIONS(3501),
    [anon_sym_let] = ACTIONS(3501),
    [anon_sym_orderby] = ACTIONS(3501),
    [anon_sym_ascending] = ACTIONS(3501),
    [anon_sym_descending] = ACTIONS(3501),
    [anon_sym_group] = ACTIONS(3501),
    [anon_sym_by] = ACTIONS(3501),
    [anon_sym_select] = ACTIONS(3501),
    [aux_sym_preproc_if_token1] = ACTIONS(3503),
    [aux_sym_preproc_if_token3] = ACTIONS(3503),
    [aux_sym_preproc_else_token1] = ACTIONS(3503),
    [aux_sym_preproc_elif_token1] = ACTIONS(3503),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3442] = {
    [sym__variable_designation] = STATE(5036),
    [sym_parenthesized_variable_designation] = STATE(5027),
    [sym_identifier] = STATE(5034),
    [sym__reserved_identifier] = STATE(3625),
    [sym_preproc_region] = STATE(3442),
    [sym_preproc_endregion] = STATE(3442),
    [sym_preproc_line] = STATE(3442),
    [sym_preproc_pragma] = STATE(3442),
    [sym_preproc_nullable] = STATE(3442),
    [sym_preproc_error] = STATE(3442),
    [sym_preproc_warning] = STATE(3442),
    [sym_preproc_define] = STATE(3442),
    [sym_preproc_undef] = STATE(3442),
    [sym__identifier_token] = ACTIONS(4349),
    [anon_sym_alias] = ACTIONS(4351),
    [anon_sym_global] = ACTIONS(4351),
    [anon_sym_LBRACK] = ACTIONS(4405),
    [anon_sym_LPAREN] = ACTIONS(4405),
    [anon_sym_file] = ACTIONS(4351),
    [anon_sym_LT] = ACTIONS(4407),
    [anon_sym_GT] = ACTIONS(4407),
    [anon_sym_where] = ACTIONS(4407),
    [anon_sym_QMARK] = ACTIONS(4407),
    [anon_sym_notnull] = ACTIONS(4351),
    [anon_sym_unmanaged] = ACTIONS(4351),
    [anon_sym_BANG] = ACTIONS(4407),
    [anon_sym_PLUS_PLUS] = ACTIONS(4405),
    [anon_sym_DASH_DASH] = ACTIONS(4405),
    [anon_sym_PLUS] = ACTIONS(4407),
    [anon_sym_DASH] = ACTIONS(4407),
    [anon_sym_STAR] = ACTIONS(4405),
    [anon_sym_SLASH] = ACTIONS(4407),
    [anon_sym_PERCENT] = ACTIONS(4405),
    [anon_sym_CARET] = ACTIONS(4405),
    [anon_sym_PIPE] = ACTIONS(4407),
    [anon_sym_AMP] = ACTIONS(4407),
    [anon_sym_LT_LT] = ACTIONS(4405),
    [anon_sym_GT_GT] = ACTIONS(4407),
    [anon_sym_GT_GT_GT] = ACTIONS(4405),
    [anon_sym_EQ_EQ] = ACTIONS(4405),
    [anon_sym_BANG_EQ] = ACTIONS(4405),
    [anon_sym_GT_EQ] = ACTIONS(4405),
    [anon_sym_LT_EQ] = ACTIONS(4405),
    [anon_sym_DOT] = ACTIONS(4407),
    [anon_sym_scoped] = ACTIONS(4351),
    [anon_sym_var] = ACTIONS(4351),
    [anon_sym_yield] = ACTIONS(4351),
    [anon_sym_switch] = ACTIONS(4407),
    [anon_sym_when] = ACTIONS(4351),
    [sym_discard] = ACTIONS(4719),
    [anon_sym_DOT_DOT] = ACTIONS(4405),
    [anon_sym_and] = ACTIONS(4407),
    [anon_sym_or] = ACTIONS(4407),
    [anon_sym_AMP_AMP] = ACTIONS(4405),
    [anon_sym_PIPE_PIPE] = ACTIONS(4405),
    [anon_sym_QMARK_QMARK] = ACTIONS(4405),
    [anon_sym_from] = ACTIONS(4407),
    [anon_sym_into] = ACTIONS(4351),
    [anon_sym_join] = ACTIONS(4407),
    [anon_sym_on] = ACTIONS(4351),
    [anon_sym_equals] = ACTIONS(4351),
    [anon_sym_let] = ACTIONS(4407),
    [anon_sym_orderby] = ACTIONS(4407),
    [anon_sym_ascending] = ACTIONS(4351),
    [anon_sym_descending] = ACTIONS(4351),
    [anon_sym_group] = ACTIONS(4407),
    [anon_sym_by] = ACTIONS(4351),
    [anon_sym_select] = ACTIONS(4407),
    [anon_sym_as] = ACTIONS(4407),
    [anon_sym_is] = ACTIONS(4407),
    [anon_sym_DASH_GT] = ACTIONS(4405),
    [anon_sym_with] = ACTIONS(4407),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3443] = {
    [sym__variable_designation] = STATE(5021),
    [sym_parenthesized_variable_designation] = STATE(5027),
    [sym_identifier] = STATE(5034),
    [sym__reserved_identifier] = STATE(3625),
    [sym_preproc_region] = STATE(3443),
    [sym_preproc_endregion] = STATE(3443),
    [sym_preproc_line] = STATE(3443),
    [sym_preproc_pragma] = STATE(3443),
    [sym_preproc_nullable] = STATE(3443),
    [sym_preproc_error] = STATE(3443),
    [sym_preproc_warning] = STATE(3443),
    [sym_preproc_define] = STATE(3443),
    [sym_preproc_undef] = STATE(3443),
    [sym__identifier_token] = ACTIONS(4349),
    [anon_sym_alias] = ACTIONS(4351),
    [anon_sym_global] = ACTIONS(4351),
    [anon_sym_LBRACK] = ACTIONS(4437),
    [anon_sym_LPAREN] = ACTIONS(4437),
    [anon_sym_file] = ACTIONS(4351),
    [anon_sym_LT] = ACTIONS(4439),
    [anon_sym_GT] = ACTIONS(4439),
    [anon_sym_where] = ACTIONS(4439),
    [anon_sym_QMARK] = ACTIONS(4439),
    [anon_sym_notnull] = ACTIONS(4351),
    [anon_sym_unmanaged] = ACTIONS(4351),
    [anon_sym_BANG] = ACTIONS(4439),
    [anon_sym_PLUS_PLUS] = ACTIONS(4437),
    [anon_sym_DASH_DASH] = ACTIONS(4437),
    [anon_sym_PLUS] = ACTIONS(4439),
    [anon_sym_DASH] = ACTIONS(4439),
    [anon_sym_STAR] = ACTIONS(4437),
    [anon_sym_SLASH] = ACTIONS(4439),
    [anon_sym_PERCENT] = ACTIONS(4437),
    [anon_sym_CARET] = ACTIONS(4437),
    [anon_sym_PIPE] = ACTIONS(4439),
    [anon_sym_AMP] = ACTIONS(4439),
    [anon_sym_LT_LT] = ACTIONS(4437),
    [anon_sym_GT_GT] = ACTIONS(4439),
    [anon_sym_GT_GT_GT] = ACTIONS(4437),
    [anon_sym_EQ_EQ] = ACTIONS(4437),
    [anon_sym_BANG_EQ] = ACTIONS(4437),
    [anon_sym_GT_EQ] = ACTIONS(4437),
    [anon_sym_LT_EQ] = ACTIONS(4437),
    [anon_sym_DOT] = ACTIONS(4439),
    [anon_sym_scoped] = ACTIONS(4351),
    [anon_sym_var] = ACTIONS(4351),
    [anon_sym_yield] = ACTIONS(4351),
    [anon_sym_switch] = ACTIONS(4439),
    [anon_sym_when] = ACTIONS(4351),
    [sym_discard] = ACTIONS(4719),
    [anon_sym_DOT_DOT] = ACTIONS(4437),
    [anon_sym_and] = ACTIONS(4439),
    [anon_sym_or] = ACTIONS(4439),
    [anon_sym_AMP_AMP] = ACTIONS(4437),
    [anon_sym_PIPE_PIPE] = ACTIONS(4437),
    [anon_sym_QMARK_QMARK] = ACTIONS(4437),
    [anon_sym_from] = ACTIONS(4439),
    [anon_sym_into] = ACTIONS(4351),
    [anon_sym_join] = ACTIONS(4439),
    [anon_sym_on] = ACTIONS(4351),
    [anon_sym_equals] = ACTIONS(4351),
    [anon_sym_let] = ACTIONS(4439),
    [anon_sym_orderby] = ACTIONS(4439),
    [anon_sym_ascending] = ACTIONS(4351),
    [anon_sym_descending] = ACTIONS(4351),
    [anon_sym_group] = ACTIONS(4439),
    [anon_sym_by] = ACTIONS(4351),
    [anon_sym_select] = ACTIONS(4439),
    [anon_sym_as] = ACTIONS(4439),
    [anon_sym_is] = ACTIONS(4439),
    [anon_sym_DASH_GT] = ACTIONS(4437),
    [anon_sym_with] = ACTIONS(4439),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3444] = {
    [sym_preproc_region] = STATE(3444),
    [sym_preproc_endregion] = STATE(3444),
    [sym_preproc_line] = STATE(3444),
    [sym_preproc_pragma] = STATE(3444),
    [sym_preproc_nullable] = STATE(3444),
    [sym_preproc_error] = STATE(3444),
    [sym_preproc_warning] = STATE(3444),
    [sym_preproc_define] = STATE(3444),
    [sym_preproc_undef] = STATE(3444),
    [anon_sym_SEMI] = ACTIONS(4128),
    [anon_sym_EQ] = ACTIONS(4126),
    [anon_sym_LBRACK] = ACTIONS(4128),
    [anon_sym_COLON] = ACTIONS(4128),
    [anon_sym_COMMA] = ACTIONS(4128),
    [anon_sym_RBRACK] = ACTIONS(4128),
    [anon_sym_LPAREN] = ACTIONS(4128),
    [anon_sym_RPAREN] = ACTIONS(4128),
    [anon_sym_RBRACE] = ACTIONS(4128),
    [anon_sym_LT] = ACTIONS(4126),
    [anon_sym_GT] = ACTIONS(4126),
    [anon_sym_in] = ACTIONS(4128),
    [anon_sym_QMARK] = ACTIONS(4126),
    [anon_sym_BANG] = ACTIONS(4126),
    [anon_sym_PLUS_PLUS] = ACTIONS(4128),
    [anon_sym_DASH_DASH] = ACTIONS(4128),
    [anon_sym_PLUS] = ACTIONS(4126),
    [anon_sym_DASH] = ACTIONS(4126),
    [anon_sym_STAR] = ACTIONS(4126),
    [anon_sym_SLASH] = ACTIONS(4126),
    [anon_sym_PERCENT] = ACTIONS(4126),
    [anon_sym_CARET] = ACTIONS(4126),
    [anon_sym_PIPE] = ACTIONS(4126),
    [anon_sym_AMP] = ACTIONS(4126),
    [anon_sym_LT_LT] = ACTIONS(4126),
    [anon_sym_GT_GT] = ACTIONS(4126),
    [anon_sym_GT_GT_GT] = ACTIONS(4126),
    [anon_sym_EQ_EQ] = ACTIONS(4128),
    [anon_sym_BANG_EQ] = ACTIONS(4128),
    [anon_sym_GT_EQ] = ACTIONS(4128),
    [anon_sym_LT_EQ] = ACTIONS(4128),
    [anon_sym_DOT] = ACTIONS(4126),
    [anon_sym_EQ_GT] = ACTIONS(4128),
    [anon_sym_switch] = ACTIONS(4128),
    [anon_sym_when] = ACTIONS(4128),
    [anon_sym_DOT_DOT] = ACTIONS(4128),
    [anon_sym_and] = ACTIONS(4128),
    [anon_sym_or] = ACTIONS(4128),
    [anon_sym_PLUS_EQ] = ACTIONS(4128),
    [anon_sym_DASH_EQ] = ACTIONS(4128),
    [anon_sym_STAR_EQ] = ACTIONS(4128),
    [anon_sym_SLASH_EQ] = ACTIONS(4128),
    [anon_sym_PERCENT_EQ] = ACTIONS(4128),
    [anon_sym_AMP_EQ] = ACTIONS(4128),
    [anon_sym_CARET_EQ] = ACTIONS(4128),
    [anon_sym_PIPE_EQ] = ACTIONS(4128),
    [anon_sym_LT_LT_EQ] = ACTIONS(4128),
    [anon_sym_GT_GT_EQ] = ACTIONS(4128),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4128),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4128),
    [anon_sym_AMP_AMP] = ACTIONS(4128),
    [anon_sym_PIPE_PIPE] = ACTIONS(4128),
    [anon_sym_QMARK_QMARK] = ACTIONS(4126),
    [anon_sym_on] = ACTIONS(4128),
    [anon_sym_equals] = ACTIONS(4128),
    [anon_sym_by] = ACTIONS(4128),
    [anon_sym_as] = ACTIONS(4128),
    [anon_sym_is] = ACTIONS(4128),
    [anon_sym_DASH_GT] = ACTIONS(4128),
    [anon_sym_with] = ACTIONS(4128),
    [aux_sym_preproc_if_token3] = ACTIONS(4128),
    [aux_sym_preproc_else_token1] = ACTIONS(4128),
    [aux_sym_preproc_elif_token1] = ACTIONS(4128),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3445] = {
    [sym_preproc_region] = STATE(3445),
    [sym_preproc_endregion] = STATE(3445),
    [sym_preproc_line] = STATE(3445),
    [sym_preproc_pragma] = STATE(3445),
    [sym_preproc_nullable] = STATE(3445),
    [sym_preproc_error] = STATE(3445),
    [sym_preproc_warning] = STATE(3445),
    [sym_preproc_define] = STATE(3445),
    [sym_preproc_undef] = STATE(3445),
    [sym__identifier_token] = ACTIONS(4482),
    [anon_sym_alias] = ACTIONS(4482),
    [anon_sym_global] = ACTIONS(4482),
    [anon_sym_LBRACK] = ACTIONS(4484),
    [anon_sym_COLON] = ACTIONS(4484),
    [anon_sym_COMMA] = ACTIONS(4484),
    [anon_sym_LPAREN] = ACTIONS(4484),
    [anon_sym_LBRACE] = ACTIONS(4484),
    [anon_sym_file] = ACTIONS(4482),
    [anon_sym_LT] = ACTIONS(4482),
    [anon_sym_GT] = ACTIONS(4482),
    [anon_sym_where] = ACTIONS(4482),
    [anon_sym_QMARK] = ACTIONS(4482),
    [anon_sym_notnull] = ACTIONS(4482),
    [anon_sym_unmanaged] = ACTIONS(4482),
    [anon_sym_BANG] = ACTIONS(4482),
    [anon_sym_PLUS_PLUS] = ACTIONS(4484),
    [anon_sym_DASH_DASH] = ACTIONS(4484),
    [anon_sym_PLUS] = ACTIONS(4482),
    [anon_sym_DASH] = ACTIONS(4482),
    [anon_sym_STAR] = ACTIONS(4484),
    [anon_sym_SLASH] = ACTIONS(4482),
    [anon_sym_PERCENT] = ACTIONS(4484),
    [anon_sym_CARET] = ACTIONS(4484),
    [anon_sym_PIPE] = ACTIONS(4482),
    [anon_sym_AMP] = ACTIONS(4482),
    [anon_sym_LT_LT] = ACTIONS(4484),
    [anon_sym_GT_GT] = ACTIONS(4482),
    [anon_sym_GT_GT_GT] = ACTIONS(4484),
    [anon_sym_EQ_EQ] = ACTIONS(4484),
    [anon_sym_BANG_EQ] = ACTIONS(4484),
    [anon_sym_GT_EQ] = ACTIONS(4484),
    [anon_sym_LT_EQ] = ACTIONS(4484),
    [anon_sym_DOT] = ACTIONS(4482),
    [anon_sym_scoped] = ACTIONS(4482),
    [anon_sym_var] = ACTIONS(4482),
    [anon_sym_yield] = ACTIONS(4482),
    [anon_sym_switch] = ACTIONS(4482),
    [anon_sym_when] = ACTIONS(4482),
    [sym_discard] = ACTIONS(4482),
    [anon_sym_DOT_DOT] = ACTIONS(4484),
    [anon_sym_and] = ACTIONS(4482),
    [anon_sym_or] = ACTIONS(4482),
    [anon_sym_AMP_AMP] = ACTIONS(4484),
    [anon_sym_PIPE_PIPE] = ACTIONS(4484),
    [anon_sym_QMARK_QMARK] = ACTIONS(4484),
    [anon_sym_from] = ACTIONS(4482),
    [anon_sym_into] = ACTIONS(4482),
    [anon_sym_join] = ACTIONS(4482),
    [anon_sym_on] = ACTIONS(4482),
    [anon_sym_equals] = ACTIONS(4482),
    [anon_sym_let] = ACTIONS(4482),
    [anon_sym_orderby] = ACTIONS(4482),
    [anon_sym_ascending] = ACTIONS(4482),
    [anon_sym_descending] = ACTIONS(4482),
    [anon_sym_group] = ACTIONS(4482),
    [anon_sym_by] = ACTIONS(4482),
    [anon_sym_select] = ACTIONS(4482),
    [anon_sym_as] = ACTIONS(4482),
    [anon_sym_is] = ACTIONS(4482),
    [anon_sym_DASH_GT] = ACTIONS(4484),
    [anon_sym_with] = ACTIONS(4482),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4484),
  },
  [3446] = {
    [sym_preproc_region] = STATE(3446),
    [sym_preproc_endregion] = STATE(3446),
    [sym_preproc_line] = STATE(3446),
    [sym_preproc_pragma] = STATE(3446),
    [sym_preproc_nullable] = STATE(3446),
    [sym_preproc_error] = STATE(3446),
    [sym_preproc_warning] = STATE(3446),
    [sym_preproc_define] = STATE(3446),
    [sym_preproc_undef] = STATE(3446),
    [sym__identifier_token] = ACTIONS(3621),
    [anon_sym_extern] = ACTIONS(3621),
    [anon_sym_alias] = ACTIONS(3621),
    [anon_sym_global] = ACTIONS(3621),
    [anon_sym_using] = ACTIONS(3621),
    [anon_sym_unsafe] = ACTIONS(3621),
    [anon_sym_static] = ACTIONS(3621),
    [anon_sym_LBRACK] = ACTIONS(3623),
    [anon_sym_LPAREN] = ACTIONS(3623),
    [anon_sym_event] = ACTIONS(3621),
    [anon_sym_namespace] = ACTIONS(3621),
    [anon_sym_class] = ACTIONS(3621),
    [anon_sym_ref] = ACTIONS(3621),
    [anon_sym_struct] = ACTIONS(3621),
    [anon_sym_enum] = ACTIONS(3621),
    [anon_sym_RBRACE] = ACTIONS(3623),
    [anon_sym_interface] = ACTIONS(3621),
    [anon_sym_delegate] = ACTIONS(3621),
    [anon_sym_record] = ACTIONS(3621),
    [anon_sym_abstract] = ACTIONS(3621),
    [anon_sym_async] = ACTIONS(3621),
    [anon_sym_const] = ACTIONS(3621),
    [anon_sym_file] = ACTIONS(3621),
    [anon_sym_fixed] = ACTIONS(3621),
    [anon_sym_internal] = ACTIONS(3621),
    [anon_sym_new] = ACTIONS(3621),
    [anon_sym_override] = ACTIONS(3621),
    [anon_sym_partial] = ACTIONS(3621),
    [anon_sym_private] = ACTIONS(3621),
    [anon_sym_protected] = ACTIONS(3621),
    [anon_sym_public] = ACTIONS(3621),
    [anon_sym_readonly] = ACTIONS(3621),
    [anon_sym_required] = ACTIONS(3621),
    [anon_sym_sealed] = ACTIONS(3621),
    [anon_sym_virtual] = ACTIONS(3621),
    [anon_sym_volatile] = ACTIONS(3621),
    [anon_sym_where] = ACTIONS(3621),
    [anon_sym_notnull] = ACTIONS(3621),
    [anon_sym_unmanaged] = ACTIONS(3621),
    [anon_sym_TILDE] = ACTIONS(3623),
    [anon_sym_implicit] = ACTIONS(3621),
    [anon_sym_explicit] = ACTIONS(3621),
    [anon_sym_scoped] = ACTIONS(3621),
    [anon_sym_var] = ACTIONS(3621),
    [sym_predefined_type] = ACTIONS(3621),
    [anon_sym_yield] = ACTIONS(3621),
    [anon_sym_when] = ACTIONS(3621),
    [anon_sym_from] = ACTIONS(3621),
    [anon_sym_into] = ACTIONS(3621),
    [anon_sym_join] = ACTIONS(3621),
    [anon_sym_on] = ACTIONS(3621),
    [anon_sym_equals] = ACTIONS(3621),
    [anon_sym_let] = ACTIONS(3621),
    [anon_sym_orderby] = ACTIONS(3621),
    [anon_sym_ascending] = ACTIONS(3621),
    [anon_sym_descending] = ACTIONS(3621),
    [anon_sym_group] = ACTIONS(3621),
    [anon_sym_by] = ACTIONS(3621),
    [anon_sym_select] = ACTIONS(3621),
    [aux_sym_preproc_if_token1] = ACTIONS(3623),
    [aux_sym_preproc_if_token3] = ACTIONS(3623),
    [aux_sym_preproc_else_token1] = ACTIONS(3623),
    [aux_sym_preproc_elif_token1] = ACTIONS(3623),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3447] = {
    [sym_preproc_region] = STATE(3447),
    [sym_preproc_endregion] = STATE(3447),
    [sym_preproc_line] = STATE(3447),
    [sym_preproc_pragma] = STATE(3447),
    [sym_preproc_nullable] = STATE(3447),
    [sym_preproc_error] = STATE(3447),
    [sym_preproc_warning] = STATE(3447),
    [sym_preproc_define] = STATE(3447),
    [sym_preproc_undef] = STATE(3447),
    [sym__identifier_token] = ACTIONS(3625),
    [anon_sym_extern] = ACTIONS(3625),
    [anon_sym_alias] = ACTIONS(3625),
    [anon_sym_global] = ACTIONS(3625),
    [anon_sym_using] = ACTIONS(3625),
    [anon_sym_unsafe] = ACTIONS(3625),
    [anon_sym_static] = ACTIONS(3625),
    [anon_sym_LBRACK] = ACTIONS(3627),
    [anon_sym_LPAREN] = ACTIONS(3627),
    [anon_sym_event] = ACTIONS(3625),
    [anon_sym_namespace] = ACTIONS(3625),
    [anon_sym_class] = ACTIONS(3625),
    [anon_sym_ref] = ACTIONS(3625),
    [anon_sym_struct] = ACTIONS(3625),
    [anon_sym_enum] = ACTIONS(3625),
    [anon_sym_RBRACE] = ACTIONS(3627),
    [anon_sym_interface] = ACTIONS(3625),
    [anon_sym_delegate] = ACTIONS(3625),
    [anon_sym_record] = ACTIONS(3625),
    [anon_sym_abstract] = ACTIONS(3625),
    [anon_sym_async] = ACTIONS(3625),
    [anon_sym_const] = ACTIONS(3625),
    [anon_sym_file] = ACTIONS(3625),
    [anon_sym_fixed] = ACTIONS(3625),
    [anon_sym_internal] = ACTIONS(3625),
    [anon_sym_new] = ACTIONS(3625),
    [anon_sym_override] = ACTIONS(3625),
    [anon_sym_partial] = ACTIONS(3625),
    [anon_sym_private] = ACTIONS(3625),
    [anon_sym_protected] = ACTIONS(3625),
    [anon_sym_public] = ACTIONS(3625),
    [anon_sym_readonly] = ACTIONS(3625),
    [anon_sym_required] = ACTIONS(3625),
    [anon_sym_sealed] = ACTIONS(3625),
    [anon_sym_virtual] = ACTIONS(3625),
    [anon_sym_volatile] = ACTIONS(3625),
    [anon_sym_where] = ACTIONS(3625),
    [anon_sym_notnull] = ACTIONS(3625),
    [anon_sym_unmanaged] = ACTIONS(3625),
    [anon_sym_TILDE] = ACTIONS(3627),
    [anon_sym_implicit] = ACTIONS(3625),
    [anon_sym_explicit] = ACTIONS(3625),
    [anon_sym_scoped] = ACTIONS(3625),
    [anon_sym_var] = ACTIONS(3625),
    [sym_predefined_type] = ACTIONS(3625),
    [anon_sym_yield] = ACTIONS(3625),
    [anon_sym_when] = ACTIONS(3625),
    [anon_sym_from] = ACTIONS(3625),
    [anon_sym_into] = ACTIONS(3625),
    [anon_sym_join] = ACTIONS(3625),
    [anon_sym_on] = ACTIONS(3625),
    [anon_sym_equals] = ACTIONS(3625),
    [anon_sym_let] = ACTIONS(3625),
    [anon_sym_orderby] = ACTIONS(3625),
    [anon_sym_ascending] = ACTIONS(3625),
    [anon_sym_descending] = ACTIONS(3625),
    [anon_sym_group] = ACTIONS(3625),
    [anon_sym_by] = ACTIONS(3625),
    [anon_sym_select] = ACTIONS(3625),
    [aux_sym_preproc_if_token1] = ACTIONS(3627),
    [aux_sym_preproc_if_token3] = ACTIONS(3627),
    [aux_sym_preproc_else_token1] = ACTIONS(3627),
    [aux_sym_preproc_elif_token1] = ACTIONS(3627),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3448] = {
    [sym_preproc_region] = STATE(3448),
    [sym_preproc_endregion] = STATE(3448),
    [sym_preproc_line] = STATE(3448),
    [sym_preproc_pragma] = STATE(3448),
    [sym_preproc_nullable] = STATE(3448),
    [sym_preproc_error] = STATE(3448),
    [sym_preproc_warning] = STATE(3448),
    [sym_preproc_define] = STATE(3448),
    [sym_preproc_undef] = STATE(3448),
    [sym__identifier_token] = ACTIONS(3629),
    [anon_sym_extern] = ACTIONS(3629),
    [anon_sym_alias] = ACTIONS(3629),
    [anon_sym_global] = ACTIONS(3629),
    [anon_sym_using] = ACTIONS(3629),
    [anon_sym_unsafe] = ACTIONS(3629),
    [anon_sym_static] = ACTIONS(3629),
    [anon_sym_LBRACK] = ACTIONS(3631),
    [anon_sym_LPAREN] = ACTIONS(3631),
    [anon_sym_event] = ACTIONS(3629),
    [anon_sym_namespace] = ACTIONS(3629),
    [anon_sym_class] = ACTIONS(3629),
    [anon_sym_ref] = ACTIONS(3629),
    [anon_sym_struct] = ACTIONS(3629),
    [anon_sym_enum] = ACTIONS(3629),
    [anon_sym_RBRACE] = ACTIONS(3631),
    [anon_sym_interface] = ACTIONS(3629),
    [anon_sym_delegate] = ACTIONS(3629),
    [anon_sym_record] = ACTIONS(3629),
    [anon_sym_abstract] = ACTIONS(3629),
    [anon_sym_async] = ACTIONS(3629),
    [anon_sym_const] = ACTIONS(3629),
    [anon_sym_file] = ACTIONS(3629),
    [anon_sym_fixed] = ACTIONS(3629),
    [anon_sym_internal] = ACTIONS(3629),
    [anon_sym_new] = ACTIONS(3629),
    [anon_sym_override] = ACTIONS(3629),
    [anon_sym_partial] = ACTIONS(3629),
    [anon_sym_private] = ACTIONS(3629),
    [anon_sym_protected] = ACTIONS(3629),
    [anon_sym_public] = ACTIONS(3629),
    [anon_sym_readonly] = ACTIONS(3629),
    [anon_sym_required] = ACTIONS(3629),
    [anon_sym_sealed] = ACTIONS(3629),
    [anon_sym_virtual] = ACTIONS(3629),
    [anon_sym_volatile] = ACTIONS(3629),
    [anon_sym_where] = ACTIONS(3629),
    [anon_sym_notnull] = ACTIONS(3629),
    [anon_sym_unmanaged] = ACTIONS(3629),
    [anon_sym_TILDE] = ACTIONS(3631),
    [anon_sym_implicit] = ACTIONS(3629),
    [anon_sym_explicit] = ACTIONS(3629),
    [anon_sym_scoped] = ACTIONS(3629),
    [anon_sym_var] = ACTIONS(3629),
    [sym_predefined_type] = ACTIONS(3629),
    [anon_sym_yield] = ACTIONS(3629),
    [anon_sym_when] = ACTIONS(3629),
    [anon_sym_from] = ACTIONS(3629),
    [anon_sym_into] = ACTIONS(3629),
    [anon_sym_join] = ACTIONS(3629),
    [anon_sym_on] = ACTIONS(3629),
    [anon_sym_equals] = ACTIONS(3629),
    [anon_sym_let] = ACTIONS(3629),
    [anon_sym_orderby] = ACTIONS(3629),
    [anon_sym_ascending] = ACTIONS(3629),
    [anon_sym_descending] = ACTIONS(3629),
    [anon_sym_group] = ACTIONS(3629),
    [anon_sym_by] = ACTIONS(3629),
    [anon_sym_select] = ACTIONS(3629),
    [aux_sym_preproc_if_token1] = ACTIONS(3631),
    [aux_sym_preproc_if_token3] = ACTIONS(3631),
    [aux_sym_preproc_else_token1] = ACTIONS(3631),
    [aux_sym_preproc_elif_token1] = ACTIONS(3631),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3449] = {
    [sym_preproc_region] = STATE(3449),
    [sym_preproc_endregion] = STATE(3449),
    [sym_preproc_line] = STATE(3449),
    [sym_preproc_pragma] = STATE(3449),
    [sym_preproc_nullable] = STATE(3449),
    [sym_preproc_error] = STATE(3449),
    [sym_preproc_warning] = STATE(3449),
    [sym_preproc_define] = STATE(3449),
    [sym_preproc_undef] = STATE(3449),
    [sym__identifier_token] = ACTIONS(3633),
    [anon_sym_extern] = ACTIONS(3633),
    [anon_sym_alias] = ACTIONS(3633),
    [anon_sym_global] = ACTIONS(3633),
    [anon_sym_using] = ACTIONS(3633),
    [anon_sym_unsafe] = ACTIONS(3633),
    [anon_sym_static] = ACTIONS(3633),
    [anon_sym_LBRACK] = ACTIONS(3635),
    [anon_sym_LPAREN] = ACTIONS(3635),
    [anon_sym_event] = ACTIONS(3633),
    [anon_sym_namespace] = ACTIONS(3633),
    [anon_sym_class] = ACTIONS(3633),
    [anon_sym_ref] = ACTIONS(3633),
    [anon_sym_struct] = ACTIONS(3633),
    [anon_sym_enum] = ACTIONS(3633),
    [anon_sym_RBRACE] = ACTIONS(3635),
    [anon_sym_interface] = ACTIONS(3633),
    [anon_sym_delegate] = ACTIONS(3633),
    [anon_sym_record] = ACTIONS(3633),
    [anon_sym_abstract] = ACTIONS(3633),
    [anon_sym_async] = ACTIONS(3633),
    [anon_sym_const] = ACTIONS(3633),
    [anon_sym_file] = ACTIONS(3633),
    [anon_sym_fixed] = ACTIONS(3633),
    [anon_sym_internal] = ACTIONS(3633),
    [anon_sym_new] = ACTIONS(3633),
    [anon_sym_override] = ACTIONS(3633),
    [anon_sym_partial] = ACTIONS(3633),
    [anon_sym_private] = ACTIONS(3633),
    [anon_sym_protected] = ACTIONS(3633),
    [anon_sym_public] = ACTIONS(3633),
    [anon_sym_readonly] = ACTIONS(3633),
    [anon_sym_required] = ACTIONS(3633),
    [anon_sym_sealed] = ACTIONS(3633),
    [anon_sym_virtual] = ACTIONS(3633),
    [anon_sym_volatile] = ACTIONS(3633),
    [anon_sym_where] = ACTIONS(3633),
    [anon_sym_notnull] = ACTIONS(3633),
    [anon_sym_unmanaged] = ACTIONS(3633),
    [anon_sym_TILDE] = ACTIONS(3635),
    [anon_sym_implicit] = ACTIONS(3633),
    [anon_sym_explicit] = ACTIONS(3633),
    [anon_sym_scoped] = ACTIONS(3633),
    [anon_sym_var] = ACTIONS(3633),
    [sym_predefined_type] = ACTIONS(3633),
    [anon_sym_yield] = ACTIONS(3633),
    [anon_sym_when] = ACTIONS(3633),
    [anon_sym_from] = ACTIONS(3633),
    [anon_sym_into] = ACTIONS(3633),
    [anon_sym_join] = ACTIONS(3633),
    [anon_sym_on] = ACTIONS(3633),
    [anon_sym_equals] = ACTIONS(3633),
    [anon_sym_let] = ACTIONS(3633),
    [anon_sym_orderby] = ACTIONS(3633),
    [anon_sym_ascending] = ACTIONS(3633),
    [anon_sym_descending] = ACTIONS(3633),
    [anon_sym_group] = ACTIONS(3633),
    [anon_sym_by] = ACTIONS(3633),
    [anon_sym_select] = ACTIONS(3633),
    [aux_sym_preproc_if_token1] = ACTIONS(3635),
    [aux_sym_preproc_if_token3] = ACTIONS(3635),
    [aux_sym_preproc_else_token1] = ACTIONS(3635),
    [aux_sym_preproc_elif_token1] = ACTIONS(3635),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3450] = {
    [sym_preproc_region] = STATE(3450),
    [sym_preproc_endregion] = STATE(3450),
    [sym_preproc_line] = STATE(3450),
    [sym_preproc_pragma] = STATE(3450),
    [sym_preproc_nullable] = STATE(3450),
    [sym_preproc_error] = STATE(3450),
    [sym_preproc_warning] = STATE(3450),
    [sym_preproc_define] = STATE(3450),
    [sym_preproc_undef] = STATE(3450),
    [sym__identifier_token] = ACTIONS(3637),
    [anon_sym_extern] = ACTIONS(3637),
    [anon_sym_alias] = ACTIONS(3637),
    [anon_sym_global] = ACTIONS(3637),
    [anon_sym_using] = ACTIONS(3637),
    [anon_sym_unsafe] = ACTIONS(3637),
    [anon_sym_static] = ACTIONS(3637),
    [anon_sym_LBRACK] = ACTIONS(3639),
    [anon_sym_LPAREN] = ACTIONS(3639),
    [anon_sym_event] = ACTIONS(3637),
    [anon_sym_namespace] = ACTIONS(3637),
    [anon_sym_class] = ACTIONS(3637),
    [anon_sym_ref] = ACTIONS(3637),
    [anon_sym_struct] = ACTIONS(3637),
    [anon_sym_enum] = ACTIONS(3637),
    [anon_sym_RBRACE] = ACTIONS(3639),
    [anon_sym_interface] = ACTIONS(3637),
    [anon_sym_delegate] = ACTIONS(3637),
    [anon_sym_record] = ACTIONS(3637),
    [anon_sym_abstract] = ACTIONS(3637),
    [anon_sym_async] = ACTIONS(3637),
    [anon_sym_const] = ACTIONS(3637),
    [anon_sym_file] = ACTIONS(3637),
    [anon_sym_fixed] = ACTIONS(3637),
    [anon_sym_internal] = ACTIONS(3637),
    [anon_sym_new] = ACTIONS(3637),
    [anon_sym_override] = ACTIONS(3637),
    [anon_sym_partial] = ACTIONS(3637),
    [anon_sym_private] = ACTIONS(3637),
    [anon_sym_protected] = ACTIONS(3637),
    [anon_sym_public] = ACTIONS(3637),
    [anon_sym_readonly] = ACTIONS(3637),
    [anon_sym_required] = ACTIONS(3637),
    [anon_sym_sealed] = ACTIONS(3637),
    [anon_sym_virtual] = ACTIONS(3637),
    [anon_sym_volatile] = ACTIONS(3637),
    [anon_sym_where] = ACTIONS(3637),
    [anon_sym_notnull] = ACTIONS(3637),
    [anon_sym_unmanaged] = ACTIONS(3637),
    [anon_sym_TILDE] = ACTIONS(3639),
    [anon_sym_implicit] = ACTIONS(3637),
    [anon_sym_explicit] = ACTIONS(3637),
    [anon_sym_scoped] = ACTIONS(3637),
    [anon_sym_var] = ACTIONS(3637),
    [sym_predefined_type] = ACTIONS(3637),
    [anon_sym_yield] = ACTIONS(3637),
    [anon_sym_when] = ACTIONS(3637),
    [anon_sym_from] = ACTIONS(3637),
    [anon_sym_into] = ACTIONS(3637),
    [anon_sym_join] = ACTIONS(3637),
    [anon_sym_on] = ACTIONS(3637),
    [anon_sym_equals] = ACTIONS(3637),
    [anon_sym_let] = ACTIONS(3637),
    [anon_sym_orderby] = ACTIONS(3637),
    [anon_sym_ascending] = ACTIONS(3637),
    [anon_sym_descending] = ACTIONS(3637),
    [anon_sym_group] = ACTIONS(3637),
    [anon_sym_by] = ACTIONS(3637),
    [anon_sym_select] = ACTIONS(3637),
    [aux_sym_preproc_if_token1] = ACTIONS(3639),
    [aux_sym_preproc_if_token3] = ACTIONS(3639),
    [aux_sym_preproc_else_token1] = ACTIONS(3639),
    [aux_sym_preproc_elif_token1] = ACTIONS(3639),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3451] = {
    [sym_preproc_region] = STATE(3451),
    [sym_preproc_endregion] = STATE(3451),
    [sym_preproc_line] = STATE(3451),
    [sym_preproc_pragma] = STATE(3451),
    [sym_preproc_nullable] = STATE(3451),
    [sym_preproc_error] = STATE(3451),
    [sym_preproc_warning] = STATE(3451),
    [sym_preproc_define] = STATE(3451),
    [sym_preproc_undef] = STATE(3451),
    [sym__identifier_token] = ACTIONS(3641),
    [anon_sym_extern] = ACTIONS(3641),
    [anon_sym_alias] = ACTIONS(3641),
    [anon_sym_global] = ACTIONS(3641),
    [anon_sym_using] = ACTIONS(3641),
    [anon_sym_unsafe] = ACTIONS(3641),
    [anon_sym_static] = ACTIONS(3641),
    [anon_sym_LBRACK] = ACTIONS(3643),
    [anon_sym_LPAREN] = ACTIONS(3643),
    [anon_sym_event] = ACTIONS(3641),
    [anon_sym_namespace] = ACTIONS(3641),
    [anon_sym_class] = ACTIONS(3641),
    [anon_sym_ref] = ACTIONS(3641),
    [anon_sym_struct] = ACTIONS(3641),
    [anon_sym_enum] = ACTIONS(3641),
    [anon_sym_RBRACE] = ACTIONS(3643),
    [anon_sym_interface] = ACTIONS(3641),
    [anon_sym_delegate] = ACTIONS(3641),
    [anon_sym_record] = ACTIONS(3641),
    [anon_sym_abstract] = ACTIONS(3641),
    [anon_sym_async] = ACTIONS(3641),
    [anon_sym_const] = ACTIONS(3641),
    [anon_sym_file] = ACTIONS(3641),
    [anon_sym_fixed] = ACTIONS(3641),
    [anon_sym_internal] = ACTIONS(3641),
    [anon_sym_new] = ACTIONS(3641),
    [anon_sym_override] = ACTIONS(3641),
    [anon_sym_partial] = ACTIONS(3641),
    [anon_sym_private] = ACTIONS(3641),
    [anon_sym_protected] = ACTIONS(3641),
    [anon_sym_public] = ACTIONS(3641),
    [anon_sym_readonly] = ACTIONS(3641),
    [anon_sym_required] = ACTIONS(3641),
    [anon_sym_sealed] = ACTIONS(3641),
    [anon_sym_virtual] = ACTIONS(3641),
    [anon_sym_volatile] = ACTIONS(3641),
    [anon_sym_where] = ACTIONS(3641),
    [anon_sym_notnull] = ACTIONS(3641),
    [anon_sym_unmanaged] = ACTIONS(3641),
    [anon_sym_TILDE] = ACTIONS(3643),
    [anon_sym_implicit] = ACTIONS(3641),
    [anon_sym_explicit] = ACTIONS(3641),
    [anon_sym_scoped] = ACTIONS(3641),
    [anon_sym_var] = ACTIONS(3641),
    [sym_predefined_type] = ACTIONS(3641),
    [anon_sym_yield] = ACTIONS(3641),
    [anon_sym_when] = ACTIONS(3641),
    [anon_sym_from] = ACTIONS(3641),
    [anon_sym_into] = ACTIONS(3641),
    [anon_sym_join] = ACTIONS(3641),
    [anon_sym_on] = ACTIONS(3641),
    [anon_sym_equals] = ACTIONS(3641),
    [anon_sym_let] = ACTIONS(3641),
    [anon_sym_orderby] = ACTIONS(3641),
    [anon_sym_ascending] = ACTIONS(3641),
    [anon_sym_descending] = ACTIONS(3641),
    [anon_sym_group] = ACTIONS(3641),
    [anon_sym_by] = ACTIONS(3641),
    [anon_sym_select] = ACTIONS(3641),
    [aux_sym_preproc_if_token1] = ACTIONS(3643),
    [aux_sym_preproc_if_token3] = ACTIONS(3643),
    [aux_sym_preproc_else_token1] = ACTIONS(3643),
    [aux_sym_preproc_elif_token1] = ACTIONS(3643),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3452] = {
    [sym_preproc_region] = STATE(3452),
    [sym_preproc_endregion] = STATE(3452),
    [sym_preproc_line] = STATE(3452),
    [sym_preproc_pragma] = STATE(3452),
    [sym_preproc_nullable] = STATE(3452),
    [sym_preproc_error] = STATE(3452),
    [sym_preproc_warning] = STATE(3452),
    [sym_preproc_define] = STATE(3452),
    [sym_preproc_undef] = STATE(3452),
    [sym__identifier_token] = ACTIONS(3645),
    [anon_sym_extern] = ACTIONS(3645),
    [anon_sym_alias] = ACTIONS(3645),
    [anon_sym_global] = ACTIONS(3645),
    [anon_sym_using] = ACTIONS(3645),
    [anon_sym_unsafe] = ACTIONS(3645),
    [anon_sym_static] = ACTIONS(3645),
    [anon_sym_LBRACK] = ACTIONS(3647),
    [anon_sym_LPAREN] = ACTIONS(3647),
    [anon_sym_event] = ACTIONS(3645),
    [anon_sym_namespace] = ACTIONS(3645),
    [anon_sym_class] = ACTIONS(3645),
    [anon_sym_ref] = ACTIONS(3645),
    [anon_sym_struct] = ACTIONS(3645),
    [anon_sym_enum] = ACTIONS(3645),
    [anon_sym_RBRACE] = ACTIONS(3647),
    [anon_sym_interface] = ACTIONS(3645),
    [anon_sym_delegate] = ACTIONS(3645),
    [anon_sym_record] = ACTIONS(3645),
    [anon_sym_abstract] = ACTIONS(3645),
    [anon_sym_async] = ACTIONS(3645),
    [anon_sym_const] = ACTIONS(3645),
    [anon_sym_file] = ACTIONS(3645),
    [anon_sym_fixed] = ACTIONS(3645),
    [anon_sym_internal] = ACTIONS(3645),
    [anon_sym_new] = ACTIONS(3645),
    [anon_sym_override] = ACTIONS(3645),
    [anon_sym_partial] = ACTIONS(3645),
    [anon_sym_private] = ACTIONS(3645),
    [anon_sym_protected] = ACTIONS(3645),
    [anon_sym_public] = ACTIONS(3645),
    [anon_sym_readonly] = ACTIONS(3645),
    [anon_sym_required] = ACTIONS(3645),
    [anon_sym_sealed] = ACTIONS(3645),
    [anon_sym_virtual] = ACTIONS(3645),
    [anon_sym_volatile] = ACTIONS(3645),
    [anon_sym_where] = ACTIONS(3645),
    [anon_sym_notnull] = ACTIONS(3645),
    [anon_sym_unmanaged] = ACTIONS(3645),
    [anon_sym_TILDE] = ACTIONS(3647),
    [anon_sym_implicit] = ACTIONS(3645),
    [anon_sym_explicit] = ACTIONS(3645),
    [anon_sym_scoped] = ACTIONS(3645),
    [anon_sym_var] = ACTIONS(3645),
    [sym_predefined_type] = ACTIONS(3645),
    [anon_sym_yield] = ACTIONS(3645),
    [anon_sym_when] = ACTIONS(3645),
    [anon_sym_from] = ACTIONS(3645),
    [anon_sym_into] = ACTIONS(3645),
    [anon_sym_join] = ACTIONS(3645),
    [anon_sym_on] = ACTIONS(3645),
    [anon_sym_equals] = ACTIONS(3645),
    [anon_sym_let] = ACTIONS(3645),
    [anon_sym_orderby] = ACTIONS(3645),
    [anon_sym_ascending] = ACTIONS(3645),
    [anon_sym_descending] = ACTIONS(3645),
    [anon_sym_group] = ACTIONS(3645),
    [anon_sym_by] = ACTIONS(3645),
    [anon_sym_select] = ACTIONS(3645),
    [aux_sym_preproc_if_token1] = ACTIONS(3647),
    [aux_sym_preproc_if_token3] = ACTIONS(3647),
    [aux_sym_preproc_else_token1] = ACTIONS(3647),
    [aux_sym_preproc_elif_token1] = ACTIONS(3647),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3453] = {
    [sym_preproc_region] = STATE(3453),
    [sym_preproc_endregion] = STATE(3453),
    [sym_preproc_line] = STATE(3453),
    [sym_preproc_pragma] = STATE(3453),
    [sym_preproc_nullable] = STATE(3453),
    [sym_preproc_error] = STATE(3453),
    [sym_preproc_warning] = STATE(3453),
    [sym_preproc_define] = STATE(3453),
    [sym_preproc_undef] = STATE(3453),
    [sym__identifier_token] = ACTIONS(3649),
    [anon_sym_extern] = ACTIONS(3649),
    [anon_sym_alias] = ACTIONS(3649),
    [anon_sym_global] = ACTIONS(3649),
    [anon_sym_using] = ACTIONS(3649),
    [anon_sym_unsafe] = ACTIONS(3649),
    [anon_sym_static] = ACTIONS(3649),
    [anon_sym_LBRACK] = ACTIONS(3651),
    [anon_sym_LPAREN] = ACTIONS(3651),
    [anon_sym_event] = ACTIONS(3649),
    [anon_sym_namespace] = ACTIONS(3649),
    [anon_sym_class] = ACTIONS(3649),
    [anon_sym_ref] = ACTIONS(3649),
    [anon_sym_struct] = ACTIONS(3649),
    [anon_sym_enum] = ACTIONS(3649),
    [anon_sym_RBRACE] = ACTIONS(3651),
    [anon_sym_interface] = ACTIONS(3649),
    [anon_sym_delegate] = ACTIONS(3649),
    [anon_sym_record] = ACTIONS(3649),
    [anon_sym_abstract] = ACTIONS(3649),
    [anon_sym_async] = ACTIONS(3649),
    [anon_sym_const] = ACTIONS(3649),
    [anon_sym_file] = ACTIONS(3649),
    [anon_sym_fixed] = ACTIONS(3649),
    [anon_sym_internal] = ACTIONS(3649),
    [anon_sym_new] = ACTIONS(3649),
    [anon_sym_override] = ACTIONS(3649),
    [anon_sym_partial] = ACTIONS(3649),
    [anon_sym_private] = ACTIONS(3649),
    [anon_sym_protected] = ACTIONS(3649),
    [anon_sym_public] = ACTIONS(3649),
    [anon_sym_readonly] = ACTIONS(3649),
    [anon_sym_required] = ACTIONS(3649),
    [anon_sym_sealed] = ACTIONS(3649),
    [anon_sym_virtual] = ACTIONS(3649),
    [anon_sym_volatile] = ACTIONS(3649),
    [anon_sym_where] = ACTIONS(3649),
    [anon_sym_notnull] = ACTIONS(3649),
    [anon_sym_unmanaged] = ACTIONS(3649),
    [anon_sym_TILDE] = ACTIONS(3651),
    [anon_sym_implicit] = ACTIONS(3649),
    [anon_sym_explicit] = ACTIONS(3649),
    [anon_sym_scoped] = ACTIONS(3649),
    [anon_sym_var] = ACTIONS(3649),
    [sym_predefined_type] = ACTIONS(3649),
    [anon_sym_yield] = ACTIONS(3649),
    [anon_sym_when] = ACTIONS(3649),
    [anon_sym_from] = ACTIONS(3649),
    [anon_sym_into] = ACTIONS(3649),
    [anon_sym_join] = ACTIONS(3649),
    [anon_sym_on] = ACTIONS(3649),
    [anon_sym_equals] = ACTIONS(3649),
    [anon_sym_let] = ACTIONS(3649),
    [anon_sym_orderby] = ACTIONS(3649),
    [anon_sym_ascending] = ACTIONS(3649),
    [anon_sym_descending] = ACTIONS(3649),
    [anon_sym_group] = ACTIONS(3649),
    [anon_sym_by] = ACTIONS(3649),
    [anon_sym_select] = ACTIONS(3649),
    [aux_sym_preproc_if_token1] = ACTIONS(3651),
    [aux_sym_preproc_if_token3] = ACTIONS(3651),
    [aux_sym_preproc_else_token1] = ACTIONS(3651),
    [aux_sym_preproc_elif_token1] = ACTIONS(3651),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3454] = {
    [sym_preproc_region] = STATE(3454),
    [sym_preproc_endregion] = STATE(3454),
    [sym_preproc_line] = STATE(3454),
    [sym_preproc_pragma] = STATE(3454),
    [sym_preproc_nullable] = STATE(3454),
    [sym_preproc_error] = STATE(3454),
    [sym_preproc_warning] = STATE(3454),
    [sym_preproc_define] = STATE(3454),
    [sym_preproc_undef] = STATE(3454),
    [sym__identifier_token] = ACTIONS(3505),
    [anon_sym_extern] = ACTIONS(3505),
    [anon_sym_alias] = ACTIONS(3505),
    [anon_sym_global] = ACTIONS(3505),
    [anon_sym_using] = ACTIONS(3505),
    [anon_sym_unsafe] = ACTIONS(3505),
    [anon_sym_static] = ACTIONS(3505),
    [anon_sym_LBRACK] = ACTIONS(3507),
    [anon_sym_LPAREN] = ACTIONS(3507),
    [anon_sym_event] = ACTIONS(3505),
    [anon_sym_namespace] = ACTIONS(3505),
    [anon_sym_class] = ACTIONS(3505),
    [anon_sym_ref] = ACTIONS(3505),
    [anon_sym_struct] = ACTIONS(3505),
    [anon_sym_enum] = ACTIONS(3505),
    [anon_sym_RBRACE] = ACTIONS(3507),
    [anon_sym_interface] = ACTIONS(3505),
    [anon_sym_delegate] = ACTIONS(3505),
    [anon_sym_record] = ACTIONS(3505),
    [anon_sym_abstract] = ACTIONS(3505),
    [anon_sym_async] = ACTIONS(3505),
    [anon_sym_const] = ACTIONS(3505),
    [anon_sym_file] = ACTIONS(3505),
    [anon_sym_fixed] = ACTIONS(3505),
    [anon_sym_internal] = ACTIONS(3505),
    [anon_sym_new] = ACTIONS(3505),
    [anon_sym_override] = ACTIONS(3505),
    [anon_sym_partial] = ACTIONS(3505),
    [anon_sym_private] = ACTIONS(3505),
    [anon_sym_protected] = ACTIONS(3505),
    [anon_sym_public] = ACTIONS(3505),
    [anon_sym_readonly] = ACTIONS(3505),
    [anon_sym_required] = ACTIONS(3505),
    [anon_sym_sealed] = ACTIONS(3505),
    [anon_sym_virtual] = ACTIONS(3505),
    [anon_sym_volatile] = ACTIONS(3505),
    [anon_sym_where] = ACTIONS(3505),
    [anon_sym_notnull] = ACTIONS(3505),
    [anon_sym_unmanaged] = ACTIONS(3505),
    [anon_sym_TILDE] = ACTIONS(3507),
    [anon_sym_implicit] = ACTIONS(3505),
    [anon_sym_explicit] = ACTIONS(3505),
    [anon_sym_scoped] = ACTIONS(3505),
    [anon_sym_var] = ACTIONS(3505),
    [sym_predefined_type] = ACTIONS(3505),
    [anon_sym_yield] = ACTIONS(3505),
    [anon_sym_when] = ACTIONS(3505),
    [anon_sym_from] = ACTIONS(3505),
    [anon_sym_into] = ACTIONS(3505),
    [anon_sym_join] = ACTIONS(3505),
    [anon_sym_on] = ACTIONS(3505),
    [anon_sym_equals] = ACTIONS(3505),
    [anon_sym_let] = ACTIONS(3505),
    [anon_sym_orderby] = ACTIONS(3505),
    [anon_sym_ascending] = ACTIONS(3505),
    [anon_sym_descending] = ACTIONS(3505),
    [anon_sym_group] = ACTIONS(3505),
    [anon_sym_by] = ACTIONS(3505),
    [anon_sym_select] = ACTIONS(3505),
    [aux_sym_preproc_if_token1] = ACTIONS(3507),
    [aux_sym_preproc_if_token3] = ACTIONS(3507),
    [aux_sym_preproc_else_token1] = ACTIONS(3507),
    [aux_sym_preproc_elif_token1] = ACTIONS(3507),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3455] = {
    [sym__variable_designation] = STATE(5005),
    [sym_parenthesized_variable_designation] = STATE(5027),
    [sym_identifier] = STATE(5034),
    [sym__reserved_identifier] = STATE(3625),
    [sym_preproc_region] = STATE(3455),
    [sym_preproc_endregion] = STATE(3455),
    [sym_preproc_line] = STATE(3455),
    [sym_preproc_pragma] = STATE(3455),
    [sym_preproc_nullable] = STATE(3455),
    [sym_preproc_error] = STATE(3455),
    [sym_preproc_warning] = STATE(3455),
    [sym_preproc_define] = STATE(3455),
    [sym_preproc_undef] = STATE(3455),
    [sym__identifier_token] = ACTIONS(4349),
    [anon_sym_alias] = ACTIONS(4351),
    [anon_sym_global] = ACTIONS(4351),
    [anon_sym_LBRACK] = ACTIONS(4441),
    [anon_sym_LPAREN] = ACTIONS(4441),
    [anon_sym_file] = ACTIONS(4351),
    [anon_sym_LT] = ACTIONS(4443),
    [anon_sym_GT] = ACTIONS(4443),
    [anon_sym_where] = ACTIONS(4443),
    [anon_sym_QMARK] = ACTIONS(4443),
    [anon_sym_notnull] = ACTIONS(4351),
    [anon_sym_unmanaged] = ACTIONS(4351),
    [anon_sym_BANG] = ACTIONS(4443),
    [anon_sym_PLUS_PLUS] = ACTIONS(4441),
    [anon_sym_DASH_DASH] = ACTIONS(4441),
    [anon_sym_PLUS] = ACTIONS(4443),
    [anon_sym_DASH] = ACTIONS(4443),
    [anon_sym_STAR] = ACTIONS(4441),
    [anon_sym_SLASH] = ACTIONS(4443),
    [anon_sym_PERCENT] = ACTIONS(4441),
    [anon_sym_CARET] = ACTIONS(4441),
    [anon_sym_PIPE] = ACTIONS(4443),
    [anon_sym_AMP] = ACTIONS(4443),
    [anon_sym_LT_LT] = ACTIONS(4441),
    [anon_sym_GT_GT] = ACTIONS(4443),
    [anon_sym_GT_GT_GT] = ACTIONS(4441),
    [anon_sym_EQ_EQ] = ACTIONS(4441),
    [anon_sym_BANG_EQ] = ACTIONS(4441),
    [anon_sym_GT_EQ] = ACTIONS(4441),
    [anon_sym_LT_EQ] = ACTIONS(4441),
    [anon_sym_DOT] = ACTIONS(4443),
    [anon_sym_scoped] = ACTIONS(4351),
    [anon_sym_var] = ACTIONS(4351),
    [anon_sym_yield] = ACTIONS(4351),
    [anon_sym_switch] = ACTIONS(4443),
    [anon_sym_when] = ACTIONS(4351),
    [sym_discard] = ACTIONS(4719),
    [anon_sym_DOT_DOT] = ACTIONS(4441),
    [anon_sym_and] = ACTIONS(4443),
    [anon_sym_or] = ACTIONS(4443),
    [anon_sym_AMP_AMP] = ACTIONS(4441),
    [anon_sym_PIPE_PIPE] = ACTIONS(4441),
    [anon_sym_QMARK_QMARK] = ACTIONS(4441),
    [anon_sym_from] = ACTIONS(4443),
    [anon_sym_into] = ACTIONS(4351),
    [anon_sym_join] = ACTIONS(4443),
    [anon_sym_on] = ACTIONS(4351),
    [anon_sym_equals] = ACTIONS(4351),
    [anon_sym_let] = ACTIONS(4443),
    [anon_sym_orderby] = ACTIONS(4443),
    [anon_sym_ascending] = ACTIONS(4351),
    [anon_sym_descending] = ACTIONS(4351),
    [anon_sym_group] = ACTIONS(4443),
    [anon_sym_by] = ACTIONS(4351),
    [anon_sym_select] = ACTIONS(4443),
    [anon_sym_as] = ACTIONS(4443),
    [anon_sym_is] = ACTIONS(4443),
    [anon_sym_DASH_GT] = ACTIONS(4441),
    [anon_sym_with] = ACTIONS(4443),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3456] = {
    [sym_preproc_region] = STATE(3456),
    [sym_preproc_endregion] = STATE(3456),
    [sym_preproc_line] = STATE(3456),
    [sym_preproc_pragma] = STATE(3456),
    [sym_preproc_nullable] = STATE(3456),
    [sym_preproc_error] = STATE(3456),
    [sym_preproc_warning] = STATE(3456),
    [sym_preproc_define] = STATE(3456),
    [sym_preproc_undef] = STATE(3456),
    [anon_sym_SEMI] = ACTIONS(4136),
    [anon_sym_EQ] = ACTIONS(4134),
    [anon_sym_LBRACK] = ACTIONS(4136),
    [anon_sym_COLON] = ACTIONS(4136),
    [anon_sym_COMMA] = ACTIONS(4136),
    [anon_sym_RBRACK] = ACTIONS(4136),
    [anon_sym_LPAREN] = ACTIONS(4136),
    [anon_sym_RPAREN] = ACTIONS(4136),
    [anon_sym_RBRACE] = ACTIONS(4136),
    [anon_sym_LT] = ACTIONS(4134),
    [anon_sym_GT] = ACTIONS(4134),
    [anon_sym_in] = ACTIONS(4136),
    [anon_sym_QMARK] = ACTIONS(4134),
    [anon_sym_BANG] = ACTIONS(4134),
    [anon_sym_PLUS_PLUS] = ACTIONS(4136),
    [anon_sym_DASH_DASH] = ACTIONS(4136),
    [anon_sym_PLUS] = ACTIONS(4134),
    [anon_sym_DASH] = ACTIONS(4134),
    [anon_sym_STAR] = ACTIONS(4134),
    [anon_sym_SLASH] = ACTIONS(4134),
    [anon_sym_PERCENT] = ACTIONS(4134),
    [anon_sym_CARET] = ACTIONS(4134),
    [anon_sym_PIPE] = ACTIONS(4134),
    [anon_sym_AMP] = ACTIONS(4134),
    [anon_sym_LT_LT] = ACTIONS(4134),
    [anon_sym_GT_GT] = ACTIONS(4134),
    [anon_sym_GT_GT_GT] = ACTIONS(4134),
    [anon_sym_EQ_EQ] = ACTIONS(4136),
    [anon_sym_BANG_EQ] = ACTIONS(4136),
    [anon_sym_GT_EQ] = ACTIONS(4136),
    [anon_sym_LT_EQ] = ACTIONS(4136),
    [anon_sym_DOT] = ACTIONS(4134),
    [anon_sym_EQ_GT] = ACTIONS(4136),
    [anon_sym_switch] = ACTIONS(4136),
    [anon_sym_when] = ACTIONS(4136),
    [anon_sym_DOT_DOT] = ACTIONS(4136),
    [anon_sym_and] = ACTIONS(4136),
    [anon_sym_or] = ACTIONS(4136),
    [anon_sym_PLUS_EQ] = ACTIONS(4136),
    [anon_sym_DASH_EQ] = ACTIONS(4136),
    [anon_sym_STAR_EQ] = ACTIONS(4136),
    [anon_sym_SLASH_EQ] = ACTIONS(4136),
    [anon_sym_PERCENT_EQ] = ACTIONS(4136),
    [anon_sym_AMP_EQ] = ACTIONS(4136),
    [anon_sym_CARET_EQ] = ACTIONS(4136),
    [anon_sym_PIPE_EQ] = ACTIONS(4136),
    [anon_sym_LT_LT_EQ] = ACTIONS(4136),
    [anon_sym_GT_GT_EQ] = ACTIONS(4136),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4136),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4136),
    [anon_sym_AMP_AMP] = ACTIONS(4136),
    [anon_sym_PIPE_PIPE] = ACTIONS(4136),
    [anon_sym_QMARK_QMARK] = ACTIONS(4134),
    [anon_sym_on] = ACTIONS(4136),
    [anon_sym_equals] = ACTIONS(4136),
    [anon_sym_by] = ACTIONS(4136),
    [anon_sym_as] = ACTIONS(4136),
    [anon_sym_is] = ACTIONS(4136),
    [anon_sym_DASH_GT] = ACTIONS(4136),
    [anon_sym_with] = ACTIONS(4136),
    [aux_sym_preproc_if_token3] = ACTIONS(4136),
    [aux_sym_preproc_else_token1] = ACTIONS(4136),
    [aux_sym_preproc_elif_token1] = ACTIONS(4136),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3457] = {
    [sym_preproc_region] = STATE(3457),
    [sym_preproc_endregion] = STATE(3457),
    [sym_preproc_line] = STATE(3457),
    [sym_preproc_pragma] = STATE(3457),
    [sym_preproc_nullable] = STATE(3457),
    [sym_preproc_error] = STATE(3457),
    [sym_preproc_warning] = STATE(3457),
    [sym_preproc_define] = STATE(3457),
    [sym_preproc_undef] = STATE(3457),
    [sym__identifier_token] = ACTIONS(4498),
    [anon_sym_alias] = ACTIONS(4498),
    [anon_sym_global] = ACTIONS(4498),
    [anon_sym_LBRACK] = ACTIONS(4500),
    [anon_sym_COLON] = ACTIONS(4500),
    [anon_sym_COMMA] = ACTIONS(4500),
    [anon_sym_LPAREN] = ACTIONS(4500),
    [anon_sym_LBRACE] = ACTIONS(4500),
    [anon_sym_file] = ACTIONS(4498),
    [anon_sym_LT] = ACTIONS(4498),
    [anon_sym_GT] = ACTIONS(4498),
    [anon_sym_where] = ACTIONS(4498),
    [anon_sym_QMARK] = ACTIONS(4498),
    [anon_sym_notnull] = ACTIONS(4498),
    [anon_sym_unmanaged] = ACTIONS(4498),
    [anon_sym_BANG] = ACTIONS(4498),
    [anon_sym_PLUS_PLUS] = ACTIONS(4500),
    [anon_sym_DASH_DASH] = ACTIONS(4500),
    [anon_sym_PLUS] = ACTIONS(4498),
    [anon_sym_DASH] = ACTIONS(4498),
    [anon_sym_STAR] = ACTIONS(4500),
    [anon_sym_SLASH] = ACTIONS(4498),
    [anon_sym_PERCENT] = ACTIONS(4500),
    [anon_sym_CARET] = ACTIONS(4500),
    [anon_sym_PIPE] = ACTIONS(4498),
    [anon_sym_AMP] = ACTIONS(4498),
    [anon_sym_LT_LT] = ACTIONS(4500),
    [anon_sym_GT_GT] = ACTIONS(4498),
    [anon_sym_GT_GT_GT] = ACTIONS(4500),
    [anon_sym_EQ_EQ] = ACTIONS(4500),
    [anon_sym_BANG_EQ] = ACTIONS(4500),
    [anon_sym_GT_EQ] = ACTIONS(4500),
    [anon_sym_LT_EQ] = ACTIONS(4500),
    [anon_sym_DOT] = ACTIONS(4498),
    [anon_sym_scoped] = ACTIONS(4498),
    [anon_sym_var] = ACTIONS(4498),
    [anon_sym_yield] = ACTIONS(4498),
    [anon_sym_switch] = ACTIONS(4498),
    [anon_sym_when] = ACTIONS(4498),
    [sym_discard] = ACTIONS(4498),
    [anon_sym_DOT_DOT] = ACTIONS(4500),
    [anon_sym_and] = ACTIONS(4498),
    [anon_sym_or] = ACTIONS(4498),
    [anon_sym_AMP_AMP] = ACTIONS(4500),
    [anon_sym_PIPE_PIPE] = ACTIONS(4500),
    [anon_sym_QMARK_QMARK] = ACTIONS(4500),
    [anon_sym_from] = ACTIONS(4498),
    [anon_sym_into] = ACTIONS(4498),
    [anon_sym_join] = ACTIONS(4498),
    [anon_sym_on] = ACTIONS(4498),
    [anon_sym_equals] = ACTIONS(4498),
    [anon_sym_let] = ACTIONS(4498),
    [anon_sym_orderby] = ACTIONS(4498),
    [anon_sym_ascending] = ACTIONS(4498),
    [anon_sym_descending] = ACTIONS(4498),
    [anon_sym_group] = ACTIONS(4498),
    [anon_sym_by] = ACTIONS(4498),
    [anon_sym_select] = ACTIONS(4498),
    [anon_sym_as] = ACTIONS(4498),
    [anon_sym_is] = ACTIONS(4498),
    [anon_sym_DASH_GT] = ACTIONS(4500),
    [anon_sym_with] = ACTIONS(4498),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4500),
  },
  [3458] = {
    [sym_preproc_region] = STATE(3458),
    [sym_preproc_endregion] = STATE(3458),
    [sym_preproc_line] = STATE(3458),
    [sym_preproc_pragma] = STATE(3458),
    [sym_preproc_nullable] = STATE(3458),
    [sym_preproc_error] = STATE(3458),
    [sym_preproc_warning] = STATE(3458),
    [sym_preproc_define] = STATE(3458),
    [sym_preproc_undef] = STATE(3458),
    [sym__identifier_token] = ACTIONS(3653),
    [anon_sym_extern] = ACTIONS(3653),
    [anon_sym_alias] = ACTIONS(3653),
    [anon_sym_global] = ACTIONS(3653),
    [anon_sym_using] = ACTIONS(3653),
    [anon_sym_unsafe] = ACTIONS(3653),
    [anon_sym_static] = ACTIONS(3653),
    [anon_sym_LBRACK] = ACTIONS(3655),
    [anon_sym_LPAREN] = ACTIONS(3655),
    [anon_sym_event] = ACTIONS(3653),
    [anon_sym_namespace] = ACTIONS(3653),
    [anon_sym_class] = ACTIONS(3653),
    [anon_sym_ref] = ACTIONS(3653),
    [anon_sym_struct] = ACTIONS(3653),
    [anon_sym_enum] = ACTIONS(3653),
    [anon_sym_RBRACE] = ACTIONS(3655),
    [anon_sym_interface] = ACTIONS(3653),
    [anon_sym_delegate] = ACTIONS(3653),
    [anon_sym_record] = ACTIONS(3653),
    [anon_sym_abstract] = ACTIONS(3653),
    [anon_sym_async] = ACTIONS(3653),
    [anon_sym_const] = ACTIONS(3653),
    [anon_sym_file] = ACTIONS(3653),
    [anon_sym_fixed] = ACTIONS(3653),
    [anon_sym_internal] = ACTIONS(3653),
    [anon_sym_new] = ACTIONS(3653),
    [anon_sym_override] = ACTIONS(3653),
    [anon_sym_partial] = ACTIONS(3653),
    [anon_sym_private] = ACTIONS(3653),
    [anon_sym_protected] = ACTIONS(3653),
    [anon_sym_public] = ACTIONS(3653),
    [anon_sym_readonly] = ACTIONS(3653),
    [anon_sym_required] = ACTIONS(3653),
    [anon_sym_sealed] = ACTIONS(3653),
    [anon_sym_virtual] = ACTIONS(3653),
    [anon_sym_volatile] = ACTIONS(3653),
    [anon_sym_where] = ACTIONS(3653),
    [anon_sym_notnull] = ACTIONS(3653),
    [anon_sym_unmanaged] = ACTIONS(3653),
    [anon_sym_TILDE] = ACTIONS(3655),
    [anon_sym_implicit] = ACTIONS(3653),
    [anon_sym_explicit] = ACTIONS(3653),
    [anon_sym_scoped] = ACTIONS(3653),
    [anon_sym_var] = ACTIONS(3653),
    [sym_predefined_type] = ACTIONS(3653),
    [anon_sym_yield] = ACTIONS(3653),
    [anon_sym_when] = ACTIONS(3653),
    [anon_sym_from] = ACTIONS(3653),
    [anon_sym_into] = ACTIONS(3653),
    [anon_sym_join] = ACTIONS(3653),
    [anon_sym_on] = ACTIONS(3653),
    [anon_sym_equals] = ACTIONS(3653),
    [anon_sym_let] = ACTIONS(3653),
    [anon_sym_orderby] = ACTIONS(3653),
    [anon_sym_ascending] = ACTIONS(3653),
    [anon_sym_descending] = ACTIONS(3653),
    [anon_sym_group] = ACTIONS(3653),
    [anon_sym_by] = ACTIONS(3653),
    [anon_sym_select] = ACTIONS(3653),
    [aux_sym_preproc_if_token1] = ACTIONS(3655),
    [aux_sym_preproc_if_token3] = ACTIONS(3655),
    [aux_sym_preproc_else_token1] = ACTIONS(3655),
    [aux_sym_preproc_elif_token1] = ACTIONS(3655),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3459] = {
    [sym_preproc_region] = STATE(3459),
    [sym_preproc_endregion] = STATE(3459),
    [sym_preproc_line] = STATE(3459),
    [sym_preproc_pragma] = STATE(3459),
    [sym_preproc_nullable] = STATE(3459),
    [sym_preproc_error] = STATE(3459),
    [sym_preproc_warning] = STATE(3459),
    [sym_preproc_define] = STATE(3459),
    [sym_preproc_undef] = STATE(3459),
    [sym__identifier_token] = ACTIONS(4502),
    [anon_sym_alias] = ACTIONS(4502),
    [anon_sym_global] = ACTIONS(4502),
    [anon_sym_LBRACK] = ACTIONS(4504),
    [anon_sym_COLON] = ACTIONS(4504),
    [anon_sym_COMMA] = ACTIONS(4504),
    [anon_sym_LPAREN] = ACTIONS(4504),
    [anon_sym_LBRACE] = ACTIONS(4504),
    [anon_sym_file] = ACTIONS(4502),
    [anon_sym_LT] = ACTIONS(4502),
    [anon_sym_GT] = ACTIONS(4502),
    [anon_sym_where] = ACTIONS(4502),
    [anon_sym_QMARK] = ACTIONS(4502),
    [anon_sym_notnull] = ACTIONS(4502),
    [anon_sym_unmanaged] = ACTIONS(4502),
    [anon_sym_BANG] = ACTIONS(4502),
    [anon_sym_PLUS_PLUS] = ACTIONS(4504),
    [anon_sym_DASH_DASH] = ACTIONS(4504),
    [anon_sym_PLUS] = ACTIONS(4502),
    [anon_sym_DASH] = ACTIONS(4502),
    [anon_sym_STAR] = ACTIONS(4504),
    [anon_sym_SLASH] = ACTIONS(4502),
    [anon_sym_PERCENT] = ACTIONS(4504),
    [anon_sym_CARET] = ACTIONS(4504),
    [anon_sym_PIPE] = ACTIONS(4502),
    [anon_sym_AMP] = ACTIONS(4502),
    [anon_sym_LT_LT] = ACTIONS(4504),
    [anon_sym_GT_GT] = ACTIONS(4502),
    [anon_sym_GT_GT_GT] = ACTIONS(4504),
    [anon_sym_EQ_EQ] = ACTIONS(4504),
    [anon_sym_BANG_EQ] = ACTIONS(4504),
    [anon_sym_GT_EQ] = ACTIONS(4504),
    [anon_sym_LT_EQ] = ACTIONS(4504),
    [anon_sym_DOT] = ACTIONS(4502),
    [anon_sym_scoped] = ACTIONS(4502),
    [anon_sym_var] = ACTIONS(4502),
    [anon_sym_yield] = ACTIONS(4502),
    [anon_sym_switch] = ACTIONS(4502),
    [anon_sym_when] = ACTIONS(4502),
    [sym_discard] = ACTIONS(4502),
    [anon_sym_DOT_DOT] = ACTIONS(4504),
    [anon_sym_and] = ACTIONS(4502),
    [anon_sym_or] = ACTIONS(4502),
    [anon_sym_AMP_AMP] = ACTIONS(4504),
    [anon_sym_PIPE_PIPE] = ACTIONS(4504),
    [anon_sym_QMARK_QMARK] = ACTIONS(4504),
    [anon_sym_from] = ACTIONS(4502),
    [anon_sym_into] = ACTIONS(4502),
    [anon_sym_join] = ACTIONS(4502),
    [anon_sym_on] = ACTIONS(4502),
    [anon_sym_equals] = ACTIONS(4502),
    [anon_sym_let] = ACTIONS(4502),
    [anon_sym_orderby] = ACTIONS(4502),
    [anon_sym_ascending] = ACTIONS(4502),
    [anon_sym_descending] = ACTIONS(4502),
    [anon_sym_group] = ACTIONS(4502),
    [anon_sym_by] = ACTIONS(4502),
    [anon_sym_select] = ACTIONS(4502),
    [anon_sym_as] = ACTIONS(4502),
    [anon_sym_is] = ACTIONS(4502),
    [anon_sym_DASH_GT] = ACTIONS(4504),
    [anon_sym_with] = ACTIONS(4502),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4504),
  },
  [3460] = {
    [sym_preproc_region] = STATE(3460),
    [sym_preproc_endregion] = STATE(3460),
    [sym_preproc_line] = STATE(3460),
    [sym_preproc_pragma] = STATE(3460),
    [sym_preproc_nullable] = STATE(3460),
    [sym_preproc_error] = STATE(3460),
    [sym_preproc_warning] = STATE(3460),
    [sym_preproc_define] = STATE(3460),
    [sym_preproc_undef] = STATE(3460),
    [sym__identifier_token] = ACTIONS(3657),
    [anon_sym_extern] = ACTIONS(3657),
    [anon_sym_alias] = ACTIONS(3657),
    [anon_sym_global] = ACTIONS(3657),
    [anon_sym_using] = ACTIONS(3657),
    [anon_sym_unsafe] = ACTIONS(3657),
    [anon_sym_static] = ACTIONS(3657),
    [anon_sym_LBRACK] = ACTIONS(3659),
    [anon_sym_LPAREN] = ACTIONS(3659),
    [anon_sym_event] = ACTIONS(3657),
    [anon_sym_namespace] = ACTIONS(3657),
    [anon_sym_class] = ACTIONS(3657),
    [anon_sym_ref] = ACTIONS(3657),
    [anon_sym_struct] = ACTIONS(3657),
    [anon_sym_enum] = ACTIONS(3657),
    [anon_sym_RBRACE] = ACTIONS(3659),
    [anon_sym_interface] = ACTIONS(3657),
    [anon_sym_delegate] = ACTIONS(3657),
    [anon_sym_record] = ACTIONS(3657),
    [anon_sym_abstract] = ACTIONS(3657),
    [anon_sym_async] = ACTIONS(3657),
    [anon_sym_const] = ACTIONS(3657),
    [anon_sym_file] = ACTIONS(3657),
    [anon_sym_fixed] = ACTIONS(3657),
    [anon_sym_internal] = ACTIONS(3657),
    [anon_sym_new] = ACTIONS(3657),
    [anon_sym_override] = ACTIONS(3657),
    [anon_sym_partial] = ACTIONS(3657),
    [anon_sym_private] = ACTIONS(3657),
    [anon_sym_protected] = ACTIONS(3657),
    [anon_sym_public] = ACTIONS(3657),
    [anon_sym_readonly] = ACTIONS(3657),
    [anon_sym_required] = ACTIONS(3657),
    [anon_sym_sealed] = ACTIONS(3657),
    [anon_sym_virtual] = ACTIONS(3657),
    [anon_sym_volatile] = ACTIONS(3657),
    [anon_sym_where] = ACTIONS(3657),
    [anon_sym_notnull] = ACTIONS(3657),
    [anon_sym_unmanaged] = ACTIONS(3657),
    [anon_sym_TILDE] = ACTIONS(3659),
    [anon_sym_implicit] = ACTIONS(3657),
    [anon_sym_explicit] = ACTIONS(3657),
    [anon_sym_scoped] = ACTIONS(3657),
    [anon_sym_var] = ACTIONS(3657),
    [sym_predefined_type] = ACTIONS(3657),
    [anon_sym_yield] = ACTIONS(3657),
    [anon_sym_when] = ACTIONS(3657),
    [anon_sym_from] = ACTIONS(3657),
    [anon_sym_into] = ACTIONS(3657),
    [anon_sym_join] = ACTIONS(3657),
    [anon_sym_on] = ACTIONS(3657),
    [anon_sym_equals] = ACTIONS(3657),
    [anon_sym_let] = ACTIONS(3657),
    [anon_sym_orderby] = ACTIONS(3657),
    [anon_sym_ascending] = ACTIONS(3657),
    [anon_sym_descending] = ACTIONS(3657),
    [anon_sym_group] = ACTIONS(3657),
    [anon_sym_by] = ACTIONS(3657),
    [anon_sym_select] = ACTIONS(3657),
    [aux_sym_preproc_if_token1] = ACTIONS(3659),
    [aux_sym_preproc_if_token3] = ACTIONS(3659),
    [aux_sym_preproc_else_token1] = ACTIONS(3659),
    [aux_sym_preproc_elif_token1] = ACTIONS(3659),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3461] = {
    [sym_preproc_region] = STATE(3461),
    [sym_preproc_endregion] = STATE(3461),
    [sym_preproc_line] = STATE(3461),
    [sym_preproc_pragma] = STATE(3461),
    [sym_preproc_nullable] = STATE(3461),
    [sym_preproc_error] = STATE(3461),
    [sym_preproc_warning] = STATE(3461),
    [sym_preproc_define] = STATE(3461),
    [sym_preproc_undef] = STATE(3461),
    [sym__identifier_token] = ACTIONS(3983),
    [anon_sym_extern] = ACTIONS(3983),
    [anon_sym_alias] = ACTIONS(3983),
    [anon_sym_global] = ACTIONS(3983),
    [anon_sym_using] = ACTIONS(3983),
    [anon_sym_unsafe] = ACTIONS(3983),
    [anon_sym_static] = ACTIONS(3983),
    [anon_sym_LBRACK] = ACTIONS(3985),
    [anon_sym_LPAREN] = ACTIONS(3985),
    [anon_sym_event] = ACTIONS(3983),
    [anon_sym_namespace] = ACTIONS(3983),
    [anon_sym_class] = ACTIONS(3983),
    [anon_sym_ref] = ACTIONS(3983),
    [anon_sym_struct] = ACTIONS(3983),
    [anon_sym_enum] = ACTIONS(3983),
    [anon_sym_RBRACE] = ACTIONS(3985),
    [anon_sym_interface] = ACTIONS(3983),
    [anon_sym_delegate] = ACTIONS(3983),
    [anon_sym_record] = ACTIONS(3983),
    [anon_sym_abstract] = ACTIONS(3983),
    [anon_sym_async] = ACTIONS(3983),
    [anon_sym_const] = ACTIONS(3983),
    [anon_sym_file] = ACTIONS(3983),
    [anon_sym_fixed] = ACTIONS(3983),
    [anon_sym_internal] = ACTIONS(3983),
    [anon_sym_new] = ACTIONS(3983),
    [anon_sym_override] = ACTIONS(3983),
    [anon_sym_partial] = ACTIONS(3983),
    [anon_sym_private] = ACTIONS(3983),
    [anon_sym_protected] = ACTIONS(3983),
    [anon_sym_public] = ACTIONS(3983),
    [anon_sym_readonly] = ACTIONS(3983),
    [anon_sym_required] = ACTIONS(3983),
    [anon_sym_sealed] = ACTIONS(3983),
    [anon_sym_virtual] = ACTIONS(3983),
    [anon_sym_volatile] = ACTIONS(3983),
    [anon_sym_where] = ACTIONS(3983),
    [anon_sym_notnull] = ACTIONS(3983),
    [anon_sym_unmanaged] = ACTIONS(3983),
    [anon_sym_TILDE] = ACTIONS(3985),
    [anon_sym_implicit] = ACTIONS(3983),
    [anon_sym_explicit] = ACTIONS(3983),
    [anon_sym_scoped] = ACTIONS(3983),
    [anon_sym_var] = ACTIONS(3983),
    [sym_predefined_type] = ACTIONS(3983),
    [anon_sym_yield] = ACTIONS(3983),
    [anon_sym_when] = ACTIONS(3983),
    [anon_sym_from] = ACTIONS(3983),
    [anon_sym_into] = ACTIONS(3983),
    [anon_sym_join] = ACTIONS(3983),
    [anon_sym_on] = ACTIONS(3983),
    [anon_sym_equals] = ACTIONS(3983),
    [anon_sym_let] = ACTIONS(3983),
    [anon_sym_orderby] = ACTIONS(3983),
    [anon_sym_ascending] = ACTIONS(3983),
    [anon_sym_descending] = ACTIONS(3983),
    [anon_sym_group] = ACTIONS(3983),
    [anon_sym_by] = ACTIONS(3983),
    [anon_sym_select] = ACTIONS(3983),
    [aux_sym_preproc_if_token1] = ACTIONS(3985),
    [aux_sym_preproc_if_token3] = ACTIONS(3985),
    [aux_sym_preproc_else_token1] = ACTIONS(3985),
    [aux_sym_preproc_elif_token1] = ACTIONS(3985),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3462] = {
    [sym_preproc_region] = STATE(3462),
    [sym_preproc_endregion] = STATE(3462),
    [sym_preproc_line] = STATE(3462),
    [sym_preproc_pragma] = STATE(3462),
    [sym_preproc_nullable] = STATE(3462),
    [sym_preproc_error] = STATE(3462),
    [sym_preproc_warning] = STATE(3462),
    [sym_preproc_define] = STATE(3462),
    [sym_preproc_undef] = STATE(3462),
    [sym__identifier_token] = ACTIONS(3665),
    [anon_sym_extern] = ACTIONS(3665),
    [anon_sym_alias] = ACTIONS(3665),
    [anon_sym_global] = ACTIONS(3665),
    [anon_sym_using] = ACTIONS(3665),
    [anon_sym_unsafe] = ACTIONS(3665),
    [anon_sym_static] = ACTIONS(3665),
    [anon_sym_LBRACK] = ACTIONS(3667),
    [anon_sym_LPAREN] = ACTIONS(3667),
    [anon_sym_event] = ACTIONS(3665),
    [anon_sym_namespace] = ACTIONS(3665),
    [anon_sym_class] = ACTIONS(3665),
    [anon_sym_ref] = ACTIONS(3665),
    [anon_sym_struct] = ACTIONS(3665),
    [anon_sym_enum] = ACTIONS(3665),
    [anon_sym_RBRACE] = ACTIONS(3667),
    [anon_sym_interface] = ACTIONS(3665),
    [anon_sym_delegate] = ACTIONS(3665),
    [anon_sym_record] = ACTIONS(3665),
    [anon_sym_abstract] = ACTIONS(3665),
    [anon_sym_async] = ACTIONS(3665),
    [anon_sym_const] = ACTIONS(3665),
    [anon_sym_file] = ACTIONS(3665),
    [anon_sym_fixed] = ACTIONS(3665),
    [anon_sym_internal] = ACTIONS(3665),
    [anon_sym_new] = ACTIONS(3665),
    [anon_sym_override] = ACTIONS(3665),
    [anon_sym_partial] = ACTIONS(3665),
    [anon_sym_private] = ACTIONS(3665),
    [anon_sym_protected] = ACTIONS(3665),
    [anon_sym_public] = ACTIONS(3665),
    [anon_sym_readonly] = ACTIONS(3665),
    [anon_sym_required] = ACTIONS(3665),
    [anon_sym_sealed] = ACTIONS(3665),
    [anon_sym_virtual] = ACTIONS(3665),
    [anon_sym_volatile] = ACTIONS(3665),
    [anon_sym_where] = ACTIONS(3665),
    [anon_sym_notnull] = ACTIONS(3665),
    [anon_sym_unmanaged] = ACTIONS(3665),
    [anon_sym_TILDE] = ACTIONS(3667),
    [anon_sym_implicit] = ACTIONS(3665),
    [anon_sym_explicit] = ACTIONS(3665),
    [anon_sym_scoped] = ACTIONS(3665),
    [anon_sym_var] = ACTIONS(3665),
    [sym_predefined_type] = ACTIONS(3665),
    [anon_sym_yield] = ACTIONS(3665),
    [anon_sym_when] = ACTIONS(3665),
    [anon_sym_from] = ACTIONS(3665),
    [anon_sym_into] = ACTIONS(3665),
    [anon_sym_join] = ACTIONS(3665),
    [anon_sym_on] = ACTIONS(3665),
    [anon_sym_equals] = ACTIONS(3665),
    [anon_sym_let] = ACTIONS(3665),
    [anon_sym_orderby] = ACTIONS(3665),
    [anon_sym_ascending] = ACTIONS(3665),
    [anon_sym_descending] = ACTIONS(3665),
    [anon_sym_group] = ACTIONS(3665),
    [anon_sym_by] = ACTIONS(3665),
    [anon_sym_select] = ACTIONS(3665),
    [aux_sym_preproc_if_token1] = ACTIONS(3667),
    [aux_sym_preproc_if_token3] = ACTIONS(3667),
    [aux_sym_preproc_else_token1] = ACTIONS(3667),
    [aux_sym_preproc_elif_token1] = ACTIONS(3667),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3463] = {
    [sym_preproc_region] = STATE(3463),
    [sym_preproc_endregion] = STATE(3463),
    [sym_preproc_line] = STATE(3463),
    [sym_preproc_pragma] = STATE(3463),
    [sym_preproc_nullable] = STATE(3463),
    [sym_preproc_error] = STATE(3463),
    [sym_preproc_warning] = STATE(3463),
    [sym_preproc_define] = STATE(3463),
    [sym_preproc_undef] = STATE(3463),
    [sym__identifier_token] = ACTIONS(3669),
    [anon_sym_extern] = ACTIONS(3669),
    [anon_sym_alias] = ACTIONS(3669),
    [anon_sym_global] = ACTIONS(3669),
    [anon_sym_using] = ACTIONS(3669),
    [anon_sym_unsafe] = ACTIONS(3669),
    [anon_sym_static] = ACTIONS(3669),
    [anon_sym_LBRACK] = ACTIONS(3671),
    [anon_sym_LPAREN] = ACTIONS(3671),
    [anon_sym_event] = ACTIONS(3669),
    [anon_sym_namespace] = ACTIONS(3669),
    [anon_sym_class] = ACTIONS(3669),
    [anon_sym_ref] = ACTIONS(3669),
    [anon_sym_struct] = ACTIONS(3669),
    [anon_sym_enum] = ACTIONS(3669),
    [anon_sym_RBRACE] = ACTIONS(3671),
    [anon_sym_interface] = ACTIONS(3669),
    [anon_sym_delegate] = ACTIONS(3669),
    [anon_sym_record] = ACTIONS(3669),
    [anon_sym_abstract] = ACTIONS(3669),
    [anon_sym_async] = ACTIONS(3669),
    [anon_sym_const] = ACTIONS(3669),
    [anon_sym_file] = ACTIONS(3669),
    [anon_sym_fixed] = ACTIONS(3669),
    [anon_sym_internal] = ACTIONS(3669),
    [anon_sym_new] = ACTIONS(3669),
    [anon_sym_override] = ACTIONS(3669),
    [anon_sym_partial] = ACTIONS(3669),
    [anon_sym_private] = ACTIONS(3669),
    [anon_sym_protected] = ACTIONS(3669),
    [anon_sym_public] = ACTIONS(3669),
    [anon_sym_readonly] = ACTIONS(3669),
    [anon_sym_required] = ACTIONS(3669),
    [anon_sym_sealed] = ACTIONS(3669),
    [anon_sym_virtual] = ACTIONS(3669),
    [anon_sym_volatile] = ACTIONS(3669),
    [anon_sym_where] = ACTIONS(3669),
    [anon_sym_notnull] = ACTIONS(3669),
    [anon_sym_unmanaged] = ACTIONS(3669),
    [anon_sym_TILDE] = ACTIONS(3671),
    [anon_sym_implicit] = ACTIONS(3669),
    [anon_sym_explicit] = ACTIONS(3669),
    [anon_sym_scoped] = ACTIONS(3669),
    [anon_sym_var] = ACTIONS(3669),
    [sym_predefined_type] = ACTIONS(3669),
    [anon_sym_yield] = ACTIONS(3669),
    [anon_sym_when] = ACTIONS(3669),
    [anon_sym_from] = ACTIONS(3669),
    [anon_sym_into] = ACTIONS(3669),
    [anon_sym_join] = ACTIONS(3669),
    [anon_sym_on] = ACTIONS(3669),
    [anon_sym_equals] = ACTIONS(3669),
    [anon_sym_let] = ACTIONS(3669),
    [anon_sym_orderby] = ACTIONS(3669),
    [anon_sym_ascending] = ACTIONS(3669),
    [anon_sym_descending] = ACTIONS(3669),
    [anon_sym_group] = ACTIONS(3669),
    [anon_sym_by] = ACTIONS(3669),
    [anon_sym_select] = ACTIONS(3669),
    [aux_sym_preproc_if_token1] = ACTIONS(3671),
    [aux_sym_preproc_if_token3] = ACTIONS(3671),
    [aux_sym_preproc_else_token1] = ACTIONS(3671),
    [aux_sym_preproc_elif_token1] = ACTIONS(3671),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3464] = {
    [sym_preproc_region] = STATE(3464),
    [sym_preproc_endregion] = STATE(3464),
    [sym_preproc_line] = STATE(3464),
    [sym_preproc_pragma] = STATE(3464),
    [sym_preproc_nullable] = STATE(3464),
    [sym_preproc_error] = STATE(3464),
    [sym_preproc_warning] = STATE(3464),
    [sym_preproc_define] = STATE(3464),
    [sym_preproc_undef] = STATE(3464),
    [sym__identifier_token] = ACTIONS(3673),
    [anon_sym_extern] = ACTIONS(3673),
    [anon_sym_alias] = ACTIONS(3673),
    [anon_sym_global] = ACTIONS(3673),
    [anon_sym_using] = ACTIONS(3673),
    [anon_sym_unsafe] = ACTIONS(3673),
    [anon_sym_static] = ACTIONS(3673),
    [anon_sym_LBRACK] = ACTIONS(3675),
    [anon_sym_LPAREN] = ACTIONS(3675),
    [anon_sym_event] = ACTIONS(3673),
    [anon_sym_namespace] = ACTIONS(3673),
    [anon_sym_class] = ACTIONS(3673),
    [anon_sym_ref] = ACTIONS(3673),
    [anon_sym_struct] = ACTIONS(3673),
    [anon_sym_enum] = ACTIONS(3673),
    [anon_sym_RBRACE] = ACTIONS(3675),
    [anon_sym_interface] = ACTIONS(3673),
    [anon_sym_delegate] = ACTIONS(3673),
    [anon_sym_record] = ACTIONS(3673),
    [anon_sym_abstract] = ACTIONS(3673),
    [anon_sym_async] = ACTIONS(3673),
    [anon_sym_const] = ACTIONS(3673),
    [anon_sym_file] = ACTIONS(3673),
    [anon_sym_fixed] = ACTIONS(3673),
    [anon_sym_internal] = ACTIONS(3673),
    [anon_sym_new] = ACTIONS(3673),
    [anon_sym_override] = ACTIONS(3673),
    [anon_sym_partial] = ACTIONS(3673),
    [anon_sym_private] = ACTIONS(3673),
    [anon_sym_protected] = ACTIONS(3673),
    [anon_sym_public] = ACTIONS(3673),
    [anon_sym_readonly] = ACTIONS(3673),
    [anon_sym_required] = ACTIONS(3673),
    [anon_sym_sealed] = ACTIONS(3673),
    [anon_sym_virtual] = ACTIONS(3673),
    [anon_sym_volatile] = ACTIONS(3673),
    [anon_sym_where] = ACTIONS(3673),
    [anon_sym_notnull] = ACTIONS(3673),
    [anon_sym_unmanaged] = ACTIONS(3673),
    [anon_sym_TILDE] = ACTIONS(3675),
    [anon_sym_implicit] = ACTIONS(3673),
    [anon_sym_explicit] = ACTIONS(3673),
    [anon_sym_scoped] = ACTIONS(3673),
    [anon_sym_var] = ACTIONS(3673),
    [sym_predefined_type] = ACTIONS(3673),
    [anon_sym_yield] = ACTIONS(3673),
    [anon_sym_when] = ACTIONS(3673),
    [anon_sym_from] = ACTIONS(3673),
    [anon_sym_into] = ACTIONS(3673),
    [anon_sym_join] = ACTIONS(3673),
    [anon_sym_on] = ACTIONS(3673),
    [anon_sym_equals] = ACTIONS(3673),
    [anon_sym_let] = ACTIONS(3673),
    [anon_sym_orderby] = ACTIONS(3673),
    [anon_sym_ascending] = ACTIONS(3673),
    [anon_sym_descending] = ACTIONS(3673),
    [anon_sym_group] = ACTIONS(3673),
    [anon_sym_by] = ACTIONS(3673),
    [anon_sym_select] = ACTIONS(3673),
    [aux_sym_preproc_if_token1] = ACTIONS(3675),
    [aux_sym_preproc_if_token3] = ACTIONS(3675),
    [aux_sym_preproc_else_token1] = ACTIONS(3675),
    [aux_sym_preproc_elif_token1] = ACTIONS(3675),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3465] = {
    [sym_preproc_region] = STATE(3465),
    [sym_preproc_endregion] = STATE(3465),
    [sym_preproc_line] = STATE(3465),
    [sym_preproc_pragma] = STATE(3465),
    [sym_preproc_nullable] = STATE(3465),
    [sym_preproc_error] = STATE(3465),
    [sym_preproc_warning] = STATE(3465),
    [sym_preproc_define] = STATE(3465),
    [sym_preproc_undef] = STATE(3465),
    [sym__identifier_token] = ACTIONS(4492),
    [anon_sym_alias] = ACTIONS(4492),
    [anon_sym_global] = ACTIONS(4492),
    [anon_sym_LBRACK] = ACTIONS(4593),
    [anon_sym_COLON] = ACTIONS(4494),
    [anon_sym_COMMA] = ACTIONS(4494),
    [anon_sym_LPAREN] = ACTIONS(4494),
    [anon_sym_LBRACE] = ACTIONS(4494),
    [anon_sym_file] = ACTIONS(4492),
    [anon_sym_LT] = ACTIONS(4492),
    [anon_sym_GT] = ACTIONS(4492),
    [anon_sym_where] = ACTIONS(4492),
    [anon_sym_QMARK] = ACTIONS(4970),
    [anon_sym_notnull] = ACTIONS(4492),
    [anon_sym_unmanaged] = ACTIONS(4492),
    [anon_sym_BANG] = ACTIONS(4492),
    [anon_sym_PLUS_PLUS] = ACTIONS(4494),
    [anon_sym_DASH_DASH] = ACTIONS(4494),
    [anon_sym_PLUS] = ACTIONS(4492),
    [anon_sym_DASH] = ACTIONS(4492),
    [anon_sym_STAR] = ACTIONS(4599),
    [anon_sym_SLASH] = ACTIONS(4492),
    [anon_sym_PERCENT] = ACTIONS(4494),
    [anon_sym_CARET] = ACTIONS(4494),
    [anon_sym_PIPE] = ACTIONS(4492),
    [anon_sym_AMP] = ACTIONS(4492),
    [anon_sym_LT_LT] = ACTIONS(4494),
    [anon_sym_GT_GT] = ACTIONS(4492),
    [anon_sym_GT_GT_GT] = ACTIONS(4494),
    [anon_sym_EQ_EQ] = ACTIONS(4494),
    [anon_sym_BANG_EQ] = ACTIONS(4494),
    [anon_sym_GT_EQ] = ACTIONS(4494),
    [anon_sym_LT_EQ] = ACTIONS(4494),
    [anon_sym_DOT] = ACTIONS(5215),
    [anon_sym_scoped] = ACTIONS(4492),
    [anon_sym_var] = ACTIONS(4492),
    [anon_sym_yield] = ACTIONS(4492),
    [anon_sym_switch] = ACTIONS(4492),
    [anon_sym_when] = ACTIONS(4492),
    [sym_discard] = ACTIONS(4492),
    [anon_sym_DOT_DOT] = ACTIONS(4494),
    [anon_sym_and] = ACTIONS(4492),
    [anon_sym_or] = ACTIONS(4492),
    [anon_sym_AMP_AMP] = ACTIONS(4494),
    [anon_sym_PIPE_PIPE] = ACTIONS(4494),
    [anon_sym_QMARK_QMARK] = ACTIONS(4494),
    [anon_sym_from] = ACTIONS(4492),
    [anon_sym_into] = ACTIONS(4492),
    [anon_sym_join] = ACTIONS(4492),
    [anon_sym_on] = ACTIONS(4492),
    [anon_sym_equals] = ACTIONS(4492),
    [anon_sym_let] = ACTIONS(4492),
    [anon_sym_orderby] = ACTIONS(4492),
    [anon_sym_ascending] = ACTIONS(4492),
    [anon_sym_descending] = ACTIONS(4492),
    [anon_sym_group] = ACTIONS(4492),
    [anon_sym_by] = ACTIONS(4492),
    [anon_sym_select] = ACTIONS(4492),
    [anon_sym_as] = ACTIONS(4492),
    [anon_sym_is] = ACTIONS(4492),
    [anon_sym_DASH_GT] = ACTIONS(4975),
    [anon_sym_with] = ACTIONS(4492),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4494),
  },
  [3466] = {
    [sym_preproc_region] = STATE(3466),
    [sym_preproc_endregion] = STATE(3466),
    [sym_preproc_line] = STATE(3466),
    [sym_preproc_pragma] = STATE(3466),
    [sym_preproc_nullable] = STATE(3466),
    [sym_preproc_error] = STATE(3466),
    [sym_preproc_warning] = STATE(3466),
    [sym_preproc_define] = STATE(3466),
    [sym_preproc_undef] = STATE(3466),
    [sym__identifier_token] = ACTIONS(3677),
    [anon_sym_extern] = ACTIONS(3677),
    [anon_sym_alias] = ACTIONS(3677),
    [anon_sym_global] = ACTIONS(3677),
    [anon_sym_using] = ACTIONS(3677),
    [anon_sym_unsafe] = ACTIONS(3677),
    [anon_sym_static] = ACTIONS(3677),
    [anon_sym_LBRACK] = ACTIONS(3679),
    [anon_sym_LPAREN] = ACTIONS(3679),
    [anon_sym_event] = ACTIONS(3677),
    [anon_sym_namespace] = ACTIONS(3677),
    [anon_sym_class] = ACTIONS(3677),
    [anon_sym_ref] = ACTIONS(3677),
    [anon_sym_struct] = ACTIONS(3677),
    [anon_sym_enum] = ACTIONS(3677),
    [anon_sym_RBRACE] = ACTIONS(3679),
    [anon_sym_interface] = ACTIONS(3677),
    [anon_sym_delegate] = ACTIONS(3677),
    [anon_sym_record] = ACTIONS(3677),
    [anon_sym_abstract] = ACTIONS(3677),
    [anon_sym_async] = ACTIONS(3677),
    [anon_sym_const] = ACTIONS(3677),
    [anon_sym_file] = ACTIONS(3677),
    [anon_sym_fixed] = ACTIONS(3677),
    [anon_sym_internal] = ACTIONS(3677),
    [anon_sym_new] = ACTIONS(3677),
    [anon_sym_override] = ACTIONS(3677),
    [anon_sym_partial] = ACTIONS(3677),
    [anon_sym_private] = ACTIONS(3677),
    [anon_sym_protected] = ACTIONS(3677),
    [anon_sym_public] = ACTIONS(3677),
    [anon_sym_readonly] = ACTIONS(3677),
    [anon_sym_required] = ACTIONS(3677),
    [anon_sym_sealed] = ACTIONS(3677),
    [anon_sym_virtual] = ACTIONS(3677),
    [anon_sym_volatile] = ACTIONS(3677),
    [anon_sym_where] = ACTIONS(3677),
    [anon_sym_notnull] = ACTIONS(3677),
    [anon_sym_unmanaged] = ACTIONS(3677),
    [anon_sym_TILDE] = ACTIONS(3679),
    [anon_sym_implicit] = ACTIONS(3677),
    [anon_sym_explicit] = ACTIONS(3677),
    [anon_sym_scoped] = ACTIONS(3677),
    [anon_sym_var] = ACTIONS(3677),
    [sym_predefined_type] = ACTIONS(3677),
    [anon_sym_yield] = ACTIONS(3677),
    [anon_sym_when] = ACTIONS(3677),
    [anon_sym_from] = ACTIONS(3677),
    [anon_sym_into] = ACTIONS(3677),
    [anon_sym_join] = ACTIONS(3677),
    [anon_sym_on] = ACTIONS(3677),
    [anon_sym_equals] = ACTIONS(3677),
    [anon_sym_let] = ACTIONS(3677),
    [anon_sym_orderby] = ACTIONS(3677),
    [anon_sym_ascending] = ACTIONS(3677),
    [anon_sym_descending] = ACTIONS(3677),
    [anon_sym_group] = ACTIONS(3677),
    [anon_sym_by] = ACTIONS(3677),
    [anon_sym_select] = ACTIONS(3677),
    [aux_sym_preproc_if_token1] = ACTIONS(3679),
    [aux_sym_preproc_if_token3] = ACTIONS(3679),
    [aux_sym_preproc_else_token1] = ACTIONS(3679),
    [aux_sym_preproc_elif_token1] = ACTIONS(3679),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3467] = {
    [sym_preproc_region] = STATE(3467),
    [sym_preproc_endregion] = STATE(3467),
    [sym_preproc_line] = STATE(3467),
    [sym_preproc_pragma] = STATE(3467),
    [sym_preproc_nullable] = STATE(3467),
    [sym_preproc_error] = STATE(3467),
    [sym_preproc_warning] = STATE(3467),
    [sym_preproc_define] = STATE(3467),
    [sym_preproc_undef] = STATE(3467),
    [sym__identifier_token] = ACTIONS(3951),
    [anon_sym_extern] = ACTIONS(3951),
    [anon_sym_alias] = ACTIONS(3951),
    [anon_sym_global] = ACTIONS(3951),
    [anon_sym_using] = ACTIONS(3951),
    [anon_sym_unsafe] = ACTIONS(3951),
    [anon_sym_static] = ACTIONS(3951),
    [anon_sym_LBRACK] = ACTIONS(3953),
    [anon_sym_LPAREN] = ACTIONS(3953),
    [anon_sym_event] = ACTIONS(3951),
    [anon_sym_namespace] = ACTIONS(3951),
    [anon_sym_class] = ACTIONS(3951),
    [anon_sym_ref] = ACTIONS(3951),
    [anon_sym_struct] = ACTIONS(3951),
    [anon_sym_enum] = ACTIONS(3951),
    [anon_sym_RBRACE] = ACTIONS(3953),
    [anon_sym_interface] = ACTIONS(3951),
    [anon_sym_delegate] = ACTIONS(3951),
    [anon_sym_record] = ACTIONS(3951),
    [anon_sym_abstract] = ACTIONS(3951),
    [anon_sym_async] = ACTIONS(3951),
    [anon_sym_const] = ACTIONS(3951),
    [anon_sym_file] = ACTIONS(3951),
    [anon_sym_fixed] = ACTIONS(3951),
    [anon_sym_internal] = ACTIONS(3951),
    [anon_sym_new] = ACTIONS(3951),
    [anon_sym_override] = ACTIONS(3951),
    [anon_sym_partial] = ACTIONS(3951),
    [anon_sym_private] = ACTIONS(3951),
    [anon_sym_protected] = ACTIONS(3951),
    [anon_sym_public] = ACTIONS(3951),
    [anon_sym_readonly] = ACTIONS(3951),
    [anon_sym_required] = ACTIONS(3951),
    [anon_sym_sealed] = ACTIONS(3951),
    [anon_sym_virtual] = ACTIONS(3951),
    [anon_sym_volatile] = ACTIONS(3951),
    [anon_sym_where] = ACTIONS(3951),
    [anon_sym_notnull] = ACTIONS(3951),
    [anon_sym_unmanaged] = ACTIONS(3951),
    [anon_sym_TILDE] = ACTIONS(3953),
    [anon_sym_implicit] = ACTIONS(3951),
    [anon_sym_explicit] = ACTIONS(3951),
    [anon_sym_scoped] = ACTIONS(3951),
    [anon_sym_var] = ACTIONS(3951),
    [sym_predefined_type] = ACTIONS(3951),
    [anon_sym_yield] = ACTIONS(3951),
    [anon_sym_when] = ACTIONS(3951),
    [anon_sym_from] = ACTIONS(3951),
    [anon_sym_into] = ACTIONS(3951),
    [anon_sym_join] = ACTIONS(3951),
    [anon_sym_on] = ACTIONS(3951),
    [anon_sym_equals] = ACTIONS(3951),
    [anon_sym_let] = ACTIONS(3951),
    [anon_sym_orderby] = ACTIONS(3951),
    [anon_sym_ascending] = ACTIONS(3951),
    [anon_sym_descending] = ACTIONS(3951),
    [anon_sym_group] = ACTIONS(3951),
    [anon_sym_by] = ACTIONS(3951),
    [anon_sym_select] = ACTIONS(3951),
    [aux_sym_preproc_if_token1] = ACTIONS(3953),
    [aux_sym_preproc_if_token3] = ACTIONS(3953),
    [aux_sym_preproc_else_token1] = ACTIONS(3953),
    [aux_sym_preproc_elif_token1] = ACTIONS(3953),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3468] = {
    [sym_preproc_region] = STATE(3468),
    [sym_preproc_endregion] = STATE(3468),
    [sym_preproc_line] = STATE(3468),
    [sym_preproc_pragma] = STATE(3468),
    [sym_preproc_nullable] = STATE(3468),
    [sym_preproc_error] = STATE(3468),
    [sym_preproc_warning] = STATE(3468),
    [sym_preproc_define] = STATE(3468),
    [sym_preproc_undef] = STATE(3468),
    [sym__identifier_token] = ACTIONS(3681),
    [anon_sym_extern] = ACTIONS(3681),
    [anon_sym_alias] = ACTIONS(3681),
    [anon_sym_global] = ACTIONS(3681),
    [anon_sym_using] = ACTIONS(3681),
    [anon_sym_unsafe] = ACTIONS(3681),
    [anon_sym_static] = ACTIONS(3681),
    [anon_sym_LBRACK] = ACTIONS(3683),
    [anon_sym_LPAREN] = ACTIONS(3683),
    [anon_sym_event] = ACTIONS(3681),
    [anon_sym_namespace] = ACTIONS(3681),
    [anon_sym_class] = ACTIONS(3681),
    [anon_sym_ref] = ACTIONS(3681),
    [anon_sym_struct] = ACTIONS(3681),
    [anon_sym_enum] = ACTIONS(3681),
    [anon_sym_RBRACE] = ACTIONS(3683),
    [anon_sym_interface] = ACTIONS(3681),
    [anon_sym_delegate] = ACTIONS(3681),
    [anon_sym_record] = ACTIONS(3681),
    [anon_sym_abstract] = ACTIONS(3681),
    [anon_sym_async] = ACTIONS(3681),
    [anon_sym_const] = ACTIONS(3681),
    [anon_sym_file] = ACTIONS(3681),
    [anon_sym_fixed] = ACTIONS(3681),
    [anon_sym_internal] = ACTIONS(3681),
    [anon_sym_new] = ACTIONS(3681),
    [anon_sym_override] = ACTIONS(3681),
    [anon_sym_partial] = ACTIONS(3681),
    [anon_sym_private] = ACTIONS(3681),
    [anon_sym_protected] = ACTIONS(3681),
    [anon_sym_public] = ACTIONS(3681),
    [anon_sym_readonly] = ACTIONS(3681),
    [anon_sym_required] = ACTIONS(3681),
    [anon_sym_sealed] = ACTIONS(3681),
    [anon_sym_virtual] = ACTIONS(3681),
    [anon_sym_volatile] = ACTIONS(3681),
    [anon_sym_where] = ACTIONS(3681),
    [anon_sym_notnull] = ACTIONS(3681),
    [anon_sym_unmanaged] = ACTIONS(3681),
    [anon_sym_TILDE] = ACTIONS(3683),
    [anon_sym_implicit] = ACTIONS(3681),
    [anon_sym_explicit] = ACTIONS(3681),
    [anon_sym_scoped] = ACTIONS(3681),
    [anon_sym_var] = ACTIONS(3681),
    [sym_predefined_type] = ACTIONS(3681),
    [anon_sym_yield] = ACTIONS(3681),
    [anon_sym_when] = ACTIONS(3681),
    [anon_sym_from] = ACTIONS(3681),
    [anon_sym_into] = ACTIONS(3681),
    [anon_sym_join] = ACTIONS(3681),
    [anon_sym_on] = ACTIONS(3681),
    [anon_sym_equals] = ACTIONS(3681),
    [anon_sym_let] = ACTIONS(3681),
    [anon_sym_orderby] = ACTIONS(3681),
    [anon_sym_ascending] = ACTIONS(3681),
    [anon_sym_descending] = ACTIONS(3681),
    [anon_sym_group] = ACTIONS(3681),
    [anon_sym_by] = ACTIONS(3681),
    [anon_sym_select] = ACTIONS(3681),
    [aux_sym_preproc_if_token1] = ACTIONS(3683),
    [aux_sym_preproc_if_token3] = ACTIONS(3683),
    [aux_sym_preproc_else_token1] = ACTIONS(3683),
    [aux_sym_preproc_elif_token1] = ACTIONS(3683),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3469] = {
    [sym_preproc_region] = STATE(3469),
    [sym_preproc_endregion] = STATE(3469),
    [sym_preproc_line] = STATE(3469),
    [sym_preproc_pragma] = STATE(3469),
    [sym_preproc_nullable] = STATE(3469),
    [sym_preproc_error] = STATE(3469),
    [sym_preproc_warning] = STATE(3469),
    [sym_preproc_define] = STATE(3469),
    [sym_preproc_undef] = STATE(3469),
    [sym__identifier_token] = ACTIONS(3509),
    [anon_sym_extern] = ACTIONS(3509),
    [anon_sym_alias] = ACTIONS(3509),
    [anon_sym_global] = ACTIONS(3509),
    [anon_sym_using] = ACTIONS(3509),
    [anon_sym_unsafe] = ACTIONS(3509),
    [anon_sym_static] = ACTIONS(3509),
    [anon_sym_LBRACK] = ACTIONS(3511),
    [anon_sym_LPAREN] = ACTIONS(3511),
    [anon_sym_event] = ACTIONS(3509),
    [anon_sym_namespace] = ACTIONS(3509),
    [anon_sym_class] = ACTIONS(3509),
    [anon_sym_ref] = ACTIONS(3509),
    [anon_sym_struct] = ACTIONS(3509),
    [anon_sym_enum] = ACTIONS(3509),
    [anon_sym_RBRACE] = ACTIONS(3511),
    [anon_sym_interface] = ACTIONS(3509),
    [anon_sym_delegate] = ACTIONS(3509),
    [anon_sym_record] = ACTIONS(3509),
    [anon_sym_abstract] = ACTIONS(3509),
    [anon_sym_async] = ACTIONS(3509),
    [anon_sym_const] = ACTIONS(3509),
    [anon_sym_file] = ACTIONS(3509),
    [anon_sym_fixed] = ACTIONS(3509),
    [anon_sym_internal] = ACTIONS(3509),
    [anon_sym_new] = ACTIONS(3509),
    [anon_sym_override] = ACTIONS(3509),
    [anon_sym_partial] = ACTIONS(3509),
    [anon_sym_private] = ACTIONS(3509),
    [anon_sym_protected] = ACTIONS(3509),
    [anon_sym_public] = ACTIONS(3509),
    [anon_sym_readonly] = ACTIONS(3509),
    [anon_sym_required] = ACTIONS(3509),
    [anon_sym_sealed] = ACTIONS(3509),
    [anon_sym_virtual] = ACTIONS(3509),
    [anon_sym_volatile] = ACTIONS(3509),
    [anon_sym_where] = ACTIONS(3509),
    [anon_sym_notnull] = ACTIONS(3509),
    [anon_sym_unmanaged] = ACTIONS(3509),
    [anon_sym_TILDE] = ACTIONS(3511),
    [anon_sym_implicit] = ACTIONS(3509),
    [anon_sym_explicit] = ACTIONS(3509),
    [anon_sym_scoped] = ACTIONS(3509),
    [anon_sym_var] = ACTIONS(3509),
    [sym_predefined_type] = ACTIONS(3509),
    [anon_sym_yield] = ACTIONS(3509),
    [anon_sym_when] = ACTIONS(3509),
    [anon_sym_from] = ACTIONS(3509),
    [anon_sym_into] = ACTIONS(3509),
    [anon_sym_join] = ACTIONS(3509),
    [anon_sym_on] = ACTIONS(3509),
    [anon_sym_equals] = ACTIONS(3509),
    [anon_sym_let] = ACTIONS(3509),
    [anon_sym_orderby] = ACTIONS(3509),
    [anon_sym_ascending] = ACTIONS(3509),
    [anon_sym_descending] = ACTIONS(3509),
    [anon_sym_group] = ACTIONS(3509),
    [anon_sym_by] = ACTIONS(3509),
    [anon_sym_select] = ACTIONS(3509),
    [aux_sym_preproc_if_token1] = ACTIONS(3511),
    [aux_sym_preproc_if_token3] = ACTIONS(3511),
    [aux_sym_preproc_else_token1] = ACTIONS(3511),
    [aux_sym_preproc_elif_token1] = ACTIONS(3511),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3470] = {
    [sym_preproc_region] = STATE(3470),
    [sym_preproc_endregion] = STATE(3470),
    [sym_preproc_line] = STATE(3470),
    [sym_preproc_pragma] = STATE(3470),
    [sym_preproc_nullable] = STATE(3470),
    [sym_preproc_error] = STATE(3470),
    [sym_preproc_warning] = STATE(3470),
    [sym_preproc_define] = STATE(3470),
    [sym_preproc_undef] = STATE(3470),
    [sym__identifier_token] = ACTIONS(3685),
    [anon_sym_extern] = ACTIONS(3685),
    [anon_sym_alias] = ACTIONS(3685),
    [anon_sym_global] = ACTIONS(3685),
    [anon_sym_using] = ACTIONS(3685),
    [anon_sym_unsafe] = ACTIONS(3685),
    [anon_sym_static] = ACTIONS(3685),
    [anon_sym_LBRACK] = ACTIONS(3687),
    [anon_sym_LPAREN] = ACTIONS(3687),
    [anon_sym_event] = ACTIONS(3685),
    [anon_sym_namespace] = ACTIONS(3685),
    [anon_sym_class] = ACTIONS(3685),
    [anon_sym_ref] = ACTIONS(3685),
    [anon_sym_struct] = ACTIONS(3685),
    [anon_sym_enum] = ACTIONS(3685),
    [anon_sym_RBRACE] = ACTIONS(3687),
    [anon_sym_interface] = ACTIONS(3685),
    [anon_sym_delegate] = ACTIONS(3685),
    [anon_sym_record] = ACTIONS(3685),
    [anon_sym_abstract] = ACTIONS(3685),
    [anon_sym_async] = ACTIONS(3685),
    [anon_sym_const] = ACTIONS(3685),
    [anon_sym_file] = ACTIONS(3685),
    [anon_sym_fixed] = ACTIONS(3685),
    [anon_sym_internal] = ACTIONS(3685),
    [anon_sym_new] = ACTIONS(3685),
    [anon_sym_override] = ACTIONS(3685),
    [anon_sym_partial] = ACTIONS(3685),
    [anon_sym_private] = ACTIONS(3685),
    [anon_sym_protected] = ACTIONS(3685),
    [anon_sym_public] = ACTIONS(3685),
    [anon_sym_readonly] = ACTIONS(3685),
    [anon_sym_required] = ACTIONS(3685),
    [anon_sym_sealed] = ACTIONS(3685),
    [anon_sym_virtual] = ACTIONS(3685),
    [anon_sym_volatile] = ACTIONS(3685),
    [anon_sym_where] = ACTIONS(3685),
    [anon_sym_notnull] = ACTIONS(3685),
    [anon_sym_unmanaged] = ACTIONS(3685),
    [anon_sym_TILDE] = ACTIONS(3687),
    [anon_sym_implicit] = ACTIONS(3685),
    [anon_sym_explicit] = ACTIONS(3685),
    [anon_sym_scoped] = ACTIONS(3685),
    [anon_sym_var] = ACTIONS(3685),
    [sym_predefined_type] = ACTIONS(3685),
    [anon_sym_yield] = ACTIONS(3685),
    [anon_sym_when] = ACTIONS(3685),
    [anon_sym_from] = ACTIONS(3685),
    [anon_sym_into] = ACTIONS(3685),
    [anon_sym_join] = ACTIONS(3685),
    [anon_sym_on] = ACTIONS(3685),
    [anon_sym_equals] = ACTIONS(3685),
    [anon_sym_let] = ACTIONS(3685),
    [anon_sym_orderby] = ACTIONS(3685),
    [anon_sym_ascending] = ACTIONS(3685),
    [anon_sym_descending] = ACTIONS(3685),
    [anon_sym_group] = ACTIONS(3685),
    [anon_sym_by] = ACTIONS(3685),
    [anon_sym_select] = ACTIONS(3685),
    [aux_sym_preproc_if_token1] = ACTIONS(3687),
    [aux_sym_preproc_if_token3] = ACTIONS(3687),
    [aux_sym_preproc_else_token1] = ACTIONS(3687),
    [aux_sym_preproc_elif_token1] = ACTIONS(3687),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3471] = {
    [sym_preproc_region] = STATE(3471),
    [sym_preproc_endregion] = STATE(3471),
    [sym_preproc_line] = STATE(3471),
    [sym_preproc_pragma] = STATE(3471),
    [sym_preproc_nullable] = STATE(3471),
    [sym_preproc_error] = STATE(3471),
    [sym_preproc_warning] = STATE(3471),
    [sym_preproc_define] = STATE(3471),
    [sym_preproc_undef] = STATE(3471),
    [sym__identifier_token] = ACTIONS(3689),
    [anon_sym_extern] = ACTIONS(3689),
    [anon_sym_alias] = ACTIONS(3689),
    [anon_sym_global] = ACTIONS(3689),
    [anon_sym_using] = ACTIONS(3689),
    [anon_sym_unsafe] = ACTIONS(3689),
    [anon_sym_static] = ACTIONS(3689),
    [anon_sym_LBRACK] = ACTIONS(3691),
    [anon_sym_LPAREN] = ACTIONS(3691),
    [anon_sym_event] = ACTIONS(3689),
    [anon_sym_namespace] = ACTIONS(3689),
    [anon_sym_class] = ACTIONS(3689),
    [anon_sym_ref] = ACTIONS(3689),
    [anon_sym_struct] = ACTIONS(3689),
    [anon_sym_enum] = ACTIONS(3689),
    [anon_sym_RBRACE] = ACTIONS(3691),
    [anon_sym_interface] = ACTIONS(3689),
    [anon_sym_delegate] = ACTIONS(3689),
    [anon_sym_record] = ACTIONS(3689),
    [anon_sym_abstract] = ACTIONS(3689),
    [anon_sym_async] = ACTIONS(3689),
    [anon_sym_const] = ACTIONS(3689),
    [anon_sym_file] = ACTIONS(3689),
    [anon_sym_fixed] = ACTIONS(3689),
    [anon_sym_internal] = ACTIONS(3689),
    [anon_sym_new] = ACTIONS(3689),
    [anon_sym_override] = ACTIONS(3689),
    [anon_sym_partial] = ACTIONS(3689),
    [anon_sym_private] = ACTIONS(3689),
    [anon_sym_protected] = ACTIONS(3689),
    [anon_sym_public] = ACTIONS(3689),
    [anon_sym_readonly] = ACTIONS(3689),
    [anon_sym_required] = ACTIONS(3689),
    [anon_sym_sealed] = ACTIONS(3689),
    [anon_sym_virtual] = ACTIONS(3689),
    [anon_sym_volatile] = ACTIONS(3689),
    [anon_sym_where] = ACTIONS(3689),
    [anon_sym_notnull] = ACTIONS(3689),
    [anon_sym_unmanaged] = ACTIONS(3689),
    [anon_sym_TILDE] = ACTIONS(3691),
    [anon_sym_implicit] = ACTIONS(3689),
    [anon_sym_explicit] = ACTIONS(3689),
    [anon_sym_scoped] = ACTIONS(3689),
    [anon_sym_var] = ACTIONS(3689),
    [sym_predefined_type] = ACTIONS(3689),
    [anon_sym_yield] = ACTIONS(3689),
    [anon_sym_when] = ACTIONS(3689),
    [anon_sym_from] = ACTIONS(3689),
    [anon_sym_into] = ACTIONS(3689),
    [anon_sym_join] = ACTIONS(3689),
    [anon_sym_on] = ACTIONS(3689),
    [anon_sym_equals] = ACTIONS(3689),
    [anon_sym_let] = ACTIONS(3689),
    [anon_sym_orderby] = ACTIONS(3689),
    [anon_sym_ascending] = ACTIONS(3689),
    [anon_sym_descending] = ACTIONS(3689),
    [anon_sym_group] = ACTIONS(3689),
    [anon_sym_by] = ACTIONS(3689),
    [anon_sym_select] = ACTIONS(3689),
    [aux_sym_preproc_if_token1] = ACTIONS(3691),
    [aux_sym_preproc_if_token3] = ACTIONS(3691),
    [aux_sym_preproc_else_token1] = ACTIONS(3691),
    [aux_sym_preproc_elif_token1] = ACTIONS(3691),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3472] = {
    [sym_preproc_region] = STATE(3472),
    [sym_preproc_endregion] = STATE(3472),
    [sym_preproc_line] = STATE(3472),
    [sym_preproc_pragma] = STATE(3472),
    [sym_preproc_nullable] = STATE(3472),
    [sym_preproc_error] = STATE(3472),
    [sym_preproc_warning] = STATE(3472),
    [sym_preproc_define] = STATE(3472),
    [sym_preproc_undef] = STATE(3472),
    [sym__identifier_token] = ACTIONS(3693),
    [anon_sym_extern] = ACTIONS(3693),
    [anon_sym_alias] = ACTIONS(3693),
    [anon_sym_global] = ACTIONS(3693),
    [anon_sym_using] = ACTIONS(3693),
    [anon_sym_unsafe] = ACTIONS(3693),
    [anon_sym_static] = ACTIONS(3693),
    [anon_sym_LBRACK] = ACTIONS(3695),
    [anon_sym_LPAREN] = ACTIONS(3695),
    [anon_sym_event] = ACTIONS(3693),
    [anon_sym_namespace] = ACTIONS(3693),
    [anon_sym_class] = ACTIONS(3693),
    [anon_sym_ref] = ACTIONS(3693),
    [anon_sym_struct] = ACTIONS(3693),
    [anon_sym_enum] = ACTIONS(3693),
    [anon_sym_RBRACE] = ACTIONS(3695),
    [anon_sym_interface] = ACTIONS(3693),
    [anon_sym_delegate] = ACTIONS(3693),
    [anon_sym_record] = ACTIONS(3693),
    [anon_sym_abstract] = ACTIONS(3693),
    [anon_sym_async] = ACTIONS(3693),
    [anon_sym_const] = ACTIONS(3693),
    [anon_sym_file] = ACTIONS(3693),
    [anon_sym_fixed] = ACTIONS(3693),
    [anon_sym_internal] = ACTIONS(3693),
    [anon_sym_new] = ACTIONS(3693),
    [anon_sym_override] = ACTIONS(3693),
    [anon_sym_partial] = ACTIONS(3693),
    [anon_sym_private] = ACTIONS(3693),
    [anon_sym_protected] = ACTIONS(3693),
    [anon_sym_public] = ACTIONS(3693),
    [anon_sym_readonly] = ACTIONS(3693),
    [anon_sym_required] = ACTIONS(3693),
    [anon_sym_sealed] = ACTIONS(3693),
    [anon_sym_virtual] = ACTIONS(3693),
    [anon_sym_volatile] = ACTIONS(3693),
    [anon_sym_where] = ACTIONS(3693),
    [anon_sym_notnull] = ACTIONS(3693),
    [anon_sym_unmanaged] = ACTIONS(3693),
    [anon_sym_TILDE] = ACTIONS(3695),
    [anon_sym_implicit] = ACTIONS(3693),
    [anon_sym_explicit] = ACTIONS(3693),
    [anon_sym_scoped] = ACTIONS(3693),
    [anon_sym_var] = ACTIONS(3693),
    [sym_predefined_type] = ACTIONS(3693),
    [anon_sym_yield] = ACTIONS(3693),
    [anon_sym_when] = ACTIONS(3693),
    [anon_sym_from] = ACTIONS(3693),
    [anon_sym_into] = ACTIONS(3693),
    [anon_sym_join] = ACTIONS(3693),
    [anon_sym_on] = ACTIONS(3693),
    [anon_sym_equals] = ACTIONS(3693),
    [anon_sym_let] = ACTIONS(3693),
    [anon_sym_orderby] = ACTIONS(3693),
    [anon_sym_ascending] = ACTIONS(3693),
    [anon_sym_descending] = ACTIONS(3693),
    [anon_sym_group] = ACTIONS(3693),
    [anon_sym_by] = ACTIONS(3693),
    [anon_sym_select] = ACTIONS(3693),
    [aux_sym_preproc_if_token1] = ACTIONS(3695),
    [aux_sym_preproc_if_token3] = ACTIONS(3695),
    [aux_sym_preproc_else_token1] = ACTIONS(3695),
    [aux_sym_preproc_elif_token1] = ACTIONS(3695),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3473] = {
    [sym_preproc_region] = STATE(3473),
    [sym_preproc_endregion] = STATE(3473),
    [sym_preproc_line] = STATE(3473),
    [sym_preproc_pragma] = STATE(3473),
    [sym_preproc_nullable] = STATE(3473),
    [sym_preproc_error] = STATE(3473),
    [sym_preproc_warning] = STATE(3473),
    [sym_preproc_define] = STATE(3473),
    [sym_preproc_undef] = STATE(3473),
    [sym__identifier_token] = ACTIONS(3697),
    [anon_sym_extern] = ACTIONS(3697),
    [anon_sym_alias] = ACTIONS(3697),
    [anon_sym_global] = ACTIONS(3697),
    [anon_sym_using] = ACTIONS(3697),
    [anon_sym_unsafe] = ACTIONS(3697),
    [anon_sym_static] = ACTIONS(3697),
    [anon_sym_LBRACK] = ACTIONS(3699),
    [anon_sym_LPAREN] = ACTIONS(3699),
    [anon_sym_event] = ACTIONS(3697),
    [anon_sym_namespace] = ACTIONS(3697),
    [anon_sym_class] = ACTIONS(3697),
    [anon_sym_ref] = ACTIONS(3697),
    [anon_sym_struct] = ACTIONS(3697),
    [anon_sym_enum] = ACTIONS(3697),
    [anon_sym_RBRACE] = ACTIONS(3699),
    [anon_sym_interface] = ACTIONS(3697),
    [anon_sym_delegate] = ACTIONS(3697),
    [anon_sym_record] = ACTIONS(3697),
    [anon_sym_abstract] = ACTIONS(3697),
    [anon_sym_async] = ACTIONS(3697),
    [anon_sym_const] = ACTIONS(3697),
    [anon_sym_file] = ACTIONS(3697),
    [anon_sym_fixed] = ACTIONS(3697),
    [anon_sym_internal] = ACTIONS(3697),
    [anon_sym_new] = ACTIONS(3697),
    [anon_sym_override] = ACTIONS(3697),
    [anon_sym_partial] = ACTIONS(3697),
    [anon_sym_private] = ACTIONS(3697),
    [anon_sym_protected] = ACTIONS(3697),
    [anon_sym_public] = ACTIONS(3697),
    [anon_sym_readonly] = ACTIONS(3697),
    [anon_sym_required] = ACTIONS(3697),
    [anon_sym_sealed] = ACTIONS(3697),
    [anon_sym_virtual] = ACTIONS(3697),
    [anon_sym_volatile] = ACTIONS(3697),
    [anon_sym_where] = ACTIONS(3697),
    [anon_sym_notnull] = ACTIONS(3697),
    [anon_sym_unmanaged] = ACTIONS(3697),
    [anon_sym_TILDE] = ACTIONS(3699),
    [anon_sym_implicit] = ACTIONS(3697),
    [anon_sym_explicit] = ACTIONS(3697),
    [anon_sym_scoped] = ACTIONS(3697),
    [anon_sym_var] = ACTIONS(3697),
    [sym_predefined_type] = ACTIONS(3697),
    [anon_sym_yield] = ACTIONS(3697),
    [anon_sym_when] = ACTIONS(3697),
    [anon_sym_from] = ACTIONS(3697),
    [anon_sym_into] = ACTIONS(3697),
    [anon_sym_join] = ACTIONS(3697),
    [anon_sym_on] = ACTIONS(3697),
    [anon_sym_equals] = ACTIONS(3697),
    [anon_sym_let] = ACTIONS(3697),
    [anon_sym_orderby] = ACTIONS(3697),
    [anon_sym_ascending] = ACTIONS(3697),
    [anon_sym_descending] = ACTIONS(3697),
    [anon_sym_group] = ACTIONS(3697),
    [anon_sym_by] = ACTIONS(3697),
    [anon_sym_select] = ACTIONS(3697),
    [aux_sym_preproc_if_token1] = ACTIONS(3699),
    [aux_sym_preproc_if_token3] = ACTIONS(3699),
    [aux_sym_preproc_else_token1] = ACTIONS(3699),
    [aux_sym_preproc_elif_token1] = ACTIONS(3699),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3474] = {
    [sym_preproc_region] = STATE(3474),
    [sym_preproc_endregion] = STATE(3474),
    [sym_preproc_line] = STATE(3474),
    [sym_preproc_pragma] = STATE(3474),
    [sym_preproc_nullable] = STATE(3474),
    [sym_preproc_error] = STATE(3474),
    [sym_preproc_warning] = STATE(3474),
    [sym_preproc_define] = STATE(3474),
    [sym_preproc_undef] = STATE(3474),
    [sym__identifier_token] = ACTIONS(3701),
    [anon_sym_extern] = ACTIONS(3701),
    [anon_sym_alias] = ACTIONS(3701),
    [anon_sym_global] = ACTIONS(3701),
    [anon_sym_using] = ACTIONS(3701),
    [anon_sym_unsafe] = ACTIONS(3701),
    [anon_sym_static] = ACTIONS(3701),
    [anon_sym_LBRACK] = ACTIONS(3703),
    [anon_sym_LPAREN] = ACTIONS(3703),
    [anon_sym_event] = ACTIONS(3701),
    [anon_sym_namespace] = ACTIONS(3701),
    [anon_sym_class] = ACTIONS(3701),
    [anon_sym_ref] = ACTIONS(3701),
    [anon_sym_struct] = ACTIONS(3701),
    [anon_sym_enum] = ACTIONS(3701),
    [anon_sym_RBRACE] = ACTIONS(3703),
    [anon_sym_interface] = ACTIONS(3701),
    [anon_sym_delegate] = ACTIONS(3701),
    [anon_sym_record] = ACTIONS(3701),
    [anon_sym_abstract] = ACTIONS(3701),
    [anon_sym_async] = ACTIONS(3701),
    [anon_sym_const] = ACTIONS(3701),
    [anon_sym_file] = ACTIONS(3701),
    [anon_sym_fixed] = ACTIONS(3701),
    [anon_sym_internal] = ACTIONS(3701),
    [anon_sym_new] = ACTIONS(3701),
    [anon_sym_override] = ACTIONS(3701),
    [anon_sym_partial] = ACTIONS(3701),
    [anon_sym_private] = ACTIONS(3701),
    [anon_sym_protected] = ACTIONS(3701),
    [anon_sym_public] = ACTIONS(3701),
    [anon_sym_readonly] = ACTIONS(3701),
    [anon_sym_required] = ACTIONS(3701),
    [anon_sym_sealed] = ACTIONS(3701),
    [anon_sym_virtual] = ACTIONS(3701),
    [anon_sym_volatile] = ACTIONS(3701),
    [anon_sym_where] = ACTIONS(3701),
    [anon_sym_notnull] = ACTIONS(3701),
    [anon_sym_unmanaged] = ACTIONS(3701),
    [anon_sym_TILDE] = ACTIONS(3703),
    [anon_sym_implicit] = ACTIONS(3701),
    [anon_sym_explicit] = ACTIONS(3701),
    [anon_sym_scoped] = ACTIONS(3701),
    [anon_sym_var] = ACTIONS(3701),
    [sym_predefined_type] = ACTIONS(3701),
    [anon_sym_yield] = ACTIONS(3701),
    [anon_sym_when] = ACTIONS(3701),
    [anon_sym_from] = ACTIONS(3701),
    [anon_sym_into] = ACTIONS(3701),
    [anon_sym_join] = ACTIONS(3701),
    [anon_sym_on] = ACTIONS(3701),
    [anon_sym_equals] = ACTIONS(3701),
    [anon_sym_let] = ACTIONS(3701),
    [anon_sym_orderby] = ACTIONS(3701),
    [anon_sym_ascending] = ACTIONS(3701),
    [anon_sym_descending] = ACTIONS(3701),
    [anon_sym_group] = ACTIONS(3701),
    [anon_sym_by] = ACTIONS(3701),
    [anon_sym_select] = ACTIONS(3701),
    [aux_sym_preproc_if_token1] = ACTIONS(3703),
    [aux_sym_preproc_if_token3] = ACTIONS(3703),
    [aux_sym_preproc_else_token1] = ACTIONS(3703),
    [aux_sym_preproc_elif_token1] = ACTIONS(3703),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3475] = {
    [sym_preproc_region] = STATE(3475),
    [sym_preproc_endregion] = STATE(3475),
    [sym_preproc_line] = STATE(3475),
    [sym_preproc_pragma] = STATE(3475),
    [sym_preproc_nullable] = STATE(3475),
    [sym_preproc_error] = STATE(3475),
    [sym_preproc_warning] = STATE(3475),
    [sym_preproc_define] = STATE(3475),
    [sym_preproc_undef] = STATE(3475),
    [sym__identifier_token] = ACTIONS(3705),
    [anon_sym_extern] = ACTIONS(3705),
    [anon_sym_alias] = ACTIONS(3705),
    [anon_sym_global] = ACTIONS(3705),
    [anon_sym_using] = ACTIONS(3705),
    [anon_sym_unsafe] = ACTIONS(3705),
    [anon_sym_static] = ACTIONS(3705),
    [anon_sym_LBRACK] = ACTIONS(3707),
    [anon_sym_LPAREN] = ACTIONS(3707),
    [anon_sym_event] = ACTIONS(3705),
    [anon_sym_namespace] = ACTIONS(3705),
    [anon_sym_class] = ACTIONS(3705),
    [anon_sym_ref] = ACTIONS(3705),
    [anon_sym_struct] = ACTIONS(3705),
    [anon_sym_enum] = ACTIONS(3705),
    [anon_sym_RBRACE] = ACTIONS(3707),
    [anon_sym_interface] = ACTIONS(3705),
    [anon_sym_delegate] = ACTIONS(3705),
    [anon_sym_record] = ACTIONS(3705),
    [anon_sym_abstract] = ACTIONS(3705),
    [anon_sym_async] = ACTIONS(3705),
    [anon_sym_const] = ACTIONS(3705),
    [anon_sym_file] = ACTIONS(3705),
    [anon_sym_fixed] = ACTIONS(3705),
    [anon_sym_internal] = ACTIONS(3705),
    [anon_sym_new] = ACTIONS(3705),
    [anon_sym_override] = ACTIONS(3705),
    [anon_sym_partial] = ACTIONS(3705),
    [anon_sym_private] = ACTIONS(3705),
    [anon_sym_protected] = ACTIONS(3705),
    [anon_sym_public] = ACTIONS(3705),
    [anon_sym_readonly] = ACTIONS(3705),
    [anon_sym_required] = ACTIONS(3705),
    [anon_sym_sealed] = ACTIONS(3705),
    [anon_sym_virtual] = ACTIONS(3705),
    [anon_sym_volatile] = ACTIONS(3705),
    [anon_sym_where] = ACTIONS(3705),
    [anon_sym_notnull] = ACTIONS(3705),
    [anon_sym_unmanaged] = ACTIONS(3705),
    [anon_sym_TILDE] = ACTIONS(3707),
    [anon_sym_implicit] = ACTIONS(3705),
    [anon_sym_explicit] = ACTIONS(3705),
    [anon_sym_scoped] = ACTIONS(3705),
    [anon_sym_var] = ACTIONS(3705),
    [sym_predefined_type] = ACTIONS(3705),
    [anon_sym_yield] = ACTIONS(3705),
    [anon_sym_when] = ACTIONS(3705),
    [anon_sym_from] = ACTIONS(3705),
    [anon_sym_into] = ACTIONS(3705),
    [anon_sym_join] = ACTIONS(3705),
    [anon_sym_on] = ACTIONS(3705),
    [anon_sym_equals] = ACTIONS(3705),
    [anon_sym_let] = ACTIONS(3705),
    [anon_sym_orderby] = ACTIONS(3705),
    [anon_sym_ascending] = ACTIONS(3705),
    [anon_sym_descending] = ACTIONS(3705),
    [anon_sym_group] = ACTIONS(3705),
    [anon_sym_by] = ACTIONS(3705),
    [anon_sym_select] = ACTIONS(3705),
    [aux_sym_preproc_if_token1] = ACTIONS(3707),
    [aux_sym_preproc_if_token3] = ACTIONS(3707),
    [aux_sym_preproc_else_token1] = ACTIONS(3707),
    [aux_sym_preproc_elif_token1] = ACTIONS(3707),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3476] = {
    [sym_preproc_region] = STATE(3476),
    [sym_preproc_endregion] = STATE(3476),
    [sym_preproc_line] = STATE(3476),
    [sym_preproc_pragma] = STATE(3476),
    [sym_preproc_nullable] = STATE(3476),
    [sym_preproc_error] = STATE(3476),
    [sym_preproc_warning] = STATE(3476),
    [sym_preproc_define] = STATE(3476),
    [sym_preproc_undef] = STATE(3476),
    [sym__identifier_token] = ACTIONS(4492),
    [anon_sym_alias] = ACTIONS(4492),
    [anon_sym_global] = ACTIONS(4492),
    [anon_sym_LBRACK] = ACTIONS(4593),
    [anon_sym_COLON] = ACTIONS(4494),
    [anon_sym_COMMA] = ACTIONS(4494),
    [anon_sym_LPAREN] = ACTIONS(4494),
    [anon_sym_LBRACE] = ACTIONS(4494),
    [anon_sym_file] = ACTIONS(4492),
    [anon_sym_LT] = ACTIONS(4492),
    [anon_sym_GT] = ACTIONS(4492),
    [anon_sym_where] = ACTIONS(4492),
    [anon_sym_QMARK] = ACTIONS(4970),
    [anon_sym_notnull] = ACTIONS(4492),
    [anon_sym_unmanaged] = ACTIONS(4492),
    [anon_sym_BANG] = ACTIONS(4492),
    [anon_sym_PLUS_PLUS] = ACTIONS(4494),
    [anon_sym_DASH_DASH] = ACTIONS(4494),
    [anon_sym_PLUS] = ACTIONS(4492),
    [anon_sym_DASH] = ACTIONS(4492),
    [anon_sym_STAR] = ACTIONS(4599),
    [anon_sym_SLASH] = ACTIONS(4492),
    [anon_sym_PERCENT] = ACTIONS(4494),
    [anon_sym_CARET] = ACTIONS(4494),
    [anon_sym_PIPE] = ACTIONS(4492),
    [anon_sym_AMP] = ACTIONS(4492),
    [anon_sym_LT_LT] = ACTIONS(4494),
    [anon_sym_GT_GT] = ACTIONS(4492),
    [anon_sym_GT_GT_GT] = ACTIONS(4494),
    [anon_sym_EQ_EQ] = ACTIONS(4494),
    [anon_sym_BANG_EQ] = ACTIONS(4494),
    [anon_sym_GT_EQ] = ACTIONS(4494),
    [anon_sym_LT_EQ] = ACTIONS(4494),
    [anon_sym_DOT] = ACTIONS(4602),
    [anon_sym_scoped] = ACTIONS(4492),
    [anon_sym_var] = ACTIONS(4492),
    [anon_sym_yield] = ACTIONS(4492),
    [anon_sym_switch] = ACTIONS(4492),
    [anon_sym_when] = ACTIONS(4492),
    [sym_discard] = ACTIONS(4492),
    [anon_sym_DOT_DOT] = ACTIONS(4494),
    [anon_sym_and] = ACTIONS(4492),
    [anon_sym_or] = ACTIONS(4492),
    [anon_sym_AMP_AMP] = ACTIONS(4494),
    [anon_sym_PIPE_PIPE] = ACTIONS(4494),
    [anon_sym_QMARK_QMARK] = ACTIONS(4494),
    [anon_sym_from] = ACTIONS(4492),
    [anon_sym_into] = ACTIONS(4492),
    [anon_sym_join] = ACTIONS(4492),
    [anon_sym_on] = ACTIONS(4492),
    [anon_sym_equals] = ACTIONS(4492),
    [anon_sym_let] = ACTIONS(4492),
    [anon_sym_orderby] = ACTIONS(4492),
    [anon_sym_ascending] = ACTIONS(4492),
    [anon_sym_descending] = ACTIONS(4492),
    [anon_sym_group] = ACTIONS(4492),
    [anon_sym_by] = ACTIONS(4492),
    [anon_sym_select] = ACTIONS(4492),
    [anon_sym_as] = ACTIONS(4492),
    [anon_sym_is] = ACTIONS(4492),
    [anon_sym_DASH_GT] = ACTIONS(4604),
    [anon_sym_with] = ACTIONS(4492),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4494),
  },
  [3477] = {
    [sym_preproc_region] = STATE(3477),
    [sym_preproc_endregion] = STATE(3477),
    [sym_preproc_line] = STATE(3477),
    [sym_preproc_pragma] = STATE(3477),
    [sym_preproc_nullable] = STATE(3477),
    [sym_preproc_error] = STATE(3477),
    [sym_preproc_warning] = STATE(3477),
    [sym_preproc_define] = STATE(3477),
    [sym_preproc_undef] = STATE(3477),
    [sym__identifier_token] = ACTIONS(3709),
    [anon_sym_extern] = ACTIONS(3709),
    [anon_sym_alias] = ACTIONS(3709),
    [anon_sym_global] = ACTIONS(3709),
    [anon_sym_using] = ACTIONS(3709),
    [anon_sym_unsafe] = ACTIONS(3709),
    [anon_sym_static] = ACTIONS(3709),
    [anon_sym_LBRACK] = ACTIONS(3711),
    [anon_sym_LPAREN] = ACTIONS(3711),
    [anon_sym_event] = ACTIONS(3709),
    [anon_sym_namespace] = ACTIONS(3709),
    [anon_sym_class] = ACTIONS(3709),
    [anon_sym_ref] = ACTIONS(3709),
    [anon_sym_struct] = ACTIONS(3709),
    [anon_sym_enum] = ACTIONS(3709),
    [anon_sym_RBRACE] = ACTIONS(3711),
    [anon_sym_interface] = ACTIONS(3709),
    [anon_sym_delegate] = ACTIONS(3709),
    [anon_sym_record] = ACTIONS(3709),
    [anon_sym_abstract] = ACTIONS(3709),
    [anon_sym_async] = ACTIONS(3709),
    [anon_sym_const] = ACTIONS(3709),
    [anon_sym_file] = ACTIONS(3709),
    [anon_sym_fixed] = ACTIONS(3709),
    [anon_sym_internal] = ACTIONS(3709),
    [anon_sym_new] = ACTIONS(3709),
    [anon_sym_override] = ACTIONS(3709),
    [anon_sym_partial] = ACTIONS(3709),
    [anon_sym_private] = ACTIONS(3709),
    [anon_sym_protected] = ACTIONS(3709),
    [anon_sym_public] = ACTIONS(3709),
    [anon_sym_readonly] = ACTIONS(3709),
    [anon_sym_required] = ACTIONS(3709),
    [anon_sym_sealed] = ACTIONS(3709),
    [anon_sym_virtual] = ACTIONS(3709),
    [anon_sym_volatile] = ACTIONS(3709),
    [anon_sym_where] = ACTIONS(3709),
    [anon_sym_notnull] = ACTIONS(3709),
    [anon_sym_unmanaged] = ACTIONS(3709),
    [anon_sym_TILDE] = ACTIONS(3711),
    [anon_sym_implicit] = ACTIONS(3709),
    [anon_sym_explicit] = ACTIONS(3709),
    [anon_sym_scoped] = ACTIONS(3709),
    [anon_sym_var] = ACTIONS(3709),
    [sym_predefined_type] = ACTIONS(3709),
    [anon_sym_yield] = ACTIONS(3709),
    [anon_sym_when] = ACTIONS(3709),
    [anon_sym_from] = ACTIONS(3709),
    [anon_sym_into] = ACTIONS(3709),
    [anon_sym_join] = ACTIONS(3709),
    [anon_sym_on] = ACTIONS(3709),
    [anon_sym_equals] = ACTIONS(3709),
    [anon_sym_let] = ACTIONS(3709),
    [anon_sym_orderby] = ACTIONS(3709),
    [anon_sym_ascending] = ACTIONS(3709),
    [anon_sym_descending] = ACTIONS(3709),
    [anon_sym_group] = ACTIONS(3709),
    [anon_sym_by] = ACTIONS(3709),
    [anon_sym_select] = ACTIONS(3709),
    [aux_sym_preproc_if_token1] = ACTIONS(3711),
    [aux_sym_preproc_if_token3] = ACTIONS(3711),
    [aux_sym_preproc_else_token1] = ACTIONS(3711),
    [aux_sym_preproc_elif_token1] = ACTIONS(3711),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3478] = {
    [sym_preproc_region] = STATE(3478),
    [sym_preproc_endregion] = STATE(3478),
    [sym_preproc_line] = STATE(3478),
    [sym_preproc_pragma] = STATE(3478),
    [sym_preproc_nullable] = STATE(3478),
    [sym_preproc_error] = STATE(3478),
    [sym_preproc_warning] = STATE(3478),
    [sym_preproc_define] = STATE(3478),
    [sym_preproc_undef] = STATE(3478),
    [sym__identifier_token] = ACTIONS(3513),
    [anon_sym_extern] = ACTIONS(3513),
    [anon_sym_alias] = ACTIONS(3513),
    [anon_sym_global] = ACTIONS(3513),
    [anon_sym_using] = ACTIONS(3513),
    [anon_sym_unsafe] = ACTIONS(3513),
    [anon_sym_static] = ACTIONS(3513),
    [anon_sym_LBRACK] = ACTIONS(3515),
    [anon_sym_LPAREN] = ACTIONS(3515),
    [anon_sym_event] = ACTIONS(3513),
    [anon_sym_namespace] = ACTIONS(3513),
    [anon_sym_class] = ACTIONS(3513),
    [anon_sym_ref] = ACTIONS(3513),
    [anon_sym_struct] = ACTIONS(3513),
    [anon_sym_enum] = ACTIONS(3513),
    [anon_sym_RBRACE] = ACTIONS(3515),
    [anon_sym_interface] = ACTIONS(3513),
    [anon_sym_delegate] = ACTIONS(3513),
    [anon_sym_record] = ACTIONS(3513),
    [anon_sym_abstract] = ACTIONS(3513),
    [anon_sym_async] = ACTIONS(3513),
    [anon_sym_const] = ACTIONS(3513),
    [anon_sym_file] = ACTIONS(3513),
    [anon_sym_fixed] = ACTIONS(3513),
    [anon_sym_internal] = ACTIONS(3513),
    [anon_sym_new] = ACTIONS(3513),
    [anon_sym_override] = ACTIONS(3513),
    [anon_sym_partial] = ACTIONS(3513),
    [anon_sym_private] = ACTIONS(3513),
    [anon_sym_protected] = ACTIONS(3513),
    [anon_sym_public] = ACTIONS(3513),
    [anon_sym_readonly] = ACTIONS(3513),
    [anon_sym_required] = ACTIONS(3513),
    [anon_sym_sealed] = ACTIONS(3513),
    [anon_sym_virtual] = ACTIONS(3513),
    [anon_sym_volatile] = ACTIONS(3513),
    [anon_sym_where] = ACTIONS(3513),
    [anon_sym_notnull] = ACTIONS(3513),
    [anon_sym_unmanaged] = ACTIONS(3513),
    [anon_sym_TILDE] = ACTIONS(3515),
    [anon_sym_implicit] = ACTIONS(3513),
    [anon_sym_explicit] = ACTIONS(3513),
    [anon_sym_scoped] = ACTIONS(3513),
    [anon_sym_var] = ACTIONS(3513),
    [sym_predefined_type] = ACTIONS(3513),
    [anon_sym_yield] = ACTIONS(3513),
    [anon_sym_when] = ACTIONS(3513),
    [anon_sym_from] = ACTIONS(3513),
    [anon_sym_into] = ACTIONS(3513),
    [anon_sym_join] = ACTIONS(3513),
    [anon_sym_on] = ACTIONS(3513),
    [anon_sym_equals] = ACTIONS(3513),
    [anon_sym_let] = ACTIONS(3513),
    [anon_sym_orderby] = ACTIONS(3513),
    [anon_sym_ascending] = ACTIONS(3513),
    [anon_sym_descending] = ACTIONS(3513),
    [anon_sym_group] = ACTIONS(3513),
    [anon_sym_by] = ACTIONS(3513),
    [anon_sym_select] = ACTIONS(3513),
    [aux_sym_preproc_if_token1] = ACTIONS(3515),
    [aux_sym_preproc_if_token3] = ACTIONS(3515),
    [aux_sym_preproc_else_token1] = ACTIONS(3515),
    [aux_sym_preproc_elif_token1] = ACTIONS(3515),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3479] = {
    [sym_preproc_region] = STATE(3479),
    [sym_preproc_endregion] = STATE(3479),
    [sym_preproc_line] = STATE(3479),
    [sym_preproc_pragma] = STATE(3479),
    [sym_preproc_nullable] = STATE(3479),
    [sym_preproc_error] = STATE(3479),
    [sym_preproc_warning] = STATE(3479),
    [sym_preproc_define] = STATE(3479),
    [sym_preproc_undef] = STATE(3479),
    [sym__identifier_token] = ACTIONS(3517),
    [anon_sym_extern] = ACTIONS(3517),
    [anon_sym_alias] = ACTIONS(3517),
    [anon_sym_global] = ACTIONS(3517),
    [anon_sym_using] = ACTIONS(3517),
    [anon_sym_unsafe] = ACTIONS(3517),
    [anon_sym_static] = ACTIONS(3517),
    [anon_sym_LBRACK] = ACTIONS(3519),
    [anon_sym_LPAREN] = ACTIONS(3519),
    [anon_sym_event] = ACTIONS(3517),
    [anon_sym_namespace] = ACTIONS(3517),
    [anon_sym_class] = ACTIONS(3517),
    [anon_sym_ref] = ACTIONS(3517),
    [anon_sym_struct] = ACTIONS(3517),
    [anon_sym_enum] = ACTIONS(3517),
    [anon_sym_RBRACE] = ACTIONS(3519),
    [anon_sym_interface] = ACTIONS(3517),
    [anon_sym_delegate] = ACTIONS(3517),
    [anon_sym_record] = ACTIONS(3517),
    [anon_sym_abstract] = ACTIONS(3517),
    [anon_sym_async] = ACTIONS(3517),
    [anon_sym_const] = ACTIONS(3517),
    [anon_sym_file] = ACTIONS(3517),
    [anon_sym_fixed] = ACTIONS(3517),
    [anon_sym_internal] = ACTIONS(3517),
    [anon_sym_new] = ACTIONS(3517),
    [anon_sym_override] = ACTIONS(3517),
    [anon_sym_partial] = ACTIONS(3517),
    [anon_sym_private] = ACTIONS(3517),
    [anon_sym_protected] = ACTIONS(3517),
    [anon_sym_public] = ACTIONS(3517),
    [anon_sym_readonly] = ACTIONS(3517),
    [anon_sym_required] = ACTIONS(3517),
    [anon_sym_sealed] = ACTIONS(3517),
    [anon_sym_virtual] = ACTIONS(3517),
    [anon_sym_volatile] = ACTIONS(3517),
    [anon_sym_where] = ACTIONS(3517),
    [anon_sym_notnull] = ACTIONS(3517),
    [anon_sym_unmanaged] = ACTIONS(3517),
    [anon_sym_TILDE] = ACTIONS(3519),
    [anon_sym_implicit] = ACTIONS(3517),
    [anon_sym_explicit] = ACTIONS(3517),
    [anon_sym_scoped] = ACTIONS(3517),
    [anon_sym_var] = ACTIONS(3517),
    [sym_predefined_type] = ACTIONS(3517),
    [anon_sym_yield] = ACTIONS(3517),
    [anon_sym_when] = ACTIONS(3517),
    [anon_sym_from] = ACTIONS(3517),
    [anon_sym_into] = ACTIONS(3517),
    [anon_sym_join] = ACTIONS(3517),
    [anon_sym_on] = ACTIONS(3517),
    [anon_sym_equals] = ACTIONS(3517),
    [anon_sym_let] = ACTIONS(3517),
    [anon_sym_orderby] = ACTIONS(3517),
    [anon_sym_ascending] = ACTIONS(3517),
    [anon_sym_descending] = ACTIONS(3517),
    [anon_sym_group] = ACTIONS(3517),
    [anon_sym_by] = ACTIONS(3517),
    [anon_sym_select] = ACTIONS(3517),
    [aux_sym_preproc_if_token1] = ACTIONS(3519),
    [aux_sym_preproc_if_token3] = ACTIONS(3519),
    [aux_sym_preproc_else_token1] = ACTIONS(3519),
    [aux_sym_preproc_elif_token1] = ACTIONS(3519),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3480] = {
    [sym_preproc_region] = STATE(3480),
    [sym_preproc_endregion] = STATE(3480),
    [sym_preproc_line] = STATE(3480),
    [sym_preproc_pragma] = STATE(3480),
    [sym_preproc_nullable] = STATE(3480),
    [sym_preproc_error] = STATE(3480),
    [sym_preproc_warning] = STATE(3480),
    [sym_preproc_define] = STATE(3480),
    [sym_preproc_undef] = STATE(3480),
    [anon_sym_SEMI] = ACTIONS(4177),
    [anon_sym_EQ] = ACTIONS(4162),
    [anon_sym_LBRACK] = ACTIONS(4177),
    [anon_sym_COLON] = ACTIONS(4177),
    [anon_sym_COMMA] = ACTIONS(4177),
    [anon_sym_RBRACK] = ACTIONS(4177),
    [anon_sym_LPAREN] = ACTIONS(4177),
    [anon_sym_RPAREN] = ACTIONS(4177),
    [anon_sym_RBRACE] = ACTIONS(4177),
    [anon_sym_LT] = ACTIONS(4162),
    [anon_sym_GT] = ACTIONS(4162),
    [anon_sym_in] = ACTIONS(4177),
    [anon_sym_QMARK] = ACTIONS(4162),
    [anon_sym_BANG] = ACTIONS(4162),
    [anon_sym_PLUS_PLUS] = ACTIONS(4177),
    [anon_sym_DASH_DASH] = ACTIONS(4177),
    [anon_sym_PLUS] = ACTIONS(4162),
    [anon_sym_DASH] = ACTIONS(4162),
    [anon_sym_STAR] = ACTIONS(4162),
    [anon_sym_SLASH] = ACTIONS(4162),
    [anon_sym_PERCENT] = ACTIONS(4162),
    [anon_sym_CARET] = ACTIONS(4162),
    [anon_sym_PIPE] = ACTIONS(4162),
    [anon_sym_AMP] = ACTIONS(4162),
    [anon_sym_LT_LT] = ACTIONS(4162),
    [anon_sym_GT_GT] = ACTIONS(4162),
    [anon_sym_GT_GT_GT] = ACTIONS(4162),
    [anon_sym_EQ_EQ] = ACTIONS(4177),
    [anon_sym_BANG_EQ] = ACTIONS(4177),
    [anon_sym_GT_EQ] = ACTIONS(4177),
    [anon_sym_LT_EQ] = ACTIONS(4177),
    [anon_sym_DOT] = ACTIONS(4162),
    [anon_sym_EQ_GT] = ACTIONS(4177),
    [anon_sym_switch] = ACTIONS(4177),
    [anon_sym_when] = ACTIONS(4177),
    [anon_sym_DOT_DOT] = ACTIONS(4177),
    [anon_sym_and] = ACTIONS(4177),
    [anon_sym_or] = ACTIONS(4177),
    [anon_sym_PLUS_EQ] = ACTIONS(4177),
    [anon_sym_DASH_EQ] = ACTIONS(4177),
    [anon_sym_STAR_EQ] = ACTIONS(4177),
    [anon_sym_SLASH_EQ] = ACTIONS(4177),
    [anon_sym_PERCENT_EQ] = ACTIONS(4177),
    [anon_sym_AMP_EQ] = ACTIONS(4177),
    [anon_sym_CARET_EQ] = ACTIONS(4177),
    [anon_sym_PIPE_EQ] = ACTIONS(4177),
    [anon_sym_LT_LT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4177),
    [anon_sym_AMP_AMP] = ACTIONS(4177),
    [anon_sym_PIPE_PIPE] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK] = ACTIONS(4162),
    [anon_sym_on] = ACTIONS(4177),
    [anon_sym_equals] = ACTIONS(4177),
    [anon_sym_by] = ACTIONS(4177),
    [anon_sym_as] = ACTIONS(4177),
    [anon_sym_is] = ACTIONS(4177),
    [anon_sym_DASH_GT] = ACTIONS(4177),
    [anon_sym_with] = ACTIONS(4177),
    [aux_sym_preproc_if_token3] = ACTIONS(4177),
    [aux_sym_preproc_else_token1] = ACTIONS(4177),
    [aux_sym_preproc_elif_token1] = ACTIONS(4177),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3481] = {
    [sym_preproc_region] = STATE(3481),
    [sym_preproc_endregion] = STATE(3481),
    [sym_preproc_line] = STATE(3481),
    [sym_preproc_pragma] = STATE(3481),
    [sym_preproc_nullable] = STATE(3481),
    [sym_preproc_error] = STATE(3481),
    [sym_preproc_warning] = STATE(3481),
    [sym_preproc_define] = STATE(3481),
    [sym_preproc_undef] = STATE(3481),
    [sym__identifier_token] = ACTIONS(3521),
    [anon_sym_extern] = ACTIONS(3521),
    [anon_sym_alias] = ACTIONS(3521),
    [anon_sym_global] = ACTIONS(3521),
    [anon_sym_using] = ACTIONS(3521),
    [anon_sym_unsafe] = ACTIONS(3521),
    [anon_sym_static] = ACTIONS(3521),
    [anon_sym_LBRACK] = ACTIONS(3523),
    [anon_sym_LPAREN] = ACTIONS(3523),
    [anon_sym_event] = ACTIONS(3521),
    [anon_sym_namespace] = ACTIONS(3521),
    [anon_sym_class] = ACTIONS(3521),
    [anon_sym_ref] = ACTIONS(3521),
    [anon_sym_struct] = ACTIONS(3521),
    [anon_sym_enum] = ACTIONS(3521),
    [anon_sym_RBRACE] = ACTIONS(3523),
    [anon_sym_interface] = ACTIONS(3521),
    [anon_sym_delegate] = ACTIONS(3521),
    [anon_sym_record] = ACTIONS(3521),
    [anon_sym_abstract] = ACTIONS(3521),
    [anon_sym_async] = ACTIONS(3521),
    [anon_sym_const] = ACTIONS(3521),
    [anon_sym_file] = ACTIONS(3521),
    [anon_sym_fixed] = ACTIONS(3521),
    [anon_sym_internal] = ACTIONS(3521),
    [anon_sym_new] = ACTIONS(3521),
    [anon_sym_override] = ACTIONS(3521),
    [anon_sym_partial] = ACTIONS(3521),
    [anon_sym_private] = ACTIONS(3521),
    [anon_sym_protected] = ACTIONS(3521),
    [anon_sym_public] = ACTIONS(3521),
    [anon_sym_readonly] = ACTIONS(3521),
    [anon_sym_required] = ACTIONS(3521),
    [anon_sym_sealed] = ACTIONS(3521),
    [anon_sym_virtual] = ACTIONS(3521),
    [anon_sym_volatile] = ACTIONS(3521),
    [anon_sym_where] = ACTIONS(3521),
    [anon_sym_notnull] = ACTIONS(3521),
    [anon_sym_unmanaged] = ACTIONS(3521),
    [anon_sym_TILDE] = ACTIONS(3523),
    [anon_sym_implicit] = ACTIONS(3521),
    [anon_sym_explicit] = ACTIONS(3521),
    [anon_sym_scoped] = ACTIONS(3521),
    [anon_sym_var] = ACTIONS(3521),
    [sym_predefined_type] = ACTIONS(3521),
    [anon_sym_yield] = ACTIONS(3521),
    [anon_sym_when] = ACTIONS(3521),
    [anon_sym_from] = ACTIONS(3521),
    [anon_sym_into] = ACTIONS(3521),
    [anon_sym_join] = ACTIONS(3521),
    [anon_sym_on] = ACTIONS(3521),
    [anon_sym_equals] = ACTIONS(3521),
    [anon_sym_let] = ACTIONS(3521),
    [anon_sym_orderby] = ACTIONS(3521),
    [anon_sym_ascending] = ACTIONS(3521),
    [anon_sym_descending] = ACTIONS(3521),
    [anon_sym_group] = ACTIONS(3521),
    [anon_sym_by] = ACTIONS(3521),
    [anon_sym_select] = ACTIONS(3521),
    [aux_sym_preproc_if_token1] = ACTIONS(3523),
    [aux_sym_preproc_if_token3] = ACTIONS(3523),
    [aux_sym_preproc_else_token1] = ACTIONS(3523),
    [aux_sym_preproc_elif_token1] = ACTIONS(3523),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3482] = {
    [sym_preproc_region] = STATE(3482),
    [sym_preproc_endregion] = STATE(3482),
    [sym_preproc_line] = STATE(3482),
    [sym_preproc_pragma] = STATE(3482),
    [sym_preproc_nullable] = STATE(3482),
    [sym_preproc_error] = STATE(3482),
    [sym_preproc_warning] = STATE(3482),
    [sym_preproc_define] = STATE(3482),
    [sym_preproc_undef] = STATE(3482),
    [anon_sym_SEMI] = ACTIONS(4806),
    [anon_sym_EQ] = ACTIONS(4162),
    [anon_sym_LBRACK] = ACTIONS(4808),
    [anon_sym_COLON] = ACTIONS(4806),
    [anon_sym_COMMA] = ACTIONS(4806),
    [anon_sym_RBRACK] = ACTIONS(4806),
    [anon_sym_LPAREN] = ACTIONS(4808),
    [anon_sym_RPAREN] = ACTIONS(4806),
    [anon_sym_RBRACE] = ACTIONS(4806),
    [anon_sym_LT] = ACTIONS(4811),
    [anon_sym_GT] = ACTIONS(4811),
    [anon_sym_in] = ACTIONS(4806),
    [anon_sym_QMARK] = ACTIONS(4811),
    [anon_sym_BANG] = ACTIONS(4811),
    [anon_sym_PLUS_PLUS] = ACTIONS(4808),
    [anon_sym_DASH_DASH] = ACTIONS(4808),
    [anon_sym_PLUS] = ACTIONS(4811),
    [anon_sym_DASH] = ACTIONS(4811),
    [anon_sym_STAR] = ACTIONS(4811),
    [anon_sym_SLASH] = ACTIONS(4811),
    [anon_sym_PERCENT] = ACTIONS(4811),
    [anon_sym_CARET] = ACTIONS(4811),
    [anon_sym_PIPE] = ACTIONS(4811),
    [anon_sym_AMP] = ACTIONS(4811),
    [anon_sym_LT_LT] = ACTIONS(4811),
    [anon_sym_GT_GT] = ACTIONS(4811),
    [anon_sym_GT_GT_GT] = ACTIONS(4811),
    [anon_sym_EQ_EQ] = ACTIONS(4808),
    [anon_sym_BANG_EQ] = ACTIONS(4808),
    [anon_sym_GT_EQ] = ACTIONS(4808),
    [anon_sym_LT_EQ] = ACTIONS(4808),
    [anon_sym_DOT] = ACTIONS(4811),
    [anon_sym_EQ_GT] = ACTIONS(4806),
    [anon_sym_switch] = ACTIONS(4808),
    [anon_sym_when] = ACTIONS(4806),
    [anon_sym_DOT_DOT] = ACTIONS(4808),
    [anon_sym_and] = ACTIONS(4806),
    [anon_sym_or] = ACTIONS(4806),
    [anon_sym_PLUS_EQ] = ACTIONS(4177),
    [anon_sym_DASH_EQ] = ACTIONS(4177),
    [anon_sym_STAR_EQ] = ACTIONS(4177),
    [anon_sym_SLASH_EQ] = ACTIONS(4177),
    [anon_sym_PERCENT_EQ] = ACTIONS(4177),
    [anon_sym_AMP_EQ] = ACTIONS(4177),
    [anon_sym_CARET_EQ] = ACTIONS(4177),
    [anon_sym_PIPE_EQ] = ACTIONS(4177),
    [anon_sym_LT_LT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4177),
    [anon_sym_AMP_AMP] = ACTIONS(4808),
    [anon_sym_PIPE_PIPE] = ACTIONS(4808),
    [anon_sym_QMARK_QMARK] = ACTIONS(4811),
    [anon_sym_on] = ACTIONS(4806),
    [anon_sym_equals] = ACTIONS(4806),
    [anon_sym_by] = ACTIONS(4806),
    [anon_sym_as] = ACTIONS(4808),
    [anon_sym_is] = ACTIONS(4808),
    [anon_sym_DASH_GT] = ACTIONS(4808),
    [anon_sym_with] = ACTIONS(4808),
    [aux_sym_preproc_if_token3] = ACTIONS(4806),
    [aux_sym_preproc_else_token1] = ACTIONS(4806),
    [aux_sym_preproc_elif_token1] = ACTIONS(4806),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3483] = {
    [sym_preproc_region] = STATE(3483),
    [sym_preproc_endregion] = STATE(3483),
    [sym_preproc_line] = STATE(3483),
    [sym_preproc_pragma] = STATE(3483),
    [sym_preproc_nullable] = STATE(3483),
    [sym_preproc_error] = STATE(3483),
    [sym_preproc_warning] = STATE(3483),
    [sym_preproc_define] = STATE(3483),
    [sym_preproc_undef] = STATE(3483),
    [sym__identifier_token] = ACTIONS(4492),
    [anon_sym_alias] = ACTIONS(4492),
    [anon_sym_global] = ACTIONS(4492),
    [anon_sym_LBRACK] = ACTIONS(4593),
    [anon_sym_COLON] = ACTIONS(4494),
    [anon_sym_COMMA] = ACTIONS(4494),
    [anon_sym_LPAREN] = ACTIONS(4494),
    [anon_sym_LBRACE] = ACTIONS(4494),
    [anon_sym_file] = ACTIONS(4492),
    [anon_sym_LT] = ACTIONS(4492),
    [anon_sym_GT] = ACTIONS(4492),
    [anon_sym_where] = ACTIONS(4492),
    [anon_sym_QMARK] = ACTIONS(4970),
    [anon_sym_notnull] = ACTIONS(4492),
    [anon_sym_unmanaged] = ACTIONS(4492),
    [anon_sym_BANG] = ACTIONS(4492),
    [anon_sym_PLUS_PLUS] = ACTIONS(4494),
    [anon_sym_DASH_DASH] = ACTIONS(4494),
    [anon_sym_PLUS] = ACTIONS(4492),
    [anon_sym_DASH] = ACTIONS(4492),
    [anon_sym_STAR] = ACTIONS(4599),
    [anon_sym_SLASH] = ACTIONS(4492),
    [anon_sym_PERCENT] = ACTIONS(4494),
    [anon_sym_CARET] = ACTIONS(4494),
    [anon_sym_PIPE] = ACTIONS(4492),
    [anon_sym_AMP] = ACTIONS(4492),
    [anon_sym_LT_LT] = ACTIONS(4494),
    [anon_sym_GT_GT] = ACTIONS(4492),
    [anon_sym_GT_GT_GT] = ACTIONS(4494),
    [anon_sym_EQ_EQ] = ACTIONS(4494),
    [anon_sym_BANG_EQ] = ACTIONS(4494),
    [anon_sym_GT_EQ] = ACTIONS(4494),
    [anon_sym_LT_EQ] = ACTIONS(4494),
    [anon_sym_DOT] = ACTIONS(5217),
    [anon_sym_scoped] = ACTIONS(4492),
    [anon_sym_var] = ACTIONS(4492),
    [anon_sym_yield] = ACTIONS(4492),
    [anon_sym_switch] = ACTIONS(4492),
    [anon_sym_when] = ACTIONS(4492),
    [sym_discard] = ACTIONS(4492),
    [anon_sym_DOT_DOT] = ACTIONS(4494),
    [anon_sym_and] = ACTIONS(4492),
    [anon_sym_or] = ACTIONS(4492),
    [anon_sym_AMP_AMP] = ACTIONS(4494),
    [anon_sym_PIPE_PIPE] = ACTIONS(4494),
    [anon_sym_QMARK_QMARK] = ACTIONS(4494),
    [anon_sym_from] = ACTIONS(4492),
    [anon_sym_into] = ACTIONS(4492),
    [anon_sym_join] = ACTIONS(4492),
    [anon_sym_on] = ACTIONS(4492),
    [anon_sym_equals] = ACTIONS(4492),
    [anon_sym_let] = ACTIONS(4492),
    [anon_sym_orderby] = ACTIONS(4492),
    [anon_sym_ascending] = ACTIONS(4492),
    [anon_sym_descending] = ACTIONS(4492),
    [anon_sym_group] = ACTIONS(4492),
    [anon_sym_by] = ACTIONS(4492),
    [anon_sym_select] = ACTIONS(4492),
    [anon_sym_as] = ACTIONS(4492),
    [anon_sym_is] = ACTIONS(4492),
    [anon_sym_DASH_GT] = ACTIONS(4604),
    [anon_sym_with] = ACTIONS(4492),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4494),
  },
  [3484] = {
    [sym_preproc_region] = STATE(3484),
    [sym_preproc_endregion] = STATE(3484),
    [sym_preproc_line] = STATE(3484),
    [sym_preproc_pragma] = STATE(3484),
    [sym_preproc_nullable] = STATE(3484),
    [sym_preproc_error] = STATE(3484),
    [sym_preproc_warning] = STATE(3484),
    [sym_preproc_define] = STATE(3484),
    [sym_preproc_undef] = STATE(3484),
    [anon_sym_SEMI] = ACTIONS(4670),
    [anon_sym_EQ] = ACTIONS(4672),
    [anon_sym_LBRACK] = ACTIONS(4670),
    [anon_sym_COLON] = ACTIONS(4670),
    [anon_sym_COMMA] = ACTIONS(4670),
    [anon_sym_RBRACK] = ACTIONS(4670),
    [anon_sym_LPAREN] = ACTIONS(4670),
    [anon_sym_RPAREN] = ACTIONS(4670),
    [anon_sym_RBRACE] = ACTIONS(4670),
    [anon_sym_LT] = ACTIONS(4672),
    [anon_sym_GT] = ACTIONS(4672),
    [anon_sym_in] = ACTIONS(4670),
    [anon_sym_QMARK] = ACTIONS(4672),
    [anon_sym_BANG] = ACTIONS(4672),
    [anon_sym_PLUS_PLUS] = ACTIONS(4670),
    [anon_sym_DASH_DASH] = ACTIONS(4670),
    [anon_sym_PLUS] = ACTIONS(4672),
    [anon_sym_DASH] = ACTIONS(4672),
    [anon_sym_STAR] = ACTIONS(4672),
    [anon_sym_SLASH] = ACTIONS(4672),
    [anon_sym_PERCENT] = ACTIONS(4672),
    [anon_sym_CARET] = ACTIONS(4672),
    [anon_sym_PIPE] = ACTIONS(4672),
    [anon_sym_AMP] = ACTIONS(4672),
    [anon_sym_LT_LT] = ACTIONS(4672),
    [anon_sym_GT_GT] = ACTIONS(4672),
    [anon_sym_GT_GT_GT] = ACTIONS(4672),
    [anon_sym_EQ_EQ] = ACTIONS(4670),
    [anon_sym_BANG_EQ] = ACTIONS(4670),
    [anon_sym_GT_EQ] = ACTIONS(4670),
    [anon_sym_LT_EQ] = ACTIONS(4670),
    [anon_sym_DOT] = ACTIONS(4672),
    [anon_sym_EQ_GT] = ACTIONS(4670),
    [anon_sym_switch] = ACTIONS(4670),
    [anon_sym_when] = ACTIONS(4670),
    [anon_sym_DOT_DOT] = ACTIONS(4670),
    [anon_sym_and] = ACTIONS(4670),
    [anon_sym_or] = ACTIONS(4670),
    [anon_sym_PLUS_EQ] = ACTIONS(4670),
    [anon_sym_DASH_EQ] = ACTIONS(4670),
    [anon_sym_STAR_EQ] = ACTIONS(4670),
    [anon_sym_SLASH_EQ] = ACTIONS(4670),
    [anon_sym_PERCENT_EQ] = ACTIONS(4670),
    [anon_sym_AMP_EQ] = ACTIONS(4670),
    [anon_sym_CARET_EQ] = ACTIONS(4670),
    [anon_sym_PIPE_EQ] = ACTIONS(4670),
    [anon_sym_LT_LT_EQ] = ACTIONS(4670),
    [anon_sym_GT_GT_EQ] = ACTIONS(4670),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4670),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4670),
    [anon_sym_AMP_AMP] = ACTIONS(4670),
    [anon_sym_PIPE_PIPE] = ACTIONS(4670),
    [anon_sym_QMARK_QMARK] = ACTIONS(4672),
    [anon_sym_on] = ACTIONS(4670),
    [anon_sym_equals] = ACTIONS(4670),
    [anon_sym_by] = ACTIONS(4670),
    [anon_sym_as] = ACTIONS(4670),
    [anon_sym_is] = ACTIONS(4670),
    [anon_sym_DASH_GT] = ACTIONS(4670),
    [anon_sym_with] = ACTIONS(4670),
    [aux_sym_preproc_if_token3] = ACTIONS(4670),
    [aux_sym_preproc_else_token1] = ACTIONS(4670),
    [aux_sym_preproc_elif_token1] = ACTIONS(4670),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3485] = {
    [sym_preproc_region] = STATE(3485),
    [sym_preproc_endregion] = STATE(3485),
    [sym_preproc_line] = STATE(3485),
    [sym_preproc_pragma] = STATE(3485),
    [sym_preproc_nullable] = STATE(3485),
    [sym_preproc_error] = STATE(3485),
    [sym_preproc_warning] = STATE(3485),
    [sym_preproc_define] = STATE(3485),
    [sym_preproc_undef] = STATE(3485),
    [sym__identifier_token] = ACTIONS(4492),
    [anon_sym_alias] = ACTIONS(4492),
    [anon_sym_global] = ACTIONS(4492),
    [anon_sym_LBRACK] = ACTIONS(4593),
    [anon_sym_COLON] = ACTIONS(4494),
    [anon_sym_COMMA] = ACTIONS(4494),
    [anon_sym_LPAREN] = ACTIONS(4494),
    [anon_sym_LBRACE] = ACTIONS(4494),
    [anon_sym_file] = ACTIONS(4492),
    [anon_sym_LT] = ACTIONS(4492),
    [anon_sym_GT] = ACTIONS(4492),
    [anon_sym_where] = ACTIONS(4492),
    [anon_sym_QMARK] = ACTIONS(4970),
    [anon_sym_notnull] = ACTIONS(4492),
    [anon_sym_unmanaged] = ACTIONS(4492),
    [anon_sym_BANG] = ACTIONS(4492),
    [anon_sym_PLUS_PLUS] = ACTIONS(4494),
    [anon_sym_DASH_DASH] = ACTIONS(4494),
    [anon_sym_PLUS] = ACTIONS(4492),
    [anon_sym_DASH] = ACTIONS(4492),
    [anon_sym_STAR] = ACTIONS(4599),
    [anon_sym_SLASH] = ACTIONS(4492),
    [anon_sym_PERCENT] = ACTIONS(4494),
    [anon_sym_CARET] = ACTIONS(4494),
    [anon_sym_PIPE] = ACTIONS(4492),
    [anon_sym_AMP] = ACTIONS(4492),
    [anon_sym_LT_LT] = ACTIONS(4494),
    [anon_sym_GT_GT] = ACTIONS(4492),
    [anon_sym_GT_GT_GT] = ACTIONS(4494),
    [anon_sym_EQ_EQ] = ACTIONS(4494),
    [anon_sym_BANG_EQ] = ACTIONS(4494),
    [anon_sym_GT_EQ] = ACTIONS(4494),
    [anon_sym_LT_EQ] = ACTIONS(4494),
    [anon_sym_DOT] = ACTIONS(5219),
    [anon_sym_scoped] = ACTIONS(4492),
    [anon_sym_var] = ACTIONS(4492),
    [anon_sym_yield] = ACTIONS(4492),
    [anon_sym_switch] = ACTIONS(4492),
    [anon_sym_when] = ACTIONS(4492),
    [sym_discard] = ACTIONS(4492),
    [anon_sym_DOT_DOT] = ACTIONS(4494),
    [anon_sym_and] = ACTIONS(4492),
    [anon_sym_or] = ACTIONS(4492),
    [anon_sym_AMP_AMP] = ACTIONS(4494),
    [anon_sym_PIPE_PIPE] = ACTIONS(4494),
    [anon_sym_QMARK_QMARK] = ACTIONS(4494),
    [anon_sym_from] = ACTIONS(4492),
    [anon_sym_into] = ACTIONS(4492),
    [anon_sym_join] = ACTIONS(4492),
    [anon_sym_on] = ACTIONS(4492),
    [anon_sym_equals] = ACTIONS(4492),
    [anon_sym_let] = ACTIONS(4492),
    [anon_sym_orderby] = ACTIONS(4492),
    [anon_sym_ascending] = ACTIONS(4492),
    [anon_sym_descending] = ACTIONS(4492),
    [anon_sym_group] = ACTIONS(4492),
    [anon_sym_by] = ACTIONS(4492),
    [anon_sym_select] = ACTIONS(4492),
    [anon_sym_as] = ACTIONS(4492),
    [anon_sym_is] = ACTIONS(4492),
    [anon_sym_DASH_GT] = ACTIONS(4975),
    [anon_sym_with] = ACTIONS(4492),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4494),
  },
  [3486] = {
    [sym_preproc_region] = STATE(3486),
    [sym_preproc_endregion] = STATE(3486),
    [sym_preproc_line] = STATE(3486),
    [sym_preproc_pragma] = STATE(3486),
    [sym_preproc_nullable] = STATE(3486),
    [sym_preproc_error] = STATE(3486),
    [sym_preproc_warning] = STATE(3486),
    [sym_preproc_define] = STATE(3486),
    [sym_preproc_undef] = STATE(3486),
    [sym__identifier_token] = ACTIONS(4157),
    [anon_sym_alias] = ACTIONS(4157),
    [anon_sym_global] = ACTIONS(4157),
    [anon_sym_LBRACK] = ACTIONS(4168),
    [anon_sym_COLON] = ACTIONS(4168),
    [anon_sym_COMMA] = ACTIONS(4168),
    [anon_sym_LPAREN] = ACTIONS(4168),
    [anon_sym_LBRACE] = ACTIONS(4168),
    [anon_sym_file] = ACTIONS(4157),
    [anon_sym_LT] = ACTIONS(4157),
    [anon_sym_GT] = ACTIONS(4157),
    [anon_sym_where] = ACTIONS(4157),
    [anon_sym_QMARK] = ACTIONS(4157),
    [anon_sym_notnull] = ACTIONS(4157),
    [anon_sym_unmanaged] = ACTIONS(4157),
    [anon_sym_BANG] = ACTIONS(4157),
    [anon_sym_PLUS_PLUS] = ACTIONS(4168),
    [anon_sym_DASH_DASH] = ACTIONS(4168),
    [anon_sym_PLUS] = ACTIONS(4157),
    [anon_sym_DASH] = ACTIONS(4157),
    [anon_sym_STAR] = ACTIONS(4168),
    [anon_sym_SLASH] = ACTIONS(4157),
    [anon_sym_PERCENT] = ACTIONS(4168),
    [anon_sym_CARET] = ACTIONS(4168),
    [anon_sym_PIPE] = ACTIONS(4157),
    [anon_sym_AMP] = ACTIONS(4157),
    [anon_sym_LT_LT] = ACTIONS(4168),
    [anon_sym_GT_GT] = ACTIONS(4157),
    [anon_sym_GT_GT_GT] = ACTIONS(4168),
    [anon_sym_EQ_EQ] = ACTIONS(4168),
    [anon_sym_BANG_EQ] = ACTIONS(4168),
    [anon_sym_GT_EQ] = ACTIONS(4168),
    [anon_sym_LT_EQ] = ACTIONS(4168),
    [anon_sym_DOT] = ACTIONS(4157),
    [anon_sym_scoped] = ACTIONS(4157),
    [anon_sym_var] = ACTIONS(4157),
    [anon_sym_yield] = ACTIONS(4157),
    [anon_sym_switch] = ACTIONS(4157),
    [anon_sym_when] = ACTIONS(4157),
    [sym_discard] = ACTIONS(4157),
    [anon_sym_DOT_DOT] = ACTIONS(4168),
    [anon_sym_and] = ACTIONS(4157),
    [anon_sym_or] = ACTIONS(4157),
    [anon_sym_AMP_AMP] = ACTIONS(4168),
    [anon_sym_PIPE_PIPE] = ACTIONS(4168),
    [anon_sym_QMARK_QMARK] = ACTIONS(4168),
    [anon_sym_from] = ACTIONS(4157),
    [anon_sym_into] = ACTIONS(4157),
    [anon_sym_join] = ACTIONS(4157),
    [anon_sym_on] = ACTIONS(4157),
    [anon_sym_equals] = ACTIONS(4157),
    [anon_sym_let] = ACTIONS(4157),
    [anon_sym_orderby] = ACTIONS(4157),
    [anon_sym_ascending] = ACTIONS(4157),
    [anon_sym_descending] = ACTIONS(4157),
    [anon_sym_group] = ACTIONS(4157),
    [anon_sym_by] = ACTIONS(4157),
    [anon_sym_select] = ACTIONS(4157),
    [anon_sym_as] = ACTIONS(4157),
    [anon_sym_is] = ACTIONS(4157),
    [anon_sym_DASH_GT] = ACTIONS(4168),
    [anon_sym_with] = ACTIONS(4157),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4168),
  },
  [3487] = {
    [sym_preproc_region] = STATE(3487),
    [sym_preproc_endregion] = STATE(3487),
    [sym_preproc_line] = STATE(3487),
    [sym_preproc_pragma] = STATE(3487),
    [sym_preproc_nullable] = STATE(3487),
    [sym_preproc_error] = STATE(3487),
    [sym_preproc_warning] = STATE(3487),
    [sym_preproc_define] = STATE(3487),
    [sym_preproc_undef] = STATE(3487),
    [sym__identifier_token] = ACTIONS(3525),
    [anon_sym_extern] = ACTIONS(3525),
    [anon_sym_alias] = ACTIONS(3525),
    [anon_sym_global] = ACTIONS(3525),
    [anon_sym_using] = ACTIONS(3525),
    [anon_sym_unsafe] = ACTIONS(3525),
    [anon_sym_static] = ACTIONS(3525),
    [anon_sym_LBRACK] = ACTIONS(3527),
    [anon_sym_LPAREN] = ACTIONS(3527),
    [anon_sym_event] = ACTIONS(3525),
    [anon_sym_namespace] = ACTIONS(3525),
    [anon_sym_class] = ACTIONS(3525),
    [anon_sym_ref] = ACTIONS(3525),
    [anon_sym_struct] = ACTIONS(3525),
    [anon_sym_enum] = ACTIONS(3525),
    [anon_sym_RBRACE] = ACTIONS(3527),
    [anon_sym_interface] = ACTIONS(3525),
    [anon_sym_delegate] = ACTIONS(3525),
    [anon_sym_record] = ACTIONS(3525),
    [anon_sym_abstract] = ACTIONS(3525),
    [anon_sym_async] = ACTIONS(3525),
    [anon_sym_const] = ACTIONS(3525),
    [anon_sym_file] = ACTIONS(3525),
    [anon_sym_fixed] = ACTIONS(3525),
    [anon_sym_internal] = ACTIONS(3525),
    [anon_sym_new] = ACTIONS(3525),
    [anon_sym_override] = ACTIONS(3525),
    [anon_sym_partial] = ACTIONS(3525),
    [anon_sym_private] = ACTIONS(3525),
    [anon_sym_protected] = ACTIONS(3525),
    [anon_sym_public] = ACTIONS(3525),
    [anon_sym_readonly] = ACTIONS(3525),
    [anon_sym_required] = ACTIONS(3525),
    [anon_sym_sealed] = ACTIONS(3525),
    [anon_sym_virtual] = ACTIONS(3525),
    [anon_sym_volatile] = ACTIONS(3525),
    [anon_sym_where] = ACTIONS(3525),
    [anon_sym_notnull] = ACTIONS(3525),
    [anon_sym_unmanaged] = ACTIONS(3525),
    [anon_sym_TILDE] = ACTIONS(3527),
    [anon_sym_implicit] = ACTIONS(3525),
    [anon_sym_explicit] = ACTIONS(3525),
    [anon_sym_scoped] = ACTIONS(3525),
    [anon_sym_var] = ACTIONS(3525),
    [sym_predefined_type] = ACTIONS(3525),
    [anon_sym_yield] = ACTIONS(3525),
    [anon_sym_when] = ACTIONS(3525),
    [anon_sym_from] = ACTIONS(3525),
    [anon_sym_into] = ACTIONS(3525),
    [anon_sym_join] = ACTIONS(3525),
    [anon_sym_on] = ACTIONS(3525),
    [anon_sym_equals] = ACTIONS(3525),
    [anon_sym_let] = ACTIONS(3525),
    [anon_sym_orderby] = ACTIONS(3525),
    [anon_sym_ascending] = ACTIONS(3525),
    [anon_sym_descending] = ACTIONS(3525),
    [anon_sym_group] = ACTIONS(3525),
    [anon_sym_by] = ACTIONS(3525),
    [anon_sym_select] = ACTIONS(3525),
    [aux_sym_preproc_if_token1] = ACTIONS(3527),
    [aux_sym_preproc_if_token3] = ACTIONS(3527),
    [aux_sym_preproc_else_token1] = ACTIONS(3527),
    [aux_sym_preproc_elif_token1] = ACTIONS(3527),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3488] = {
    [sym_preproc_region] = STATE(3488),
    [sym_preproc_endregion] = STATE(3488),
    [sym_preproc_line] = STATE(3488),
    [sym_preproc_pragma] = STATE(3488),
    [sym_preproc_nullable] = STATE(3488),
    [sym_preproc_error] = STATE(3488),
    [sym_preproc_warning] = STATE(3488),
    [sym_preproc_define] = STATE(3488),
    [sym_preproc_undef] = STATE(3488),
    [sym__identifier_token] = ACTIONS(4492),
    [anon_sym_alias] = ACTIONS(4492),
    [anon_sym_global] = ACTIONS(4492),
    [anon_sym_LBRACK] = ACTIONS(4593),
    [anon_sym_COLON] = ACTIONS(4494),
    [anon_sym_COMMA] = ACTIONS(4494),
    [anon_sym_LPAREN] = ACTIONS(4494),
    [anon_sym_LBRACE] = ACTIONS(4494),
    [anon_sym_file] = ACTIONS(4492),
    [anon_sym_LT] = ACTIONS(4492),
    [anon_sym_GT] = ACTIONS(4492),
    [anon_sym_where] = ACTIONS(4492),
    [anon_sym_QMARK] = ACTIONS(4970),
    [anon_sym_notnull] = ACTIONS(4492),
    [anon_sym_unmanaged] = ACTIONS(4492),
    [anon_sym_BANG] = ACTIONS(4492),
    [anon_sym_PLUS_PLUS] = ACTIONS(4494),
    [anon_sym_DASH_DASH] = ACTIONS(4494),
    [anon_sym_PLUS] = ACTIONS(4492),
    [anon_sym_DASH] = ACTIONS(4492),
    [anon_sym_STAR] = ACTIONS(4494),
    [anon_sym_SLASH] = ACTIONS(4492),
    [anon_sym_PERCENT] = ACTIONS(4494),
    [anon_sym_CARET] = ACTIONS(4494),
    [anon_sym_PIPE] = ACTIONS(4492),
    [anon_sym_AMP] = ACTIONS(4492),
    [anon_sym_LT_LT] = ACTIONS(4494),
    [anon_sym_GT_GT] = ACTIONS(4492),
    [anon_sym_GT_GT_GT] = ACTIONS(4494),
    [anon_sym_EQ_EQ] = ACTIONS(4494),
    [anon_sym_BANG_EQ] = ACTIONS(4494),
    [anon_sym_GT_EQ] = ACTIONS(4494),
    [anon_sym_LT_EQ] = ACTIONS(4494),
    [anon_sym_DOT] = ACTIONS(4492),
    [anon_sym_scoped] = ACTIONS(4492),
    [anon_sym_var] = ACTIONS(4492),
    [anon_sym_yield] = ACTIONS(4492),
    [anon_sym_switch] = ACTIONS(4492),
    [anon_sym_when] = ACTIONS(4492),
    [sym_discard] = ACTIONS(4492),
    [anon_sym_DOT_DOT] = ACTIONS(4494),
    [anon_sym_and] = ACTIONS(4492),
    [anon_sym_or] = ACTIONS(4492),
    [anon_sym_AMP_AMP] = ACTIONS(4494),
    [anon_sym_PIPE_PIPE] = ACTIONS(4494),
    [anon_sym_QMARK_QMARK] = ACTIONS(4494),
    [anon_sym_from] = ACTIONS(4492),
    [anon_sym_into] = ACTIONS(4492),
    [anon_sym_join] = ACTIONS(4492),
    [anon_sym_on] = ACTIONS(4492),
    [anon_sym_equals] = ACTIONS(4492),
    [anon_sym_let] = ACTIONS(4492),
    [anon_sym_orderby] = ACTIONS(4492),
    [anon_sym_ascending] = ACTIONS(4492),
    [anon_sym_descending] = ACTIONS(4492),
    [anon_sym_group] = ACTIONS(4492),
    [anon_sym_by] = ACTIONS(4492),
    [anon_sym_select] = ACTIONS(4492),
    [anon_sym_as] = ACTIONS(4492),
    [anon_sym_is] = ACTIONS(4492),
    [anon_sym_DASH_GT] = ACTIONS(4494),
    [anon_sym_with] = ACTIONS(4492),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4494),
  },
  [3489] = {
    [sym_preproc_region] = STATE(3489),
    [sym_preproc_endregion] = STATE(3489),
    [sym_preproc_line] = STATE(3489),
    [sym_preproc_pragma] = STATE(3489),
    [sym_preproc_nullable] = STATE(3489),
    [sym_preproc_error] = STATE(3489),
    [sym_preproc_warning] = STATE(3489),
    [sym_preproc_define] = STATE(3489),
    [sym_preproc_undef] = STATE(3489),
    [sym__identifier_token] = ACTIONS(4492),
    [anon_sym_alias] = ACTIONS(4492),
    [anon_sym_global] = ACTIONS(4492),
    [anon_sym_LBRACK] = ACTIONS(4593),
    [anon_sym_COLON] = ACTIONS(4494),
    [anon_sym_COMMA] = ACTIONS(4494),
    [anon_sym_LPAREN] = ACTIONS(4494),
    [anon_sym_LBRACE] = ACTIONS(4494),
    [anon_sym_file] = ACTIONS(4492),
    [anon_sym_LT] = ACTIONS(4492),
    [anon_sym_GT] = ACTIONS(4492),
    [anon_sym_where] = ACTIONS(4492),
    [anon_sym_QMARK] = ACTIONS(4492),
    [anon_sym_notnull] = ACTIONS(4492),
    [anon_sym_unmanaged] = ACTIONS(4492),
    [anon_sym_BANG] = ACTIONS(4492),
    [anon_sym_PLUS_PLUS] = ACTIONS(4494),
    [anon_sym_DASH_DASH] = ACTIONS(4494),
    [anon_sym_PLUS] = ACTIONS(4492),
    [anon_sym_DASH] = ACTIONS(4492),
    [anon_sym_STAR] = ACTIONS(4599),
    [anon_sym_SLASH] = ACTIONS(4492),
    [anon_sym_PERCENT] = ACTIONS(4494),
    [anon_sym_CARET] = ACTIONS(4494),
    [anon_sym_PIPE] = ACTIONS(4492),
    [anon_sym_AMP] = ACTIONS(4492),
    [anon_sym_LT_LT] = ACTIONS(4494),
    [anon_sym_GT_GT] = ACTIONS(4492),
    [anon_sym_GT_GT_GT] = ACTIONS(4494),
    [anon_sym_EQ_EQ] = ACTIONS(4494),
    [anon_sym_BANG_EQ] = ACTIONS(4494),
    [anon_sym_GT_EQ] = ACTIONS(4494),
    [anon_sym_LT_EQ] = ACTIONS(4494),
    [anon_sym_DOT] = ACTIONS(4492),
    [anon_sym_scoped] = ACTIONS(4492),
    [anon_sym_var] = ACTIONS(4492),
    [anon_sym_yield] = ACTIONS(4492),
    [anon_sym_switch] = ACTIONS(4492),
    [anon_sym_when] = ACTIONS(4492),
    [sym_discard] = ACTIONS(4492),
    [anon_sym_DOT_DOT] = ACTIONS(4494),
    [anon_sym_and] = ACTIONS(4492),
    [anon_sym_or] = ACTIONS(4492),
    [anon_sym_AMP_AMP] = ACTIONS(4494),
    [anon_sym_PIPE_PIPE] = ACTIONS(4494),
    [anon_sym_QMARK_QMARK] = ACTIONS(4494),
    [anon_sym_from] = ACTIONS(4492),
    [anon_sym_into] = ACTIONS(4492),
    [anon_sym_join] = ACTIONS(4492),
    [anon_sym_on] = ACTIONS(4492),
    [anon_sym_equals] = ACTIONS(4492),
    [anon_sym_let] = ACTIONS(4492),
    [anon_sym_orderby] = ACTIONS(4492),
    [anon_sym_ascending] = ACTIONS(4492),
    [anon_sym_descending] = ACTIONS(4492),
    [anon_sym_group] = ACTIONS(4492),
    [anon_sym_by] = ACTIONS(4492),
    [anon_sym_select] = ACTIONS(4492),
    [anon_sym_as] = ACTIONS(4492),
    [anon_sym_is] = ACTIONS(4492),
    [anon_sym_DASH_GT] = ACTIONS(4494),
    [anon_sym_with] = ACTIONS(4492),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4494),
  },
  [3490] = {
    [sym_preproc_region] = STATE(3490),
    [sym_preproc_endregion] = STATE(3490),
    [sym_preproc_line] = STATE(3490),
    [sym_preproc_pragma] = STATE(3490),
    [sym_preproc_nullable] = STATE(3490),
    [sym_preproc_error] = STATE(3490),
    [sym_preproc_warning] = STATE(3490),
    [sym_preproc_define] = STATE(3490),
    [sym_preproc_undef] = STATE(3490),
    [sym__identifier_token] = ACTIONS(4492),
    [anon_sym_alias] = ACTIONS(4492),
    [anon_sym_global] = ACTIONS(4492),
    [anon_sym_LBRACK] = ACTIONS(4593),
    [anon_sym_COLON] = ACTIONS(4494),
    [anon_sym_COMMA] = ACTIONS(4494),
    [anon_sym_LPAREN] = ACTIONS(4494),
    [anon_sym_LBRACE] = ACTIONS(4494),
    [anon_sym_file] = ACTIONS(4492),
    [anon_sym_LT] = ACTIONS(4492),
    [anon_sym_GT] = ACTIONS(4492),
    [anon_sym_where] = ACTIONS(4492),
    [anon_sym_QMARK] = ACTIONS(4970),
    [anon_sym_notnull] = ACTIONS(4492),
    [anon_sym_unmanaged] = ACTIONS(4492),
    [anon_sym_BANG] = ACTIONS(4492),
    [anon_sym_PLUS_PLUS] = ACTIONS(4494),
    [anon_sym_DASH_DASH] = ACTIONS(4494),
    [anon_sym_PLUS] = ACTIONS(4492),
    [anon_sym_DASH] = ACTIONS(4492),
    [anon_sym_STAR] = ACTIONS(4599),
    [anon_sym_SLASH] = ACTIONS(4492),
    [anon_sym_PERCENT] = ACTIONS(4494),
    [anon_sym_CARET] = ACTIONS(4494),
    [anon_sym_PIPE] = ACTIONS(4492),
    [anon_sym_AMP] = ACTIONS(4492),
    [anon_sym_LT_LT] = ACTIONS(4494),
    [anon_sym_GT_GT] = ACTIONS(4492),
    [anon_sym_GT_GT_GT] = ACTIONS(4494),
    [anon_sym_EQ_EQ] = ACTIONS(4494),
    [anon_sym_BANG_EQ] = ACTIONS(4494),
    [anon_sym_GT_EQ] = ACTIONS(4494),
    [anon_sym_LT_EQ] = ACTIONS(4494),
    [anon_sym_DOT] = ACTIONS(4492),
    [anon_sym_scoped] = ACTIONS(4492),
    [anon_sym_var] = ACTIONS(4492),
    [anon_sym_yield] = ACTIONS(4492),
    [anon_sym_switch] = ACTIONS(4492),
    [anon_sym_when] = ACTIONS(4492),
    [sym_discard] = ACTIONS(4492),
    [anon_sym_DOT_DOT] = ACTIONS(4494),
    [anon_sym_and] = ACTIONS(4492),
    [anon_sym_or] = ACTIONS(4492),
    [anon_sym_AMP_AMP] = ACTIONS(4494),
    [anon_sym_PIPE_PIPE] = ACTIONS(4494),
    [anon_sym_QMARK_QMARK] = ACTIONS(4494),
    [anon_sym_from] = ACTIONS(4492),
    [anon_sym_into] = ACTIONS(4492),
    [anon_sym_join] = ACTIONS(4492),
    [anon_sym_on] = ACTIONS(4492),
    [anon_sym_equals] = ACTIONS(4492),
    [anon_sym_let] = ACTIONS(4492),
    [anon_sym_orderby] = ACTIONS(4492),
    [anon_sym_ascending] = ACTIONS(4492),
    [anon_sym_descending] = ACTIONS(4492),
    [anon_sym_group] = ACTIONS(4492),
    [anon_sym_by] = ACTIONS(4492),
    [anon_sym_select] = ACTIONS(4492),
    [anon_sym_as] = ACTIONS(4492),
    [anon_sym_is] = ACTIONS(4492),
    [anon_sym_DASH_GT] = ACTIONS(4494),
    [anon_sym_with] = ACTIONS(4492),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4494),
  },
  [3491] = {
    [sym_preproc_region] = STATE(3491),
    [sym_preproc_endregion] = STATE(3491),
    [sym_preproc_line] = STATE(3491),
    [sym_preproc_pragma] = STATE(3491),
    [sym_preproc_nullable] = STATE(3491),
    [sym_preproc_error] = STATE(3491),
    [sym_preproc_warning] = STATE(3491),
    [sym_preproc_define] = STATE(3491),
    [sym_preproc_undef] = STATE(3491),
    [sym__identifier_token] = ACTIONS(3959),
    [anon_sym_extern] = ACTIONS(3959),
    [anon_sym_alias] = ACTIONS(3959),
    [anon_sym_global] = ACTIONS(3959),
    [anon_sym_using] = ACTIONS(3959),
    [anon_sym_unsafe] = ACTIONS(3959),
    [anon_sym_static] = ACTIONS(3959),
    [anon_sym_LBRACK] = ACTIONS(3961),
    [anon_sym_LPAREN] = ACTIONS(3961),
    [anon_sym_event] = ACTIONS(3959),
    [anon_sym_namespace] = ACTIONS(3959),
    [anon_sym_class] = ACTIONS(3959),
    [anon_sym_ref] = ACTIONS(3959),
    [anon_sym_struct] = ACTIONS(3959),
    [anon_sym_enum] = ACTIONS(3959),
    [anon_sym_RBRACE] = ACTIONS(3961),
    [anon_sym_interface] = ACTIONS(3959),
    [anon_sym_delegate] = ACTIONS(3959),
    [anon_sym_record] = ACTIONS(3959),
    [anon_sym_abstract] = ACTIONS(3959),
    [anon_sym_async] = ACTIONS(3959),
    [anon_sym_const] = ACTIONS(3959),
    [anon_sym_file] = ACTIONS(3959),
    [anon_sym_fixed] = ACTIONS(3959),
    [anon_sym_internal] = ACTIONS(3959),
    [anon_sym_new] = ACTIONS(3959),
    [anon_sym_override] = ACTIONS(3959),
    [anon_sym_partial] = ACTIONS(3959),
    [anon_sym_private] = ACTIONS(3959),
    [anon_sym_protected] = ACTIONS(3959),
    [anon_sym_public] = ACTIONS(3959),
    [anon_sym_readonly] = ACTIONS(3959),
    [anon_sym_required] = ACTIONS(3959),
    [anon_sym_sealed] = ACTIONS(3959),
    [anon_sym_virtual] = ACTIONS(3959),
    [anon_sym_volatile] = ACTIONS(3959),
    [anon_sym_where] = ACTIONS(3959),
    [anon_sym_notnull] = ACTIONS(3959),
    [anon_sym_unmanaged] = ACTIONS(3959),
    [anon_sym_TILDE] = ACTIONS(3961),
    [anon_sym_implicit] = ACTIONS(3959),
    [anon_sym_explicit] = ACTIONS(3959),
    [anon_sym_scoped] = ACTIONS(3959),
    [anon_sym_var] = ACTIONS(3959),
    [sym_predefined_type] = ACTIONS(3959),
    [anon_sym_yield] = ACTIONS(3959),
    [anon_sym_when] = ACTIONS(3959),
    [anon_sym_from] = ACTIONS(3959),
    [anon_sym_into] = ACTIONS(3959),
    [anon_sym_join] = ACTIONS(3959),
    [anon_sym_on] = ACTIONS(3959),
    [anon_sym_equals] = ACTIONS(3959),
    [anon_sym_let] = ACTIONS(3959),
    [anon_sym_orderby] = ACTIONS(3959),
    [anon_sym_ascending] = ACTIONS(3959),
    [anon_sym_descending] = ACTIONS(3959),
    [anon_sym_group] = ACTIONS(3959),
    [anon_sym_by] = ACTIONS(3959),
    [anon_sym_select] = ACTIONS(3959),
    [aux_sym_preproc_if_token1] = ACTIONS(3961),
    [aux_sym_preproc_if_token3] = ACTIONS(3961),
    [aux_sym_preproc_else_token1] = ACTIONS(3961),
    [aux_sym_preproc_elif_token1] = ACTIONS(3961),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3492] = {
    [sym_preproc_region] = STATE(3492),
    [sym_preproc_endregion] = STATE(3492),
    [sym_preproc_line] = STATE(3492),
    [sym_preproc_pragma] = STATE(3492),
    [sym_preproc_nullable] = STATE(3492),
    [sym_preproc_error] = STATE(3492),
    [sym_preproc_warning] = STATE(3492),
    [sym_preproc_define] = STATE(3492),
    [sym_preproc_undef] = STATE(3492),
    [sym__identifier_token] = ACTIONS(3963),
    [anon_sym_extern] = ACTIONS(3963),
    [anon_sym_alias] = ACTIONS(3963),
    [anon_sym_global] = ACTIONS(3963),
    [anon_sym_using] = ACTIONS(3963),
    [anon_sym_unsafe] = ACTIONS(3963),
    [anon_sym_static] = ACTIONS(3963),
    [anon_sym_LBRACK] = ACTIONS(3965),
    [anon_sym_LPAREN] = ACTIONS(3965),
    [anon_sym_event] = ACTIONS(3963),
    [anon_sym_namespace] = ACTIONS(3963),
    [anon_sym_class] = ACTIONS(3963),
    [anon_sym_ref] = ACTIONS(3963),
    [anon_sym_struct] = ACTIONS(3963),
    [anon_sym_enum] = ACTIONS(3963),
    [anon_sym_RBRACE] = ACTIONS(3965),
    [anon_sym_interface] = ACTIONS(3963),
    [anon_sym_delegate] = ACTIONS(3963),
    [anon_sym_record] = ACTIONS(3963),
    [anon_sym_abstract] = ACTIONS(3963),
    [anon_sym_async] = ACTIONS(3963),
    [anon_sym_const] = ACTIONS(3963),
    [anon_sym_file] = ACTIONS(3963),
    [anon_sym_fixed] = ACTIONS(3963),
    [anon_sym_internal] = ACTIONS(3963),
    [anon_sym_new] = ACTIONS(3963),
    [anon_sym_override] = ACTIONS(3963),
    [anon_sym_partial] = ACTIONS(3963),
    [anon_sym_private] = ACTIONS(3963),
    [anon_sym_protected] = ACTIONS(3963),
    [anon_sym_public] = ACTIONS(3963),
    [anon_sym_readonly] = ACTIONS(3963),
    [anon_sym_required] = ACTIONS(3963),
    [anon_sym_sealed] = ACTIONS(3963),
    [anon_sym_virtual] = ACTIONS(3963),
    [anon_sym_volatile] = ACTIONS(3963),
    [anon_sym_where] = ACTIONS(3963),
    [anon_sym_notnull] = ACTIONS(3963),
    [anon_sym_unmanaged] = ACTIONS(3963),
    [anon_sym_TILDE] = ACTIONS(3965),
    [anon_sym_implicit] = ACTIONS(3963),
    [anon_sym_explicit] = ACTIONS(3963),
    [anon_sym_scoped] = ACTIONS(3963),
    [anon_sym_var] = ACTIONS(3963),
    [sym_predefined_type] = ACTIONS(3963),
    [anon_sym_yield] = ACTIONS(3963),
    [anon_sym_when] = ACTIONS(3963),
    [anon_sym_from] = ACTIONS(3963),
    [anon_sym_into] = ACTIONS(3963),
    [anon_sym_join] = ACTIONS(3963),
    [anon_sym_on] = ACTIONS(3963),
    [anon_sym_equals] = ACTIONS(3963),
    [anon_sym_let] = ACTIONS(3963),
    [anon_sym_orderby] = ACTIONS(3963),
    [anon_sym_ascending] = ACTIONS(3963),
    [anon_sym_descending] = ACTIONS(3963),
    [anon_sym_group] = ACTIONS(3963),
    [anon_sym_by] = ACTIONS(3963),
    [anon_sym_select] = ACTIONS(3963),
    [aux_sym_preproc_if_token1] = ACTIONS(3965),
    [aux_sym_preproc_if_token3] = ACTIONS(3965),
    [aux_sym_preproc_else_token1] = ACTIONS(3965),
    [aux_sym_preproc_elif_token1] = ACTIONS(3965),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3493] = {
    [sym_preproc_region] = STATE(3493),
    [sym_preproc_endregion] = STATE(3493),
    [sym_preproc_line] = STATE(3493),
    [sym_preproc_pragma] = STATE(3493),
    [sym_preproc_nullable] = STATE(3493),
    [sym_preproc_error] = STATE(3493),
    [sym_preproc_warning] = STATE(3493),
    [sym_preproc_define] = STATE(3493),
    [sym_preproc_undef] = STATE(3493),
    [sym__identifier_token] = ACTIONS(3967),
    [anon_sym_extern] = ACTIONS(3967),
    [anon_sym_alias] = ACTIONS(3967),
    [anon_sym_global] = ACTIONS(3967),
    [anon_sym_using] = ACTIONS(3967),
    [anon_sym_unsafe] = ACTIONS(3967),
    [anon_sym_static] = ACTIONS(3967),
    [anon_sym_LBRACK] = ACTIONS(3969),
    [anon_sym_LPAREN] = ACTIONS(3969),
    [anon_sym_event] = ACTIONS(3967),
    [anon_sym_namespace] = ACTIONS(3967),
    [anon_sym_class] = ACTIONS(3967),
    [anon_sym_ref] = ACTIONS(3967),
    [anon_sym_struct] = ACTIONS(3967),
    [anon_sym_enum] = ACTIONS(3967),
    [anon_sym_RBRACE] = ACTIONS(3969),
    [anon_sym_interface] = ACTIONS(3967),
    [anon_sym_delegate] = ACTIONS(3967),
    [anon_sym_record] = ACTIONS(3967),
    [anon_sym_abstract] = ACTIONS(3967),
    [anon_sym_async] = ACTIONS(3967),
    [anon_sym_const] = ACTIONS(3967),
    [anon_sym_file] = ACTIONS(3967),
    [anon_sym_fixed] = ACTIONS(3967),
    [anon_sym_internal] = ACTIONS(3967),
    [anon_sym_new] = ACTIONS(3967),
    [anon_sym_override] = ACTIONS(3967),
    [anon_sym_partial] = ACTIONS(3967),
    [anon_sym_private] = ACTIONS(3967),
    [anon_sym_protected] = ACTIONS(3967),
    [anon_sym_public] = ACTIONS(3967),
    [anon_sym_readonly] = ACTIONS(3967),
    [anon_sym_required] = ACTIONS(3967),
    [anon_sym_sealed] = ACTIONS(3967),
    [anon_sym_virtual] = ACTIONS(3967),
    [anon_sym_volatile] = ACTIONS(3967),
    [anon_sym_where] = ACTIONS(3967),
    [anon_sym_notnull] = ACTIONS(3967),
    [anon_sym_unmanaged] = ACTIONS(3967),
    [anon_sym_TILDE] = ACTIONS(3969),
    [anon_sym_implicit] = ACTIONS(3967),
    [anon_sym_explicit] = ACTIONS(3967),
    [anon_sym_scoped] = ACTIONS(3967),
    [anon_sym_var] = ACTIONS(3967),
    [sym_predefined_type] = ACTIONS(3967),
    [anon_sym_yield] = ACTIONS(3967),
    [anon_sym_when] = ACTIONS(3967),
    [anon_sym_from] = ACTIONS(3967),
    [anon_sym_into] = ACTIONS(3967),
    [anon_sym_join] = ACTIONS(3967),
    [anon_sym_on] = ACTIONS(3967),
    [anon_sym_equals] = ACTIONS(3967),
    [anon_sym_let] = ACTIONS(3967),
    [anon_sym_orderby] = ACTIONS(3967),
    [anon_sym_ascending] = ACTIONS(3967),
    [anon_sym_descending] = ACTIONS(3967),
    [anon_sym_group] = ACTIONS(3967),
    [anon_sym_by] = ACTIONS(3967),
    [anon_sym_select] = ACTIONS(3967),
    [aux_sym_preproc_if_token1] = ACTIONS(3969),
    [aux_sym_preproc_if_token3] = ACTIONS(3969),
    [aux_sym_preproc_else_token1] = ACTIONS(3969),
    [aux_sym_preproc_elif_token1] = ACTIONS(3969),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3494] = {
    [sym_preproc_region] = STATE(3494),
    [sym_preproc_endregion] = STATE(3494),
    [sym_preproc_line] = STATE(3494),
    [sym_preproc_pragma] = STATE(3494),
    [sym_preproc_nullable] = STATE(3494),
    [sym_preproc_error] = STATE(3494),
    [sym_preproc_warning] = STATE(3494),
    [sym_preproc_define] = STATE(3494),
    [sym_preproc_undef] = STATE(3494),
    [sym__identifier_token] = ACTIONS(3971),
    [anon_sym_extern] = ACTIONS(3971),
    [anon_sym_alias] = ACTIONS(3971),
    [anon_sym_global] = ACTIONS(3971),
    [anon_sym_using] = ACTIONS(3971),
    [anon_sym_unsafe] = ACTIONS(3971),
    [anon_sym_static] = ACTIONS(3971),
    [anon_sym_LBRACK] = ACTIONS(3973),
    [anon_sym_LPAREN] = ACTIONS(3973),
    [anon_sym_event] = ACTIONS(3971),
    [anon_sym_namespace] = ACTIONS(3971),
    [anon_sym_class] = ACTIONS(3971),
    [anon_sym_ref] = ACTIONS(3971),
    [anon_sym_struct] = ACTIONS(3971),
    [anon_sym_enum] = ACTIONS(3971),
    [anon_sym_RBRACE] = ACTIONS(3973),
    [anon_sym_interface] = ACTIONS(3971),
    [anon_sym_delegate] = ACTIONS(3971),
    [anon_sym_record] = ACTIONS(3971),
    [anon_sym_abstract] = ACTIONS(3971),
    [anon_sym_async] = ACTIONS(3971),
    [anon_sym_const] = ACTIONS(3971),
    [anon_sym_file] = ACTIONS(3971),
    [anon_sym_fixed] = ACTIONS(3971),
    [anon_sym_internal] = ACTIONS(3971),
    [anon_sym_new] = ACTIONS(3971),
    [anon_sym_override] = ACTIONS(3971),
    [anon_sym_partial] = ACTIONS(3971),
    [anon_sym_private] = ACTIONS(3971),
    [anon_sym_protected] = ACTIONS(3971),
    [anon_sym_public] = ACTIONS(3971),
    [anon_sym_readonly] = ACTIONS(3971),
    [anon_sym_required] = ACTIONS(3971),
    [anon_sym_sealed] = ACTIONS(3971),
    [anon_sym_virtual] = ACTIONS(3971),
    [anon_sym_volatile] = ACTIONS(3971),
    [anon_sym_where] = ACTIONS(3971),
    [anon_sym_notnull] = ACTIONS(3971),
    [anon_sym_unmanaged] = ACTIONS(3971),
    [anon_sym_TILDE] = ACTIONS(3973),
    [anon_sym_implicit] = ACTIONS(3971),
    [anon_sym_explicit] = ACTIONS(3971),
    [anon_sym_scoped] = ACTIONS(3971),
    [anon_sym_var] = ACTIONS(3971),
    [sym_predefined_type] = ACTIONS(3971),
    [anon_sym_yield] = ACTIONS(3971),
    [anon_sym_when] = ACTIONS(3971),
    [anon_sym_from] = ACTIONS(3971),
    [anon_sym_into] = ACTIONS(3971),
    [anon_sym_join] = ACTIONS(3971),
    [anon_sym_on] = ACTIONS(3971),
    [anon_sym_equals] = ACTIONS(3971),
    [anon_sym_let] = ACTIONS(3971),
    [anon_sym_orderby] = ACTIONS(3971),
    [anon_sym_ascending] = ACTIONS(3971),
    [anon_sym_descending] = ACTIONS(3971),
    [anon_sym_group] = ACTIONS(3971),
    [anon_sym_by] = ACTIONS(3971),
    [anon_sym_select] = ACTIONS(3971),
    [aux_sym_preproc_if_token1] = ACTIONS(3973),
    [aux_sym_preproc_if_token3] = ACTIONS(3973),
    [aux_sym_preproc_else_token1] = ACTIONS(3973),
    [aux_sym_preproc_elif_token1] = ACTIONS(3973),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3495] = {
    [sym_preproc_region] = STATE(3495),
    [sym_preproc_endregion] = STATE(3495),
    [sym_preproc_line] = STATE(3495),
    [sym_preproc_pragma] = STATE(3495),
    [sym_preproc_nullable] = STATE(3495),
    [sym_preproc_error] = STATE(3495),
    [sym_preproc_warning] = STATE(3495),
    [sym_preproc_define] = STATE(3495),
    [sym_preproc_undef] = STATE(3495),
    [sym__identifier_token] = ACTIONS(3975),
    [anon_sym_extern] = ACTIONS(3975),
    [anon_sym_alias] = ACTIONS(3975),
    [anon_sym_global] = ACTIONS(3975),
    [anon_sym_using] = ACTIONS(3975),
    [anon_sym_unsafe] = ACTIONS(3975),
    [anon_sym_static] = ACTIONS(3975),
    [anon_sym_LBRACK] = ACTIONS(3977),
    [anon_sym_LPAREN] = ACTIONS(3977),
    [anon_sym_event] = ACTIONS(3975),
    [anon_sym_namespace] = ACTIONS(3975),
    [anon_sym_class] = ACTIONS(3975),
    [anon_sym_ref] = ACTIONS(3975),
    [anon_sym_struct] = ACTIONS(3975),
    [anon_sym_enum] = ACTIONS(3975),
    [anon_sym_RBRACE] = ACTIONS(3977),
    [anon_sym_interface] = ACTIONS(3975),
    [anon_sym_delegate] = ACTIONS(3975),
    [anon_sym_record] = ACTIONS(3975),
    [anon_sym_abstract] = ACTIONS(3975),
    [anon_sym_async] = ACTIONS(3975),
    [anon_sym_const] = ACTIONS(3975),
    [anon_sym_file] = ACTIONS(3975),
    [anon_sym_fixed] = ACTIONS(3975),
    [anon_sym_internal] = ACTIONS(3975),
    [anon_sym_new] = ACTIONS(3975),
    [anon_sym_override] = ACTIONS(3975),
    [anon_sym_partial] = ACTIONS(3975),
    [anon_sym_private] = ACTIONS(3975),
    [anon_sym_protected] = ACTIONS(3975),
    [anon_sym_public] = ACTIONS(3975),
    [anon_sym_readonly] = ACTIONS(3975),
    [anon_sym_required] = ACTIONS(3975),
    [anon_sym_sealed] = ACTIONS(3975),
    [anon_sym_virtual] = ACTIONS(3975),
    [anon_sym_volatile] = ACTIONS(3975),
    [anon_sym_where] = ACTIONS(3975),
    [anon_sym_notnull] = ACTIONS(3975),
    [anon_sym_unmanaged] = ACTIONS(3975),
    [anon_sym_TILDE] = ACTIONS(3977),
    [anon_sym_implicit] = ACTIONS(3975),
    [anon_sym_explicit] = ACTIONS(3975),
    [anon_sym_scoped] = ACTIONS(3975),
    [anon_sym_var] = ACTIONS(3975),
    [sym_predefined_type] = ACTIONS(3975),
    [anon_sym_yield] = ACTIONS(3975),
    [anon_sym_when] = ACTIONS(3975),
    [anon_sym_from] = ACTIONS(3975),
    [anon_sym_into] = ACTIONS(3975),
    [anon_sym_join] = ACTIONS(3975),
    [anon_sym_on] = ACTIONS(3975),
    [anon_sym_equals] = ACTIONS(3975),
    [anon_sym_let] = ACTIONS(3975),
    [anon_sym_orderby] = ACTIONS(3975),
    [anon_sym_ascending] = ACTIONS(3975),
    [anon_sym_descending] = ACTIONS(3975),
    [anon_sym_group] = ACTIONS(3975),
    [anon_sym_by] = ACTIONS(3975),
    [anon_sym_select] = ACTIONS(3975),
    [aux_sym_preproc_if_token1] = ACTIONS(3977),
    [aux_sym_preproc_if_token3] = ACTIONS(3977),
    [aux_sym_preproc_else_token1] = ACTIONS(3977),
    [aux_sym_preproc_elif_token1] = ACTIONS(3977),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3496] = {
    [sym_preproc_region] = STATE(3496),
    [sym_preproc_endregion] = STATE(3496),
    [sym_preproc_line] = STATE(3496),
    [sym_preproc_pragma] = STATE(3496),
    [sym_preproc_nullable] = STATE(3496),
    [sym_preproc_error] = STATE(3496),
    [sym_preproc_warning] = STATE(3496),
    [sym_preproc_define] = STATE(3496),
    [sym_preproc_undef] = STATE(3496),
    [sym__identifier_token] = ACTIONS(3979),
    [anon_sym_extern] = ACTIONS(3979),
    [anon_sym_alias] = ACTIONS(3979),
    [anon_sym_global] = ACTIONS(3979),
    [anon_sym_using] = ACTIONS(3979),
    [anon_sym_unsafe] = ACTIONS(3979),
    [anon_sym_static] = ACTIONS(3979),
    [anon_sym_LBRACK] = ACTIONS(3981),
    [anon_sym_LPAREN] = ACTIONS(3981),
    [anon_sym_event] = ACTIONS(3979),
    [anon_sym_namespace] = ACTIONS(3979),
    [anon_sym_class] = ACTIONS(3979),
    [anon_sym_ref] = ACTIONS(3979),
    [anon_sym_struct] = ACTIONS(3979),
    [anon_sym_enum] = ACTIONS(3979),
    [anon_sym_RBRACE] = ACTIONS(3981),
    [anon_sym_interface] = ACTIONS(3979),
    [anon_sym_delegate] = ACTIONS(3979),
    [anon_sym_record] = ACTIONS(3979),
    [anon_sym_abstract] = ACTIONS(3979),
    [anon_sym_async] = ACTIONS(3979),
    [anon_sym_const] = ACTIONS(3979),
    [anon_sym_file] = ACTIONS(3979),
    [anon_sym_fixed] = ACTIONS(3979),
    [anon_sym_internal] = ACTIONS(3979),
    [anon_sym_new] = ACTIONS(3979),
    [anon_sym_override] = ACTIONS(3979),
    [anon_sym_partial] = ACTIONS(3979),
    [anon_sym_private] = ACTIONS(3979),
    [anon_sym_protected] = ACTIONS(3979),
    [anon_sym_public] = ACTIONS(3979),
    [anon_sym_readonly] = ACTIONS(3979),
    [anon_sym_required] = ACTIONS(3979),
    [anon_sym_sealed] = ACTIONS(3979),
    [anon_sym_virtual] = ACTIONS(3979),
    [anon_sym_volatile] = ACTIONS(3979),
    [anon_sym_where] = ACTIONS(3979),
    [anon_sym_notnull] = ACTIONS(3979),
    [anon_sym_unmanaged] = ACTIONS(3979),
    [anon_sym_TILDE] = ACTIONS(3981),
    [anon_sym_implicit] = ACTIONS(3979),
    [anon_sym_explicit] = ACTIONS(3979),
    [anon_sym_scoped] = ACTIONS(3979),
    [anon_sym_var] = ACTIONS(3979),
    [sym_predefined_type] = ACTIONS(3979),
    [anon_sym_yield] = ACTIONS(3979),
    [anon_sym_when] = ACTIONS(3979),
    [anon_sym_from] = ACTIONS(3979),
    [anon_sym_into] = ACTIONS(3979),
    [anon_sym_join] = ACTIONS(3979),
    [anon_sym_on] = ACTIONS(3979),
    [anon_sym_equals] = ACTIONS(3979),
    [anon_sym_let] = ACTIONS(3979),
    [anon_sym_orderby] = ACTIONS(3979),
    [anon_sym_ascending] = ACTIONS(3979),
    [anon_sym_descending] = ACTIONS(3979),
    [anon_sym_group] = ACTIONS(3979),
    [anon_sym_by] = ACTIONS(3979),
    [anon_sym_select] = ACTIONS(3979),
    [aux_sym_preproc_if_token1] = ACTIONS(3981),
    [aux_sym_preproc_if_token3] = ACTIONS(3981),
    [aux_sym_preproc_else_token1] = ACTIONS(3981),
    [aux_sym_preproc_elif_token1] = ACTIONS(3981),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3497] = {
    [sym_preproc_region] = STATE(3497),
    [sym_preproc_endregion] = STATE(3497),
    [sym_preproc_line] = STATE(3497),
    [sym_preproc_pragma] = STATE(3497),
    [sym_preproc_nullable] = STATE(3497),
    [sym_preproc_error] = STATE(3497),
    [sym_preproc_warning] = STATE(3497),
    [sym_preproc_define] = STATE(3497),
    [sym_preproc_undef] = STATE(3497),
    [sym__identifier_token] = ACTIONS(3661),
    [anon_sym_extern] = ACTIONS(3661),
    [anon_sym_alias] = ACTIONS(3661),
    [anon_sym_global] = ACTIONS(3661),
    [anon_sym_using] = ACTIONS(3661),
    [anon_sym_unsafe] = ACTIONS(3661),
    [anon_sym_static] = ACTIONS(3661),
    [anon_sym_LBRACK] = ACTIONS(3663),
    [anon_sym_LPAREN] = ACTIONS(3663),
    [anon_sym_event] = ACTIONS(3661),
    [anon_sym_namespace] = ACTIONS(3661),
    [anon_sym_class] = ACTIONS(3661),
    [anon_sym_ref] = ACTIONS(3661),
    [anon_sym_struct] = ACTIONS(3661),
    [anon_sym_enum] = ACTIONS(3661),
    [anon_sym_RBRACE] = ACTIONS(3663),
    [anon_sym_interface] = ACTIONS(3661),
    [anon_sym_delegate] = ACTIONS(3661),
    [anon_sym_record] = ACTIONS(3661),
    [anon_sym_abstract] = ACTIONS(3661),
    [anon_sym_async] = ACTIONS(3661),
    [anon_sym_const] = ACTIONS(3661),
    [anon_sym_file] = ACTIONS(3661),
    [anon_sym_fixed] = ACTIONS(3661),
    [anon_sym_internal] = ACTIONS(3661),
    [anon_sym_new] = ACTIONS(3661),
    [anon_sym_override] = ACTIONS(3661),
    [anon_sym_partial] = ACTIONS(3661),
    [anon_sym_private] = ACTIONS(3661),
    [anon_sym_protected] = ACTIONS(3661),
    [anon_sym_public] = ACTIONS(3661),
    [anon_sym_readonly] = ACTIONS(3661),
    [anon_sym_required] = ACTIONS(3661),
    [anon_sym_sealed] = ACTIONS(3661),
    [anon_sym_virtual] = ACTIONS(3661),
    [anon_sym_volatile] = ACTIONS(3661),
    [anon_sym_where] = ACTIONS(3661),
    [anon_sym_notnull] = ACTIONS(3661),
    [anon_sym_unmanaged] = ACTIONS(3661),
    [anon_sym_TILDE] = ACTIONS(3663),
    [anon_sym_implicit] = ACTIONS(3661),
    [anon_sym_explicit] = ACTIONS(3661),
    [anon_sym_scoped] = ACTIONS(3661),
    [anon_sym_var] = ACTIONS(3661),
    [sym_predefined_type] = ACTIONS(3661),
    [anon_sym_yield] = ACTIONS(3661),
    [anon_sym_when] = ACTIONS(3661),
    [anon_sym_from] = ACTIONS(3661),
    [anon_sym_into] = ACTIONS(3661),
    [anon_sym_join] = ACTIONS(3661),
    [anon_sym_on] = ACTIONS(3661),
    [anon_sym_equals] = ACTIONS(3661),
    [anon_sym_let] = ACTIONS(3661),
    [anon_sym_orderby] = ACTIONS(3661),
    [anon_sym_ascending] = ACTIONS(3661),
    [anon_sym_descending] = ACTIONS(3661),
    [anon_sym_group] = ACTIONS(3661),
    [anon_sym_by] = ACTIONS(3661),
    [anon_sym_select] = ACTIONS(3661),
    [aux_sym_preproc_if_token1] = ACTIONS(3663),
    [aux_sym_preproc_if_token3] = ACTIONS(3663),
    [aux_sym_preproc_else_token1] = ACTIONS(3663),
    [aux_sym_preproc_elif_token1] = ACTIONS(3663),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3498] = {
    [sym_preproc_region] = STATE(3498),
    [sym_preproc_endregion] = STATE(3498),
    [sym_preproc_line] = STATE(3498),
    [sym_preproc_pragma] = STATE(3498),
    [sym_preproc_nullable] = STATE(3498),
    [sym_preproc_error] = STATE(3498),
    [sym_preproc_warning] = STATE(3498),
    [sym_preproc_define] = STATE(3498),
    [sym_preproc_undef] = STATE(3498),
    [sym__identifier_token] = ACTIONS(3409),
    [anon_sym_extern] = ACTIONS(3409),
    [anon_sym_alias] = ACTIONS(3409),
    [anon_sym_global] = ACTIONS(3409),
    [anon_sym_using] = ACTIONS(3409),
    [anon_sym_unsafe] = ACTIONS(3409),
    [anon_sym_static] = ACTIONS(3409),
    [anon_sym_LBRACK] = ACTIONS(3411),
    [anon_sym_LPAREN] = ACTIONS(3411),
    [anon_sym_event] = ACTIONS(3409),
    [anon_sym_namespace] = ACTIONS(3409),
    [anon_sym_class] = ACTIONS(3409),
    [anon_sym_ref] = ACTIONS(3409),
    [anon_sym_struct] = ACTIONS(3409),
    [anon_sym_enum] = ACTIONS(3409),
    [anon_sym_RBRACE] = ACTIONS(3411),
    [anon_sym_interface] = ACTIONS(3409),
    [anon_sym_delegate] = ACTIONS(3409),
    [anon_sym_record] = ACTIONS(3409),
    [anon_sym_abstract] = ACTIONS(3409),
    [anon_sym_async] = ACTIONS(3409),
    [anon_sym_const] = ACTIONS(3409),
    [anon_sym_file] = ACTIONS(3409),
    [anon_sym_fixed] = ACTIONS(3409),
    [anon_sym_internal] = ACTIONS(3409),
    [anon_sym_new] = ACTIONS(3409),
    [anon_sym_override] = ACTIONS(3409),
    [anon_sym_partial] = ACTIONS(3409),
    [anon_sym_private] = ACTIONS(3409),
    [anon_sym_protected] = ACTIONS(3409),
    [anon_sym_public] = ACTIONS(3409),
    [anon_sym_readonly] = ACTIONS(3409),
    [anon_sym_required] = ACTIONS(3409),
    [anon_sym_sealed] = ACTIONS(3409),
    [anon_sym_virtual] = ACTIONS(3409),
    [anon_sym_volatile] = ACTIONS(3409),
    [anon_sym_where] = ACTIONS(3409),
    [anon_sym_notnull] = ACTIONS(3409),
    [anon_sym_unmanaged] = ACTIONS(3409),
    [anon_sym_TILDE] = ACTIONS(3411),
    [anon_sym_implicit] = ACTIONS(3409),
    [anon_sym_explicit] = ACTIONS(3409),
    [anon_sym_scoped] = ACTIONS(3409),
    [anon_sym_var] = ACTIONS(3409),
    [sym_predefined_type] = ACTIONS(3409),
    [anon_sym_yield] = ACTIONS(3409),
    [anon_sym_when] = ACTIONS(3409),
    [anon_sym_from] = ACTIONS(3409),
    [anon_sym_into] = ACTIONS(3409),
    [anon_sym_join] = ACTIONS(3409),
    [anon_sym_on] = ACTIONS(3409),
    [anon_sym_equals] = ACTIONS(3409),
    [anon_sym_let] = ACTIONS(3409),
    [anon_sym_orderby] = ACTIONS(3409),
    [anon_sym_ascending] = ACTIONS(3409),
    [anon_sym_descending] = ACTIONS(3409),
    [anon_sym_group] = ACTIONS(3409),
    [anon_sym_by] = ACTIONS(3409),
    [anon_sym_select] = ACTIONS(3409),
    [aux_sym_preproc_if_token1] = ACTIONS(3411),
    [aux_sym_preproc_if_token3] = ACTIONS(3411),
    [aux_sym_preproc_else_token1] = ACTIONS(3411),
    [aux_sym_preproc_elif_token1] = ACTIONS(3411),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3499] = {
    [sym_preproc_region] = STATE(3499),
    [sym_preproc_endregion] = STATE(3499),
    [sym_preproc_line] = STATE(3499),
    [sym_preproc_pragma] = STATE(3499),
    [sym_preproc_nullable] = STATE(3499),
    [sym_preproc_error] = STATE(3499),
    [sym_preproc_warning] = STATE(3499),
    [sym_preproc_define] = STATE(3499),
    [sym_preproc_undef] = STATE(3499),
    [sym__identifier_token] = ACTIONS(4492),
    [anon_sym_alias] = ACTIONS(4492),
    [anon_sym_global] = ACTIONS(4492),
    [anon_sym_LBRACK] = ACTIONS(4593),
    [anon_sym_COLON] = ACTIONS(4494),
    [anon_sym_COMMA] = ACTIONS(4494),
    [anon_sym_LPAREN] = ACTIONS(4494),
    [anon_sym_LBRACE] = ACTIONS(4494),
    [anon_sym_file] = ACTIONS(4492),
    [anon_sym_LT] = ACTIONS(4492),
    [anon_sym_GT] = ACTIONS(4492),
    [anon_sym_where] = ACTIONS(4492),
    [anon_sym_QMARK] = ACTIONS(4970),
    [anon_sym_notnull] = ACTIONS(4492),
    [anon_sym_unmanaged] = ACTIONS(4492),
    [anon_sym_BANG] = ACTIONS(4492),
    [anon_sym_PLUS_PLUS] = ACTIONS(4494),
    [anon_sym_DASH_DASH] = ACTIONS(4494),
    [anon_sym_PLUS] = ACTIONS(4492),
    [anon_sym_DASH] = ACTIONS(4492),
    [anon_sym_STAR] = ACTIONS(4599),
    [anon_sym_SLASH] = ACTIONS(4492),
    [anon_sym_PERCENT] = ACTIONS(4494),
    [anon_sym_CARET] = ACTIONS(4494),
    [anon_sym_PIPE] = ACTIONS(4492),
    [anon_sym_AMP] = ACTIONS(4492),
    [anon_sym_LT_LT] = ACTIONS(4494),
    [anon_sym_GT_GT] = ACTIONS(4492),
    [anon_sym_GT_GT_GT] = ACTIONS(4494),
    [anon_sym_EQ_EQ] = ACTIONS(4494),
    [anon_sym_BANG_EQ] = ACTIONS(4494),
    [anon_sym_GT_EQ] = ACTIONS(4494),
    [anon_sym_LT_EQ] = ACTIONS(4494),
    [anon_sym_DOT] = ACTIONS(5073),
    [anon_sym_scoped] = ACTIONS(4492),
    [anon_sym_var] = ACTIONS(4492),
    [anon_sym_yield] = ACTIONS(4492),
    [anon_sym_switch] = ACTIONS(4492),
    [anon_sym_when] = ACTIONS(4492),
    [sym_discard] = ACTIONS(4492),
    [anon_sym_DOT_DOT] = ACTIONS(4494),
    [anon_sym_and] = ACTIONS(4492),
    [anon_sym_or] = ACTIONS(4492),
    [anon_sym_AMP_AMP] = ACTIONS(4494),
    [anon_sym_PIPE_PIPE] = ACTIONS(4494),
    [anon_sym_QMARK_QMARK] = ACTIONS(4494),
    [anon_sym_from] = ACTIONS(4492),
    [anon_sym_into] = ACTIONS(4492),
    [anon_sym_join] = ACTIONS(4492),
    [anon_sym_on] = ACTIONS(4492),
    [anon_sym_equals] = ACTIONS(4492),
    [anon_sym_let] = ACTIONS(4492),
    [anon_sym_orderby] = ACTIONS(4492),
    [anon_sym_ascending] = ACTIONS(4492),
    [anon_sym_descending] = ACTIONS(4492),
    [anon_sym_group] = ACTIONS(4492),
    [anon_sym_by] = ACTIONS(4492),
    [anon_sym_select] = ACTIONS(4492),
    [anon_sym_as] = ACTIONS(4492),
    [anon_sym_is] = ACTIONS(4492),
    [anon_sym_DASH_GT] = ACTIONS(4494),
    [anon_sym_with] = ACTIONS(4492),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4494),
  },
  [3500] = {
    [sym_preproc_region] = STATE(3500),
    [sym_preproc_endregion] = STATE(3500),
    [sym_preproc_line] = STATE(3500),
    [sym_preproc_pragma] = STATE(3500),
    [sym_preproc_nullable] = STATE(3500),
    [sym_preproc_error] = STATE(3500),
    [sym_preproc_warning] = STATE(3500),
    [sym_preproc_define] = STATE(3500),
    [sym_preproc_undef] = STATE(3500),
    [anon_sym_SEMI] = ACTIONS(4699),
    [anon_sym_EQ] = ACTIONS(4701),
    [anon_sym_LBRACK] = ACTIONS(4699),
    [anon_sym_COLON] = ACTIONS(4699),
    [anon_sym_COMMA] = ACTIONS(4699),
    [anon_sym_RBRACK] = ACTIONS(4699),
    [anon_sym_LPAREN] = ACTIONS(4699),
    [anon_sym_RPAREN] = ACTIONS(4699),
    [anon_sym_RBRACE] = ACTIONS(4699),
    [anon_sym_LT] = ACTIONS(4701),
    [anon_sym_GT] = ACTIONS(4701),
    [anon_sym_in] = ACTIONS(4699),
    [anon_sym_QMARK] = ACTIONS(4701),
    [anon_sym_BANG] = ACTIONS(4701),
    [anon_sym_PLUS_PLUS] = ACTIONS(4699),
    [anon_sym_DASH_DASH] = ACTIONS(4699),
    [anon_sym_PLUS] = ACTIONS(4701),
    [anon_sym_DASH] = ACTIONS(4701),
    [anon_sym_STAR] = ACTIONS(4701),
    [anon_sym_SLASH] = ACTIONS(4701),
    [anon_sym_PERCENT] = ACTIONS(4701),
    [anon_sym_CARET] = ACTIONS(4701),
    [anon_sym_PIPE] = ACTIONS(4701),
    [anon_sym_AMP] = ACTIONS(4701),
    [anon_sym_LT_LT] = ACTIONS(4701),
    [anon_sym_GT_GT] = ACTIONS(4701),
    [anon_sym_GT_GT_GT] = ACTIONS(4701),
    [anon_sym_EQ_EQ] = ACTIONS(4699),
    [anon_sym_BANG_EQ] = ACTIONS(4699),
    [anon_sym_GT_EQ] = ACTIONS(4699),
    [anon_sym_LT_EQ] = ACTIONS(4699),
    [anon_sym_DOT] = ACTIONS(4701),
    [anon_sym_EQ_GT] = ACTIONS(4699),
    [anon_sym_switch] = ACTIONS(4699),
    [anon_sym_when] = ACTIONS(4699),
    [anon_sym_DOT_DOT] = ACTIONS(4699),
    [anon_sym_and] = ACTIONS(4699),
    [anon_sym_or] = ACTIONS(4699),
    [anon_sym_PLUS_EQ] = ACTIONS(4699),
    [anon_sym_DASH_EQ] = ACTIONS(4699),
    [anon_sym_STAR_EQ] = ACTIONS(4699),
    [anon_sym_SLASH_EQ] = ACTIONS(4699),
    [anon_sym_PERCENT_EQ] = ACTIONS(4699),
    [anon_sym_AMP_EQ] = ACTIONS(4699),
    [anon_sym_CARET_EQ] = ACTIONS(4699),
    [anon_sym_PIPE_EQ] = ACTIONS(4699),
    [anon_sym_LT_LT_EQ] = ACTIONS(4699),
    [anon_sym_GT_GT_EQ] = ACTIONS(4699),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4699),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4699),
    [anon_sym_AMP_AMP] = ACTIONS(4699),
    [anon_sym_PIPE_PIPE] = ACTIONS(4699),
    [anon_sym_QMARK_QMARK] = ACTIONS(4701),
    [anon_sym_on] = ACTIONS(4699),
    [anon_sym_equals] = ACTIONS(4699),
    [anon_sym_by] = ACTIONS(4699),
    [anon_sym_as] = ACTIONS(4699),
    [anon_sym_is] = ACTIONS(4699),
    [anon_sym_DASH_GT] = ACTIONS(4699),
    [anon_sym_with] = ACTIONS(4699),
    [aux_sym_preproc_if_token3] = ACTIONS(4699),
    [aux_sym_preproc_else_token1] = ACTIONS(4699),
    [aux_sym_preproc_elif_token1] = ACTIONS(4699),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3501] = {
    [sym_preproc_region] = STATE(3501),
    [sym_preproc_endregion] = STATE(3501),
    [sym_preproc_line] = STATE(3501),
    [sym_preproc_pragma] = STATE(3501),
    [sym_preproc_nullable] = STATE(3501),
    [sym_preproc_error] = STATE(3501),
    [sym_preproc_warning] = STATE(3501),
    [sym_preproc_define] = STATE(3501),
    [sym_preproc_undef] = STATE(3501),
    [sym__identifier_token] = ACTIONS(4548),
    [anon_sym_alias] = ACTIONS(4548),
    [anon_sym_global] = ACTIONS(4548),
    [anon_sym_LBRACK] = ACTIONS(4550),
    [anon_sym_COLON] = ACTIONS(4550),
    [anon_sym_COMMA] = ACTIONS(4550),
    [anon_sym_LPAREN] = ACTIONS(4550),
    [anon_sym_LBRACE] = ACTIONS(4550),
    [anon_sym_file] = ACTIONS(4548),
    [anon_sym_LT] = ACTIONS(4548),
    [anon_sym_GT] = ACTIONS(4548),
    [anon_sym_where] = ACTIONS(4548),
    [anon_sym_QMARK] = ACTIONS(4548),
    [anon_sym_notnull] = ACTIONS(4548),
    [anon_sym_unmanaged] = ACTIONS(4548),
    [anon_sym_BANG] = ACTIONS(4548),
    [anon_sym_PLUS_PLUS] = ACTIONS(4550),
    [anon_sym_DASH_DASH] = ACTIONS(4550),
    [anon_sym_PLUS] = ACTIONS(4548),
    [anon_sym_DASH] = ACTIONS(4548),
    [anon_sym_STAR] = ACTIONS(4550),
    [anon_sym_SLASH] = ACTIONS(4548),
    [anon_sym_PERCENT] = ACTIONS(4550),
    [anon_sym_CARET] = ACTIONS(4550),
    [anon_sym_PIPE] = ACTIONS(4548),
    [anon_sym_AMP] = ACTIONS(4548),
    [anon_sym_LT_LT] = ACTIONS(4550),
    [anon_sym_GT_GT] = ACTIONS(4548),
    [anon_sym_GT_GT_GT] = ACTIONS(4550),
    [anon_sym_EQ_EQ] = ACTIONS(4550),
    [anon_sym_BANG_EQ] = ACTIONS(4550),
    [anon_sym_GT_EQ] = ACTIONS(4550),
    [anon_sym_LT_EQ] = ACTIONS(4550),
    [anon_sym_DOT] = ACTIONS(4548),
    [anon_sym_scoped] = ACTIONS(4548),
    [anon_sym_var] = ACTIONS(4548),
    [anon_sym_yield] = ACTIONS(4548),
    [anon_sym_switch] = ACTIONS(4548),
    [anon_sym_when] = ACTIONS(4548),
    [sym_discard] = ACTIONS(4548),
    [anon_sym_DOT_DOT] = ACTIONS(4550),
    [anon_sym_and] = ACTIONS(4548),
    [anon_sym_or] = ACTIONS(4548),
    [anon_sym_AMP_AMP] = ACTIONS(4550),
    [anon_sym_PIPE_PIPE] = ACTIONS(4550),
    [anon_sym_QMARK_QMARK] = ACTIONS(4550),
    [anon_sym_from] = ACTIONS(4548),
    [anon_sym_into] = ACTIONS(4548),
    [anon_sym_join] = ACTIONS(4548),
    [anon_sym_on] = ACTIONS(4548),
    [anon_sym_equals] = ACTIONS(4548),
    [anon_sym_let] = ACTIONS(4548),
    [anon_sym_orderby] = ACTIONS(4548),
    [anon_sym_ascending] = ACTIONS(4548),
    [anon_sym_descending] = ACTIONS(4548),
    [anon_sym_group] = ACTIONS(4548),
    [anon_sym_by] = ACTIONS(4548),
    [anon_sym_select] = ACTIONS(4548),
    [anon_sym_as] = ACTIONS(4548),
    [anon_sym_is] = ACTIONS(4548),
    [anon_sym_DASH_GT] = ACTIONS(4550),
    [anon_sym_with] = ACTIONS(4548),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4550),
  },
  [3502] = {
    [sym_preproc_region] = STATE(3502),
    [sym_preproc_endregion] = STATE(3502),
    [sym_preproc_line] = STATE(3502),
    [sym_preproc_pragma] = STATE(3502),
    [sym_preproc_nullable] = STATE(3502),
    [sym_preproc_error] = STATE(3502),
    [sym_preproc_warning] = STATE(3502),
    [sym_preproc_define] = STATE(3502),
    [sym_preproc_undef] = STATE(3502),
    [sym__identifier_token] = ACTIONS(3533),
    [anon_sym_extern] = ACTIONS(3533),
    [anon_sym_alias] = ACTIONS(3533),
    [anon_sym_global] = ACTIONS(3533),
    [anon_sym_using] = ACTIONS(3533),
    [anon_sym_unsafe] = ACTIONS(3533),
    [anon_sym_static] = ACTIONS(3533),
    [anon_sym_LBRACK] = ACTIONS(3535),
    [anon_sym_LPAREN] = ACTIONS(3535),
    [anon_sym_event] = ACTIONS(3533),
    [anon_sym_namespace] = ACTIONS(3533),
    [anon_sym_class] = ACTIONS(3533),
    [anon_sym_ref] = ACTIONS(3533),
    [anon_sym_struct] = ACTIONS(3533),
    [anon_sym_enum] = ACTIONS(3533),
    [anon_sym_RBRACE] = ACTIONS(3535),
    [anon_sym_interface] = ACTIONS(3533),
    [anon_sym_delegate] = ACTIONS(3533),
    [anon_sym_record] = ACTIONS(3533),
    [anon_sym_abstract] = ACTIONS(3533),
    [anon_sym_async] = ACTIONS(3533),
    [anon_sym_const] = ACTIONS(3533),
    [anon_sym_file] = ACTIONS(3533),
    [anon_sym_fixed] = ACTIONS(3533),
    [anon_sym_internal] = ACTIONS(3533),
    [anon_sym_new] = ACTIONS(3533),
    [anon_sym_override] = ACTIONS(3533),
    [anon_sym_partial] = ACTIONS(3533),
    [anon_sym_private] = ACTIONS(3533),
    [anon_sym_protected] = ACTIONS(3533),
    [anon_sym_public] = ACTIONS(3533),
    [anon_sym_readonly] = ACTIONS(3533),
    [anon_sym_required] = ACTIONS(3533),
    [anon_sym_sealed] = ACTIONS(3533),
    [anon_sym_virtual] = ACTIONS(3533),
    [anon_sym_volatile] = ACTIONS(3533),
    [anon_sym_where] = ACTIONS(3533),
    [anon_sym_notnull] = ACTIONS(3533),
    [anon_sym_unmanaged] = ACTIONS(3533),
    [anon_sym_TILDE] = ACTIONS(3535),
    [anon_sym_implicit] = ACTIONS(3533),
    [anon_sym_explicit] = ACTIONS(3533),
    [anon_sym_scoped] = ACTIONS(3533),
    [anon_sym_var] = ACTIONS(3533),
    [sym_predefined_type] = ACTIONS(3533),
    [anon_sym_yield] = ACTIONS(3533),
    [anon_sym_when] = ACTIONS(3533),
    [anon_sym_from] = ACTIONS(3533),
    [anon_sym_into] = ACTIONS(3533),
    [anon_sym_join] = ACTIONS(3533),
    [anon_sym_on] = ACTIONS(3533),
    [anon_sym_equals] = ACTIONS(3533),
    [anon_sym_let] = ACTIONS(3533),
    [anon_sym_orderby] = ACTIONS(3533),
    [anon_sym_ascending] = ACTIONS(3533),
    [anon_sym_descending] = ACTIONS(3533),
    [anon_sym_group] = ACTIONS(3533),
    [anon_sym_by] = ACTIONS(3533),
    [anon_sym_select] = ACTIONS(3533),
    [aux_sym_preproc_if_token1] = ACTIONS(3535),
    [aux_sym_preproc_if_token3] = ACTIONS(3535),
    [aux_sym_preproc_else_token1] = ACTIONS(3535),
    [aux_sym_preproc_elif_token1] = ACTIONS(3535),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3503] = {
    [sym_preproc_region] = STATE(3503),
    [sym_preproc_endregion] = STATE(3503),
    [sym_preproc_line] = STATE(3503),
    [sym_preproc_pragma] = STATE(3503),
    [sym_preproc_nullable] = STATE(3503),
    [sym_preproc_error] = STATE(3503),
    [sym_preproc_warning] = STATE(3503),
    [sym_preproc_define] = STATE(3503),
    [sym_preproc_undef] = STATE(3503),
    [sym__identifier_token] = ACTIONS(3713),
    [anon_sym_extern] = ACTIONS(3713),
    [anon_sym_alias] = ACTIONS(3713),
    [anon_sym_global] = ACTIONS(3713),
    [anon_sym_using] = ACTIONS(3713),
    [anon_sym_unsafe] = ACTIONS(3713),
    [anon_sym_static] = ACTIONS(3713),
    [anon_sym_LBRACK] = ACTIONS(3715),
    [anon_sym_LPAREN] = ACTIONS(3715),
    [anon_sym_event] = ACTIONS(3713),
    [anon_sym_namespace] = ACTIONS(3713),
    [anon_sym_class] = ACTIONS(3713),
    [anon_sym_ref] = ACTIONS(3713),
    [anon_sym_struct] = ACTIONS(3713),
    [anon_sym_enum] = ACTIONS(3713),
    [anon_sym_RBRACE] = ACTIONS(3715),
    [anon_sym_interface] = ACTIONS(3713),
    [anon_sym_delegate] = ACTIONS(3713),
    [anon_sym_record] = ACTIONS(3713),
    [anon_sym_abstract] = ACTIONS(3713),
    [anon_sym_async] = ACTIONS(3713),
    [anon_sym_const] = ACTIONS(3713),
    [anon_sym_file] = ACTIONS(3713),
    [anon_sym_fixed] = ACTIONS(3713),
    [anon_sym_internal] = ACTIONS(3713),
    [anon_sym_new] = ACTIONS(3713),
    [anon_sym_override] = ACTIONS(3713),
    [anon_sym_partial] = ACTIONS(3713),
    [anon_sym_private] = ACTIONS(3713),
    [anon_sym_protected] = ACTIONS(3713),
    [anon_sym_public] = ACTIONS(3713),
    [anon_sym_readonly] = ACTIONS(3713),
    [anon_sym_required] = ACTIONS(3713),
    [anon_sym_sealed] = ACTIONS(3713),
    [anon_sym_virtual] = ACTIONS(3713),
    [anon_sym_volatile] = ACTIONS(3713),
    [anon_sym_where] = ACTIONS(3713),
    [anon_sym_notnull] = ACTIONS(3713),
    [anon_sym_unmanaged] = ACTIONS(3713),
    [anon_sym_TILDE] = ACTIONS(3715),
    [anon_sym_implicit] = ACTIONS(3713),
    [anon_sym_explicit] = ACTIONS(3713),
    [anon_sym_scoped] = ACTIONS(3713),
    [anon_sym_var] = ACTIONS(3713),
    [sym_predefined_type] = ACTIONS(3713),
    [anon_sym_yield] = ACTIONS(3713),
    [anon_sym_when] = ACTIONS(3713),
    [anon_sym_from] = ACTIONS(3713),
    [anon_sym_into] = ACTIONS(3713),
    [anon_sym_join] = ACTIONS(3713),
    [anon_sym_on] = ACTIONS(3713),
    [anon_sym_equals] = ACTIONS(3713),
    [anon_sym_let] = ACTIONS(3713),
    [anon_sym_orderby] = ACTIONS(3713),
    [anon_sym_ascending] = ACTIONS(3713),
    [anon_sym_descending] = ACTIONS(3713),
    [anon_sym_group] = ACTIONS(3713),
    [anon_sym_by] = ACTIONS(3713),
    [anon_sym_select] = ACTIONS(3713),
    [aux_sym_preproc_if_token1] = ACTIONS(3715),
    [aux_sym_preproc_if_token3] = ACTIONS(3715),
    [aux_sym_preproc_else_token1] = ACTIONS(3715),
    [aux_sym_preproc_elif_token1] = ACTIONS(3715),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3504] = {
    [sym_preproc_region] = STATE(3504),
    [sym_preproc_endregion] = STATE(3504),
    [sym_preproc_line] = STATE(3504),
    [sym_preproc_pragma] = STATE(3504),
    [sym_preproc_nullable] = STATE(3504),
    [sym_preproc_error] = STATE(3504),
    [sym_preproc_warning] = STATE(3504),
    [sym_preproc_define] = STATE(3504),
    [sym_preproc_undef] = STATE(3504),
    [sym__identifier_token] = ACTIONS(3417),
    [anon_sym_extern] = ACTIONS(3417),
    [anon_sym_alias] = ACTIONS(3417),
    [anon_sym_global] = ACTIONS(3417),
    [anon_sym_using] = ACTIONS(3417),
    [anon_sym_unsafe] = ACTIONS(3417),
    [anon_sym_static] = ACTIONS(3417),
    [anon_sym_LBRACK] = ACTIONS(3419),
    [anon_sym_LPAREN] = ACTIONS(3419),
    [anon_sym_event] = ACTIONS(3417),
    [anon_sym_namespace] = ACTIONS(3417),
    [anon_sym_class] = ACTIONS(3417),
    [anon_sym_ref] = ACTIONS(3417),
    [anon_sym_struct] = ACTIONS(3417),
    [anon_sym_enum] = ACTIONS(3417),
    [anon_sym_RBRACE] = ACTIONS(3419),
    [anon_sym_interface] = ACTIONS(3417),
    [anon_sym_delegate] = ACTIONS(3417),
    [anon_sym_record] = ACTIONS(3417),
    [anon_sym_abstract] = ACTIONS(3417),
    [anon_sym_async] = ACTIONS(3417),
    [anon_sym_const] = ACTIONS(3417),
    [anon_sym_file] = ACTIONS(3417),
    [anon_sym_fixed] = ACTIONS(3417),
    [anon_sym_internal] = ACTIONS(3417),
    [anon_sym_new] = ACTIONS(3417),
    [anon_sym_override] = ACTIONS(3417),
    [anon_sym_partial] = ACTIONS(3417),
    [anon_sym_private] = ACTIONS(3417),
    [anon_sym_protected] = ACTIONS(3417),
    [anon_sym_public] = ACTIONS(3417),
    [anon_sym_readonly] = ACTIONS(3417),
    [anon_sym_required] = ACTIONS(3417),
    [anon_sym_sealed] = ACTIONS(3417),
    [anon_sym_virtual] = ACTIONS(3417),
    [anon_sym_volatile] = ACTIONS(3417),
    [anon_sym_where] = ACTIONS(3417),
    [anon_sym_notnull] = ACTIONS(3417),
    [anon_sym_unmanaged] = ACTIONS(3417),
    [anon_sym_TILDE] = ACTIONS(3419),
    [anon_sym_implicit] = ACTIONS(3417),
    [anon_sym_explicit] = ACTIONS(3417),
    [anon_sym_scoped] = ACTIONS(3417),
    [anon_sym_var] = ACTIONS(3417),
    [sym_predefined_type] = ACTIONS(3417),
    [anon_sym_yield] = ACTIONS(3417),
    [anon_sym_when] = ACTIONS(3417),
    [anon_sym_from] = ACTIONS(3417),
    [anon_sym_into] = ACTIONS(3417),
    [anon_sym_join] = ACTIONS(3417),
    [anon_sym_on] = ACTIONS(3417),
    [anon_sym_equals] = ACTIONS(3417),
    [anon_sym_let] = ACTIONS(3417),
    [anon_sym_orderby] = ACTIONS(3417),
    [anon_sym_ascending] = ACTIONS(3417),
    [anon_sym_descending] = ACTIONS(3417),
    [anon_sym_group] = ACTIONS(3417),
    [anon_sym_by] = ACTIONS(3417),
    [anon_sym_select] = ACTIONS(3417),
    [aux_sym_preproc_if_token1] = ACTIONS(3419),
    [aux_sym_preproc_if_token3] = ACTIONS(3419),
    [aux_sym_preproc_else_token1] = ACTIONS(3419),
    [aux_sym_preproc_elif_token1] = ACTIONS(3419),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3505] = {
    [sym_preproc_region] = STATE(3505),
    [sym_preproc_endregion] = STATE(3505),
    [sym_preproc_line] = STATE(3505),
    [sym_preproc_pragma] = STATE(3505),
    [sym_preproc_nullable] = STATE(3505),
    [sym_preproc_error] = STATE(3505),
    [sym_preproc_warning] = STATE(3505),
    [sym_preproc_define] = STATE(3505),
    [sym_preproc_undef] = STATE(3505),
    [sym__identifier_token] = ACTIONS(3717),
    [anon_sym_extern] = ACTIONS(3717),
    [anon_sym_alias] = ACTIONS(3717),
    [anon_sym_global] = ACTIONS(3717),
    [anon_sym_using] = ACTIONS(3717),
    [anon_sym_unsafe] = ACTIONS(3717),
    [anon_sym_static] = ACTIONS(3717),
    [anon_sym_LBRACK] = ACTIONS(3719),
    [anon_sym_LPAREN] = ACTIONS(3719),
    [anon_sym_event] = ACTIONS(3717),
    [anon_sym_namespace] = ACTIONS(3717),
    [anon_sym_class] = ACTIONS(3717),
    [anon_sym_ref] = ACTIONS(3717),
    [anon_sym_struct] = ACTIONS(3717),
    [anon_sym_enum] = ACTIONS(3717),
    [anon_sym_RBRACE] = ACTIONS(3719),
    [anon_sym_interface] = ACTIONS(3717),
    [anon_sym_delegate] = ACTIONS(3717),
    [anon_sym_record] = ACTIONS(3717),
    [anon_sym_abstract] = ACTIONS(3717),
    [anon_sym_async] = ACTIONS(3717),
    [anon_sym_const] = ACTIONS(3717),
    [anon_sym_file] = ACTIONS(3717),
    [anon_sym_fixed] = ACTIONS(3717),
    [anon_sym_internal] = ACTIONS(3717),
    [anon_sym_new] = ACTIONS(3717),
    [anon_sym_override] = ACTIONS(3717),
    [anon_sym_partial] = ACTIONS(3717),
    [anon_sym_private] = ACTIONS(3717),
    [anon_sym_protected] = ACTIONS(3717),
    [anon_sym_public] = ACTIONS(3717),
    [anon_sym_readonly] = ACTIONS(3717),
    [anon_sym_required] = ACTIONS(3717),
    [anon_sym_sealed] = ACTIONS(3717),
    [anon_sym_virtual] = ACTIONS(3717),
    [anon_sym_volatile] = ACTIONS(3717),
    [anon_sym_where] = ACTIONS(3717),
    [anon_sym_notnull] = ACTIONS(3717),
    [anon_sym_unmanaged] = ACTIONS(3717),
    [anon_sym_TILDE] = ACTIONS(3719),
    [anon_sym_implicit] = ACTIONS(3717),
    [anon_sym_explicit] = ACTIONS(3717),
    [anon_sym_scoped] = ACTIONS(3717),
    [anon_sym_var] = ACTIONS(3717),
    [sym_predefined_type] = ACTIONS(3717),
    [anon_sym_yield] = ACTIONS(3717),
    [anon_sym_when] = ACTIONS(3717),
    [anon_sym_from] = ACTIONS(3717),
    [anon_sym_into] = ACTIONS(3717),
    [anon_sym_join] = ACTIONS(3717),
    [anon_sym_on] = ACTIONS(3717),
    [anon_sym_equals] = ACTIONS(3717),
    [anon_sym_let] = ACTIONS(3717),
    [anon_sym_orderby] = ACTIONS(3717),
    [anon_sym_ascending] = ACTIONS(3717),
    [anon_sym_descending] = ACTIONS(3717),
    [anon_sym_group] = ACTIONS(3717),
    [anon_sym_by] = ACTIONS(3717),
    [anon_sym_select] = ACTIONS(3717),
    [aux_sym_preproc_if_token1] = ACTIONS(3719),
    [aux_sym_preproc_if_token3] = ACTIONS(3719),
    [aux_sym_preproc_else_token1] = ACTIONS(3719),
    [aux_sym_preproc_elif_token1] = ACTIONS(3719),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3506] = {
    [sym_preproc_region] = STATE(3506),
    [sym_preproc_endregion] = STATE(3506),
    [sym_preproc_line] = STATE(3506),
    [sym_preproc_pragma] = STATE(3506),
    [sym_preproc_nullable] = STATE(3506),
    [sym_preproc_error] = STATE(3506),
    [sym_preproc_warning] = STATE(3506),
    [sym_preproc_define] = STATE(3506),
    [sym_preproc_undef] = STATE(3506),
    [sym__identifier_token] = ACTIONS(3421),
    [anon_sym_extern] = ACTIONS(3421),
    [anon_sym_alias] = ACTIONS(3421),
    [anon_sym_global] = ACTIONS(3421),
    [anon_sym_using] = ACTIONS(3421),
    [anon_sym_unsafe] = ACTIONS(3421),
    [anon_sym_static] = ACTIONS(3421),
    [anon_sym_LBRACK] = ACTIONS(3423),
    [anon_sym_LPAREN] = ACTIONS(3423),
    [anon_sym_event] = ACTIONS(3421),
    [anon_sym_namespace] = ACTIONS(3421),
    [anon_sym_class] = ACTIONS(3421),
    [anon_sym_ref] = ACTIONS(3421),
    [anon_sym_struct] = ACTIONS(3421),
    [anon_sym_enum] = ACTIONS(3421),
    [anon_sym_RBRACE] = ACTIONS(3423),
    [anon_sym_interface] = ACTIONS(3421),
    [anon_sym_delegate] = ACTIONS(3421),
    [anon_sym_record] = ACTIONS(3421),
    [anon_sym_abstract] = ACTIONS(3421),
    [anon_sym_async] = ACTIONS(3421),
    [anon_sym_const] = ACTIONS(3421),
    [anon_sym_file] = ACTIONS(3421),
    [anon_sym_fixed] = ACTIONS(3421),
    [anon_sym_internal] = ACTIONS(3421),
    [anon_sym_new] = ACTIONS(3421),
    [anon_sym_override] = ACTIONS(3421),
    [anon_sym_partial] = ACTIONS(3421),
    [anon_sym_private] = ACTIONS(3421),
    [anon_sym_protected] = ACTIONS(3421),
    [anon_sym_public] = ACTIONS(3421),
    [anon_sym_readonly] = ACTIONS(3421),
    [anon_sym_required] = ACTIONS(3421),
    [anon_sym_sealed] = ACTIONS(3421),
    [anon_sym_virtual] = ACTIONS(3421),
    [anon_sym_volatile] = ACTIONS(3421),
    [anon_sym_where] = ACTIONS(3421),
    [anon_sym_notnull] = ACTIONS(3421),
    [anon_sym_unmanaged] = ACTIONS(3421),
    [anon_sym_TILDE] = ACTIONS(3423),
    [anon_sym_implicit] = ACTIONS(3421),
    [anon_sym_explicit] = ACTIONS(3421),
    [anon_sym_scoped] = ACTIONS(3421),
    [anon_sym_var] = ACTIONS(3421),
    [sym_predefined_type] = ACTIONS(3421),
    [anon_sym_yield] = ACTIONS(3421),
    [anon_sym_when] = ACTIONS(3421),
    [anon_sym_from] = ACTIONS(3421),
    [anon_sym_into] = ACTIONS(3421),
    [anon_sym_join] = ACTIONS(3421),
    [anon_sym_on] = ACTIONS(3421),
    [anon_sym_equals] = ACTIONS(3421),
    [anon_sym_let] = ACTIONS(3421),
    [anon_sym_orderby] = ACTIONS(3421),
    [anon_sym_ascending] = ACTIONS(3421),
    [anon_sym_descending] = ACTIONS(3421),
    [anon_sym_group] = ACTIONS(3421),
    [anon_sym_by] = ACTIONS(3421),
    [anon_sym_select] = ACTIONS(3421),
    [aux_sym_preproc_if_token1] = ACTIONS(3423),
    [aux_sym_preproc_if_token3] = ACTIONS(3423),
    [aux_sym_preproc_else_token1] = ACTIONS(3423),
    [aux_sym_preproc_elif_token1] = ACTIONS(3423),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3507] = {
    [sym_preproc_region] = STATE(3507),
    [sym_preproc_endregion] = STATE(3507),
    [sym_preproc_line] = STATE(3507),
    [sym_preproc_pragma] = STATE(3507),
    [sym_preproc_nullable] = STATE(3507),
    [sym_preproc_error] = STATE(3507),
    [sym_preproc_warning] = STATE(3507),
    [sym_preproc_define] = STATE(3507),
    [sym_preproc_undef] = STATE(3507),
    [anon_sym_SEMI] = ACTIONS(4666),
    [anon_sym_EQ] = ACTIONS(4668),
    [anon_sym_LBRACK] = ACTIONS(4666),
    [anon_sym_COLON] = ACTIONS(4666),
    [anon_sym_COMMA] = ACTIONS(4666),
    [anon_sym_RBRACK] = ACTIONS(4666),
    [anon_sym_LPAREN] = ACTIONS(4666),
    [anon_sym_RPAREN] = ACTIONS(4666),
    [anon_sym_RBRACE] = ACTIONS(4666),
    [anon_sym_LT] = ACTIONS(4668),
    [anon_sym_GT] = ACTIONS(4668),
    [anon_sym_in] = ACTIONS(4666),
    [anon_sym_QMARK] = ACTIONS(4668),
    [anon_sym_BANG] = ACTIONS(4668),
    [anon_sym_PLUS_PLUS] = ACTIONS(4666),
    [anon_sym_DASH_DASH] = ACTIONS(4666),
    [anon_sym_PLUS] = ACTIONS(4668),
    [anon_sym_DASH] = ACTIONS(4668),
    [anon_sym_STAR] = ACTIONS(4668),
    [anon_sym_SLASH] = ACTIONS(4668),
    [anon_sym_PERCENT] = ACTIONS(4668),
    [anon_sym_CARET] = ACTIONS(4668),
    [anon_sym_PIPE] = ACTIONS(4668),
    [anon_sym_AMP] = ACTIONS(4668),
    [anon_sym_LT_LT] = ACTIONS(4668),
    [anon_sym_GT_GT] = ACTIONS(4668),
    [anon_sym_GT_GT_GT] = ACTIONS(4668),
    [anon_sym_EQ_EQ] = ACTIONS(4666),
    [anon_sym_BANG_EQ] = ACTIONS(4666),
    [anon_sym_GT_EQ] = ACTIONS(4666),
    [anon_sym_LT_EQ] = ACTIONS(4666),
    [anon_sym_DOT] = ACTIONS(4668),
    [anon_sym_EQ_GT] = ACTIONS(4666),
    [anon_sym_switch] = ACTIONS(4666),
    [anon_sym_when] = ACTIONS(4666),
    [anon_sym_DOT_DOT] = ACTIONS(4666),
    [anon_sym_and] = ACTIONS(4666),
    [anon_sym_or] = ACTIONS(4666),
    [anon_sym_PLUS_EQ] = ACTIONS(4666),
    [anon_sym_DASH_EQ] = ACTIONS(4666),
    [anon_sym_STAR_EQ] = ACTIONS(4666),
    [anon_sym_SLASH_EQ] = ACTIONS(4666),
    [anon_sym_PERCENT_EQ] = ACTIONS(4666),
    [anon_sym_AMP_EQ] = ACTIONS(4666),
    [anon_sym_CARET_EQ] = ACTIONS(4666),
    [anon_sym_PIPE_EQ] = ACTIONS(4666),
    [anon_sym_LT_LT_EQ] = ACTIONS(4666),
    [anon_sym_GT_GT_EQ] = ACTIONS(4666),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4666),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4666),
    [anon_sym_AMP_AMP] = ACTIONS(4666),
    [anon_sym_PIPE_PIPE] = ACTIONS(4666),
    [anon_sym_QMARK_QMARK] = ACTIONS(4668),
    [anon_sym_on] = ACTIONS(4666),
    [anon_sym_equals] = ACTIONS(4666),
    [anon_sym_by] = ACTIONS(4666),
    [anon_sym_as] = ACTIONS(4666),
    [anon_sym_is] = ACTIONS(4666),
    [anon_sym_DASH_GT] = ACTIONS(4666),
    [anon_sym_with] = ACTIONS(4666),
    [aux_sym_preproc_if_token3] = ACTIONS(4666),
    [aux_sym_preproc_else_token1] = ACTIONS(4666),
    [aux_sym_preproc_elif_token1] = ACTIONS(4666),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3508] = {
    [sym_preproc_region] = STATE(3508),
    [sym_preproc_endregion] = STATE(3508),
    [sym_preproc_line] = STATE(3508),
    [sym_preproc_pragma] = STATE(3508),
    [sym_preproc_nullable] = STATE(3508),
    [sym_preproc_error] = STATE(3508),
    [sym_preproc_warning] = STATE(3508),
    [sym_preproc_define] = STATE(3508),
    [sym_preproc_undef] = STATE(3508),
    [sym__identifier_token] = ACTIONS(3721),
    [anon_sym_extern] = ACTIONS(3721),
    [anon_sym_alias] = ACTIONS(3721),
    [anon_sym_global] = ACTIONS(3721),
    [anon_sym_using] = ACTIONS(3721),
    [anon_sym_unsafe] = ACTIONS(3721),
    [anon_sym_static] = ACTIONS(3721),
    [anon_sym_LBRACK] = ACTIONS(3723),
    [anon_sym_LPAREN] = ACTIONS(3723),
    [anon_sym_event] = ACTIONS(3721),
    [anon_sym_namespace] = ACTIONS(3721),
    [anon_sym_class] = ACTIONS(3721),
    [anon_sym_ref] = ACTIONS(3721),
    [anon_sym_struct] = ACTIONS(3721),
    [anon_sym_enum] = ACTIONS(3721),
    [anon_sym_RBRACE] = ACTIONS(3723),
    [anon_sym_interface] = ACTIONS(3721),
    [anon_sym_delegate] = ACTIONS(3721),
    [anon_sym_record] = ACTIONS(3721),
    [anon_sym_abstract] = ACTIONS(3721),
    [anon_sym_async] = ACTIONS(3721),
    [anon_sym_const] = ACTIONS(3721),
    [anon_sym_file] = ACTIONS(3721),
    [anon_sym_fixed] = ACTIONS(3721),
    [anon_sym_internal] = ACTIONS(3721),
    [anon_sym_new] = ACTIONS(3721),
    [anon_sym_override] = ACTIONS(3721),
    [anon_sym_partial] = ACTIONS(3721),
    [anon_sym_private] = ACTIONS(3721),
    [anon_sym_protected] = ACTIONS(3721),
    [anon_sym_public] = ACTIONS(3721),
    [anon_sym_readonly] = ACTIONS(3721),
    [anon_sym_required] = ACTIONS(3721),
    [anon_sym_sealed] = ACTIONS(3721),
    [anon_sym_virtual] = ACTIONS(3721),
    [anon_sym_volatile] = ACTIONS(3721),
    [anon_sym_where] = ACTIONS(3721),
    [anon_sym_notnull] = ACTIONS(3721),
    [anon_sym_unmanaged] = ACTIONS(3721),
    [anon_sym_TILDE] = ACTIONS(3723),
    [anon_sym_implicit] = ACTIONS(3721),
    [anon_sym_explicit] = ACTIONS(3721),
    [anon_sym_scoped] = ACTIONS(3721),
    [anon_sym_var] = ACTIONS(3721),
    [sym_predefined_type] = ACTIONS(3721),
    [anon_sym_yield] = ACTIONS(3721),
    [anon_sym_when] = ACTIONS(3721),
    [anon_sym_from] = ACTIONS(3721),
    [anon_sym_into] = ACTIONS(3721),
    [anon_sym_join] = ACTIONS(3721),
    [anon_sym_on] = ACTIONS(3721),
    [anon_sym_equals] = ACTIONS(3721),
    [anon_sym_let] = ACTIONS(3721),
    [anon_sym_orderby] = ACTIONS(3721),
    [anon_sym_ascending] = ACTIONS(3721),
    [anon_sym_descending] = ACTIONS(3721),
    [anon_sym_group] = ACTIONS(3721),
    [anon_sym_by] = ACTIONS(3721),
    [anon_sym_select] = ACTIONS(3721),
    [aux_sym_preproc_if_token1] = ACTIONS(3723),
    [aux_sym_preproc_if_token3] = ACTIONS(3723),
    [aux_sym_preproc_else_token1] = ACTIONS(3723),
    [aux_sym_preproc_elif_token1] = ACTIONS(3723),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3509] = {
    [sym_preproc_region] = STATE(3509),
    [sym_preproc_endregion] = STATE(3509),
    [sym_preproc_line] = STATE(3509),
    [sym_preproc_pragma] = STATE(3509),
    [sym_preproc_nullable] = STATE(3509),
    [sym_preproc_error] = STATE(3509),
    [sym_preproc_warning] = STATE(3509),
    [sym_preproc_define] = STATE(3509),
    [sym_preproc_undef] = STATE(3509),
    [sym__identifier_token] = ACTIONS(3725),
    [anon_sym_extern] = ACTIONS(3725),
    [anon_sym_alias] = ACTIONS(3725),
    [anon_sym_global] = ACTIONS(3725),
    [anon_sym_using] = ACTIONS(3725),
    [anon_sym_unsafe] = ACTIONS(3725),
    [anon_sym_static] = ACTIONS(3725),
    [anon_sym_LBRACK] = ACTIONS(3727),
    [anon_sym_LPAREN] = ACTIONS(3727),
    [anon_sym_event] = ACTIONS(3725),
    [anon_sym_namespace] = ACTIONS(3725),
    [anon_sym_class] = ACTIONS(3725),
    [anon_sym_ref] = ACTIONS(3725),
    [anon_sym_struct] = ACTIONS(3725),
    [anon_sym_enum] = ACTIONS(3725),
    [anon_sym_RBRACE] = ACTIONS(3727),
    [anon_sym_interface] = ACTIONS(3725),
    [anon_sym_delegate] = ACTIONS(3725),
    [anon_sym_record] = ACTIONS(3725),
    [anon_sym_abstract] = ACTIONS(3725),
    [anon_sym_async] = ACTIONS(3725),
    [anon_sym_const] = ACTIONS(3725),
    [anon_sym_file] = ACTIONS(3725),
    [anon_sym_fixed] = ACTIONS(3725),
    [anon_sym_internal] = ACTIONS(3725),
    [anon_sym_new] = ACTIONS(3725),
    [anon_sym_override] = ACTIONS(3725),
    [anon_sym_partial] = ACTIONS(3725),
    [anon_sym_private] = ACTIONS(3725),
    [anon_sym_protected] = ACTIONS(3725),
    [anon_sym_public] = ACTIONS(3725),
    [anon_sym_readonly] = ACTIONS(3725),
    [anon_sym_required] = ACTIONS(3725),
    [anon_sym_sealed] = ACTIONS(3725),
    [anon_sym_virtual] = ACTIONS(3725),
    [anon_sym_volatile] = ACTIONS(3725),
    [anon_sym_where] = ACTIONS(3725),
    [anon_sym_notnull] = ACTIONS(3725),
    [anon_sym_unmanaged] = ACTIONS(3725),
    [anon_sym_TILDE] = ACTIONS(3727),
    [anon_sym_implicit] = ACTIONS(3725),
    [anon_sym_explicit] = ACTIONS(3725),
    [anon_sym_scoped] = ACTIONS(3725),
    [anon_sym_var] = ACTIONS(3725),
    [sym_predefined_type] = ACTIONS(3725),
    [anon_sym_yield] = ACTIONS(3725),
    [anon_sym_when] = ACTIONS(3725),
    [anon_sym_from] = ACTIONS(3725),
    [anon_sym_into] = ACTIONS(3725),
    [anon_sym_join] = ACTIONS(3725),
    [anon_sym_on] = ACTIONS(3725),
    [anon_sym_equals] = ACTIONS(3725),
    [anon_sym_let] = ACTIONS(3725),
    [anon_sym_orderby] = ACTIONS(3725),
    [anon_sym_ascending] = ACTIONS(3725),
    [anon_sym_descending] = ACTIONS(3725),
    [anon_sym_group] = ACTIONS(3725),
    [anon_sym_by] = ACTIONS(3725),
    [anon_sym_select] = ACTIONS(3725),
    [aux_sym_preproc_if_token1] = ACTIONS(3727),
    [aux_sym_preproc_if_token3] = ACTIONS(3727),
    [aux_sym_preproc_else_token1] = ACTIONS(3727),
    [aux_sym_preproc_elif_token1] = ACTIONS(3727),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3510] = {
    [sym_preproc_region] = STATE(3510),
    [sym_preproc_endregion] = STATE(3510),
    [sym_preproc_line] = STATE(3510),
    [sym_preproc_pragma] = STATE(3510),
    [sym_preproc_nullable] = STATE(3510),
    [sym_preproc_error] = STATE(3510),
    [sym_preproc_warning] = STATE(3510),
    [sym_preproc_define] = STATE(3510),
    [sym_preproc_undef] = STATE(3510),
    [sym__identifier_token] = ACTIONS(5221),
    [anon_sym_extern] = ACTIONS(5221),
    [anon_sym_alias] = ACTIONS(5221),
    [anon_sym_global] = ACTIONS(5221),
    [anon_sym_using] = ACTIONS(5221),
    [anon_sym_unsafe] = ACTIONS(5221),
    [anon_sym_static] = ACTIONS(5221),
    [anon_sym_LBRACK] = ACTIONS(5223),
    [anon_sym_LPAREN] = ACTIONS(5223),
    [anon_sym_event] = ACTIONS(5221),
    [anon_sym_namespace] = ACTIONS(5221),
    [anon_sym_class] = ACTIONS(5221),
    [anon_sym_ref] = ACTIONS(5221),
    [anon_sym_struct] = ACTIONS(5221),
    [anon_sym_enum] = ACTIONS(5221),
    [anon_sym_RBRACE] = ACTIONS(5223),
    [anon_sym_interface] = ACTIONS(5221),
    [anon_sym_delegate] = ACTIONS(5221),
    [anon_sym_record] = ACTIONS(5221),
    [anon_sym_abstract] = ACTIONS(5221),
    [anon_sym_async] = ACTIONS(5221),
    [anon_sym_const] = ACTIONS(5221),
    [anon_sym_file] = ACTIONS(5221),
    [anon_sym_fixed] = ACTIONS(5221),
    [anon_sym_internal] = ACTIONS(5221),
    [anon_sym_new] = ACTIONS(5221),
    [anon_sym_override] = ACTIONS(5221),
    [anon_sym_partial] = ACTIONS(5221),
    [anon_sym_private] = ACTIONS(5221),
    [anon_sym_protected] = ACTIONS(5221),
    [anon_sym_public] = ACTIONS(5221),
    [anon_sym_readonly] = ACTIONS(5221),
    [anon_sym_required] = ACTIONS(5221),
    [anon_sym_sealed] = ACTIONS(5221),
    [anon_sym_virtual] = ACTIONS(5221),
    [anon_sym_volatile] = ACTIONS(5221),
    [anon_sym_where] = ACTIONS(5221),
    [anon_sym_notnull] = ACTIONS(5221),
    [anon_sym_unmanaged] = ACTIONS(5221),
    [anon_sym_TILDE] = ACTIONS(5223),
    [anon_sym_implicit] = ACTIONS(5221),
    [anon_sym_explicit] = ACTIONS(5221),
    [anon_sym_scoped] = ACTIONS(5221),
    [anon_sym_var] = ACTIONS(5221),
    [sym_predefined_type] = ACTIONS(5221),
    [anon_sym_yield] = ACTIONS(5221),
    [anon_sym_when] = ACTIONS(5221),
    [anon_sym_from] = ACTIONS(5221),
    [anon_sym_into] = ACTIONS(5221),
    [anon_sym_join] = ACTIONS(5221),
    [anon_sym_on] = ACTIONS(5221),
    [anon_sym_equals] = ACTIONS(5221),
    [anon_sym_let] = ACTIONS(5221),
    [anon_sym_orderby] = ACTIONS(5221),
    [anon_sym_ascending] = ACTIONS(5221),
    [anon_sym_descending] = ACTIONS(5221),
    [anon_sym_group] = ACTIONS(5221),
    [anon_sym_by] = ACTIONS(5221),
    [anon_sym_select] = ACTIONS(5221),
    [aux_sym_preproc_if_token1] = ACTIONS(5223),
    [aux_sym_preproc_if_token3] = ACTIONS(5223),
    [aux_sym_preproc_else_token1] = ACTIONS(5223),
    [aux_sym_preproc_elif_token1] = ACTIONS(5223),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3511] = {
    [sym_preproc_region] = STATE(3511),
    [sym_preproc_endregion] = STATE(3511),
    [sym_preproc_line] = STATE(3511),
    [sym_preproc_pragma] = STATE(3511),
    [sym_preproc_nullable] = STATE(3511),
    [sym_preproc_error] = STATE(3511),
    [sym_preproc_warning] = STATE(3511),
    [sym_preproc_define] = STATE(3511),
    [sym_preproc_undef] = STATE(3511),
    [sym__identifier_token] = ACTIONS(3425),
    [anon_sym_extern] = ACTIONS(3425),
    [anon_sym_alias] = ACTIONS(3425),
    [anon_sym_global] = ACTIONS(3425),
    [anon_sym_using] = ACTIONS(3425),
    [anon_sym_unsafe] = ACTIONS(3425),
    [anon_sym_static] = ACTIONS(3425),
    [anon_sym_LBRACK] = ACTIONS(3427),
    [anon_sym_LPAREN] = ACTIONS(3427),
    [anon_sym_event] = ACTIONS(3425),
    [anon_sym_namespace] = ACTIONS(3425),
    [anon_sym_class] = ACTIONS(3425),
    [anon_sym_ref] = ACTIONS(3425),
    [anon_sym_struct] = ACTIONS(3425),
    [anon_sym_enum] = ACTIONS(3425),
    [anon_sym_RBRACE] = ACTIONS(3427),
    [anon_sym_interface] = ACTIONS(3425),
    [anon_sym_delegate] = ACTIONS(3425),
    [anon_sym_record] = ACTIONS(3425),
    [anon_sym_abstract] = ACTIONS(3425),
    [anon_sym_async] = ACTIONS(3425),
    [anon_sym_const] = ACTIONS(3425),
    [anon_sym_file] = ACTIONS(3425),
    [anon_sym_fixed] = ACTIONS(3425),
    [anon_sym_internal] = ACTIONS(3425),
    [anon_sym_new] = ACTIONS(3425),
    [anon_sym_override] = ACTIONS(3425),
    [anon_sym_partial] = ACTIONS(3425),
    [anon_sym_private] = ACTIONS(3425),
    [anon_sym_protected] = ACTIONS(3425),
    [anon_sym_public] = ACTIONS(3425),
    [anon_sym_readonly] = ACTIONS(3425),
    [anon_sym_required] = ACTIONS(3425),
    [anon_sym_sealed] = ACTIONS(3425),
    [anon_sym_virtual] = ACTIONS(3425),
    [anon_sym_volatile] = ACTIONS(3425),
    [anon_sym_where] = ACTIONS(3425),
    [anon_sym_notnull] = ACTIONS(3425),
    [anon_sym_unmanaged] = ACTIONS(3425),
    [anon_sym_TILDE] = ACTIONS(3427),
    [anon_sym_implicit] = ACTIONS(3425),
    [anon_sym_explicit] = ACTIONS(3425),
    [anon_sym_scoped] = ACTIONS(3425),
    [anon_sym_var] = ACTIONS(3425),
    [sym_predefined_type] = ACTIONS(3425),
    [anon_sym_yield] = ACTIONS(3425),
    [anon_sym_when] = ACTIONS(3425),
    [anon_sym_from] = ACTIONS(3425),
    [anon_sym_into] = ACTIONS(3425),
    [anon_sym_join] = ACTIONS(3425),
    [anon_sym_on] = ACTIONS(3425),
    [anon_sym_equals] = ACTIONS(3425),
    [anon_sym_let] = ACTIONS(3425),
    [anon_sym_orderby] = ACTIONS(3425),
    [anon_sym_ascending] = ACTIONS(3425),
    [anon_sym_descending] = ACTIONS(3425),
    [anon_sym_group] = ACTIONS(3425),
    [anon_sym_by] = ACTIONS(3425),
    [anon_sym_select] = ACTIONS(3425),
    [aux_sym_preproc_if_token1] = ACTIONS(3427),
    [aux_sym_preproc_if_token3] = ACTIONS(3427),
    [aux_sym_preproc_else_token1] = ACTIONS(3427),
    [aux_sym_preproc_elif_token1] = ACTIONS(3427),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3512] = {
    [sym_preproc_region] = STATE(3512),
    [sym_preproc_endregion] = STATE(3512),
    [sym_preproc_line] = STATE(3512),
    [sym_preproc_pragma] = STATE(3512),
    [sym_preproc_nullable] = STATE(3512),
    [sym_preproc_error] = STATE(3512),
    [sym_preproc_warning] = STATE(3512),
    [sym_preproc_define] = STATE(3512),
    [sym_preproc_undef] = STATE(3512),
    [sym__identifier_token] = ACTIONS(3729),
    [anon_sym_extern] = ACTIONS(3729),
    [anon_sym_alias] = ACTIONS(3729),
    [anon_sym_global] = ACTIONS(3729),
    [anon_sym_using] = ACTIONS(3729),
    [anon_sym_unsafe] = ACTIONS(3729),
    [anon_sym_static] = ACTIONS(3729),
    [anon_sym_LBRACK] = ACTIONS(3731),
    [anon_sym_LPAREN] = ACTIONS(3731),
    [anon_sym_event] = ACTIONS(3729),
    [anon_sym_namespace] = ACTIONS(3729),
    [anon_sym_class] = ACTIONS(3729),
    [anon_sym_ref] = ACTIONS(3729),
    [anon_sym_struct] = ACTIONS(3729),
    [anon_sym_enum] = ACTIONS(3729),
    [anon_sym_RBRACE] = ACTIONS(3731),
    [anon_sym_interface] = ACTIONS(3729),
    [anon_sym_delegate] = ACTIONS(3729),
    [anon_sym_record] = ACTIONS(3729),
    [anon_sym_abstract] = ACTIONS(3729),
    [anon_sym_async] = ACTIONS(3729),
    [anon_sym_const] = ACTIONS(3729),
    [anon_sym_file] = ACTIONS(3729),
    [anon_sym_fixed] = ACTIONS(3729),
    [anon_sym_internal] = ACTIONS(3729),
    [anon_sym_new] = ACTIONS(3729),
    [anon_sym_override] = ACTIONS(3729),
    [anon_sym_partial] = ACTIONS(3729),
    [anon_sym_private] = ACTIONS(3729),
    [anon_sym_protected] = ACTIONS(3729),
    [anon_sym_public] = ACTIONS(3729),
    [anon_sym_readonly] = ACTIONS(3729),
    [anon_sym_required] = ACTIONS(3729),
    [anon_sym_sealed] = ACTIONS(3729),
    [anon_sym_virtual] = ACTIONS(3729),
    [anon_sym_volatile] = ACTIONS(3729),
    [anon_sym_where] = ACTIONS(3729),
    [anon_sym_notnull] = ACTIONS(3729),
    [anon_sym_unmanaged] = ACTIONS(3729),
    [anon_sym_TILDE] = ACTIONS(3731),
    [anon_sym_implicit] = ACTIONS(3729),
    [anon_sym_explicit] = ACTIONS(3729),
    [anon_sym_scoped] = ACTIONS(3729),
    [anon_sym_var] = ACTIONS(3729),
    [sym_predefined_type] = ACTIONS(3729),
    [anon_sym_yield] = ACTIONS(3729),
    [anon_sym_when] = ACTIONS(3729),
    [anon_sym_from] = ACTIONS(3729),
    [anon_sym_into] = ACTIONS(3729),
    [anon_sym_join] = ACTIONS(3729),
    [anon_sym_on] = ACTIONS(3729),
    [anon_sym_equals] = ACTIONS(3729),
    [anon_sym_let] = ACTIONS(3729),
    [anon_sym_orderby] = ACTIONS(3729),
    [anon_sym_ascending] = ACTIONS(3729),
    [anon_sym_descending] = ACTIONS(3729),
    [anon_sym_group] = ACTIONS(3729),
    [anon_sym_by] = ACTIONS(3729),
    [anon_sym_select] = ACTIONS(3729),
    [aux_sym_preproc_if_token1] = ACTIONS(3731),
    [aux_sym_preproc_if_token3] = ACTIONS(3731),
    [aux_sym_preproc_else_token1] = ACTIONS(3731),
    [aux_sym_preproc_elif_token1] = ACTIONS(3731),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3513] = {
    [sym_preproc_region] = STATE(3513),
    [sym_preproc_endregion] = STATE(3513),
    [sym_preproc_line] = STATE(3513),
    [sym_preproc_pragma] = STATE(3513),
    [sym_preproc_nullable] = STATE(3513),
    [sym_preproc_error] = STATE(3513),
    [sym_preproc_warning] = STATE(3513),
    [sym_preproc_define] = STATE(3513),
    [sym_preproc_undef] = STATE(3513),
    [sym__identifier_token] = ACTIONS(3429),
    [anon_sym_extern] = ACTIONS(3429),
    [anon_sym_alias] = ACTIONS(3429),
    [anon_sym_global] = ACTIONS(3429),
    [anon_sym_using] = ACTIONS(3429),
    [anon_sym_unsafe] = ACTIONS(3429),
    [anon_sym_static] = ACTIONS(3429),
    [anon_sym_LBRACK] = ACTIONS(3431),
    [anon_sym_LPAREN] = ACTIONS(3431),
    [anon_sym_event] = ACTIONS(3429),
    [anon_sym_namespace] = ACTIONS(3429),
    [anon_sym_class] = ACTIONS(3429),
    [anon_sym_ref] = ACTIONS(3429),
    [anon_sym_struct] = ACTIONS(3429),
    [anon_sym_enum] = ACTIONS(3429),
    [anon_sym_RBRACE] = ACTIONS(3431),
    [anon_sym_interface] = ACTIONS(3429),
    [anon_sym_delegate] = ACTIONS(3429),
    [anon_sym_record] = ACTIONS(3429),
    [anon_sym_abstract] = ACTIONS(3429),
    [anon_sym_async] = ACTIONS(3429),
    [anon_sym_const] = ACTIONS(3429),
    [anon_sym_file] = ACTIONS(3429),
    [anon_sym_fixed] = ACTIONS(3429),
    [anon_sym_internal] = ACTIONS(3429),
    [anon_sym_new] = ACTIONS(3429),
    [anon_sym_override] = ACTIONS(3429),
    [anon_sym_partial] = ACTIONS(3429),
    [anon_sym_private] = ACTIONS(3429),
    [anon_sym_protected] = ACTIONS(3429),
    [anon_sym_public] = ACTIONS(3429),
    [anon_sym_readonly] = ACTIONS(3429),
    [anon_sym_required] = ACTIONS(3429),
    [anon_sym_sealed] = ACTIONS(3429),
    [anon_sym_virtual] = ACTIONS(3429),
    [anon_sym_volatile] = ACTIONS(3429),
    [anon_sym_where] = ACTIONS(3429),
    [anon_sym_notnull] = ACTIONS(3429),
    [anon_sym_unmanaged] = ACTIONS(3429),
    [anon_sym_TILDE] = ACTIONS(3431),
    [anon_sym_implicit] = ACTIONS(3429),
    [anon_sym_explicit] = ACTIONS(3429),
    [anon_sym_scoped] = ACTIONS(3429),
    [anon_sym_var] = ACTIONS(3429),
    [sym_predefined_type] = ACTIONS(3429),
    [anon_sym_yield] = ACTIONS(3429),
    [anon_sym_when] = ACTIONS(3429),
    [anon_sym_from] = ACTIONS(3429),
    [anon_sym_into] = ACTIONS(3429),
    [anon_sym_join] = ACTIONS(3429),
    [anon_sym_on] = ACTIONS(3429),
    [anon_sym_equals] = ACTIONS(3429),
    [anon_sym_let] = ACTIONS(3429),
    [anon_sym_orderby] = ACTIONS(3429),
    [anon_sym_ascending] = ACTIONS(3429),
    [anon_sym_descending] = ACTIONS(3429),
    [anon_sym_group] = ACTIONS(3429),
    [anon_sym_by] = ACTIONS(3429),
    [anon_sym_select] = ACTIONS(3429),
    [aux_sym_preproc_if_token1] = ACTIONS(3431),
    [aux_sym_preproc_if_token3] = ACTIONS(3431),
    [aux_sym_preproc_else_token1] = ACTIONS(3431),
    [aux_sym_preproc_elif_token1] = ACTIONS(3431),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3514] = {
    [sym_preproc_region] = STATE(3514),
    [sym_preproc_endregion] = STATE(3514),
    [sym_preproc_line] = STATE(3514),
    [sym_preproc_pragma] = STATE(3514),
    [sym_preproc_nullable] = STATE(3514),
    [sym_preproc_error] = STATE(3514),
    [sym_preproc_warning] = STATE(3514),
    [sym_preproc_define] = STATE(3514),
    [sym_preproc_undef] = STATE(3514),
    [sym__identifier_token] = ACTIONS(3433),
    [anon_sym_extern] = ACTIONS(3433),
    [anon_sym_alias] = ACTIONS(3433),
    [anon_sym_global] = ACTIONS(3433),
    [anon_sym_using] = ACTIONS(3433),
    [anon_sym_unsafe] = ACTIONS(3433),
    [anon_sym_static] = ACTIONS(3433),
    [anon_sym_LBRACK] = ACTIONS(3435),
    [anon_sym_LPAREN] = ACTIONS(3435),
    [anon_sym_event] = ACTIONS(3433),
    [anon_sym_namespace] = ACTIONS(3433),
    [anon_sym_class] = ACTIONS(3433),
    [anon_sym_ref] = ACTIONS(3433),
    [anon_sym_struct] = ACTIONS(3433),
    [anon_sym_enum] = ACTIONS(3433),
    [anon_sym_RBRACE] = ACTIONS(3435),
    [anon_sym_interface] = ACTIONS(3433),
    [anon_sym_delegate] = ACTIONS(3433),
    [anon_sym_record] = ACTIONS(3433),
    [anon_sym_abstract] = ACTIONS(3433),
    [anon_sym_async] = ACTIONS(3433),
    [anon_sym_const] = ACTIONS(3433),
    [anon_sym_file] = ACTIONS(3433),
    [anon_sym_fixed] = ACTIONS(3433),
    [anon_sym_internal] = ACTIONS(3433),
    [anon_sym_new] = ACTIONS(3433),
    [anon_sym_override] = ACTIONS(3433),
    [anon_sym_partial] = ACTIONS(3433),
    [anon_sym_private] = ACTIONS(3433),
    [anon_sym_protected] = ACTIONS(3433),
    [anon_sym_public] = ACTIONS(3433),
    [anon_sym_readonly] = ACTIONS(3433),
    [anon_sym_required] = ACTIONS(3433),
    [anon_sym_sealed] = ACTIONS(3433),
    [anon_sym_virtual] = ACTIONS(3433),
    [anon_sym_volatile] = ACTIONS(3433),
    [anon_sym_where] = ACTIONS(3433),
    [anon_sym_notnull] = ACTIONS(3433),
    [anon_sym_unmanaged] = ACTIONS(3433),
    [anon_sym_TILDE] = ACTIONS(3435),
    [anon_sym_implicit] = ACTIONS(3433),
    [anon_sym_explicit] = ACTIONS(3433),
    [anon_sym_scoped] = ACTIONS(3433),
    [anon_sym_var] = ACTIONS(3433),
    [sym_predefined_type] = ACTIONS(3433),
    [anon_sym_yield] = ACTIONS(3433),
    [anon_sym_when] = ACTIONS(3433),
    [anon_sym_from] = ACTIONS(3433),
    [anon_sym_into] = ACTIONS(3433),
    [anon_sym_join] = ACTIONS(3433),
    [anon_sym_on] = ACTIONS(3433),
    [anon_sym_equals] = ACTIONS(3433),
    [anon_sym_let] = ACTIONS(3433),
    [anon_sym_orderby] = ACTIONS(3433),
    [anon_sym_ascending] = ACTIONS(3433),
    [anon_sym_descending] = ACTIONS(3433),
    [anon_sym_group] = ACTIONS(3433),
    [anon_sym_by] = ACTIONS(3433),
    [anon_sym_select] = ACTIONS(3433),
    [aux_sym_preproc_if_token1] = ACTIONS(3435),
    [aux_sym_preproc_if_token3] = ACTIONS(3435),
    [aux_sym_preproc_else_token1] = ACTIONS(3435),
    [aux_sym_preproc_elif_token1] = ACTIONS(3435),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3515] = {
    [sym_preproc_region] = STATE(3515),
    [sym_preproc_endregion] = STATE(3515),
    [sym_preproc_line] = STATE(3515),
    [sym_preproc_pragma] = STATE(3515),
    [sym_preproc_nullable] = STATE(3515),
    [sym_preproc_error] = STATE(3515),
    [sym_preproc_warning] = STATE(3515),
    [sym_preproc_define] = STATE(3515),
    [sym_preproc_undef] = STATE(3515),
    [sym__identifier_token] = ACTIONS(3437),
    [anon_sym_extern] = ACTIONS(3437),
    [anon_sym_alias] = ACTIONS(3437),
    [anon_sym_global] = ACTIONS(3437),
    [anon_sym_using] = ACTIONS(3437),
    [anon_sym_unsafe] = ACTIONS(3437),
    [anon_sym_static] = ACTIONS(3437),
    [anon_sym_LBRACK] = ACTIONS(3439),
    [anon_sym_LPAREN] = ACTIONS(3439),
    [anon_sym_event] = ACTIONS(3437),
    [anon_sym_namespace] = ACTIONS(3437),
    [anon_sym_class] = ACTIONS(3437),
    [anon_sym_ref] = ACTIONS(3437),
    [anon_sym_struct] = ACTIONS(3437),
    [anon_sym_enum] = ACTIONS(3437),
    [anon_sym_RBRACE] = ACTIONS(3439),
    [anon_sym_interface] = ACTIONS(3437),
    [anon_sym_delegate] = ACTIONS(3437),
    [anon_sym_record] = ACTIONS(3437),
    [anon_sym_abstract] = ACTIONS(3437),
    [anon_sym_async] = ACTIONS(3437),
    [anon_sym_const] = ACTIONS(3437),
    [anon_sym_file] = ACTIONS(3437),
    [anon_sym_fixed] = ACTIONS(3437),
    [anon_sym_internal] = ACTIONS(3437),
    [anon_sym_new] = ACTIONS(3437),
    [anon_sym_override] = ACTIONS(3437),
    [anon_sym_partial] = ACTIONS(3437),
    [anon_sym_private] = ACTIONS(3437),
    [anon_sym_protected] = ACTIONS(3437),
    [anon_sym_public] = ACTIONS(3437),
    [anon_sym_readonly] = ACTIONS(3437),
    [anon_sym_required] = ACTIONS(3437),
    [anon_sym_sealed] = ACTIONS(3437),
    [anon_sym_virtual] = ACTIONS(3437),
    [anon_sym_volatile] = ACTIONS(3437),
    [anon_sym_where] = ACTIONS(3437),
    [anon_sym_notnull] = ACTIONS(3437),
    [anon_sym_unmanaged] = ACTIONS(3437),
    [anon_sym_TILDE] = ACTIONS(3439),
    [anon_sym_implicit] = ACTIONS(3437),
    [anon_sym_explicit] = ACTIONS(3437),
    [anon_sym_scoped] = ACTIONS(3437),
    [anon_sym_var] = ACTIONS(3437),
    [sym_predefined_type] = ACTIONS(3437),
    [anon_sym_yield] = ACTIONS(3437),
    [anon_sym_when] = ACTIONS(3437),
    [anon_sym_from] = ACTIONS(3437),
    [anon_sym_into] = ACTIONS(3437),
    [anon_sym_join] = ACTIONS(3437),
    [anon_sym_on] = ACTIONS(3437),
    [anon_sym_equals] = ACTIONS(3437),
    [anon_sym_let] = ACTIONS(3437),
    [anon_sym_orderby] = ACTIONS(3437),
    [anon_sym_ascending] = ACTIONS(3437),
    [anon_sym_descending] = ACTIONS(3437),
    [anon_sym_group] = ACTIONS(3437),
    [anon_sym_by] = ACTIONS(3437),
    [anon_sym_select] = ACTIONS(3437),
    [aux_sym_preproc_if_token1] = ACTIONS(3439),
    [aux_sym_preproc_if_token3] = ACTIONS(3439),
    [aux_sym_preproc_else_token1] = ACTIONS(3439),
    [aux_sym_preproc_elif_token1] = ACTIONS(3439),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3516] = {
    [sym_preproc_region] = STATE(3516),
    [sym_preproc_endregion] = STATE(3516),
    [sym_preproc_line] = STATE(3516),
    [sym_preproc_pragma] = STATE(3516),
    [sym_preproc_nullable] = STATE(3516),
    [sym_preproc_error] = STATE(3516),
    [sym_preproc_warning] = STATE(3516),
    [sym_preproc_define] = STATE(3516),
    [sym_preproc_undef] = STATE(3516),
    [sym__identifier_token] = ACTIONS(3441),
    [anon_sym_extern] = ACTIONS(3441),
    [anon_sym_alias] = ACTIONS(3441),
    [anon_sym_global] = ACTIONS(3441),
    [anon_sym_using] = ACTIONS(3441),
    [anon_sym_unsafe] = ACTIONS(3441),
    [anon_sym_static] = ACTIONS(3441),
    [anon_sym_LBRACK] = ACTIONS(3443),
    [anon_sym_LPAREN] = ACTIONS(3443),
    [anon_sym_event] = ACTIONS(3441),
    [anon_sym_namespace] = ACTIONS(3441),
    [anon_sym_class] = ACTIONS(3441),
    [anon_sym_ref] = ACTIONS(3441),
    [anon_sym_struct] = ACTIONS(3441),
    [anon_sym_enum] = ACTIONS(3441),
    [anon_sym_RBRACE] = ACTIONS(3443),
    [anon_sym_interface] = ACTIONS(3441),
    [anon_sym_delegate] = ACTIONS(3441),
    [anon_sym_record] = ACTIONS(3441),
    [anon_sym_abstract] = ACTIONS(3441),
    [anon_sym_async] = ACTIONS(3441),
    [anon_sym_const] = ACTIONS(3441),
    [anon_sym_file] = ACTIONS(3441),
    [anon_sym_fixed] = ACTIONS(3441),
    [anon_sym_internal] = ACTIONS(3441),
    [anon_sym_new] = ACTIONS(3441),
    [anon_sym_override] = ACTIONS(3441),
    [anon_sym_partial] = ACTIONS(3441),
    [anon_sym_private] = ACTIONS(3441),
    [anon_sym_protected] = ACTIONS(3441),
    [anon_sym_public] = ACTIONS(3441),
    [anon_sym_readonly] = ACTIONS(3441),
    [anon_sym_required] = ACTIONS(3441),
    [anon_sym_sealed] = ACTIONS(3441),
    [anon_sym_virtual] = ACTIONS(3441),
    [anon_sym_volatile] = ACTIONS(3441),
    [anon_sym_where] = ACTIONS(3441),
    [anon_sym_notnull] = ACTIONS(3441),
    [anon_sym_unmanaged] = ACTIONS(3441),
    [anon_sym_TILDE] = ACTIONS(3443),
    [anon_sym_implicit] = ACTIONS(3441),
    [anon_sym_explicit] = ACTIONS(3441),
    [anon_sym_scoped] = ACTIONS(3441),
    [anon_sym_var] = ACTIONS(3441),
    [sym_predefined_type] = ACTIONS(3441),
    [anon_sym_yield] = ACTIONS(3441),
    [anon_sym_when] = ACTIONS(3441),
    [anon_sym_from] = ACTIONS(3441),
    [anon_sym_into] = ACTIONS(3441),
    [anon_sym_join] = ACTIONS(3441),
    [anon_sym_on] = ACTIONS(3441),
    [anon_sym_equals] = ACTIONS(3441),
    [anon_sym_let] = ACTIONS(3441),
    [anon_sym_orderby] = ACTIONS(3441),
    [anon_sym_ascending] = ACTIONS(3441),
    [anon_sym_descending] = ACTIONS(3441),
    [anon_sym_group] = ACTIONS(3441),
    [anon_sym_by] = ACTIONS(3441),
    [anon_sym_select] = ACTIONS(3441),
    [aux_sym_preproc_if_token1] = ACTIONS(3443),
    [aux_sym_preproc_if_token3] = ACTIONS(3443),
    [aux_sym_preproc_else_token1] = ACTIONS(3443),
    [aux_sym_preproc_elif_token1] = ACTIONS(3443),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3517] = {
    [sym_preproc_region] = STATE(3517),
    [sym_preproc_endregion] = STATE(3517),
    [sym_preproc_line] = STATE(3517),
    [sym_preproc_pragma] = STATE(3517),
    [sym_preproc_nullable] = STATE(3517),
    [sym_preproc_error] = STATE(3517),
    [sym_preproc_warning] = STATE(3517),
    [sym_preproc_define] = STATE(3517),
    [sym_preproc_undef] = STATE(3517),
    [sym__identifier_token] = ACTIONS(3445),
    [anon_sym_extern] = ACTIONS(3445),
    [anon_sym_alias] = ACTIONS(3445),
    [anon_sym_global] = ACTIONS(3445),
    [anon_sym_using] = ACTIONS(3445),
    [anon_sym_unsafe] = ACTIONS(3445),
    [anon_sym_static] = ACTIONS(3445),
    [anon_sym_LBRACK] = ACTIONS(3447),
    [anon_sym_LPAREN] = ACTIONS(3447),
    [anon_sym_event] = ACTIONS(3445),
    [anon_sym_namespace] = ACTIONS(3445),
    [anon_sym_class] = ACTIONS(3445),
    [anon_sym_ref] = ACTIONS(3445),
    [anon_sym_struct] = ACTIONS(3445),
    [anon_sym_enum] = ACTIONS(3445),
    [anon_sym_RBRACE] = ACTIONS(3447),
    [anon_sym_interface] = ACTIONS(3445),
    [anon_sym_delegate] = ACTIONS(3445),
    [anon_sym_record] = ACTIONS(3445),
    [anon_sym_abstract] = ACTIONS(3445),
    [anon_sym_async] = ACTIONS(3445),
    [anon_sym_const] = ACTIONS(3445),
    [anon_sym_file] = ACTIONS(3445),
    [anon_sym_fixed] = ACTIONS(3445),
    [anon_sym_internal] = ACTIONS(3445),
    [anon_sym_new] = ACTIONS(3445),
    [anon_sym_override] = ACTIONS(3445),
    [anon_sym_partial] = ACTIONS(3445),
    [anon_sym_private] = ACTIONS(3445),
    [anon_sym_protected] = ACTIONS(3445),
    [anon_sym_public] = ACTIONS(3445),
    [anon_sym_readonly] = ACTIONS(3445),
    [anon_sym_required] = ACTIONS(3445),
    [anon_sym_sealed] = ACTIONS(3445),
    [anon_sym_virtual] = ACTIONS(3445),
    [anon_sym_volatile] = ACTIONS(3445),
    [anon_sym_where] = ACTIONS(3445),
    [anon_sym_notnull] = ACTIONS(3445),
    [anon_sym_unmanaged] = ACTIONS(3445),
    [anon_sym_TILDE] = ACTIONS(3447),
    [anon_sym_implicit] = ACTIONS(3445),
    [anon_sym_explicit] = ACTIONS(3445),
    [anon_sym_scoped] = ACTIONS(3445),
    [anon_sym_var] = ACTIONS(3445),
    [sym_predefined_type] = ACTIONS(3445),
    [anon_sym_yield] = ACTIONS(3445),
    [anon_sym_when] = ACTIONS(3445),
    [anon_sym_from] = ACTIONS(3445),
    [anon_sym_into] = ACTIONS(3445),
    [anon_sym_join] = ACTIONS(3445),
    [anon_sym_on] = ACTIONS(3445),
    [anon_sym_equals] = ACTIONS(3445),
    [anon_sym_let] = ACTIONS(3445),
    [anon_sym_orderby] = ACTIONS(3445),
    [anon_sym_ascending] = ACTIONS(3445),
    [anon_sym_descending] = ACTIONS(3445),
    [anon_sym_group] = ACTIONS(3445),
    [anon_sym_by] = ACTIONS(3445),
    [anon_sym_select] = ACTIONS(3445),
    [aux_sym_preproc_if_token1] = ACTIONS(3447),
    [aux_sym_preproc_if_token3] = ACTIONS(3447),
    [aux_sym_preproc_else_token1] = ACTIONS(3447),
    [aux_sym_preproc_elif_token1] = ACTIONS(3447),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3518] = {
    [sym_preproc_region] = STATE(3518),
    [sym_preproc_endregion] = STATE(3518),
    [sym_preproc_line] = STATE(3518),
    [sym_preproc_pragma] = STATE(3518),
    [sym_preproc_nullable] = STATE(3518),
    [sym_preproc_error] = STATE(3518),
    [sym_preproc_warning] = STATE(3518),
    [sym_preproc_define] = STATE(3518),
    [sym_preproc_undef] = STATE(3518),
    [sym__identifier_token] = ACTIONS(3449),
    [anon_sym_extern] = ACTIONS(3449),
    [anon_sym_alias] = ACTIONS(3449),
    [anon_sym_global] = ACTIONS(3449),
    [anon_sym_using] = ACTIONS(3449),
    [anon_sym_unsafe] = ACTIONS(3449),
    [anon_sym_static] = ACTIONS(3449),
    [anon_sym_LBRACK] = ACTIONS(3451),
    [anon_sym_LPAREN] = ACTIONS(3451),
    [anon_sym_event] = ACTIONS(3449),
    [anon_sym_namespace] = ACTIONS(3449),
    [anon_sym_class] = ACTIONS(3449),
    [anon_sym_ref] = ACTIONS(3449),
    [anon_sym_struct] = ACTIONS(3449),
    [anon_sym_enum] = ACTIONS(3449),
    [anon_sym_RBRACE] = ACTIONS(3451),
    [anon_sym_interface] = ACTIONS(3449),
    [anon_sym_delegate] = ACTIONS(3449),
    [anon_sym_record] = ACTIONS(3449),
    [anon_sym_abstract] = ACTIONS(3449),
    [anon_sym_async] = ACTIONS(3449),
    [anon_sym_const] = ACTIONS(3449),
    [anon_sym_file] = ACTIONS(3449),
    [anon_sym_fixed] = ACTIONS(3449),
    [anon_sym_internal] = ACTIONS(3449),
    [anon_sym_new] = ACTIONS(3449),
    [anon_sym_override] = ACTIONS(3449),
    [anon_sym_partial] = ACTIONS(3449),
    [anon_sym_private] = ACTIONS(3449),
    [anon_sym_protected] = ACTIONS(3449),
    [anon_sym_public] = ACTIONS(3449),
    [anon_sym_readonly] = ACTIONS(3449),
    [anon_sym_required] = ACTIONS(3449),
    [anon_sym_sealed] = ACTIONS(3449),
    [anon_sym_virtual] = ACTIONS(3449),
    [anon_sym_volatile] = ACTIONS(3449),
    [anon_sym_where] = ACTIONS(3449),
    [anon_sym_notnull] = ACTIONS(3449),
    [anon_sym_unmanaged] = ACTIONS(3449),
    [anon_sym_TILDE] = ACTIONS(3451),
    [anon_sym_implicit] = ACTIONS(3449),
    [anon_sym_explicit] = ACTIONS(3449),
    [anon_sym_scoped] = ACTIONS(3449),
    [anon_sym_var] = ACTIONS(3449),
    [sym_predefined_type] = ACTIONS(3449),
    [anon_sym_yield] = ACTIONS(3449),
    [anon_sym_when] = ACTIONS(3449),
    [anon_sym_from] = ACTIONS(3449),
    [anon_sym_into] = ACTIONS(3449),
    [anon_sym_join] = ACTIONS(3449),
    [anon_sym_on] = ACTIONS(3449),
    [anon_sym_equals] = ACTIONS(3449),
    [anon_sym_let] = ACTIONS(3449),
    [anon_sym_orderby] = ACTIONS(3449),
    [anon_sym_ascending] = ACTIONS(3449),
    [anon_sym_descending] = ACTIONS(3449),
    [anon_sym_group] = ACTIONS(3449),
    [anon_sym_by] = ACTIONS(3449),
    [anon_sym_select] = ACTIONS(3449),
    [aux_sym_preproc_if_token1] = ACTIONS(3451),
    [aux_sym_preproc_if_token3] = ACTIONS(3451),
    [aux_sym_preproc_else_token1] = ACTIONS(3451),
    [aux_sym_preproc_elif_token1] = ACTIONS(3451),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3519] = {
    [sym_preproc_region] = STATE(3519),
    [sym_preproc_endregion] = STATE(3519),
    [sym_preproc_line] = STATE(3519),
    [sym_preproc_pragma] = STATE(3519),
    [sym_preproc_nullable] = STATE(3519),
    [sym_preproc_error] = STATE(3519),
    [sym_preproc_warning] = STATE(3519),
    [sym_preproc_define] = STATE(3519),
    [sym_preproc_undef] = STATE(3519),
    [sym__identifier_token] = ACTIONS(3453),
    [anon_sym_extern] = ACTIONS(3453),
    [anon_sym_alias] = ACTIONS(3453),
    [anon_sym_global] = ACTIONS(3453),
    [anon_sym_using] = ACTIONS(3453),
    [anon_sym_unsafe] = ACTIONS(3453),
    [anon_sym_static] = ACTIONS(3453),
    [anon_sym_LBRACK] = ACTIONS(3455),
    [anon_sym_LPAREN] = ACTIONS(3455),
    [anon_sym_event] = ACTIONS(3453),
    [anon_sym_namespace] = ACTIONS(3453),
    [anon_sym_class] = ACTIONS(3453),
    [anon_sym_ref] = ACTIONS(3453),
    [anon_sym_struct] = ACTIONS(3453),
    [anon_sym_enum] = ACTIONS(3453),
    [anon_sym_RBRACE] = ACTIONS(3455),
    [anon_sym_interface] = ACTIONS(3453),
    [anon_sym_delegate] = ACTIONS(3453),
    [anon_sym_record] = ACTIONS(3453),
    [anon_sym_abstract] = ACTIONS(3453),
    [anon_sym_async] = ACTIONS(3453),
    [anon_sym_const] = ACTIONS(3453),
    [anon_sym_file] = ACTIONS(3453),
    [anon_sym_fixed] = ACTIONS(3453),
    [anon_sym_internal] = ACTIONS(3453),
    [anon_sym_new] = ACTIONS(3453),
    [anon_sym_override] = ACTIONS(3453),
    [anon_sym_partial] = ACTIONS(3453),
    [anon_sym_private] = ACTIONS(3453),
    [anon_sym_protected] = ACTIONS(3453),
    [anon_sym_public] = ACTIONS(3453),
    [anon_sym_readonly] = ACTIONS(3453),
    [anon_sym_required] = ACTIONS(3453),
    [anon_sym_sealed] = ACTIONS(3453),
    [anon_sym_virtual] = ACTIONS(3453),
    [anon_sym_volatile] = ACTIONS(3453),
    [anon_sym_where] = ACTIONS(3453),
    [anon_sym_notnull] = ACTIONS(3453),
    [anon_sym_unmanaged] = ACTIONS(3453),
    [anon_sym_TILDE] = ACTIONS(3455),
    [anon_sym_implicit] = ACTIONS(3453),
    [anon_sym_explicit] = ACTIONS(3453),
    [anon_sym_scoped] = ACTIONS(3453),
    [anon_sym_var] = ACTIONS(3453),
    [sym_predefined_type] = ACTIONS(3453),
    [anon_sym_yield] = ACTIONS(3453),
    [anon_sym_when] = ACTIONS(3453),
    [anon_sym_from] = ACTIONS(3453),
    [anon_sym_into] = ACTIONS(3453),
    [anon_sym_join] = ACTIONS(3453),
    [anon_sym_on] = ACTIONS(3453),
    [anon_sym_equals] = ACTIONS(3453),
    [anon_sym_let] = ACTIONS(3453),
    [anon_sym_orderby] = ACTIONS(3453),
    [anon_sym_ascending] = ACTIONS(3453),
    [anon_sym_descending] = ACTIONS(3453),
    [anon_sym_group] = ACTIONS(3453),
    [anon_sym_by] = ACTIONS(3453),
    [anon_sym_select] = ACTIONS(3453),
    [aux_sym_preproc_if_token1] = ACTIONS(3455),
    [aux_sym_preproc_if_token3] = ACTIONS(3455),
    [aux_sym_preproc_else_token1] = ACTIONS(3455),
    [aux_sym_preproc_elif_token1] = ACTIONS(3455),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3520] = {
    [sym_preproc_region] = STATE(3520),
    [sym_preproc_endregion] = STATE(3520),
    [sym_preproc_line] = STATE(3520),
    [sym_preproc_pragma] = STATE(3520),
    [sym_preproc_nullable] = STATE(3520),
    [sym_preproc_error] = STATE(3520),
    [sym_preproc_warning] = STATE(3520),
    [sym_preproc_define] = STATE(3520),
    [sym_preproc_undef] = STATE(3520),
    [sym__identifier_token] = ACTIONS(3457),
    [anon_sym_extern] = ACTIONS(3457),
    [anon_sym_alias] = ACTIONS(3457),
    [anon_sym_global] = ACTIONS(3457),
    [anon_sym_using] = ACTIONS(3457),
    [anon_sym_unsafe] = ACTIONS(3457),
    [anon_sym_static] = ACTIONS(3457),
    [anon_sym_LBRACK] = ACTIONS(3459),
    [anon_sym_LPAREN] = ACTIONS(3459),
    [anon_sym_event] = ACTIONS(3457),
    [anon_sym_namespace] = ACTIONS(3457),
    [anon_sym_class] = ACTIONS(3457),
    [anon_sym_ref] = ACTIONS(3457),
    [anon_sym_struct] = ACTIONS(3457),
    [anon_sym_enum] = ACTIONS(3457),
    [anon_sym_RBRACE] = ACTIONS(3459),
    [anon_sym_interface] = ACTIONS(3457),
    [anon_sym_delegate] = ACTIONS(3457),
    [anon_sym_record] = ACTIONS(3457),
    [anon_sym_abstract] = ACTIONS(3457),
    [anon_sym_async] = ACTIONS(3457),
    [anon_sym_const] = ACTIONS(3457),
    [anon_sym_file] = ACTIONS(3457),
    [anon_sym_fixed] = ACTIONS(3457),
    [anon_sym_internal] = ACTIONS(3457),
    [anon_sym_new] = ACTIONS(3457),
    [anon_sym_override] = ACTIONS(3457),
    [anon_sym_partial] = ACTIONS(3457),
    [anon_sym_private] = ACTIONS(3457),
    [anon_sym_protected] = ACTIONS(3457),
    [anon_sym_public] = ACTIONS(3457),
    [anon_sym_readonly] = ACTIONS(3457),
    [anon_sym_required] = ACTIONS(3457),
    [anon_sym_sealed] = ACTIONS(3457),
    [anon_sym_virtual] = ACTIONS(3457),
    [anon_sym_volatile] = ACTIONS(3457),
    [anon_sym_where] = ACTIONS(3457),
    [anon_sym_notnull] = ACTIONS(3457),
    [anon_sym_unmanaged] = ACTIONS(3457),
    [anon_sym_TILDE] = ACTIONS(3459),
    [anon_sym_implicit] = ACTIONS(3457),
    [anon_sym_explicit] = ACTIONS(3457),
    [anon_sym_scoped] = ACTIONS(3457),
    [anon_sym_var] = ACTIONS(3457),
    [sym_predefined_type] = ACTIONS(3457),
    [anon_sym_yield] = ACTIONS(3457),
    [anon_sym_when] = ACTIONS(3457),
    [anon_sym_from] = ACTIONS(3457),
    [anon_sym_into] = ACTIONS(3457),
    [anon_sym_join] = ACTIONS(3457),
    [anon_sym_on] = ACTIONS(3457),
    [anon_sym_equals] = ACTIONS(3457),
    [anon_sym_let] = ACTIONS(3457),
    [anon_sym_orderby] = ACTIONS(3457),
    [anon_sym_ascending] = ACTIONS(3457),
    [anon_sym_descending] = ACTIONS(3457),
    [anon_sym_group] = ACTIONS(3457),
    [anon_sym_by] = ACTIONS(3457),
    [anon_sym_select] = ACTIONS(3457),
    [aux_sym_preproc_if_token1] = ACTIONS(3459),
    [aux_sym_preproc_if_token3] = ACTIONS(3459),
    [aux_sym_preproc_else_token1] = ACTIONS(3459),
    [aux_sym_preproc_elif_token1] = ACTIONS(3459),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3521] = {
    [sym_preproc_region] = STATE(3521),
    [sym_preproc_endregion] = STATE(3521),
    [sym_preproc_line] = STATE(3521),
    [sym_preproc_pragma] = STATE(3521),
    [sym_preproc_nullable] = STATE(3521),
    [sym_preproc_error] = STATE(3521),
    [sym_preproc_warning] = STATE(3521),
    [sym_preproc_define] = STATE(3521),
    [sym_preproc_undef] = STATE(3521),
    [sym__identifier_token] = ACTIONS(3461),
    [anon_sym_extern] = ACTIONS(3461),
    [anon_sym_alias] = ACTIONS(3461),
    [anon_sym_global] = ACTIONS(3461),
    [anon_sym_using] = ACTIONS(3461),
    [anon_sym_unsafe] = ACTIONS(3461),
    [anon_sym_static] = ACTIONS(3461),
    [anon_sym_LBRACK] = ACTIONS(3463),
    [anon_sym_LPAREN] = ACTIONS(3463),
    [anon_sym_event] = ACTIONS(3461),
    [anon_sym_namespace] = ACTIONS(3461),
    [anon_sym_class] = ACTIONS(3461),
    [anon_sym_ref] = ACTIONS(3461),
    [anon_sym_struct] = ACTIONS(3461),
    [anon_sym_enum] = ACTIONS(3461),
    [anon_sym_RBRACE] = ACTIONS(3463),
    [anon_sym_interface] = ACTIONS(3461),
    [anon_sym_delegate] = ACTIONS(3461),
    [anon_sym_record] = ACTIONS(3461),
    [anon_sym_abstract] = ACTIONS(3461),
    [anon_sym_async] = ACTIONS(3461),
    [anon_sym_const] = ACTIONS(3461),
    [anon_sym_file] = ACTIONS(3461),
    [anon_sym_fixed] = ACTIONS(3461),
    [anon_sym_internal] = ACTIONS(3461),
    [anon_sym_new] = ACTIONS(3461),
    [anon_sym_override] = ACTIONS(3461),
    [anon_sym_partial] = ACTIONS(3461),
    [anon_sym_private] = ACTIONS(3461),
    [anon_sym_protected] = ACTIONS(3461),
    [anon_sym_public] = ACTIONS(3461),
    [anon_sym_readonly] = ACTIONS(3461),
    [anon_sym_required] = ACTIONS(3461),
    [anon_sym_sealed] = ACTIONS(3461),
    [anon_sym_virtual] = ACTIONS(3461),
    [anon_sym_volatile] = ACTIONS(3461),
    [anon_sym_where] = ACTIONS(3461),
    [anon_sym_notnull] = ACTIONS(3461),
    [anon_sym_unmanaged] = ACTIONS(3461),
    [anon_sym_TILDE] = ACTIONS(3463),
    [anon_sym_implicit] = ACTIONS(3461),
    [anon_sym_explicit] = ACTIONS(3461),
    [anon_sym_scoped] = ACTIONS(3461),
    [anon_sym_var] = ACTIONS(3461),
    [sym_predefined_type] = ACTIONS(3461),
    [anon_sym_yield] = ACTIONS(3461),
    [anon_sym_when] = ACTIONS(3461),
    [anon_sym_from] = ACTIONS(3461),
    [anon_sym_into] = ACTIONS(3461),
    [anon_sym_join] = ACTIONS(3461),
    [anon_sym_on] = ACTIONS(3461),
    [anon_sym_equals] = ACTIONS(3461),
    [anon_sym_let] = ACTIONS(3461),
    [anon_sym_orderby] = ACTIONS(3461),
    [anon_sym_ascending] = ACTIONS(3461),
    [anon_sym_descending] = ACTIONS(3461),
    [anon_sym_group] = ACTIONS(3461),
    [anon_sym_by] = ACTIONS(3461),
    [anon_sym_select] = ACTIONS(3461),
    [aux_sym_preproc_if_token1] = ACTIONS(3463),
    [aux_sym_preproc_if_token3] = ACTIONS(3463),
    [aux_sym_preproc_else_token1] = ACTIONS(3463),
    [aux_sym_preproc_elif_token1] = ACTIONS(3463),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3522] = {
    [sym_preproc_region] = STATE(3522),
    [sym_preproc_endregion] = STATE(3522),
    [sym_preproc_line] = STATE(3522),
    [sym_preproc_pragma] = STATE(3522),
    [sym_preproc_nullable] = STATE(3522),
    [sym_preproc_error] = STATE(3522),
    [sym_preproc_warning] = STATE(3522),
    [sym_preproc_define] = STATE(3522),
    [sym_preproc_undef] = STATE(3522),
    [anon_sym_SEMI] = ACTIONS(4683),
    [anon_sym_EQ] = ACTIONS(4685),
    [anon_sym_LBRACK] = ACTIONS(4683),
    [anon_sym_COLON] = ACTIONS(4683),
    [anon_sym_COMMA] = ACTIONS(4683),
    [anon_sym_RBRACK] = ACTIONS(4683),
    [anon_sym_LPAREN] = ACTIONS(4683),
    [anon_sym_RPAREN] = ACTIONS(4683),
    [anon_sym_RBRACE] = ACTIONS(4683),
    [anon_sym_LT] = ACTIONS(4685),
    [anon_sym_GT] = ACTIONS(4685),
    [anon_sym_in] = ACTIONS(4683),
    [anon_sym_QMARK] = ACTIONS(4685),
    [anon_sym_BANG] = ACTIONS(4685),
    [anon_sym_PLUS_PLUS] = ACTIONS(4683),
    [anon_sym_DASH_DASH] = ACTIONS(4683),
    [anon_sym_PLUS] = ACTIONS(4685),
    [anon_sym_DASH] = ACTIONS(4685),
    [anon_sym_STAR] = ACTIONS(4685),
    [anon_sym_SLASH] = ACTIONS(4685),
    [anon_sym_PERCENT] = ACTIONS(4685),
    [anon_sym_CARET] = ACTIONS(4685),
    [anon_sym_PIPE] = ACTIONS(4685),
    [anon_sym_AMP] = ACTIONS(4685),
    [anon_sym_LT_LT] = ACTIONS(4685),
    [anon_sym_GT_GT] = ACTIONS(4685),
    [anon_sym_GT_GT_GT] = ACTIONS(4685),
    [anon_sym_EQ_EQ] = ACTIONS(4683),
    [anon_sym_BANG_EQ] = ACTIONS(4683),
    [anon_sym_GT_EQ] = ACTIONS(4683),
    [anon_sym_LT_EQ] = ACTIONS(4683),
    [anon_sym_DOT] = ACTIONS(4685),
    [anon_sym_EQ_GT] = ACTIONS(4683),
    [anon_sym_switch] = ACTIONS(4683),
    [anon_sym_when] = ACTIONS(4683),
    [anon_sym_DOT_DOT] = ACTIONS(4683),
    [anon_sym_and] = ACTIONS(4683),
    [anon_sym_or] = ACTIONS(4683),
    [anon_sym_PLUS_EQ] = ACTIONS(4683),
    [anon_sym_DASH_EQ] = ACTIONS(4683),
    [anon_sym_STAR_EQ] = ACTIONS(4683),
    [anon_sym_SLASH_EQ] = ACTIONS(4683),
    [anon_sym_PERCENT_EQ] = ACTIONS(4683),
    [anon_sym_AMP_EQ] = ACTIONS(4683),
    [anon_sym_CARET_EQ] = ACTIONS(4683),
    [anon_sym_PIPE_EQ] = ACTIONS(4683),
    [anon_sym_LT_LT_EQ] = ACTIONS(4683),
    [anon_sym_GT_GT_EQ] = ACTIONS(4683),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4683),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4683),
    [anon_sym_AMP_AMP] = ACTIONS(4683),
    [anon_sym_PIPE_PIPE] = ACTIONS(4683),
    [anon_sym_QMARK_QMARK] = ACTIONS(4685),
    [anon_sym_on] = ACTIONS(4683),
    [anon_sym_equals] = ACTIONS(4683),
    [anon_sym_by] = ACTIONS(4683),
    [anon_sym_as] = ACTIONS(4683),
    [anon_sym_is] = ACTIONS(4683),
    [anon_sym_DASH_GT] = ACTIONS(4683),
    [anon_sym_with] = ACTIONS(4683),
    [aux_sym_preproc_if_token3] = ACTIONS(4683),
    [aux_sym_preproc_else_token1] = ACTIONS(4683),
    [aux_sym_preproc_elif_token1] = ACTIONS(4683),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3523] = {
    [sym_preproc_region] = STATE(3523),
    [sym_preproc_endregion] = STATE(3523),
    [sym_preproc_line] = STATE(3523),
    [sym_preproc_pragma] = STATE(3523),
    [sym_preproc_nullable] = STATE(3523),
    [sym_preproc_error] = STATE(3523),
    [sym_preproc_warning] = STATE(3523),
    [sym_preproc_define] = STATE(3523),
    [sym_preproc_undef] = STATE(3523),
    [sym__identifier_token] = ACTIONS(3465),
    [anon_sym_extern] = ACTIONS(3465),
    [anon_sym_alias] = ACTIONS(3465),
    [anon_sym_global] = ACTIONS(3465),
    [anon_sym_using] = ACTIONS(3465),
    [anon_sym_unsafe] = ACTIONS(3465),
    [anon_sym_static] = ACTIONS(3465),
    [anon_sym_LBRACK] = ACTIONS(3467),
    [anon_sym_LPAREN] = ACTIONS(3467),
    [anon_sym_event] = ACTIONS(3465),
    [anon_sym_namespace] = ACTIONS(3465),
    [anon_sym_class] = ACTIONS(3465),
    [anon_sym_ref] = ACTIONS(3465),
    [anon_sym_struct] = ACTIONS(3465),
    [anon_sym_enum] = ACTIONS(3465),
    [anon_sym_RBRACE] = ACTIONS(3467),
    [anon_sym_interface] = ACTIONS(3465),
    [anon_sym_delegate] = ACTIONS(3465),
    [anon_sym_record] = ACTIONS(3465),
    [anon_sym_abstract] = ACTIONS(3465),
    [anon_sym_async] = ACTIONS(3465),
    [anon_sym_const] = ACTIONS(3465),
    [anon_sym_file] = ACTIONS(3465),
    [anon_sym_fixed] = ACTIONS(3465),
    [anon_sym_internal] = ACTIONS(3465),
    [anon_sym_new] = ACTIONS(3465),
    [anon_sym_override] = ACTIONS(3465),
    [anon_sym_partial] = ACTIONS(3465),
    [anon_sym_private] = ACTIONS(3465),
    [anon_sym_protected] = ACTIONS(3465),
    [anon_sym_public] = ACTIONS(3465),
    [anon_sym_readonly] = ACTIONS(3465),
    [anon_sym_required] = ACTIONS(3465),
    [anon_sym_sealed] = ACTIONS(3465),
    [anon_sym_virtual] = ACTIONS(3465),
    [anon_sym_volatile] = ACTIONS(3465),
    [anon_sym_where] = ACTIONS(3465),
    [anon_sym_notnull] = ACTIONS(3465),
    [anon_sym_unmanaged] = ACTIONS(3465),
    [anon_sym_TILDE] = ACTIONS(3467),
    [anon_sym_implicit] = ACTIONS(3465),
    [anon_sym_explicit] = ACTIONS(3465),
    [anon_sym_scoped] = ACTIONS(3465),
    [anon_sym_var] = ACTIONS(3465),
    [sym_predefined_type] = ACTIONS(3465),
    [anon_sym_yield] = ACTIONS(3465),
    [anon_sym_when] = ACTIONS(3465),
    [anon_sym_from] = ACTIONS(3465),
    [anon_sym_into] = ACTIONS(3465),
    [anon_sym_join] = ACTIONS(3465),
    [anon_sym_on] = ACTIONS(3465),
    [anon_sym_equals] = ACTIONS(3465),
    [anon_sym_let] = ACTIONS(3465),
    [anon_sym_orderby] = ACTIONS(3465),
    [anon_sym_ascending] = ACTIONS(3465),
    [anon_sym_descending] = ACTIONS(3465),
    [anon_sym_group] = ACTIONS(3465),
    [anon_sym_by] = ACTIONS(3465),
    [anon_sym_select] = ACTIONS(3465),
    [aux_sym_preproc_if_token1] = ACTIONS(3467),
    [aux_sym_preproc_if_token3] = ACTIONS(3467),
    [aux_sym_preproc_else_token1] = ACTIONS(3467),
    [aux_sym_preproc_elif_token1] = ACTIONS(3467),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3524] = {
    [sym_preproc_region] = STATE(3524),
    [sym_preproc_endregion] = STATE(3524),
    [sym_preproc_line] = STATE(3524),
    [sym_preproc_pragma] = STATE(3524),
    [sym_preproc_nullable] = STATE(3524),
    [sym_preproc_error] = STATE(3524),
    [sym_preproc_warning] = STATE(3524),
    [sym_preproc_define] = STATE(3524),
    [sym_preproc_undef] = STATE(3524),
    [anon_sym_SEMI] = ACTIONS(4687),
    [anon_sym_EQ] = ACTIONS(4689),
    [anon_sym_LBRACK] = ACTIONS(4687),
    [anon_sym_COLON] = ACTIONS(4687),
    [anon_sym_COMMA] = ACTIONS(4687),
    [anon_sym_RBRACK] = ACTIONS(4687),
    [anon_sym_LPAREN] = ACTIONS(4687),
    [anon_sym_RPAREN] = ACTIONS(4687),
    [anon_sym_RBRACE] = ACTIONS(4687),
    [anon_sym_LT] = ACTIONS(4689),
    [anon_sym_GT] = ACTIONS(4689),
    [anon_sym_in] = ACTIONS(4687),
    [anon_sym_QMARK] = ACTIONS(4689),
    [anon_sym_BANG] = ACTIONS(4689),
    [anon_sym_PLUS_PLUS] = ACTIONS(4687),
    [anon_sym_DASH_DASH] = ACTIONS(4687),
    [anon_sym_PLUS] = ACTIONS(4689),
    [anon_sym_DASH] = ACTIONS(4689),
    [anon_sym_STAR] = ACTIONS(4689),
    [anon_sym_SLASH] = ACTIONS(4689),
    [anon_sym_PERCENT] = ACTIONS(4689),
    [anon_sym_CARET] = ACTIONS(4689),
    [anon_sym_PIPE] = ACTIONS(4689),
    [anon_sym_AMP] = ACTIONS(4689),
    [anon_sym_LT_LT] = ACTIONS(4689),
    [anon_sym_GT_GT] = ACTIONS(4689),
    [anon_sym_GT_GT_GT] = ACTIONS(4689),
    [anon_sym_EQ_EQ] = ACTIONS(4687),
    [anon_sym_BANG_EQ] = ACTIONS(4687),
    [anon_sym_GT_EQ] = ACTIONS(4687),
    [anon_sym_LT_EQ] = ACTIONS(4687),
    [anon_sym_DOT] = ACTIONS(4689),
    [anon_sym_EQ_GT] = ACTIONS(4687),
    [anon_sym_switch] = ACTIONS(4687),
    [anon_sym_when] = ACTIONS(4687),
    [anon_sym_DOT_DOT] = ACTIONS(4687),
    [anon_sym_and] = ACTIONS(4687),
    [anon_sym_or] = ACTIONS(4687),
    [anon_sym_PLUS_EQ] = ACTIONS(4687),
    [anon_sym_DASH_EQ] = ACTIONS(4687),
    [anon_sym_STAR_EQ] = ACTIONS(4687),
    [anon_sym_SLASH_EQ] = ACTIONS(4687),
    [anon_sym_PERCENT_EQ] = ACTIONS(4687),
    [anon_sym_AMP_EQ] = ACTIONS(4687),
    [anon_sym_CARET_EQ] = ACTIONS(4687),
    [anon_sym_PIPE_EQ] = ACTIONS(4687),
    [anon_sym_LT_LT_EQ] = ACTIONS(4687),
    [anon_sym_GT_GT_EQ] = ACTIONS(4687),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4687),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4687),
    [anon_sym_AMP_AMP] = ACTIONS(4687),
    [anon_sym_PIPE_PIPE] = ACTIONS(4687),
    [anon_sym_QMARK_QMARK] = ACTIONS(4689),
    [anon_sym_on] = ACTIONS(4687),
    [anon_sym_equals] = ACTIONS(4687),
    [anon_sym_by] = ACTIONS(4687),
    [anon_sym_as] = ACTIONS(4687),
    [anon_sym_is] = ACTIONS(4687),
    [anon_sym_DASH_GT] = ACTIONS(4687),
    [anon_sym_with] = ACTIONS(4687),
    [aux_sym_preproc_if_token3] = ACTIONS(4687),
    [aux_sym_preproc_else_token1] = ACTIONS(4687),
    [aux_sym_preproc_elif_token1] = ACTIONS(4687),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3525] = {
    [sym_preproc_region] = STATE(3525),
    [sym_preproc_endregion] = STATE(3525),
    [sym_preproc_line] = STATE(3525),
    [sym_preproc_pragma] = STATE(3525),
    [sym_preproc_nullable] = STATE(3525),
    [sym_preproc_error] = STATE(3525),
    [sym_preproc_warning] = STATE(3525),
    [sym_preproc_define] = STATE(3525),
    [sym_preproc_undef] = STATE(3525),
    [sym__identifier_token] = ACTIONS(3733),
    [anon_sym_extern] = ACTIONS(3733),
    [anon_sym_alias] = ACTIONS(3733),
    [anon_sym_global] = ACTIONS(3733),
    [anon_sym_using] = ACTIONS(3733),
    [anon_sym_unsafe] = ACTIONS(3733),
    [anon_sym_static] = ACTIONS(3733),
    [anon_sym_LBRACK] = ACTIONS(3735),
    [anon_sym_LPAREN] = ACTIONS(3735),
    [anon_sym_event] = ACTIONS(3733),
    [anon_sym_namespace] = ACTIONS(3733),
    [anon_sym_class] = ACTIONS(3733),
    [anon_sym_ref] = ACTIONS(3733),
    [anon_sym_struct] = ACTIONS(3733),
    [anon_sym_enum] = ACTIONS(3733),
    [anon_sym_RBRACE] = ACTIONS(3735),
    [anon_sym_interface] = ACTIONS(3733),
    [anon_sym_delegate] = ACTIONS(3733),
    [anon_sym_record] = ACTIONS(3733),
    [anon_sym_abstract] = ACTIONS(3733),
    [anon_sym_async] = ACTIONS(3733),
    [anon_sym_const] = ACTIONS(3733),
    [anon_sym_file] = ACTIONS(3733),
    [anon_sym_fixed] = ACTIONS(3733),
    [anon_sym_internal] = ACTIONS(3733),
    [anon_sym_new] = ACTIONS(3733),
    [anon_sym_override] = ACTIONS(3733),
    [anon_sym_partial] = ACTIONS(3733),
    [anon_sym_private] = ACTIONS(3733),
    [anon_sym_protected] = ACTIONS(3733),
    [anon_sym_public] = ACTIONS(3733),
    [anon_sym_readonly] = ACTIONS(3733),
    [anon_sym_required] = ACTIONS(3733),
    [anon_sym_sealed] = ACTIONS(3733),
    [anon_sym_virtual] = ACTIONS(3733),
    [anon_sym_volatile] = ACTIONS(3733),
    [anon_sym_where] = ACTIONS(3733),
    [anon_sym_notnull] = ACTIONS(3733),
    [anon_sym_unmanaged] = ACTIONS(3733),
    [anon_sym_TILDE] = ACTIONS(3735),
    [anon_sym_implicit] = ACTIONS(3733),
    [anon_sym_explicit] = ACTIONS(3733),
    [anon_sym_scoped] = ACTIONS(3733),
    [anon_sym_var] = ACTIONS(3733),
    [sym_predefined_type] = ACTIONS(3733),
    [anon_sym_yield] = ACTIONS(3733),
    [anon_sym_when] = ACTIONS(3733),
    [anon_sym_from] = ACTIONS(3733),
    [anon_sym_into] = ACTIONS(3733),
    [anon_sym_join] = ACTIONS(3733),
    [anon_sym_on] = ACTIONS(3733),
    [anon_sym_equals] = ACTIONS(3733),
    [anon_sym_let] = ACTIONS(3733),
    [anon_sym_orderby] = ACTIONS(3733),
    [anon_sym_ascending] = ACTIONS(3733),
    [anon_sym_descending] = ACTIONS(3733),
    [anon_sym_group] = ACTIONS(3733),
    [anon_sym_by] = ACTIONS(3733),
    [anon_sym_select] = ACTIONS(3733),
    [aux_sym_preproc_if_token1] = ACTIONS(3735),
    [aux_sym_preproc_if_token3] = ACTIONS(3735),
    [aux_sym_preproc_else_token1] = ACTIONS(3735),
    [aux_sym_preproc_elif_token1] = ACTIONS(3735),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3526] = {
    [sym_preproc_region] = STATE(3526),
    [sym_preproc_endregion] = STATE(3526),
    [sym_preproc_line] = STATE(3526),
    [sym_preproc_pragma] = STATE(3526),
    [sym_preproc_nullable] = STATE(3526),
    [sym_preproc_error] = STATE(3526),
    [sym_preproc_warning] = STATE(3526),
    [sym_preproc_define] = STATE(3526),
    [sym_preproc_undef] = STATE(3526),
    [sym__identifier_token] = ACTIONS(3737),
    [anon_sym_extern] = ACTIONS(3737),
    [anon_sym_alias] = ACTIONS(3737),
    [anon_sym_global] = ACTIONS(3737),
    [anon_sym_using] = ACTIONS(3737),
    [anon_sym_unsafe] = ACTIONS(3737),
    [anon_sym_static] = ACTIONS(3737),
    [anon_sym_LBRACK] = ACTIONS(3739),
    [anon_sym_LPAREN] = ACTIONS(3739),
    [anon_sym_event] = ACTIONS(3737),
    [anon_sym_namespace] = ACTIONS(3737),
    [anon_sym_class] = ACTIONS(3737),
    [anon_sym_ref] = ACTIONS(3737),
    [anon_sym_struct] = ACTIONS(3737),
    [anon_sym_enum] = ACTIONS(3737),
    [anon_sym_RBRACE] = ACTIONS(3739),
    [anon_sym_interface] = ACTIONS(3737),
    [anon_sym_delegate] = ACTIONS(3737),
    [anon_sym_record] = ACTIONS(3737),
    [anon_sym_abstract] = ACTIONS(3737),
    [anon_sym_async] = ACTIONS(3737),
    [anon_sym_const] = ACTIONS(3737),
    [anon_sym_file] = ACTIONS(3737),
    [anon_sym_fixed] = ACTIONS(3737),
    [anon_sym_internal] = ACTIONS(3737),
    [anon_sym_new] = ACTIONS(3737),
    [anon_sym_override] = ACTIONS(3737),
    [anon_sym_partial] = ACTIONS(3737),
    [anon_sym_private] = ACTIONS(3737),
    [anon_sym_protected] = ACTIONS(3737),
    [anon_sym_public] = ACTIONS(3737),
    [anon_sym_readonly] = ACTIONS(3737),
    [anon_sym_required] = ACTIONS(3737),
    [anon_sym_sealed] = ACTIONS(3737),
    [anon_sym_virtual] = ACTIONS(3737),
    [anon_sym_volatile] = ACTIONS(3737),
    [anon_sym_where] = ACTIONS(3737),
    [anon_sym_notnull] = ACTIONS(3737),
    [anon_sym_unmanaged] = ACTIONS(3737),
    [anon_sym_TILDE] = ACTIONS(3739),
    [anon_sym_implicit] = ACTIONS(3737),
    [anon_sym_explicit] = ACTIONS(3737),
    [anon_sym_scoped] = ACTIONS(3737),
    [anon_sym_var] = ACTIONS(3737),
    [sym_predefined_type] = ACTIONS(3737),
    [anon_sym_yield] = ACTIONS(3737),
    [anon_sym_when] = ACTIONS(3737),
    [anon_sym_from] = ACTIONS(3737),
    [anon_sym_into] = ACTIONS(3737),
    [anon_sym_join] = ACTIONS(3737),
    [anon_sym_on] = ACTIONS(3737),
    [anon_sym_equals] = ACTIONS(3737),
    [anon_sym_let] = ACTIONS(3737),
    [anon_sym_orderby] = ACTIONS(3737),
    [anon_sym_ascending] = ACTIONS(3737),
    [anon_sym_descending] = ACTIONS(3737),
    [anon_sym_group] = ACTIONS(3737),
    [anon_sym_by] = ACTIONS(3737),
    [anon_sym_select] = ACTIONS(3737),
    [aux_sym_preproc_if_token1] = ACTIONS(3739),
    [aux_sym_preproc_if_token3] = ACTIONS(3739),
    [aux_sym_preproc_else_token1] = ACTIONS(3739),
    [aux_sym_preproc_elif_token1] = ACTIONS(3739),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3527] = {
    [sym_preproc_region] = STATE(3527),
    [sym_preproc_endregion] = STATE(3527),
    [sym_preproc_line] = STATE(3527),
    [sym_preproc_pragma] = STATE(3527),
    [sym_preproc_nullable] = STATE(3527),
    [sym_preproc_error] = STATE(3527),
    [sym_preproc_warning] = STATE(3527),
    [sym_preproc_define] = STATE(3527),
    [sym_preproc_undef] = STATE(3527),
    [sym__identifier_token] = ACTIONS(5225),
    [anon_sym_extern] = ACTIONS(5225),
    [anon_sym_alias] = ACTIONS(5225),
    [anon_sym_global] = ACTIONS(5225),
    [anon_sym_using] = ACTIONS(5225),
    [anon_sym_unsafe] = ACTIONS(5225),
    [anon_sym_static] = ACTIONS(5225),
    [anon_sym_LBRACK] = ACTIONS(5227),
    [anon_sym_LPAREN] = ACTIONS(5227),
    [anon_sym_event] = ACTIONS(5225),
    [anon_sym_namespace] = ACTIONS(5225),
    [anon_sym_class] = ACTIONS(5225),
    [anon_sym_ref] = ACTIONS(5225),
    [anon_sym_struct] = ACTIONS(5225),
    [anon_sym_enum] = ACTIONS(5225),
    [anon_sym_RBRACE] = ACTIONS(5227),
    [anon_sym_interface] = ACTIONS(5225),
    [anon_sym_delegate] = ACTIONS(5225),
    [anon_sym_record] = ACTIONS(5225),
    [anon_sym_abstract] = ACTIONS(5225),
    [anon_sym_async] = ACTIONS(5225),
    [anon_sym_const] = ACTIONS(5225),
    [anon_sym_file] = ACTIONS(5225),
    [anon_sym_fixed] = ACTIONS(5225),
    [anon_sym_internal] = ACTIONS(5225),
    [anon_sym_new] = ACTIONS(5225),
    [anon_sym_override] = ACTIONS(5225),
    [anon_sym_partial] = ACTIONS(5225),
    [anon_sym_private] = ACTIONS(5225),
    [anon_sym_protected] = ACTIONS(5225),
    [anon_sym_public] = ACTIONS(5225),
    [anon_sym_readonly] = ACTIONS(5225),
    [anon_sym_required] = ACTIONS(5225),
    [anon_sym_sealed] = ACTIONS(5225),
    [anon_sym_virtual] = ACTIONS(5225),
    [anon_sym_volatile] = ACTIONS(5225),
    [anon_sym_where] = ACTIONS(5225),
    [anon_sym_notnull] = ACTIONS(5225),
    [anon_sym_unmanaged] = ACTIONS(5225),
    [anon_sym_TILDE] = ACTIONS(5227),
    [anon_sym_implicit] = ACTIONS(5225),
    [anon_sym_explicit] = ACTIONS(5225),
    [anon_sym_scoped] = ACTIONS(5225),
    [anon_sym_var] = ACTIONS(5225),
    [sym_predefined_type] = ACTIONS(5225),
    [anon_sym_yield] = ACTIONS(5225),
    [anon_sym_when] = ACTIONS(5225),
    [anon_sym_from] = ACTIONS(5225),
    [anon_sym_into] = ACTIONS(5225),
    [anon_sym_join] = ACTIONS(5225),
    [anon_sym_on] = ACTIONS(5225),
    [anon_sym_equals] = ACTIONS(5225),
    [anon_sym_let] = ACTIONS(5225),
    [anon_sym_orderby] = ACTIONS(5225),
    [anon_sym_ascending] = ACTIONS(5225),
    [anon_sym_descending] = ACTIONS(5225),
    [anon_sym_group] = ACTIONS(5225),
    [anon_sym_by] = ACTIONS(5225),
    [anon_sym_select] = ACTIONS(5225),
    [aux_sym_preproc_if_token1] = ACTIONS(5227),
    [aux_sym_preproc_if_token3] = ACTIONS(5227),
    [aux_sym_preproc_else_token1] = ACTIONS(5227),
    [aux_sym_preproc_elif_token1] = ACTIONS(5227),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3528] = {
    [sym_preproc_region] = STATE(3528),
    [sym_preproc_endregion] = STATE(3528),
    [sym_preproc_line] = STATE(3528),
    [sym_preproc_pragma] = STATE(3528),
    [sym_preproc_nullable] = STATE(3528),
    [sym_preproc_error] = STATE(3528),
    [sym_preproc_warning] = STATE(3528),
    [sym_preproc_define] = STATE(3528),
    [sym_preproc_undef] = STATE(3528),
    [sym__identifier_token] = ACTIONS(4650),
    [anon_sym_alias] = ACTIONS(4650),
    [anon_sym_global] = ACTIONS(4650),
    [anon_sym_LBRACK] = ACTIONS(4652),
    [anon_sym_COLON] = ACTIONS(4652),
    [anon_sym_COMMA] = ACTIONS(4652),
    [anon_sym_LPAREN] = ACTIONS(4652),
    [anon_sym_file] = ACTIONS(4650),
    [anon_sym_LT] = ACTIONS(4650),
    [anon_sym_GT] = ACTIONS(4650),
    [anon_sym_where] = ACTIONS(4650),
    [anon_sym_QMARK] = ACTIONS(4650),
    [anon_sym_notnull] = ACTIONS(4650),
    [anon_sym_unmanaged] = ACTIONS(4650),
    [anon_sym_BANG] = ACTIONS(4650),
    [anon_sym_PLUS_PLUS] = ACTIONS(4652),
    [anon_sym_DASH_DASH] = ACTIONS(4652),
    [anon_sym_PLUS] = ACTIONS(4650),
    [anon_sym_DASH] = ACTIONS(4650),
    [anon_sym_STAR] = ACTIONS(4652),
    [anon_sym_SLASH] = ACTIONS(4650),
    [anon_sym_PERCENT] = ACTIONS(4652),
    [anon_sym_CARET] = ACTIONS(4652),
    [anon_sym_PIPE] = ACTIONS(4650),
    [anon_sym_AMP] = ACTIONS(4650),
    [anon_sym_LT_LT] = ACTIONS(4652),
    [anon_sym_GT_GT] = ACTIONS(4650),
    [anon_sym_GT_GT_GT] = ACTIONS(4652),
    [anon_sym_EQ_EQ] = ACTIONS(4652),
    [anon_sym_BANG_EQ] = ACTIONS(4652),
    [anon_sym_GT_EQ] = ACTIONS(4652),
    [anon_sym_LT_EQ] = ACTIONS(4652),
    [anon_sym_DOT] = ACTIONS(4650),
    [anon_sym_scoped] = ACTIONS(4650),
    [anon_sym_var] = ACTIONS(4650),
    [anon_sym_yield] = ACTIONS(4650),
    [anon_sym_switch] = ACTIONS(4650),
    [anon_sym_when] = ACTIONS(4650),
    [sym_discard] = ACTIONS(4650),
    [anon_sym_DOT_DOT] = ACTIONS(4652),
    [anon_sym_and] = ACTIONS(4650),
    [anon_sym_or] = ACTIONS(4650),
    [anon_sym_AMP_AMP] = ACTIONS(4652),
    [anon_sym_PIPE_PIPE] = ACTIONS(4652),
    [anon_sym_QMARK_QMARK] = ACTIONS(4652),
    [anon_sym_from] = ACTIONS(4650),
    [anon_sym_into] = ACTIONS(4650),
    [anon_sym_join] = ACTIONS(4650),
    [anon_sym_on] = ACTIONS(4650),
    [anon_sym_equals] = ACTIONS(4650),
    [anon_sym_let] = ACTIONS(4650),
    [anon_sym_orderby] = ACTIONS(4650),
    [anon_sym_ascending] = ACTIONS(4650),
    [anon_sym_descending] = ACTIONS(4650),
    [anon_sym_group] = ACTIONS(4650),
    [anon_sym_by] = ACTIONS(4650),
    [anon_sym_select] = ACTIONS(4650),
    [anon_sym_as] = ACTIONS(4650),
    [anon_sym_is] = ACTIONS(4650),
    [anon_sym_DASH_GT] = ACTIONS(4652),
    [anon_sym_with] = ACTIONS(4650),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4652),
  },
  [3529] = {
    [sym_preproc_region] = STATE(3529),
    [sym_preproc_endregion] = STATE(3529),
    [sym_preproc_line] = STATE(3529),
    [sym_preproc_pragma] = STATE(3529),
    [sym_preproc_nullable] = STATE(3529),
    [sym_preproc_error] = STATE(3529),
    [sym_preproc_warning] = STATE(3529),
    [sym_preproc_define] = STATE(3529),
    [sym_preproc_undef] = STATE(3529),
    [sym__identifier_token] = ACTIONS(4695),
    [anon_sym_alias] = ACTIONS(4695),
    [anon_sym_global] = ACTIONS(4695),
    [anon_sym_LBRACK] = ACTIONS(4697),
    [anon_sym_COLON] = ACTIONS(4697),
    [anon_sym_COMMA] = ACTIONS(4697),
    [anon_sym_LPAREN] = ACTIONS(4697),
    [anon_sym_file] = ACTIONS(4695),
    [anon_sym_LT] = ACTIONS(4695),
    [anon_sym_GT] = ACTIONS(4695),
    [anon_sym_where] = ACTIONS(4695),
    [anon_sym_QMARK] = ACTIONS(4695),
    [anon_sym_notnull] = ACTIONS(4695),
    [anon_sym_unmanaged] = ACTIONS(4695),
    [anon_sym_BANG] = ACTIONS(4695),
    [anon_sym_PLUS_PLUS] = ACTIONS(4697),
    [anon_sym_DASH_DASH] = ACTIONS(4697),
    [anon_sym_PLUS] = ACTIONS(4695),
    [anon_sym_DASH] = ACTIONS(4695),
    [anon_sym_STAR] = ACTIONS(4697),
    [anon_sym_SLASH] = ACTIONS(4695),
    [anon_sym_PERCENT] = ACTIONS(4697),
    [anon_sym_CARET] = ACTIONS(4697),
    [anon_sym_PIPE] = ACTIONS(4695),
    [anon_sym_AMP] = ACTIONS(4695),
    [anon_sym_LT_LT] = ACTIONS(4697),
    [anon_sym_GT_GT] = ACTIONS(4695),
    [anon_sym_GT_GT_GT] = ACTIONS(4697),
    [anon_sym_EQ_EQ] = ACTIONS(4697),
    [anon_sym_BANG_EQ] = ACTIONS(4697),
    [anon_sym_GT_EQ] = ACTIONS(4697),
    [anon_sym_LT_EQ] = ACTIONS(4697),
    [anon_sym_DOT] = ACTIONS(4695),
    [anon_sym_scoped] = ACTIONS(4695),
    [anon_sym_var] = ACTIONS(4695),
    [anon_sym_yield] = ACTIONS(4695),
    [anon_sym_switch] = ACTIONS(4695),
    [anon_sym_when] = ACTIONS(4695),
    [sym_discard] = ACTIONS(4695),
    [anon_sym_DOT_DOT] = ACTIONS(4697),
    [anon_sym_and] = ACTIONS(4695),
    [anon_sym_or] = ACTIONS(4695),
    [anon_sym_AMP_AMP] = ACTIONS(4697),
    [anon_sym_PIPE_PIPE] = ACTIONS(4697),
    [anon_sym_QMARK_QMARK] = ACTIONS(4697),
    [anon_sym_from] = ACTIONS(4695),
    [anon_sym_into] = ACTIONS(4695),
    [anon_sym_join] = ACTIONS(4695),
    [anon_sym_on] = ACTIONS(4695),
    [anon_sym_equals] = ACTIONS(4695),
    [anon_sym_let] = ACTIONS(4695),
    [anon_sym_orderby] = ACTIONS(4695),
    [anon_sym_ascending] = ACTIONS(4695),
    [anon_sym_descending] = ACTIONS(4695),
    [anon_sym_group] = ACTIONS(4695),
    [anon_sym_by] = ACTIONS(4695),
    [anon_sym_select] = ACTIONS(4695),
    [anon_sym_as] = ACTIONS(4695),
    [anon_sym_is] = ACTIONS(4695),
    [anon_sym_DASH_GT] = ACTIONS(4697),
    [anon_sym_with] = ACTIONS(4695),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4697),
  },
  [3530] = {
    [sym_preproc_region] = STATE(3530),
    [sym_preproc_endregion] = STATE(3530),
    [sym_preproc_line] = STATE(3530),
    [sym_preproc_pragma] = STATE(3530),
    [sym_preproc_nullable] = STATE(3530),
    [sym_preproc_error] = STATE(3530),
    [sym_preproc_warning] = STATE(3530),
    [sym_preproc_define] = STATE(3530),
    [sym_preproc_undef] = STATE(3530),
    [sym__identifier_token] = ACTIONS(4674),
    [anon_sym_alias] = ACTIONS(4674),
    [anon_sym_global] = ACTIONS(4674),
    [anon_sym_LBRACK] = ACTIONS(4676),
    [anon_sym_COLON] = ACTIONS(4676),
    [anon_sym_COMMA] = ACTIONS(4676),
    [anon_sym_LPAREN] = ACTIONS(4676),
    [anon_sym_file] = ACTIONS(4674),
    [anon_sym_LT] = ACTIONS(4674),
    [anon_sym_GT] = ACTIONS(4674),
    [anon_sym_where] = ACTIONS(4674),
    [anon_sym_QMARK] = ACTIONS(4674),
    [anon_sym_notnull] = ACTIONS(4674),
    [anon_sym_unmanaged] = ACTIONS(4674),
    [anon_sym_BANG] = ACTIONS(4674),
    [anon_sym_PLUS_PLUS] = ACTIONS(4676),
    [anon_sym_DASH_DASH] = ACTIONS(4676),
    [anon_sym_PLUS] = ACTIONS(4674),
    [anon_sym_DASH] = ACTIONS(4674),
    [anon_sym_STAR] = ACTIONS(4676),
    [anon_sym_SLASH] = ACTIONS(4674),
    [anon_sym_PERCENT] = ACTIONS(4676),
    [anon_sym_CARET] = ACTIONS(4676),
    [anon_sym_PIPE] = ACTIONS(4674),
    [anon_sym_AMP] = ACTIONS(4674),
    [anon_sym_LT_LT] = ACTIONS(4676),
    [anon_sym_GT_GT] = ACTIONS(4674),
    [anon_sym_GT_GT_GT] = ACTIONS(4676),
    [anon_sym_EQ_EQ] = ACTIONS(4676),
    [anon_sym_BANG_EQ] = ACTIONS(4676),
    [anon_sym_GT_EQ] = ACTIONS(4676),
    [anon_sym_LT_EQ] = ACTIONS(4676),
    [anon_sym_DOT] = ACTIONS(4674),
    [anon_sym_scoped] = ACTIONS(4674),
    [anon_sym_var] = ACTIONS(4674),
    [anon_sym_yield] = ACTIONS(4674),
    [anon_sym_switch] = ACTIONS(4674),
    [anon_sym_when] = ACTIONS(4674),
    [sym_discard] = ACTIONS(4674),
    [anon_sym_DOT_DOT] = ACTIONS(4676),
    [anon_sym_and] = ACTIONS(4674),
    [anon_sym_or] = ACTIONS(4674),
    [anon_sym_AMP_AMP] = ACTIONS(4676),
    [anon_sym_PIPE_PIPE] = ACTIONS(4676),
    [anon_sym_QMARK_QMARK] = ACTIONS(4676),
    [anon_sym_from] = ACTIONS(4674),
    [anon_sym_into] = ACTIONS(4674),
    [anon_sym_join] = ACTIONS(4674),
    [anon_sym_on] = ACTIONS(4674),
    [anon_sym_equals] = ACTIONS(4674),
    [anon_sym_let] = ACTIONS(4674),
    [anon_sym_orderby] = ACTIONS(4674),
    [anon_sym_ascending] = ACTIONS(4674),
    [anon_sym_descending] = ACTIONS(4674),
    [anon_sym_group] = ACTIONS(4674),
    [anon_sym_by] = ACTIONS(4674),
    [anon_sym_select] = ACTIONS(4674),
    [anon_sym_as] = ACTIONS(4674),
    [anon_sym_is] = ACTIONS(4674),
    [anon_sym_DASH_GT] = ACTIONS(4676),
    [anon_sym_with] = ACTIONS(4674),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4676),
  },
  [3531] = {
    [sym_preproc_region] = STATE(3531),
    [sym_preproc_endregion] = STATE(3531),
    [sym_preproc_line] = STATE(3531),
    [sym_preproc_pragma] = STATE(3531),
    [sym_preproc_nullable] = STATE(3531),
    [sym_preproc_error] = STATE(3531),
    [sym_preproc_warning] = STATE(3531),
    [sym_preproc_define] = STATE(3531),
    [sym_preproc_undef] = STATE(3531),
    [sym__identifier_token] = ACTIONS(4654),
    [anon_sym_alias] = ACTIONS(4654),
    [anon_sym_global] = ACTIONS(4654),
    [anon_sym_LBRACK] = ACTIONS(4656),
    [anon_sym_COLON] = ACTIONS(4656),
    [anon_sym_COMMA] = ACTIONS(4656),
    [anon_sym_LPAREN] = ACTIONS(4656),
    [anon_sym_file] = ACTIONS(4654),
    [anon_sym_LT] = ACTIONS(4654),
    [anon_sym_GT] = ACTIONS(4654),
    [anon_sym_where] = ACTIONS(4654),
    [anon_sym_QMARK] = ACTIONS(4654),
    [anon_sym_notnull] = ACTIONS(4654),
    [anon_sym_unmanaged] = ACTIONS(4654),
    [anon_sym_BANG] = ACTIONS(4654),
    [anon_sym_PLUS_PLUS] = ACTIONS(4656),
    [anon_sym_DASH_DASH] = ACTIONS(4656),
    [anon_sym_PLUS] = ACTIONS(4654),
    [anon_sym_DASH] = ACTIONS(4654),
    [anon_sym_STAR] = ACTIONS(4656),
    [anon_sym_SLASH] = ACTIONS(4654),
    [anon_sym_PERCENT] = ACTIONS(4656),
    [anon_sym_CARET] = ACTIONS(4656),
    [anon_sym_PIPE] = ACTIONS(4654),
    [anon_sym_AMP] = ACTIONS(4654),
    [anon_sym_LT_LT] = ACTIONS(4656),
    [anon_sym_GT_GT] = ACTIONS(4654),
    [anon_sym_GT_GT_GT] = ACTIONS(4656),
    [anon_sym_EQ_EQ] = ACTIONS(4656),
    [anon_sym_BANG_EQ] = ACTIONS(4656),
    [anon_sym_GT_EQ] = ACTIONS(4656),
    [anon_sym_LT_EQ] = ACTIONS(4656),
    [anon_sym_DOT] = ACTIONS(4654),
    [anon_sym_scoped] = ACTIONS(4654),
    [anon_sym_var] = ACTIONS(4654),
    [anon_sym_yield] = ACTIONS(4654),
    [anon_sym_switch] = ACTIONS(4654),
    [anon_sym_when] = ACTIONS(4654),
    [sym_discard] = ACTIONS(4654),
    [anon_sym_DOT_DOT] = ACTIONS(4656),
    [anon_sym_and] = ACTIONS(4654),
    [anon_sym_or] = ACTIONS(4654),
    [anon_sym_AMP_AMP] = ACTIONS(4656),
    [anon_sym_PIPE_PIPE] = ACTIONS(4656),
    [anon_sym_QMARK_QMARK] = ACTIONS(4656),
    [anon_sym_from] = ACTIONS(4654),
    [anon_sym_into] = ACTIONS(4654),
    [anon_sym_join] = ACTIONS(4654),
    [anon_sym_on] = ACTIONS(4654),
    [anon_sym_equals] = ACTIONS(4654),
    [anon_sym_let] = ACTIONS(4654),
    [anon_sym_orderby] = ACTIONS(4654),
    [anon_sym_ascending] = ACTIONS(4654),
    [anon_sym_descending] = ACTIONS(4654),
    [anon_sym_group] = ACTIONS(4654),
    [anon_sym_by] = ACTIONS(4654),
    [anon_sym_select] = ACTIONS(4654),
    [anon_sym_as] = ACTIONS(4654),
    [anon_sym_is] = ACTIONS(4654),
    [anon_sym_DASH_GT] = ACTIONS(4656),
    [anon_sym_with] = ACTIONS(4654),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4656),
  },
  [3532] = {
    [sym_preproc_region] = STATE(3532),
    [sym_preproc_endregion] = STATE(3532),
    [sym_preproc_line] = STATE(3532),
    [sym_preproc_pragma] = STATE(3532),
    [sym_preproc_nullable] = STATE(3532),
    [sym_preproc_error] = STATE(3532),
    [sym_preproc_warning] = STATE(3532),
    [sym_preproc_define] = STATE(3532),
    [sym_preproc_undef] = STATE(3532),
    [sym__identifier_token] = ACTIONS(4650),
    [anon_sym_alias] = ACTIONS(4650),
    [anon_sym_global] = ACTIONS(4650),
    [anon_sym_LBRACK] = ACTIONS(4652),
    [anon_sym_COLON] = ACTIONS(4652),
    [anon_sym_COMMA] = ACTIONS(4652),
    [anon_sym_LPAREN] = ACTIONS(4652),
    [anon_sym_file] = ACTIONS(4650),
    [anon_sym_LT] = ACTIONS(4650),
    [anon_sym_GT] = ACTIONS(4650),
    [anon_sym_where] = ACTIONS(4650),
    [anon_sym_QMARK] = ACTIONS(4650),
    [anon_sym_notnull] = ACTIONS(4650),
    [anon_sym_unmanaged] = ACTIONS(4650),
    [anon_sym_BANG] = ACTIONS(4650),
    [anon_sym_PLUS_PLUS] = ACTIONS(4652),
    [anon_sym_DASH_DASH] = ACTIONS(4652),
    [anon_sym_PLUS] = ACTIONS(4650),
    [anon_sym_DASH] = ACTIONS(4650),
    [anon_sym_STAR] = ACTIONS(4652),
    [anon_sym_SLASH] = ACTIONS(4650),
    [anon_sym_PERCENT] = ACTIONS(4652),
    [anon_sym_CARET] = ACTIONS(4652),
    [anon_sym_PIPE] = ACTIONS(4650),
    [anon_sym_AMP] = ACTIONS(4650),
    [anon_sym_LT_LT] = ACTIONS(4652),
    [anon_sym_GT_GT] = ACTIONS(4650),
    [anon_sym_GT_GT_GT] = ACTIONS(4652),
    [anon_sym_EQ_EQ] = ACTIONS(4652),
    [anon_sym_BANG_EQ] = ACTIONS(4652),
    [anon_sym_GT_EQ] = ACTIONS(4652),
    [anon_sym_LT_EQ] = ACTIONS(4652),
    [anon_sym_DOT] = ACTIONS(4650),
    [anon_sym_scoped] = ACTIONS(4650),
    [anon_sym_var] = ACTIONS(4650),
    [anon_sym_yield] = ACTIONS(4650),
    [anon_sym_switch] = ACTIONS(4650),
    [anon_sym_when] = ACTIONS(4650),
    [sym_discard] = ACTIONS(4650),
    [anon_sym_DOT_DOT] = ACTIONS(4652),
    [anon_sym_and] = ACTIONS(4650),
    [anon_sym_or] = ACTIONS(4650),
    [anon_sym_AMP_AMP] = ACTIONS(4652),
    [anon_sym_PIPE_PIPE] = ACTIONS(4652),
    [anon_sym_QMARK_QMARK] = ACTIONS(4652),
    [anon_sym_from] = ACTIONS(4650),
    [anon_sym_into] = ACTIONS(4650),
    [anon_sym_join] = ACTIONS(4650),
    [anon_sym_on] = ACTIONS(4650),
    [anon_sym_equals] = ACTIONS(4650),
    [anon_sym_let] = ACTIONS(4650),
    [anon_sym_orderby] = ACTIONS(4650),
    [anon_sym_ascending] = ACTIONS(4650),
    [anon_sym_descending] = ACTIONS(4650),
    [anon_sym_group] = ACTIONS(4650),
    [anon_sym_by] = ACTIONS(4650),
    [anon_sym_select] = ACTIONS(4650),
    [anon_sym_as] = ACTIONS(4650),
    [anon_sym_is] = ACTIONS(4650),
    [anon_sym_DASH_GT] = ACTIONS(4652),
    [anon_sym_with] = ACTIONS(4650),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4652),
  },
  [3533] = {
    [sym_preproc_region] = STATE(3533),
    [sym_preproc_endregion] = STATE(3533),
    [sym_preproc_line] = STATE(3533),
    [sym_preproc_pragma] = STATE(3533),
    [sym_preproc_nullable] = STATE(3533),
    [sym_preproc_error] = STATE(3533),
    [sym_preproc_warning] = STATE(3533),
    [sym_preproc_define] = STATE(3533),
    [sym_preproc_undef] = STATE(3533),
    [sym__identifier_token] = ACTIONS(4674),
    [anon_sym_alias] = ACTIONS(4674),
    [anon_sym_global] = ACTIONS(4674),
    [anon_sym_LBRACK] = ACTIONS(4676),
    [anon_sym_COLON] = ACTIONS(4676),
    [anon_sym_COMMA] = ACTIONS(4676),
    [anon_sym_LPAREN] = ACTIONS(4676),
    [anon_sym_file] = ACTIONS(4674),
    [anon_sym_LT] = ACTIONS(4674),
    [anon_sym_GT] = ACTIONS(4674),
    [anon_sym_where] = ACTIONS(4674),
    [anon_sym_QMARK] = ACTIONS(4674),
    [anon_sym_notnull] = ACTIONS(4674),
    [anon_sym_unmanaged] = ACTIONS(4674),
    [anon_sym_BANG] = ACTIONS(4674),
    [anon_sym_PLUS_PLUS] = ACTIONS(4676),
    [anon_sym_DASH_DASH] = ACTIONS(4676),
    [anon_sym_PLUS] = ACTIONS(4674),
    [anon_sym_DASH] = ACTIONS(4674),
    [anon_sym_STAR] = ACTIONS(4676),
    [anon_sym_SLASH] = ACTIONS(4674),
    [anon_sym_PERCENT] = ACTIONS(4676),
    [anon_sym_CARET] = ACTIONS(4676),
    [anon_sym_PIPE] = ACTIONS(4674),
    [anon_sym_AMP] = ACTIONS(4674),
    [anon_sym_LT_LT] = ACTIONS(4676),
    [anon_sym_GT_GT] = ACTIONS(4674),
    [anon_sym_GT_GT_GT] = ACTIONS(4676),
    [anon_sym_EQ_EQ] = ACTIONS(4676),
    [anon_sym_BANG_EQ] = ACTIONS(4676),
    [anon_sym_GT_EQ] = ACTIONS(4676),
    [anon_sym_LT_EQ] = ACTIONS(4676),
    [anon_sym_DOT] = ACTIONS(4674),
    [anon_sym_scoped] = ACTIONS(4674),
    [anon_sym_var] = ACTIONS(4674),
    [anon_sym_yield] = ACTIONS(4674),
    [anon_sym_switch] = ACTIONS(4674),
    [anon_sym_when] = ACTIONS(4674),
    [sym_discard] = ACTIONS(4674),
    [anon_sym_DOT_DOT] = ACTIONS(4676),
    [anon_sym_and] = ACTIONS(4674),
    [anon_sym_or] = ACTIONS(4674),
    [anon_sym_AMP_AMP] = ACTIONS(4676),
    [anon_sym_PIPE_PIPE] = ACTIONS(4676),
    [anon_sym_QMARK_QMARK] = ACTIONS(4676),
    [anon_sym_from] = ACTIONS(4674),
    [anon_sym_into] = ACTIONS(4674),
    [anon_sym_join] = ACTIONS(4674),
    [anon_sym_on] = ACTIONS(4674),
    [anon_sym_equals] = ACTIONS(4674),
    [anon_sym_let] = ACTIONS(4674),
    [anon_sym_orderby] = ACTIONS(4674),
    [anon_sym_ascending] = ACTIONS(4674),
    [anon_sym_descending] = ACTIONS(4674),
    [anon_sym_group] = ACTIONS(4674),
    [anon_sym_by] = ACTIONS(4674),
    [anon_sym_select] = ACTIONS(4674),
    [anon_sym_as] = ACTIONS(4674),
    [anon_sym_is] = ACTIONS(4674),
    [anon_sym_DASH_GT] = ACTIONS(4676),
    [anon_sym_with] = ACTIONS(4674),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4676),
  },
  [3534] = {
    [sym_preproc_region] = STATE(3534),
    [sym_preproc_endregion] = STATE(3534),
    [sym_preproc_line] = STATE(3534),
    [sym_preproc_pragma] = STATE(3534),
    [sym_preproc_nullable] = STATE(3534),
    [sym_preproc_error] = STATE(3534),
    [sym_preproc_warning] = STATE(3534),
    [sym_preproc_define] = STATE(3534),
    [sym_preproc_undef] = STATE(3534),
    [sym__identifier_token] = ACTIONS(4587),
    [anon_sym_alias] = ACTIONS(4587),
    [anon_sym_global] = ACTIONS(4587),
    [anon_sym_LBRACK] = ACTIONS(4589),
    [anon_sym_LPAREN] = ACTIONS(4589),
    [anon_sym_LBRACE] = ACTIONS(4589),
    [anon_sym_file] = ACTIONS(4587),
    [anon_sym_LT] = ACTIONS(4587),
    [anon_sym_GT] = ACTIONS(4587),
    [anon_sym_where] = ACTIONS(4587),
    [anon_sym_QMARK] = ACTIONS(4587),
    [anon_sym_notnull] = ACTIONS(4587),
    [anon_sym_unmanaged] = ACTIONS(4587),
    [anon_sym_BANG] = ACTIONS(4587),
    [anon_sym_PLUS_PLUS] = ACTIONS(4589),
    [anon_sym_DASH_DASH] = ACTIONS(4589),
    [anon_sym_PLUS] = ACTIONS(4587),
    [anon_sym_DASH] = ACTIONS(4587),
    [anon_sym_STAR] = ACTIONS(4589),
    [anon_sym_SLASH] = ACTIONS(4587),
    [anon_sym_PERCENT] = ACTIONS(4589),
    [anon_sym_CARET] = ACTIONS(4589),
    [anon_sym_PIPE] = ACTIONS(4587),
    [anon_sym_AMP] = ACTIONS(4587),
    [anon_sym_LT_LT] = ACTIONS(4589),
    [anon_sym_GT_GT] = ACTIONS(4587),
    [anon_sym_GT_GT_GT] = ACTIONS(4589),
    [anon_sym_EQ_EQ] = ACTIONS(4589),
    [anon_sym_BANG_EQ] = ACTIONS(4589),
    [anon_sym_GT_EQ] = ACTIONS(4589),
    [anon_sym_LT_EQ] = ACTIONS(4589),
    [anon_sym_DOT] = ACTIONS(4587),
    [anon_sym_scoped] = ACTIONS(4587),
    [anon_sym_EQ_GT] = ACTIONS(4589),
    [anon_sym_var] = ACTIONS(4587),
    [anon_sym_yield] = ACTIONS(4587),
    [anon_sym_switch] = ACTIONS(4587),
    [anon_sym_when] = ACTIONS(4587),
    [sym_discard] = ACTIONS(4587),
    [anon_sym_DOT_DOT] = ACTIONS(4589),
    [anon_sym_and] = ACTIONS(4587),
    [anon_sym_or] = ACTIONS(4587),
    [anon_sym_AMP_AMP] = ACTIONS(4589),
    [anon_sym_PIPE_PIPE] = ACTIONS(4589),
    [anon_sym_QMARK_QMARK] = ACTIONS(4589),
    [anon_sym_from] = ACTIONS(4587),
    [anon_sym_into] = ACTIONS(4587),
    [anon_sym_join] = ACTIONS(4587),
    [anon_sym_on] = ACTIONS(4587),
    [anon_sym_equals] = ACTIONS(4587),
    [anon_sym_let] = ACTIONS(4587),
    [anon_sym_orderby] = ACTIONS(4587),
    [anon_sym_ascending] = ACTIONS(4587),
    [anon_sym_descending] = ACTIONS(4587),
    [anon_sym_group] = ACTIONS(4587),
    [anon_sym_by] = ACTIONS(4587),
    [anon_sym_select] = ACTIONS(4587),
    [anon_sym_as] = ACTIONS(4587),
    [anon_sym_is] = ACTIONS(4587),
    [anon_sym_DASH_GT] = ACTIONS(4589),
    [anon_sym_with] = ACTIONS(4587),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3535] = {
    [sym_preproc_region] = STATE(3535),
    [sym_preproc_endregion] = STATE(3535),
    [sym_preproc_line] = STATE(3535),
    [sym_preproc_pragma] = STATE(3535),
    [sym_preproc_nullable] = STATE(3535),
    [sym_preproc_error] = STATE(3535),
    [sym_preproc_warning] = STATE(3535),
    [sym_preproc_define] = STATE(3535),
    [sym_preproc_undef] = STATE(3535),
    [sym__identifier_token] = ACTIONS(4492),
    [anon_sym_alias] = ACTIONS(4492),
    [anon_sym_global] = ACTIONS(4492),
    [anon_sym_LBRACK] = ACTIONS(4593),
    [anon_sym_LPAREN] = ACTIONS(4494),
    [anon_sym_LBRACE] = ACTIONS(4494),
    [anon_sym_file] = ACTIONS(4492),
    [anon_sym_LT] = ACTIONS(4492),
    [anon_sym_GT] = ACTIONS(4492),
    [anon_sym_where] = ACTIONS(4492),
    [anon_sym_QMARK] = ACTIONS(4596),
    [anon_sym_notnull] = ACTIONS(4492),
    [anon_sym_unmanaged] = ACTIONS(4492),
    [anon_sym_BANG] = ACTIONS(4492),
    [anon_sym_PLUS_PLUS] = ACTIONS(4494),
    [anon_sym_DASH_DASH] = ACTIONS(4494),
    [anon_sym_PLUS] = ACTIONS(4492),
    [anon_sym_DASH] = ACTIONS(4492),
    [anon_sym_STAR] = ACTIONS(4599),
    [anon_sym_SLASH] = ACTIONS(4492),
    [anon_sym_PERCENT] = ACTIONS(4494),
    [anon_sym_CARET] = ACTIONS(4494),
    [anon_sym_PIPE] = ACTIONS(4492),
    [anon_sym_AMP] = ACTIONS(4492),
    [anon_sym_LT_LT] = ACTIONS(4494),
    [anon_sym_GT_GT] = ACTIONS(4492),
    [anon_sym_GT_GT_GT] = ACTIONS(4494),
    [anon_sym_EQ_EQ] = ACTIONS(4494),
    [anon_sym_BANG_EQ] = ACTIONS(4494),
    [anon_sym_GT_EQ] = ACTIONS(4494),
    [anon_sym_LT_EQ] = ACTIONS(4494),
    [anon_sym_DOT] = ACTIONS(5229),
    [anon_sym_scoped] = ACTIONS(4492),
    [anon_sym_EQ_GT] = ACTIONS(4494),
    [anon_sym_var] = ACTIONS(4492),
    [anon_sym_yield] = ACTIONS(4492),
    [anon_sym_switch] = ACTIONS(4492),
    [anon_sym_when] = ACTIONS(4492),
    [sym_discard] = ACTIONS(4492),
    [anon_sym_DOT_DOT] = ACTIONS(4494),
    [anon_sym_and] = ACTIONS(4492),
    [anon_sym_or] = ACTIONS(4492),
    [anon_sym_AMP_AMP] = ACTIONS(4494),
    [anon_sym_PIPE_PIPE] = ACTIONS(4494),
    [anon_sym_QMARK_QMARK] = ACTIONS(4494),
    [anon_sym_from] = ACTIONS(4492),
    [anon_sym_into] = ACTIONS(4492),
    [anon_sym_join] = ACTIONS(4492),
    [anon_sym_on] = ACTIONS(4492),
    [anon_sym_equals] = ACTIONS(4492),
    [anon_sym_let] = ACTIONS(4492),
    [anon_sym_orderby] = ACTIONS(4492),
    [anon_sym_ascending] = ACTIONS(4492),
    [anon_sym_descending] = ACTIONS(4492),
    [anon_sym_group] = ACTIONS(4492),
    [anon_sym_by] = ACTIONS(4492),
    [anon_sym_select] = ACTIONS(4492),
    [anon_sym_as] = ACTIONS(4492),
    [anon_sym_is] = ACTIONS(4492),
    [anon_sym_DASH_GT] = ACTIONS(4636),
    [anon_sym_with] = ACTIONS(4492),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3536] = {
    [sym_preproc_region] = STATE(3536),
    [sym_preproc_endregion] = STATE(3536),
    [sym_preproc_line] = STATE(3536),
    [sym_preproc_pragma] = STATE(3536),
    [sym_preproc_nullable] = STATE(3536),
    [sym_preproc_error] = STATE(3536),
    [sym_preproc_warning] = STATE(3536),
    [sym_preproc_define] = STATE(3536),
    [sym_preproc_undef] = STATE(3536),
    [sym__identifier_token] = ACTIONS(4492),
    [anon_sym_alias] = ACTIONS(4492),
    [anon_sym_global] = ACTIONS(4492),
    [anon_sym_LBRACK] = ACTIONS(4593),
    [anon_sym_COMMA] = ACTIONS(4494),
    [anon_sym_LPAREN] = ACTIONS(4494),
    [anon_sym_LBRACE] = ACTIONS(4494),
    [anon_sym_file] = ACTIONS(4492),
    [anon_sym_LT] = ACTIONS(4492),
    [anon_sym_GT] = ACTIONS(4492),
    [anon_sym_where] = ACTIONS(4492),
    [anon_sym_QMARK] = ACTIONS(4596),
    [anon_sym_notnull] = ACTIONS(4492),
    [anon_sym_unmanaged] = ACTIONS(4492),
    [anon_sym_BANG] = ACTIONS(4492),
    [anon_sym_PLUS_PLUS] = ACTIONS(4494),
    [anon_sym_DASH_DASH] = ACTIONS(4494),
    [anon_sym_PLUS] = ACTIONS(4492),
    [anon_sym_DASH] = ACTIONS(4492),
    [anon_sym_STAR] = ACTIONS(4599),
    [anon_sym_SLASH] = ACTIONS(4492),
    [anon_sym_PERCENT] = ACTIONS(4494),
    [anon_sym_CARET] = ACTIONS(4494),
    [anon_sym_PIPE] = ACTIONS(4492),
    [anon_sym_AMP] = ACTIONS(4492),
    [anon_sym_LT_LT] = ACTIONS(4494),
    [anon_sym_GT_GT] = ACTIONS(4492),
    [anon_sym_GT_GT_GT] = ACTIONS(4494),
    [anon_sym_EQ_EQ] = ACTIONS(4494),
    [anon_sym_BANG_EQ] = ACTIONS(4494),
    [anon_sym_GT_EQ] = ACTIONS(4494),
    [anon_sym_LT_EQ] = ACTIONS(4494),
    [anon_sym_DOT] = ACTIONS(5231),
    [anon_sym_scoped] = ACTIONS(4492),
    [anon_sym_var] = ACTIONS(4492),
    [anon_sym_yield] = ACTIONS(4492),
    [anon_sym_switch] = ACTIONS(4492),
    [anon_sym_when] = ACTIONS(4492),
    [sym_discard] = ACTIONS(4492),
    [anon_sym_DOT_DOT] = ACTIONS(4494),
    [anon_sym_and] = ACTIONS(4492),
    [anon_sym_or] = ACTIONS(4492),
    [anon_sym_AMP_AMP] = ACTIONS(4494),
    [anon_sym_PIPE_PIPE] = ACTIONS(4494),
    [anon_sym_QMARK_QMARK] = ACTIONS(4494),
    [anon_sym_from] = ACTIONS(4492),
    [anon_sym_into] = ACTIONS(4492),
    [anon_sym_join] = ACTIONS(4492),
    [anon_sym_on] = ACTIONS(4492),
    [anon_sym_equals] = ACTIONS(4492),
    [anon_sym_let] = ACTIONS(4492),
    [anon_sym_orderby] = ACTIONS(4492),
    [anon_sym_ascending] = ACTIONS(4492),
    [anon_sym_descending] = ACTIONS(4492),
    [anon_sym_group] = ACTIONS(4492),
    [anon_sym_by] = ACTIONS(4492),
    [anon_sym_select] = ACTIONS(4492),
    [anon_sym_as] = ACTIONS(4492),
    [anon_sym_is] = ACTIONS(4492),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(4492),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3537] = {
    [sym_preproc_region] = STATE(3537),
    [sym_preproc_endregion] = STATE(3537),
    [sym_preproc_line] = STATE(3537),
    [sym_preproc_pragma] = STATE(3537),
    [sym_preproc_nullable] = STATE(3537),
    [sym_preproc_error] = STATE(3537),
    [sym_preproc_warning] = STATE(3537),
    [sym_preproc_define] = STATE(3537),
    [sym_preproc_undef] = STATE(3537),
    [sym__identifier_token] = ACTIONS(4492),
    [anon_sym_alias] = ACTIONS(4492),
    [anon_sym_global] = ACTIONS(4492),
    [anon_sym_LBRACK] = ACTIONS(4593),
    [anon_sym_COLON] = ACTIONS(4494),
    [anon_sym_LPAREN] = ACTIONS(4494),
    [anon_sym_LBRACE] = ACTIONS(4494),
    [anon_sym_file] = ACTIONS(4492),
    [anon_sym_LT] = ACTIONS(4492),
    [anon_sym_GT] = ACTIONS(4492),
    [anon_sym_where] = ACTIONS(4492),
    [anon_sym_QMARK] = ACTIONS(4596),
    [anon_sym_notnull] = ACTIONS(4492),
    [anon_sym_unmanaged] = ACTIONS(4492),
    [anon_sym_BANG] = ACTIONS(4492),
    [anon_sym_PLUS_PLUS] = ACTIONS(4494),
    [anon_sym_DASH_DASH] = ACTIONS(4494),
    [anon_sym_PLUS] = ACTIONS(4492),
    [anon_sym_DASH] = ACTIONS(4492),
    [anon_sym_STAR] = ACTIONS(4599),
    [anon_sym_SLASH] = ACTIONS(4492),
    [anon_sym_PERCENT] = ACTIONS(4494),
    [anon_sym_CARET] = ACTIONS(4494),
    [anon_sym_PIPE] = ACTIONS(4492),
    [anon_sym_AMP] = ACTIONS(4492),
    [anon_sym_LT_LT] = ACTIONS(4494),
    [anon_sym_GT_GT] = ACTIONS(4492),
    [anon_sym_GT_GT_GT] = ACTIONS(4494),
    [anon_sym_EQ_EQ] = ACTIONS(4494),
    [anon_sym_BANG_EQ] = ACTIONS(4494),
    [anon_sym_GT_EQ] = ACTIONS(4494),
    [anon_sym_LT_EQ] = ACTIONS(4494),
    [anon_sym_DOT] = ACTIONS(5235),
    [anon_sym_scoped] = ACTIONS(4492),
    [anon_sym_var] = ACTIONS(4492),
    [anon_sym_yield] = ACTIONS(4492),
    [anon_sym_switch] = ACTIONS(4492),
    [anon_sym_when] = ACTIONS(4492),
    [sym_discard] = ACTIONS(4492),
    [anon_sym_DOT_DOT] = ACTIONS(4494),
    [anon_sym_and] = ACTIONS(4492),
    [anon_sym_or] = ACTIONS(4492),
    [anon_sym_AMP_AMP] = ACTIONS(4494),
    [anon_sym_PIPE_PIPE] = ACTIONS(4494),
    [anon_sym_QMARK_QMARK] = ACTIONS(4494),
    [anon_sym_from] = ACTIONS(4492),
    [anon_sym_into] = ACTIONS(4492),
    [anon_sym_join] = ACTIONS(4492),
    [anon_sym_on] = ACTIONS(4492),
    [anon_sym_equals] = ACTIONS(4492),
    [anon_sym_let] = ACTIONS(4492),
    [anon_sym_orderby] = ACTIONS(4492),
    [anon_sym_ascending] = ACTIONS(4492),
    [anon_sym_descending] = ACTIONS(4492),
    [anon_sym_group] = ACTIONS(4492),
    [anon_sym_by] = ACTIONS(4492),
    [anon_sym_select] = ACTIONS(4492),
    [anon_sym_as] = ACTIONS(4492),
    [anon_sym_is] = ACTIONS(4492),
    [anon_sym_DASH_GT] = ACTIONS(4604),
    [anon_sym_with] = ACTIONS(4492),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3538] = {
    [sym_preproc_region] = STATE(3538),
    [sym_preproc_endregion] = STATE(3538),
    [sym_preproc_line] = STATE(3538),
    [sym_preproc_pragma] = STATE(3538),
    [sym_preproc_nullable] = STATE(3538),
    [sym_preproc_error] = STATE(3538),
    [sym_preproc_warning] = STATE(3538),
    [sym_preproc_define] = STATE(3538),
    [sym_preproc_undef] = STATE(3538),
    [sym__identifier_token] = ACTIONS(4492),
    [anon_sym_alias] = ACTIONS(4492),
    [anon_sym_global] = ACTIONS(4492),
    [anon_sym_LBRACK] = ACTIONS(4593),
    [anon_sym_COLON] = ACTIONS(4494),
    [anon_sym_LPAREN] = ACTIONS(4494),
    [anon_sym_LBRACE] = ACTIONS(4494),
    [anon_sym_file] = ACTIONS(4492),
    [anon_sym_LT] = ACTIONS(4492),
    [anon_sym_GT] = ACTIONS(4492),
    [anon_sym_where] = ACTIONS(4492),
    [anon_sym_QMARK] = ACTIONS(4596),
    [anon_sym_notnull] = ACTIONS(4492),
    [anon_sym_unmanaged] = ACTIONS(4492),
    [anon_sym_BANG] = ACTIONS(4492),
    [anon_sym_PLUS_PLUS] = ACTIONS(4494),
    [anon_sym_DASH_DASH] = ACTIONS(4494),
    [anon_sym_PLUS] = ACTIONS(4492),
    [anon_sym_DASH] = ACTIONS(4492),
    [anon_sym_STAR] = ACTIONS(4599),
    [anon_sym_SLASH] = ACTIONS(4492),
    [anon_sym_PERCENT] = ACTIONS(4494),
    [anon_sym_CARET] = ACTIONS(4494),
    [anon_sym_PIPE] = ACTIONS(4492),
    [anon_sym_AMP] = ACTIONS(4492),
    [anon_sym_LT_LT] = ACTIONS(4494),
    [anon_sym_GT_GT] = ACTIONS(4492),
    [anon_sym_GT_GT_GT] = ACTIONS(4494),
    [anon_sym_EQ_EQ] = ACTIONS(4494),
    [anon_sym_BANG_EQ] = ACTIONS(4494),
    [anon_sym_GT_EQ] = ACTIONS(4494),
    [anon_sym_LT_EQ] = ACTIONS(4494),
    [anon_sym_DOT] = ACTIONS(5237),
    [anon_sym_scoped] = ACTIONS(4492),
    [anon_sym_var] = ACTIONS(4492),
    [anon_sym_yield] = ACTIONS(4492),
    [anon_sym_switch] = ACTIONS(4492),
    [anon_sym_when] = ACTIONS(4492),
    [sym_discard] = ACTIONS(4492),
    [anon_sym_DOT_DOT] = ACTIONS(4494),
    [anon_sym_and] = ACTIONS(4492),
    [anon_sym_or] = ACTIONS(4492),
    [anon_sym_AMP_AMP] = ACTIONS(4494),
    [anon_sym_PIPE_PIPE] = ACTIONS(4494),
    [anon_sym_QMARK_QMARK] = ACTIONS(4494),
    [anon_sym_from] = ACTIONS(4492),
    [anon_sym_into] = ACTIONS(4492),
    [anon_sym_join] = ACTIONS(4492),
    [anon_sym_on] = ACTIONS(4492),
    [anon_sym_equals] = ACTIONS(4492),
    [anon_sym_let] = ACTIONS(4492),
    [anon_sym_orderby] = ACTIONS(4492),
    [anon_sym_ascending] = ACTIONS(4492),
    [anon_sym_descending] = ACTIONS(4492),
    [anon_sym_group] = ACTIONS(4492),
    [anon_sym_by] = ACTIONS(4492),
    [anon_sym_select] = ACTIONS(4492),
    [anon_sym_as] = ACTIONS(4492),
    [anon_sym_is] = ACTIONS(4492),
    [anon_sym_DASH_GT] = ACTIONS(4636),
    [anon_sym_with] = ACTIONS(4492),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3539] = {
    [sym_preproc_region] = STATE(3539),
    [sym_preproc_endregion] = STATE(3539),
    [sym_preproc_line] = STATE(3539),
    [sym_preproc_pragma] = STATE(3539),
    [sym_preproc_nullable] = STATE(3539),
    [sym_preproc_error] = STATE(3539),
    [sym_preproc_warning] = STATE(3539),
    [sym_preproc_define] = STATE(3539),
    [sym_preproc_undef] = STATE(3539),
    [sym__identifier_token] = ACTIONS(4492),
    [anon_sym_alias] = ACTIONS(4492),
    [anon_sym_global] = ACTIONS(4492),
    [anon_sym_LBRACK] = ACTIONS(4593),
    [anon_sym_COMMA] = ACTIONS(4494),
    [anon_sym_LPAREN] = ACTIONS(4494),
    [anon_sym_LBRACE] = ACTIONS(4494),
    [anon_sym_file] = ACTIONS(4492),
    [anon_sym_LT] = ACTIONS(4492),
    [anon_sym_GT] = ACTIONS(4492),
    [anon_sym_where] = ACTIONS(4492),
    [anon_sym_QMARK] = ACTIONS(4596),
    [anon_sym_notnull] = ACTIONS(4492),
    [anon_sym_unmanaged] = ACTIONS(4492),
    [anon_sym_BANG] = ACTIONS(4492),
    [anon_sym_PLUS_PLUS] = ACTIONS(4494),
    [anon_sym_DASH_DASH] = ACTIONS(4494),
    [anon_sym_PLUS] = ACTIONS(4492),
    [anon_sym_DASH] = ACTIONS(4492),
    [anon_sym_STAR] = ACTIONS(4599),
    [anon_sym_SLASH] = ACTIONS(4492),
    [anon_sym_PERCENT] = ACTIONS(4494),
    [anon_sym_CARET] = ACTIONS(4494),
    [anon_sym_PIPE] = ACTIONS(4492),
    [anon_sym_AMP] = ACTIONS(4492),
    [anon_sym_LT_LT] = ACTIONS(4494),
    [anon_sym_GT_GT] = ACTIONS(4492),
    [anon_sym_GT_GT_GT] = ACTIONS(4494),
    [anon_sym_EQ_EQ] = ACTIONS(4494),
    [anon_sym_BANG_EQ] = ACTIONS(4494),
    [anon_sym_GT_EQ] = ACTIONS(4494),
    [anon_sym_LT_EQ] = ACTIONS(4494),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_scoped] = ACTIONS(4492),
    [anon_sym_var] = ACTIONS(4492),
    [anon_sym_yield] = ACTIONS(4492),
    [anon_sym_switch] = ACTIONS(4492),
    [anon_sym_when] = ACTIONS(4492),
    [sym_discard] = ACTIONS(4492),
    [anon_sym_DOT_DOT] = ACTIONS(4494),
    [anon_sym_and] = ACTIONS(4492),
    [anon_sym_or] = ACTIONS(4492),
    [anon_sym_AMP_AMP] = ACTIONS(4494),
    [anon_sym_PIPE_PIPE] = ACTIONS(4494),
    [anon_sym_QMARK_QMARK] = ACTIONS(4494),
    [anon_sym_from] = ACTIONS(4492),
    [anon_sym_into] = ACTIONS(4492),
    [anon_sym_join] = ACTIONS(4492),
    [anon_sym_on] = ACTIONS(4492),
    [anon_sym_equals] = ACTIONS(4492),
    [anon_sym_let] = ACTIONS(4492),
    [anon_sym_orderby] = ACTIONS(4492),
    [anon_sym_ascending] = ACTIONS(4492),
    [anon_sym_descending] = ACTIONS(4492),
    [anon_sym_group] = ACTIONS(4492),
    [anon_sym_by] = ACTIONS(4492),
    [anon_sym_select] = ACTIONS(4492),
    [anon_sym_as] = ACTIONS(4492),
    [anon_sym_is] = ACTIONS(4492),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(4492),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3540] = {
    [sym_preproc_region] = STATE(3540),
    [sym_preproc_endregion] = STATE(3540),
    [sym_preproc_line] = STATE(3540),
    [sym_preproc_pragma] = STATE(3540),
    [sym_preproc_nullable] = STATE(3540),
    [sym_preproc_error] = STATE(3540),
    [sym_preproc_warning] = STATE(3540),
    [sym_preproc_define] = STATE(3540),
    [sym_preproc_undef] = STATE(3540),
    [sym__identifier_token] = ACTIONS(4492),
    [anon_sym_alias] = ACTIONS(4492),
    [anon_sym_global] = ACTIONS(4492),
    [anon_sym_LBRACK] = ACTIONS(4593),
    [anon_sym_LPAREN] = ACTIONS(4494),
    [anon_sym_LBRACE] = ACTIONS(4494),
    [anon_sym_file] = ACTIONS(4492),
    [anon_sym_LT] = ACTIONS(4492),
    [anon_sym_GT] = ACTIONS(4492),
    [anon_sym_where] = ACTIONS(4492),
    [anon_sym_QMARK] = ACTIONS(4596),
    [anon_sym_notnull] = ACTIONS(4492),
    [anon_sym_unmanaged] = ACTIONS(4492),
    [anon_sym_BANG] = ACTIONS(4492),
    [anon_sym_PLUS_PLUS] = ACTIONS(4494),
    [anon_sym_DASH_DASH] = ACTIONS(4494),
    [anon_sym_PLUS] = ACTIONS(4492),
    [anon_sym_DASH] = ACTIONS(4492),
    [anon_sym_STAR] = ACTIONS(4599),
    [anon_sym_SLASH] = ACTIONS(4492),
    [anon_sym_PERCENT] = ACTIONS(4494),
    [anon_sym_CARET] = ACTIONS(4494),
    [anon_sym_PIPE] = ACTIONS(4492),
    [anon_sym_AMP] = ACTIONS(4492),
    [anon_sym_LT_LT] = ACTIONS(4494),
    [anon_sym_GT_GT] = ACTIONS(4492),
    [anon_sym_GT_GT_GT] = ACTIONS(4494),
    [anon_sym_EQ_EQ] = ACTIONS(4494),
    [anon_sym_BANG_EQ] = ACTIONS(4494),
    [anon_sym_GT_EQ] = ACTIONS(4494),
    [anon_sym_LT_EQ] = ACTIONS(4494),
    [anon_sym_DOT] = ACTIONS(5241),
    [anon_sym_scoped] = ACTIONS(4492),
    [anon_sym_EQ_GT] = ACTIONS(4494),
    [anon_sym_var] = ACTIONS(4492),
    [anon_sym_yield] = ACTIONS(4492),
    [anon_sym_switch] = ACTIONS(4492),
    [anon_sym_when] = ACTIONS(4492),
    [sym_discard] = ACTIONS(4492),
    [anon_sym_DOT_DOT] = ACTIONS(4494),
    [anon_sym_and] = ACTIONS(4492),
    [anon_sym_or] = ACTIONS(4492),
    [anon_sym_AMP_AMP] = ACTIONS(4494),
    [anon_sym_PIPE_PIPE] = ACTIONS(4494),
    [anon_sym_QMARK_QMARK] = ACTIONS(4494),
    [anon_sym_from] = ACTIONS(4492),
    [anon_sym_into] = ACTIONS(4492),
    [anon_sym_join] = ACTIONS(4492),
    [anon_sym_on] = ACTIONS(4492),
    [anon_sym_equals] = ACTIONS(4492),
    [anon_sym_let] = ACTIONS(4492),
    [anon_sym_orderby] = ACTIONS(4492),
    [anon_sym_ascending] = ACTIONS(4492),
    [anon_sym_descending] = ACTIONS(4492),
    [anon_sym_group] = ACTIONS(4492),
    [anon_sym_by] = ACTIONS(4492),
    [anon_sym_select] = ACTIONS(4492),
    [anon_sym_as] = ACTIONS(4492),
    [anon_sym_is] = ACTIONS(4492),
    [anon_sym_DASH_GT] = ACTIONS(4604),
    [anon_sym_with] = ACTIONS(4492),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3541] = {
    [sym_preproc_region] = STATE(3541),
    [sym_preproc_endregion] = STATE(3541),
    [sym_preproc_line] = STATE(3541),
    [sym_preproc_pragma] = STATE(3541),
    [sym_preproc_nullable] = STATE(3541),
    [sym_preproc_error] = STATE(3541),
    [sym_preproc_warning] = STATE(3541),
    [sym_preproc_define] = STATE(3541),
    [sym_preproc_undef] = STATE(3541),
    [sym__identifier_token] = ACTIONS(4492),
    [anon_sym_alias] = ACTIONS(4492),
    [anon_sym_global] = ACTIONS(4492),
    [anon_sym_LBRACK] = ACTIONS(4593),
    [anon_sym_COMMA] = ACTIONS(4494),
    [anon_sym_LPAREN] = ACTIONS(4494),
    [anon_sym_LBRACE] = ACTIONS(4494),
    [anon_sym_file] = ACTIONS(4492),
    [anon_sym_LT] = ACTIONS(4492),
    [anon_sym_GT] = ACTIONS(4492),
    [anon_sym_where] = ACTIONS(4492),
    [anon_sym_QMARK] = ACTIONS(4596),
    [anon_sym_notnull] = ACTIONS(4492),
    [anon_sym_unmanaged] = ACTIONS(4492),
    [anon_sym_BANG] = ACTIONS(4492),
    [anon_sym_PLUS_PLUS] = ACTIONS(4494),
    [anon_sym_DASH_DASH] = ACTIONS(4494),
    [anon_sym_PLUS] = ACTIONS(4492),
    [anon_sym_DASH] = ACTIONS(4492),
    [anon_sym_STAR] = ACTIONS(4599),
    [anon_sym_SLASH] = ACTIONS(4492),
    [anon_sym_PERCENT] = ACTIONS(4494),
    [anon_sym_CARET] = ACTIONS(4494),
    [anon_sym_PIPE] = ACTIONS(4492),
    [anon_sym_AMP] = ACTIONS(4492),
    [anon_sym_LT_LT] = ACTIONS(4494),
    [anon_sym_GT_GT] = ACTIONS(4492),
    [anon_sym_GT_GT_GT] = ACTIONS(4494),
    [anon_sym_EQ_EQ] = ACTIONS(4494),
    [anon_sym_BANG_EQ] = ACTIONS(4494),
    [anon_sym_GT_EQ] = ACTIONS(4494),
    [anon_sym_LT_EQ] = ACTIONS(4494),
    [anon_sym_DOT] = ACTIONS(5243),
    [anon_sym_scoped] = ACTIONS(4492),
    [anon_sym_var] = ACTIONS(4492),
    [anon_sym_yield] = ACTIONS(4492),
    [anon_sym_switch] = ACTIONS(4492),
    [anon_sym_when] = ACTIONS(4492),
    [sym_discard] = ACTIONS(4492),
    [anon_sym_DOT_DOT] = ACTIONS(4494),
    [anon_sym_and] = ACTIONS(4492),
    [anon_sym_or] = ACTIONS(4492),
    [anon_sym_AMP_AMP] = ACTIONS(4494),
    [anon_sym_PIPE_PIPE] = ACTIONS(4494),
    [anon_sym_QMARK_QMARK] = ACTIONS(4494),
    [anon_sym_from] = ACTIONS(4492),
    [anon_sym_into] = ACTIONS(4492),
    [anon_sym_join] = ACTIONS(4492),
    [anon_sym_on] = ACTIONS(4492),
    [anon_sym_equals] = ACTIONS(4492),
    [anon_sym_let] = ACTIONS(4492),
    [anon_sym_orderby] = ACTIONS(4492),
    [anon_sym_ascending] = ACTIONS(4492),
    [anon_sym_descending] = ACTIONS(4492),
    [anon_sym_group] = ACTIONS(4492),
    [anon_sym_by] = ACTIONS(4492),
    [anon_sym_select] = ACTIONS(4492),
    [anon_sym_as] = ACTIONS(4492),
    [anon_sym_is] = ACTIONS(4492),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(4492),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3542] = {
    [sym_preproc_region] = STATE(3542),
    [sym_preproc_endregion] = STATE(3542),
    [sym_preproc_line] = STATE(3542),
    [sym_preproc_pragma] = STATE(3542),
    [sym_preproc_nullable] = STATE(3542),
    [sym_preproc_error] = STATE(3542),
    [sym_preproc_warning] = STATE(3542),
    [sym_preproc_define] = STATE(3542),
    [sym_preproc_undef] = STATE(3542),
    [sym__identifier_token] = ACTIONS(4587),
    [anon_sym_alias] = ACTIONS(4587),
    [anon_sym_global] = ACTIONS(4587),
    [anon_sym_LBRACK] = ACTIONS(4589),
    [anon_sym_LPAREN] = ACTIONS(4589),
    [anon_sym_LBRACE] = ACTIONS(4589),
    [anon_sym_file] = ACTIONS(4587),
    [anon_sym_LT] = ACTIONS(4587),
    [anon_sym_GT] = ACTIONS(4587),
    [anon_sym_where] = ACTIONS(4587),
    [anon_sym_QMARK] = ACTIONS(4587),
    [anon_sym_notnull] = ACTIONS(4587),
    [anon_sym_unmanaged] = ACTIONS(4587),
    [anon_sym_BANG] = ACTIONS(4587),
    [anon_sym_PLUS_PLUS] = ACTIONS(4589),
    [anon_sym_DASH_DASH] = ACTIONS(4589),
    [anon_sym_PLUS] = ACTIONS(4587),
    [anon_sym_DASH] = ACTIONS(4587),
    [anon_sym_STAR] = ACTIONS(4589),
    [anon_sym_SLASH] = ACTIONS(4587),
    [anon_sym_PERCENT] = ACTIONS(4589),
    [anon_sym_CARET] = ACTIONS(4589),
    [anon_sym_PIPE] = ACTIONS(4587),
    [anon_sym_AMP] = ACTIONS(4587),
    [anon_sym_LT_LT] = ACTIONS(4589),
    [anon_sym_GT_GT] = ACTIONS(4587),
    [anon_sym_GT_GT_GT] = ACTIONS(4589),
    [anon_sym_EQ_EQ] = ACTIONS(4589),
    [anon_sym_BANG_EQ] = ACTIONS(4589),
    [anon_sym_GT_EQ] = ACTIONS(4589),
    [anon_sym_LT_EQ] = ACTIONS(4589),
    [anon_sym_DOT] = ACTIONS(4587),
    [anon_sym_scoped] = ACTIONS(4587),
    [anon_sym_EQ_GT] = ACTIONS(4589),
    [anon_sym_var] = ACTIONS(4587),
    [anon_sym_yield] = ACTIONS(4587),
    [anon_sym_switch] = ACTIONS(4587),
    [anon_sym_when] = ACTIONS(4587),
    [sym_discard] = ACTIONS(4587),
    [anon_sym_DOT_DOT] = ACTIONS(4589),
    [anon_sym_and] = ACTIONS(4587),
    [anon_sym_or] = ACTIONS(4587),
    [anon_sym_AMP_AMP] = ACTIONS(4589),
    [anon_sym_PIPE_PIPE] = ACTIONS(4589),
    [anon_sym_QMARK_QMARK] = ACTIONS(4589),
    [anon_sym_from] = ACTIONS(4587),
    [anon_sym_into] = ACTIONS(4587),
    [anon_sym_join] = ACTIONS(4587),
    [anon_sym_on] = ACTIONS(4587),
    [anon_sym_equals] = ACTIONS(4587),
    [anon_sym_let] = ACTIONS(4587),
    [anon_sym_orderby] = ACTIONS(4587),
    [anon_sym_ascending] = ACTIONS(4587),
    [anon_sym_descending] = ACTIONS(4587),
    [anon_sym_group] = ACTIONS(4587),
    [anon_sym_by] = ACTIONS(4587),
    [anon_sym_select] = ACTIONS(4587),
    [anon_sym_as] = ACTIONS(4587),
    [anon_sym_is] = ACTIONS(4587),
    [anon_sym_DASH_GT] = ACTIONS(4589),
    [anon_sym_with] = ACTIONS(4587),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3543] = {
    [sym_preproc_region] = STATE(3543),
    [sym_preproc_endregion] = STATE(3543),
    [sym_preproc_line] = STATE(3543),
    [sym_preproc_pragma] = STATE(3543),
    [sym_preproc_nullable] = STATE(3543),
    [sym_preproc_error] = STATE(3543),
    [sym_preproc_warning] = STATE(3543),
    [sym_preproc_define] = STATE(3543),
    [sym_preproc_undef] = STATE(3543),
    [sym__identifier_token] = ACTIONS(4492),
    [anon_sym_alias] = ACTIONS(4492),
    [anon_sym_global] = ACTIONS(4492),
    [anon_sym_LBRACK] = ACTIONS(4593),
    [anon_sym_LPAREN] = ACTIONS(4494),
    [anon_sym_LBRACE] = ACTIONS(4494),
    [anon_sym_file] = ACTIONS(4492),
    [anon_sym_LT] = ACTIONS(4492),
    [anon_sym_GT] = ACTIONS(4492),
    [anon_sym_where] = ACTIONS(4492),
    [anon_sym_QMARK] = ACTIONS(4596),
    [anon_sym_notnull] = ACTIONS(4492),
    [anon_sym_unmanaged] = ACTIONS(4492),
    [anon_sym_BANG] = ACTIONS(4492),
    [anon_sym_PLUS_PLUS] = ACTIONS(4494),
    [anon_sym_DASH_DASH] = ACTIONS(4494),
    [anon_sym_PLUS] = ACTIONS(4492),
    [anon_sym_DASH] = ACTIONS(4492),
    [anon_sym_STAR] = ACTIONS(4599),
    [anon_sym_SLASH] = ACTIONS(4492),
    [anon_sym_PERCENT] = ACTIONS(4494),
    [anon_sym_CARET] = ACTIONS(4494),
    [anon_sym_PIPE] = ACTIONS(4492),
    [anon_sym_AMP] = ACTIONS(4492),
    [anon_sym_LT_LT] = ACTIONS(4494),
    [anon_sym_GT_GT] = ACTIONS(4492),
    [anon_sym_GT_GT_GT] = ACTIONS(4494),
    [anon_sym_EQ_EQ] = ACTIONS(4494),
    [anon_sym_BANG_EQ] = ACTIONS(4494),
    [anon_sym_GT_EQ] = ACTIONS(4494),
    [anon_sym_LT_EQ] = ACTIONS(4494),
    [anon_sym_DOT] = ACTIONS(5245),
    [anon_sym_scoped] = ACTIONS(4492),
    [anon_sym_var] = ACTIONS(4492),
    [anon_sym_yield] = ACTIONS(4492),
    [anon_sym_switch] = ACTIONS(4492),
    [anon_sym_when] = ACTIONS(4492),
    [sym_discard] = ACTIONS(4492),
    [anon_sym_DOT_DOT] = ACTIONS(4494),
    [anon_sym_and] = ACTIONS(4492),
    [anon_sym_or] = ACTIONS(4492),
    [anon_sym_AMP_AMP] = ACTIONS(4494),
    [anon_sym_PIPE_PIPE] = ACTIONS(4494),
    [anon_sym_QMARK_QMARK] = ACTIONS(4494),
    [anon_sym_from] = ACTIONS(4492),
    [anon_sym_into] = ACTIONS(4492),
    [anon_sym_join] = ACTIONS(4492),
    [anon_sym_on] = ACTIONS(4492),
    [anon_sym_equals] = ACTIONS(4492),
    [anon_sym_let] = ACTIONS(4492),
    [anon_sym_orderby] = ACTIONS(4492),
    [anon_sym_ascending] = ACTIONS(4492),
    [anon_sym_descending] = ACTIONS(4492),
    [anon_sym_group] = ACTIONS(4492),
    [anon_sym_by] = ACTIONS(4492),
    [anon_sym_select] = ACTIONS(4492),
    [anon_sym_as] = ACTIONS(4492),
    [anon_sym_is] = ACTIONS(4492),
    [anon_sym_DASH_GT] = ACTIONS(5247),
    [anon_sym_with] = ACTIONS(4492),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3544] = {
    [sym_preproc_region] = STATE(3544),
    [sym_preproc_endregion] = STATE(3544),
    [sym_preproc_line] = STATE(3544),
    [sym_preproc_pragma] = STATE(3544),
    [sym_preproc_nullable] = STATE(3544),
    [sym_preproc_error] = STATE(3544),
    [sym_preproc_warning] = STATE(3544),
    [sym_preproc_define] = STATE(3544),
    [sym_preproc_undef] = STATE(3544),
    [sym__identifier_token] = ACTIONS(4492),
    [anon_sym_alias] = ACTIONS(4492),
    [anon_sym_global] = ACTIONS(4492),
    [anon_sym_LBRACK] = ACTIONS(4593),
    [anon_sym_LPAREN] = ACTIONS(4494),
    [anon_sym_LBRACE] = ACTIONS(4494),
    [anon_sym_file] = ACTIONS(4492),
    [anon_sym_LT] = ACTIONS(4492),
    [anon_sym_GT] = ACTIONS(4492),
    [anon_sym_where] = ACTIONS(4492),
    [anon_sym_QMARK] = ACTIONS(4596),
    [anon_sym_notnull] = ACTIONS(4492),
    [anon_sym_unmanaged] = ACTIONS(4492),
    [anon_sym_BANG] = ACTIONS(4492),
    [anon_sym_PLUS_PLUS] = ACTIONS(4494),
    [anon_sym_DASH_DASH] = ACTIONS(4494),
    [anon_sym_PLUS] = ACTIONS(4492),
    [anon_sym_DASH] = ACTIONS(4492),
    [anon_sym_STAR] = ACTIONS(4599),
    [anon_sym_SLASH] = ACTIONS(4492),
    [anon_sym_PERCENT] = ACTIONS(4494),
    [anon_sym_CARET] = ACTIONS(4494),
    [anon_sym_PIPE] = ACTIONS(4492),
    [anon_sym_AMP] = ACTIONS(4492),
    [anon_sym_LT_LT] = ACTIONS(4494),
    [anon_sym_GT_GT] = ACTIONS(4492),
    [anon_sym_GT_GT_GT] = ACTIONS(4494),
    [anon_sym_EQ_EQ] = ACTIONS(4494),
    [anon_sym_BANG_EQ] = ACTIONS(4494),
    [anon_sym_GT_EQ] = ACTIONS(4494),
    [anon_sym_LT_EQ] = ACTIONS(4494),
    [anon_sym_DOT] = ACTIONS(5249),
    [anon_sym_scoped] = ACTIONS(4492),
    [anon_sym_var] = ACTIONS(4492),
    [anon_sym_yield] = ACTIONS(4492),
    [anon_sym_switch] = ACTIONS(4492),
    [anon_sym_when] = ACTIONS(4492),
    [sym_discard] = ACTIONS(4492),
    [anon_sym_DOT_DOT] = ACTIONS(4494),
    [anon_sym_and] = ACTIONS(4492),
    [anon_sym_or] = ACTIONS(4492),
    [anon_sym_AMP_AMP] = ACTIONS(4494),
    [anon_sym_PIPE_PIPE] = ACTIONS(4494),
    [anon_sym_QMARK_QMARK] = ACTIONS(4494),
    [anon_sym_from] = ACTIONS(4492),
    [anon_sym_into] = ACTIONS(4492),
    [anon_sym_join] = ACTIONS(4492),
    [anon_sym_on] = ACTIONS(4492),
    [anon_sym_equals] = ACTIONS(4492),
    [anon_sym_let] = ACTIONS(4492),
    [anon_sym_orderby] = ACTIONS(4492),
    [anon_sym_ascending] = ACTIONS(4492),
    [anon_sym_descending] = ACTIONS(4492),
    [anon_sym_group] = ACTIONS(4492),
    [anon_sym_by] = ACTIONS(4492),
    [anon_sym_select] = ACTIONS(4492),
    [anon_sym_as] = ACTIONS(4492),
    [anon_sym_is] = ACTIONS(4492),
    [anon_sym_DASH_GT] = ACTIONS(5247),
    [anon_sym_with] = ACTIONS(4492),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3545] = {
    [sym_preproc_region] = STATE(3545),
    [sym_preproc_endregion] = STATE(3545),
    [sym_preproc_line] = STATE(3545),
    [sym_preproc_pragma] = STATE(3545),
    [sym_preproc_nullable] = STATE(3545),
    [sym_preproc_error] = STATE(3545),
    [sym_preproc_warning] = STATE(3545),
    [sym_preproc_define] = STATE(3545),
    [sym_preproc_undef] = STATE(3545),
    [sym__identifier_token] = ACTIONS(4492),
    [anon_sym_alias] = ACTIONS(4492),
    [anon_sym_global] = ACTIONS(4492),
    [anon_sym_LBRACK] = ACTIONS(4593),
    [anon_sym_LPAREN] = ACTIONS(4494),
    [anon_sym_LBRACE] = ACTIONS(4494),
    [anon_sym_file] = ACTIONS(4492),
    [anon_sym_LT] = ACTIONS(4492),
    [anon_sym_GT] = ACTIONS(4492),
    [anon_sym_where] = ACTIONS(4492),
    [anon_sym_QMARK] = ACTIONS(4596),
    [anon_sym_notnull] = ACTIONS(4492),
    [anon_sym_unmanaged] = ACTIONS(4492),
    [anon_sym_BANG] = ACTIONS(4492),
    [anon_sym_PLUS_PLUS] = ACTIONS(4494),
    [anon_sym_DASH_DASH] = ACTIONS(4494),
    [anon_sym_PLUS] = ACTIONS(4492),
    [anon_sym_DASH] = ACTIONS(4492),
    [anon_sym_STAR] = ACTIONS(4599),
    [anon_sym_SLASH] = ACTIONS(4492),
    [anon_sym_PERCENT] = ACTIONS(4494),
    [anon_sym_CARET] = ACTIONS(4494),
    [anon_sym_PIPE] = ACTIONS(4492),
    [anon_sym_AMP] = ACTIONS(4492),
    [anon_sym_LT_LT] = ACTIONS(4494),
    [anon_sym_GT_GT] = ACTIONS(4492),
    [anon_sym_GT_GT_GT] = ACTIONS(4494),
    [anon_sym_EQ_EQ] = ACTIONS(4494),
    [anon_sym_BANG_EQ] = ACTIONS(4494),
    [anon_sym_GT_EQ] = ACTIONS(4494),
    [anon_sym_LT_EQ] = ACTIONS(4494),
    [anon_sym_DOT] = ACTIONS(5251),
    [anon_sym_scoped] = ACTIONS(4492),
    [anon_sym_var] = ACTIONS(4492),
    [anon_sym_yield] = ACTIONS(4492),
    [anon_sym_switch] = ACTIONS(4492),
    [anon_sym_when] = ACTIONS(4492),
    [sym_discard] = ACTIONS(4492),
    [anon_sym_DOT_DOT] = ACTIONS(4494),
    [anon_sym_and] = ACTIONS(4492),
    [anon_sym_or] = ACTIONS(4492),
    [anon_sym_AMP_AMP] = ACTIONS(4494),
    [anon_sym_PIPE_PIPE] = ACTIONS(4494),
    [anon_sym_QMARK_QMARK] = ACTIONS(4494),
    [anon_sym_from] = ACTIONS(4492),
    [anon_sym_into] = ACTIONS(4492),
    [anon_sym_join] = ACTIONS(4492),
    [anon_sym_on] = ACTIONS(4492),
    [anon_sym_equals] = ACTIONS(4492),
    [anon_sym_let] = ACTIONS(4492),
    [anon_sym_orderby] = ACTIONS(4492),
    [anon_sym_ascending] = ACTIONS(4492),
    [anon_sym_descending] = ACTIONS(4492),
    [anon_sym_group] = ACTIONS(4492),
    [anon_sym_by] = ACTIONS(4492),
    [anon_sym_select] = ACTIONS(4492),
    [anon_sym_as] = ACTIONS(4492),
    [anon_sym_is] = ACTIONS(4492),
    [anon_sym_DASH_GT] = ACTIONS(5247),
    [anon_sym_with] = ACTIONS(4492),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3546] = {
    [sym_preproc_region] = STATE(3546),
    [sym_preproc_endregion] = STATE(3546),
    [sym_preproc_line] = STATE(3546),
    [sym_preproc_pragma] = STATE(3546),
    [sym_preproc_nullable] = STATE(3546),
    [sym_preproc_error] = STATE(3546),
    [sym_preproc_warning] = STATE(3546),
    [sym_preproc_define] = STATE(3546),
    [sym_preproc_undef] = STATE(3546),
    [anon_sym_SEMI] = ACTIONS(2997),
    [anon_sym_LBRACK] = ACTIONS(2997),
    [anon_sym_COLON] = ACTIONS(2997),
    [anon_sym_COMMA] = ACTIONS(2997),
    [anon_sym_RBRACK] = ACTIONS(2997),
    [anon_sym_LPAREN] = ACTIONS(2997),
    [anon_sym_RPAREN] = ACTIONS(2997),
    [anon_sym_RBRACE] = ACTIONS(2997),
    [anon_sym_LT] = ACTIONS(2995),
    [anon_sym_GT] = ACTIONS(2995),
    [anon_sym_in] = ACTIONS(2997),
    [anon_sym_where] = ACTIONS(2997),
    [anon_sym_QMARK] = ACTIONS(2995),
    [anon_sym_BANG] = ACTIONS(2995),
    [anon_sym_PLUS_PLUS] = ACTIONS(2997),
    [anon_sym_DASH_DASH] = ACTIONS(2997),
    [anon_sym_PLUS] = ACTIONS(2995),
    [anon_sym_DASH] = ACTIONS(2995),
    [anon_sym_STAR] = ACTIONS(2997),
    [anon_sym_SLASH] = ACTIONS(2995),
    [anon_sym_PERCENT] = ACTIONS(2997),
    [anon_sym_CARET] = ACTIONS(2997),
    [anon_sym_PIPE] = ACTIONS(2995),
    [anon_sym_AMP] = ACTIONS(2995),
    [anon_sym_LT_LT] = ACTIONS(2997),
    [anon_sym_GT_GT] = ACTIONS(2995),
    [anon_sym_GT_GT_GT] = ACTIONS(2997),
    [anon_sym_EQ_EQ] = ACTIONS(2997),
    [anon_sym_BANG_EQ] = ACTIONS(2997),
    [anon_sym_GT_EQ] = ACTIONS(2997),
    [anon_sym_LT_EQ] = ACTIONS(2997),
    [anon_sym_DOT] = ACTIONS(2995),
    [anon_sym_EQ_GT] = ACTIONS(2997),
    [anon_sym_while] = ACTIONS(2997),
    [anon_sym_switch] = ACTIONS(2997),
    [anon_sym_catch] = ACTIONS(2997),
    [anon_sym_finally] = ACTIONS(2997),
    [anon_sym_else] = ACTIONS(2997),
    [anon_sym_DOT_DOT] = ACTIONS(2997),
    [anon_sym_and] = ACTIONS(2997),
    [anon_sym_or] = ACTIONS(2995),
    [anon_sym_AMP_AMP] = ACTIONS(2997),
    [anon_sym_PIPE_PIPE] = ACTIONS(2997),
    [anon_sym_QMARK_QMARK] = ACTIONS(2997),
    [anon_sym_from] = ACTIONS(2997),
    [anon_sym_join] = ACTIONS(2997),
    [anon_sym_on] = ACTIONS(2997),
    [anon_sym_equals] = ACTIONS(2997),
    [anon_sym_let] = ACTIONS(2997),
    [anon_sym_orderby] = ACTIONS(2997),
    [anon_sym_group] = ACTIONS(2997),
    [anon_sym_by] = ACTIONS(2997),
    [anon_sym_select] = ACTIONS(2997),
    [anon_sym_as] = ACTIONS(2997),
    [anon_sym_is] = ACTIONS(2997),
    [anon_sym_DASH_GT] = ACTIONS(2997),
    [anon_sym_with] = ACTIONS(2997),
    [aux_sym_preproc_if_token3] = ACTIONS(2997),
    [aux_sym_preproc_else_token1] = ACTIONS(2997),
    [aux_sym_preproc_elif_token1] = ACTIONS(2997),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3547] = {
    [sym_preproc_region] = STATE(3547),
    [sym_preproc_endregion] = STATE(3547),
    [sym_preproc_line] = STATE(3547),
    [sym_preproc_pragma] = STATE(3547),
    [sym_preproc_nullable] = STATE(3547),
    [sym_preproc_error] = STATE(3547),
    [sym_preproc_warning] = STATE(3547),
    [sym_preproc_define] = STATE(3547),
    [sym_preproc_undef] = STATE(3547),
    [sym__identifier_token] = ACTIONS(4650),
    [anon_sym_alias] = ACTIONS(4650),
    [anon_sym_global] = ACTIONS(4650),
    [anon_sym_LBRACK] = ACTIONS(4765),
    [anon_sym_COLON] = ACTIONS(4652),
    [anon_sym_LPAREN] = ACTIONS(4652),
    [anon_sym_file] = ACTIONS(4650),
    [anon_sym_LT] = ACTIONS(4767),
    [anon_sym_GT] = ACTIONS(4767),
    [anon_sym_where] = ACTIONS(4650),
    [anon_sym_QMARK] = ACTIONS(4767),
    [anon_sym_notnull] = ACTIONS(4650),
    [anon_sym_unmanaged] = ACTIONS(4650),
    [anon_sym_BANG] = ACTIONS(4767),
    [anon_sym_PLUS_PLUS] = ACTIONS(4765),
    [anon_sym_DASH_DASH] = ACTIONS(4765),
    [anon_sym_PLUS] = ACTIONS(4767),
    [anon_sym_DASH] = ACTIONS(4767),
    [anon_sym_STAR] = ACTIONS(4765),
    [anon_sym_SLASH] = ACTIONS(4767),
    [anon_sym_PERCENT] = ACTIONS(4765),
    [anon_sym_CARET] = ACTIONS(4765),
    [anon_sym_PIPE] = ACTIONS(4767),
    [anon_sym_AMP] = ACTIONS(4767),
    [anon_sym_LT_LT] = ACTIONS(4765),
    [anon_sym_GT_GT] = ACTIONS(4767),
    [anon_sym_GT_GT_GT] = ACTIONS(4765),
    [anon_sym_EQ_EQ] = ACTIONS(4765),
    [anon_sym_BANG_EQ] = ACTIONS(4765),
    [anon_sym_GT_EQ] = ACTIONS(4765),
    [anon_sym_LT_EQ] = ACTIONS(4765),
    [anon_sym_DOT] = ACTIONS(4767),
    [anon_sym_scoped] = ACTIONS(4650),
    [anon_sym_var] = ACTIONS(4650),
    [anon_sym_yield] = ACTIONS(4650),
    [anon_sym_switch] = ACTIONS(4767),
    [anon_sym_when] = ACTIONS(4650),
    [sym_discard] = ACTIONS(4650),
    [anon_sym_DOT_DOT] = ACTIONS(4765),
    [anon_sym_and] = ACTIONS(4650),
    [anon_sym_or] = ACTIONS(4650),
    [anon_sym_AMP_AMP] = ACTIONS(4765),
    [anon_sym_PIPE_PIPE] = ACTIONS(4765),
    [anon_sym_QMARK_QMARK] = ACTIONS(4765),
    [anon_sym_from] = ACTIONS(4650),
    [anon_sym_into] = ACTIONS(4650),
    [anon_sym_join] = ACTIONS(4650),
    [anon_sym_on] = ACTIONS(4650),
    [anon_sym_equals] = ACTIONS(4650),
    [anon_sym_let] = ACTIONS(4650),
    [anon_sym_orderby] = ACTIONS(4650),
    [anon_sym_ascending] = ACTIONS(4650),
    [anon_sym_descending] = ACTIONS(4650),
    [anon_sym_group] = ACTIONS(4650),
    [anon_sym_by] = ACTIONS(4650),
    [anon_sym_select] = ACTIONS(4650),
    [anon_sym_as] = ACTIONS(4767),
    [anon_sym_is] = ACTIONS(4767),
    [anon_sym_DASH_GT] = ACTIONS(4765),
    [anon_sym_with] = ACTIONS(4767),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3548] = {
    [sym_preproc_region] = STATE(3548),
    [sym_preproc_endregion] = STATE(3548),
    [sym_preproc_line] = STATE(3548),
    [sym_preproc_pragma] = STATE(3548),
    [sym_preproc_nullable] = STATE(3548),
    [sym_preproc_error] = STATE(3548),
    [sym_preproc_warning] = STATE(3548),
    [sym_preproc_define] = STATE(3548),
    [sym_preproc_undef] = STATE(3548),
    [sym__identifier_token] = ACTIONS(4492),
    [anon_sym_alias] = ACTIONS(4492),
    [anon_sym_global] = ACTIONS(4492),
    [anon_sym_LBRACK] = ACTIONS(4593),
    [anon_sym_LPAREN] = ACTIONS(4494),
    [anon_sym_LBRACE] = ACTIONS(4494),
    [anon_sym_file] = ACTIONS(4492),
    [anon_sym_LT] = ACTIONS(4492),
    [anon_sym_GT] = ACTIONS(4492),
    [anon_sym_where] = ACTIONS(4492),
    [anon_sym_QMARK] = ACTIONS(4596),
    [anon_sym_notnull] = ACTIONS(4492),
    [anon_sym_unmanaged] = ACTIONS(4492),
    [anon_sym_BANG] = ACTIONS(4492),
    [anon_sym_PLUS_PLUS] = ACTIONS(4494),
    [anon_sym_DASH_DASH] = ACTIONS(4494),
    [anon_sym_PLUS] = ACTIONS(4492),
    [anon_sym_DASH] = ACTIONS(4492),
    [anon_sym_STAR] = ACTIONS(4599),
    [anon_sym_SLASH] = ACTIONS(4492),
    [anon_sym_PERCENT] = ACTIONS(4494),
    [anon_sym_CARET] = ACTIONS(4494),
    [anon_sym_PIPE] = ACTIONS(4492),
    [anon_sym_AMP] = ACTIONS(4492),
    [anon_sym_LT_LT] = ACTIONS(4494),
    [anon_sym_GT_GT] = ACTIONS(4492),
    [anon_sym_GT_GT_GT] = ACTIONS(4494),
    [anon_sym_EQ_EQ] = ACTIONS(4494),
    [anon_sym_BANG_EQ] = ACTIONS(4494),
    [anon_sym_GT_EQ] = ACTIONS(4494),
    [anon_sym_LT_EQ] = ACTIONS(4494),
    [anon_sym_DOT] = ACTIONS(5253),
    [anon_sym_scoped] = ACTIONS(4492),
    [anon_sym_var] = ACTIONS(4492),
    [anon_sym_yield] = ACTIONS(4492),
    [anon_sym_switch] = ACTIONS(4492),
    [anon_sym_when] = ACTIONS(4492),
    [sym_discard] = ACTIONS(4492),
    [anon_sym_DOT_DOT] = ACTIONS(4494),
    [anon_sym_and] = ACTIONS(4492),
    [anon_sym_or] = ACTIONS(4492),
    [anon_sym_AMP_AMP] = ACTIONS(4494),
    [anon_sym_PIPE_PIPE] = ACTIONS(4494),
    [anon_sym_QMARK_QMARK] = ACTIONS(4494),
    [anon_sym_from] = ACTIONS(4492),
    [anon_sym_into] = ACTIONS(4492),
    [anon_sym_join] = ACTIONS(4492),
    [anon_sym_on] = ACTIONS(4492),
    [anon_sym_equals] = ACTIONS(4492),
    [anon_sym_let] = ACTIONS(4492),
    [anon_sym_orderby] = ACTIONS(4492),
    [anon_sym_ascending] = ACTIONS(4492),
    [anon_sym_descending] = ACTIONS(4492),
    [anon_sym_group] = ACTIONS(4492),
    [anon_sym_by] = ACTIONS(4492),
    [anon_sym_select] = ACTIONS(4492),
    [anon_sym_as] = ACTIONS(4492),
    [anon_sym_is] = ACTIONS(4492),
    [anon_sym_DASH_GT] = ACTIONS(4636),
    [anon_sym_with] = ACTIONS(4492),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3549] = {
    [sym_preproc_region] = STATE(3549),
    [sym_preproc_endregion] = STATE(3549),
    [sym_preproc_line] = STATE(3549),
    [sym_preproc_pragma] = STATE(3549),
    [sym_preproc_nullable] = STATE(3549),
    [sym_preproc_error] = STATE(3549),
    [sym_preproc_warning] = STATE(3549),
    [sym_preproc_define] = STATE(3549),
    [sym_preproc_undef] = STATE(3549),
    [sym__identifier_token] = ACTIONS(4492),
    [anon_sym_alias] = ACTIONS(4492),
    [anon_sym_global] = ACTIONS(4492),
    [anon_sym_LBRACK] = ACTIONS(4593),
    [anon_sym_LPAREN] = ACTIONS(4494),
    [anon_sym_LBRACE] = ACTIONS(4494),
    [anon_sym_file] = ACTIONS(4492),
    [anon_sym_LT] = ACTIONS(4492),
    [anon_sym_GT] = ACTIONS(4492),
    [anon_sym_where] = ACTIONS(4492),
    [anon_sym_QMARK] = ACTIONS(4596),
    [anon_sym_notnull] = ACTIONS(4492),
    [anon_sym_unmanaged] = ACTIONS(4492),
    [anon_sym_BANG] = ACTIONS(4492),
    [anon_sym_PLUS_PLUS] = ACTIONS(4494),
    [anon_sym_DASH_DASH] = ACTIONS(4494),
    [anon_sym_PLUS] = ACTIONS(4492),
    [anon_sym_DASH] = ACTIONS(4492),
    [anon_sym_STAR] = ACTIONS(4599),
    [anon_sym_SLASH] = ACTIONS(4492),
    [anon_sym_PERCENT] = ACTIONS(4494),
    [anon_sym_CARET] = ACTIONS(4494),
    [anon_sym_PIPE] = ACTIONS(4492),
    [anon_sym_AMP] = ACTIONS(4492),
    [anon_sym_LT_LT] = ACTIONS(4494),
    [anon_sym_GT_GT] = ACTIONS(4492),
    [anon_sym_GT_GT_GT] = ACTIONS(4494),
    [anon_sym_EQ_EQ] = ACTIONS(4494),
    [anon_sym_BANG_EQ] = ACTIONS(4494),
    [anon_sym_GT_EQ] = ACTIONS(4494),
    [anon_sym_LT_EQ] = ACTIONS(4494),
    [anon_sym_DOT] = ACTIONS(5255),
    [anon_sym_scoped] = ACTIONS(4492),
    [anon_sym_var] = ACTIONS(4492),
    [anon_sym_yield] = ACTIONS(4492),
    [anon_sym_switch] = ACTIONS(4492),
    [anon_sym_when] = ACTIONS(4492),
    [sym_discard] = ACTIONS(4492),
    [anon_sym_DOT_DOT] = ACTIONS(4494),
    [anon_sym_and] = ACTIONS(4492),
    [anon_sym_or] = ACTIONS(4492),
    [anon_sym_AMP_AMP] = ACTIONS(4494),
    [anon_sym_PIPE_PIPE] = ACTIONS(4494),
    [anon_sym_QMARK_QMARK] = ACTIONS(4494),
    [anon_sym_from] = ACTIONS(4492),
    [anon_sym_into] = ACTIONS(4492),
    [anon_sym_join] = ACTIONS(4492),
    [anon_sym_on] = ACTIONS(4492),
    [anon_sym_equals] = ACTIONS(4492),
    [anon_sym_let] = ACTIONS(4492),
    [anon_sym_orderby] = ACTIONS(4492),
    [anon_sym_ascending] = ACTIONS(4492),
    [anon_sym_descending] = ACTIONS(4492),
    [anon_sym_group] = ACTIONS(4492),
    [anon_sym_by] = ACTIONS(4492),
    [anon_sym_select] = ACTIONS(4492),
    [anon_sym_as] = ACTIONS(4492),
    [anon_sym_is] = ACTIONS(4492),
    [anon_sym_DASH_GT] = ACTIONS(4604),
    [anon_sym_with] = ACTIONS(4492),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3550] = {
    [sym_preproc_region] = STATE(3550),
    [sym_preproc_endregion] = STATE(3550),
    [sym_preproc_line] = STATE(3550),
    [sym_preproc_pragma] = STATE(3550),
    [sym_preproc_nullable] = STATE(3550),
    [sym_preproc_error] = STATE(3550),
    [sym_preproc_warning] = STATE(3550),
    [sym_preproc_define] = STATE(3550),
    [sym_preproc_undef] = STATE(3550),
    [anon_sym_EQ] = ACTIONS(4685),
    [anon_sym_LBRACK] = ACTIONS(4683),
    [anon_sym_COLON] = ACTIONS(4683),
    [anon_sym_COMMA] = ACTIONS(4683),
    [anon_sym_LPAREN] = ACTIONS(4683),
    [anon_sym_LT] = ACTIONS(4685),
    [anon_sym_GT] = ACTIONS(4685),
    [anon_sym_where] = ACTIONS(4683),
    [anon_sym_QMARK] = ACTIONS(4685),
    [anon_sym_BANG] = ACTIONS(4685),
    [anon_sym_PLUS_PLUS] = ACTIONS(4683),
    [anon_sym_DASH_DASH] = ACTIONS(4683),
    [anon_sym_PLUS] = ACTIONS(4685),
    [anon_sym_DASH] = ACTIONS(4685),
    [anon_sym_STAR] = ACTIONS(4685),
    [anon_sym_SLASH] = ACTIONS(4685),
    [anon_sym_PERCENT] = ACTIONS(4685),
    [anon_sym_CARET] = ACTIONS(4685),
    [anon_sym_PIPE] = ACTIONS(4685),
    [anon_sym_AMP] = ACTIONS(4685),
    [anon_sym_LT_LT] = ACTIONS(4685),
    [anon_sym_GT_GT] = ACTIONS(4685),
    [anon_sym_GT_GT_GT] = ACTIONS(4685),
    [anon_sym_EQ_EQ] = ACTIONS(4683),
    [anon_sym_BANG_EQ] = ACTIONS(4683),
    [anon_sym_GT_EQ] = ACTIONS(4683),
    [anon_sym_LT_EQ] = ACTIONS(4683),
    [anon_sym_DOT] = ACTIONS(4685),
    [anon_sym_switch] = ACTIONS(4683),
    [anon_sym_DOT_DOT] = ACTIONS(4683),
    [anon_sym_and] = ACTIONS(4683),
    [anon_sym_or] = ACTIONS(4685),
    [anon_sym_PLUS_EQ] = ACTIONS(4683),
    [anon_sym_DASH_EQ] = ACTIONS(4683),
    [anon_sym_STAR_EQ] = ACTIONS(4683),
    [anon_sym_SLASH_EQ] = ACTIONS(4683),
    [anon_sym_PERCENT_EQ] = ACTIONS(4683),
    [anon_sym_AMP_EQ] = ACTIONS(4683),
    [anon_sym_CARET_EQ] = ACTIONS(4683),
    [anon_sym_PIPE_EQ] = ACTIONS(4683),
    [anon_sym_LT_LT_EQ] = ACTIONS(4683),
    [anon_sym_GT_GT_EQ] = ACTIONS(4683),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4683),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4683),
    [anon_sym_AMP_AMP] = ACTIONS(4683),
    [anon_sym_PIPE_PIPE] = ACTIONS(4683),
    [anon_sym_QMARK_QMARK] = ACTIONS(4685),
    [anon_sym_from] = ACTIONS(4683),
    [anon_sym_into] = ACTIONS(4683),
    [anon_sym_join] = ACTIONS(4683),
    [anon_sym_let] = ACTIONS(4683),
    [anon_sym_orderby] = ACTIONS(4683),
    [anon_sym_ascending] = ACTIONS(4683),
    [anon_sym_descending] = ACTIONS(4683),
    [anon_sym_group] = ACTIONS(4683),
    [anon_sym_select] = ACTIONS(4683),
    [anon_sym_as] = ACTIONS(4685),
    [anon_sym_is] = ACTIONS(4683),
    [anon_sym_DASH_GT] = ACTIONS(4683),
    [anon_sym_with] = ACTIONS(4683),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3551] = {
    [sym_preproc_region] = STATE(3551),
    [sym_preproc_endregion] = STATE(3551),
    [sym_preproc_line] = STATE(3551),
    [sym_preproc_pragma] = STATE(3551),
    [sym_preproc_nullable] = STATE(3551),
    [sym_preproc_error] = STATE(3551),
    [sym_preproc_warning] = STATE(3551),
    [sym_preproc_define] = STATE(3551),
    [sym_preproc_undef] = STATE(3551),
    [sym__identifier_token] = ACTIONS(4674),
    [anon_sym_alias] = ACTIONS(4674),
    [anon_sym_global] = ACTIONS(4674),
    [anon_sym_LBRACK] = ACTIONS(3001),
    [anon_sym_COLON] = ACTIONS(4676),
    [anon_sym_LPAREN] = ACTIONS(4676),
    [anon_sym_file] = ACTIONS(4674),
    [anon_sym_LT] = ACTIONS(2999),
    [anon_sym_GT] = ACTIONS(2999),
    [anon_sym_where] = ACTIONS(4674),
    [anon_sym_QMARK] = ACTIONS(2999),
    [anon_sym_notnull] = ACTIONS(4674),
    [anon_sym_unmanaged] = ACTIONS(4674),
    [anon_sym_BANG] = ACTIONS(2999),
    [anon_sym_PLUS_PLUS] = ACTIONS(3001),
    [anon_sym_DASH_DASH] = ACTIONS(3001),
    [anon_sym_PLUS] = ACTIONS(2999),
    [anon_sym_DASH] = ACTIONS(2999),
    [anon_sym_STAR] = ACTIONS(3001),
    [anon_sym_SLASH] = ACTIONS(2999),
    [anon_sym_PERCENT] = ACTIONS(3001),
    [anon_sym_CARET] = ACTIONS(3001),
    [anon_sym_PIPE] = ACTIONS(2999),
    [anon_sym_AMP] = ACTIONS(2999),
    [anon_sym_LT_LT] = ACTIONS(3001),
    [anon_sym_GT_GT] = ACTIONS(2999),
    [anon_sym_GT_GT_GT] = ACTIONS(3001),
    [anon_sym_EQ_EQ] = ACTIONS(3001),
    [anon_sym_BANG_EQ] = ACTIONS(3001),
    [anon_sym_GT_EQ] = ACTIONS(3001),
    [anon_sym_LT_EQ] = ACTIONS(3001),
    [anon_sym_DOT] = ACTIONS(2999),
    [anon_sym_scoped] = ACTIONS(4674),
    [anon_sym_var] = ACTIONS(4674),
    [anon_sym_yield] = ACTIONS(4674),
    [anon_sym_switch] = ACTIONS(2999),
    [anon_sym_when] = ACTIONS(4674),
    [sym_discard] = ACTIONS(4674),
    [anon_sym_DOT_DOT] = ACTIONS(3001),
    [anon_sym_and] = ACTIONS(4674),
    [anon_sym_or] = ACTIONS(4674),
    [anon_sym_AMP_AMP] = ACTIONS(3001),
    [anon_sym_PIPE_PIPE] = ACTIONS(3001),
    [anon_sym_QMARK_QMARK] = ACTIONS(3001),
    [anon_sym_from] = ACTIONS(4674),
    [anon_sym_into] = ACTIONS(4674),
    [anon_sym_join] = ACTIONS(4674),
    [anon_sym_on] = ACTIONS(4674),
    [anon_sym_equals] = ACTIONS(4674),
    [anon_sym_let] = ACTIONS(4674),
    [anon_sym_orderby] = ACTIONS(4674),
    [anon_sym_ascending] = ACTIONS(4674),
    [anon_sym_descending] = ACTIONS(4674),
    [anon_sym_group] = ACTIONS(4674),
    [anon_sym_by] = ACTIONS(4674),
    [anon_sym_select] = ACTIONS(4674),
    [anon_sym_as] = ACTIONS(2999),
    [anon_sym_is] = ACTIONS(2999),
    [anon_sym_DASH_GT] = ACTIONS(3001),
    [anon_sym_with] = ACTIONS(2999),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3552] = {
    [sym_preproc_region] = STATE(3552),
    [sym_preproc_endregion] = STATE(3552),
    [sym_preproc_line] = STATE(3552),
    [sym_preproc_pragma] = STATE(3552),
    [sym_preproc_nullable] = STATE(3552),
    [sym_preproc_error] = STATE(3552),
    [sym_preproc_warning] = STATE(3552),
    [sym_preproc_define] = STATE(3552),
    [sym_preproc_undef] = STATE(3552),
    [sym__identifier_token] = ACTIONS(4492),
    [anon_sym_alias] = ACTIONS(4492),
    [anon_sym_global] = ACTIONS(4492),
    [anon_sym_LBRACK] = ACTIONS(4593),
    [anon_sym_LPAREN] = ACTIONS(4494),
    [anon_sym_LBRACE] = ACTIONS(4494),
    [anon_sym_file] = ACTIONS(4492),
    [anon_sym_LT] = ACTIONS(4492),
    [anon_sym_GT] = ACTIONS(4492),
    [anon_sym_where] = ACTIONS(4492),
    [anon_sym_QMARK] = ACTIONS(4596),
    [anon_sym_notnull] = ACTIONS(4492),
    [anon_sym_unmanaged] = ACTIONS(4492),
    [anon_sym_BANG] = ACTIONS(4492),
    [anon_sym_PLUS_PLUS] = ACTIONS(4494),
    [anon_sym_DASH_DASH] = ACTIONS(4494),
    [anon_sym_PLUS] = ACTIONS(4492),
    [anon_sym_DASH] = ACTIONS(4492),
    [anon_sym_STAR] = ACTIONS(4599),
    [anon_sym_SLASH] = ACTIONS(4492),
    [anon_sym_PERCENT] = ACTIONS(4494),
    [anon_sym_CARET] = ACTIONS(4494),
    [anon_sym_PIPE] = ACTIONS(4492),
    [anon_sym_AMP] = ACTIONS(4492),
    [anon_sym_LT_LT] = ACTIONS(4494),
    [anon_sym_GT_GT] = ACTIONS(4492),
    [anon_sym_GT_GT_GT] = ACTIONS(4494),
    [anon_sym_EQ_EQ] = ACTIONS(4494),
    [anon_sym_BANG_EQ] = ACTIONS(4494),
    [anon_sym_GT_EQ] = ACTIONS(4494),
    [anon_sym_LT_EQ] = ACTIONS(4494),
    [anon_sym_DOT] = ACTIONS(5257),
    [anon_sym_scoped] = ACTIONS(4492),
    [anon_sym_var] = ACTIONS(4492),
    [anon_sym_yield] = ACTIONS(4492),
    [anon_sym_switch] = ACTIONS(4492),
    [anon_sym_when] = ACTIONS(4492),
    [sym_discard] = ACTIONS(4492),
    [anon_sym_DOT_DOT] = ACTIONS(4494),
    [anon_sym_and] = ACTIONS(4492),
    [anon_sym_or] = ACTIONS(4492),
    [anon_sym_AMP_AMP] = ACTIONS(4494),
    [anon_sym_PIPE_PIPE] = ACTIONS(4494),
    [anon_sym_QMARK_QMARK] = ACTIONS(4494),
    [anon_sym_from] = ACTIONS(4492),
    [anon_sym_into] = ACTIONS(4492),
    [anon_sym_join] = ACTIONS(4492),
    [anon_sym_on] = ACTIONS(4492),
    [anon_sym_equals] = ACTIONS(4492),
    [anon_sym_let] = ACTIONS(4492),
    [anon_sym_orderby] = ACTIONS(4492),
    [anon_sym_ascending] = ACTIONS(4492),
    [anon_sym_descending] = ACTIONS(4492),
    [anon_sym_group] = ACTIONS(4492),
    [anon_sym_by] = ACTIONS(4492),
    [anon_sym_select] = ACTIONS(4492),
    [anon_sym_as] = ACTIONS(4492),
    [anon_sym_is] = ACTIONS(4492),
    [anon_sym_DASH_GT] = ACTIONS(4636),
    [anon_sym_with] = ACTIONS(4492),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3553] = {
    [sym_preproc_region] = STATE(3553),
    [sym_preproc_endregion] = STATE(3553),
    [sym_preproc_line] = STATE(3553),
    [sym_preproc_pragma] = STATE(3553),
    [sym_preproc_nullable] = STATE(3553),
    [sym_preproc_error] = STATE(3553),
    [sym_preproc_warning] = STATE(3553),
    [sym_preproc_define] = STATE(3553),
    [sym_preproc_undef] = STATE(3553),
    [anon_sym_EQ] = ACTIONS(4672),
    [anon_sym_LBRACK] = ACTIONS(4703),
    [anon_sym_COLON] = ACTIONS(4670),
    [anon_sym_COMMA] = ACTIONS(4703),
    [anon_sym_LPAREN] = ACTIONS(4703),
    [anon_sym_LT] = ACTIONS(4705),
    [anon_sym_GT] = ACTIONS(4705),
    [anon_sym_where] = ACTIONS(4703),
    [anon_sym_QMARK] = ACTIONS(4705),
    [anon_sym_BANG] = ACTIONS(4705),
    [anon_sym_PLUS_PLUS] = ACTIONS(4703),
    [anon_sym_DASH_DASH] = ACTIONS(4703),
    [anon_sym_PLUS] = ACTIONS(4705),
    [anon_sym_DASH] = ACTIONS(4705),
    [anon_sym_STAR] = ACTIONS(4705),
    [anon_sym_SLASH] = ACTIONS(4705),
    [anon_sym_PERCENT] = ACTIONS(4705),
    [anon_sym_CARET] = ACTIONS(4705),
    [anon_sym_PIPE] = ACTIONS(4705),
    [anon_sym_AMP] = ACTIONS(4705),
    [anon_sym_LT_LT] = ACTIONS(4705),
    [anon_sym_GT_GT] = ACTIONS(4705),
    [anon_sym_GT_GT_GT] = ACTIONS(4705),
    [anon_sym_EQ_EQ] = ACTIONS(4703),
    [anon_sym_BANG_EQ] = ACTIONS(4703),
    [anon_sym_GT_EQ] = ACTIONS(4703),
    [anon_sym_LT_EQ] = ACTIONS(4703),
    [anon_sym_DOT] = ACTIONS(4705),
    [anon_sym_switch] = ACTIONS(4703),
    [anon_sym_DOT_DOT] = ACTIONS(4703),
    [anon_sym_and] = ACTIONS(4703),
    [anon_sym_or] = ACTIONS(4705),
    [anon_sym_PLUS_EQ] = ACTIONS(4670),
    [anon_sym_DASH_EQ] = ACTIONS(4670),
    [anon_sym_STAR_EQ] = ACTIONS(4670),
    [anon_sym_SLASH_EQ] = ACTIONS(4670),
    [anon_sym_PERCENT_EQ] = ACTIONS(4670),
    [anon_sym_AMP_EQ] = ACTIONS(4670),
    [anon_sym_CARET_EQ] = ACTIONS(4670),
    [anon_sym_PIPE_EQ] = ACTIONS(4670),
    [anon_sym_LT_LT_EQ] = ACTIONS(4670),
    [anon_sym_GT_GT_EQ] = ACTIONS(4670),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4670),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4670),
    [anon_sym_AMP_AMP] = ACTIONS(4703),
    [anon_sym_PIPE_PIPE] = ACTIONS(4703),
    [anon_sym_QMARK_QMARK] = ACTIONS(4705),
    [anon_sym_from] = ACTIONS(4703),
    [anon_sym_into] = ACTIONS(4703),
    [anon_sym_join] = ACTIONS(4703),
    [anon_sym_let] = ACTIONS(4703),
    [anon_sym_orderby] = ACTIONS(4703),
    [anon_sym_ascending] = ACTIONS(4703),
    [anon_sym_descending] = ACTIONS(4703),
    [anon_sym_group] = ACTIONS(4703),
    [anon_sym_select] = ACTIONS(4703),
    [anon_sym_as] = ACTIONS(4705),
    [anon_sym_is] = ACTIONS(4703),
    [anon_sym_DASH_GT] = ACTIONS(4703),
    [anon_sym_with] = ACTIONS(4703),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3554] = {
    [sym_preproc_region] = STATE(3554),
    [sym_preproc_endregion] = STATE(3554),
    [sym_preproc_line] = STATE(3554),
    [sym_preproc_pragma] = STATE(3554),
    [sym_preproc_nullable] = STATE(3554),
    [sym_preproc_error] = STATE(3554),
    [sym_preproc_warning] = STATE(3554),
    [sym_preproc_define] = STATE(3554),
    [sym_preproc_undef] = STATE(3554),
    [sym__identifier_token] = ACTIONS(4492),
    [anon_sym_alias] = ACTIONS(4492),
    [anon_sym_global] = ACTIONS(4492),
    [anon_sym_LBRACK] = ACTIONS(4593),
    [anon_sym_LPAREN] = ACTIONS(4494),
    [anon_sym_LBRACE] = ACTIONS(4494),
    [anon_sym_file] = ACTIONS(4492),
    [anon_sym_LT] = ACTIONS(4492),
    [anon_sym_GT] = ACTIONS(4492),
    [anon_sym_where] = ACTIONS(4492),
    [anon_sym_QMARK] = ACTIONS(4596),
    [anon_sym_notnull] = ACTIONS(4492),
    [anon_sym_unmanaged] = ACTIONS(4492),
    [anon_sym_BANG] = ACTIONS(4492),
    [anon_sym_PLUS_PLUS] = ACTIONS(4494),
    [anon_sym_DASH_DASH] = ACTIONS(4494),
    [anon_sym_PLUS] = ACTIONS(4492),
    [anon_sym_DASH] = ACTIONS(4492),
    [anon_sym_STAR] = ACTIONS(4599),
    [anon_sym_SLASH] = ACTIONS(4492),
    [anon_sym_PERCENT] = ACTIONS(4494),
    [anon_sym_CARET] = ACTIONS(4494),
    [anon_sym_PIPE] = ACTIONS(4492),
    [anon_sym_AMP] = ACTIONS(4492),
    [anon_sym_LT_LT] = ACTIONS(4494),
    [anon_sym_GT_GT] = ACTIONS(4492),
    [anon_sym_GT_GT_GT] = ACTIONS(4494),
    [anon_sym_EQ_EQ] = ACTIONS(4494),
    [anon_sym_BANG_EQ] = ACTIONS(4494),
    [anon_sym_GT_EQ] = ACTIONS(4494),
    [anon_sym_LT_EQ] = ACTIONS(4494),
    [anon_sym_DOT] = ACTIONS(5259),
    [anon_sym_scoped] = ACTIONS(4492),
    [anon_sym_var] = ACTIONS(4492),
    [anon_sym_yield] = ACTIONS(4492),
    [anon_sym_switch] = ACTIONS(4492),
    [anon_sym_when] = ACTIONS(4492),
    [sym_discard] = ACTIONS(4492),
    [anon_sym_DOT_DOT] = ACTIONS(4494),
    [anon_sym_and] = ACTIONS(4492),
    [anon_sym_or] = ACTIONS(4492),
    [anon_sym_AMP_AMP] = ACTIONS(4494),
    [anon_sym_PIPE_PIPE] = ACTIONS(4494),
    [anon_sym_QMARK_QMARK] = ACTIONS(4494),
    [anon_sym_from] = ACTIONS(4492),
    [anon_sym_into] = ACTIONS(4492),
    [anon_sym_join] = ACTIONS(4492),
    [anon_sym_on] = ACTIONS(4492),
    [anon_sym_equals] = ACTIONS(4492),
    [anon_sym_let] = ACTIONS(4492),
    [anon_sym_orderby] = ACTIONS(4492),
    [anon_sym_ascending] = ACTIONS(4492),
    [anon_sym_descending] = ACTIONS(4492),
    [anon_sym_group] = ACTIONS(4492),
    [anon_sym_by] = ACTIONS(4492),
    [anon_sym_select] = ACTIONS(4492),
    [anon_sym_as] = ACTIONS(4492),
    [anon_sym_is] = ACTIONS(4492),
    [anon_sym_DASH_GT] = ACTIONS(4636),
    [anon_sym_with] = ACTIONS(4492),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3555] = {
    [sym_preproc_region] = STATE(3555),
    [sym_preproc_endregion] = STATE(3555),
    [sym_preproc_line] = STATE(3555),
    [sym_preproc_pragma] = STATE(3555),
    [sym_preproc_nullable] = STATE(3555),
    [sym_preproc_error] = STATE(3555),
    [sym_preproc_warning] = STATE(3555),
    [sym_preproc_define] = STATE(3555),
    [sym_preproc_undef] = STATE(3555),
    [sym__identifier_token] = ACTIONS(4492),
    [anon_sym_alias] = ACTIONS(4492),
    [anon_sym_global] = ACTIONS(4492),
    [anon_sym_LBRACK] = ACTIONS(4593),
    [anon_sym_LPAREN] = ACTIONS(4494),
    [anon_sym_LBRACE] = ACTIONS(4494),
    [anon_sym_file] = ACTIONS(4492),
    [anon_sym_LT] = ACTIONS(4492),
    [anon_sym_GT] = ACTIONS(4492),
    [anon_sym_where] = ACTIONS(4492),
    [anon_sym_QMARK] = ACTIONS(4596),
    [anon_sym_notnull] = ACTIONS(4492),
    [anon_sym_unmanaged] = ACTIONS(4492),
    [anon_sym_BANG] = ACTIONS(4492),
    [anon_sym_PLUS_PLUS] = ACTIONS(4494),
    [anon_sym_DASH_DASH] = ACTIONS(4494),
    [anon_sym_PLUS] = ACTIONS(4492),
    [anon_sym_DASH] = ACTIONS(4492),
    [anon_sym_STAR] = ACTIONS(4599),
    [anon_sym_SLASH] = ACTIONS(4492),
    [anon_sym_PERCENT] = ACTIONS(4494),
    [anon_sym_CARET] = ACTIONS(4494),
    [anon_sym_PIPE] = ACTIONS(4492),
    [anon_sym_AMP] = ACTIONS(4492),
    [anon_sym_LT_LT] = ACTIONS(4494),
    [anon_sym_GT_GT] = ACTIONS(4492),
    [anon_sym_GT_GT_GT] = ACTIONS(4494),
    [anon_sym_EQ_EQ] = ACTIONS(4494),
    [anon_sym_BANG_EQ] = ACTIONS(4494),
    [anon_sym_GT_EQ] = ACTIONS(4494),
    [anon_sym_LT_EQ] = ACTIONS(4494),
    [anon_sym_DOT] = ACTIONS(5261),
    [anon_sym_scoped] = ACTIONS(4492),
    [anon_sym_var] = ACTIONS(4492),
    [anon_sym_yield] = ACTIONS(4492),
    [anon_sym_switch] = ACTIONS(4492),
    [anon_sym_when] = ACTIONS(4492),
    [sym_discard] = ACTIONS(4492),
    [anon_sym_DOT_DOT] = ACTIONS(4494),
    [anon_sym_and] = ACTIONS(4492),
    [anon_sym_or] = ACTIONS(4492),
    [anon_sym_AMP_AMP] = ACTIONS(4494),
    [anon_sym_PIPE_PIPE] = ACTIONS(4494),
    [anon_sym_QMARK_QMARK] = ACTIONS(4494),
    [anon_sym_from] = ACTIONS(4492),
    [anon_sym_into] = ACTIONS(4492),
    [anon_sym_join] = ACTIONS(4492),
    [anon_sym_on] = ACTIONS(4492),
    [anon_sym_equals] = ACTIONS(4492),
    [anon_sym_let] = ACTIONS(4492),
    [anon_sym_orderby] = ACTIONS(4492),
    [anon_sym_ascending] = ACTIONS(4492),
    [anon_sym_descending] = ACTIONS(4492),
    [anon_sym_group] = ACTIONS(4492),
    [anon_sym_by] = ACTIONS(4492),
    [anon_sym_select] = ACTIONS(4492),
    [anon_sym_as] = ACTIONS(4492),
    [anon_sym_is] = ACTIONS(4492),
    [anon_sym_DASH_GT] = ACTIONS(4604),
    [anon_sym_with] = ACTIONS(4492),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3556] = {
    [sym_preproc_region] = STATE(3556),
    [sym_preproc_endregion] = STATE(3556),
    [sym_preproc_line] = STATE(3556),
    [sym_preproc_pragma] = STATE(3556),
    [sym_preproc_nullable] = STATE(3556),
    [sym_preproc_error] = STATE(3556),
    [sym_preproc_warning] = STATE(3556),
    [sym_preproc_define] = STATE(3556),
    [sym_preproc_undef] = STATE(3556),
    [anon_sym_EQ] = ACTIONS(4709),
    [anon_sym_LBRACK] = ACTIONS(4707),
    [anon_sym_COLON] = ACTIONS(4707),
    [anon_sym_COMMA] = ACTIONS(4707),
    [anon_sym_LPAREN] = ACTIONS(4707),
    [anon_sym_LT] = ACTIONS(4709),
    [anon_sym_GT] = ACTIONS(4709),
    [anon_sym_where] = ACTIONS(4707),
    [anon_sym_QMARK] = ACTIONS(4709),
    [anon_sym_BANG] = ACTIONS(4709),
    [anon_sym_PLUS_PLUS] = ACTIONS(4707),
    [anon_sym_DASH_DASH] = ACTIONS(4707),
    [anon_sym_PLUS] = ACTIONS(4709),
    [anon_sym_DASH] = ACTIONS(4709),
    [anon_sym_STAR] = ACTIONS(4709),
    [anon_sym_SLASH] = ACTIONS(4709),
    [anon_sym_PERCENT] = ACTIONS(4709),
    [anon_sym_CARET] = ACTIONS(4709),
    [anon_sym_PIPE] = ACTIONS(4709),
    [anon_sym_AMP] = ACTIONS(4709),
    [anon_sym_LT_LT] = ACTIONS(4709),
    [anon_sym_GT_GT] = ACTIONS(4709),
    [anon_sym_GT_GT_GT] = ACTIONS(4709),
    [anon_sym_EQ_EQ] = ACTIONS(4707),
    [anon_sym_BANG_EQ] = ACTIONS(4707),
    [anon_sym_GT_EQ] = ACTIONS(4707),
    [anon_sym_LT_EQ] = ACTIONS(4707),
    [anon_sym_DOT] = ACTIONS(4709),
    [anon_sym_switch] = ACTIONS(4707),
    [anon_sym_DOT_DOT] = ACTIONS(4707),
    [anon_sym_and] = ACTIONS(4707),
    [anon_sym_or] = ACTIONS(4709),
    [anon_sym_PLUS_EQ] = ACTIONS(4707),
    [anon_sym_DASH_EQ] = ACTIONS(4707),
    [anon_sym_STAR_EQ] = ACTIONS(4707),
    [anon_sym_SLASH_EQ] = ACTIONS(4707),
    [anon_sym_PERCENT_EQ] = ACTIONS(4707),
    [anon_sym_AMP_EQ] = ACTIONS(4707),
    [anon_sym_CARET_EQ] = ACTIONS(4707),
    [anon_sym_PIPE_EQ] = ACTIONS(4707),
    [anon_sym_LT_LT_EQ] = ACTIONS(4707),
    [anon_sym_GT_GT_EQ] = ACTIONS(4707),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4707),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4707),
    [anon_sym_AMP_AMP] = ACTIONS(4707),
    [anon_sym_PIPE_PIPE] = ACTIONS(4707),
    [anon_sym_QMARK_QMARK] = ACTIONS(4709),
    [anon_sym_from] = ACTIONS(4707),
    [anon_sym_into] = ACTIONS(4707),
    [anon_sym_join] = ACTIONS(4707),
    [anon_sym_let] = ACTIONS(4707),
    [anon_sym_orderby] = ACTIONS(4707),
    [anon_sym_ascending] = ACTIONS(4707),
    [anon_sym_descending] = ACTIONS(4707),
    [anon_sym_group] = ACTIONS(4707),
    [anon_sym_select] = ACTIONS(4707),
    [anon_sym_as] = ACTIONS(4709),
    [anon_sym_is] = ACTIONS(4707),
    [anon_sym_DASH_GT] = ACTIONS(4707),
    [anon_sym_with] = ACTIONS(4707),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3557] = {
    [sym_argument_list] = STATE(3571),
    [sym_initializer_expression] = STATE(3686),
    [sym_preproc_region] = STATE(3557),
    [sym_preproc_endregion] = STATE(3557),
    [sym_preproc_line] = STATE(3557),
    [sym_preproc_pragma] = STATE(3557),
    [sym_preproc_nullable] = STATE(3557),
    [sym_preproc_error] = STATE(3557),
    [sym_preproc_warning] = STATE(3557),
    [sym_preproc_define] = STATE(3557),
    [sym_preproc_undef] = STATE(3557),
    [anon_sym_SEMI] = ACTIONS(5263),
    [anon_sym_LBRACK] = ACTIONS(5263),
    [anon_sym_COLON] = ACTIONS(5263),
    [anon_sym_COMMA] = ACTIONS(5263),
    [anon_sym_RBRACK] = ACTIONS(5263),
    [anon_sym_LPAREN] = ACTIONS(5265),
    [anon_sym_RPAREN] = ACTIONS(5263),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_RBRACE] = ACTIONS(5263),
    [anon_sym_LT] = ACTIONS(5267),
    [anon_sym_GT] = ACTIONS(5267),
    [anon_sym_in] = ACTIONS(5267),
    [anon_sym_where] = ACTIONS(5263),
    [anon_sym_QMARK] = ACTIONS(5267),
    [anon_sym_BANG] = ACTIONS(5267),
    [anon_sym_PLUS_PLUS] = ACTIONS(5263),
    [anon_sym_DASH_DASH] = ACTIONS(5263),
    [anon_sym_PLUS] = ACTIONS(5267),
    [anon_sym_DASH] = ACTIONS(5267),
    [anon_sym_STAR] = ACTIONS(5263),
    [anon_sym_SLASH] = ACTIONS(5267),
    [anon_sym_PERCENT] = ACTIONS(5263),
    [anon_sym_CARET] = ACTIONS(5263),
    [anon_sym_PIPE] = ACTIONS(5267),
    [anon_sym_AMP] = ACTIONS(5267),
    [anon_sym_LT_LT] = ACTIONS(5263),
    [anon_sym_GT_GT] = ACTIONS(5267),
    [anon_sym_GT_GT_GT] = ACTIONS(5263),
    [anon_sym_EQ_EQ] = ACTIONS(5263),
    [anon_sym_BANG_EQ] = ACTIONS(5263),
    [anon_sym_GT_EQ] = ACTIONS(5263),
    [anon_sym_LT_EQ] = ACTIONS(5263),
    [anon_sym_DOT] = ACTIONS(5267),
    [anon_sym_EQ_GT] = ACTIONS(5263),
    [anon_sym_switch] = ACTIONS(5263),
    [anon_sym_DOT_DOT] = ACTIONS(5263),
    [anon_sym_and] = ACTIONS(5263),
    [anon_sym_or] = ACTIONS(5267),
    [anon_sym_AMP_AMP] = ACTIONS(5263),
    [anon_sym_PIPE_PIPE] = ACTIONS(5263),
    [anon_sym_QMARK_QMARK] = ACTIONS(5263),
    [anon_sym_from] = ACTIONS(5263),
    [anon_sym_into] = ACTIONS(5263),
    [anon_sym_join] = ACTIONS(5263),
    [anon_sym_on] = ACTIONS(5263),
    [anon_sym_equals] = ACTIONS(5263),
    [anon_sym_let] = ACTIONS(5263),
    [anon_sym_orderby] = ACTIONS(5263),
    [anon_sym_group] = ACTIONS(5263),
    [anon_sym_by] = ACTIONS(5263),
    [anon_sym_select] = ACTIONS(5263),
    [anon_sym_as] = ACTIONS(5263),
    [anon_sym_is] = ACTIONS(5263),
    [anon_sym_DASH_GT] = ACTIONS(5263),
    [anon_sym_with] = ACTIONS(5263),
    [aux_sym_preproc_if_token3] = ACTIONS(5263),
    [aux_sym_preproc_else_token1] = ACTIONS(5263),
    [aux_sym_preproc_elif_token1] = ACTIONS(5263),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3558] = {
    [sym_preproc_region] = STATE(3558),
    [sym_preproc_endregion] = STATE(3558),
    [sym_preproc_line] = STATE(3558),
    [sym_preproc_pragma] = STATE(3558),
    [sym_preproc_nullable] = STATE(3558),
    [sym_preproc_error] = STATE(3558),
    [sym_preproc_warning] = STATE(3558),
    [sym_preproc_define] = STATE(3558),
    [sym_preproc_undef] = STATE(3558),
    [anon_sym_EQ] = ACTIONS(4642),
    [anon_sym_LBRACK] = ACTIONS(4640),
    [anon_sym_COLON] = ACTIONS(4640),
    [anon_sym_COMMA] = ACTIONS(4640),
    [anon_sym_LPAREN] = ACTIONS(4640),
    [anon_sym_LT] = ACTIONS(4642),
    [anon_sym_GT] = ACTIONS(4642),
    [anon_sym_where] = ACTIONS(4640),
    [anon_sym_QMARK] = ACTIONS(4642),
    [anon_sym_BANG] = ACTIONS(4642),
    [anon_sym_PLUS_PLUS] = ACTIONS(4640),
    [anon_sym_DASH_DASH] = ACTIONS(4640),
    [anon_sym_PLUS] = ACTIONS(4642),
    [anon_sym_DASH] = ACTIONS(4642),
    [anon_sym_STAR] = ACTIONS(4642),
    [anon_sym_SLASH] = ACTIONS(4642),
    [anon_sym_PERCENT] = ACTIONS(4642),
    [anon_sym_CARET] = ACTIONS(4642),
    [anon_sym_PIPE] = ACTIONS(4642),
    [anon_sym_AMP] = ACTIONS(4642),
    [anon_sym_LT_LT] = ACTIONS(4642),
    [anon_sym_GT_GT] = ACTIONS(4642),
    [anon_sym_GT_GT_GT] = ACTIONS(4642),
    [anon_sym_EQ_EQ] = ACTIONS(4640),
    [anon_sym_BANG_EQ] = ACTIONS(4640),
    [anon_sym_GT_EQ] = ACTIONS(4640),
    [anon_sym_LT_EQ] = ACTIONS(4640),
    [anon_sym_DOT] = ACTIONS(4642),
    [anon_sym_switch] = ACTIONS(4640),
    [anon_sym_DOT_DOT] = ACTIONS(4640),
    [anon_sym_and] = ACTIONS(4640),
    [anon_sym_or] = ACTIONS(4642),
    [anon_sym_PLUS_EQ] = ACTIONS(4640),
    [anon_sym_DASH_EQ] = ACTIONS(4640),
    [anon_sym_STAR_EQ] = ACTIONS(4640),
    [anon_sym_SLASH_EQ] = ACTIONS(4640),
    [anon_sym_PERCENT_EQ] = ACTIONS(4640),
    [anon_sym_AMP_EQ] = ACTIONS(4640),
    [anon_sym_CARET_EQ] = ACTIONS(4640),
    [anon_sym_PIPE_EQ] = ACTIONS(4640),
    [anon_sym_LT_LT_EQ] = ACTIONS(4640),
    [anon_sym_GT_GT_EQ] = ACTIONS(4640),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4640),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4640),
    [anon_sym_AMP_AMP] = ACTIONS(4640),
    [anon_sym_PIPE_PIPE] = ACTIONS(4640),
    [anon_sym_QMARK_QMARK] = ACTIONS(4642),
    [anon_sym_from] = ACTIONS(4640),
    [anon_sym_into] = ACTIONS(4640),
    [anon_sym_join] = ACTIONS(4640),
    [anon_sym_let] = ACTIONS(4640),
    [anon_sym_orderby] = ACTIONS(4640),
    [anon_sym_ascending] = ACTIONS(4640),
    [anon_sym_descending] = ACTIONS(4640),
    [anon_sym_group] = ACTIONS(4640),
    [anon_sym_select] = ACTIONS(4640),
    [anon_sym_as] = ACTIONS(4642),
    [anon_sym_is] = ACTIONS(4640),
    [anon_sym_DASH_GT] = ACTIONS(4640),
    [anon_sym_with] = ACTIONS(4640),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3559] = {
    [sym_preproc_region] = STATE(3559),
    [sym_preproc_endregion] = STATE(3559),
    [sym_preproc_line] = STATE(3559),
    [sym_preproc_pragma] = STATE(3559),
    [sym_preproc_nullable] = STATE(3559),
    [sym_preproc_error] = STATE(3559),
    [sym_preproc_warning] = STATE(3559),
    [sym_preproc_define] = STATE(3559),
    [sym_preproc_undef] = STATE(3559),
    [sym__identifier_token] = ACTIONS(4492),
    [anon_sym_alias] = ACTIONS(4492),
    [anon_sym_global] = ACTIONS(4492),
    [anon_sym_LBRACK] = ACTIONS(4593),
    [anon_sym_LPAREN] = ACTIONS(4494),
    [anon_sym_LBRACE] = ACTIONS(4494),
    [anon_sym_file] = ACTIONS(4492),
    [anon_sym_LT] = ACTIONS(4492),
    [anon_sym_GT] = ACTIONS(4492),
    [anon_sym_where] = ACTIONS(4492),
    [anon_sym_QMARK] = ACTIONS(4596),
    [anon_sym_notnull] = ACTIONS(4492),
    [anon_sym_unmanaged] = ACTIONS(4492),
    [anon_sym_BANG] = ACTIONS(4492),
    [anon_sym_PLUS_PLUS] = ACTIONS(4494),
    [anon_sym_DASH_DASH] = ACTIONS(4494),
    [anon_sym_PLUS] = ACTIONS(4492),
    [anon_sym_DASH] = ACTIONS(4492),
    [anon_sym_STAR] = ACTIONS(4599),
    [anon_sym_SLASH] = ACTIONS(4492),
    [anon_sym_PERCENT] = ACTIONS(4494),
    [anon_sym_CARET] = ACTIONS(4494),
    [anon_sym_PIPE] = ACTIONS(4492),
    [anon_sym_AMP] = ACTIONS(4492),
    [anon_sym_LT_LT] = ACTIONS(4494),
    [anon_sym_GT_GT] = ACTIONS(4492),
    [anon_sym_GT_GT_GT] = ACTIONS(4494),
    [anon_sym_EQ_EQ] = ACTIONS(4494),
    [anon_sym_BANG_EQ] = ACTIONS(4494),
    [anon_sym_GT_EQ] = ACTIONS(4494),
    [anon_sym_LT_EQ] = ACTIONS(4494),
    [anon_sym_DOT] = ACTIONS(5269),
    [anon_sym_scoped] = ACTIONS(4492),
    [anon_sym_var] = ACTIONS(4492),
    [anon_sym_yield] = ACTIONS(4492),
    [anon_sym_switch] = ACTIONS(4492),
    [anon_sym_when] = ACTIONS(4492),
    [sym_discard] = ACTIONS(4492),
    [anon_sym_DOT_DOT] = ACTIONS(4494),
    [anon_sym_and] = ACTIONS(4492),
    [anon_sym_or] = ACTIONS(4492),
    [anon_sym_AMP_AMP] = ACTIONS(4494),
    [anon_sym_PIPE_PIPE] = ACTIONS(4494),
    [anon_sym_QMARK_QMARK] = ACTIONS(4494),
    [anon_sym_from] = ACTIONS(4492),
    [anon_sym_into] = ACTIONS(4492),
    [anon_sym_join] = ACTIONS(4492),
    [anon_sym_on] = ACTIONS(4492),
    [anon_sym_equals] = ACTIONS(4492),
    [anon_sym_let] = ACTIONS(4492),
    [anon_sym_orderby] = ACTIONS(4492),
    [anon_sym_ascending] = ACTIONS(4492),
    [anon_sym_descending] = ACTIONS(4492),
    [anon_sym_group] = ACTIONS(4492),
    [anon_sym_by] = ACTIONS(4492),
    [anon_sym_select] = ACTIONS(4492),
    [anon_sym_as] = ACTIONS(4492),
    [anon_sym_is] = ACTIONS(4492),
    [anon_sym_DASH_GT] = ACTIONS(4604),
    [anon_sym_with] = ACTIONS(4492),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3560] = {
    [sym_preproc_region] = STATE(3560),
    [sym_preproc_endregion] = STATE(3560),
    [sym_preproc_line] = STATE(3560),
    [sym_preproc_pragma] = STATE(3560),
    [sym_preproc_nullable] = STATE(3560),
    [sym_preproc_error] = STATE(3560),
    [sym_preproc_warning] = STATE(3560),
    [sym_preproc_define] = STATE(3560),
    [sym_preproc_undef] = STATE(3560),
    [anon_sym_SEMI] = ACTIONS(3039),
    [anon_sym_LBRACK] = ACTIONS(3039),
    [anon_sym_COLON] = ACTIONS(3039),
    [anon_sym_COMMA] = ACTIONS(3039),
    [anon_sym_RBRACK] = ACTIONS(3039),
    [anon_sym_LPAREN] = ACTIONS(3039),
    [anon_sym_RPAREN] = ACTIONS(3039),
    [anon_sym_RBRACE] = ACTIONS(3039),
    [anon_sym_LT] = ACTIONS(3037),
    [anon_sym_GT] = ACTIONS(3037),
    [anon_sym_in] = ACTIONS(3039),
    [anon_sym_where] = ACTIONS(3039),
    [anon_sym_QMARK] = ACTIONS(3037),
    [anon_sym_BANG] = ACTIONS(3037),
    [anon_sym_PLUS_PLUS] = ACTIONS(3039),
    [anon_sym_DASH_DASH] = ACTIONS(3039),
    [anon_sym_PLUS] = ACTIONS(3037),
    [anon_sym_DASH] = ACTIONS(3037),
    [anon_sym_STAR] = ACTIONS(3039),
    [anon_sym_SLASH] = ACTIONS(3037),
    [anon_sym_PERCENT] = ACTIONS(3039),
    [anon_sym_CARET] = ACTIONS(3039),
    [anon_sym_PIPE] = ACTIONS(3037),
    [anon_sym_AMP] = ACTIONS(3037),
    [anon_sym_LT_LT] = ACTIONS(3039),
    [anon_sym_GT_GT] = ACTIONS(3037),
    [anon_sym_GT_GT_GT] = ACTIONS(3039),
    [anon_sym_EQ_EQ] = ACTIONS(3039),
    [anon_sym_BANG_EQ] = ACTIONS(3039),
    [anon_sym_GT_EQ] = ACTIONS(3039),
    [anon_sym_LT_EQ] = ACTIONS(3039),
    [anon_sym_DOT] = ACTIONS(3037),
    [anon_sym_EQ_GT] = ACTIONS(3039),
    [anon_sym_while] = ACTIONS(3039),
    [anon_sym_switch] = ACTIONS(3039),
    [anon_sym_catch] = ACTIONS(3039),
    [anon_sym_finally] = ACTIONS(3039),
    [anon_sym_else] = ACTIONS(3039),
    [anon_sym_DOT_DOT] = ACTIONS(3039),
    [anon_sym_and] = ACTIONS(3039),
    [anon_sym_or] = ACTIONS(3037),
    [anon_sym_AMP_AMP] = ACTIONS(3039),
    [anon_sym_PIPE_PIPE] = ACTIONS(3039),
    [anon_sym_QMARK_QMARK] = ACTIONS(3039),
    [anon_sym_from] = ACTIONS(3039),
    [anon_sym_join] = ACTIONS(3039),
    [anon_sym_on] = ACTIONS(3039),
    [anon_sym_equals] = ACTIONS(3039),
    [anon_sym_let] = ACTIONS(3039),
    [anon_sym_orderby] = ACTIONS(3039),
    [anon_sym_group] = ACTIONS(3039),
    [anon_sym_by] = ACTIONS(3039),
    [anon_sym_select] = ACTIONS(3039),
    [anon_sym_as] = ACTIONS(3039),
    [anon_sym_is] = ACTIONS(3039),
    [anon_sym_DASH_GT] = ACTIONS(3039),
    [anon_sym_with] = ACTIONS(3039),
    [aux_sym_preproc_if_token3] = ACTIONS(3039),
    [aux_sym_preproc_else_token1] = ACTIONS(3039),
    [aux_sym_preproc_elif_token1] = ACTIONS(3039),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3561] = {
    [sym_argument_list] = STATE(3682),
    [sym_bracketed_argument_list] = STATE(3001),
    [sym_preproc_region] = STATE(3561),
    [sym_preproc_endregion] = STATE(3561),
    [sym_preproc_line] = STATE(3561),
    [sym_preproc_pragma] = STATE(3561),
    [sym_preproc_nullable] = STATE(3561),
    [sym_preproc_error] = STATE(3561),
    [sym_preproc_warning] = STATE(3561),
    [sym_preproc_define] = STATE(3561),
    [sym_preproc_undef] = STATE(3561),
    [anon_sym_SEMI] = ACTIONS(5271),
    [anon_sym_LBRACK] = ACTIONS(5273),
    [anon_sym_COLON] = ACTIONS(5271),
    [anon_sym_COMMA] = ACTIONS(5271),
    [anon_sym_RBRACK] = ACTIONS(5271),
    [anon_sym_LPAREN] = ACTIONS(5265),
    [anon_sym_RPAREN] = ACTIONS(5271),
    [anon_sym_RBRACE] = ACTIONS(5271),
    [anon_sym_LT] = ACTIONS(5275),
    [anon_sym_GT] = ACTIONS(5275),
    [anon_sym_in] = ACTIONS(5275),
    [anon_sym_where] = ACTIONS(5271),
    [anon_sym_QMARK] = ACTIONS(5275),
    [anon_sym_BANG] = ACTIONS(5277),
    [anon_sym_PLUS_PLUS] = ACTIONS(5279),
    [anon_sym_DASH_DASH] = ACTIONS(5279),
    [anon_sym_PLUS] = ACTIONS(5275),
    [anon_sym_DASH] = ACTIONS(5275),
    [anon_sym_STAR] = ACTIONS(5271),
    [anon_sym_SLASH] = ACTIONS(5275),
    [anon_sym_PERCENT] = ACTIONS(5271),
    [anon_sym_CARET] = ACTIONS(5271),
    [anon_sym_PIPE] = ACTIONS(5275),
    [anon_sym_AMP] = ACTIONS(5275),
    [anon_sym_LT_LT] = ACTIONS(5271),
    [anon_sym_GT_GT] = ACTIONS(5275),
    [anon_sym_GT_GT_GT] = ACTIONS(5271),
    [anon_sym_EQ_EQ] = ACTIONS(5271),
    [anon_sym_BANG_EQ] = ACTIONS(5271),
    [anon_sym_GT_EQ] = ACTIONS(5271),
    [anon_sym_LT_EQ] = ACTIONS(5271),
    [anon_sym_DOT] = ACTIONS(5249),
    [anon_sym_EQ_GT] = ACTIONS(5271),
    [anon_sym_switch] = ACTIONS(5271),
    [anon_sym_DOT_DOT] = ACTIONS(5271),
    [anon_sym_and] = ACTIONS(5271),
    [anon_sym_or] = ACTIONS(5275),
    [anon_sym_AMP_AMP] = ACTIONS(5271),
    [anon_sym_PIPE_PIPE] = ACTIONS(5271),
    [anon_sym_QMARK_QMARK] = ACTIONS(5271),
    [anon_sym_from] = ACTIONS(5271),
    [anon_sym_into] = ACTIONS(5271),
    [anon_sym_join] = ACTIONS(5271),
    [anon_sym_on] = ACTIONS(5271),
    [anon_sym_equals] = ACTIONS(5271),
    [anon_sym_let] = ACTIONS(5271),
    [anon_sym_orderby] = ACTIONS(5271),
    [anon_sym_group] = ACTIONS(5271),
    [anon_sym_by] = ACTIONS(5271),
    [anon_sym_select] = ACTIONS(5271),
    [anon_sym_as] = ACTIONS(5271),
    [anon_sym_is] = ACTIONS(5271),
    [anon_sym_DASH_GT] = ACTIONS(5247),
    [anon_sym_with] = ACTIONS(5271),
    [aux_sym_preproc_if_token3] = ACTIONS(5271),
    [aux_sym_preproc_else_token1] = ACTIONS(5271),
    [aux_sym_preproc_elif_token1] = ACTIONS(5271),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3562] = {
    [sym_type_argument_list] = STATE(3607),
    [sym_preproc_region] = STATE(3562),
    [sym_preproc_endregion] = STATE(3562),
    [sym_preproc_line] = STATE(3562),
    [sym_preproc_pragma] = STATE(3562),
    [sym_preproc_nullable] = STATE(3562),
    [sym_preproc_error] = STATE(3562),
    [sym_preproc_warning] = STATE(3562),
    [sym_preproc_define] = STATE(3562),
    [sym_preproc_undef] = STATE(3562),
    [anon_sym_SEMI] = ACTIONS(4140),
    [anon_sym_LBRACK] = ACTIONS(4140),
    [anon_sym_COLON] = ACTIONS(4140),
    [anon_sym_COMMA] = ACTIONS(4140),
    [anon_sym_RBRACK] = ACTIONS(4140),
    [anon_sym_LPAREN] = ACTIONS(4140),
    [anon_sym_RPAREN] = ACTIONS(4140),
    [anon_sym_LBRACE] = ACTIONS(4140),
    [anon_sym_RBRACE] = ACTIONS(4140),
    [anon_sym_LT] = ACTIONS(5281),
    [anon_sym_GT] = ACTIONS(4138),
    [anon_sym_in] = ACTIONS(4138),
    [anon_sym_where] = ACTIONS(4140),
    [anon_sym_QMARK] = ACTIONS(4138),
    [anon_sym_BANG] = ACTIONS(4138),
    [anon_sym_PLUS_PLUS] = ACTIONS(4140),
    [anon_sym_DASH_DASH] = ACTIONS(4140),
    [anon_sym_PLUS] = ACTIONS(4138),
    [anon_sym_DASH] = ACTIONS(4138),
    [anon_sym_STAR] = ACTIONS(4140),
    [anon_sym_SLASH] = ACTIONS(4138),
    [anon_sym_PERCENT] = ACTIONS(4140),
    [anon_sym_CARET] = ACTIONS(4140),
    [anon_sym_PIPE] = ACTIONS(4138),
    [anon_sym_AMP] = ACTIONS(4138),
    [anon_sym_LT_LT] = ACTIONS(4140),
    [anon_sym_GT_GT] = ACTIONS(4138),
    [anon_sym_GT_GT_GT] = ACTIONS(4140),
    [anon_sym_EQ_EQ] = ACTIONS(4140),
    [anon_sym_BANG_EQ] = ACTIONS(4140),
    [anon_sym_GT_EQ] = ACTIONS(4140),
    [anon_sym_LT_EQ] = ACTIONS(4140),
    [anon_sym_DOT] = ACTIONS(4138),
    [anon_sym_EQ_GT] = ACTIONS(4140),
    [anon_sym_switch] = ACTIONS(4140),
    [anon_sym_DOT_DOT] = ACTIONS(4140),
    [anon_sym_and] = ACTIONS(4140),
    [anon_sym_or] = ACTIONS(4138),
    [anon_sym_AMP_AMP] = ACTIONS(4140),
    [anon_sym_PIPE_PIPE] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK] = ACTIONS(4140),
    [anon_sym_from] = ACTIONS(4140),
    [anon_sym_into] = ACTIONS(4140),
    [anon_sym_join] = ACTIONS(4140),
    [anon_sym_on] = ACTIONS(4140),
    [anon_sym_equals] = ACTIONS(4140),
    [anon_sym_let] = ACTIONS(4140),
    [anon_sym_orderby] = ACTIONS(4140),
    [anon_sym_group] = ACTIONS(4140),
    [anon_sym_by] = ACTIONS(4140),
    [anon_sym_select] = ACTIONS(4140),
    [anon_sym_as] = ACTIONS(4140),
    [anon_sym_is] = ACTIONS(4140),
    [anon_sym_DASH_GT] = ACTIONS(4140),
    [anon_sym_with] = ACTIONS(4140),
    [aux_sym_preproc_if_token3] = ACTIONS(4140),
    [aux_sym_preproc_else_token1] = ACTIONS(4140),
    [aux_sym_preproc_elif_token1] = ACTIONS(4140),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3563] = {
    [sym_preproc_region] = STATE(3563),
    [sym_preproc_endregion] = STATE(3563),
    [sym_preproc_line] = STATE(3563),
    [sym_preproc_pragma] = STATE(3563),
    [sym_preproc_nullable] = STATE(3563),
    [sym_preproc_error] = STATE(3563),
    [sym_preproc_warning] = STATE(3563),
    [sym_preproc_define] = STATE(3563),
    [sym_preproc_undef] = STATE(3563),
    [anon_sym_EQ] = ACTIONS(4689),
    [anon_sym_LBRACK] = ACTIONS(4687),
    [anon_sym_COMMA] = ACTIONS(4687),
    [anon_sym_LPAREN] = ACTIONS(4687),
    [anon_sym_LT] = ACTIONS(4689),
    [anon_sym_GT] = ACTIONS(4689),
    [anon_sym_where] = ACTIONS(4687),
    [anon_sym_QMARK] = ACTIONS(4689),
    [anon_sym_BANG] = ACTIONS(4689),
    [anon_sym_PLUS_PLUS] = ACTIONS(4687),
    [anon_sym_DASH_DASH] = ACTIONS(4687),
    [anon_sym_PLUS] = ACTIONS(4689),
    [anon_sym_DASH] = ACTIONS(4689),
    [anon_sym_STAR] = ACTIONS(4689),
    [anon_sym_SLASH] = ACTIONS(4689),
    [anon_sym_PERCENT] = ACTIONS(4689),
    [anon_sym_CARET] = ACTIONS(4689),
    [anon_sym_PIPE] = ACTIONS(4689),
    [anon_sym_AMP] = ACTIONS(4689),
    [anon_sym_LT_LT] = ACTIONS(4689),
    [anon_sym_GT_GT] = ACTIONS(4689),
    [anon_sym_GT_GT_GT] = ACTIONS(4689),
    [anon_sym_EQ_EQ] = ACTIONS(4687),
    [anon_sym_BANG_EQ] = ACTIONS(4687),
    [anon_sym_GT_EQ] = ACTIONS(4687),
    [anon_sym_LT_EQ] = ACTIONS(4687),
    [anon_sym_DOT] = ACTIONS(4689),
    [anon_sym_switch] = ACTIONS(4687),
    [anon_sym_DOT_DOT] = ACTIONS(4687),
    [anon_sym_and] = ACTIONS(4687),
    [anon_sym_or] = ACTIONS(4689),
    [anon_sym_PLUS_EQ] = ACTIONS(4687),
    [anon_sym_DASH_EQ] = ACTIONS(4687),
    [anon_sym_STAR_EQ] = ACTIONS(4687),
    [anon_sym_SLASH_EQ] = ACTIONS(4687),
    [anon_sym_PERCENT_EQ] = ACTIONS(4687),
    [anon_sym_AMP_EQ] = ACTIONS(4687),
    [anon_sym_CARET_EQ] = ACTIONS(4687),
    [anon_sym_PIPE_EQ] = ACTIONS(4687),
    [anon_sym_LT_LT_EQ] = ACTIONS(4687),
    [anon_sym_GT_GT_EQ] = ACTIONS(4687),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4687),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4687),
    [anon_sym_AMP_AMP] = ACTIONS(4687),
    [anon_sym_PIPE_PIPE] = ACTIONS(4687),
    [anon_sym_QMARK_QMARK] = ACTIONS(4689),
    [anon_sym_from] = ACTIONS(4687),
    [anon_sym_into] = ACTIONS(4687),
    [anon_sym_join] = ACTIONS(4687),
    [anon_sym_let] = ACTIONS(4687),
    [anon_sym_orderby] = ACTIONS(4687),
    [anon_sym_ascending] = ACTIONS(4687),
    [anon_sym_descending] = ACTIONS(4687),
    [anon_sym_group] = ACTIONS(4687),
    [anon_sym_select] = ACTIONS(4687),
    [anon_sym_as] = ACTIONS(4689),
    [anon_sym_is] = ACTIONS(4687),
    [anon_sym_DASH_GT] = ACTIONS(4687),
    [anon_sym_with] = ACTIONS(4687),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3564] = {
    [sym_preproc_region] = STATE(3564),
    [sym_preproc_endregion] = STATE(3564),
    [sym_preproc_line] = STATE(3564),
    [sym_preproc_pragma] = STATE(3564),
    [sym_preproc_nullable] = STATE(3564),
    [sym_preproc_error] = STATE(3564),
    [sym_preproc_warning] = STATE(3564),
    [sym_preproc_define] = STATE(3564),
    [sym_preproc_undef] = STATE(3564),
    [anon_sym_EQ] = ACTIONS(4183),
    [anon_sym_LBRACK] = ACTIONS(4191),
    [anon_sym_COMMA] = ACTIONS(4191),
    [anon_sym_LPAREN] = ACTIONS(4191),
    [anon_sym_LT] = ACTIONS(4183),
    [anon_sym_GT] = ACTIONS(4183),
    [anon_sym_where] = ACTIONS(4191),
    [anon_sym_QMARK] = ACTIONS(4183),
    [anon_sym_BANG] = ACTIONS(4183),
    [anon_sym_PLUS_PLUS] = ACTIONS(4191),
    [anon_sym_DASH_DASH] = ACTIONS(4191),
    [anon_sym_PLUS] = ACTIONS(4183),
    [anon_sym_DASH] = ACTIONS(4183),
    [anon_sym_STAR] = ACTIONS(4183),
    [anon_sym_SLASH] = ACTIONS(4183),
    [anon_sym_PERCENT] = ACTIONS(4183),
    [anon_sym_CARET] = ACTIONS(4183),
    [anon_sym_PIPE] = ACTIONS(4183),
    [anon_sym_AMP] = ACTIONS(4183),
    [anon_sym_LT_LT] = ACTIONS(4183),
    [anon_sym_GT_GT] = ACTIONS(4183),
    [anon_sym_GT_GT_GT] = ACTIONS(4183),
    [anon_sym_EQ_EQ] = ACTIONS(4191),
    [anon_sym_BANG_EQ] = ACTIONS(4191),
    [anon_sym_GT_EQ] = ACTIONS(4191),
    [anon_sym_LT_EQ] = ACTIONS(4191),
    [anon_sym_DOT] = ACTIONS(4183),
    [anon_sym_switch] = ACTIONS(4191),
    [anon_sym_DOT_DOT] = ACTIONS(4191),
    [anon_sym_and] = ACTIONS(4191),
    [anon_sym_or] = ACTIONS(4183),
    [anon_sym_PLUS_EQ] = ACTIONS(4191),
    [anon_sym_DASH_EQ] = ACTIONS(4191),
    [anon_sym_STAR_EQ] = ACTIONS(4191),
    [anon_sym_SLASH_EQ] = ACTIONS(4191),
    [anon_sym_PERCENT_EQ] = ACTIONS(4191),
    [anon_sym_AMP_EQ] = ACTIONS(4191),
    [anon_sym_CARET_EQ] = ACTIONS(4191),
    [anon_sym_PIPE_EQ] = ACTIONS(4191),
    [anon_sym_LT_LT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4191),
    [anon_sym_AMP_AMP] = ACTIONS(4191),
    [anon_sym_PIPE_PIPE] = ACTIONS(4191),
    [anon_sym_QMARK_QMARK] = ACTIONS(4183),
    [anon_sym_from] = ACTIONS(4191),
    [anon_sym_into] = ACTIONS(4191),
    [anon_sym_join] = ACTIONS(4191),
    [anon_sym_let] = ACTIONS(4191),
    [anon_sym_orderby] = ACTIONS(4191),
    [anon_sym_ascending] = ACTIONS(4191),
    [anon_sym_descending] = ACTIONS(4191),
    [anon_sym_group] = ACTIONS(4191),
    [anon_sym_select] = ACTIONS(4191),
    [anon_sym_as] = ACTIONS(4183),
    [anon_sym_is] = ACTIONS(4191),
    [anon_sym_DASH_GT] = ACTIONS(4191),
    [anon_sym_with] = ACTIONS(4191),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3565] = {
    [sym_preproc_region] = STATE(3565),
    [sym_preproc_endregion] = STATE(3565),
    [sym_preproc_line] = STATE(3565),
    [sym_preproc_pragma] = STATE(3565),
    [sym_preproc_nullable] = STATE(3565),
    [sym_preproc_error] = STATE(3565),
    [sym_preproc_warning] = STATE(3565),
    [sym_preproc_define] = STATE(3565),
    [sym_preproc_undef] = STATE(3565),
    [anon_sym_EQ] = ACTIONS(5284),
    [anon_sym_LBRACK] = ACTIONS(5286),
    [anon_sym_COMMA] = ACTIONS(5286),
    [anon_sym_LPAREN] = ACTIONS(5286),
    [anon_sym_LT] = ACTIONS(5288),
    [anon_sym_GT] = ACTIONS(5288),
    [anon_sym_where] = ACTIONS(5286),
    [anon_sym_QMARK] = ACTIONS(5288),
    [anon_sym_BANG] = ACTIONS(5288),
    [anon_sym_PLUS_PLUS] = ACTIONS(5286),
    [anon_sym_DASH_DASH] = ACTIONS(5286),
    [anon_sym_PLUS] = ACTIONS(5288),
    [anon_sym_DASH] = ACTIONS(5288),
    [anon_sym_STAR] = ACTIONS(5288),
    [anon_sym_SLASH] = ACTIONS(5288),
    [anon_sym_PERCENT] = ACTIONS(5288),
    [anon_sym_CARET] = ACTIONS(5288),
    [anon_sym_PIPE] = ACTIONS(5288),
    [anon_sym_AMP] = ACTIONS(5288),
    [anon_sym_LT_LT] = ACTIONS(5288),
    [anon_sym_GT_GT] = ACTIONS(5288),
    [anon_sym_GT_GT_GT] = ACTIONS(5288),
    [anon_sym_EQ_EQ] = ACTIONS(5286),
    [anon_sym_BANG_EQ] = ACTIONS(5286),
    [anon_sym_GT_EQ] = ACTIONS(5286),
    [anon_sym_LT_EQ] = ACTIONS(5286),
    [anon_sym_DOT] = ACTIONS(5288),
    [anon_sym_switch] = ACTIONS(5286),
    [anon_sym_DOT_DOT] = ACTIONS(5286),
    [anon_sym_and] = ACTIONS(5286),
    [anon_sym_or] = ACTIONS(5288),
    [anon_sym_PLUS_EQ] = ACTIONS(5290),
    [anon_sym_DASH_EQ] = ACTIONS(5290),
    [anon_sym_STAR_EQ] = ACTIONS(5290),
    [anon_sym_SLASH_EQ] = ACTIONS(5290),
    [anon_sym_PERCENT_EQ] = ACTIONS(5290),
    [anon_sym_AMP_EQ] = ACTIONS(5290),
    [anon_sym_CARET_EQ] = ACTIONS(5290),
    [anon_sym_PIPE_EQ] = ACTIONS(5290),
    [anon_sym_LT_LT_EQ] = ACTIONS(5290),
    [anon_sym_GT_GT_EQ] = ACTIONS(5290),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(5290),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(5290),
    [anon_sym_AMP_AMP] = ACTIONS(5286),
    [anon_sym_PIPE_PIPE] = ACTIONS(5286),
    [anon_sym_QMARK_QMARK] = ACTIONS(5288),
    [anon_sym_from] = ACTIONS(5286),
    [anon_sym_into] = ACTIONS(5286),
    [anon_sym_join] = ACTIONS(5286),
    [anon_sym_let] = ACTIONS(5286),
    [anon_sym_orderby] = ACTIONS(5286),
    [anon_sym_ascending] = ACTIONS(5286),
    [anon_sym_descending] = ACTIONS(5286),
    [anon_sym_group] = ACTIONS(5286),
    [anon_sym_select] = ACTIONS(5286),
    [anon_sym_as] = ACTIONS(5288),
    [anon_sym_is] = ACTIONS(5286),
    [anon_sym_DASH_GT] = ACTIONS(5286),
    [anon_sym_with] = ACTIONS(5286),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3566] = {
    [sym_preproc_region] = STATE(3566),
    [sym_preproc_endregion] = STATE(3566),
    [sym_preproc_line] = STATE(3566),
    [sym_preproc_pragma] = STATE(3566),
    [sym_preproc_nullable] = STATE(3566),
    [sym_preproc_error] = STATE(3566),
    [sym_preproc_warning] = STATE(3566),
    [sym_preproc_define] = STATE(3566),
    [sym_preproc_undef] = STATE(3566),
    [anon_sym_EQ] = ACTIONS(4672),
    [anon_sym_LBRACK] = ACTIONS(4670),
    [anon_sym_COMMA] = ACTIONS(4670),
    [anon_sym_LPAREN] = ACTIONS(4670),
    [anon_sym_LT] = ACTIONS(4672),
    [anon_sym_GT] = ACTIONS(4672),
    [anon_sym_where] = ACTIONS(4670),
    [anon_sym_QMARK] = ACTIONS(4672),
    [anon_sym_BANG] = ACTIONS(4672),
    [anon_sym_PLUS_PLUS] = ACTIONS(4670),
    [anon_sym_DASH_DASH] = ACTIONS(4670),
    [anon_sym_PLUS] = ACTIONS(4672),
    [anon_sym_DASH] = ACTIONS(4672),
    [anon_sym_STAR] = ACTIONS(4672),
    [anon_sym_SLASH] = ACTIONS(4672),
    [anon_sym_PERCENT] = ACTIONS(4672),
    [anon_sym_CARET] = ACTIONS(4672),
    [anon_sym_PIPE] = ACTIONS(4672),
    [anon_sym_AMP] = ACTIONS(4672),
    [anon_sym_LT_LT] = ACTIONS(4672),
    [anon_sym_GT_GT] = ACTIONS(4672),
    [anon_sym_GT_GT_GT] = ACTIONS(4672),
    [anon_sym_EQ_EQ] = ACTIONS(4670),
    [anon_sym_BANG_EQ] = ACTIONS(4670),
    [anon_sym_GT_EQ] = ACTIONS(4670),
    [anon_sym_LT_EQ] = ACTIONS(4670),
    [anon_sym_DOT] = ACTIONS(4672),
    [anon_sym_switch] = ACTIONS(4670),
    [anon_sym_DOT_DOT] = ACTIONS(4670),
    [anon_sym_and] = ACTIONS(4670),
    [anon_sym_or] = ACTIONS(4672),
    [anon_sym_PLUS_EQ] = ACTIONS(4670),
    [anon_sym_DASH_EQ] = ACTIONS(4670),
    [anon_sym_STAR_EQ] = ACTIONS(4670),
    [anon_sym_SLASH_EQ] = ACTIONS(4670),
    [anon_sym_PERCENT_EQ] = ACTIONS(4670),
    [anon_sym_AMP_EQ] = ACTIONS(4670),
    [anon_sym_CARET_EQ] = ACTIONS(4670),
    [anon_sym_PIPE_EQ] = ACTIONS(4670),
    [anon_sym_LT_LT_EQ] = ACTIONS(4670),
    [anon_sym_GT_GT_EQ] = ACTIONS(4670),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4670),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4670),
    [anon_sym_AMP_AMP] = ACTIONS(4670),
    [anon_sym_PIPE_PIPE] = ACTIONS(4670),
    [anon_sym_QMARK_QMARK] = ACTIONS(4672),
    [anon_sym_from] = ACTIONS(4670),
    [anon_sym_into] = ACTIONS(4670),
    [anon_sym_join] = ACTIONS(4670),
    [anon_sym_let] = ACTIONS(4670),
    [anon_sym_orderby] = ACTIONS(4670),
    [anon_sym_ascending] = ACTIONS(4670),
    [anon_sym_descending] = ACTIONS(4670),
    [anon_sym_group] = ACTIONS(4670),
    [anon_sym_select] = ACTIONS(4670),
    [anon_sym_as] = ACTIONS(4672),
    [anon_sym_is] = ACTIONS(4670),
    [anon_sym_DASH_GT] = ACTIONS(4670),
    [anon_sym_with] = ACTIONS(4670),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3567] = {
    [sym_argument_list] = STATE(3682),
    [sym_bracketed_argument_list] = STATE(3001),
    [sym_preproc_region] = STATE(3567),
    [sym_preproc_endregion] = STATE(3567),
    [sym_preproc_line] = STATE(3567),
    [sym_preproc_pragma] = STATE(3567),
    [sym_preproc_nullable] = STATE(3567),
    [sym_preproc_error] = STATE(3567),
    [sym_preproc_warning] = STATE(3567),
    [sym_preproc_define] = STATE(3567),
    [sym_preproc_undef] = STATE(3567),
    [anon_sym_SEMI] = ACTIONS(5292),
    [anon_sym_LBRACK] = ACTIONS(5273),
    [anon_sym_COLON] = ACTIONS(5292),
    [anon_sym_COMMA] = ACTIONS(5292),
    [anon_sym_RBRACK] = ACTIONS(5292),
    [anon_sym_LPAREN] = ACTIONS(5265),
    [anon_sym_RPAREN] = ACTIONS(5292),
    [anon_sym_RBRACE] = ACTIONS(5292),
    [anon_sym_LT] = ACTIONS(5294),
    [anon_sym_GT] = ACTIONS(5294),
    [anon_sym_in] = ACTIONS(5294),
    [anon_sym_where] = ACTIONS(5292),
    [anon_sym_QMARK] = ACTIONS(5294),
    [anon_sym_BANG] = ACTIONS(5277),
    [anon_sym_PLUS_PLUS] = ACTIONS(5279),
    [anon_sym_DASH_DASH] = ACTIONS(5279),
    [anon_sym_PLUS] = ACTIONS(5294),
    [anon_sym_DASH] = ACTIONS(5294),
    [anon_sym_STAR] = ACTIONS(5292),
    [anon_sym_SLASH] = ACTIONS(5294),
    [anon_sym_PERCENT] = ACTIONS(5292),
    [anon_sym_CARET] = ACTIONS(5292),
    [anon_sym_PIPE] = ACTIONS(5294),
    [anon_sym_AMP] = ACTIONS(5294),
    [anon_sym_LT_LT] = ACTIONS(5292),
    [anon_sym_GT_GT] = ACTIONS(5294),
    [anon_sym_GT_GT_GT] = ACTIONS(5292),
    [anon_sym_EQ_EQ] = ACTIONS(5292),
    [anon_sym_BANG_EQ] = ACTIONS(5292),
    [anon_sym_GT_EQ] = ACTIONS(5292),
    [anon_sym_LT_EQ] = ACTIONS(5292),
    [anon_sym_DOT] = ACTIONS(5249),
    [anon_sym_EQ_GT] = ACTIONS(5292),
    [anon_sym_switch] = ACTIONS(5292),
    [anon_sym_DOT_DOT] = ACTIONS(5292),
    [anon_sym_and] = ACTIONS(5292),
    [anon_sym_or] = ACTIONS(5294),
    [anon_sym_AMP_AMP] = ACTIONS(5292),
    [anon_sym_PIPE_PIPE] = ACTIONS(5292),
    [anon_sym_QMARK_QMARK] = ACTIONS(5292),
    [anon_sym_from] = ACTIONS(5292),
    [anon_sym_into] = ACTIONS(5292),
    [anon_sym_join] = ACTIONS(5292),
    [anon_sym_on] = ACTIONS(5292),
    [anon_sym_equals] = ACTIONS(5292),
    [anon_sym_let] = ACTIONS(5292),
    [anon_sym_orderby] = ACTIONS(5292),
    [anon_sym_group] = ACTIONS(5292),
    [anon_sym_by] = ACTIONS(5292),
    [anon_sym_select] = ACTIONS(5292),
    [anon_sym_as] = ACTIONS(5292),
    [anon_sym_is] = ACTIONS(5292),
    [anon_sym_DASH_GT] = ACTIONS(5247),
    [anon_sym_with] = ACTIONS(5292),
    [aux_sym_preproc_if_token3] = ACTIONS(5292),
    [aux_sym_preproc_else_token1] = ACTIONS(5292),
    [aux_sym_preproc_elif_token1] = ACTIONS(5292),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3568] = {
    [sym_initializer_expression] = STATE(3690),
    [sym_preproc_region] = STATE(3568),
    [sym_preproc_endregion] = STATE(3568),
    [sym_preproc_line] = STATE(3568),
    [sym_preproc_pragma] = STATE(3568),
    [sym_preproc_nullable] = STATE(3568),
    [sym_preproc_error] = STATE(3568),
    [sym_preproc_warning] = STATE(3568),
    [sym_preproc_define] = STATE(3568),
    [sym_preproc_undef] = STATE(3568),
    [anon_sym_SEMI] = ACTIONS(5296),
    [anon_sym_LBRACK] = ACTIONS(5298),
    [anon_sym_COLON] = ACTIONS(5296),
    [anon_sym_COMMA] = ACTIONS(5296),
    [anon_sym_RBRACK] = ACTIONS(5296),
    [anon_sym_LPAREN] = ACTIONS(5296),
    [anon_sym_RPAREN] = ACTIONS(5296),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_RBRACE] = ACTIONS(5296),
    [anon_sym_LT] = ACTIONS(5301),
    [anon_sym_GT] = ACTIONS(5301),
    [anon_sym_in] = ACTIONS(5301),
    [anon_sym_where] = ACTIONS(5296),
    [anon_sym_QMARK] = ACTIONS(5301),
    [anon_sym_BANG] = ACTIONS(5301),
    [anon_sym_PLUS_PLUS] = ACTIONS(5296),
    [anon_sym_DASH_DASH] = ACTIONS(5296),
    [anon_sym_PLUS] = ACTIONS(5301),
    [anon_sym_DASH] = ACTIONS(5301),
    [anon_sym_STAR] = ACTIONS(5296),
    [anon_sym_SLASH] = ACTIONS(5301),
    [anon_sym_PERCENT] = ACTIONS(5296),
    [anon_sym_CARET] = ACTIONS(5296),
    [anon_sym_PIPE] = ACTIONS(5301),
    [anon_sym_AMP] = ACTIONS(5301),
    [anon_sym_LT_LT] = ACTIONS(5296),
    [anon_sym_GT_GT] = ACTIONS(5301),
    [anon_sym_GT_GT_GT] = ACTIONS(5296),
    [anon_sym_EQ_EQ] = ACTIONS(5296),
    [anon_sym_BANG_EQ] = ACTIONS(5296),
    [anon_sym_GT_EQ] = ACTIONS(5296),
    [anon_sym_LT_EQ] = ACTIONS(5296),
    [anon_sym_DOT] = ACTIONS(5301),
    [anon_sym_EQ_GT] = ACTIONS(5296),
    [anon_sym_switch] = ACTIONS(5296),
    [anon_sym_DOT_DOT] = ACTIONS(5296),
    [anon_sym_and] = ACTIONS(5296),
    [anon_sym_or] = ACTIONS(5301),
    [anon_sym_AMP_AMP] = ACTIONS(5296),
    [anon_sym_PIPE_PIPE] = ACTIONS(5296),
    [anon_sym_QMARK_QMARK] = ACTIONS(5296),
    [anon_sym_from] = ACTIONS(5296),
    [anon_sym_into] = ACTIONS(5296),
    [anon_sym_join] = ACTIONS(5296),
    [anon_sym_on] = ACTIONS(5296),
    [anon_sym_equals] = ACTIONS(5296),
    [anon_sym_let] = ACTIONS(5296),
    [anon_sym_orderby] = ACTIONS(5296),
    [anon_sym_group] = ACTIONS(5296),
    [anon_sym_by] = ACTIONS(5296),
    [anon_sym_select] = ACTIONS(5296),
    [anon_sym_as] = ACTIONS(5296),
    [anon_sym_is] = ACTIONS(5296),
    [anon_sym_DASH_GT] = ACTIONS(5296),
    [anon_sym_with] = ACTIONS(5296),
    [aux_sym_preproc_if_token3] = ACTIONS(5296),
    [aux_sym_preproc_else_token1] = ACTIONS(5296),
    [aux_sym_preproc_elif_token1] = ACTIONS(5296),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3569] = {
    [sym_preproc_region] = STATE(3569),
    [sym_preproc_endregion] = STATE(3569),
    [sym_preproc_line] = STATE(3569),
    [sym_preproc_pragma] = STATE(3569),
    [sym_preproc_nullable] = STATE(3569),
    [sym_preproc_error] = STATE(3569),
    [sym_preproc_warning] = STATE(3569),
    [sym_preproc_define] = STATE(3569),
    [sym_preproc_undef] = STATE(3569),
    [anon_sym_EQ] = ACTIONS(4701),
    [anon_sym_LBRACK] = ACTIONS(4699),
    [anon_sym_COMMA] = ACTIONS(4699),
    [anon_sym_LPAREN] = ACTIONS(4699),
    [anon_sym_LT] = ACTIONS(4701),
    [anon_sym_GT] = ACTIONS(4701),
    [anon_sym_where] = ACTIONS(4699),
    [anon_sym_QMARK] = ACTIONS(4701),
    [anon_sym_BANG] = ACTIONS(4701),
    [anon_sym_PLUS_PLUS] = ACTIONS(4699),
    [anon_sym_DASH_DASH] = ACTIONS(4699),
    [anon_sym_PLUS] = ACTIONS(4701),
    [anon_sym_DASH] = ACTIONS(4701),
    [anon_sym_STAR] = ACTIONS(4701),
    [anon_sym_SLASH] = ACTIONS(4701),
    [anon_sym_PERCENT] = ACTIONS(4701),
    [anon_sym_CARET] = ACTIONS(4701),
    [anon_sym_PIPE] = ACTIONS(4701),
    [anon_sym_AMP] = ACTIONS(4701),
    [anon_sym_LT_LT] = ACTIONS(4701),
    [anon_sym_GT_GT] = ACTIONS(4701),
    [anon_sym_GT_GT_GT] = ACTIONS(4701),
    [anon_sym_EQ_EQ] = ACTIONS(4699),
    [anon_sym_BANG_EQ] = ACTIONS(4699),
    [anon_sym_GT_EQ] = ACTIONS(4699),
    [anon_sym_LT_EQ] = ACTIONS(4699),
    [anon_sym_DOT] = ACTIONS(4701),
    [anon_sym_switch] = ACTIONS(4699),
    [anon_sym_DOT_DOT] = ACTIONS(4699),
    [anon_sym_and] = ACTIONS(4699),
    [anon_sym_or] = ACTIONS(4701),
    [anon_sym_PLUS_EQ] = ACTIONS(4699),
    [anon_sym_DASH_EQ] = ACTIONS(4699),
    [anon_sym_STAR_EQ] = ACTIONS(4699),
    [anon_sym_SLASH_EQ] = ACTIONS(4699),
    [anon_sym_PERCENT_EQ] = ACTIONS(4699),
    [anon_sym_AMP_EQ] = ACTIONS(4699),
    [anon_sym_CARET_EQ] = ACTIONS(4699),
    [anon_sym_PIPE_EQ] = ACTIONS(4699),
    [anon_sym_LT_LT_EQ] = ACTIONS(4699),
    [anon_sym_GT_GT_EQ] = ACTIONS(4699),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4699),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4699),
    [anon_sym_AMP_AMP] = ACTIONS(4699),
    [anon_sym_PIPE_PIPE] = ACTIONS(4699),
    [anon_sym_QMARK_QMARK] = ACTIONS(4701),
    [anon_sym_from] = ACTIONS(4699),
    [anon_sym_into] = ACTIONS(4699),
    [anon_sym_join] = ACTIONS(4699),
    [anon_sym_let] = ACTIONS(4699),
    [anon_sym_orderby] = ACTIONS(4699),
    [anon_sym_ascending] = ACTIONS(4699),
    [anon_sym_descending] = ACTIONS(4699),
    [anon_sym_group] = ACTIONS(4699),
    [anon_sym_select] = ACTIONS(4699),
    [anon_sym_as] = ACTIONS(4701),
    [anon_sym_is] = ACTIONS(4699),
    [anon_sym_DASH_GT] = ACTIONS(4699),
    [anon_sym_with] = ACTIONS(4699),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3570] = {
    [sym_preproc_region] = STATE(3570),
    [sym_preproc_endregion] = STATE(3570),
    [sym_preproc_line] = STATE(3570),
    [sym_preproc_pragma] = STATE(3570),
    [sym_preproc_nullable] = STATE(3570),
    [sym_preproc_error] = STATE(3570),
    [sym_preproc_warning] = STATE(3570),
    [sym_preproc_define] = STATE(3570),
    [sym_preproc_undef] = STATE(3570),
    [anon_sym_EQ] = ACTIONS(4713),
    [anon_sym_LBRACK] = ACTIONS(4711),
    [anon_sym_COMMA] = ACTIONS(4711),
    [anon_sym_LPAREN] = ACTIONS(4711),
    [anon_sym_LT] = ACTIONS(4713),
    [anon_sym_GT] = ACTIONS(4713),
    [anon_sym_where] = ACTIONS(4711),
    [anon_sym_QMARK] = ACTIONS(4713),
    [anon_sym_BANG] = ACTIONS(4713),
    [anon_sym_PLUS_PLUS] = ACTIONS(4711),
    [anon_sym_DASH_DASH] = ACTIONS(4711),
    [anon_sym_PLUS] = ACTIONS(4713),
    [anon_sym_DASH] = ACTIONS(4713),
    [anon_sym_STAR] = ACTIONS(4713),
    [anon_sym_SLASH] = ACTIONS(4713),
    [anon_sym_PERCENT] = ACTIONS(4713),
    [anon_sym_CARET] = ACTIONS(4713),
    [anon_sym_PIPE] = ACTIONS(4713),
    [anon_sym_AMP] = ACTIONS(4713),
    [anon_sym_LT_LT] = ACTIONS(4713),
    [anon_sym_GT_GT] = ACTIONS(4713),
    [anon_sym_GT_GT_GT] = ACTIONS(4713),
    [anon_sym_EQ_EQ] = ACTIONS(4711),
    [anon_sym_BANG_EQ] = ACTIONS(4711),
    [anon_sym_GT_EQ] = ACTIONS(4711),
    [anon_sym_LT_EQ] = ACTIONS(4711),
    [anon_sym_DOT] = ACTIONS(4713),
    [anon_sym_switch] = ACTIONS(4711),
    [anon_sym_DOT_DOT] = ACTIONS(4711),
    [anon_sym_and] = ACTIONS(4711),
    [anon_sym_or] = ACTIONS(4713),
    [anon_sym_PLUS_EQ] = ACTIONS(4711),
    [anon_sym_DASH_EQ] = ACTIONS(4711),
    [anon_sym_STAR_EQ] = ACTIONS(4711),
    [anon_sym_SLASH_EQ] = ACTIONS(4711),
    [anon_sym_PERCENT_EQ] = ACTIONS(4711),
    [anon_sym_AMP_EQ] = ACTIONS(4711),
    [anon_sym_CARET_EQ] = ACTIONS(4711),
    [anon_sym_PIPE_EQ] = ACTIONS(4711),
    [anon_sym_LT_LT_EQ] = ACTIONS(4711),
    [anon_sym_GT_GT_EQ] = ACTIONS(4711),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4711),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4711),
    [anon_sym_AMP_AMP] = ACTIONS(4711),
    [anon_sym_PIPE_PIPE] = ACTIONS(4711),
    [anon_sym_QMARK_QMARK] = ACTIONS(4713),
    [anon_sym_from] = ACTIONS(4711),
    [anon_sym_into] = ACTIONS(4711),
    [anon_sym_join] = ACTIONS(4711),
    [anon_sym_let] = ACTIONS(4711),
    [anon_sym_orderby] = ACTIONS(4711),
    [anon_sym_ascending] = ACTIONS(4711),
    [anon_sym_descending] = ACTIONS(4711),
    [anon_sym_group] = ACTIONS(4711),
    [anon_sym_select] = ACTIONS(4711),
    [anon_sym_as] = ACTIONS(4713),
    [anon_sym_is] = ACTIONS(4711),
    [anon_sym_DASH_GT] = ACTIONS(4711),
    [anon_sym_with] = ACTIONS(4711),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3571] = {
    [sym_initializer_expression] = STATE(3661),
    [sym_preproc_region] = STATE(3571),
    [sym_preproc_endregion] = STATE(3571),
    [sym_preproc_line] = STATE(3571),
    [sym_preproc_pragma] = STATE(3571),
    [sym_preproc_nullable] = STATE(3571),
    [sym_preproc_error] = STATE(3571),
    [sym_preproc_warning] = STATE(3571),
    [sym_preproc_define] = STATE(3571),
    [sym_preproc_undef] = STATE(3571),
    [anon_sym_SEMI] = ACTIONS(5303),
    [anon_sym_LBRACK] = ACTIONS(5303),
    [anon_sym_COLON] = ACTIONS(5303),
    [anon_sym_COMMA] = ACTIONS(5303),
    [anon_sym_RBRACK] = ACTIONS(5303),
    [anon_sym_LPAREN] = ACTIONS(5303),
    [anon_sym_RPAREN] = ACTIONS(5303),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_RBRACE] = ACTIONS(5303),
    [anon_sym_LT] = ACTIONS(5305),
    [anon_sym_GT] = ACTIONS(5305),
    [anon_sym_in] = ACTIONS(5305),
    [anon_sym_where] = ACTIONS(5303),
    [anon_sym_QMARK] = ACTIONS(5305),
    [anon_sym_BANG] = ACTIONS(5305),
    [anon_sym_PLUS_PLUS] = ACTIONS(5303),
    [anon_sym_DASH_DASH] = ACTIONS(5303),
    [anon_sym_PLUS] = ACTIONS(5305),
    [anon_sym_DASH] = ACTIONS(5305),
    [anon_sym_STAR] = ACTIONS(5303),
    [anon_sym_SLASH] = ACTIONS(5305),
    [anon_sym_PERCENT] = ACTIONS(5303),
    [anon_sym_CARET] = ACTIONS(5303),
    [anon_sym_PIPE] = ACTIONS(5305),
    [anon_sym_AMP] = ACTIONS(5305),
    [anon_sym_LT_LT] = ACTIONS(5303),
    [anon_sym_GT_GT] = ACTIONS(5305),
    [anon_sym_GT_GT_GT] = ACTIONS(5303),
    [anon_sym_EQ_EQ] = ACTIONS(5303),
    [anon_sym_BANG_EQ] = ACTIONS(5303),
    [anon_sym_GT_EQ] = ACTIONS(5303),
    [anon_sym_LT_EQ] = ACTIONS(5303),
    [anon_sym_DOT] = ACTIONS(5305),
    [anon_sym_EQ_GT] = ACTIONS(5303),
    [anon_sym_switch] = ACTIONS(5303),
    [anon_sym_DOT_DOT] = ACTIONS(5303),
    [anon_sym_and] = ACTIONS(5303),
    [anon_sym_or] = ACTIONS(5305),
    [anon_sym_AMP_AMP] = ACTIONS(5303),
    [anon_sym_PIPE_PIPE] = ACTIONS(5303),
    [anon_sym_QMARK_QMARK] = ACTIONS(5303),
    [anon_sym_from] = ACTIONS(5303),
    [anon_sym_into] = ACTIONS(5303),
    [anon_sym_join] = ACTIONS(5303),
    [anon_sym_on] = ACTIONS(5303),
    [anon_sym_equals] = ACTIONS(5303),
    [anon_sym_let] = ACTIONS(5303),
    [anon_sym_orderby] = ACTIONS(5303),
    [anon_sym_group] = ACTIONS(5303),
    [anon_sym_by] = ACTIONS(5303),
    [anon_sym_select] = ACTIONS(5303),
    [anon_sym_as] = ACTIONS(5303),
    [anon_sym_is] = ACTIONS(5303),
    [anon_sym_DASH_GT] = ACTIONS(5303),
    [anon_sym_with] = ACTIONS(5303),
    [aux_sym_preproc_if_token3] = ACTIONS(5303),
    [aux_sym_preproc_else_token1] = ACTIONS(5303),
    [aux_sym_preproc_elif_token1] = ACTIONS(5303),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3572] = {
    [sym_preproc_region] = STATE(3572),
    [sym_preproc_endregion] = STATE(3572),
    [sym_preproc_line] = STATE(3572),
    [sym_preproc_pragma] = STATE(3572),
    [sym_preproc_nullable] = STATE(3572),
    [sym_preproc_error] = STATE(3572),
    [sym_preproc_warning] = STATE(3572),
    [sym_preproc_define] = STATE(3572),
    [sym_preproc_undef] = STATE(3572),
    [anon_sym_SEMI] = ACTIONS(4124),
    [anon_sym_LBRACK] = ACTIONS(4124),
    [anon_sym_COLON] = ACTIONS(4122),
    [anon_sym_COMMA] = ACTIONS(4124),
    [anon_sym_RBRACK] = ACTIONS(4124),
    [anon_sym_LPAREN] = ACTIONS(4124),
    [anon_sym_RPAREN] = ACTIONS(4124),
    [anon_sym_LBRACE] = ACTIONS(4124),
    [anon_sym_RBRACE] = ACTIONS(4124),
    [anon_sym_LT] = ACTIONS(4122),
    [anon_sym_GT] = ACTIONS(4122),
    [anon_sym_in] = ACTIONS(4122),
    [anon_sym_where] = ACTIONS(4124),
    [anon_sym_QMARK] = ACTIONS(4122),
    [anon_sym_BANG] = ACTIONS(4122),
    [anon_sym_PLUS_PLUS] = ACTIONS(4124),
    [anon_sym_DASH_DASH] = ACTIONS(4124),
    [anon_sym_PLUS] = ACTIONS(4122),
    [anon_sym_DASH] = ACTIONS(4122),
    [anon_sym_STAR] = ACTIONS(4124),
    [anon_sym_SLASH] = ACTIONS(4122),
    [anon_sym_PERCENT] = ACTIONS(4124),
    [anon_sym_CARET] = ACTIONS(4124),
    [anon_sym_PIPE] = ACTIONS(4122),
    [anon_sym_AMP] = ACTIONS(4122),
    [anon_sym_LT_LT] = ACTIONS(4124),
    [anon_sym_GT_GT] = ACTIONS(4122),
    [anon_sym_GT_GT_GT] = ACTIONS(4124),
    [anon_sym_EQ_EQ] = ACTIONS(4124),
    [anon_sym_BANG_EQ] = ACTIONS(4124),
    [anon_sym_GT_EQ] = ACTIONS(4124),
    [anon_sym_LT_EQ] = ACTIONS(4124),
    [anon_sym_DOT] = ACTIONS(4122),
    [anon_sym_EQ_GT] = ACTIONS(4124),
    [anon_sym_COLON_COLON] = ACTIONS(4124),
    [anon_sym_switch] = ACTIONS(4124),
    [anon_sym_DOT_DOT] = ACTIONS(4124),
    [anon_sym_and] = ACTIONS(4124),
    [anon_sym_or] = ACTIONS(4122),
    [anon_sym_AMP_AMP] = ACTIONS(4124),
    [anon_sym_PIPE_PIPE] = ACTIONS(4124),
    [anon_sym_QMARK_QMARK] = ACTIONS(4124),
    [anon_sym_from] = ACTIONS(4124),
    [anon_sym_into] = ACTIONS(4124),
    [anon_sym_join] = ACTIONS(4124),
    [anon_sym_on] = ACTIONS(4124),
    [anon_sym_equals] = ACTIONS(4124),
    [anon_sym_let] = ACTIONS(4124),
    [anon_sym_orderby] = ACTIONS(4124),
    [anon_sym_group] = ACTIONS(4124),
    [anon_sym_by] = ACTIONS(4124),
    [anon_sym_select] = ACTIONS(4124),
    [anon_sym_as] = ACTIONS(4124),
    [anon_sym_is] = ACTIONS(4124),
    [anon_sym_DASH_GT] = ACTIONS(4124),
    [anon_sym_with] = ACTIONS(4124),
    [aux_sym_preproc_if_token3] = ACTIONS(4124),
    [aux_sym_preproc_else_token1] = ACTIONS(4124),
    [aux_sym_preproc_elif_token1] = ACTIONS(4124),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3573] = {
    [sym_preproc_region] = STATE(3573),
    [sym_preproc_endregion] = STATE(3573),
    [sym_preproc_line] = STATE(3573),
    [sym_preproc_pragma] = STATE(3573),
    [sym_preproc_nullable] = STATE(3573),
    [sym_preproc_error] = STATE(3573),
    [sym_preproc_warning] = STATE(3573),
    [sym_preproc_define] = STATE(3573),
    [sym_preproc_undef] = STATE(3573),
    [anon_sym_SEMI] = ACTIONS(4088),
    [anon_sym_LBRACK] = ACTIONS(4088),
    [anon_sym_COLON] = ACTIONS(4091),
    [anon_sym_COMMA] = ACTIONS(4088),
    [anon_sym_RBRACK] = ACTIONS(4088),
    [anon_sym_LPAREN] = ACTIONS(4088),
    [anon_sym_RPAREN] = ACTIONS(4088),
    [anon_sym_LBRACE] = ACTIONS(4088),
    [anon_sym_RBRACE] = ACTIONS(4088),
    [anon_sym_LT] = ACTIONS(4091),
    [anon_sym_GT] = ACTIONS(4091),
    [anon_sym_in] = ACTIONS(4091),
    [anon_sym_where] = ACTIONS(4088),
    [anon_sym_QMARK] = ACTIONS(4091),
    [anon_sym_BANG] = ACTIONS(4091),
    [anon_sym_PLUS_PLUS] = ACTIONS(4088),
    [anon_sym_DASH_DASH] = ACTIONS(4088),
    [anon_sym_PLUS] = ACTIONS(4091),
    [anon_sym_DASH] = ACTIONS(4091),
    [anon_sym_STAR] = ACTIONS(4088),
    [anon_sym_SLASH] = ACTIONS(4091),
    [anon_sym_PERCENT] = ACTIONS(4088),
    [anon_sym_CARET] = ACTIONS(4088),
    [anon_sym_PIPE] = ACTIONS(4091),
    [anon_sym_AMP] = ACTIONS(4091),
    [anon_sym_LT_LT] = ACTIONS(4088),
    [anon_sym_GT_GT] = ACTIONS(4091),
    [anon_sym_GT_GT_GT] = ACTIONS(4088),
    [anon_sym_EQ_EQ] = ACTIONS(4088),
    [anon_sym_BANG_EQ] = ACTIONS(4088),
    [anon_sym_GT_EQ] = ACTIONS(4088),
    [anon_sym_LT_EQ] = ACTIONS(4088),
    [anon_sym_DOT] = ACTIONS(4091),
    [anon_sym_EQ_GT] = ACTIONS(4088),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_switch] = ACTIONS(4088),
    [anon_sym_DOT_DOT] = ACTIONS(4088),
    [anon_sym_and] = ACTIONS(4088),
    [anon_sym_or] = ACTIONS(4091),
    [anon_sym_AMP_AMP] = ACTIONS(4088),
    [anon_sym_PIPE_PIPE] = ACTIONS(4088),
    [anon_sym_QMARK_QMARK] = ACTIONS(4088),
    [anon_sym_from] = ACTIONS(4088),
    [anon_sym_into] = ACTIONS(4088),
    [anon_sym_join] = ACTIONS(4088),
    [anon_sym_on] = ACTIONS(4088),
    [anon_sym_equals] = ACTIONS(4088),
    [anon_sym_let] = ACTIONS(4088),
    [anon_sym_orderby] = ACTIONS(4088),
    [anon_sym_group] = ACTIONS(4088),
    [anon_sym_by] = ACTIONS(4088),
    [anon_sym_select] = ACTIONS(4088),
    [anon_sym_as] = ACTIONS(4088),
    [anon_sym_is] = ACTIONS(4088),
    [anon_sym_DASH_GT] = ACTIONS(4088),
    [anon_sym_with] = ACTIONS(4088),
    [aux_sym_preproc_if_token3] = ACTIONS(4088),
    [aux_sym_preproc_else_token1] = ACTIONS(4088),
    [aux_sym_preproc_elif_token1] = ACTIONS(4088),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3574] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7110),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9077),
    [sym_identifier] = STATE(6738),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3574),
    [sym_preproc_endregion] = STATE(3574),
    [sym_preproc_line] = STATE(3574),
    [sym_preproc_pragma] = STATE(3574),
    [sym_preproc_nullable] = STATE(3574),
    [sym_preproc_error] = STATE(3574),
    [sym_preproc_warning] = STATE(3574),
    [sym_preproc_define] = STATE(3574),
    [sym_preproc_undef] = STATE(3574),
    [aux_sym_class_declaration_repeat1] = STATE(6149),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4312),
    [aux_sym_lambda_expression_repeat1] = STATE(4314),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(5307),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(5309),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_in] = ACTIONS(1113),
    [anon_sym_out] = ACTIONS(1113),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_this] = ACTIONS(1113),
    [anon_sym_scoped] = ACTIONS(5311),
    [anon_sym_params] = ACTIONS(5313),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3575] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7026),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9821),
    [sym_identifier] = STATE(6738),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3575),
    [sym_preproc_endregion] = STATE(3575),
    [sym_preproc_line] = STATE(3575),
    [sym_preproc_pragma] = STATE(3575),
    [sym_preproc_nullable] = STATE(3575),
    [sym_preproc_error] = STATE(3575),
    [sym_preproc_warning] = STATE(3575),
    [sym_preproc_define] = STATE(3575),
    [sym_preproc_undef] = STATE(3575),
    [aux_sym_class_declaration_repeat1] = STATE(6149),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4312),
    [aux_sym_lambda_expression_repeat1] = STATE(4289),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(5307),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(5309),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_in] = ACTIONS(1113),
    [anon_sym_out] = ACTIONS(1113),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_this] = ACTIONS(1113),
    [anon_sym_scoped] = ACTIONS(5311),
    [anon_sym_params] = ACTIONS(5313),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3576] = {
    [sym_initializer_expression] = STATE(3684),
    [sym_preproc_region] = STATE(3576),
    [sym_preproc_endregion] = STATE(3576),
    [sym_preproc_line] = STATE(3576),
    [sym_preproc_pragma] = STATE(3576),
    [sym_preproc_nullable] = STATE(3576),
    [sym_preproc_error] = STATE(3576),
    [sym_preproc_warning] = STATE(3576),
    [sym_preproc_define] = STATE(3576),
    [sym_preproc_undef] = STATE(3576),
    [anon_sym_SEMI] = ACTIONS(5315),
    [anon_sym_LBRACK] = ACTIONS(5315),
    [anon_sym_COLON] = ACTIONS(5315),
    [anon_sym_COMMA] = ACTIONS(5315),
    [anon_sym_RBRACK] = ACTIONS(5315),
    [anon_sym_LPAREN] = ACTIONS(5315),
    [anon_sym_RPAREN] = ACTIONS(5315),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_RBRACE] = ACTIONS(5315),
    [anon_sym_LT] = ACTIONS(5317),
    [anon_sym_GT] = ACTIONS(5317),
    [anon_sym_in] = ACTIONS(5317),
    [anon_sym_where] = ACTIONS(5315),
    [anon_sym_QMARK] = ACTIONS(5317),
    [anon_sym_BANG] = ACTIONS(5317),
    [anon_sym_PLUS_PLUS] = ACTIONS(5315),
    [anon_sym_DASH_DASH] = ACTIONS(5315),
    [anon_sym_PLUS] = ACTIONS(5317),
    [anon_sym_DASH] = ACTIONS(5317),
    [anon_sym_STAR] = ACTIONS(5315),
    [anon_sym_SLASH] = ACTIONS(5317),
    [anon_sym_PERCENT] = ACTIONS(5315),
    [anon_sym_CARET] = ACTIONS(5315),
    [anon_sym_PIPE] = ACTIONS(5317),
    [anon_sym_AMP] = ACTIONS(5317),
    [anon_sym_LT_LT] = ACTIONS(5315),
    [anon_sym_GT_GT] = ACTIONS(5317),
    [anon_sym_GT_GT_GT] = ACTIONS(5315),
    [anon_sym_EQ_EQ] = ACTIONS(5315),
    [anon_sym_BANG_EQ] = ACTIONS(5315),
    [anon_sym_GT_EQ] = ACTIONS(5315),
    [anon_sym_LT_EQ] = ACTIONS(5315),
    [anon_sym_DOT] = ACTIONS(5317),
    [anon_sym_EQ_GT] = ACTIONS(5315),
    [anon_sym_switch] = ACTIONS(5315),
    [anon_sym_DOT_DOT] = ACTIONS(5315),
    [anon_sym_and] = ACTIONS(5315),
    [anon_sym_or] = ACTIONS(5317),
    [anon_sym_AMP_AMP] = ACTIONS(5315),
    [anon_sym_PIPE_PIPE] = ACTIONS(5315),
    [anon_sym_QMARK_QMARK] = ACTIONS(5315),
    [anon_sym_from] = ACTIONS(5315),
    [anon_sym_into] = ACTIONS(5315),
    [anon_sym_join] = ACTIONS(5315),
    [anon_sym_on] = ACTIONS(5315),
    [anon_sym_equals] = ACTIONS(5315),
    [anon_sym_let] = ACTIONS(5315),
    [anon_sym_orderby] = ACTIONS(5315),
    [anon_sym_group] = ACTIONS(5315),
    [anon_sym_by] = ACTIONS(5315),
    [anon_sym_select] = ACTIONS(5315),
    [anon_sym_as] = ACTIONS(5315),
    [anon_sym_is] = ACTIONS(5315),
    [anon_sym_DASH_GT] = ACTIONS(5315),
    [anon_sym_with] = ACTIONS(5315),
    [aux_sym_preproc_if_token3] = ACTIONS(5315),
    [aux_sym_preproc_else_token1] = ACTIONS(5315),
    [aux_sym_preproc_elif_token1] = ACTIONS(5315),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3577] = {
    [sym_preproc_region] = STATE(3577),
    [sym_preproc_endregion] = STATE(3577),
    [sym_preproc_line] = STATE(3577),
    [sym_preproc_pragma] = STATE(3577),
    [sym_preproc_nullable] = STATE(3577),
    [sym_preproc_error] = STATE(3577),
    [sym_preproc_warning] = STATE(3577),
    [sym_preproc_define] = STATE(3577),
    [sym_preproc_undef] = STATE(3577),
    [anon_sym_EQ] = ACTIONS(4668),
    [anon_sym_LBRACK] = ACTIONS(4666),
    [anon_sym_COMMA] = ACTIONS(4666),
    [anon_sym_LPAREN] = ACTIONS(4666),
    [anon_sym_LT] = ACTIONS(4668),
    [anon_sym_GT] = ACTIONS(4668),
    [anon_sym_where] = ACTIONS(4666),
    [anon_sym_QMARK] = ACTIONS(4668),
    [anon_sym_BANG] = ACTIONS(4668),
    [anon_sym_PLUS_PLUS] = ACTIONS(4666),
    [anon_sym_DASH_DASH] = ACTIONS(4666),
    [anon_sym_PLUS] = ACTIONS(4668),
    [anon_sym_DASH] = ACTIONS(4668),
    [anon_sym_STAR] = ACTIONS(4668),
    [anon_sym_SLASH] = ACTIONS(4668),
    [anon_sym_PERCENT] = ACTIONS(4668),
    [anon_sym_CARET] = ACTIONS(4668),
    [anon_sym_PIPE] = ACTIONS(4668),
    [anon_sym_AMP] = ACTIONS(4668),
    [anon_sym_LT_LT] = ACTIONS(4668),
    [anon_sym_GT_GT] = ACTIONS(4668),
    [anon_sym_GT_GT_GT] = ACTIONS(4668),
    [anon_sym_EQ_EQ] = ACTIONS(4666),
    [anon_sym_BANG_EQ] = ACTIONS(4666),
    [anon_sym_GT_EQ] = ACTIONS(4666),
    [anon_sym_LT_EQ] = ACTIONS(4666),
    [anon_sym_DOT] = ACTIONS(4668),
    [anon_sym_switch] = ACTIONS(4666),
    [anon_sym_DOT_DOT] = ACTIONS(4666),
    [anon_sym_and] = ACTIONS(4666),
    [anon_sym_or] = ACTIONS(4668),
    [anon_sym_PLUS_EQ] = ACTIONS(4666),
    [anon_sym_DASH_EQ] = ACTIONS(4666),
    [anon_sym_STAR_EQ] = ACTIONS(4666),
    [anon_sym_SLASH_EQ] = ACTIONS(4666),
    [anon_sym_PERCENT_EQ] = ACTIONS(4666),
    [anon_sym_AMP_EQ] = ACTIONS(4666),
    [anon_sym_CARET_EQ] = ACTIONS(4666),
    [anon_sym_PIPE_EQ] = ACTIONS(4666),
    [anon_sym_LT_LT_EQ] = ACTIONS(4666),
    [anon_sym_GT_GT_EQ] = ACTIONS(4666),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4666),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4666),
    [anon_sym_AMP_AMP] = ACTIONS(4666),
    [anon_sym_PIPE_PIPE] = ACTIONS(4666),
    [anon_sym_QMARK_QMARK] = ACTIONS(4668),
    [anon_sym_from] = ACTIONS(4666),
    [anon_sym_into] = ACTIONS(4666),
    [anon_sym_join] = ACTIONS(4666),
    [anon_sym_let] = ACTIONS(4666),
    [anon_sym_orderby] = ACTIONS(4666),
    [anon_sym_ascending] = ACTIONS(4666),
    [anon_sym_descending] = ACTIONS(4666),
    [anon_sym_group] = ACTIONS(4666),
    [anon_sym_select] = ACTIONS(4666),
    [anon_sym_as] = ACTIONS(4668),
    [anon_sym_is] = ACTIONS(4666),
    [anon_sym_DASH_GT] = ACTIONS(4666),
    [anon_sym_with] = ACTIONS(4666),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3578] = {
    [sym_preproc_region] = STATE(3578),
    [sym_preproc_endregion] = STATE(3578),
    [sym_preproc_line] = STATE(3578),
    [sym_preproc_pragma] = STATE(3578),
    [sym_preproc_nullable] = STATE(3578),
    [sym_preproc_error] = STATE(3578),
    [sym_preproc_warning] = STATE(3578),
    [sym_preproc_define] = STATE(3578),
    [sym_preproc_undef] = STATE(3578),
    [anon_sym_SEMI] = ACTIONS(3993),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_COLON] = ACTIONS(3995),
    [anon_sym_COMMA] = ACTIONS(3993),
    [anon_sym_RBRACK] = ACTIONS(3993),
    [anon_sym_LPAREN] = ACTIONS(3993),
    [anon_sym_RPAREN] = ACTIONS(3993),
    [anon_sym_LBRACE] = ACTIONS(3993),
    [anon_sym_RBRACE] = ACTIONS(3993),
    [anon_sym_LT] = ACTIONS(3995),
    [anon_sym_GT] = ACTIONS(3995),
    [anon_sym_in] = ACTIONS(3995),
    [anon_sym_where] = ACTIONS(3993),
    [anon_sym_QMARK] = ACTIONS(3995),
    [anon_sym_BANG] = ACTIONS(3995),
    [anon_sym_PLUS_PLUS] = ACTIONS(3993),
    [anon_sym_DASH_DASH] = ACTIONS(3993),
    [anon_sym_PLUS] = ACTIONS(3995),
    [anon_sym_DASH] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3993),
    [anon_sym_SLASH] = ACTIONS(3995),
    [anon_sym_PERCENT] = ACTIONS(3993),
    [anon_sym_CARET] = ACTIONS(3993),
    [anon_sym_PIPE] = ACTIONS(3995),
    [anon_sym_AMP] = ACTIONS(3995),
    [anon_sym_LT_LT] = ACTIONS(3993),
    [anon_sym_GT_GT] = ACTIONS(3995),
    [anon_sym_GT_GT_GT] = ACTIONS(3993),
    [anon_sym_EQ_EQ] = ACTIONS(3993),
    [anon_sym_BANG_EQ] = ACTIONS(3993),
    [anon_sym_GT_EQ] = ACTIONS(3993),
    [anon_sym_LT_EQ] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3995),
    [anon_sym_EQ_GT] = ACTIONS(3993),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_switch] = ACTIONS(3993),
    [anon_sym_DOT_DOT] = ACTIONS(3993),
    [anon_sym_and] = ACTIONS(3993),
    [anon_sym_or] = ACTIONS(3995),
    [anon_sym_AMP_AMP] = ACTIONS(3993),
    [anon_sym_PIPE_PIPE] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK] = ACTIONS(3993),
    [anon_sym_from] = ACTIONS(3993),
    [anon_sym_into] = ACTIONS(3993),
    [anon_sym_join] = ACTIONS(3993),
    [anon_sym_on] = ACTIONS(3993),
    [anon_sym_equals] = ACTIONS(3993),
    [anon_sym_let] = ACTIONS(3993),
    [anon_sym_orderby] = ACTIONS(3993),
    [anon_sym_group] = ACTIONS(3993),
    [anon_sym_by] = ACTIONS(3993),
    [anon_sym_select] = ACTIONS(3993),
    [anon_sym_as] = ACTIONS(3993),
    [anon_sym_is] = ACTIONS(3993),
    [anon_sym_DASH_GT] = ACTIONS(3993),
    [anon_sym_with] = ACTIONS(3993),
    [aux_sym_preproc_if_token3] = ACTIONS(3993),
    [aux_sym_preproc_else_token1] = ACTIONS(3993),
    [aux_sym_preproc_elif_token1] = ACTIONS(3993),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3579] = {
    [sym_preproc_region] = STATE(3579),
    [sym_preproc_endregion] = STATE(3579),
    [sym_preproc_line] = STATE(3579),
    [sym_preproc_pragma] = STATE(3579),
    [sym_preproc_nullable] = STATE(3579),
    [sym_preproc_error] = STATE(3579),
    [sym_preproc_warning] = STATE(3579),
    [sym_preproc_define] = STATE(3579),
    [sym_preproc_undef] = STATE(3579),
    [anon_sym_EQ] = ACTIONS(4162),
    [anon_sym_LBRACK] = ACTIONS(4177),
    [anon_sym_COMMA] = ACTIONS(4177),
    [anon_sym_LPAREN] = ACTIONS(4177),
    [anon_sym_LT] = ACTIONS(4162),
    [anon_sym_GT] = ACTIONS(4162),
    [anon_sym_where] = ACTIONS(4177),
    [anon_sym_QMARK] = ACTIONS(4162),
    [anon_sym_BANG] = ACTIONS(4162),
    [anon_sym_PLUS_PLUS] = ACTIONS(4177),
    [anon_sym_DASH_DASH] = ACTIONS(4177),
    [anon_sym_PLUS] = ACTIONS(4162),
    [anon_sym_DASH] = ACTIONS(4162),
    [anon_sym_STAR] = ACTIONS(4162),
    [anon_sym_SLASH] = ACTIONS(4162),
    [anon_sym_PERCENT] = ACTIONS(4162),
    [anon_sym_CARET] = ACTIONS(4162),
    [anon_sym_PIPE] = ACTIONS(4162),
    [anon_sym_AMP] = ACTIONS(4162),
    [anon_sym_LT_LT] = ACTIONS(4162),
    [anon_sym_GT_GT] = ACTIONS(4162),
    [anon_sym_GT_GT_GT] = ACTIONS(4162),
    [anon_sym_EQ_EQ] = ACTIONS(4177),
    [anon_sym_BANG_EQ] = ACTIONS(4177),
    [anon_sym_GT_EQ] = ACTIONS(4177),
    [anon_sym_LT_EQ] = ACTIONS(4177),
    [anon_sym_DOT] = ACTIONS(4162),
    [anon_sym_switch] = ACTIONS(4177),
    [anon_sym_DOT_DOT] = ACTIONS(4177),
    [anon_sym_and] = ACTIONS(4177),
    [anon_sym_or] = ACTIONS(4162),
    [anon_sym_PLUS_EQ] = ACTIONS(4177),
    [anon_sym_DASH_EQ] = ACTIONS(4177),
    [anon_sym_STAR_EQ] = ACTIONS(4177),
    [anon_sym_SLASH_EQ] = ACTIONS(4177),
    [anon_sym_PERCENT_EQ] = ACTIONS(4177),
    [anon_sym_AMP_EQ] = ACTIONS(4177),
    [anon_sym_CARET_EQ] = ACTIONS(4177),
    [anon_sym_PIPE_EQ] = ACTIONS(4177),
    [anon_sym_LT_LT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4177),
    [anon_sym_AMP_AMP] = ACTIONS(4177),
    [anon_sym_PIPE_PIPE] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK] = ACTIONS(4162),
    [anon_sym_from] = ACTIONS(4177),
    [anon_sym_into] = ACTIONS(4177),
    [anon_sym_join] = ACTIONS(4177),
    [anon_sym_let] = ACTIONS(4177),
    [anon_sym_orderby] = ACTIONS(4177),
    [anon_sym_ascending] = ACTIONS(4177),
    [anon_sym_descending] = ACTIONS(4177),
    [anon_sym_group] = ACTIONS(4177),
    [anon_sym_select] = ACTIONS(4177),
    [anon_sym_as] = ACTIONS(4162),
    [anon_sym_is] = ACTIONS(4177),
    [anon_sym_DASH_GT] = ACTIONS(4177),
    [anon_sym_with] = ACTIONS(4177),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3580] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym_tuple_pattern] = STATE(8499),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7375),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(6752),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3580),
    [sym_preproc_endregion] = STATE(3580),
    [sym_preproc_line] = STATE(3580),
    [sym_preproc_pragma] = STATE(3580),
    [sym_preproc_nullable] = STATE(3580),
    [sym_preproc_error] = STATE(3580),
    [sym_preproc_warning] = STATE(3580),
    [sym_preproc_define] = STATE(3580),
    [sym_preproc_undef] = STATE(3580),
    [aux_sym_class_declaration_repeat1] = STATE(3802),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LBRACK] = ACTIONS(5307),
    [anon_sym_LPAREN] = ACTIONS(5319),
    [anon_sym_RPAREN] = ACTIONS(2603),
    [anon_sym_ref] = ACTIONS(5309),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_in] = ACTIONS(1113),
    [anon_sym_out] = ACTIONS(1113),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_this] = ACTIONS(1113),
    [anon_sym_scoped] = ACTIONS(5321),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [sym_discard] = ACTIONS(5323),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3581] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7127),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9841),
    [sym_identifier] = STATE(6738),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3581),
    [sym_preproc_endregion] = STATE(3581),
    [sym_preproc_line] = STATE(3581),
    [sym_preproc_pragma] = STATE(3581),
    [sym_preproc_nullable] = STATE(3581),
    [sym_preproc_error] = STATE(3581),
    [sym_preproc_warning] = STATE(3581),
    [sym_preproc_define] = STATE(3581),
    [sym_preproc_undef] = STATE(3581),
    [aux_sym_class_declaration_repeat1] = STATE(6149),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4312),
    [aux_sym_lambda_expression_repeat1] = STATE(4307),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(5307),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(5309),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_in] = ACTIONS(1113),
    [anon_sym_out] = ACTIONS(1113),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_this] = ACTIONS(1113),
    [anon_sym_scoped] = ACTIONS(5311),
    [anon_sym_params] = ACTIONS(5313),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3582] = {
    [sym_argument_list] = STATE(3682),
    [sym_bracketed_argument_list] = STATE(3001),
    [sym_preproc_region] = STATE(3582),
    [sym_preproc_endregion] = STATE(3582),
    [sym_preproc_line] = STATE(3582),
    [sym_preproc_pragma] = STATE(3582),
    [sym_preproc_nullable] = STATE(3582),
    [sym_preproc_error] = STATE(3582),
    [sym_preproc_warning] = STATE(3582),
    [sym_preproc_define] = STATE(3582),
    [sym_preproc_undef] = STATE(3582),
    [anon_sym_SEMI] = ACTIONS(5325),
    [anon_sym_LBRACK] = ACTIONS(5273),
    [anon_sym_COLON] = ACTIONS(5325),
    [anon_sym_COMMA] = ACTIONS(5325),
    [anon_sym_RBRACK] = ACTIONS(5325),
    [anon_sym_LPAREN] = ACTIONS(5265),
    [anon_sym_RPAREN] = ACTIONS(5325),
    [anon_sym_RBRACE] = ACTIONS(5325),
    [anon_sym_LT] = ACTIONS(5327),
    [anon_sym_GT] = ACTIONS(5327),
    [anon_sym_in] = ACTIONS(5327),
    [anon_sym_where] = ACTIONS(5325),
    [anon_sym_QMARK] = ACTIONS(5327),
    [anon_sym_BANG] = ACTIONS(5277),
    [anon_sym_PLUS_PLUS] = ACTIONS(5279),
    [anon_sym_DASH_DASH] = ACTIONS(5279),
    [anon_sym_PLUS] = ACTIONS(5327),
    [anon_sym_DASH] = ACTIONS(5327),
    [anon_sym_STAR] = ACTIONS(5325),
    [anon_sym_SLASH] = ACTIONS(5327),
    [anon_sym_PERCENT] = ACTIONS(5325),
    [anon_sym_CARET] = ACTIONS(5325),
    [anon_sym_PIPE] = ACTIONS(5327),
    [anon_sym_AMP] = ACTIONS(5327),
    [anon_sym_LT_LT] = ACTIONS(5325),
    [anon_sym_GT_GT] = ACTIONS(5327),
    [anon_sym_GT_GT_GT] = ACTIONS(5325),
    [anon_sym_EQ_EQ] = ACTIONS(5325),
    [anon_sym_BANG_EQ] = ACTIONS(5325),
    [anon_sym_GT_EQ] = ACTIONS(5325),
    [anon_sym_LT_EQ] = ACTIONS(5325),
    [anon_sym_DOT] = ACTIONS(5249),
    [anon_sym_EQ_GT] = ACTIONS(5325),
    [anon_sym_switch] = ACTIONS(5325),
    [anon_sym_DOT_DOT] = ACTIONS(5325),
    [anon_sym_and] = ACTIONS(5325),
    [anon_sym_or] = ACTIONS(5327),
    [anon_sym_AMP_AMP] = ACTIONS(5325),
    [anon_sym_PIPE_PIPE] = ACTIONS(5325),
    [anon_sym_QMARK_QMARK] = ACTIONS(5325),
    [anon_sym_from] = ACTIONS(5325),
    [anon_sym_into] = ACTIONS(5325),
    [anon_sym_join] = ACTIONS(5325),
    [anon_sym_on] = ACTIONS(5325),
    [anon_sym_equals] = ACTIONS(5325),
    [anon_sym_let] = ACTIONS(5325),
    [anon_sym_orderby] = ACTIONS(5325),
    [anon_sym_group] = ACTIONS(5325),
    [anon_sym_by] = ACTIONS(5325),
    [anon_sym_select] = ACTIONS(5325),
    [anon_sym_as] = ACTIONS(5325),
    [anon_sym_is] = ACTIONS(5325),
    [anon_sym_DASH_GT] = ACTIONS(5247),
    [anon_sym_with] = ACTIONS(5325),
    [aux_sym_preproc_if_token3] = ACTIONS(5325),
    [aux_sym_preproc_else_token1] = ACTIONS(5325),
    [aux_sym_preproc_elif_token1] = ACTIONS(5325),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3583] = {
    [sym_preproc_region] = STATE(3583),
    [sym_preproc_endregion] = STATE(3583),
    [sym_preproc_line] = STATE(3583),
    [sym_preproc_pragma] = STATE(3583),
    [sym_preproc_nullable] = STATE(3583),
    [sym_preproc_error] = STATE(3583),
    [sym_preproc_warning] = STATE(3583),
    [sym_preproc_define] = STATE(3583),
    [sym_preproc_undef] = STATE(3583),
    [anon_sym_EQ] = ACTIONS(4162),
    [anon_sym_LBRACK] = ACTIONS(4808),
    [anon_sym_COMMA] = ACTIONS(4806),
    [anon_sym_LPAREN] = ACTIONS(4808),
    [anon_sym_LT] = ACTIONS(4811),
    [anon_sym_GT] = ACTIONS(4811),
    [anon_sym_where] = ACTIONS(4806),
    [anon_sym_QMARK] = ACTIONS(4811),
    [anon_sym_BANG] = ACTIONS(4811),
    [anon_sym_PLUS_PLUS] = ACTIONS(4808),
    [anon_sym_DASH_DASH] = ACTIONS(4808),
    [anon_sym_PLUS] = ACTIONS(4811),
    [anon_sym_DASH] = ACTIONS(4811),
    [anon_sym_STAR] = ACTIONS(4811),
    [anon_sym_SLASH] = ACTIONS(4811),
    [anon_sym_PERCENT] = ACTIONS(4811),
    [anon_sym_CARET] = ACTIONS(4811),
    [anon_sym_PIPE] = ACTIONS(4811),
    [anon_sym_AMP] = ACTIONS(4811),
    [anon_sym_LT_LT] = ACTIONS(4811),
    [anon_sym_GT_GT] = ACTIONS(4811),
    [anon_sym_GT_GT_GT] = ACTIONS(4811),
    [anon_sym_EQ_EQ] = ACTIONS(4808),
    [anon_sym_BANG_EQ] = ACTIONS(4808),
    [anon_sym_GT_EQ] = ACTIONS(4808),
    [anon_sym_LT_EQ] = ACTIONS(4808),
    [anon_sym_DOT] = ACTIONS(4811),
    [anon_sym_switch] = ACTIONS(4808),
    [anon_sym_DOT_DOT] = ACTIONS(4808),
    [anon_sym_and] = ACTIONS(4806),
    [anon_sym_or] = ACTIONS(4814),
    [anon_sym_PLUS_EQ] = ACTIONS(4177),
    [anon_sym_DASH_EQ] = ACTIONS(4177),
    [anon_sym_STAR_EQ] = ACTIONS(4177),
    [anon_sym_SLASH_EQ] = ACTIONS(4177),
    [anon_sym_PERCENT_EQ] = ACTIONS(4177),
    [anon_sym_AMP_EQ] = ACTIONS(4177),
    [anon_sym_CARET_EQ] = ACTIONS(4177),
    [anon_sym_PIPE_EQ] = ACTIONS(4177),
    [anon_sym_LT_LT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4177),
    [anon_sym_AMP_AMP] = ACTIONS(4808),
    [anon_sym_PIPE_PIPE] = ACTIONS(4808),
    [anon_sym_QMARK_QMARK] = ACTIONS(4811),
    [anon_sym_from] = ACTIONS(4806),
    [anon_sym_into] = ACTIONS(4806),
    [anon_sym_join] = ACTIONS(4806),
    [anon_sym_let] = ACTIONS(4806),
    [anon_sym_orderby] = ACTIONS(4806),
    [anon_sym_ascending] = ACTIONS(4806),
    [anon_sym_descending] = ACTIONS(4806),
    [anon_sym_group] = ACTIONS(4806),
    [anon_sym_select] = ACTIONS(4806),
    [anon_sym_as] = ACTIONS(4811),
    [anon_sym_is] = ACTIONS(4808),
    [anon_sym_DASH_GT] = ACTIONS(4808),
    [anon_sym_with] = ACTIONS(4808),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3584] = {
    [sym_type_argument_list] = STATE(3715),
    [sym_preproc_region] = STATE(3584),
    [sym_preproc_endregion] = STATE(3584),
    [sym_preproc_line] = STATE(3584),
    [sym_preproc_pragma] = STATE(3584),
    [sym_preproc_nullable] = STATE(3584),
    [sym_preproc_error] = STATE(3584),
    [sym_preproc_warning] = STATE(3584),
    [sym_preproc_define] = STATE(3584),
    [sym_preproc_undef] = STATE(3584),
    [anon_sym_SEMI] = ACTIONS(4140),
    [anon_sym_LBRACK] = ACTIONS(4140),
    [anon_sym_COLON] = ACTIONS(4140),
    [anon_sym_COMMA] = ACTIONS(4140),
    [anon_sym_RBRACK] = ACTIONS(4140),
    [anon_sym_LPAREN] = ACTIONS(4140),
    [anon_sym_RPAREN] = ACTIONS(4140),
    [anon_sym_LBRACE] = ACTIONS(4140),
    [anon_sym_RBRACE] = ACTIONS(4140),
    [anon_sym_LT] = ACTIONS(5329),
    [anon_sym_GT] = ACTIONS(4138),
    [anon_sym_in] = ACTIONS(4140),
    [anon_sym_where] = ACTIONS(4140),
    [anon_sym_QMARK] = ACTIONS(4138),
    [anon_sym_BANG] = ACTIONS(4138),
    [anon_sym_PLUS_PLUS] = ACTIONS(4140),
    [anon_sym_DASH_DASH] = ACTIONS(4140),
    [anon_sym_PLUS] = ACTIONS(4138),
    [anon_sym_DASH] = ACTIONS(4138),
    [anon_sym_STAR] = ACTIONS(4140),
    [anon_sym_SLASH] = ACTIONS(4138),
    [anon_sym_PERCENT] = ACTIONS(4140),
    [anon_sym_CARET] = ACTIONS(4140),
    [anon_sym_PIPE] = ACTIONS(4138),
    [anon_sym_AMP] = ACTIONS(4138),
    [anon_sym_LT_LT] = ACTIONS(4140),
    [anon_sym_GT_GT] = ACTIONS(4138),
    [anon_sym_GT_GT_GT] = ACTIONS(4140),
    [anon_sym_EQ_EQ] = ACTIONS(4140),
    [anon_sym_BANG_EQ] = ACTIONS(4140),
    [anon_sym_GT_EQ] = ACTIONS(4140),
    [anon_sym_LT_EQ] = ACTIONS(4140),
    [anon_sym_DOT] = ACTIONS(4138),
    [anon_sym_EQ_GT] = ACTIONS(4140),
    [anon_sym_switch] = ACTIONS(4140),
    [anon_sym_DOT_DOT] = ACTIONS(4140),
    [anon_sym_and] = ACTIONS(4140),
    [anon_sym_or] = ACTIONS(4138),
    [anon_sym_AMP_AMP] = ACTIONS(4140),
    [anon_sym_PIPE_PIPE] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK] = ACTIONS(4140),
    [anon_sym_from] = ACTIONS(4140),
    [anon_sym_join] = ACTIONS(4140),
    [anon_sym_on] = ACTIONS(4140),
    [anon_sym_equals] = ACTIONS(4140),
    [anon_sym_let] = ACTIONS(4140),
    [anon_sym_orderby] = ACTIONS(4140),
    [anon_sym_group] = ACTIONS(4140),
    [anon_sym_by] = ACTIONS(4140),
    [anon_sym_select] = ACTIONS(4140),
    [anon_sym_as] = ACTIONS(4140),
    [anon_sym_is] = ACTIONS(4140),
    [anon_sym_DASH_GT] = ACTIONS(4140),
    [anon_sym_with] = ACTIONS(4140),
    [aux_sym_preproc_if_token3] = ACTIONS(4140),
    [aux_sym_preproc_else_token1] = ACTIONS(4140),
    [aux_sym_preproc_elif_token1] = ACTIONS(4140),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3585] = {
    [sym_preproc_region] = STATE(3585),
    [sym_preproc_endregion] = STATE(3585),
    [sym_preproc_line] = STATE(3585),
    [sym_preproc_pragma] = STATE(3585),
    [sym_preproc_nullable] = STATE(3585),
    [sym_preproc_error] = STATE(3585),
    [sym_preproc_warning] = STATE(3585),
    [sym_preproc_define] = STATE(3585),
    [sym_preproc_undef] = STATE(3585),
    [anon_sym_SEMI] = ACTIONS(5286),
    [anon_sym_EQ] = ACTIONS(5332),
    [anon_sym_LBRACK] = ACTIONS(5286),
    [anon_sym_COMMA] = ACTIONS(5286),
    [anon_sym_RBRACK] = ACTIONS(5286),
    [anon_sym_LPAREN] = ACTIONS(5286),
    [anon_sym_RPAREN] = ACTIONS(5286),
    [anon_sym_RBRACE] = ACTIONS(5286),
    [anon_sym_LT] = ACTIONS(5288),
    [anon_sym_GT] = ACTIONS(5288),
    [anon_sym_in] = ACTIONS(5288),
    [anon_sym_QMARK] = ACTIONS(5288),
    [anon_sym_BANG] = ACTIONS(5288),
    [anon_sym_PLUS_PLUS] = ACTIONS(5286),
    [anon_sym_DASH_DASH] = ACTIONS(5286),
    [anon_sym_PLUS] = ACTIONS(5288),
    [anon_sym_DASH] = ACTIONS(5288),
    [anon_sym_STAR] = ACTIONS(5288),
    [anon_sym_SLASH] = ACTIONS(5288),
    [anon_sym_PERCENT] = ACTIONS(5288),
    [anon_sym_CARET] = ACTIONS(5288),
    [anon_sym_PIPE] = ACTIONS(5288),
    [anon_sym_AMP] = ACTIONS(5288),
    [anon_sym_LT_LT] = ACTIONS(5288),
    [anon_sym_GT_GT] = ACTIONS(5288),
    [anon_sym_GT_GT_GT] = ACTIONS(5288),
    [anon_sym_EQ_EQ] = ACTIONS(5286),
    [anon_sym_BANG_EQ] = ACTIONS(5286),
    [anon_sym_GT_EQ] = ACTIONS(5286),
    [anon_sym_LT_EQ] = ACTIONS(5286),
    [anon_sym_DOT] = ACTIONS(5288),
    [anon_sym_switch] = ACTIONS(5286),
    [anon_sym_DOT_DOT] = ACTIONS(5286),
    [anon_sym_and] = ACTIONS(5286),
    [anon_sym_or] = ACTIONS(5286),
    [anon_sym_PLUS_EQ] = ACTIONS(5334),
    [anon_sym_DASH_EQ] = ACTIONS(5334),
    [anon_sym_STAR_EQ] = ACTIONS(5334),
    [anon_sym_SLASH_EQ] = ACTIONS(5334),
    [anon_sym_PERCENT_EQ] = ACTIONS(5334),
    [anon_sym_AMP_EQ] = ACTIONS(5334),
    [anon_sym_CARET_EQ] = ACTIONS(5334),
    [anon_sym_PIPE_EQ] = ACTIONS(5334),
    [anon_sym_LT_LT_EQ] = ACTIONS(5334),
    [anon_sym_GT_GT_EQ] = ACTIONS(5334),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(5334),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(5334),
    [anon_sym_AMP_AMP] = ACTIONS(5286),
    [anon_sym_PIPE_PIPE] = ACTIONS(5286),
    [anon_sym_QMARK_QMARK] = ACTIONS(5288),
    [anon_sym_into] = ACTIONS(5286),
    [anon_sym_as] = ACTIONS(5286),
    [anon_sym_is] = ACTIONS(5286),
    [anon_sym_DASH_GT] = ACTIONS(5286),
    [anon_sym_with] = ACTIONS(5286),
    [aux_sym_preproc_if_token3] = ACTIONS(5286),
    [aux_sym_preproc_else_token1] = ACTIONS(5286),
    [aux_sym_preproc_elif_token1] = ACTIONS(5286),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3586] = {
    [sym_initializer_expression] = STATE(3784),
    [sym_preproc_region] = STATE(3586),
    [sym_preproc_endregion] = STATE(3586),
    [sym_preproc_line] = STATE(3586),
    [sym_preproc_pragma] = STATE(3586),
    [sym_preproc_nullable] = STATE(3586),
    [sym_preproc_error] = STATE(3586),
    [sym_preproc_warning] = STATE(3586),
    [sym_preproc_define] = STATE(3586),
    [sym_preproc_undef] = STATE(3586),
    [anon_sym_SEMI] = ACTIONS(4494),
    [anon_sym_LBRACK] = ACTIONS(5336),
    [anon_sym_COLON] = ACTIONS(5340),
    [anon_sym_COMMA] = ACTIONS(5340),
    [anon_sym_RBRACK] = ACTIONS(5340),
    [anon_sym_LPAREN] = ACTIONS(5340),
    [anon_sym_RPAREN] = ACTIONS(5340),
    [anon_sym_LBRACE] = ACTIONS(5343),
    [anon_sym_RBRACE] = ACTIONS(5340),
    [anon_sym_LT] = ACTIONS(5346),
    [anon_sym_GT] = ACTIONS(5346),
    [anon_sym_in] = ACTIONS(5340),
    [anon_sym_where] = ACTIONS(5340),
    [anon_sym_QMARK] = ACTIONS(5349),
    [anon_sym_BANG] = ACTIONS(5346),
    [anon_sym_PLUS_PLUS] = ACTIONS(5340),
    [anon_sym_DASH_DASH] = ACTIONS(5340),
    [anon_sym_PLUS] = ACTIONS(5346),
    [anon_sym_DASH] = ACTIONS(5346),
    [anon_sym_STAR] = ACTIONS(5340),
    [anon_sym_SLASH] = ACTIONS(5346),
    [anon_sym_PERCENT] = ACTIONS(5340),
    [anon_sym_CARET] = ACTIONS(5340),
    [anon_sym_PIPE] = ACTIONS(5346),
    [anon_sym_AMP] = ACTIONS(5346),
    [anon_sym_LT_LT] = ACTIONS(5340),
    [anon_sym_GT_GT] = ACTIONS(5346),
    [anon_sym_GT_GT_GT] = ACTIONS(5340),
    [anon_sym_EQ_EQ] = ACTIONS(5340),
    [anon_sym_BANG_EQ] = ACTIONS(5340),
    [anon_sym_GT_EQ] = ACTIONS(5340),
    [anon_sym_LT_EQ] = ACTIONS(5340),
    [anon_sym_DOT] = ACTIONS(5346),
    [anon_sym_EQ_GT] = ACTIONS(5340),
    [anon_sym_switch] = ACTIONS(5340),
    [anon_sym_DOT_DOT] = ACTIONS(5340),
    [anon_sym_and] = ACTIONS(5340),
    [anon_sym_or] = ACTIONS(5346),
    [anon_sym_AMP_AMP] = ACTIONS(5340),
    [anon_sym_PIPE_PIPE] = ACTIONS(5340),
    [anon_sym_QMARK_QMARK] = ACTIONS(5340),
    [anon_sym_from] = ACTIONS(5340),
    [anon_sym_join] = ACTIONS(5340),
    [anon_sym_on] = ACTIONS(5340),
    [anon_sym_equals] = ACTIONS(5340),
    [anon_sym_let] = ACTIONS(5340),
    [anon_sym_orderby] = ACTIONS(5340),
    [anon_sym_group] = ACTIONS(5340),
    [anon_sym_by] = ACTIONS(5340),
    [anon_sym_select] = ACTIONS(5340),
    [anon_sym_as] = ACTIONS(5340),
    [anon_sym_is] = ACTIONS(5340),
    [anon_sym_DASH_GT] = ACTIONS(5340),
    [anon_sym_with] = ACTIONS(5340),
    [aux_sym_preproc_if_token3] = ACTIONS(5340),
    [aux_sym_preproc_else_token1] = ACTIONS(5340),
    [aux_sym_preproc_elif_token1] = ACTIONS(5340),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3587] = {
    [sym_preproc_region] = STATE(3587),
    [sym_preproc_endregion] = STATE(3587),
    [sym_preproc_line] = STATE(3587),
    [sym_preproc_pragma] = STATE(3587),
    [sym_preproc_nullable] = STATE(3587),
    [sym_preproc_error] = STATE(3587),
    [sym_preproc_warning] = STATE(3587),
    [sym_preproc_define] = STATE(3587),
    [sym_preproc_undef] = STATE(3587),
    [anon_sym_SEMI] = ACTIONS(4554),
    [anon_sym_LBRACK] = ACTIONS(4554),
    [anon_sym_COLON] = ACTIONS(4554),
    [anon_sym_COMMA] = ACTIONS(4554),
    [anon_sym_RBRACK] = ACTIONS(4554),
    [anon_sym_LPAREN] = ACTIONS(4554),
    [anon_sym_RPAREN] = ACTIONS(4554),
    [anon_sym_LBRACE] = ACTIONS(4554),
    [anon_sym_RBRACE] = ACTIONS(4554),
    [anon_sym_LT] = ACTIONS(4552),
    [anon_sym_GT] = ACTIONS(4552),
    [anon_sym_in] = ACTIONS(4552),
    [anon_sym_where] = ACTIONS(4554),
    [anon_sym_QMARK] = ACTIONS(4552),
    [anon_sym_BANG] = ACTIONS(4552),
    [anon_sym_PLUS_PLUS] = ACTIONS(4554),
    [anon_sym_DASH_DASH] = ACTIONS(4554),
    [anon_sym_PLUS] = ACTIONS(4552),
    [anon_sym_DASH] = ACTIONS(4552),
    [anon_sym_STAR] = ACTIONS(4554),
    [anon_sym_SLASH] = ACTIONS(4552),
    [anon_sym_PERCENT] = ACTIONS(4554),
    [anon_sym_CARET] = ACTIONS(4554),
    [anon_sym_PIPE] = ACTIONS(4552),
    [anon_sym_AMP] = ACTIONS(4552),
    [anon_sym_LT_LT] = ACTIONS(4554),
    [anon_sym_GT_GT] = ACTIONS(4552),
    [anon_sym_GT_GT_GT] = ACTIONS(4554),
    [anon_sym_EQ_EQ] = ACTIONS(4554),
    [anon_sym_BANG_EQ] = ACTIONS(4554),
    [anon_sym_GT_EQ] = ACTIONS(4554),
    [anon_sym_LT_EQ] = ACTIONS(4554),
    [anon_sym_DOT] = ACTIONS(4552),
    [anon_sym_EQ_GT] = ACTIONS(4554),
    [anon_sym_switch] = ACTIONS(4554),
    [anon_sym_DOT_DOT] = ACTIONS(4554),
    [anon_sym_and] = ACTIONS(4554),
    [anon_sym_or] = ACTIONS(4552),
    [anon_sym_AMP_AMP] = ACTIONS(4554),
    [anon_sym_PIPE_PIPE] = ACTIONS(4554),
    [anon_sym_QMARK_QMARK] = ACTIONS(4554),
    [anon_sym_from] = ACTIONS(4554),
    [anon_sym_into] = ACTIONS(4554),
    [anon_sym_join] = ACTIONS(4554),
    [anon_sym_on] = ACTIONS(4554),
    [anon_sym_equals] = ACTIONS(4554),
    [anon_sym_let] = ACTIONS(4554),
    [anon_sym_orderby] = ACTIONS(4554),
    [anon_sym_group] = ACTIONS(4554),
    [anon_sym_by] = ACTIONS(4554),
    [anon_sym_select] = ACTIONS(4554),
    [anon_sym_as] = ACTIONS(4554),
    [anon_sym_is] = ACTIONS(4554),
    [anon_sym_DASH_GT] = ACTIONS(4554),
    [anon_sym_with] = ACTIONS(4554),
    [aux_sym_preproc_if_token3] = ACTIONS(4554),
    [aux_sym_preproc_else_token1] = ACTIONS(4554),
    [aux_sym_preproc_elif_token1] = ACTIONS(4554),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3588] = {
    [sym_preproc_region] = STATE(3588),
    [sym_preproc_endregion] = STATE(3588),
    [sym_preproc_line] = STATE(3588),
    [sym_preproc_pragma] = STATE(3588),
    [sym_preproc_nullable] = STATE(3588),
    [sym_preproc_error] = STATE(3588),
    [sym_preproc_warning] = STATE(3588),
    [sym_preproc_define] = STATE(3588),
    [sym_preproc_undef] = STATE(3588),
    [anon_sym_SEMI] = ACTIONS(4168),
    [anon_sym_LBRACK] = ACTIONS(4168),
    [anon_sym_COLON] = ACTIONS(4168),
    [anon_sym_COMMA] = ACTIONS(4168),
    [anon_sym_RBRACK] = ACTIONS(4168),
    [anon_sym_LPAREN] = ACTIONS(4168),
    [anon_sym_RPAREN] = ACTIONS(4168),
    [anon_sym_LBRACE] = ACTIONS(4168),
    [anon_sym_RBRACE] = ACTIONS(4168),
    [anon_sym_LT] = ACTIONS(4157),
    [anon_sym_GT] = ACTIONS(4157),
    [anon_sym_in] = ACTIONS(4157),
    [anon_sym_where] = ACTIONS(4168),
    [anon_sym_QMARK] = ACTIONS(4157),
    [anon_sym_BANG] = ACTIONS(4157),
    [anon_sym_PLUS_PLUS] = ACTIONS(4168),
    [anon_sym_DASH_DASH] = ACTIONS(4168),
    [anon_sym_PLUS] = ACTIONS(4157),
    [anon_sym_DASH] = ACTIONS(4157),
    [anon_sym_STAR] = ACTIONS(4168),
    [anon_sym_SLASH] = ACTIONS(4157),
    [anon_sym_PERCENT] = ACTIONS(4168),
    [anon_sym_CARET] = ACTIONS(4168),
    [anon_sym_PIPE] = ACTIONS(4157),
    [anon_sym_AMP] = ACTIONS(4157),
    [anon_sym_LT_LT] = ACTIONS(4168),
    [anon_sym_GT_GT] = ACTIONS(4157),
    [anon_sym_GT_GT_GT] = ACTIONS(4168),
    [anon_sym_EQ_EQ] = ACTIONS(4168),
    [anon_sym_BANG_EQ] = ACTIONS(4168),
    [anon_sym_GT_EQ] = ACTIONS(4168),
    [anon_sym_LT_EQ] = ACTIONS(4168),
    [anon_sym_DOT] = ACTIONS(4157),
    [anon_sym_EQ_GT] = ACTIONS(4168),
    [anon_sym_switch] = ACTIONS(4168),
    [anon_sym_DOT_DOT] = ACTIONS(4168),
    [anon_sym_and] = ACTIONS(4168),
    [anon_sym_or] = ACTIONS(4157),
    [anon_sym_AMP_AMP] = ACTIONS(4168),
    [anon_sym_PIPE_PIPE] = ACTIONS(4168),
    [anon_sym_QMARK_QMARK] = ACTIONS(4168),
    [anon_sym_from] = ACTIONS(4168),
    [anon_sym_into] = ACTIONS(4168),
    [anon_sym_join] = ACTIONS(4168),
    [anon_sym_on] = ACTIONS(4168),
    [anon_sym_equals] = ACTIONS(4168),
    [anon_sym_let] = ACTIONS(4168),
    [anon_sym_orderby] = ACTIONS(4168),
    [anon_sym_group] = ACTIONS(4168),
    [anon_sym_by] = ACTIONS(4168),
    [anon_sym_select] = ACTIONS(4168),
    [anon_sym_as] = ACTIONS(4168),
    [anon_sym_is] = ACTIONS(4168),
    [anon_sym_DASH_GT] = ACTIONS(4168),
    [anon_sym_with] = ACTIONS(4168),
    [aux_sym_preproc_if_token3] = ACTIONS(4168),
    [aux_sym_preproc_else_token1] = ACTIONS(4168),
    [aux_sym_preproc_elif_token1] = ACTIONS(4168),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3589] = {
    [sym_preproc_region] = STATE(3589),
    [sym_preproc_endregion] = STATE(3589),
    [sym_preproc_line] = STATE(3589),
    [sym_preproc_pragma] = STATE(3589),
    [sym_preproc_nullable] = STATE(3589),
    [sym_preproc_error] = STATE(3589),
    [sym_preproc_warning] = STATE(3589),
    [sym_preproc_define] = STATE(3589),
    [sym_preproc_undef] = STATE(3589),
    [anon_sym_SEMI] = ACTIONS(5353),
    [anon_sym_LBRACK] = ACTIONS(5353),
    [anon_sym_COLON] = ACTIONS(5353),
    [anon_sym_COMMA] = ACTIONS(5353),
    [anon_sym_RBRACK] = ACTIONS(5353),
    [anon_sym_LPAREN] = ACTIONS(5353),
    [anon_sym_RPAREN] = ACTIONS(5353),
    [anon_sym_LBRACE] = ACTIONS(5353),
    [anon_sym_RBRACE] = ACTIONS(5353),
    [anon_sym_LT] = ACTIONS(5355),
    [anon_sym_GT] = ACTIONS(5355),
    [anon_sym_in] = ACTIONS(5355),
    [anon_sym_where] = ACTIONS(5353),
    [anon_sym_QMARK] = ACTIONS(5355),
    [anon_sym_BANG] = ACTIONS(5355),
    [anon_sym_PLUS_PLUS] = ACTIONS(5353),
    [anon_sym_DASH_DASH] = ACTIONS(5353),
    [anon_sym_PLUS] = ACTIONS(5355),
    [anon_sym_DASH] = ACTIONS(5355),
    [anon_sym_STAR] = ACTIONS(5353),
    [anon_sym_SLASH] = ACTIONS(5355),
    [anon_sym_PERCENT] = ACTIONS(5353),
    [anon_sym_CARET] = ACTIONS(5353),
    [anon_sym_PIPE] = ACTIONS(5355),
    [anon_sym_AMP] = ACTIONS(5355),
    [anon_sym_LT_LT] = ACTIONS(5353),
    [anon_sym_GT_GT] = ACTIONS(5355),
    [anon_sym_GT_GT_GT] = ACTIONS(5353),
    [anon_sym_EQ_EQ] = ACTIONS(5353),
    [anon_sym_BANG_EQ] = ACTIONS(5353),
    [anon_sym_GT_EQ] = ACTIONS(5353),
    [anon_sym_LT_EQ] = ACTIONS(5353),
    [anon_sym_DOT] = ACTIONS(5355),
    [anon_sym_EQ_GT] = ACTIONS(5353),
    [anon_sym_switch] = ACTIONS(5353),
    [anon_sym_DOT_DOT] = ACTIONS(5353),
    [anon_sym_and] = ACTIONS(5353),
    [anon_sym_or] = ACTIONS(5355),
    [anon_sym_AMP_AMP] = ACTIONS(5353),
    [anon_sym_PIPE_PIPE] = ACTIONS(5353),
    [anon_sym_QMARK_QMARK] = ACTIONS(5353),
    [anon_sym_from] = ACTIONS(5353),
    [anon_sym_into] = ACTIONS(5353),
    [anon_sym_join] = ACTIONS(5353),
    [anon_sym_on] = ACTIONS(5353),
    [anon_sym_equals] = ACTIONS(5353),
    [anon_sym_let] = ACTIONS(5353),
    [anon_sym_orderby] = ACTIONS(5353),
    [anon_sym_group] = ACTIONS(5353),
    [anon_sym_by] = ACTIONS(5353),
    [anon_sym_select] = ACTIONS(5353),
    [anon_sym_as] = ACTIONS(5353),
    [anon_sym_is] = ACTIONS(5353),
    [anon_sym_DASH_GT] = ACTIONS(5353),
    [anon_sym_with] = ACTIONS(5353),
    [aux_sym_preproc_if_token3] = ACTIONS(5353),
    [aux_sym_preproc_else_token1] = ACTIONS(5353),
    [aux_sym_preproc_elif_token1] = ACTIONS(5353),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3590] = {
    [sym_type_argument_list] = STATE(3715),
    [sym_preproc_region] = STATE(3590),
    [sym_preproc_endregion] = STATE(3590),
    [sym_preproc_line] = STATE(3590),
    [sym_preproc_pragma] = STATE(3590),
    [sym_preproc_nullable] = STATE(3590),
    [sym_preproc_error] = STATE(3590),
    [sym_preproc_warning] = STATE(3590),
    [sym_preproc_define] = STATE(3590),
    [sym_preproc_undef] = STATE(3590),
    [anon_sym_SEMI] = ACTIONS(4140),
    [anon_sym_LBRACK] = ACTIONS(4140),
    [anon_sym_COMMA] = ACTIONS(4140),
    [anon_sym_RBRACK] = ACTIONS(4140),
    [anon_sym_LPAREN] = ACTIONS(4140),
    [anon_sym_RPAREN] = ACTIONS(4140),
    [anon_sym_LBRACE] = ACTIONS(4140),
    [anon_sym_RBRACE] = ACTIONS(4140),
    [anon_sym_LT] = ACTIONS(5329),
    [anon_sym_GT] = ACTIONS(4138),
    [anon_sym_in] = ACTIONS(4140),
    [anon_sym_where] = ACTIONS(4140),
    [anon_sym_QMARK] = ACTIONS(4138),
    [anon_sym_BANG] = ACTIONS(4138),
    [anon_sym_PLUS_PLUS] = ACTIONS(4140),
    [anon_sym_DASH_DASH] = ACTIONS(4140),
    [anon_sym_PLUS] = ACTIONS(4138),
    [anon_sym_DASH] = ACTIONS(4138),
    [anon_sym_STAR] = ACTIONS(4140),
    [anon_sym_SLASH] = ACTIONS(4138),
    [anon_sym_PERCENT] = ACTIONS(4140),
    [anon_sym_CARET] = ACTIONS(4140),
    [anon_sym_PIPE] = ACTIONS(4138),
    [anon_sym_AMP] = ACTIONS(4138),
    [anon_sym_LT_LT] = ACTIONS(4140),
    [anon_sym_GT_GT] = ACTIONS(4138),
    [anon_sym_GT_GT_GT] = ACTIONS(4140),
    [anon_sym_EQ_EQ] = ACTIONS(4140),
    [anon_sym_BANG_EQ] = ACTIONS(4140),
    [anon_sym_GT_EQ] = ACTIONS(4140),
    [anon_sym_LT_EQ] = ACTIONS(4140),
    [anon_sym_DOT] = ACTIONS(4138),
    [anon_sym_EQ_GT] = ACTIONS(4140),
    [anon_sym_COLON_COLON] = ACTIONS(5357),
    [anon_sym_switch] = ACTIONS(4140),
    [anon_sym_DOT_DOT] = ACTIONS(4140),
    [anon_sym_and] = ACTIONS(4140),
    [anon_sym_or] = ACTIONS(4138),
    [anon_sym_AMP_AMP] = ACTIONS(4140),
    [anon_sym_PIPE_PIPE] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK] = ACTIONS(4140),
    [anon_sym_from] = ACTIONS(4140),
    [anon_sym_join] = ACTIONS(4140),
    [anon_sym_on] = ACTIONS(4140),
    [anon_sym_equals] = ACTIONS(4140),
    [anon_sym_let] = ACTIONS(4140),
    [anon_sym_orderby] = ACTIONS(4140),
    [anon_sym_group] = ACTIONS(4140),
    [anon_sym_by] = ACTIONS(4140),
    [anon_sym_select] = ACTIONS(4140),
    [anon_sym_as] = ACTIONS(4140),
    [anon_sym_is] = ACTIONS(4140),
    [anon_sym_DASH_GT] = ACTIONS(4140),
    [anon_sym_with] = ACTIONS(4140),
    [aux_sym_preproc_if_token3] = ACTIONS(4140),
    [aux_sym_preproc_else_token1] = ACTIONS(4140),
    [aux_sym_preproc_elif_token1] = ACTIONS(4140),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3591] = {
    [sym_preproc_region] = STATE(3591),
    [sym_preproc_endregion] = STATE(3591),
    [sym_preproc_line] = STATE(3591),
    [sym_preproc_pragma] = STATE(3591),
    [sym_preproc_nullable] = STATE(3591),
    [sym_preproc_error] = STATE(3591),
    [sym_preproc_warning] = STATE(3591),
    [sym_preproc_define] = STATE(3591),
    [sym_preproc_undef] = STATE(3591),
    [anon_sym_SEMI] = ACTIONS(4484),
    [anon_sym_LBRACK] = ACTIONS(4484),
    [anon_sym_COLON] = ACTIONS(4484),
    [anon_sym_COMMA] = ACTIONS(4484),
    [anon_sym_RBRACK] = ACTIONS(4484),
    [anon_sym_LPAREN] = ACTIONS(4484),
    [anon_sym_RPAREN] = ACTIONS(4484),
    [anon_sym_LBRACE] = ACTIONS(4484),
    [anon_sym_RBRACE] = ACTIONS(4484),
    [anon_sym_LT] = ACTIONS(4482),
    [anon_sym_GT] = ACTIONS(4482),
    [anon_sym_in] = ACTIONS(4482),
    [anon_sym_where] = ACTIONS(4484),
    [anon_sym_QMARK] = ACTIONS(4482),
    [anon_sym_BANG] = ACTIONS(4482),
    [anon_sym_PLUS_PLUS] = ACTIONS(4484),
    [anon_sym_DASH_DASH] = ACTIONS(4484),
    [anon_sym_PLUS] = ACTIONS(4482),
    [anon_sym_DASH] = ACTIONS(4482),
    [anon_sym_STAR] = ACTIONS(4484),
    [anon_sym_SLASH] = ACTIONS(4482),
    [anon_sym_PERCENT] = ACTIONS(4484),
    [anon_sym_CARET] = ACTIONS(4484),
    [anon_sym_PIPE] = ACTIONS(4482),
    [anon_sym_AMP] = ACTIONS(4482),
    [anon_sym_LT_LT] = ACTIONS(4484),
    [anon_sym_GT_GT] = ACTIONS(4482),
    [anon_sym_GT_GT_GT] = ACTIONS(4484),
    [anon_sym_EQ_EQ] = ACTIONS(4484),
    [anon_sym_BANG_EQ] = ACTIONS(4484),
    [anon_sym_GT_EQ] = ACTIONS(4484),
    [anon_sym_LT_EQ] = ACTIONS(4484),
    [anon_sym_DOT] = ACTIONS(4482),
    [anon_sym_EQ_GT] = ACTIONS(4484),
    [anon_sym_switch] = ACTIONS(4484),
    [anon_sym_DOT_DOT] = ACTIONS(4484),
    [anon_sym_and] = ACTIONS(4484),
    [anon_sym_or] = ACTIONS(4482),
    [anon_sym_AMP_AMP] = ACTIONS(4484),
    [anon_sym_PIPE_PIPE] = ACTIONS(4484),
    [anon_sym_QMARK_QMARK] = ACTIONS(4484),
    [anon_sym_from] = ACTIONS(4484),
    [anon_sym_into] = ACTIONS(4484),
    [anon_sym_join] = ACTIONS(4484),
    [anon_sym_on] = ACTIONS(4484),
    [anon_sym_equals] = ACTIONS(4484),
    [anon_sym_let] = ACTIONS(4484),
    [anon_sym_orderby] = ACTIONS(4484),
    [anon_sym_group] = ACTIONS(4484),
    [anon_sym_by] = ACTIONS(4484),
    [anon_sym_select] = ACTIONS(4484),
    [anon_sym_as] = ACTIONS(4484),
    [anon_sym_is] = ACTIONS(4484),
    [anon_sym_DASH_GT] = ACTIONS(4484),
    [anon_sym_with] = ACTIONS(4484),
    [aux_sym_preproc_if_token3] = ACTIONS(4484),
    [aux_sym_preproc_else_token1] = ACTIONS(4484),
    [aux_sym_preproc_elif_token1] = ACTIONS(4484),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3592] = {
    [sym_initializer_expression] = STATE(3749),
    [sym_preproc_region] = STATE(3592),
    [sym_preproc_endregion] = STATE(3592),
    [sym_preproc_line] = STATE(3592),
    [sym_preproc_pragma] = STATE(3592),
    [sym_preproc_nullable] = STATE(3592),
    [sym_preproc_error] = STATE(3592),
    [sym_preproc_warning] = STATE(3592),
    [sym_preproc_define] = STATE(3592),
    [sym_preproc_undef] = STATE(3592),
    [anon_sym_SEMI] = ACTIONS(5303),
    [anon_sym_LBRACK] = ACTIONS(5303),
    [anon_sym_COLON] = ACTIONS(5303),
    [anon_sym_COMMA] = ACTIONS(5303),
    [anon_sym_RBRACK] = ACTIONS(5303),
    [anon_sym_LPAREN] = ACTIONS(5303),
    [anon_sym_RPAREN] = ACTIONS(5303),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_RBRACE] = ACTIONS(5303),
    [anon_sym_LT] = ACTIONS(5305),
    [anon_sym_GT] = ACTIONS(5305),
    [anon_sym_in] = ACTIONS(5303),
    [anon_sym_where] = ACTIONS(5303),
    [anon_sym_QMARK] = ACTIONS(5305),
    [anon_sym_BANG] = ACTIONS(5305),
    [anon_sym_PLUS_PLUS] = ACTIONS(5303),
    [anon_sym_DASH_DASH] = ACTIONS(5303),
    [anon_sym_PLUS] = ACTIONS(5305),
    [anon_sym_DASH] = ACTIONS(5305),
    [anon_sym_STAR] = ACTIONS(5303),
    [anon_sym_SLASH] = ACTIONS(5305),
    [anon_sym_PERCENT] = ACTIONS(5303),
    [anon_sym_CARET] = ACTIONS(5303),
    [anon_sym_PIPE] = ACTIONS(5305),
    [anon_sym_AMP] = ACTIONS(5305),
    [anon_sym_LT_LT] = ACTIONS(5303),
    [anon_sym_GT_GT] = ACTIONS(5305),
    [anon_sym_GT_GT_GT] = ACTIONS(5303),
    [anon_sym_EQ_EQ] = ACTIONS(5303),
    [anon_sym_BANG_EQ] = ACTIONS(5303),
    [anon_sym_GT_EQ] = ACTIONS(5303),
    [anon_sym_LT_EQ] = ACTIONS(5303),
    [anon_sym_DOT] = ACTIONS(5305),
    [anon_sym_EQ_GT] = ACTIONS(5303),
    [anon_sym_switch] = ACTIONS(5303),
    [anon_sym_DOT_DOT] = ACTIONS(5303),
    [anon_sym_and] = ACTIONS(5303),
    [anon_sym_or] = ACTIONS(5305),
    [anon_sym_AMP_AMP] = ACTIONS(5303),
    [anon_sym_PIPE_PIPE] = ACTIONS(5303),
    [anon_sym_QMARK_QMARK] = ACTIONS(5303),
    [anon_sym_from] = ACTIONS(5303),
    [anon_sym_join] = ACTIONS(5303),
    [anon_sym_on] = ACTIONS(5303),
    [anon_sym_equals] = ACTIONS(5303),
    [anon_sym_let] = ACTIONS(5303),
    [anon_sym_orderby] = ACTIONS(5303),
    [anon_sym_group] = ACTIONS(5303),
    [anon_sym_by] = ACTIONS(5303),
    [anon_sym_select] = ACTIONS(5303),
    [anon_sym_as] = ACTIONS(5303),
    [anon_sym_is] = ACTIONS(5303),
    [anon_sym_DASH_GT] = ACTIONS(5303),
    [anon_sym_with] = ACTIONS(5303),
    [aux_sym_preproc_if_token3] = ACTIONS(5303),
    [aux_sym_preproc_else_token1] = ACTIONS(5303),
    [aux_sym_preproc_elif_token1] = ACTIONS(5303),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3593] = {
    [sym_preproc_region] = STATE(3593),
    [sym_preproc_endregion] = STATE(3593),
    [sym_preproc_line] = STATE(3593),
    [sym_preproc_pragma] = STATE(3593),
    [sym_preproc_nullable] = STATE(3593),
    [sym_preproc_error] = STATE(3593),
    [sym_preproc_warning] = STATE(3593),
    [sym_preproc_define] = STATE(3593),
    [sym_preproc_undef] = STATE(3593),
    [anon_sym_SEMI] = ACTIONS(4626),
    [anon_sym_LBRACK] = ACTIONS(4626),
    [anon_sym_COLON] = ACTIONS(4626),
    [anon_sym_COMMA] = ACTIONS(4626),
    [anon_sym_RBRACK] = ACTIONS(4626),
    [anon_sym_LPAREN] = ACTIONS(4626),
    [anon_sym_RPAREN] = ACTIONS(4626),
    [anon_sym_LBRACE] = ACTIONS(4626),
    [anon_sym_RBRACE] = ACTIONS(4626),
    [anon_sym_LT] = ACTIONS(4624),
    [anon_sym_GT] = ACTIONS(4624),
    [anon_sym_in] = ACTIONS(4624),
    [anon_sym_where] = ACTIONS(4626),
    [anon_sym_QMARK] = ACTIONS(4624),
    [anon_sym_BANG] = ACTIONS(4624),
    [anon_sym_PLUS_PLUS] = ACTIONS(4626),
    [anon_sym_DASH_DASH] = ACTIONS(4626),
    [anon_sym_PLUS] = ACTIONS(4624),
    [anon_sym_DASH] = ACTIONS(4624),
    [anon_sym_STAR] = ACTIONS(4626),
    [anon_sym_SLASH] = ACTIONS(4624),
    [anon_sym_PERCENT] = ACTIONS(4626),
    [anon_sym_CARET] = ACTIONS(4626),
    [anon_sym_PIPE] = ACTIONS(4624),
    [anon_sym_AMP] = ACTIONS(4624),
    [anon_sym_LT_LT] = ACTIONS(4626),
    [anon_sym_GT_GT] = ACTIONS(4624),
    [anon_sym_GT_GT_GT] = ACTIONS(4626),
    [anon_sym_EQ_EQ] = ACTIONS(4626),
    [anon_sym_BANG_EQ] = ACTIONS(4626),
    [anon_sym_GT_EQ] = ACTIONS(4626),
    [anon_sym_LT_EQ] = ACTIONS(4626),
    [anon_sym_DOT] = ACTIONS(4624),
    [anon_sym_EQ_GT] = ACTIONS(4626),
    [anon_sym_switch] = ACTIONS(4626),
    [anon_sym_DOT_DOT] = ACTIONS(4626),
    [anon_sym_and] = ACTIONS(4626),
    [anon_sym_or] = ACTIONS(4624),
    [anon_sym_AMP_AMP] = ACTIONS(4626),
    [anon_sym_PIPE_PIPE] = ACTIONS(4626),
    [anon_sym_QMARK_QMARK] = ACTIONS(4626),
    [anon_sym_from] = ACTIONS(4626),
    [anon_sym_into] = ACTIONS(4626),
    [anon_sym_join] = ACTIONS(4626),
    [anon_sym_on] = ACTIONS(4626),
    [anon_sym_equals] = ACTIONS(4626),
    [anon_sym_let] = ACTIONS(4626),
    [anon_sym_orderby] = ACTIONS(4626),
    [anon_sym_group] = ACTIONS(4626),
    [anon_sym_by] = ACTIONS(4626),
    [anon_sym_select] = ACTIONS(4626),
    [anon_sym_as] = ACTIONS(4626),
    [anon_sym_is] = ACTIONS(4626),
    [anon_sym_DASH_GT] = ACTIONS(4626),
    [anon_sym_with] = ACTIONS(4626),
    [aux_sym_preproc_if_token3] = ACTIONS(4626),
    [aux_sym_preproc_else_token1] = ACTIONS(4626),
    [aux_sym_preproc_elif_token1] = ACTIONS(4626),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3594] = {
    [sym_initializer_expression] = STATE(3773),
    [sym_preproc_region] = STATE(3594),
    [sym_preproc_endregion] = STATE(3594),
    [sym_preproc_line] = STATE(3594),
    [sym_preproc_pragma] = STATE(3594),
    [sym_preproc_nullable] = STATE(3594),
    [sym_preproc_error] = STATE(3594),
    [sym_preproc_warning] = STATE(3594),
    [sym_preproc_define] = STATE(3594),
    [sym_preproc_undef] = STATE(3594),
    [anon_sym_SEMI] = ACTIONS(5315),
    [anon_sym_LBRACK] = ACTIONS(5315),
    [anon_sym_COLON] = ACTIONS(5315),
    [anon_sym_COMMA] = ACTIONS(5315),
    [anon_sym_RBRACK] = ACTIONS(5315),
    [anon_sym_LPAREN] = ACTIONS(5315),
    [anon_sym_RPAREN] = ACTIONS(5315),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_RBRACE] = ACTIONS(5315),
    [anon_sym_LT] = ACTIONS(5317),
    [anon_sym_GT] = ACTIONS(5317),
    [anon_sym_in] = ACTIONS(5315),
    [anon_sym_where] = ACTIONS(5315),
    [anon_sym_QMARK] = ACTIONS(5317),
    [anon_sym_BANG] = ACTIONS(5317),
    [anon_sym_PLUS_PLUS] = ACTIONS(5315),
    [anon_sym_DASH_DASH] = ACTIONS(5315),
    [anon_sym_PLUS] = ACTIONS(5317),
    [anon_sym_DASH] = ACTIONS(5317),
    [anon_sym_STAR] = ACTIONS(5315),
    [anon_sym_SLASH] = ACTIONS(5317),
    [anon_sym_PERCENT] = ACTIONS(5315),
    [anon_sym_CARET] = ACTIONS(5315),
    [anon_sym_PIPE] = ACTIONS(5317),
    [anon_sym_AMP] = ACTIONS(5317),
    [anon_sym_LT_LT] = ACTIONS(5315),
    [anon_sym_GT_GT] = ACTIONS(5317),
    [anon_sym_GT_GT_GT] = ACTIONS(5315),
    [anon_sym_EQ_EQ] = ACTIONS(5315),
    [anon_sym_BANG_EQ] = ACTIONS(5315),
    [anon_sym_GT_EQ] = ACTIONS(5315),
    [anon_sym_LT_EQ] = ACTIONS(5315),
    [anon_sym_DOT] = ACTIONS(5317),
    [anon_sym_EQ_GT] = ACTIONS(5315),
    [anon_sym_switch] = ACTIONS(5315),
    [anon_sym_DOT_DOT] = ACTIONS(5315),
    [anon_sym_and] = ACTIONS(5315),
    [anon_sym_or] = ACTIONS(5317),
    [anon_sym_AMP_AMP] = ACTIONS(5315),
    [anon_sym_PIPE_PIPE] = ACTIONS(5315),
    [anon_sym_QMARK_QMARK] = ACTIONS(5315),
    [anon_sym_from] = ACTIONS(5315),
    [anon_sym_join] = ACTIONS(5315),
    [anon_sym_on] = ACTIONS(5315),
    [anon_sym_equals] = ACTIONS(5315),
    [anon_sym_let] = ACTIONS(5315),
    [anon_sym_orderby] = ACTIONS(5315),
    [anon_sym_group] = ACTIONS(5315),
    [anon_sym_by] = ACTIONS(5315),
    [anon_sym_select] = ACTIONS(5315),
    [anon_sym_as] = ACTIONS(5315),
    [anon_sym_is] = ACTIONS(5315),
    [anon_sym_DASH_GT] = ACTIONS(5315),
    [anon_sym_with] = ACTIONS(5315),
    [aux_sym_preproc_if_token3] = ACTIONS(5315),
    [aux_sym_preproc_else_token1] = ACTIONS(5315),
    [aux_sym_preproc_elif_token1] = ACTIONS(5315),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3595] = {
    [sym_preproc_region] = STATE(3595),
    [sym_preproc_endregion] = STATE(3595),
    [sym_preproc_line] = STATE(3595),
    [sym_preproc_pragma] = STATE(3595),
    [sym_preproc_nullable] = STATE(3595),
    [sym_preproc_error] = STATE(3595),
    [sym_preproc_warning] = STATE(3595),
    [sym_preproc_define] = STATE(3595),
    [sym_preproc_undef] = STATE(3595),
    [anon_sym_SEMI] = ACTIONS(5359),
    [anon_sym_LBRACK] = ACTIONS(5359),
    [anon_sym_COLON] = ACTIONS(5359),
    [anon_sym_COMMA] = ACTIONS(5359),
    [anon_sym_RBRACK] = ACTIONS(5359),
    [anon_sym_LPAREN] = ACTIONS(5359),
    [anon_sym_RPAREN] = ACTIONS(5359),
    [anon_sym_LBRACE] = ACTIONS(5359),
    [anon_sym_RBRACE] = ACTIONS(5359),
    [anon_sym_LT] = ACTIONS(5361),
    [anon_sym_GT] = ACTIONS(5361),
    [anon_sym_in] = ACTIONS(5361),
    [anon_sym_where] = ACTIONS(5359),
    [anon_sym_QMARK] = ACTIONS(5361),
    [anon_sym_BANG] = ACTIONS(5361),
    [anon_sym_PLUS_PLUS] = ACTIONS(5359),
    [anon_sym_DASH_DASH] = ACTIONS(5359),
    [anon_sym_PLUS] = ACTIONS(5361),
    [anon_sym_DASH] = ACTIONS(5361),
    [anon_sym_STAR] = ACTIONS(5359),
    [anon_sym_SLASH] = ACTIONS(5361),
    [anon_sym_PERCENT] = ACTIONS(5359),
    [anon_sym_CARET] = ACTIONS(5359),
    [anon_sym_PIPE] = ACTIONS(5361),
    [anon_sym_AMP] = ACTIONS(5361),
    [anon_sym_LT_LT] = ACTIONS(5359),
    [anon_sym_GT_GT] = ACTIONS(5361),
    [anon_sym_GT_GT_GT] = ACTIONS(5359),
    [anon_sym_EQ_EQ] = ACTIONS(5359),
    [anon_sym_BANG_EQ] = ACTIONS(5359),
    [anon_sym_GT_EQ] = ACTIONS(5359),
    [anon_sym_LT_EQ] = ACTIONS(5359),
    [anon_sym_DOT] = ACTIONS(5361),
    [anon_sym_EQ_GT] = ACTIONS(5359),
    [anon_sym_switch] = ACTIONS(5359),
    [anon_sym_DOT_DOT] = ACTIONS(5359),
    [anon_sym_and] = ACTIONS(5359),
    [anon_sym_or] = ACTIONS(5361),
    [anon_sym_AMP_AMP] = ACTIONS(5359),
    [anon_sym_PIPE_PIPE] = ACTIONS(5359),
    [anon_sym_QMARK_QMARK] = ACTIONS(5359),
    [anon_sym_from] = ACTIONS(5359),
    [anon_sym_into] = ACTIONS(5359),
    [anon_sym_join] = ACTIONS(5359),
    [anon_sym_on] = ACTIONS(5359),
    [anon_sym_equals] = ACTIONS(5359),
    [anon_sym_let] = ACTIONS(5359),
    [anon_sym_orderby] = ACTIONS(5359),
    [anon_sym_group] = ACTIONS(5359),
    [anon_sym_by] = ACTIONS(5359),
    [anon_sym_select] = ACTIONS(5359),
    [anon_sym_as] = ACTIONS(5359),
    [anon_sym_is] = ACTIONS(5359),
    [anon_sym_DASH_GT] = ACTIONS(5359),
    [anon_sym_with] = ACTIONS(5359),
    [aux_sym_preproc_if_token3] = ACTIONS(5359),
    [aux_sym_preproc_else_token1] = ACTIONS(5359),
    [aux_sym_preproc_elif_token1] = ACTIONS(5359),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3596] = {
    [sym_preproc_region] = STATE(3596),
    [sym_preproc_endregion] = STATE(3596),
    [sym_preproc_line] = STATE(3596),
    [sym_preproc_pragma] = STATE(3596),
    [sym_preproc_nullable] = STATE(3596),
    [sym_preproc_error] = STATE(3596),
    [sym_preproc_warning] = STATE(3596),
    [sym_preproc_define] = STATE(3596),
    [sym_preproc_undef] = STATE(3596),
    [anon_sym_SEMI] = ACTIONS(4494),
    [anon_sym_LBRACK] = ACTIONS(4494),
    [anon_sym_COLON] = ACTIONS(4494),
    [anon_sym_COMMA] = ACTIONS(4494),
    [anon_sym_RBRACK] = ACTIONS(4494),
    [anon_sym_LPAREN] = ACTIONS(4494),
    [anon_sym_RPAREN] = ACTIONS(4494),
    [anon_sym_LBRACE] = ACTIONS(4494),
    [anon_sym_RBRACE] = ACTIONS(4494),
    [anon_sym_LT] = ACTIONS(4492),
    [anon_sym_GT] = ACTIONS(4492),
    [anon_sym_in] = ACTIONS(4492),
    [anon_sym_where] = ACTIONS(4494),
    [anon_sym_QMARK] = ACTIONS(4492),
    [anon_sym_BANG] = ACTIONS(4492),
    [anon_sym_PLUS_PLUS] = ACTIONS(4494),
    [anon_sym_DASH_DASH] = ACTIONS(4494),
    [anon_sym_PLUS] = ACTIONS(4492),
    [anon_sym_DASH] = ACTIONS(4492),
    [anon_sym_STAR] = ACTIONS(4494),
    [anon_sym_SLASH] = ACTIONS(4492),
    [anon_sym_PERCENT] = ACTIONS(4494),
    [anon_sym_CARET] = ACTIONS(4494),
    [anon_sym_PIPE] = ACTIONS(4492),
    [anon_sym_AMP] = ACTIONS(4492),
    [anon_sym_LT_LT] = ACTIONS(4494),
    [anon_sym_GT_GT] = ACTIONS(4492),
    [anon_sym_GT_GT_GT] = ACTIONS(4494),
    [anon_sym_EQ_EQ] = ACTIONS(4494),
    [anon_sym_BANG_EQ] = ACTIONS(4494),
    [anon_sym_GT_EQ] = ACTIONS(4494),
    [anon_sym_LT_EQ] = ACTIONS(4494),
    [anon_sym_DOT] = ACTIONS(4492),
    [anon_sym_EQ_GT] = ACTIONS(4494),
    [anon_sym_switch] = ACTIONS(4494),
    [anon_sym_DOT_DOT] = ACTIONS(4494),
    [anon_sym_and] = ACTIONS(4494),
    [anon_sym_or] = ACTIONS(4492),
    [anon_sym_AMP_AMP] = ACTIONS(4494),
    [anon_sym_PIPE_PIPE] = ACTIONS(4494),
    [anon_sym_QMARK_QMARK] = ACTIONS(4494),
    [anon_sym_from] = ACTIONS(4494),
    [anon_sym_into] = ACTIONS(4494),
    [anon_sym_join] = ACTIONS(4494),
    [anon_sym_on] = ACTIONS(4494),
    [anon_sym_equals] = ACTIONS(4494),
    [anon_sym_let] = ACTIONS(4494),
    [anon_sym_orderby] = ACTIONS(4494),
    [anon_sym_group] = ACTIONS(4494),
    [anon_sym_by] = ACTIONS(4494),
    [anon_sym_select] = ACTIONS(4494),
    [anon_sym_as] = ACTIONS(4494),
    [anon_sym_is] = ACTIONS(4494),
    [anon_sym_DASH_GT] = ACTIONS(4494),
    [anon_sym_with] = ACTIONS(4494),
    [aux_sym_preproc_if_token3] = ACTIONS(4494),
    [aux_sym_preproc_else_token1] = ACTIONS(4494),
    [aux_sym_preproc_elif_token1] = ACTIONS(4494),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3597] = {
    [sym_preproc_region] = STATE(3597),
    [sym_preproc_endregion] = STATE(3597),
    [sym_preproc_line] = STATE(3597),
    [sym_preproc_pragma] = STATE(3597),
    [sym_preproc_nullable] = STATE(3597),
    [sym_preproc_error] = STATE(3597),
    [sym_preproc_warning] = STATE(3597),
    [sym_preproc_define] = STATE(3597),
    [sym_preproc_undef] = STATE(3597),
    [anon_sym_SEMI] = ACTIONS(4140),
    [anon_sym_LBRACK] = ACTIONS(4140),
    [anon_sym_COLON] = ACTIONS(4140),
    [anon_sym_COMMA] = ACTIONS(4140),
    [anon_sym_RBRACK] = ACTIONS(4140),
    [anon_sym_LPAREN] = ACTIONS(4140),
    [anon_sym_RPAREN] = ACTIONS(4140),
    [anon_sym_LBRACE] = ACTIONS(4140),
    [anon_sym_RBRACE] = ACTIONS(4140),
    [anon_sym_LT] = ACTIONS(4138),
    [anon_sym_GT] = ACTIONS(4138),
    [anon_sym_in] = ACTIONS(4138),
    [anon_sym_where] = ACTIONS(4140),
    [anon_sym_QMARK] = ACTIONS(4138),
    [anon_sym_BANG] = ACTIONS(4138),
    [anon_sym_PLUS_PLUS] = ACTIONS(4140),
    [anon_sym_DASH_DASH] = ACTIONS(4140),
    [anon_sym_PLUS] = ACTIONS(4138),
    [anon_sym_DASH] = ACTIONS(4138),
    [anon_sym_STAR] = ACTIONS(4140),
    [anon_sym_SLASH] = ACTIONS(4138),
    [anon_sym_PERCENT] = ACTIONS(4140),
    [anon_sym_CARET] = ACTIONS(4140),
    [anon_sym_PIPE] = ACTIONS(4138),
    [anon_sym_AMP] = ACTIONS(4138),
    [anon_sym_LT_LT] = ACTIONS(4140),
    [anon_sym_GT_GT] = ACTIONS(4138),
    [anon_sym_GT_GT_GT] = ACTIONS(4140),
    [anon_sym_EQ_EQ] = ACTIONS(4140),
    [anon_sym_BANG_EQ] = ACTIONS(4140),
    [anon_sym_GT_EQ] = ACTIONS(4140),
    [anon_sym_LT_EQ] = ACTIONS(4140),
    [anon_sym_DOT] = ACTIONS(4138),
    [anon_sym_EQ_GT] = ACTIONS(4140),
    [anon_sym_switch] = ACTIONS(4140),
    [anon_sym_DOT_DOT] = ACTIONS(4140),
    [anon_sym_and] = ACTIONS(4140),
    [anon_sym_or] = ACTIONS(4138),
    [anon_sym_AMP_AMP] = ACTIONS(4140),
    [anon_sym_PIPE_PIPE] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK] = ACTIONS(4140),
    [anon_sym_from] = ACTIONS(4140),
    [anon_sym_into] = ACTIONS(4140),
    [anon_sym_join] = ACTIONS(4140),
    [anon_sym_on] = ACTIONS(4140),
    [anon_sym_equals] = ACTIONS(4140),
    [anon_sym_let] = ACTIONS(4140),
    [anon_sym_orderby] = ACTIONS(4140),
    [anon_sym_group] = ACTIONS(4140),
    [anon_sym_by] = ACTIONS(4140),
    [anon_sym_select] = ACTIONS(4140),
    [anon_sym_as] = ACTIONS(4140),
    [anon_sym_is] = ACTIONS(4140),
    [anon_sym_DASH_GT] = ACTIONS(4140),
    [anon_sym_with] = ACTIONS(4140),
    [aux_sym_preproc_if_token3] = ACTIONS(4140),
    [aux_sym_preproc_else_token1] = ACTIONS(4140),
    [aux_sym_preproc_elif_token1] = ACTIONS(4140),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3598] = {
    [sym_preproc_region] = STATE(3598),
    [sym_preproc_endregion] = STATE(3598),
    [sym_preproc_line] = STATE(3598),
    [sym_preproc_pragma] = STATE(3598),
    [sym_preproc_nullable] = STATE(3598),
    [sym_preproc_error] = STATE(3598),
    [sym_preproc_warning] = STATE(3598),
    [sym_preproc_define] = STATE(3598),
    [sym_preproc_undef] = STATE(3598),
    [anon_sym_SEMI] = ACTIONS(4546),
    [anon_sym_LBRACK] = ACTIONS(4546),
    [anon_sym_COLON] = ACTIONS(4546),
    [anon_sym_COMMA] = ACTIONS(4546),
    [anon_sym_RBRACK] = ACTIONS(4546),
    [anon_sym_LPAREN] = ACTIONS(4546),
    [anon_sym_RPAREN] = ACTIONS(4546),
    [anon_sym_LBRACE] = ACTIONS(4546),
    [anon_sym_RBRACE] = ACTIONS(4546),
    [anon_sym_LT] = ACTIONS(4544),
    [anon_sym_GT] = ACTIONS(4544),
    [anon_sym_in] = ACTIONS(4544),
    [anon_sym_where] = ACTIONS(4546),
    [anon_sym_QMARK] = ACTIONS(4544),
    [anon_sym_BANG] = ACTIONS(4544),
    [anon_sym_PLUS_PLUS] = ACTIONS(4546),
    [anon_sym_DASH_DASH] = ACTIONS(4546),
    [anon_sym_PLUS] = ACTIONS(4544),
    [anon_sym_DASH] = ACTIONS(4544),
    [anon_sym_STAR] = ACTIONS(4546),
    [anon_sym_SLASH] = ACTIONS(4544),
    [anon_sym_PERCENT] = ACTIONS(4546),
    [anon_sym_CARET] = ACTIONS(4546),
    [anon_sym_PIPE] = ACTIONS(4544),
    [anon_sym_AMP] = ACTIONS(4544),
    [anon_sym_LT_LT] = ACTIONS(4546),
    [anon_sym_GT_GT] = ACTIONS(4544),
    [anon_sym_GT_GT_GT] = ACTIONS(4546),
    [anon_sym_EQ_EQ] = ACTIONS(4546),
    [anon_sym_BANG_EQ] = ACTIONS(4546),
    [anon_sym_GT_EQ] = ACTIONS(4546),
    [anon_sym_LT_EQ] = ACTIONS(4546),
    [anon_sym_DOT] = ACTIONS(4544),
    [anon_sym_EQ_GT] = ACTIONS(4546),
    [anon_sym_switch] = ACTIONS(4546),
    [anon_sym_DOT_DOT] = ACTIONS(4546),
    [anon_sym_and] = ACTIONS(4546),
    [anon_sym_or] = ACTIONS(4544),
    [anon_sym_AMP_AMP] = ACTIONS(4546),
    [anon_sym_PIPE_PIPE] = ACTIONS(4546),
    [anon_sym_QMARK_QMARK] = ACTIONS(4546),
    [anon_sym_from] = ACTIONS(4546),
    [anon_sym_into] = ACTIONS(4546),
    [anon_sym_join] = ACTIONS(4546),
    [anon_sym_on] = ACTIONS(4546),
    [anon_sym_equals] = ACTIONS(4546),
    [anon_sym_let] = ACTIONS(4546),
    [anon_sym_orderby] = ACTIONS(4546),
    [anon_sym_group] = ACTIONS(4546),
    [anon_sym_by] = ACTIONS(4546),
    [anon_sym_select] = ACTIONS(4546),
    [anon_sym_as] = ACTIONS(4546),
    [anon_sym_is] = ACTIONS(4546),
    [anon_sym_DASH_GT] = ACTIONS(4546),
    [anon_sym_with] = ACTIONS(4546),
    [aux_sym_preproc_if_token3] = ACTIONS(4546),
    [aux_sym_preproc_else_token1] = ACTIONS(4546),
    [aux_sym_preproc_elif_token1] = ACTIONS(4546),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3599] = {
    [sym_preproc_region] = STATE(3599),
    [sym_preproc_endregion] = STATE(3599),
    [sym_preproc_line] = STATE(3599),
    [sym_preproc_pragma] = STATE(3599),
    [sym_preproc_nullable] = STATE(3599),
    [sym_preproc_error] = STATE(3599),
    [sym_preproc_warning] = STATE(3599),
    [sym_preproc_define] = STATE(3599),
    [sym_preproc_undef] = STATE(3599),
    [anon_sym_SEMI] = ACTIONS(4181),
    [anon_sym_LBRACK] = ACTIONS(4181),
    [anon_sym_COLON] = ACTIONS(4181),
    [anon_sym_COMMA] = ACTIONS(4181),
    [anon_sym_RBRACK] = ACTIONS(4181),
    [anon_sym_LPAREN] = ACTIONS(4181),
    [anon_sym_RPAREN] = ACTIONS(4181),
    [anon_sym_LBRACE] = ACTIONS(4181),
    [anon_sym_RBRACE] = ACTIONS(4181),
    [anon_sym_LT] = ACTIONS(4179),
    [anon_sym_GT] = ACTIONS(4179),
    [anon_sym_in] = ACTIONS(4179),
    [anon_sym_where] = ACTIONS(4181),
    [anon_sym_QMARK] = ACTIONS(4179),
    [anon_sym_BANG] = ACTIONS(4179),
    [anon_sym_PLUS_PLUS] = ACTIONS(4181),
    [anon_sym_DASH_DASH] = ACTIONS(4181),
    [anon_sym_PLUS] = ACTIONS(4179),
    [anon_sym_DASH] = ACTIONS(4179),
    [anon_sym_STAR] = ACTIONS(4181),
    [anon_sym_SLASH] = ACTIONS(4179),
    [anon_sym_PERCENT] = ACTIONS(4181),
    [anon_sym_CARET] = ACTIONS(4181),
    [anon_sym_PIPE] = ACTIONS(4179),
    [anon_sym_AMP] = ACTIONS(4179),
    [anon_sym_LT_LT] = ACTIONS(4181),
    [anon_sym_GT_GT] = ACTIONS(4179),
    [anon_sym_GT_GT_GT] = ACTIONS(4181),
    [anon_sym_EQ_EQ] = ACTIONS(4181),
    [anon_sym_BANG_EQ] = ACTIONS(4181),
    [anon_sym_GT_EQ] = ACTIONS(4181),
    [anon_sym_LT_EQ] = ACTIONS(4181),
    [anon_sym_DOT] = ACTIONS(4179),
    [anon_sym_EQ_GT] = ACTIONS(4181),
    [anon_sym_switch] = ACTIONS(4181),
    [anon_sym_DOT_DOT] = ACTIONS(4181),
    [anon_sym_and] = ACTIONS(4181),
    [anon_sym_or] = ACTIONS(4179),
    [anon_sym_AMP_AMP] = ACTIONS(4181),
    [anon_sym_PIPE_PIPE] = ACTIONS(4181),
    [anon_sym_QMARK_QMARK] = ACTIONS(4181),
    [anon_sym_from] = ACTIONS(4181),
    [anon_sym_into] = ACTIONS(4181),
    [anon_sym_join] = ACTIONS(4181),
    [anon_sym_on] = ACTIONS(4181),
    [anon_sym_equals] = ACTIONS(4181),
    [anon_sym_let] = ACTIONS(4181),
    [anon_sym_orderby] = ACTIONS(4181),
    [anon_sym_group] = ACTIONS(4181),
    [anon_sym_by] = ACTIONS(4181),
    [anon_sym_select] = ACTIONS(4181),
    [anon_sym_as] = ACTIONS(4181),
    [anon_sym_is] = ACTIONS(4181),
    [anon_sym_DASH_GT] = ACTIONS(4181),
    [anon_sym_with] = ACTIONS(4181),
    [aux_sym_preproc_if_token3] = ACTIONS(4181),
    [aux_sym_preproc_else_token1] = ACTIONS(4181),
    [aux_sym_preproc_elif_token1] = ACTIONS(4181),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3600] = {
    [sym_preproc_region] = STATE(3600),
    [sym_preproc_endregion] = STATE(3600),
    [sym_preproc_line] = STATE(3600),
    [sym_preproc_pragma] = STATE(3600),
    [sym_preproc_nullable] = STATE(3600),
    [sym_preproc_error] = STATE(3600),
    [sym_preproc_warning] = STATE(3600),
    [sym_preproc_define] = STATE(3600),
    [sym_preproc_undef] = STATE(3600),
    [anon_sym_SEMI] = ACTIONS(5363),
    [anon_sym_LBRACK] = ACTIONS(5363),
    [anon_sym_COLON] = ACTIONS(5363),
    [anon_sym_COMMA] = ACTIONS(5363),
    [anon_sym_RBRACK] = ACTIONS(5363),
    [anon_sym_LPAREN] = ACTIONS(5363),
    [anon_sym_RPAREN] = ACTIONS(5363),
    [anon_sym_RBRACE] = ACTIONS(5363),
    [anon_sym_LT] = ACTIONS(5365),
    [anon_sym_GT] = ACTIONS(5365),
    [anon_sym_in] = ACTIONS(5365),
    [anon_sym_where] = ACTIONS(5363),
    [anon_sym_QMARK] = ACTIONS(5365),
    [anon_sym_BANG] = ACTIONS(5365),
    [anon_sym_PLUS_PLUS] = ACTIONS(5363),
    [anon_sym_DASH_DASH] = ACTIONS(5363),
    [anon_sym_PLUS] = ACTIONS(5365),
    [anon_sym_DASH] = ACTIONS(5365),
    [anon_sym_STAR] = ACTIONS(5363),
    [anon_sym_SLASH] = ACTIONS(5365),
    [anon_sym_PERCENT] = ACTIONS(5363),
    [anon_sym_CARET] = ACTIONS(5363),
    [anon_sym_PIPE] = ACTIONS(5365),
    [anon_sym_AMP] = ACTIONS(5365),
    [anon_sym_LT_LT] = ACTIONS(5363),
    [anon_sym_GT_GT] = ACTIONS(5365),
    [anon_sym_GT_GT_GT] = ACTIONS(5363),
    [anon_sym_EQ_EQ] = ACTIONS(5363),
    [anon_sym_BANG_EQ] = ACTIONS(5363),
    [anon_sym_GT_EQ] = ACTIONS(5363),
    [anon_sym_LT_EQ] = ACTIONS(5363),
    [anon_sym_DOT] = ACTIONS(5365),
    [anon_sym_EQ_GT] = ACTIONS(5363),
    [anon_sym_switch] = ACTIONS(5363),
    [anon_sym_DOT_DOT] = ACTIONS(5363),
    [anon_sym_and] = ACTIONS(5363),
    [anon_sym_or] = ACTIONS(5365),
    [anon_sym_AMP_AMP] = ACTIONS(5363),
    [anon_sym_PIPE_PIPE] = ACTIONS(5363),
    [anon_sym_QMARK_QMARK] = ACTIONS(5363),
    [anon_sym_from] = ACTIONS(5363),
    [anon_sym_into] = ACTIONS(5363),
    [anon_sym_join] = ACTIONS(5363),
    [anon_sym_on] = ACTIONS(5363),
    [anon_sym_equals] = ACTIONS(5363),
    [anon_sym_let] = ACTIONS(5363),
    [anon_sym_orderby] = ACTIONS(5363),
    [anon_sym_group] = ACTIONS(5363),
    [anon_sym_by] = ACTIONS(5363),
    [anon_sym_select] = ACTIONS(5363),
    [anon_sym_as] = ACTIONS(5363),
    [anon_sym_is] = ACTIONS(5363),
    [anon_sym_DASH_GT] = ACTIONS(5363),
    [anon_sym_with] = ACTIONS(5363),
    [sym_string_literal_encoding] = ACTIONS(5367),
    [aux_sym_preproc_if_token3] = ACTIONS(5363),
    [aux_sym_preproc_else_token1] = ACTIONS(5363),
    [aux_sym_preproc_elif_token1] = ACTIONS(5363),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3601] = {
    [sym_preproc_region] = STATE(3601),
    [sym_preproc_endregion] = STATE(3601),
    [sym_preproc_line] = STATE(3601),
    [sym_preproc_pragma] = STATE(3601),
    [sym_preproc_nullable] = STATE(3601),
    [sym_preproc_error] = STATE(3601),
    [sym_preproc_warning] = STATE(3601),
    [sym_preproc_define] = STATE(3601),
    [sym_preproc_undef] = STATE(3601),
    [anon_sym_SEMI] = ACTIONS(4455),
    [anon_sym_LBRACK] = ACTIONS(4455),
    [anon_sym_COLON] = ACTIONS(4455),
    [anon_sym_COMMA] = ACTIONS(4455),
    [anon_sym_RBRACK] = ACTIONS(4455),
    [anon_sym_LPAREN] = ACTIONS(4455),
    [anon_sym_RPAREN] = ACTIONS(4455),
    [anon_sym_LBRACE] = ACTIONS(4455),
    [anon_sym_RBRACE] = ACTIONS(4455),
    [anon_sym_LT] = ACTIONS(4453),
    [anon_sym_GT] = ACTIONS(4453),
    [anon_sym_in] = ACTIONS(4453),
    [anon_sym_where] = ACTIONS(4455),
    [anon_sym_QMARK] = ACTIONS(4453),
    [anon_sym_BANG] = ACTIONS(4453),
    [anon_sym_PLUS_PLUS] = ACTIONS(4455),
    [anon_sym_DASH_DASH] = ACTIONS(4455),
    [anon_sym_PLUS] = ACTIONS(4453),
    [anon_sym_DASH] = ACTIONS(4453),
    [anon_sym_STAR] = ACTIONS(4455),
    [anon_sym_SLASH] = ACTIONS(4453),
    [anon_sym_PERCENT] = ACTIONS(4455),
    [anon_sym_CARET] = ACTIONS(4455),
    [anon_sym_PIPE] = ACTIONS(4453),
    [anon_sym_AMP] = ACTIONS(4453),
    [anon_sym_LT_LT] = ACTIONS(4455),
    [anon_sym_GT_GT] = ACTIONS(4453),
    [anon_sym_GT_GT_GT] = ACTIONS(4455),
    [anon_sym_EQ_EQ] = ACTIONS(4455),
    [anon_sym_BANG_EQ] = ACTIONS(4455),
    [anon_sym_GT_EQ] = ACTIONS(4455),
    [anon_sym_LT_EQ] = ACTIONS(4455),
    [anon_sym_DOT] = ACTIONS(4453),
    [anon_sym_EQ_GT] = ACTIONS(4455),
    [anon_sym_switch] = ACTIONS(4455),
    [anon_sym_DOT_DOT] = ACTIONS(4455),
    [anon_sym_and] = ACTIONS(4455),
    [anon_sym_or] = ACTIONS(4453),
    [anon_sym_AMP_AMP] = ACTIONS(4455),
    [anon_sym_PIPE_PIPE] = ACTIONS(4455),
    [anon_sym_QMARK_QMARK] = ACTIONS(4455),
    [anon_sym_from] = ACTIONS(4455),
    [anon_sym_into] = ACTIONS(4455),
    [anon_sym_join] = ACTIONS(4455),
    [anon_sym_on] = ACTIONS(4455),
    [anon_sym_equals] = ACTIONS(4455),
    [anon_sym_let] = ACTIONS(4455),
    [anon_sym_orderby] = ACTIONS(4455),
    [anon_sym_group] = ACTIONS(4455),
    [anon_sym_by] = ACTIONS(4455),
    [anon_sym_select] = ACTIONS(4455),
    [anon_sym_as] = ACTIONS(4455),
    [anon_sym_is] = ACTIONS(4455),
    [anon_sym_DASH_GT] = ACTIONS(4455),
    [anon_sym_with] = ACTIONS(4455),
    [aux_sym_preproc_if_token3] = ACTIONS(4455),
    [aux_sym_preproc_else_token1] = ACTIONS(4455),
    [aux_sym_preproc_elif_token1] = ACTIONS(4455),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3602] = {
    [sym_preproc_region] = STATE(3602),
    [sym_preproc_endregion] = STATE(3602),
    [sym_preproc_line] = STATE(3602),
    [sym_preproc_pragma] = STATE(3602),
    [sym_preproc_nullable] = STATE(3602),
    [sym_preproc_error] = STATE(3602),
    [sym_preproc_warning] = STATE(3602),
    [sym_preproc_define] = STATE(3602),
    [sym_preproc_undef] = STATE(3602),
    [anon_sym_SEMI] = ACTIONS(4585),
    [anon_sym_LBRACK] = ACTIONS(4585),
    [anon_sym_COLON] = ACTIONS(4585),
    [anon_sym_COMMA] = ACTIONS(4585),
    [anon_sym_RBRACK] = ACTIONS(4585),
    [anon_sym_LPAREN] = ACTIONS(4585),
    [anon_sym_RPAREN] = ACTIONS(4585),
    [anon_sym_LBRACE] = ACTIONS(4585),
    [anon_sym_RBRACE] = ACTIONS(4585),
    [anon_sym_LT] = ACTIONS(4583),
    [anon_sym_GT] = ACTIONS(4583),
    [anon_sym_in] = ACTIONS(4583),
    [anon_sym_where] = ACTIONS(4585),
    [anon_sym_QMARK] = ACTIONS(4583),
    [anon_sym_BANG] = ACTIONS(4583),
    [anon_sym_PLUS_PLUS] = ACTIONS(4585),
    [anon_sym_DASH_DASH] = ACTIONS(4585),
    [anon_sym_PLUS] = ACTIONS(4583),
    [anon_sym_DASH] = ACTIONS(4583),
    [anon_sym_STAR] = ACTIONS(4585),
    [anon_sym_SLASH] = ACTIONS(4583),
    [anon_sym_PERCENT] = ACTIONS(4585),
    [anon_sym_CARET] = ACTIONS(4585),
    [anon_sym_PIPE] = ACTIONS(4583),
    [anon_sym_AMP] = ACTIONS(4583),
    [anon_sym_LT_LT] = ACTIONS(4585),
    [anon_sym_GT_GT] = ACTIONS(4583),
    [anon_sym_GT_GT_GT] = ACTIONS(4585),
    [anon_sym_EQ_EQ] = ACTIONS(4585),
    [anon_sym_BANG_EQ] = ACTIONS(4585),
    [anon_sym_GT_EQ] = ACTIONS(4585),
    [anon_sym_LT_EQ] = ACTIONS(4585),
    [anon_sym_DOT] = ACTIONS(4583),
    [anon_sym_EQ_GT] = ACTIONS(4585),
    [anon_sym_switch] = ACTIONS(4585),
    [anon_sym_DOT_DOT] = ACTIONS(4585),
    [anon_sym_and] = ACTIONS(4585),
    [anon_sym_or] = ACTIONS(4583),
    [anon_sym_AMP_AMP] = ACTIONS(4585),
    [anon_sym_PIPE_PIPE] = ACTIONS(4585),
    [anon_sym_QMARK_QMARK] = ACTIONS(4585),
    [anon_sym_from] = ACTIONS(4585),
    [anon_sym_into] = ACTIONS(4585),
    [anon_sym_join] = ACTIONS(4585),
    [anon_sym_on] = ACTIONS(4585),
    [anon_sym_equals] = ACTIONS(4585),
    [anon_sym_let] = ACTIONS(4585),
    [anon_sym_orderby] = ACTIONS(4585),
    [anon_sym_group] = ACTIONS(4585),
    [anon_sym_by] = ACTIONS(4585),
    [anon_sym_select] = ACTIONS(4585),
    [anon_sym_as] = ACTIONS(4585),
    [anon_sym_is] = ACTIONS(4585),
    [anon_sym_DASH_GT] = ACTIONS(4585),
    [anon_sym_with] = ACTIONS(4585),
    [aux_sym_preproc_if_token3] = ACTIONS(4585),
    [aux_sym_preproc_else_token1] = ACTIONS(4585),
    [aux_sym_preproc_elif_token1] = ACTIONS(4585),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3603] = {
    [sym_preproc_region] = STATE(3603),
    [sym_preproc_endregion] = STATE(3603),
    [sym_preproc_line] = STATE(3603),
    [sym_preproc_pragma] = STATE(3603),
    [sym_preproc_nullable] = STATE(3603),
    [sym_preproc_error] = STATE(3603),
    [sym_preproc_warning] = STATE(3603),
    [sym_preproc_define] = STATE(3603),
    [sym_preproc_undef] = STATE(3603),
    [anon_sym_SEMI] = ACTIONS(4630),
    [anon_sym_LBRACK] = ACTIONS(4630),
    [anon_sym_COLON] = ACTIONS(4630),
    [anon_sym_COMMA] = ACTIONS(4630),
    [anon_sym_RBRACK] = ACTIONS(4630),
    [anon_sym_LPAREN] = ACTIONS(4630),
    [anon_sym_RPAREN] = ACTIONS(4630),
    [anon_sym_LBRACE] = ACTIONS(4630),
    [anon_sym_RBRACE] = ACTIONS(4630),
    [anon_sym_LT] = ACTIONS(4628),
    [anon_sym_GT] = ACTIONS(4628),
    [anon_sym_in] = ACTIONS(4628),
    [anon_sym_where] = ACTIONS(4630),
    [anon_sym_QMARK] = ACTIONS(4628),
    [anon_sym_BANG] = ACTIONS(4628),
    [anon_sym_PLUS_PLUS] = ACTIONS(4630),
    [anon_sym_DASH_DASH] = ACTIONS(4630),
    [anon_sym_PLUS] = ACTIONS(4628),
    [anon_sym_DASH] = ACTIONS(4628),
    [anon_sym_STAR] = ACTIONS(4630),
    [anon_sym_SLASH] = ACTIONS(4628),
    [anon_sym_PERCENT] = ACTIONS(4630),
    [anon_sym_CARET] = ACTIONS(4630),
    [anon_sym_PIPE] = ACTIONS(4628),
    [anon_sym_AMP] = ACTIONS(4628),
    [anon_sym_LT_LT] = ACTIONS(4630),
    [anon_sym_GT_GT] = ACTIONS(4628),
    [anon_sym_GT_GT_GT] = ACTIONS(4630),
    [anon_sym_EQ_EQ] = ACTIONS(4630),
    [anon_sym_BANG_EQ] = ACTIONS(4630),
    [anon_sym_GT_EQ] = ACTIONS(4630),
    [anon_sym_LT_EQ] = ACTIONS(4630),
    [anon_sym_DOT] = ACTIONS(4628),
    [anon_sym_EQ_GT] = ACTIONS(4630),
    [anon_sym_switch] = ACTIONS(4630),
    [anon_sym_DOT_DOT] = ACTIONS(4630),
    [anon_sym_and] = ACTIONS(4630),
    [anon_sym_or] = ACTIONS(4628),
    [anon_sym_AMP_AMP] = ACTIONS(4630),
    [anon_sym_PIPE_PIPE] = ACTIONS(4630),
    [anon_sym_QMARK_QMARK] = ACTIONS(4630),
    [anon_sym_from] = ACTIONS(4630),
    [anon_sym_into] = ACTIONS(4630),
    [anon_sym_join] = ACTIONS(4630),
    [anon_sym_on] = ACTIONS(4630),
    [anon_sym_equals] = ACTIONS(4630),
    [anon_sym_let] = ACTIONS(4630),
    [anon_sym_orderby] = ACTIONS(4630),
    [anon_sym_group] = ACTIONS(4630),
    [anon_sym_by] = ACTIONS(4630),
    [anon_sym_select] = ACTIONS(4630),
    [anon_sym_as] = ACTIONS(4630),
    [anon_sym_is] = ACTIONS(4630),
    [anon_sym_DASH_GT] = ACTIONS(4630),
    [anon_sym_with] = ACTIONS(4630),
    [aux_sym_preproc_if_token3] = ACTIONS(4630),
    [aux_sym_preproc_else_token1] = ACTIONS(4630),
    [aux_sym_preproc_elif_token1] = ACTIONS(4630),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3604] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7297),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8977),
    [sym_identifier] = STATE(6768),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3604),
    [sym_preproc_endregion] = STATE(3604),
    [sym_preproc_line] = STATE(3604),
    [sym_preproc_pragma] = STATE(3604),
    [sym_preproc_nullable] = STATE(3604),
    [sym_preproc_error] = STATE(3604),
    [sym_preproc_warning] = STATE(3604),
    [sym_preproc_define] = STATE(3604),
    [sym_preproc_undef] = STATE(3604),
    [aux_sym_class_declaration_repeat1] = STATE(3802),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LBRACK] = ACTIONS(5307),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_RPAREN] = ACTIONS(2603),
    [anon_sym_ref] = ACTIONS(5309),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_in] = ACTIONS(1113),
    [anon_sym_out] = ACTIONS(1113),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_this] = ACTIONS(1113),
    [anon_sym_scoped] = ACTIONS(5321),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_var] = ACTIONS(5369),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3605] = {
    [sym_preproc_region] = STATE(3605),
    [sym_preproc_endregion] = STATE(3605),
    [sym_preproc_line] = STATE(3605),
    [sym_preproc_pragma] = STATE(3605),
    [sym_preproc_nullable] = STATE(3605),
    [sym_preproc_error] = STATE(3605),
    [sym_preproc_warning] = STATE(3605),
    [sym_preproc_define] = STATE(3605),
    [sym_preproc_undef] = STATE(3605),
    [anon_sym_EQ] = ACTIONS(5371),
    [anon_sym_LBRACK] = ACTIONS(5286),
    [anon_sym_COMMA] = ACTIONS(5286),
    [anon_sym_LPAREN] = ACTIONS(5286),
    [anon_sym_LT] = ACTIONS(5288),
    [anon_sym_GT] = ACTIONS(5288),
    [anon_sym_where] = ACTIONS(5286),
    [anon_sym_QMARK] = ACTIONS(5288),
    [anon_sym_BANG] = ACTIONS(5288),
    [anon_sym_PLUS_PLUS] = ACTIONS(5286),
    [anon_sym_DASH_DASH] = ACTIONS(5286),
    [anon_sym_PLUS] = ACTIONS(5288),
    [anon_sym_DASH] = ACTIONS(5288),
    [anon_sym_STAR] = ACTIONS(5288),
    [anon_sym_SLASH] = ACTIONS(5288),
    [anon_sym_PERCENT] = ACTIONS(5288),
    [anon_sym_CARET] = ACTIONS(5288),
    [anon_sym_PIPE] = ACTIONS(5288),
    [anon_sym_AMP] = ACTIONS(5288),
    [anon_sym_LT_LT] = ACTIONS(5288),
    [anon_sym_GT_GT] = ACTIONS(5288),
    [anon_sym_GT_GT_GT] = ACTIONS(5288),
    [anon_sym_EQ_EQ] = ACTIONS(5286),
    [anon_sym_BANG_EQ] = ACTIONS(5286),
    [anon_sym_GT_EQ] = ACTIONS(5286),
    [anon_sym_LT_EQ] = ACTIONS(5286),
    [anon_sym_DOT] = ACTIONS(5288),
    [anon_sym_switch] = ACTIONS(5286),
    [anon_sym_DOT_DOT] = ACTIONS(5286),
    [anon_sym_and] = ACTIONS(5286),
    [anon_sym_or] = ACTIONS(5288),
    [anon_sym_PLUS_EQ] = ACTIONS(5373),
    [anon_sym_DASH_EQ] = ACTIONS(5373),
    [anon_sym_STAR_EQ] = ACTIONS(5373),
    [anon_sym_SLASH_EQ] = ACTIONS(5373),
    [anon_sym_PERCENT_EQ] = ACTIONS(5373),
    [anon_sym_AMP_EQ] = ACTIONS(5373),
    [anon_sym_CARET_EQ] = ACTIONS(5373),
    [anon_sym_PIPE_EQ] = ACTIONS(5373),
    [anon_sym_LT_LT_EQ] = ACTIONS(5373),
    [anon_sym_GT_GT_EQ] = ACTIONS(5373),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(5373),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(5373),
    [anon_sym_AMP_AMP] = ACTIONS(5286),
    [anon_sym_PIPE_PIPE] = ACTIONS(5286),
    [anon_sym_QMARK_QMARK] = ACTIONS(5288),
    [anon_sym_from] = ACTIONS(5286),
    [anon_sym_join] = ACTIONS(5286),
    [anon_sym_let] = ACTIONS(5286),
    [anon_sym_orderby] = ACTIONS(5286),
    [anon_sym_ascending] = ACTIONS(5286),
    [anon_sym_descending] = ACTIONS(5286),
    [anon_sym_group] = ACTIONS(5286),
    [anon_sym_select] = ACTIONS(5286),
    [anon_sym_as] = ACTIONS(5288),
    [anon_sym_is] = ACTIONS(5286),
    [anon_sym_DASH_GT] = ACTIONS(5286),
    [anon_sym_with] = ACTIONS(5286),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3606] = {
    [sym_preproc_region] = STATE(3606),
    [sym_preproc_endregion] = STATE(3606),
    [sym_preproc_line] = STATE(3606),
    [sym_preproc_pragma] = STATE(3606),
    [sym_preproc_nullable] = STATE(3606),
    [sym_preproc_error] = STATE(3606),
    [sym_preproc_warning] = STATE(3606),
    [sym_preproc_define] = STATE(3606),
    [sym_preproc_undef] = STATE(3606),
    [anon_sym_SEMI] = ACTIONS(4468),
    [anon_sym_LBRACK] = ACTIONS(4468),
    [anon_sym_COLON] = ACTIONS(4468),
    [anon_sym_COMMA] = ACTIONS(4468),
    [anon_sym_RBRACK] = ACTIONS(4468),
    [anon_sym_LPAREN] = ACTIONS(4468),
    [anon_sym_RPAREN] = ACTIONS(4468),
    [anon_sym_LBRACE] = ACTIONS(4468),
    [anon_sym_RBRACE] = ACTIONS(4468),
    [anon_sym_LT] = ACTIONS(4466),
    [anon_sym_GT] = ACTIONS(4466),
    [anon_sym_in] = ACTIONS(4466),
    [anon_sym_where] = ACTIONS(4468),
    [anon_sym_QMARK] = ACTIONS(4466),
    [anon_sym_BANG] = ACTIONS(4466),
    [anon_sym_PLUS_PLUS] = ACTIONS(4468),
    [anon_sym_DASH_DASH] = ACTIONS(4468),
    [anon_sym_PLUS] = ACTIONS(4466),
    [anon_sym_DASH] = ACTIONS(4466),
    [anon_sym_STAR] = ACTIONS(4468),
    [anon_sym_SLASH] = ACTIONS(4466),
    [anon_sym_PERCENT] = ACTIONS(4468),
    [anon_sym_CARET] = ACTIONS(4468),
    [anon_sym_PIPE] = ACTIONS(4466),
    [anon_sym_AMP] = ACTIONS(4466),
    [anon_sym_LT_LT] = ACTIONS(4468),
    [anon_sym_GT_GT] = ACTIONS(4466),
    [anon_sym_GT_GT_GT] = ACTIONS(4468),
    [anon_sym_EQ_EQ] = ACTIONS(4468),
    [anon_sym_BANG_EQ] = ACTIONS(4468),
    [anon_sym_GT_EQ] = ACTIONS(4468),
    [anon_sym_LT_EQ] = ACTIONS(4468),
    [anon_sym_DOT] = ACTIONS(4466),
    [anon_sym_EQ_GT] = ACTIONS(4468),
    [anon_sym_switch] = ACTIONS(4468),
    [anon_sym_DOT_DOT] = ACTIONS(4468),
    [anon_sym_and] = ACTIONS(4468),
    [anon_sym_or] = ACTIONS(4466),
    [anon_sym_AMP_AMP] = ACTIONS(4468),
    [anon_sym_PIPE_PIPE] = ACTIONS(4468),
    [anon_sym_QMARK_QMARK] = ACTIONS(4468),
    [anon_sym_from] = ACTIONS(4468),
    [anon_sym_into] = ACTIONS(4468),
    [anon_sym_join] = ACTIONS(4468),
    [anon_sym_on] = ACTIONS(4468),
    [anon_sym_equals] = ACTIONS(4468),
    [anon_sym_let] = ACTIONS(4468),
    [anon_sym_orderby] = ACTIONS(4468),
    [anon_sym_group] = ACTIONS(4468),
    [anon_sym_by] = ACTIONS(4468),
    [anon_sym_select] = ACTIONS(4468),
    [anon_sym_as] = ACTIONS(4468),
    [anon_sym_is] = ACTIONS(4468),
    [anon_sym_DASH_GT] = ACTIONS(4468),
    [anon_sym_with] = ACTIONS(4468),
    [aux_sym_preproc_if_token3] = ACTIONS(4468),
    [aux_sym_preproc_else_token1] = ACTIONS(4468),
    [aux_sym_preproc_elif_token1] = ACTIONS(4468),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3607] = {
    [sym_preproc_region] = STATE(3607),
    [sym_preproc_endregion] = STATE(3607),
    [sym_preproc_line] = STATE(3607),
    [sym_preproc_pragma] = STATE(3607),
    [sym_preproc_nullable] = STATE(3607),
    [sym_preproc_error] = STATE(3607),
    [sym_preproc_warning] = STATE(3607),
    [sym_preproc_define] = STATE(3607),
    [sym_preproc_undef] = STATE(3607),
    [anon_sym_SEMI] = ACTIONS(4132),
    [anon_sym_LBRACK] = ACTIONS(4132),
    [anon_sym_COLON] = ACTIONS(4132),
    [anon_sym_COMMA] = ACTIONS(4132),
    [anon_sym_RBRACK] = ACTIONS(4132),
    [anon_sym_LPAREN] = ACTIONS(4132),
    [anon_sym_RPAREN] = ACTIONS(4132),
    [anon_sym_LBRACE] = ACTIONS(4132),
    [anon_sym_RBRACE] = ACTIONS(4132),
    [anon_sym_LT] = ACTIONS(4130),
    [anon_sym_GT] = ACTIONS(4130),
    [anon_sym_in] = ACTIONS(4130),
    [anon_sym_where] = ACTIONS(4132),
    [anon_sym_QMARK] = ACTIONS(4130),
    [anon_sym_BANG] = ACTIONS(4130),
    [anon_sym_PLUS_PLUS] = ACTIONS(4132),
    [anon_sym_DASH_DASH] = ACTIONS(4132),
    [anon_sym_PLUS] = ACTIONS(4130),
    [anon_sym_DASH] = ACTIONS(4130),
    [anon_sym_STAR] = ACTIONS(4132),
    [anon_sym_SLASH] = ACTIONS(4130),
    [anon_sym_PERCENT] = ACTIONS(4132),
    [anon_sym_CARET] = ACTIONS(4132),
    [anon_sym_PIPE] = ACTIONS(4130),
    [anon_sym_AMP] = ACTIONS(4130),
    [anon_sym_LT_LT] = ACTIONS(4132),
    [anon_sym_GT_GT] = ACTIONS(4130),
    [anon_sym_GT_GT_GT] = ACTIONS(4132),
    [anon_sym_EQ_EQ] = ACTIONS(4132),
    [anon_sym_BANG_EQ] = ACTIONS(4132),
    [anon_sym_GT_EQ] = ACTIONS(4132),
    [anon_sym_LT_EQ] = ACTIONS(4132),
    [anon_sym_DOT] = ACTIONS(4130),
    [anon_sym_EQ_GT] = ACTIONS(4132),
    [anon_sym_switch] = ACTIONS(4132),
    [anon_sym_DOT_DOT] = ACTIONS(4132),
    [anon_sym_and] = ACTIONS(4132),
    [anon_sym_or] = ACTIONS(4130),
    [anon_sym_AMP_AMP] = ACTIONS(4132),
    [anon_sym_PIPE_PIPE] = ACTIONS(4132),
    [anon_sym_QMARK_QMARK] = ACTIONS(4132),
    [anon_sym_from] = ACTIONS(4132),
    [anon_sym_into] = ACTIONS(4132),
    [anon_sym_join] = ACTIONS(4132),
    [anon_sym_on] = ACTIONS(4132),
    [anon_sym_equals] = ACTIONS(4132),
    [anon_sym_let] = ACTIONS(4132),
    [anon_sym_orderby] = ACTIONS(4132),
    [anon_sym_group] = ACTIONS(4132),
    [anon_sym_by] = ACTIONS(4132),
    [anon_sym_select] = ACTIONS(4132),
    [anon_sym_as] = ACTIONS(4132),
    [anon_sym_is] = ACTIONS(4132),
    [anon_sym_DASH_GT] = ACTIONS(4132),
    [anon_sym_with] = ACTIONS(4132),
    [aux_sym_preproc_if_token3] = ACTIONS(4132),
    [aux_sym_preproc_else_token1] = ACTIONS(4132),
    [aux_sym_preproc_elif_token1] = ACTIONS(4132),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3608] = {
    [sym_preproc_region] = STATE(3608),
    [sym_preproc_endregion] = STATE(3608),
    [sym_preproc_line] = STATE(3608),
    [sym_preproc_pragma] = STATE(3608),
    [sym_preproc_nullable] = STATE(3608),
    [sym_preproc_error] = STATE(3608),
    [sym_preproc_warning] = STATE(3608),
    [sym_preproc_define] = STATE(3608),
    [sym_preproc_undef] = STATE(3608),
    [anon_sym_SEMI] = ACTIONS(4494),
    [anon_sym_LBRACK] = ACTIONS(4593),
    [anon_sym_COLON] = ACTIONS(4494),
    [anon_sym_COMMA] = ACTIONS(4494),
    [anon_sym_RBRACK] = ACTIONS(4494),
    [anon_sym_LPAREN] = ACTIONS(4494),
    [anon_sym_RPAREN] = ACTIONS(4494),
    [anon_sym_LBRACE] = ACTIONS(4494),
    [anon_sym_RBRACE] = ACTIONS(4494),
    [anon_sym_LT] = ACTIONS(4492),
    [anon_sym_GT] = ACTIONS(4492),
    [anon_sym_in] = ACTIONS(4492),
    [anon_sym_where] = ACTIONS(4494),
    [anon_sym_QMARK] = ACTIONS(5375),
    [anon_sym_BANG] = ACTIONS(4492),
    [anon_sym_PLUS_PLUS] = ACTIONS(4494),
    [anon_sym_DASH_DASH] = ACTIONS(4494),
    [anon_sym_PLUS] = ACTIONS(4492),
    [anon_sym_DASH] = ACTIONS(4492),
    [anon_sym_STAR] = ACTIONS(4494),
    [anon_sym_SLASH] = ACTIONS(4492),
    [anon_sym_PERCENT] = ACTIONS(4494),
    [anon_sym_CARET] = ACTIONS(4494),
    [anon_sym_PIPE] = ACTIONS(4492),
    [anon_sym_AMP] = ACTIONS(4492),
    [anon_sym_LT_LT] = ACTIONS(4494),
    [anon_sym_GT_GT] = ACTIONS(4492),
    [anon_sym_GT_GT_GT] = ACTIONS(4494),
    [anon_sym_EQ_EQ] = ACTIONS(4494),
    [anon_sym_BANG_EQ] = ACTIONS(4494),
    [anon_sym_GT_EQ] = ACTIONS(4494),
    [anon_sym_LT_EQ] = ACTIONS(4494),
    [anon_sym_DOT] = ACTIONS(4492),
    [anon_sym_EQ_GT] = ACTIONS(4494),
    [anon_sym_switch] = ACTIONS(4494),
    [anon_sym_DOT_DOT] = ACTIONS(4494),
    [anon_sym_and] = ACTIONS(4494),
    [anon_sym_or] = ACTIONS(4492),
    [anon_sym_AMP_AMP] = ACTIONS(4494),
    [anon_sym_PIPE_PIPE] = ACTIONS(4494),
    [anon_sym_QMARK_QMARK] = ACTIONS(4494),
    [anon_sym_from] = ACTIONS(4494),
    [anon_sym_into] = ACTIONS(4494),
    [anon_sym_join] = ACTIONS(4494),
    [anon_sym_on] = ACTIONS(4494),
    [anon_sym_equals] = ACTIONS(4494),
    [anon_sym_let] = ACTIONS(4494),
    [anon_sym_orderby] = ACTIONS(4494),
    [anon_sym_group] = ACTIONS(4494),
    [anon_sym_by] = ACTIONS(4494),
    [anon_sym_select] = ACTIONS(4494),
    [anon_sym_as] = ACTIONS(4494),
    [anon_sym_is] = ACTIONS(4494),
    [anon_sym_DASH_GT] = ACTIONS(4494),
    [anon_sym_with] = ACTIONS(4494),
    [aux_sym_preproc_if_token3] = ACTIONS(4494),
    [aux_sym_preproc_else_token1] = ACTIONS(4494),
    [aux_sym_preproc_elif_token1] = ACTIONS(4494),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3609] = {
    [sym_preproc_region] = STATE(3609),
    [sym_preproc_endregion] = STATE(3609),
    [sym_preproc_line] = STATE(3609),
    [sym_preproc_pragma] = STATE(3609),
    [sym_preproc_nullable] = STATE(3609),
    [sym_preproc_error] = STATE(3609),
    [sym_preproc_warning] = STATE(3609),
    [sym_preproc_define] = STATE(3609),
    [sym_preproc_undef] = STATE(3609),
    [anon_sym_SEMI] = ACTIONS(4151),
    [anon_sym_LBRACK] = ACTIONS(4151),
    [anon_sym_COLON] = ACTIONS(4151),
    [anon_sym_COMMA] = ACTIONS(4151),
    [anon_sym_RBRACK] = ACTIONS(4151),
    [anon_sym_LPAREN] = ACTIONS(4151),
    [anon_sym_RPAREN] = ACTIONS(4151),
    [anon_sym_LBRACE] = ACTIONS(4151),
    [anon_sym_RBRACE] = ACTIONS(4151),
    [anon_sym_LT] = ACTIONS(4149),
    [anon_sym_GT] = ACTIONS(4149),
    [anon_sym_in] = ACTIONS(4149),
    [anon_sym_where] = ACTIONS(4151),
    [anon_sym_QMARK] = ACTIONS(4149),
    [anon_sym_BANG] = ACTIONS(4149),
    [anon_sym_PLUS_PLUS] = ACTIONS(4151),
    [anon_sym_DASH_DASH] = ACTIONS(4151),
    [anon_sym_PLUS] = ACTIONS(4149),
    [anon_sym_DASH] = ACTIONS(4149),
    [anon_sym_STAR] = ACTIONS(4151),
    [anon_sym_SLASH] = ACTIONS(4149),
    [anon_sym_PERCENT] = ACTIONS(4151),
    [anon_sym_CARET] = ACTIONS(4151),
    [anon_sym_PIPE] = ACTIONS(4149),
    [anon_sym_AMP] = ACTIONS(4149),
    [anon_sym_LT_LT] = ACTIONS(4151),
    [anon_sym_GT_GT] = ACTIONS(4149),
    [anon_sym_GT_GT_GT] = ACTIONS(4151),
    [anon_sym_EQ_EQ] = ACTIONS(4151),
    [anon_sym_BANG_EQ] = ACTIONS(4151),
    [anon_sym_GT_EQ] = ACTIONS(4151),
    [anon_sym_LT_EQ] = ACTIONS(4151),
    [anon_sym_DOT] = ACTIONS(4149),
    [anon_sym_EQ_GT] = ACTIONS(4151),
    [anon_sym_switch] = ACTIONS(4151),
    [anon_sym_DOT_DOT] = ACTIONS(4151),
    [anon_sym_and] = ACTIONS(4151),
    [anon_sym_or] = ACTIONS(4149),
    [anon_sym_AMP_AMP] = ACTIONS(4151),
    [anon_sym_PIPE_PIPE] = ACTIONS(4151),
    [anon_sym_QMARK_QMARK] = ACTIONS(4151),
    [anon_sym_from] = ACTIONS(4151),
    [anon_sym_into] = ACTIONS(4151),
    [anon_sym_join] = ACTIONS(4151),
    [anon_sym_on] = ACTIONS(4151),
    [anon_sym_equals] = ACTIONS(4151),
    [anon_sym_let] = ACTIONS(4151),
    [anon_sym_orderby] = ACTIONS(4151),
    [anon_sym_group] = ACTIONS(4151),
    [anon_sym_by] = ACTIONS(4151),
    [anon_sym_select] = ACTIONS(4151),
    [anon_sym_as] = ACTIONS(4151),
    [anon_sym_is] = ACTIONS(4151),
    [anon_sym_DASH_GT] = ACTIONS(4151),
    [anon_sym_with] = ACTIONS(4151),
    [aux_sym_preproc_if_token3] = ACTIONS(4151),
    [aux_sym_preproc_else_token1] = ACTIONS(4151),
    [aux_sym_preproc_elif_token1] = ACTIONS(4151),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3610] = {
    [sym_preproc_region] = STATE(3610),
    [sym_preproc_endregion] = STATE(3610),
    [sym_preproc_line] = STATE(3610),
    [sym_preproc_pragma] = STATE(3610),
    [sym_preproc_nullable] = STATE(3610),
    [sym_preproc_error] = STATE(3610),
    [sym_preproc_warning] = STATE(3610),
    [sym_preproc_define] = STATE(3610),
    [sym_preproc_undef] = STATE(3610),
    [anon_sym_SEMI] = ACTIONS(3993),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_COLON] = ACTIONS(3995),
    [anon_sym_COMMA] = ACTIONS(3993),
    [anon_sym_RBRACK] = ACTIONS(3993),
    [anon_sym_LPAREN] = ACTIONS(3993),
    [anon_sym_RPAREN] = ACTIONS(3993),
    [anon_sym_LBRACE] = ACTIONS(3993),
    [anon_sym_RBRACE] = ACTIONS(3993),
    [anon_sym_LT] = ACTIONS(3995),
    [anon_sym_GT] = ACTIONS(3995),
    [anon_sym_in] = ACTIONS(3993),
    [anon_sym_where] = ACTIONS(3993),
    [anon_sym_QMARK] = ACTIONS(3995),
    [anon_sym_BANG] = ACTIONS(3995),
    [anon_sym_PLUS_PLUS] = ACTIONS(3993),
    [anon_sym_DASH_DASH] = ACTIONS(3993),
    [anon_sym_PLUS] = ACTIONS(3995),
    [anon_sym_DASH] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3993),
    [anon_sym_SLASH] = ACTIONS(3995),
    [anon_sym_PERCENT] = ACTIONS(3993),
    [anon_sym_CARET] = ACTIONS(3993),
    [anon_sym_PIPE] = ACTIONS(3995),
    [anon_sym_AMP] = ACTIONS(3995),
    [anon_sym_LT_LT] = ACTIONS(3993),
    [anon_sym_GT_GT] = ACTIONS(3995),
    [anon_sym_GT_GT_GT] = ACTIONS(3993),
    [anon_sym_EQ_EQ] = ACTIONS(3993),
    [anon_sym_BANG_EQ] = ACTIONS(3993),
    [anon_sym_GT_EQ] = ACTIONS(3993),
    [anon_sym_LT_EQ] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3995),
    [anon_sym_EQ_GT] = ACTIONS(3993),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_switch] = ACTIONS(3993),
    [anon_sym_DOT_DOT] = ACTIONS(3993),
    [anon_sym_and] = ACTIONS(3993),
    [anon_sym_or] = ACTIONS(3995),
    [anon_sym_AMP_AMP] = ACTIONS(3993),
    [anon_sym_PIPE_PIPE] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK] = ACTIONS(3993),
    [anon_sym_from] = ACTIONS(3993),
    [anon_sym_join] = ACTIONS(3993),
    [anon_sym_on] = ACTIONS(3993),
    [anon_sym_equals] = ACTIONS(3993),
    [anon_sym_let] = ACTIONS(3993),
    [anon_sym_orderby] = ACTIONS(3993),
    [anon_sym_group] = ACTIONS(3993),
    [anon_sym_by] = ACTIONS(3993),
    [anon_sym_select] = ACTIONS(3993),
    [anon_sym_as] = ACTIONS(3993),
    [anon_sym_is] = ACTIONS(3993),
    [anon_sym_DASH_GT] = ACTIONS(3993),
    [anon_sym_with] = ACTIONS(3993),
    [aux_sym_preproc_if_token3] = ACTIONS(3993),
    [aux_sym_preproc_else_token1] = ACTIONS(3993),
    [aux_sym_preproc_elif_token1] = ACTIONS(3993),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3611] = {
    [sym_preproc_region] = STATE(3611),
    [sym_preproc_endregion] = STATE(3611),
    [sym_preproc_line] = STATE(3611),
    [sym_preproc_pragma] = STATE(3611),
    [sym_preproc_nullable] = STATE(3611),
    [sym_preproc_error] = STATE(3611),
    [sym_preproc_warning] = STATE(3611),
    [sym_preproc_define] = STATE(3611),
    [sym_preproc_undef] = STATE(3611),
    [anon_sym_SEMI] = ACTIONS(4433),
    [anon_sym_LBRACK] = ACTIONS(4433),
    [anon_sym_COLON] = ACTIONS(4433),
    [anon_sym_COMMA] = ACTIONS(4433),
    [anon_sym_RBRACK] = ACTIONS(4433),
    [anon_sym_LPAREN] = ACTIONS(4433),
    [anon_sym_RPAREN] = ACTIONS(4433),
    [anon_sym_LBRACE] = ACTIONS(4433),
    [anon_sym_RBRACE] = ACTIONS(4433),
    [anon_sym_LT] = ACTIONS(4431),
    [anon_sym_GT] = ACTIONS(4431),
    [anon_sym_in] = ACTIONS(4431),
    [anon_sym_where] = ACTIONS(4433),
    [anon_sym_QMARK] = ACTIONS(4431),
    [anon_sym_BANG] = ACTIONS(4431),
    [anon_sym_PLUS_PLUS] = ACTIONS(4433),
    [anon_sym_DASH_DASH] = ACTIONS(4433),
    [anon_sym_PLUS] = ACTIONS(4431),
    [anon_sym_DASH] = ACTIONS(4431),
    [anon_sym_STAR] = ACTIONS(4433),
    [anon_sym_SLASH] = ACTIONS(4431),
    [anon_sym_PERCENT] = ACTIONS(4433),
    [anon_sym_CARET] = ACTIONS(4433),
    [anon_sym_PIPE] = ACTIONS(4431),
    [anon_sym_AMP] = ACTIONS(4431),
    [anon_sym_LT_LT] = ACTIONS(4433),
    [anon_sym_GT_GT] = ACTIONS(4431),
    [anon_sym_GT_GT_GT] = ACTIONS(4433),
    [anon_sym_EQ_EQ] = ACTIONS(4433),
    [anon_sym_BANG_EQ] = ACTIONS(4433),
    [anon_sym_GT_EQ] = ACTIONS(4433),
    [anon_sym_LT_EQ] = ACTIONS(4433),
    [anon_sym_DOT] = ACTIONS(4431),
    [anon_sym_EQ_GT] = ACTIONS(4433),
    [anon_sym_switch] = ACTIONS(4433),
    [anon_sym_DOT_DOT] = ACTIONS(4433),
    [anon_sym_and] = ACTIONS(4433),
    [anon_sym_or] = ACTIONS(4431),
    [anon_sym_AMP_AMP] = ACTIONS(4433),
    [anon_sym_PIPE_PIPE] = ACTIONS(4433),
    [anon_sym_QMARK_QMARK] = ACTIONS(4433),
    [anon_sym_from] = ACTIONS(4433),
    [anon_sym_into] = ACTIONS(4433),
    [anon_sym_join] = ACTIONS(4433),
    [anon_sym_on] = ACTIONS(4433),
    [anon_sym_equals] = ACTIONS(4433),
    [anon_sym_let] = ACTIONS(4433),
    [anon_sym_orderby] = ACTIONS(4433),
    [anon_sym_group] = ACTIONS(4433),
    [anon_sym_by] = ACTIONS(4433),
    [anon_sym_select] = ACTIONS(4433),
    [anon_sym_as] = ACTIONS(4433),
    [anon_sym_is] = ACTIONS(4433),
    [anon_sym_DASH_GT] = ACTIONS(4433),
    [anon_sym_with] = ACTIONS(4433),
    [aux_sym_preproc_if_token3] = ACTIONS(4433),
    [aux_sym_preproc_else_token1] = ACTIONS(4433),
    [aux_sym_preproc_elif_token1] = ACTIONS(4433),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3612] = {
    [sym_preproc_region] = STATE(3612),
    [sym_preproc_endregion] = STATE(3612),
    [sym_preproc_line] = STATE(3612),
    [sym_preproc_pragma] = STATE(3612),
    [sym_preproc_nullable] = STATE(3612),
    [sym_preproc_error] = STATE(3612),
    [sym_preproc_warning] = STATE(3612),
    [sym_preproc_define] = STATE(3612),
    [sym_preproc_undef] = STATE(3612),
    [anon_sym_SEMI] = ACTIONS(4494),
    [anon_sym_LBRACK] = ACTIONS(4593),
    [anon_sym_COLON] = ACTIONS(4494),
    [anon_sym_COMMA] = ACTIONS(4494),
    [anon_sym_RBRACK] = ACTIONS(4494),
    [anon_sym_LPAREN] = ACTIONS(4494),
    [anon_sym_RPAREN] = ACTIONS(4494),
    [anon_sym_LBRACE] = ACTIONS(4494),
    [anon_sym_RBRACE] = ACTIONS(4494),
    [anon_sym_LT] = ACTIONS(4492),
    [anon_sym_GT] = ACTIONS(4492),
    [anon_sym_in] = ACTIONS(4492),
    [anon_sym_where] = ACTIONS(4494),
    [anon_sym_QMARK] = ACTIONS(4492),
    [anon_sym_BANG] = ACTIONS(4492),
    [anon_sym_PLUS_PLUS] = ACTIONS(4494),
    [anon_sym_DASH_DASH] = ACTIONS(4494),
    [anon_sym_PLUS] = ACTIONS(4492),
    [anon_sym_DASH] = ACTIONS(4492),
    [anon_sym_STAR] = ACTIONS(4599),
    [anon_sym_SLASH] = ACTIONS(4492),
    [anon_sym_PERCENT] = ACTIONS(4494),
    [anon_sym_CARET] = ACTIONS(4494),
    [anon_sym_PIPE] = ACTIONS(4492),
    [anon_sym_AMP] = ACTIONS(4492),
    [anon_sym_LT_LT] = ACTIONS(4494),
    [anon_sym_GT_GT] = ACTIONS(4492),
    [anon_sym_GT_GT_GT] = ACTIONS(4494),
    [anon_sym_EQ_EQ] = ACTIONS(4494),
    [anon_sym_BANG_EQ] = ACTIONS(4494),
    [anon_sym_GT_EQ] = ACTIONS(4494),
    [anon_sym_LT_EQ] = ACTIONS(4494),
    [anon_sym_DOT] = ACTIONS(4492),
    [anon_sym_EQ_GT] = ACTIONS(4494),
    [anon_sym_switch] = ACTIONS(4494),
    [anon_sym_DOT_DOT] = ACTIONS(4494),
    [anon_sym_and] = ACTIONS(4494),
    [anon_sym_or] = ACTIONS(4492),
    [anon_sym_AMP_AMP] = ACTIONS(4494),
    [anon_sym_PIPE_PIPE] = ACTIONS(4494),
    [anon_sym_QMARK_QMARK] = ACTIONS(4494),
    [anon_sym_from] = ACTIONS(4494),
    [anon_sym_into] = ACTIONS(4494),
    [anon_sym_join] = ACTIONS(4494),
    [anon_sym_on] = ACTIONS(4494),
    [anon_sym_equals] = ACTIONS(4494),
    [anon_sym_let] = ACTIONS(4494),
    [anon_sym_orderby] = ACTIONS(4494),
    [anon_sym_group] = ACTIONS(4494),
    [anon_sym_by] = ACTIONS(4494),
    [anon_sym_select] = ACTIONS(4494),
    [anon_sym_as] = ACTIONS(4494),
    [anon_sym_is] = ACTIONS(4494),
    [anon_sym_DASH_GT] = ACTIONS(4494),
    [anon_sym_with] = ACTIONS(4494),
    [aux_sym_preproc_if_token3] = ACTIONS(4494),
    [aux_sym_preproc_else_token1] = ACTIONS(4494),
    [aux_sym_preproc_elif_token1] = ACTIONS(4494),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3613] = {
    [sym_preproc_region] = STATE(3613),
    [sym_preproc_endregion] = STATE(3613),
    [sym_preproc_line] = STATE(3613),
    [sym_preproc_pragma] = STATE(3613),
    [sym_preproc_nullable] = STATE(3613),
    [sym_preproc_error] = STATE(3613),
    [sym_preproc_warning] = STATE(3613),
    [sym_preproc_define] = STATE(3613),
    [sym_preproc_undef] = STATE(3613),
    [anon_sym_SEMI] = ACTIONS(4088),
    [anon_sym_LBRACK] = ACTIONS(4088),
    [anon_sym_COLON] = ACTIONS(4091),
    [anon_sym_COMMA] = ACTIONS(4088),
    [anon_sym_RBRACK] = ACTIONS(4088),
    [anon_sym_LPAREN] = ACTIONS(4088),
    [anon_sym_RPAREN] = ACTIONS(4088),
    [anon_sym_LBRACE] = ACTIONS(4088),
    [anon_sym_RBRACE] = ACTIONS(4088),
    [anon_sym_LT] = ACTIONS(4091),
    [anon_sym_GT] = ACTIONS(4091),
    [anon_sym_in] = ACTIONS(4088),
    [anon_sym_where] = ACTIONS(4088),
    [anon_sym_QMARK] = ACTIONS(4091),
    [anon_sym_BANG] = ACTIONS(4091),
    [anon_sym_PLUS_PLUS] = ACTIONS(4088),
    [anon_sym_DASH_DASH] = ACTIONS(4088),
    [anon_sym_PLUS] = ACTIONS(4091),
    [anon_sym_DASH] = ACTIONS(4091),
    [anon_sym_STAR] = ACTIONS(4088),
    [anon_sym_SLASH] = ACTIONS(4091),
    [anon_sym_PERCENT] = ACTIONS(4088),
    [anon_sym_CARET] = ACTIONS(4088),
    [anon_sym_PIPE] = ACTIONS(4091),
    [anon_sym_AMP] = ACTIONS(4091),
    [anon_sym_LT_LT] = ACTIONS(4088),
    [anon_sym_GT_GT] = ACTIONS(4091),
    [anon_sym_GT_GT_GT] = ACTIONS(4088),
    [anon_sym_EQ_EQ] = ACTIONS(4088),
    [anon_sym_BANG_EQ] = ACTIONS(4088),
    [anon_sym_GT_EQ] = ACTIONS(4088),
    [anon_sym_LT_EQ] = ACTIONS(4088),
    [anon_sym_DOT] = ACTIONS(4091),
    [anon_sym_EQ_GT] = ACTIONS(4088),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_switch] = ACTIONS(4088),
    [anon_sym_DOT_DOT] = ACTIONS(4088),
    [anon_sym_and] = ACTIONS(4088),
    [anon_sym_or] = ACTIONS(4091),
    [anon_sym_AMP_AMP] = ACTIONS(4088),
    [anon_sym_PIPE_PIPE] = ACTIONS(4088),
    [anon_sym_QMARK_QMARK] = ACTIONS(4088),
    [anon_sym_from] = ACTIONS(4088),
    [anon_sym_join] = ACTIONS(4088),
    [anon_sym_on] = ACTIONS(4088),
    [anon_sym_equals] = ACTIONS(4088),
    [anon_sym_let] = ACTIONS(4088),
    [anon_sym_orderby] = ACTIONS(4088),
    [anon_sym_group] = ACTIONS(4088),
    [anon_sym_by] = ACTIONS(4088),
    [anon_sym_select] = ACTIONS(4088),
    [anon_sym_as] = ACTIONS(4088),
    [anon_sym_is] = ACTIONS(4088),
    [anon_sym_DASH_GT] = ACTIONS(4088),
    [anon_sym_with] = ACTIONS(4088),
    [aux_sym_preproc_if_token3] = ACTIONS(4088),
    [aux_sym_preproc_else_token1] = ACTIONS(4088),
    [aux_sym_preproc_elif_token1] = ACTIONS(4088),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3614] = {
    [sym_preproc_region] = STATE(3614),
    [sym_preproc_endregion] = STATE(3614),
    [sym_preproc_line] = STATE(3614),
    [sym_preproc_pragma] = STATE(3614),
    [sym_preproc_nullable] = STATE(3614),
    [sym_preproc_error] = STATE(3614),
    [sym_preproc_warning] = STATE(3614),
    [sym_preproc_define] = STATE(3614),
    [sym_preproc_undef] = STATE(3614),
    [anon_sym_SEMI] = ACTIONS(4128),
    [anon_sym_LBRACK] = ACTIONS(4128),
    [anon_sym_COLON] = ACTIONS(4128),
    [anon_sym_COMMA] = ACTIONS(4128),
    [anon_sym_RBRACK] = ACTIONS(4128),
    [anon_sym_LPAREN] = ACTIONS(4128),
    [anon_sym_RPAREN] = ACTIONS(4128),
    [anon_sym_LBRACE] = ACTIONS(4128),
    [anon_sym_RBRACE] = ACTIONS(4128),
    [anon_sym_LT] = ACTIONS(4126),
    [anon_sym_GT] = ACTIONS(4126),
    [anon_sym_in] = ACTIONS(4126),
    [anon_sym_where] = ACTIONS(4128),
    [anon_sym_QMARK] = ACTIONS(4126),
    [anon_sym_BANG] = ACTIONS(4126),
    [anon_sym_PLUS_PLUS] = ACTIONS(4128),
    [anon_sym_DASH_DASH] = ACTIONS(4128),
    [anon_sym_PLUS] = ACTIONS(4126),
    [anon_sym_DASH] = ACTIONS(4126),
    [anon_sym_STAR] = ACTIONS(4128),
    [anon_sym_SLASH] = ACTIONS(4126),
    [anon_sym_PERCENT] = ACTIONS(4128),
    [anon_sym_CARET] = ACTIONS(4128),
    [anon_sym_PIPE] = ACTIONS(4126),
    [anon_sym_AMP] = ACTIONS(4126),
    [anon_sym_LT_LT] = ACTIONS(4128),
    [anon_sym_GT_GT] = ACTIONS(4126),
    [anon_sym_GT_GT_GT] = ACTIONS(4128),
    [anon_sym_EQ_EQ] = ACTIONS(4128),
    [anon_sym_BANG_EQ] = ACTIONS(4128),
    [anon_sym_GT_EQ] = ACTIONS(4128),
    [anon_sym_LT_EQ] = ACTIONS(4128),
    [anon_sym_DOT] = ACTIONS(4126),
    [anon_sym_EQ_GT] = ACTIONS(4128),
    [anon_sym_switch] = ACTIONS(4128),
    [anon_sym_DOT_DOT] = ACTIONS(4128),
    [anon_sym_and] = ACTIONS(4128),
    [anon_sym_or] = ACTIONS(4126),
    [anon_sym_AMP_AMP] = ACTIONS(4128),
    [anon_sym_PIPE_PIPE] = ACTIONS(4128),
    [anon_sym_QMARK_QMARK] = ACTIONS(4128),
    [anon_sym_from] = ACTIONS(4128),
    [anon_sym_into] = ACTIONS(4128),
    [anon_sym_join] = ACTIONS(4128),
    [anon_sym_on] = ACTIONS(4128),
    [anon_sym_equals] = ACTIONS(4128),
    [anon_sym_let] = ACTIONS(4128),
    [anon_sym_orderby] = ACTIONS(4128),
    [anon_sym_group] = ACTIONS(4128),
    [anon_sym_by] = ACTIONS(4128),
    [anon_sym_select] = ACTIONS(4128),
    [anon_sym_as] = ACTIONS(4128),
    [anon_sym_is] = ACTIONS(4128),
    [anon_sym_DASH_GT] = ACTIONS(4128),
    [anon_sym_with] = ACTIONS(4128),
    [aux_sym_preproc_if_token3] = ACTIONS(4128),
    [aux_sym_preproc_else_token1] = ACTIONS(4128),
    [aux_sym_preproc_elif_token1] = ACTIONS(4128),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3615] = {
    [sym_preproc_region] = STATE(3615),
    [sym_preproc_endregion] = STATE(3615),
    [sym_preproc_line] = STATE(3615),
    [sym_preproc_pragma] = STATE(3615),
    [sym_preproc_nullable] = STATE(3615),
    [sym_preproc_error] = STATE(3615),
    [sym_preproc_warning] = STATE(3615),
    [sym_preproc_define] = STATE(3615),
    [sym_preproc_undef] = STATE(3615),
    [anon_sym_SEMI] = ACTIONS(4500),
    [anon_sym_LBRACK] = ACTIONS(4500),
    [anon_sym_COLON] = ACTIONS(4500),
    [anon_sym_COMMA] = ACTIONS(4500),
    [anon_sym_RBRACK] = ACTIONS(4500),
    [anon_sym_LPAREN] = ACTIONS(4500),
    [anon_sym_RPAREN] = ACTIONS(4500),
    [anon_sym_LBRACE] = ACTIONS(4500),
    [anon_sym_RBRACE] = ACTIONS(4500),
    [anon_sym_LT] = ACTIONS(4498),
    [anon_sym_GT] = ACTIONS(4498),
    [anon_sym_in] = ACTIONS(4498),
    [anon_sym_where] = ACTIONS(4500),
    [anon_sym_QMARK] = ACTIONS(4498),
    [anon_sym_BANG] = ACTIONS(4498),
    [anon_sym_PLUS_PLUS] = ACTIONS(4500),
    [anon_sym_DASH_DASH] = ACTIONS(4500),
    [anon_sym_PLUS] = ACTIONS(4498),
    [anon_sym_DASH] = ACTIONS(4498),
    [anon_sym_STAR] = ACTIONS(4500),
    [anon_sym_SLASH] = ACTIONS(4498),
    [anon_sym_PERCENT] = ACTIONS(4500),
    [anon_sym_CARET] = ACTIONS(4500),
    [anon_sym_PIPE] = ACTIONS(4498),
    [anon_sym_AMP] = ACTIONS(4498),
    [anon_sym_LT_LT] = ACTIONS(4500),
    [anon_sym_GT_GT] = ACTIONS(4498),
    [anon_sym_GT_GT_GT] = ACTIONS(4500),
    [anon_sym_EQ_EQ] = ACTIONS(4500),
    [anon_sym_BANG_EQ] = ACTIONS(4500),
    [anon_sym_GT_EQ] = ACTIONS(4500),
    [anon_sym_LT_EQ] = ACTIONS(4500),
    [anon_sym_DOT] = ACTIONS(4498),
    [anon_sym_EQ_GT] = ACTIONS(4500),
    [anon_sym_switch] = ACTIONS(4500),
    [anon_sym_DOT_DOT] = ACTIONS(4500),
    [anon_sym_and] = ACTIONS(4500),
    [anon_sym_or] = ACTIONS(4498),
    [anon_sym_AMP_AMP] = ACTIONS(4500),
    [anon_sym_PIPE_PIPE] = ACTIONS(4500),
    [anon_sym_QMARK_QMARK] = ACTIONS(4500),
    [anon_sym_from] = ACTIONS(4500),
    [anon_sym_into] = ACTIONS(4500),
    [anon_sym_join] = ACTIONS(4500),
    [anon_sym_on] = ACTIONS(4500),
    [anon_sym_equals] = ACTIONS(4500),
    [anon_sym_let] = ACTIONS(4500),
    [anon_sym_orderby] = ACTIONS(4500),
    [anon_sym_group] = ACTIONS(4500),
    [anon_sym_by] = ACTIONS(4500),
    [anon_sym_select] = ACTIONS(4500),
    [anon_sym_as] = ACTIONS(4500),
    [anon_sym_is] = ACTIONS(4500),
    [anon_sym_DASH_GT] = ACTIONS(4500),
    [anon_sym_with] = ACTIONS(4500),
    [aux_sym_preproc_if_token3] = ACTIONS(4500),
    [aux_sym_preproc_else_token1] = ACTIONS(4500),
    [aux_sym_preproc_elif_token1] = ACTIONS(4500),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3616] = {
    [sym_preproc_region] = STATE(3616),
    [sym_preproc_endregion] = STATE(3616),
    [sym_preproc_line] = STATE(3616),
    [sym_preproc_pragma] = STATE(3616),
    [sym_preproc_nullable] = STATE(3616),
    [sym_preproc_error] = STATE(3616),
    [sym_preproc_warning] = STATE(3616),
    [sym_preproc_define] = STATE(3616),
    [sym_preproc_undef] = STATE(3616),
    [anon_sym_SEMI] = ACTIONS(4136),
    [anon_sym_LBRACK] = ACTIONS(4136),
    [anon_sym_COLON] = ACTIONS(4136),
    [anon_sym_COMMA] = ACTIONS(4136),
    [anon_sym_RBRACK] = ACTIONS(4136),
    [anon_sym_LPAREN] = ACTIONS(4136),
    [anon_sym_RPAREN] = ACTIONS(4136),
    [anon_sym_LBRACE] = ACTIONS(4136),
    [anon_sym_RBRACE] = ACTIONS(4136),
    [anon_sym_LT] = ACTIONS(4134),
    [anon_sym_GT] = ACTIONS(4134),
    [anon_sym_in] = ACTIONS(4134),
    [anon_sym_where] = ACTIONS(4136),
    [anon_sym_QMARK] = ACTIONS(4134),
    [anon_sym_BANG] = ACTIONS(4134),
    [anon_sym_PLUS_PLUS] = ACTIONS(4136),
    [anon_sym_DASH_DASH] = ACTIONS(4136),
    [anon_sym_PLUS] = ACTIONS(4134),
    [anon_sym_DASH] = ACTIONS(4134),
    [anon_sym_STAR] = ACTIONS(4136),
    [anon_sym_SLASH] = ACTIONS(4134),
    [anon_sym_PERCENT] = ACTIONS(4136),
    [anon_sym_CARET] = ACTIONS(4136),
    [anon_sym_PIPE] = ACTIONS(4134),
    [anon_sym_AMP] = ACTIONS(4134),
    [anon_sym_LT_LT] = ACTIONS(4136),
    [anon_sym_GT_GT] = ACTIONS(4134),
    [anon_sym_GT_GT_GT] = ACTIONS(4136),
    [anon_sym_EQ_EQ] = ACTIONS(4136),
    [anon_sym_BANG_EQ] = ACTIONS(4136),
    [anon_sym_GT_EQ] = ACTIONS(4136),
    [anon_sym_LT_EQ] = ACTIONS(4136),
    [anon_sym_DOT] = ACTIONS(4134),
    [anon_sym_EQ_GT] = ACTIONS(4136),
    [anon_sym_switch] = ACTIONS(4136),
    [anon_sym_DOT_DOT] = ACTIONS(4136),
    [anon_sym_and] = ACTIONS(4136),
    [anon_sym_or] = ACTIONS(4134),
    [anon_sym_AMP_AMP] = ACTIONS(4136),
    [anon_sym_PIPE_PIPE] = ACTIONS(4136),
    [anon_sym_QMARK_QMARK] = ACTIONS(4136),
    [anon_sym_from] = ACTIONS(4136),
    [anon_sym_into] = ACTIONS(4136),
    [anon_sym_join] = ACTIONS(4136),
    [anon_sym_on] = ACTIONS(4136),
    [anon_sym_equals] = ACTIONS(4136),
    [anon_sym_let] = ACTIONS(4136),
    [anon_sym_orderby] = ACTIONS(4136),
    [anon_sym_group] = ACTIONS(4136),
    [anon_sym_by] = ACTIONS(4136),
    [anon_sym_select] = ACTIONS(4136),
    [anon_sym_as] = ACTIONS(4136),
    [anon_sym_is] = ACTIONS(4136),
    [anon_sym_DASH_GT] = ACTIONS(4136),
    [anon_sym_with] = ACTIONS(4136),
    [aux_sym_preproc_if_token3] = ACTIONS(4136),
    [aux_sym_preproc_else_token1] = ACTIONS(4136),
    [aux_sym_preproc_elif_token1] = ACTIONS(4136),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3617] = {
    [sym_preproc_region] = STATE(3617),
    [sym_preproc_endregion] = STATE(3617),
    [sym_preproc_line] = STATE(3617),
    [sym_preproc_pragma] = STATE(3617),
    [sym_preproc_nullable] = STATE(3617),
    [sym_preproc_error] = STATE(3617),
    [sym_preproc_warning] = STATE(3617),
    [sym_preproc_define] = STATE(3617),
    [sym_preproc_undef] = STATE(3617),
    [anon_sym_SEMI] = ACTIONS(4480),
    [anon_sym_LBRACK] = ACTIONS(4480),
    [anon_sym_COLON] = ACTIONS(4480),
    [anon_sym_COMMA] = ACTIONS(4480),
    [anon_sym_RBRACK] = ACTIONS(4480),
    [anon_sym_LPAREN] = ACTIONS(4480),
    [anon_sym_RPAREN] = ACTIONS(4480),
    [anon_sym_LBRACE] = ACTIONS(4480),
    [anon_sym_RBRACE] = ACTIONS(4480),
    [anon_sym_LT] = ACTIONS(4478),
    [anon_sym_GT] = ACTIONS(4478),
    [anon_sym_in] = ACTIONS(4478),
    [anon_sym_where] = ACTIONS(4480),
    [anon_sym_QMARK] = ACTIONS(4478),
    [anon_sym_BANG] = ACTIONS(4478),
    [anon_sym_PLUS_PLUS] = ACTIONS(4480),
    [anon_sym_DASH_DASH] = ACTIONS(4480),
    [anon_sym_PLUS] = ACTIONS(4478),
    [anon_sym_DASH] = ACTIONS(4478),
    [anon_sym_STAR] = ACTIONS(4480),
    [anon_sym_SLASH] = ACTIONS(4478),
    [anon_sym_PERCENT] = ACTIONS(4480),
    [anon_sym_CARET] = ACTIONS(4480),
    [anon_sym_PIPE] = ACTIONS(4478),
    [anon_sym_AMP] = ACTIONS(4478),
    [anon_sym_LT_LT] = ACTIONS(4480),
    [anon_sym_GT_GT] = ACTIONS(4478),
    [anon_sym_GT_GT_GT] = ACTIONS(4480),
    [anon_sym_EQ_EQ] = ACTIONS(4480),
    [anon_sym_BANG_EQ] = ACTIONS(4480),
    [anon_sym_GT_EQ] = ACTIONS(4480),
    [anon_sym_LT_EQ] = ACTIONS(4480),
    [anon_sym_DOT] = ACTIONS(4478),
    [anon_sym_EQ_GT] = ACTIONS(4480),
    [anon_sym_switch] = ACTIONS(4480),
    [anon_sym_DOT_DOT] = ACTIONS(4480),
    [anon_sym_and] = ACTIONS(4480),
    [anon_sym_or] = ACTIONS(4478),
    [anon_sym_AMP_AMP] = ACTIONS(4480),
    [anon_sym_PIPE_PIPE] = ACTIONS(4480),
    [anon_sym_QMARK_QMARK] = ACTIONS(4480),
    [anon_sym_from] = ACTIONS(4480),
    [anon_sym_into] = ACTIONS(4480),
    [anon_sym_join] = ACTIONS(4480),
    [anon_sym_on] = ACTIONS(4480),
    [anon_sym_equals] = ACTIONS(4480),
    [anon_sym_let] = ACTIONS(4480),
    [anon_sym_orderby] = ACTIONS(4480),
    [anon_sym_group] = ACTIONS(4480),
    [anon_sym_by] = ACTIONS(4480),
    [anon_sym_select] = ACTIONS(4480),
    [anon_sym_as] = ACTIONS(4480),
    [anon_sym_is] = ACTIONS(4480),
    [anon_sym_DASH_GT] = ACTIONS(4480),
    [anon_sym_with] = ACTIONS(4480),
    [aux_sym_preproc_if_token3] = ACTIONS(4480),
    [aux_sym_preproc_else_token1] = ACTIONS(4480),
    [aux_sym_preproc_elif_token1] = ACTIONS(4480),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3618] = {
    [sym_preproc_region] = STATE(3618),
    [sym_preproc_endregion] = STATE(3618),
    [sym_preproc_line] = STATE(3618),
    [sym_preproc_pragma] = STATE(3618),
    [sym_preproc_nullable] = STATE(3618),
    [sym_preproc_error] = STATE(3618),
    [sym_preproc_warning] = STATE(3618),
    [sym_preproc_define] = STATE(3618),
    [sym_preproc_undef] = STATE(3618),
    [anon_sym_SEMI] = ACTIONS(5378),
    [anon_sym_LBRACK] = ACTIONS(5378),
    [anon_sym_COLON] = ACTIONS(5378),
    [anon_sym_COMMA] = ACTIONS(5378),
    [anon_sym_RBRACK] = ACTIONS(5378),
    [anon_sym_LPAREN] = ACTIONS(5378),
    [anon_sym_RPAREN] = ACTIONS(5378),
    [anon_sym_LBRACE] = ACTIONS(5378),
    [anon_sym_RBRACE] = ACTIONS(5378),
    [anon_sym_LT] = ACTIONS(5380),
    [anon_sym_GT] = ACTIONS(5380),
    [anon_sym_in] = ACTIONS(5380),
    [anon_sym_where] = ACTIONS(5378),
    [anon_sym_QMARK] = ACTIONS(5380),
    [anon_sym_BANG] = ACTIONS(5380),
    [anon_sym_PLUS_PLUS] = ACTIONS(5378),
    [anon_sym_DASH_DASH] = ACTIONS(5378),
    [anon_sym_PLUS] = ACTIONS(5380),
    [anon_sym_DASH] = ACTIONS(5380),
    [anon_sym_STAR] = ACTIONS(5378),
    [anon_sym_SLASH] = ACTIONS(5380),
    [anon_sym_PERCENT] = ACTIONS(5378),
    [anon_sym_CARET] = ACTIONS(5378),
    [anon_sym_PIPE] = ACTIONS(5380),
    [anon_sym_AMP] = ACTIONS(5380),
    [anon_sym_LT_LT] = ACTIONS(5378),
    [anon_sym_GT_GT] = ACTIONS(5380),
    [anon_sym_GT_GT_GT] = ACTIONS(5378),
    [anon_sym_EQ_EQ] = ACTIONS(5378),
    [anon_sym_BANG_EQ] = ACTIONS(5378),
    [anon_sym_GT_EQ] = ACTIONS(5378),
    [anon_sym_LT_EQ] = ACTIONS(5378),
    [anon_sym_DOT] = ACTIONS(5380),
    [anon_sym_EQ_GT] = ACTIONS(5378),
    [anon_sym_switch] = ACTIONS(5378),
    [anon_sym_DOT_DOT] = ACTIONS(5378),
    [anon_sym_and] = ACTIONS(5378),
    [anon_sym_or] = ACTIONS(5380),
    [anon_sym_AMP_AMP] = ACTIONS(5378),
    [anon_sym_PIPE_PIPE] = ACTIONS(5378),
    [anon_sym_QMARK_QMARK] = ACTIONS(5378),
    [anon_sym_from] = ACTIONS(5378),
    [anon_sym_into] = ACTIONS(5378),
    [anon_sym_join] = ACTIONS(5378),
    [anon_sym_on] = ACTIONS(5378),
    [anon_sym_equals] = ACTIONS(5378),
    [anon_sym_let] = ACTIONS(5378),
    [anon_sym_orderby] = ACTIONS(5378),
    [anon_sym_group] = ACTIONS(5378),
    [anon_sym_by] = ACTIONS(5378),
    [anon_sym_select] = ACTIONS(5378),
    [anon_sym_as] = ACTIONS(5378),
    [anon_sym_is] = ACTIONS(5378),
    [anon_sym_DASH_GT] = ACTIONS(5378),
    [anon_sym_with] = ACTIONS(5378),
    [aux_sym_preproc_if_token3] = ACTIONS(5378),
    [aux_sym_preproc_else_token1] = ACTIONS(5378),
    [aux_sym_preproc_elif_token1] = ACTIONS(5378),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3619] = {
    [sym_preproc_region] = STATE(3619),
    [sym_preproc_endregion] = STATE(3619),
    [sym_preproc_line] = STATE(3619),
    [sym_preproc_pragma] = STATE(3619),
    [sym_preproc_nullable] = STATE(3619),
    [sym_preproc_error] = STATE(3619),
    [sym_preproc_warning] = STATE(3619),
    [sym_preproc_define] = STATE(3619),
    [sym_preproc_undef] = STATE(3619),
    [anon_sym_SEMI] = ACTIONS(4504),
    [anon_sym_LBRACK] = ACTIONS(4504),
    [anon_sym_COLON] = ACTIONS(4504),
    [anon_sym_COMMA] = ACTIONS(4504),
    [anon_sym_RBRACK] = ACTIONS(4504),
    [anon_sym_LPAREN] = ACTIONS(4504),
    [anon_sym_RPAREN] = ACTIONS(4504),
    [anon_sym_LBRACE] = ACTIONS(4504),
    [anon_sym_RBRACE] = ACTIONS(4504),
    [anon_sym_LT] = ACTIONS(4502),
    [anon_sym_GT] = ACTIONS(4502),
    [anon_sym_in] = ACTIONS(4502),
    [anon_sym_where] = ACTIONS(4504),
    [anon_sym_QMARK] = ACTIONS(4502),
    [anon_sym_BANG] = ACTIONS(4502),
    [anon_sym_PLUS_PLUS] = ACTIONS(4504),
    [anon_sym_DASH_DASH] = ACTIONS(4504),
    [anon_sym_PLUS] = ACTIONS(4502),
    [anon_sym_DASH] = ACTIONS(4502),
    [anon_sym_STAR] = ACTIONS(4504),
    [anon_sym_SLASH] = ACTIONS(4502),
    [anon_sym_PERCENT] = ACTIONS(4504),
    [anon_sym_CARET] = ACTIONS(4504),
    [anon_sym_PIPE] = ACTIONS(4502),
    [anon_sym_AMP] = ACTIONS(4502),
    [anon_sym_LT_LT] = ACTIONS(4504),
    [anon_sym_GT_GT] = ACTIONS(4502),
    [anon_sym_GT_GT_GT] = ACTIONS(4504),
    [anon_sym_EQ_EQ] = ACTIONS(4504),
    [anon_sym_BANG_EQ] = ACTIONS(4504),
    [anon_sym_GT_EQ] = ACTIONS(4504),
    [anon_sym_LT_EQ] = ACTIONS(4504),
    [anon_sym_DOT] = ACTIONS(4502),
    [anon_sym_EQ_GT] = ACTIONS(4504),
    [anon_sym_switch] = ACTIONS(4504),
    [anon_sym_DOT_DOT] = ACTIONS(4504),
    [anon_sym_and] = ACTIONS(4504),
    [anon_sym_or] = ACTIONS(4502),
    [anon_sym_AMP_AMP] = ACTIONS(4504),
    [anon_sym_PIPE_PIPE] = ACTIONS(4504),
    [anon_sym_QMARK_QMARK] = ACTIONS(4504),
    [anon_sym_from] = ACTIONS(4504),
    [anon_sym_into] = ACTIONS(4504),
    [anon_sym_join] = ACTIONS(4504),
    [anon_sym_on] = ACTIONS(4504),
    [anon_sym_equals] = ACTIONS(4504),
    [anon_sym_let] = ACTIONS(4504),
    [anon_sym_orderby] = ACTIONS(4504),
    [anon_sym_group] = ACTIONS(4504),
    [anon_sym_by] = ACTIONS(4504),
    [anon_sym_select] = ACTIONS(4504),
    [anon_sym_as] = ACTIONS(4504),
    [anon_sym_is] = ACTIONS(4504),
    [anon_sym_DASH_GT] = ACTIONS(4504),
    [anon_sym_with] = ACTIONS(4504),
    [aux_sym_preproc_if_token3] = ACTIONS(4504),
    [aux_sym_preproc_else_token1] = ACTIONS(4504),
    [aux_sym_preproc_elif_token1] = ACTIONS(4504),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3620] = {
    [sym_preproc_region] = STATE(3620),
    [sym_preproc_endregion] = STATE(3620),
    [sym_preproc_line] = STATE(3620),
    [sym_preproc_pragma] = STATE(3620),
    [sym_preproc_nullable] = STATE(3620),
    [sym_preproc_error] = STATE(3620),
    [sym_preproc_warning] = STATE(3620),
    [sym_preproc_define] = STATE(3620),
    [sym_preproc_undef] = STATE(3620),
    [anon_sym_SEMI] = ACTIONS(4550),
    [anon_sym_LBRACK] = ACTIONS(4550),
    [anon_sym_COLON] = ACTIONS(4550),
    [anon_sym_COMMA] = ACTIONS(4550),
    [anon_sym_RBRACK] = ACTIONS(4550),
    [anon_sym_LPAREN] = ACTIONS(4550),
    [anon_sym_RPAREN] = ACTIONS(4550),
    [anon_sym_LBRACE] = ACTIONS(4550),
    [anon_sym_RBRACE] = ACTIONS(4550),
    [anon_sym_LT] = ACTIONS(4548),
    [anon_sym_GT] = ACTIONS(4548),
    [anon_sym_in] = ACTIONS(4548),
    [anon_sym_where] = ACTIONS(4550),
    [anon_sym_QMARK] = ACTIONS(4548),
    [anon_sym_BANG] = ACTIONS(4548),
    [anon_sym_PLUS_PLUS] = ACTIONS(4550),
    [anon_sym_DASH_DASH] = ACTIONS(4550),
    [anon_sym_PLUS] = ACTIONS(4548),
    [anon_sym_DASH] = ACTIONS(4548),
    [anon_sym_STAR] = ACTIONS(4550),
    [anon_sym_SLASH] = ACTIONS(4548),
    [anon_sym_PERCENT] = ACTIONS(4550),
    [anon_sym_CARET] = ACTIONS(4550),
    [anon_sym_PIPE] = ACTIONS(4548),
    [anon_sym_AMP] = ACTIONS(4548),
    [anon_sym_LT_LT] = ACTIONS(4550),
    [anon_sym_GT_GT] = ACTIONS(4548),
    [anon_sym_GT_GT_GT] = ACTIONS(4550),
    [anon_sym_EQ_EQ] = ACTIONS(4550),
    [anon_sym_BANG_EQ] = ACTIONS(4550),
    [anon_sym_GT_EQ] = ACTIONS(4550),
    [anon_sym_LT_EQ] = ACTIONS(4550),
    [anon_sym_DOT] = ACTIONS(4548),
    [anon_sym_EQ_GT] = ACTIONS(4550),
    [anon_sym_switch] = ACTIONS(4550),
    [anon_sym_DOT_DOT] = ACTIONS(4550),
    [anon_sym_and] = ACTIONS(4550),
    [anon_sym_or] = ACTIONS(4548),
    [anon_sym_AMP_AMP] = ACTIONS(4550),
    [anon_sym_PIPE_PIPE] = ACTIONS(4550),
    [anon_sym_QMARK_QMARK] = ACTIONS(4550),
    [anon_sym_from] = ACTIONS(4550),
    [anon_sym_into] = ACTIONS(4550),
    [anon_sym_join] = ACTIONS(4550),
    [anon_sym_on] = ACTIONS(4550),
    [anon_sym_equals] = ACTIONS(4550),
    [anon_sym_let] = ACTIONS(4550),
    [anon_sym_orderby] = ACTIONS(4550),
    [anon_sym_group] = ACTIONS(4550),
    [anon_sym_by] = ACTIONS(4550),
    [anon_sym_select] = ACTIONS(4550),
    [anon_sym_as] = ACTIONS(4550),
    [anon_sym_is] = ACTIONS(4550),
    [anon_sym_DASH_GT] = ACTIONS(4550),
    [anon_sym_with] = ACTIONS(4550),
    [aux_sym_preproc_if_token3] = ACTIONS(4550),
    [aux_sym_preproc_else_token1] = ACTIONS(4550),
    [aux_sym_preproc_elif_token1] = ACTIONS(4550),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3621] = {
    [sym_preproc_region] = STATE(3621),
    [sym_preproc_endregion] = STATE(3621),
    [sym_preproc_line] = STATE(3621),
    [sym_preproc_pragma] = STATE(3621),
    [sym_preproc_nullable] = STATE(3621),
    [sym_preproc_error] = STATE(3621),
    [sym_preproc_warning] = STATE(3621),
    [sym_preproc_define] = STATE(3621),
    [sym_preproc_undef] = STATE(3621),
    [anon_sym_SEMI] = ACTIONS(4494),
    [anon_sym_LBRACK] = ACTIONS(4593),
    [anon_sym_COLON] = ACTIONS(4494),
    [anon_sym_COMMA] = ACTIONS(4494),
    [anon_sym_RBRACK] = ACTIONS(4494),
    [anon_sym_LPAREN] = ACTIONS(4494),
    [anon_sym_RPAREN] = ACTIONS(4494),
    [anon_sym_LBRACE] = ACTIONS(4494),
    [anon_sym_RBRACE] = ACTIONS(4494),
    [anon_sym_LT] = ACTIONS(4492),
    [anon_sym_GT] = ACTIONS(4492),
    [anon_sym_in] = ACTIONS(4492),
    [anon_sym_where] = ACTIONS(4494),
    [anon_sym_QMARK] = ACTIONS(5375),
    [anon_sym_BANG] = ACTIONS(4492),
    [anon_sym_PLUS_PLUS] = ACTIONS(4494),
    [anon_sym_DASH_DASH] = ACTIONS(4494),
    [anon_sym_PLUS] = ACTIONS(4492),
    [anon_sym_DASH] = ACTIONS(4492),
    [anon_sym_STAR] = ACTIONS(4599),
    [anon_sym_SLASH] = ACTIONS(4492),
    [anon_sym_PERCENT] = ACTIONS(4494),
    [anon_sym_CARET] = ACTIONS(4494),
    [anon_sym_PIPE] = ACTIONS(4492),
    [anon_sym_AMP] = ACTIONS(4492),
    [anon_sym_LT_LT] = ACTIONS(4494),
    [anon_sym_GT_GT] = ACTIONS(4492),
    [anon_sym_GT_GT_GT] = ACTIONS(4494),
    [anon_sym_EQ_EQ] = ACTIONS(4494),
    [anon_sym_BANG_EQ] = ACTIONS(4494),
    [anon_sym_GT_EQ] = ACTIONS(4494),
    [anon_sym_LT_EQ] = ACTIONS(4494),
    [anon_sym_DOT] = ACTIONS(4492),
    [anon_sym_EQ_GT] = ACTIONS(4494),
    [anon_sym_switch] = ACTIONS(4494),
    [anon_sym_DOT_DOT] = ACTIONS(4494),
    [anon_sym_and] = ACTIONS(4494),
    [anon_sym_or] = ACTIONS(4492),
    [anon_sym_AMP_AMP] = ACTIONS(4494),
    [anon_sym_PIPE_PIPE] = ACTIONS(4494),
    [anon_sym_QMARK_QMARK] = ACTIONS(4494),
    [anon_sym_from] = ACTIONS(4494),
    [anon_sym_into] = ACTIONS(4494),
    [anon_sym_join] = ACTIONS(4494),
    [anon_sym_on] = ACTIONS(4494),
    [anon_sym_equals] = ACTIONS(4494),
    [anon_sym_let] = ACTIONS(4494),
    [anon_sym_orderby] = ACTIONS(4494),
    [anon_sym_group] = ACTIONS(4494),
    [anon_sym_by] = ACTIONS(4494),
    [anon_sym_select] = ACTIONS(4494),
    [anon_sym_as] = ACTIONS(4494),
    [anon_sym_is] = ACTIONS(4494),
    [anon_sym_DASH_GT] = ACTIONS(4494),
    [anon_sym_with] = ACTIONS(4494),
    [aux_sym_preproc_if_token3] = ACTIONS(4494),
    [aux_sym_preproc_else_token1] = ACTIONS(4494),
    [aux_sym_preproc_elif_token1] = ACTIONS(4494),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3622] = {
    [sym_initializer_expression] = STATE(3743),
    [sym_preproc_region] = STATE(3622),
    [sym_preproc_endregion] = STATE(3622),
    [sym_preproc_line] = STATE(3622),
    [sym_preproc_pragma] = STATE(3622),
    [sym_preproc_nullable] = STATE(3622),
    [sym_preproc_error] = STATE(3622),
    [sym_preproc_warning] = STATE(3622),
    [sym_preproc_define] = STATE(3622),
    [sym_preproc_undef] = STATE(3622),
    [anon_sym_SEMI] = ACTIONS(5296),
    [anon_sym_LBRACK] = ACTIONS(5298),
    [anon_sym_COLON] = ACTIONS(5296),
    [anon_sym_COMMA] = ACTIONS(5296),
    [anon_sym_RBRACK] = ACTIONS(5296),
    [anon_sym_LPAREN] = ACTIONS(5296),
    [anon_sym_RPAREN] = ACTIONS(5296),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_RBRACE] = ACTIONS(5296),
    [anon_sym_LT] = ACTIONS(5301),
    [anon_sym_GT] = ACTIONS(5301),
    [anon_sym_in] = ACTIONS(5296),
    [anon_sym_where] = ACTIONS(5296),
    [anon_sym_QMARK] = ACTIONS(5301),
    [anon_sym_BANG] = ACTIONS(5301),
    [anon_sym_PLUS_PLUS] = ACTIONS(5296),
    [anon_sym_DASH_DASH] = ACTIONS(5296),
    [anon_sym_PLUS] = ACTIONS(5301),
    [anon_sym_DASH] = ACTIONS(5301),
    [anon_sym_STAR] = ACTIONS(5296),
    [anon_sym_SLASH] = ACTIONS(5301),
    [anon_sym_PERCENT] = ACTIONS(5296),
    [anon_sym_CARET] = ACTIONS(5296),
    [anon_sym_PIPE] = ACTIONS(5301),
    [anon_sym_AMP] = ACTIONS(5301),
    [anon_sym_LT_LT] = ACTIONS(5296),
    [anon_sym_GT_GT] = ACTIONS(5301),
    [anon_sym_GT_GT_GT] = ACTIONS(5296),
    [anon_sym_EQ_EQ] = ACTIONS(5296),
    [anon_sym_BANG_EQ] = ACTIONS(5296),
    [anon_sym_GT_EQ] = ACTIONS(5296),
    [anon_sym_LT_EQ] = ACTIONS(5296),
    [anon_sym_DOT] = ACTIONS(5301),
    [anon_sym_EQ_GT] = ACTIONS(5296),
    [anon_sym_switch] = ACTIONS(5296),
    [anon_sym_DOT_DOT] = ACTIONS(5296),
    [anon_sym_and] = ACTIONS(5296),
    [anon_sym_or] = ACTIONS(5301),
    [anon_sym_AMP_AMP] = ACTIONS(5296),
    [anon_sym_PIPE_PIPE] = ACTIONS(5296),
    [anon_sym_QMARK_QMARK] = ACTIONS(5296),
    [anon_sym_from] = ACTIONS(5296),
    [anon_sym_join] = ACTIONS(5296),
    [anon_sym_on] = ACTIONS(5296),
    [anon_sym_equals] = ACTIONS(5296),
    [anon_sym_let] = ACTIONS(5296),
    [anon_sym_orderby] = ACTIONS(5296),
    [anon_sym_group] = ACTIONS(5296),
    [anon_sym_by] = ACTIONS(5296),
    [anon_sym_select] = ACTIONS(5296),
    [anon_sym_as] = ACTIONS(5296),
    [anon_sym_is] = ACTIONS(5296),
    [anon_sym_DASH_GT] = ACTIONS(5296),
    [anon_sym_with] = ACTIONS(5296),
    [aux_sym_preproc_if_token3] = ACTIONS(5296),
    [aux_sym_preproc_else_token1] = ACTIONS(5296),
    [aux_sym_preproc_elif_token1] = ACTIONS(5296),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3623] = {
    [sym_preproc_region] = STATE(3623),
    [sym_preproc_endregion] = STATE(3623),
    [sym_preproc_line] = STATE(3623),
    [sym_preproc_pragma] = STATE(3623),
    [sym_preproc_nullable] = STATE(3623),
    [sym_preproc_error] = STATE(3623),
    [sym_preproc_warning] = STATE(3623),
    [sym_preproc_define] = STATE(3623),
    [sym_preproc_undef] = STATE(3623),
    [anon_sym_SEMI] = ACTIONS(4488),
    [anon_sym_LBRACK] = ACTIONS(4488),
    [anon_sym_COLON] = ACTIONS(4488),
    [anon_sym_COMMA] = ACTIONS(4488),
    [anon_sym_RBRACK] = ACTIONS(4488),
    [anon_sym_LPAREN] = ACTIONS(4488),
    [anon_sym_RPAREN] = ACTIONS(4488),
    [anon_sym_LBRACE] = ACTIONS(4488),
    [anon_sym_RBRACE] = ACTIONS(4488),
    [anon_sym_LT] = ACTIONS(4486),
    [anon_sym_GT] = ACTIONS(4486),
    [anon_sym_in] = ACTIONS(4486),
    [anon_sym_where] = ACTIONS(4488),
    [anon_sym_QMARK] = ACTIONS(4486),
    [anon_sym_BANG] = ACTIONS(4486),
    [anon_sym_PLUS_PLUS] = ACTIONS(4488),
    [anon_sym_DASH_DASH] = ACTIONS(4488),
    [anon_sym_PLUS] = ACTIONS(4486),
    [anon_sym_DASH] = ACTIONS(4486),
    [anon_sym_STAR] = ACTIONS(4488),
    [anon_sym_SLASH] = ACTIONS(4486),
    [anon_sym_PERCENT] = ACTIONS(4488),
    [anon_sym_CARET] = ACTIONS(4488),
    [anon_sym_PIPE] = ACTIONS(4486),
    [anon_sym_AMP] = ACTIONS(4486),
    [anon_sym_LT_LT] = ACTIONS(4488),
    [anon_sym_GT_GT] = ACTIONS(4486),
    [anon_sym_GT_GT_GT] = ACTIONS(4488),
    [anon_sym_EQ_EQ] = ACTIONS(4488),
    [anon_sym_BANG_EQ] = ACTIONS(4488),
    [anon_sym_GT_EQ] = ACTIONS(4488),
    [anon_sym_LT_EQ] = ACTIONS(4488),
    [anon_sym_DOT] = ACTIONS(4486),
    [anon_sym_EQ_GT] = ACTIONS(4488),
    [anon_sym_switch] = ACTIONS(4488),
    [anon_sym_DOT_DOT] = ACTIONS(4488),
    [anon_sym_and] = ACTIONS(4488),
    [anon_sym_or] = ACTIONS(4486),
    [anon_sym_AMP_AMP] = ACTIONS(4488),
    [anon_sym_PIPE_PIPE] = ACTIONS(4488),
    [anon_sym_QMARK_QMARK] = ACTIONS(4488),
    [anon_sym_from] = ACTIONS(4488),
    [anon_sym_into] = ACTIONS(4488),
    [anon_sym_join] = ACTIONS(4488),
    [anon_sym_on] = ACTIONS(4488),
    [anon_sym_equals] = ACTIONS(4488),
    [anon_sym_let] = ACTIONS(4488),
    [anon_sym_orderby] = ACTIONS(4488),
    [anon_sym_group] = ACTIONS(4488),
    [anon_sym_by] = ACTIONS(4488),
    [anon_sym_select] = ACTIONS(4488),
    [anon_sym_as] = ACTIONS(4488),
    [anon_sym_is] = ACTIONS(4488),
    [anon_sym_DASH_GT] = ACTIONS(4488),
    [anon_sym_with] = ACTIONS(4488),
    [aux_sym_preproc_if_token3] = ACTIONS(4488),
    [aux_sym_preproc_else_token1] = ACTIONS(4488),
    [aux_sym_preproc_elif_token1] = ACTIONS(4488),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3624] = {
    [sym_preproc_region] = STATE(3624),
    [sym_preproc_endregion] = STATE(3624),
    [sym_preproc_line] = STATE(3624),
    [sym_preproc_pragma] = STATE(3624),
    [sym_preproc_nullable] = STATE(3624),
    [sym_preproc_error] = STATE(3624),
    [sym_preproc_warning] = STATE(3624),
    [sym_preproc_define] = STATE(3624),
    [sym_preproc_undef] = STATE(3624),
    [anon_sym_SEMI] = ACTIONS(4472),
    [anon_sym_LBRACK] = ACTIONS(4472),
    [anon_sym_COLON] = ACTIONS(4472),
    [anon_sym_COMMA] = ACTIONS(4472),
    [anon_sym_RBRACK] = ACTIONS(4472),
    [anon_sym_LPAREN] = ACTIONS(4472),
    [anon_sym_RPAREN] = ACTIONS(4472),
    [anon_sym_LBRACE] = ACTIONS(4472),
    [anon_sym_RBRACE] = ACTIONS(4472),
    [anon_sym_LT] = ACTIONS(4470),
    [anon_sym_GT] = ACTIONS(4470),
    [anon_sym_in] = ACTIONS(4470),
    [anon_sym_where] = ACTIONS(4472),
    [anon_sym_QMARK] = ACTIONS(4470),
    [anon_sym_BANG] = ACTIONS(4470),
    [anon_sym_PLUS_PLUS] = ACTIONS(4472),
    [anon_sym_DASH_DASH] = ACTIONS(4472),
    [anon_sym_PLUS] = ACTIONS(4470),
    [anon_sym_DASH] = ACTIONS(4470),
    [anon_sym_STAR] = ACTIONS(4472),
    [anon_sym_SLASH] = ACTIONS(4470),
    [anon_sym_PERCENT] = ACTIONS(4472),
    [anon_sym_CARET] = ACTIONS(4472),
    [anon_sym_PIPE] = ACTIONS(4470),
    [anon_sym_AMP] = ACTIONS(4470),
    [anon_sym_LT_LT] = ACTIONS(4472),
    [anon_sym_GT_GT] = ACTIONS(4470),
    [anon_sym_GT_GT_GT] = ACTIONS(4472),
    [anon_sym_EQ_EQ] = ACTIONS(4472),
    [anon_sym_BANG_EQ] = ACTIONS(4472),
    [anon_sym_GT_EQ] = ACTIONS(4472),
    [anon_sym_LT_EQ] = ACTIONS(4472),
    [anon_sym_DOT] = ACTIONS(4470),
    [anon_sym_EQ_GT] = ACTIONS(4472),
    [anon_sym_switch] = ACTIONS(4472),
    [anon_sym_DOT_DOT] = ACTIONS(4472),
    [anon_sym_and] = ACTIONS(4472),
    [anon_sym_or] = ACTIONS(4470),
    [anon_sym_AMP_AMP] = ACTIONS(4472),
    [anon_sym_PIPE_PIPE] = ACTIONS(4472),
    [anon_sym_QMARK_QMARK] = ACTIONS(4472),
    [anon_sym_from] = ACTIONS(4472),
    [anon_sym_into] = ACTIONS(4472),
    [anon_sym_join] = ACTIONS(4472),
    [anon_sym_on] = ACTIONS(4472),
    [anon_sym_equals] = ACTIONS(4472),
    [anon_sym_let] = ACTIONS(4472),
    [anon_sym_orderby] = ACTIONS(4472),
    [anon_sym_group] = ACTIONS(4472),
    [anon_sym_by] = ACTIONS(4472),
    [anon_sym_select] = ACTIONS(4472),
    [anon_sym_as] = ACTIONS(4472),
    [anon_sym_is] = ACTIONS(4472),
    [anon_sym_DASH_GT] = ACTIONS(4472),
    [anon_sym_with] = ACTIONS(4472),
    [aux_sym_preproc_if_token3] = ACTIONS(4472),
    [aux_sym_preproc_else_token1] = ACTIONS(4472),
    [aux_sym_preproc_elif_token1] = ACTIONS(4472),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3625] = {
    [sym_preproc_region] = STATE(3625),
    [sym_preproc_endregion] = STATE(3625),
    [sym_preproc_line] = STATE(3625),
    [sym_preproc_pragma] = STATE(3625),
    [sym_preproc_nullable] = STATE(3625),
    [sym_preproc_error] = STATE(3625),
    [sym_preproc_warning] = STATE(3625),
    [sym_preproc_define] = STATE(3625),
    [sym_preproc_undef] = STATE(3625),
    [anon_sym_SEMI] = ACTIONS(4124),
    [anon_sym_LBRACK] = ACTIONS(4124),
    [anon_sym_COLON] = ACTIONS(4122),
    [anon_sym_COMMA] = ACTIONS(4124),
    [anon_sym_RBRACK] = ACTIONS(4124),
    [anon_sym_LPAREN] = ACTIONS(4124),
    [anon_sym_RPAREN] = ACTIONS(4124),
    [anon_sym_LBRACE] = ACTIONS(4124),
    [anon_sym_RBRACE] = ACTIONS(4124),
    [anon_sym_LT] = ACTIONS(4122),
    [anon_sym_GT] = ACTIONS(4122),
    [anon_sym_in] = ACTIONS(4124),
    [anon_sym_where] = ACTIONS(4124),
    [anon_sym_QMARK] = ACTIONS(4122),
    [anon_sym_BANG] = ACTIONS(4122),
    [anon_sym_PLUS_PLUS] = ACTIONS(4124),
    [anon_sym_DASH_DASH] = ACTIONS(4124),
    [anon_sym_PLUS] = ACTIONS(4122),
    [anon_sym_DASH] = ACTIONS(4122),
    [anon_sym_STAR] = ACTIONS(4124),
    [anon_sym_SLASH] = ACTIONS(4122),
    [anon_sym_PERCENT] = ACTIONS(4124),
    [anon_sym_CARET] = ACTIONS(4124),
    [anon_sym_PIPE] = ACTIONS(4122),
    [anon_sym_AMP] = ACTIONS(4122),
    [anon_sym_LT_LT] = ACTIONS(4124),
    [anon_sym_GT_GT] = ACTIONS(4122),
    [anon_sym_GT_GT_GT] = ACTIONS(4124),
    [anon_sym_EQ_EQ] = ACTIONS(4124),
    [anon_sym_BANG_EQ] = ACTIONS(4124),
    [anon_sym_GT_EQ] = ACTIONS(4124),
    [anon_sym_LT_EQ] = ACTIONS(4124),
    [anon_sym_DOT] = ACTIONS(4122),
    [anon_sym_EQ_GT] = ACTIONS(4124),
    [anon_sym_COLON_COLON] = ACTIONS(4124),
    [anon_sym_switch] = ACTIONS(4124),
    [anon_sym_DOT_DOT] = ACTIONS(4124),
    [anon_sym_and] = ACTIONS(4124),
    [anon_sym_or] = ACTIONS(4122),
    [anon_sym_AMP_AMP] = ACTIONS(4124),
    [anon_sym_PIPE_PIPE] = ACTIONS(4124),
    [anon_sym_QMARK_QMARK] = ACTIONS(4124),
    [anon_sym_from] = ACTIONS(4124),
    [anon_sym_join] = ACTIONS(4124),
    [anon_sym_on] = ACTIONS(4124),
    [anon_sym_equals] = ACTIONS(4124),
    [anon_sym_let] = ACTIONS(4124),
    [anon_sym_orderby] = ACTIONS(4124),
    [anon_sym_group] = ACTIONS(4124),
    [anon_sym_by] = ACTIONS(4124),
    [anon_sym_select] = ACTIONS(4124),
    [anon_sym_as] = ACTIONS(4124),
    [anon_sym_is] = ACTIONS(4124),
    [anon_sym_DASH_GT] = ACTIONS(4124),
    [anon_sym_with] = ACTIONS(4124),
    [aux_sym_preproc_if_token3] = ACTIONS(4124),
    [aux_sym_preproc_else_token1] = ACTIONS(4124),
    [aux_sym_preproc_elif_token1] = ACTIONS(4124),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3626] = {
    [sym_preproc_region] = STATE(3626),
    [sym_preproc_endregion] = STATE(3626),
    [sym_preproc_line] = STATE(3626),
    [sym_preproc_pragma] = STATE(3626),
    [sym_preproc_nullable] = STATE(3626),
    [sym_preproc_error] = STATE(3626),
    [sym_preproc_warning] = STATE(3626),
    [sym_preproc_define] = STATE(3626),
    [sym_preproc_undef] = STATE(3626),
    [anon_sym_SEMI] = ACTIONS(5382),
    [anon_sym_LBRACK] = ACTIONS(5382),
    [anon_sym_COLON] = ACTIONS(5382),
    [anon_sym_COMMA] = ACTIONS(5382),
    [anon_sym_RBRACK] = ACTIONS(5382),
    [anon_sym_LPAREN] = ACTIONS(5382),
    [anon_sym_RPAREN] = ACTIONS(5382),
    [anon_sym_RBRACE] = ACTIONS(5382),
    [anon_sym_LT] = ACTIONS(5384),
    [anon_sym_GT] = ACTIONS(5384),
    [anon_sym_in] = ACTIONS(5384),
    [anon_sym_where] = ACTIONS(5382),
    [anon_sym_QMARK] = ACTIONS(5384),
    [anon_sym_BANG] = ACTIONS(5384),
    [anon_sym_PLUS_PLUS] = ACTIONS(5382),
    [anon_sym_DASH_DASH] = ACTIONS(5382),
    [anon_sym_PLUS] = ACTIONS(5384),
    [anon_sym_DASH] = ACTIONS(5384),
    [anon_sym_STAR] = ACTIONS(5382),
    [anon_sym_SLASH] = ACTIONS(5384),
    [anon_sym_PERCENT] = ACTIONS(5382),
    [anon_sym_CARET] = ACTIONS(5382),
    [anon_sym_PIPE] = ACTIONS(5384),
    [anon_sym_AMP] = ACTIONS(5384),
    [anon_sym_LT_LT] = ACTIONS(5382),
    [anon_sym_GT_GT] = ACTIONS(5384),
    [anon_sym_GT_GT_GT] = ACTIONS(5382),
    [anon_sym_EQ_EQ] = ACTIONS(5382),
    [anon_sym_BANG_EQ] = ACTIONS(5382),
    [anon_sym_GT_EQ] = ACTIONS(5382),
    [anon_sym_LT_EQ] = ACTIONS(5382),
    [anon_sym_DOT] = ACTIONS(5384),
    [anon_sym_EQ_GT] = ACTIONS(5382),
    [anon_sym_switch] = ACTIONS(5382),
    [anon_sym_DOT_DOT] = ACTIONS(5382),
    [anon_sym_and] = ACTIONS(5382),
    [anon_sym_or] = ACTIONS(5384),
    [anon_sym_AMP_AMP] = ACTIONS(5382),
    [anon_sym_PIPE_PIPE] = ACTIONS(5382),
    [anon_sym_QMARK_QMARK] = ACTIONS(5382),
    [anon_sym_from] = ACTIONS(5382),
    [anon_sym_into] = ACTIONS(5382),
    [anon_sym_join] = ACTIONS(5382),
    [anon_sym_on] = ACTIONS(5382),
    [anon_sym_equals] = ACTIONS(5382),
    [anon_sym_let] = ACTIONS(5382),
    [anon_sym_orderby] = ACTIONS(5382),
    [anon_sym_group] = ACTIONS(5382),
    [anon_sym_by] = ACTIONS(5382),
    [anon_sym_select] = ACTIONS(5382),
    [anon_sym_as] = ACTIONS(5382),
    [anon_sym_is] = ACTIONS(5382),
    [anon_sym_DASH_GT] = ACTIONS(5382),
    [anon_sym_with] = ACTIONS(5382),
    [sym_string_literal_encoding] = ACTIONS(5386),
    [aux_sym_preproc_if_token3] = ACTIONS(5382),
    [aux_sym_preproc_else_token1] = ACTIONS(5382),
    [aux_sym_preproc_elif_token1] = ACTIONS(5382),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3627] = {
    [sym_preproc_region] = STATE(3627),
    [sym_preproc_endregion] = STATE(3627),
    [sym_preproc_line] = STATE(3627),
    [sym_preproc_pragma] = STATE(3627),
    [sym_preproc_nullable] = STATE(3627),
    [sym_preproc_error] = STATE(3627),
    [sym_preproc_warning] = STATE(3627),
    [sym_preproc_define] = STATE(3627),
    [sym_preproc_undef] = STATE(3627),
    [anon_sym_SEMI] = ACTIONS(5388),
    [anon_sym_LBRACK] = ACTIONS(5388),
    [anon_sym_COLON] = ACTIONS(5388),
    [anon_sym_COMMA] = ACTIONS(5388),
    [anon_sym_RBRACK] = ACTIONS(5388),
    [anon_sym_LPAREN] = ACTIONS(5388),
    [anon_sym_RPAREN] = ACTIONS(5388),
    [anon_sym_RBRACE] = ACTIONS(5388),
    [anon_sym_LT] = ACTIONS(5390),
    [anon_sym_GT] = ACTIONS(5390),
    [anon_sym_in] = ACTIONS(5390),
    [anon_sym_where] = ACTIONS(5388),
    [anon_sym_QMARK] = ACTIONS(5390),
    [anon_sym_BANG] = ACTIONS(5390),
    [anon_sym_PLUS_PLUS] = ACTIONS(5388),
    [anon_sym_DASH_DASH] = ACTIONS(5388),
    [anon_sym_PLUS] = ACTIONS(5390),
    [anon_sym_DASH] = ACTIONS(5390),
    [anon_sym_STAR] = ACTIONS(5388),
    [anon_sym_SLASH] = ACTIONS(5390),
    [anon_sym_PERCENT] = ACTIONS(5388),
    [anon_sym_CARET] = ACTIONS(5388),
    [anon_sym_PIPE] = ACTIONS(5390),
    [anon_sym_AMP] = ACTIONS(5390),
    [anon_sym_LT_LT] = ACTIONS(5388),
    [anon_sym_GT_GT] = ACTIONS(5390),
    [anon_sym_GT_GT_GT] = ACTIONS(5388),
    [anon_sym_EQ_EQ] = ACTIONS(5388),
    [anon_sym_BANG_EQ] = ACTIONS(5388),
    [anon_sym_GT_EQ] = ACTIONS(5388),
    [anon_sym_LT_EQ] = ACTIONS(5388),
    [anon_sym_DOT] = ACTIONS(5390),
    [anon_sym_EQ_GT] = ACTIONS(5388),
    [anon_sym_switch] = ACTIONS(5388),
    [anon_sym_DOT_DOT] = ACTIONS(5388),
    [anon_sym_and] = ACTIONS(5388),
    [anon_sym_or] = ACTIONS(5390),
    [anon_sym_AMP_AMP] = ACTIONS(5388),
    [anon_sym_PIPE_PIPE] = ACTIONS(5388),
    [anon_sym_QMARK_QMARK] = ACTIONS(5388),
    [anon_sym_from] = ACTIONS(5388),
    [anon_sym_into] = ACTIONS(5388),
    [anon_sym_join] = ACTIONS(5388),
    [anon_sym_on] = ACTIONS(5388),
    [anon_sym_equals] = ACTIONS(5388),
    [anon_sym_let] = ACTIONS(5388),
    [anon_sym_orderby] = ACTIONS(5388),
    [anon_sym_group] = ACTIONS(5388),
    [anon_sym_by] = ACTIONS(5388),
    [anon_sym_select] = ACTIONS(5388),
    [anon_sym_as] = ACTIONS(5388),
    [anon_sym_is] = ACTIONS(5388),
    [anon_sym_DASH_GT] = ACTIONS(5388),
    [anon_sym_with] = ACTIONS(5388),
    [aux_sym_raw_string_literal_token1] = ACTIONS(5392),
    [aux_sym_preproc_if_token3] = ACTIONS(5388),
    [aux_sym_preproc_else_token1] = ACTIONS(5388),
    [aux_sym_preproc_elif_token1] = ACTIONS(5388),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3628] = {
    [sym_attribute_list] = STATE(3740),
    [sym_preproc_region] = STATE(3628),
    [sym_preproc_endregion] = STATE(3628),
    [sym_preproc_line] = STATE(3628),
    [sym_preproc_pragma] = STATE(3628),
    [sym_preproc_nullable] = STATE(3628),
    [sym_preproc_error] = STATE(3628),
    [sym_preproc_warning] = STATE(3628),
    [sym_preproc_define] = STATE(3628),
    [sym_preproc_undef] = STATE(3628),
    [aux_sym_class_declaration_repeat1] = STATE(3628),
    [sym__identifier_token] = ACTIONS(5394),
    [anon_sym_extern] = ACTIONS(5394),
    [anon_sym_alias] = ACTIONS(5394),
    [anon_sym_global] = ACTIONS(5394),
    [anon_sym_unsafe] = ACTIONS(5394),
    [anon_sym_static] = ACTIONS(5394),
    [anon_sym_LBRACK] = ACTIONS(5396),
    [anon_sym_LPAREN] = ACTIONS(5399),
    [anon_sym_event] = ACTIONS(5394),
    [anon_sym_class] = ACTIONS(5394),
    [anon_sym_ref] = ACTIONS(5394),
    [anon_sym_struct] = ACTIONS(5394),
    [anon_sym_enum] = ACTIONS(5394),
    [anon_sym_interface] = ACTIONS(5394),
    [anon_sym_delegate] = ACTIONS(5394),
    [anon_sym_record] = ACTIONS(5394),
    [anon_sym_abstract] = ACTIONS(5394),
    [anon_sym_async] = ACTIONS(5394),
    [anon_sym_const] = ACTIONS(5394),
    [anon_sym_file] = ACTIONS(5394),
    [anon_sym_fixed] = ACTIONS(5394),
    [anon_sym_internal] = ACTIONS(5394),
    [anon_sym_new] = ACTIONS(5394),
    [anon_sym_override] = ACTIONS(5394),
    [anon_sym_partial] = ACTIONS(5394),
    [anon_sym_private] = ACTIONS(5394),
    [anon_sym_protected] = ACTIONS(5394),
    [anon_sym_public] = ACTIONS(5394),
    [anon_sym_readonly] = ACTIONS(5394),
    [anon_sym_required] = ACTIONS(5394),
    [anon_sym_sealed] = ACTIONS(5394),
    [anon_sym_virtual] = ACTIONS(5394),
    [anon_sym_volatile] = ACTIONS(5394),
    [anon_sym_where] = ACTIONS(5394),
    [anon_sym_notnull] = ACTIONS(5394),
    [anon_sym_unmanaged] = ACTIONS(5394),
    [anon_sym_TILDE] = ACTIONS(5399),
    [anon_sym_implicit] = ACTIONS(5394),
    [anon_sym_explicit] = ACTIONS(5394),
    [anon_sym_scoped] = ACTIONS(5394),
    [anon_sym_var] = ACTIONS(5394),
    [sym_predefined_type] = ACTIONS(5394),
    [anon_sym_yield] = ACTIONS(5394),
    [anon_sym_when] = ACTIONS(5394),
    [anon_sym_from] = ACTIONS(5394),
    [anon_sym_into] = ACTIONS(5394),
    [anon_sym_join] = ACTIONS(5394),
    [anon_sym_on] = ACTIONS(5394),
    [anon_sym_equals] = ACTIONS(5394),
    [anon_sym_let] = ACTIONS(5394),
    [anon_sym_orderby] = ACTIONS(5394),
    [anon_sym_ascending] = ACTIONS(5394),
    [anon_sym_descending] = ACTIONS(5394),
    [anon_sym_group] = ACTIONS(5394),
    [anon_sym_by] = ACTIONS(5394),
    [anon_sym_select] = ACTIONS(5394),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3629] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter] = STATE(8570),
    [sym__parameter_array] = STATE(8572),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7375),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(6760),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3629),
    [sym_preproc_endregion] = STATE(3629),
    [sym_preproc_line] = STATE(3629),
    [sym_preproc_pragma] = STATE(3629),
    [sym_preproc_nullable] = STATE(3629),
    [sym_preproc_error] = STATE(3629),
    [sym_preproc_warning] = STATE(3629),
    [sym_preproc_define] = STATE(3629),
    [sym_preproc_undef] = STATE(3629),
    [aux_sym_class_declaration_repeat1] = STATE(3802),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LBRACK] = ACTIONS(5307),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_RPAREN] = ACTIONS(2603),
    [anon_sym_ref] = ACTIONS(5309),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_in] = ACTIONS(1113),
    [anon_sym_out] = ACTIONS(1113),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_this] = ACTIONS(1113),
    [anon_sym_scoped] = ACTIONS(5321),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3630] = {
    [sym_preproc_region] = STATE(3630),
    [sym_preproc_endregion] = STATE(3630),
    [sym_preproc_line] = STATE(3630),
    [sym_preproc_pragma] = STATE(3630),
    [sym_preproc_nullable] = STATE(3630),
    [sym_preproc_error] = STATE(3630),
    [sym_preproc_warning] = STATE(3630),
    [sym_preproc_define] = STATE(3630),
    [sym_preproc_undef] = STATE(3630),
    [anon_sym_SEMI] = ACTIONS(5401),
    [anon_sym_LBRACK] = ACTIONS(5401),
    [anon_sym_COLON] = ACTIONS(5401),
    [anon_sym_COMMA] = ACTIONS(5401),
    [anon_sym_RBRACK] = ACTIONS(5401),
    [anon_sym_LPAREN] = ACTIONS(5401),
    [anon_sym_RPAREN] = ACTIONS(5401),
    [anon_sym_RBRACE] = ACTIONS(5401),
    [anon_sym_LT] = ACTIONS(5403),
    [anon_sym_GT] = ACTIONS(5403),
    [anon_sym_in] = ACTIONS(5403),
    [anon_sym_where] = ACTIONS(5401),
    [anon_sym_QMARK] = ACTIONS(5403),
    [anon_sym_BANG] = ACTIONS(5403),
    [anon_sym_PLUS_PLUS] = ACTIONS(5401),
    [anon_sym_DASH_DASH] = ACTIONS(5401),
    [anon_sym_PLUS] = ACTIONS(5403),
    [anon_sym_DASH] = ACTIONS(5403),
    [anon_sym_STAR] = ACTIONS(5401),
    [anon_sym_SLASH] = ACTIONS(5403),
    [anon_sym_PERCENT] = ACTIONS(5401),
    [anon_sym_CARET] = ACTIONS(5401),
    [anon_sym_PIPE] = ACTIONS(5403),
    [anon_sym_AMP] = ACTIONS(5403),
    [anon_sym_LT_LT] = ACTIONS(5401),
    [anon_sym_GT_GT] = ACTIONS(5403),
    [anon_sym_GT_GT_GT] = ACTIONS(5401),
    [anon_sym_EQ_EQ] = ACTIONS(5401),
    [anon_sym_BANG_EQ] = ACTIONS(5401),
    [anon_sym_GT_EQ] = ACTIONS(5401),
    [anon_sym_LT_EQ] = ACTIONS(5401),
    [anon_sym_DOT] = ACTIONS(5403),
    [anon_sym_EQ_GT] = ACTIONS(5401),
    [anon_sym_switch] = ACTIONS(5401),
    [anon_sym_DOT_DOT] = ACTIONS(5401),
    [anon_sym_and] = ACTIONS(5401),
    [anon_sym_or] = ACTIONS(5403),
    [anon_sym_AMP_AMP] = ACTIONS(5401),
    [anon_sym_PIPE_PIPE] = ACTIONS(5401),
    [anon_sym_QMARK_QMARK] = ACTIONS(5401),
    [anon_sym_from] = ACTIONS(5401),
    [anon_sym_into] = ACTIONS(5401),
    [anon_sym_join] = ACTIONS(5401),
    [anon_sym_on] = ACTIONS(5401),
    [anon_sym_equals] = ACTIONS(5401),
    [anon_sym_let] = ACTIONS(5401),
    [anon_sym_orderby] = ACTIONS(5401),
    [anon_sym_group] = ACTIONS(5401),
    [anon_sym_by] = ACTIONS(5401),
    [anon_sym_select] = ACTIONS(5401),
    [anon_sym_as] = ACTIONS(5401),
    [anon_sym_is] = ACTIONS(5401),
    [anon_sym_DASH_GT] = ACTIONS(5401),
    [anon_sym_with] = ACTIONS(5401),
    [aux_sym_preproc_if_token3] = ACTIONS(5401),
    [aux_sym_preproc_else_token1] = ACTIONS(5401),
    [aux_sym_preproc_elif_token1] = ACTIONS(5401),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3631] = {
    [sym_preproc_region] = STATE(3631),
    [sym_preproc_endregion] = STATE(3631),
    [sym_preproc_line] = STATE(3631),
    [sym_preproc_pragma] = STATE(3631),
    [sym_preproc_nullable] = STATE(3631),
    [sym_preproc_error] = STATE(3631),
    [sym_preproc_warning] = STATE(3631),
    [sym_preproc_define] = STATE(3631),
    [sym_preproc_undef] = STATE(3631),
    [anon_sym_SEMI] = ACTIONS(4494),
    [anon_sym_LBRACK] = ACTIONS(4593),
    [anon_sym_COLON] = ACTIONS(4494),
    [anon_sym_COMMA] = ACTIONS(4494),
    [anon_sym_RBRACK] = ACTIONS(4494),
    [anon_sym_LPAREN] = ACTIONS(4494),
    [anon_sym_RPAREN] = ACTIONS(4494),
    [anon_sym_LBRACE] = ACTIONS(4494),
    [anon_sym_RBRACE] = ACTIONS(4494),
    [anon_sym_LT] = ACTIONS(4492),
    [anon_sym_GT] = ACTIONS(4492),
    [anon_sym_in] = ACTIONS(4494),
    [anon_sym_where] = ACTIONS(4494),
    [anon_sym_QMARK] = ACTIONS(5405),
    [anon_sym_BANG] = ACTIONS(4492),
    [anon_sym_PLUS_PLUS] = ACTIONS(4494),
    [anon_sym_DASH_DASH] = ACTIONS(4494),
    [anon_sym_PLUS] = ACTIONS(4492),
    [anon_sym_DASH] = ACTIONS(4492),
    [anon_sym_STAR] = ACTIONS(4599),
    [anon_sym_SLASH] = ACTIONS(4492),
    [anon_sym_PERCENT] = ACTIONS(4494),
    [anon_sym_CARET] = ACTIONS(4494),
    [anon_sym_PIPE] = ACTIONS(4492),
    [anon_sym_AMP] = ACTIONS(4492),
    [anon_sym_LT_LT] = ACTIONS(4494),
    [anon_sym_GT_GT] = ACTIONS(4492),
    [anon_sym_GT_GT_GT] = ACTIONS(4494),
    [anon_sym_EQ_EQ] = ACTIONS(4494),
    [anon_sym_BANG_EQ] = ACTIONS(4494),
    [anon_sym_GT_EQ] = ACTIONS(4494),
    [anon_sym_LT_EQ] = ACTIONS(4494),
    [anon_sym_DOT] = ACTIONS(4492),
    [anon_sym_EQ_GT] = ACTIONS(4494),
    [anon_sym_switch] = ACTIONS(4494),
    [anon_sym_DOT_DOT] = ACTIONS(4494),
    [anon_sym_and] = ACTIONS(4494),
    [anon_sym_or] = ACTIONS(4492),
    [anon_sym_AMP_AMP] = ACTIONS(4494),
    [anon_sym_PIPE_PIPE] = ACTIONS(4494),
    [anon_sym_QMARK_QMARK] = ACTIONS(4494),
    [anon_sym_from] = ACTIONS(4494),
    [anon_sym_join] = ACTIONS(4494),
    [anon_sym_on] = ACTIONS(4494),
    [anon_sym_equals] = ACTIONS(4494),
    [anon_sym_let] = ACTIONS(4494),
    [anon_sym_orderby] = ACTIONS(4494),
    [anon_sym_group] = ACTIONS(4494),
    [anon_sym_by] = ACTIONS(4494),
    [anon_sym_select] = ACTIONS(4494),
    [anon_sym_as] = ACTIONS(4494),
    [anon_sym_is] = ACTIONS(4494),
    [anon_sym_DASH_GT] = ACTIONS(4494),
    [anon_sym_with] = ACTIONS(4494),
    [aux_sym_preproc_if_token3] = ACTIONS(4494),
    [aux_sym_preproc_else_token1] = ACTIONS(4494),
    [aux_sym_preproc_elif_token1] = ACTIONS(4494),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3632] = {
    [sym_preproc_region] = STATE(3632),
    [sym_preproc_endregion] = STATE(3632),
    [sym_preproc_line] = STATE(3632),
    [sym_preproc_pragma] = STATE(3632),
    [sym_preproc_nullable] = STATE(3632),
    [sym_preproc_error] = STATE(3632),
    [sym_preproc_warning] = STATE(3632),
    [sym_preproc_define] = STATE(3632),
    [sym_preproc_undef] = STATE(3632),
    [anon_sym_SEMI] = ACTIONS(4500),
    [anon_sym_LBRACK] = ACTIONS(4500),
    [anon_sym_COLON] = ACTIONS(4500),
    [anon_sym_COMMA] = ACTIONS(4500),
    [anon_sym_RBRACK] = ACTIONS(4500),
    [anon_sym_LPAREN] = ACTIONS(4500),
    [anon_sym_RPAREN] = ACTIONS(4500),
    [anon_sym_LBRACE] = ACTIONS(4500),
    [anon_sym_RBRACE] = ACTIONS(4500),
    [anon_sym_LT] = ACTIONS(4498),
    [anon_sym_GT] = ACTIONS(4498),
    [anon_sym_in] = ACTIONS(4500),
    [anon_sym_where] = ACTIONS(4500),
    [anon_sym_QMARK] = ACTIONS(4498),
    [anon_sym_BANG] = ACTIONS(4498),
    [anon_sym_PLUS_PLUS] = ACTIONS(4500),
    [anon_sym_DASH_DASH] = ACTIONS(4500),
    [anon_sym_PLUS] = ACTIONS(4498),
    [anon_sym_DASH] = ACTIONS(4498),
    [anon_sym_STAR] = ACTIONS(4500),
    [anon_sym_SLASH] = ACTIONS(4498),
    [anon_sym_PERCENT] = ACTIONS(4500),
    [anon_sym_CARET] = ACTIONS(4500),
    [anon_sym_PIPE] = ACTIONS(4498),
    [anon_sym_AMP] = ACTIONS(4498),
    [anon_sym_LT_LT] = ACTIONS(4500),
    [anon_sym_GT_GT] = ACTIONS(4498),
    [anon_sym_GT_GT_GT] = ACTIONS(4500),
    [anon_sym_EQ_EQ] = ACTIONS(4500),
    [anon_sym_BANG_EQ] = ACTIONS(4500),
    [anon_sym_GT_EQ] = ACTIONS(4500),
    [anon_sym_LT_EQ] = ACTIONS(4500),
    [anon_sym_DOT] = ACTIONS(4498),
    [anon_sym_EQ_GT] = ACTIONS(4500),
    [anon_sym_switch] = ACTIONS(4500),
    [anon_sym_DOT_DOT] = ACTIONS(4500),
    [anon_sym_and] = ACTIONS(4500),
    [anon_sym_or] = ACTIONS(4498),
    [anon_sym_AMP_AMP] = ACTIONS(4500),
    [anon_sym_PIPE_PIPE] = ACTIONS(4500),
    [anon_sym_QMARK_QMARK] = ACTIONS(4500),
    [anon_sym_from] = ACTIONS(4500),
    [anon_sym_join] = ACTIONS(4500),
    [anon_sym_on] = ACTIONS(4500),
    [anon_sym_equals] = ACTIONS(4500),
    [anon_sym_let] = ACTIONS(4500),
    [anon_sym_orderby] = ACTIONS(4500),
    [anon_sym_group] = ACTIONS(4500),
    [anon_sym_by] = ACTIONS(4500),
    [anon_sym_select] = ACTIONS(4500),
    [anon_sym_as] = ACTIONS(4500),
    [anon_sym_is] = ACTIONS(4500),
    [anon_sym_DASH_GT] = ACTIONS(4500),
    [anon_sym_with] = ACTIONS(4500),
    [aux_sym_preproc_if_token3] = ACTIONS(4500),
    [aux_sym_preproc_else_token1] = ACTIONS(4500),
    [aux_sym_preproc_elif_token1] = ACTIONS(4500),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3633] = {
    [sym_preproc_region] = STATE(3633),
    [sym_preproc_endregion] = STATE(3633),
    [sym_preproc_line] = STATE(3633),
    [sym_preproc_pragma] = STATE(3633),
    [sym_preproc_nullable] = STATE(3633),
    [sym_preproc_error] = STATE(3633),
    [sym_preproc_warning] = STATE(3633),
    [sym_preproc_define] = STATE(3633),
    [sym_preproc_undef] = STATE(3633),
    [anon_sym_SEMI] = ACTIONS(3001),
    [anon_sym_LBRACK] = ACTIONS(3001),
    [anon_sym_COLON] = ACTIONS(3001),
    [anon_sym_COMMA] = ACTIONS(3001),
    [anon_sym_RBRACK] = ACTIONS(3001),
    [anon_sym_LPAREN] = ACTIONS(3001),
    [anon_sym_RPAREN] = ACTIONS(3001),
    [anon_sym_RBRACE] = ACTIONS(3001),
    [anon_sym_LT] = ACTIONS(2999),
    [anon_sym_GT] = ACTIONS(2999),
    [anon_sym_in] = ACTIONS(2999),
    [anon_sym_where] = ACTIONS(3001),
    [anon_sym_QMARK] = ACTIONS(2999),
    [anon_sym_BANG] = ACTIONS(2999),
    [anon_sym_PLUS_PLUS] = ACTIONS(3001),
    [anon_sym_DASH_DASH] = ACTIONS(3001),
    [anon_sym_PLUS] = ACTIONS(2999),
    [anon_sym_DASH] = ACTIONS(2999),
    [anon_sym_STAR] = ACTIONS(3001),
    [anon_sym_SLASH] = ACTIONS(2999),
    [anon_sym_PERCENT] = ACTIONS(3001),
    [anon_sym_CARET] = ACTIONS(3001),
    [anon_sym_PIPE] = ACTIONS(2999),
    [anon_sym_AMP] = ACTIONS(2999),
    [anon_sym_LT_LT] = ACTIONS(3001),
    [anon_sym_GT_GT] = ACTIONS(2999),
    [anon_sym_GT_GT_GT] = ACTIONS(3001),
    [anon_sym_EQ_EQ] = ACTIONS(3001),
    [anon_sym_BANG_EQ] = ACTIONS(3001),
    [anon_sym_GT_EQ] = ACTIONS(3001),
    [anon_sym_LT_EQ] = ACTIONS(3001),
    [anon_sym_DOT] = ACTIONS(2999),
    [anon_sym_EQ_GT] = ACTIONS(3001),
    [anon_sym_switch] = ACTIONS(3001),
    [anon_sym_DOT_DOT] = ACTIONS(3001),
    [anon_sym_and] = ACTIONS(3001),
    [anon_sym_or] = ACTIONS(2999),
    [anon_sym_AMP_AMP] = ACTIONS(3001),
    [anon_sym_PIPE_PIPE] = ACTIONS(3001),
    [anon_sym_QMARK_QMARK] = ACTIONS(3001),
    [anon_sym_from] = ACTIONS(3001),
    [anon_sym_into] = ACTIONS(3001),
    [anon_sym_join] = ACTIONS(3001),
    [anon_sym_on] = ACTIONS(3001),
    [anon_sym_equals] = ACTIONS(3001),
    [anon_sym_let] = ACTIONS(3001),
    [anon_sym_orderby] = ACTIONS(3001),
    [anon_sym_group] = ACTIONS(3001),
    [anon_sym_by] = ACTIONS(3001),
    [anon_sym_select] = ACTIONS(3001),
    [anon_sym_as] = ACTIONS(3001),
    [anon_sym_is] = ACTIONS(3001),
    [anon_sym_DASH_GT] = ACTIONS(3001),
    [anon_sym_with] = ACTIONS(3001),
    [aux_sym_preproc_if_token3] = ACTIONS(3001),
    [aux_sym_preproc_else_token1] = ACTIONS(3001),
    [aux_sym_preproc_elif_token1] = ACTIONS(3001),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3634] = {
    [sym_preproc_region] = STATE(3634),
    [sym_preproc_endregion] = STATE(3634),
    [sym_preproc_line] = STATE(3634),
    [sym_preproc_pragma] = STATE(3634),
    [sym_preproc_nullable] = STATE(3634),
    [sym_preproc_error] = STATE(3634),
    [sym_preproc_warning] = STATE(3634),
    [sym_preproc_define] = STATE(3634),
    [sym_preproc_undef] = STATE(3634),
    [anon_sym_SEMI] = ACTIONS(5408),
    [anon_sym_LBRACK] = ACTIONS(5408),
    [anon_sym_COLON] = ACTIONS(5408),
    [anon_sym_COMMA] = ACTIONS(5408),
    [anon_sym_RBRACK] = ACTIONS(5408),
    [anon_sym_LPAREN] = ACTIONS(5408),
    [anon_sym_RPAREN] = ACTIONS(5408),
    [anon_sym_RBRACE] = ACTIONS(5408),
    [anon_sym_LT] = ACTIONS(5410),
    [anon_sym_GT] = ACTIONS(5410),
    [anon_sym_in] = ACTIONS(5410),
    [anon_sym_where] = ACTIONS(5408),
    [anon_sym_QMARK] = ACTIONS(5410),
    [anon_sym_BANG] = ACTIONS(5410),
    [anon_sym_PLUS_PLUS] = ACTIONS(5408),
    [anon_sym_DASH_DASH] = ACTIONS(5408),
    [anon_sym_PLUS] = ACTIONS(5410),
    [anon_sym_DASH] = ACTIONS(5410),
    [anon_sym_STAR] = ACTIONS(5408),
    [anon_sym_SLASH] = ACTIONS(5410),
    [anon_sym_PERCENT] = ACTIONS(5408),
    [anon_sym_CARET] = ACTIONS(5408),
    [anon_sym_PIPE] = ACTIONS(5410),
    [anon_sym_AMP] = ACTIONS(5410),
    [anon_sym_LT_LT] = ACTIONS(5408),
    [anon_sym_GT_GT] = ACTIONS(5410),
    [anon_sym_GT_GT_GT] = ACTIONS(5408),
    [anon_sym_EQ_EQ] = ACTIONS(5408),
    [anon_sym_BANG_EQ] = ACTIONS(5408),
    [anon_sym_GT_EQ] = ACTIONS(5408),
    [anon_sym_LT_EQ] = ACTIONS(5408),
    [anon_sym_DOT] = ACTIONS(5410),
    [anon_sym_EQ_GT] = ACTIONS(5408),
    [anon_sym_switch] = ACTIONS(5408),
    [anon_sym_DOT_DOT] = ACTIONS(5408),
    [anon_sym_and] = ACTIONS(5408),
    [anon_sym_or] = ACTIONS(5410),
    [anon_sym_AMP_AMP] = ACTIONS(5408),
    [anon_sym_PIPE_PIPE] = ACTIONS(5408),
    [anon_sym_QMARK_QMARK] = ACTIONS(5408),
    [anon_sym_from] = ACTIONS(5408),
    [anon_sym_into] = ACTIONS(5408),
    [anon_sym_join] = ACTIONS(5408),
    [anon_sym_on] = ACTIONS(5408),
    [anon_sym_equals] = ACTIONS(5408),
    [anon_sym_let] = ACTIONS(5408),
    [anon_sym_orderby] = ACTIONS(5408),
    [anon_sym_group] = ACTIONS(5408),
    [anon_sym_by] = ACTIONS(5408),
    [anon_sym_select] = ACTIONS(5408),
    [anon_sym_as] = ACTIONS(5408),
    [anon_sym_is] = ACTIONS(5408),
    [anon_sym_DASH_GT] = ACTIONS(5408),
    [anon_sym_with] = ACTIONS(5408),
    [aux_sym_preproc_if_token3] = ACTIONS(5408),
    [aux_sym_preproc_else_token1] = ACTIONS(5408),
    [aux_sym_preproc_elif_token1] = ACTIONS(5408),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3635] = {
    [sym_preproc_region] = STATE(3635),
    [sym_preproc_endregion] = STATE(3635),
    [sym_preproc_line] = STATE(3635),
    [sym_preproc_pragma] = STATE(3635),
    [sym_preproc_nullable] = STATE(3635),
    [sym_preproc_error] = STATE(3635),
    [sym_preproc_warning] = STATE(3635),
    [sym_preproc_define] = STATE(3635),
    [sym_preproc_undef] = STATE(3635),
    [anon_sym_SEMI] = ACTIONS(3039),
    [anon_sym_LBRACK] = ACTIONS(3039),
    [anon_sym_COLON] = ACTIONS(3039),
    [anon_sym_COMMA] = ACTIONS(3039),
    [anon_sym_RBRACK] = ACTIONS(3039),
    [anon_sym_LPAREN] = ACTIONS(3039),
    [anon_sym_RPAREN] = ACTIONS(3039),
    [anon_sym_RBRACE] = ACTIONS(3039),
    [anon_sym_LT] = ACTIONS(3037),
    [anon_sym_GT] = ACTIONS(3037),
    [anon_sym_in] = ACTIONS(3037),
    [anon_sym_where] = ACTIONS(3039),
    [anon_sym_QMARK] = ACTIONS(3037),
    [anon_sym_BANG] = ACTIONS(3037),
    [anon_sym_PLUS_PLUS] = ACTIONS(3039),
    [anon_sym_DASH_DASH] = ACTIONS(3039),
    [anon_sym_PLUS] = ACTIONS(3037),
    [anon_sym_DASH] = ACTIONS(3037),
    [anon_sym_STAR] = ACTIONS(3039),
    [anon_sym_SLASH] = ACTIONS(3037),
    [anon_sym_PERCENT] = ACTIONS(3039),
    [anon_sym_CARET] = ACTIONS(3039),
    [anon_sym_PIPE] = ACTIONS(3037),
    [anon_sym_AMP] = ACTIONS(3037),
    [anon_sym_LT_LT] = ACTIONS(3039),
    [anon_sym_GT_GT] = ACTIONS(3037),
    [anon_sym_GT_GT_GT] = ACTIONS(3039),
    [anon_sym_EQ_EQ] = ACTIONS(3039),
    [anon_sym_BANG_EQ] = ACTIONS(3039),
    [anon_sym_GT_EQ] = ACTIONS(3039),
    [anon_sym_LT_EQ] = ACTIONS(3039),
    [anon_sym_DOT] = ACTIONS(3037),
    [anon_sym_EQ_GT] = ACTIONS(3039),
    [anon_sym_switch] = ACTIONS(3039),
    [anon_sym_DOT_DOT] = ACTIONS(3039),
    [anon_sym_and] = ACTIONS(3039),
    [anon_sym_or] = ACTIONS(3037),
    [anon_sym_AMP_AMP] = ACTIONS(3039),
    [anon_sym_PIPE_PIPE] = ACTIONS(3039),
    [anon_sym_QMARK_QMARK] = ACTIONS(3039),
    [anon_sym_from] = ACTIONS(3039),
    [anon_sym_into] = ACTIONS(3039),
    [anon_sym_join] = ACTIONS(3039),
    [anon_sym_on] = ACTIONS(3039),
    [anon_sym_equals] = ACTIONS(3039),
    [anon_sym_let] = ACTIONS(3039),
    [anon_sym_orderby] = ACTIONS(3039),
    [anon_sym_group] = ACTIONS(3039),
    [anon_sym_by] = ACTIONS(3039),
    [anon_sym_select] = ACTIONS(3039),
    [anon_sym_as] = ACTIONS(3039),
    [anon_sym_is] = ACTIONS(3039),
    [anon_sym_DASH_GT] = ACTIONS(3039),
    [anon_sym_with] = ACTIONS(3039),
    [aux_sym_preproc_if_token3] = ACTIONS(3039),
    [aux_sym_preproc_else_token1] = ACTIONS(3039),
    [aux_sym_preproc_elif_token1] = ACTIONS(3039),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3636] = {
    [sym_preproc_region] = STATE(3636),
    [sym_preproc_endregion] = STATE(3636),
    [sym_preproc_line] = STATE(3636),
    [sym_preproc_pragma] = STATE(3636),
    [sym_preproc_nullable] = STATE(3636),
    [sym_preproc_error] = STATE(3636),
    [sym_preproc_warning] = STATE(3636),
    [sym_preproc_define] = STATE(3636),
    [sym_preproc_undef] = STATE(3636),
    [anon_sym_SEMI] = ACTIONS(5412),
    [anon_sym_LBRACK] = ACTIONS(5412),
    [anon_sym_COLON] = ACTIONS(5412),
    [anon_sym_COMMA] = ACTIONS(5412),
    [anon_sym_RBRACK] = ACTIONS(5412),
    [anon_sym_LPAREN] = ACTIONS(5412),
    [anon_sym_RPAREN] = ACTIONS(5412),
    [anon_sym_RBRACE] = ACTIONS(5412),
    [anon_sym_LT] = ACTIONS(5414),
    [anon_sym_GT] = ACTIONS(5414),
    [anon_sym_in] = ACTIONS(5414),
    [anon_sym_where] = ACTIONS(5412),
    [anon_sym_QMARK] = ACTIONS(5414),
    [anon_sym_BANG] = ACTIONS(5414),
    [anon_sym_PLUS_PLUS] = ACTIONS(5412),
    [anon_sym_DASH_DASH] = ACTIONS(5412),
    [anon_sym_PLUS] = ACTIONS(5414),
    [anon_sym_DASH] = ACTIONS(5414),
    [anon_sym_STAR] = ACTIONS(5412),
    [anon_sym_SLASH] = ACTIONS(5414),
    [anon_sym_PERCENT] = ACTIONS(5412),
    [anon_sym_CARET] = ACTIONS(5412),
    [anon_sym_PIPE] = ACTIONS(5414),
    [anon_sym_AMP] = ACTIONS(5414),
    [anon_sym_LT_LT] = ACTIONS(5412),
    [anon_sym_GT_GT] = ACTIONS(5414),
    [anon_sym_GT_GT_GT] = ACTIONS(5412),
    [anon_sym_EQ_EQ] = ACTIONS(5412),
    [anon_sym_BANG_EQ] = ACTIONS(5412),
    [anon_sym_GT_EQ] = ACTIONS(5412),
    [anon_sym_LT_EQ] = ACTIONS(5412),
    [anon_sym_DOT] = ACTIONS(5414),
    [anon_sym_EQ_GT] = ACTIONS(5412),
    [anon_sym_switch] = ACTIONS(5412),
    [anon_sym_DOT_DOT] = ACTIONS(5412),
    [anon_sym_and] = ACTIONS(5412),
    [anon_sym_or] = ACTIONS(5414),
    [anon_sym_AMP_AMP] = ACTIONS(5412),
    [anon_sym_PIPE_PIPE] = ACTIONS(5412),
    [anon_sym_QMARK_QMARK] = ACTIONS(5412),
    [anon_sym_from] = ACTIONS(5412),
    [anon_sym_into] = ACTIONS(5412),
    [anon_sym_join] = ACTIONS(5412),
    [anon_sym_on] = ACTIONS(5412),
    [anon_sym_equals] = ACTIONS(5412),
    [anon_sym_let] = ACTIONS(5412),
    [anon_sym_orderby] = ACTIONS(5412),
    [anon_sym_group] = ACTIONS(5412),
    [anon_sym_by] = ACTIONS(5412),
    [anon_sym_select] = ACTIONS(5412),
    [anon_sym_as] = ACTIONS(5412),
    [anon_sym_is] = ACTIONS(5412),
    [anon_sym_DASH_GT] = ACTIONS(5412),
    [anon_sym_with] = ACTIONS(5412),
    [aux_sym_preproc_if_token3] = ACTIONS(5412),
    [aux_sym_preproc_else_token1] = ACTIONS(5412),
    [aux_sym_preproc_elif_token1] = ACTIONS(5412),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3637] = {
    [sym_preproc_region] = STATE(3637),
    [sym_preproc_endregion] = STATE(3637),
    [sym_preproc_line] = STATE(3637),
    [sym_preproc_pragma] = STATE(3637),
    [sym_preproc_nullable] = STATE(3637),
    [sym_preproc_error] = STATE(3637),
    [sym_preproc_warning] = STATE(3637),
    [sym_preproc_define] = STATE(3637),
    [sym_preproc_undef] = STATE(3637),
    [anon_sym_SEMI] = ACTIONS(5416),
    [anon_sym_LBRACK] = ACTIONS(5416),
    [anon_sym_COLON] = ACTIONS(5416),
    [anon_sym_COMMA] = ACTIONS(5416),
    [anon_sym_RBRACK] = ACTIONS(5416),
    [anon_sym_LPAREN] = ACTIONS(5416),
    [anon_sym_RPAREN] = ACTIONS(5416),
    [anon_sym_RBRACE] = ACTIONS(5416),
    [anon_sym_LT] = ACTIONS(5418),
    [anon_sym_GT] = ACTIONS(5418),
    [anon_sym_in] = ACTIONS(5418),
    [anon_sym_where] = ACTIONS(5416),
    [anon_sym_QMARK] = ACTIONS(5418),
    [anon_sym_BANG] = ACTIONS(5418),
    [anon_sym_PLUS_PLUS] = ACTIONS(5416),
    [anon_sym_DASH_DASH] = ACTIONS(5416),
    [anon_sym_PLUS] = ACTIONS(5418),
    [anon_sym_DASH] = ACTIONS(5418),
    [anon_sym_STAR] = ACTIONS(5416),
    [anon_sym_SLASH] = ACTIONS(5418),
    [anon_sym_PERCENT] = ACTIONS(5416),
    [anon_sym_CARET] = ACTIONS(5416),
    [anon_sym_PIPE] = ACTIONS(5418),
    [anon_sym_AMP] = ACTIONS(5418),
    [anon_sym_LT_LT] = ACTIONS(5416),
    [anon_sym_GT_GT] = ACTIONS(5418),
    [anon_sym_GT_GT_GT] = ACTIONS(5416),
    [anon_sym_EQ_EQ] = ACTIONS(5416),
    [anon_sym_BANG_EQ] = ACTIONS(5416),
    [anon_sym_GT_EQ] = ACTIONS(5416),
    [anon_sym_LT_EQ] = ACTIONS(5416),
    [anon_sym_DOT] = ACTIONS(5418),
    [anon_sym_EQ_GT] = ACTIONS(5416),
    [anon_sym_switch] = ACTIONS(5416),
    [anon_sym_DOT_DOT] = ACTIONS(5416),
    [anon_sym_and] = ACTIONS(5416),
    [anon_sym_or] = ACTIONS(5418),
    [anon_sym_AMP_AMP] = ACTIONS(5416),
    [anon_sym_PIPE_PIPE] = ACTIONS(5416),
    [anon_sym_QMARK_QMARK] = ACTIONS(5416),
    [anon_sym_from] = ACTIONS(5416),
    [anon_sym_into] = ACTIONS(5416),
    [anon_sym_join] = ACTIONS(5416),
    [anon_sym_on] = ACTIONS(5416),
    [anon_sym_equals] = ACTIONS(5416),
    [anon_sym_let] = ACTIONS(5416),
    [anon_sym_orderby] = ACTIONS(5416),
    [anon_sym_group] = ACTIONS(5416),
    [anon_sym_by] = ACTIONS(5416),
    [anon_sym_select] = ACTIONS(5416),
    [anon_sym_as] = ACTIONS(5416),
    [anon_sym_is] = ACTIONS(5416),
    [anon_sym_DASH_GT] = ACTIONS(5416),
    [anon_sym_with] = ACTIONS(5416),
    [aux_sym_preproc_if_token3] = ACTIONS(5416),
    [aux_sym_preproc_else_token1] = ACTIONS(5416),
    [aux_sym_preproc_elif_token1] = ACTIONS(5416),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3638] = {
    [sym_preproc_region] = STATE(3638),
    [sym_preproc_endregion] = STATE(3638),
    [sym_preproc_line] = STATE(3638),
    [sym_preproc_pragma] = STATE(3638),
    [sym_preproc_nullable] = STATE(3638),
    [sym_preproc_error] = STATE(3638),
    [sym_preproc_warning] = STATE(3638),
    [sym_preproc_define] = STATE(3638),
    [sym_preproc_undef] = STATE(3638),
    [anon_sym_SEMI] = ACTIONS(5382),
    [anon_sym_LBRACK] = ACTIONS(5382),
    [anon_sym_COLON] = ACTIONS(5382),
    [anon_sym_COMMA] = ACTIONS(5382),
    [anon_sym_RBRACK] = ACTIONS(5382),
    [anon_sym_LPAREN] = ACTIONS(5382),
    [anon_sym_RPAREN] = ACTIONS(5382),
    [anon_sym_RBRACE] = ACTIONS(5382),
    [anon_sym_LT] = ACTIONS(5384),
    [anon_sym_GT] = ACTIONS(5384),
    [anon_sym_in] = ACTIONS(5384),
    [anon_sym_where] = ACTIONS(5382),
    [anon_sym_QMARK] = ACTIONS(5384),
    [anon_sym_BANG] = ACTIONS(5384),
    [anon_sym_PLUS_PLUS] = ACTIONS(5382),
    [anon_sym_DASH_DASH] = ACTIONS(5382),
    [anon_sym_PLUS] = ACTIONS(5384),
    [anon_sym_DASH] = ACTIONS(5384),
    [anon_sym_STAR] = ACTIONS(5382),
    [anon_sym_SLASH] = ACTIONS(5384),
    [anon_sym_PERCENT] = ACTIONS(5382),
    [anon_sym_CARET] = ACTIONS(5382),
    [anon_sym_PIPE] = ACTIONS(5384),
    [anon_sym_AMP] = ACTIONS(5384),
    [anon_sym_LT_LT] = ACTIONS(5382),
    [anon_sym_GT_GT] = ACTIONS(5384),
    [anon_sym_GT_GT_GT] = ACTIONS(5382),
    [anon_sym_EQ_EQ] = ACTIONS(5382),
    [anon_sym_BANG_EQ] = ACTIONS(5382),
    [anon_sym_GT_EQ] = ACTIONS(5382),
    [anon_sym_LT_EQ] = ACTIONS(5382),
    [anon_sym_DOT] = ACTIONS(5384),
    [anon_sym_EQ_GT] = ACTIONS(5382),
    [anon_sym_switch] = ACTIONS(5382),
    [anon_sym_DOT_DOT] = ACTIONS(5382),
    [anon_sym_and] = ACTIONS(5382),
    [anon_sym_or] = ACTIONS(5384),
    [anon_sym_AMP_AMP] = ACTIONS(5382),
    [anon_sym_PIPE_PIPE] = ACTIONS(5382),
    [anon_sym_QMARK_QMARK] = ACTIONS(5382),
    [anon_sym_from] = ACTIONS(5382),
    [anon_sym_into] = ACTIONS(5382),
    [anon_sym_join] = ACTIONS(5382),
    [anon_sym_on] = ACTIONS(5382),
    [anon_sym_equals] = ACTIONS(5382),
    [anon_sym_let] = ACTIONS(5382),
    [anon_sym_orderby] = ACTIONS(5382),
    [anon_sym_group] = ACTIONS(5382),
    [anon_sym_by] = ACTIONS(5382),
    [anon_sym_select] = ACTIONS(5382),
    [anon_sym_as] = ACTIONS(5382),
    [anon_sym_is] = ACTIONS(5382),
    [anon_sym_DASH_GT] = ACTIONS(5382),
    [anon_sym_with] = ACTIONS(5382),
    [aux_sym_preproc_if_token3] = ACTIONS(5382),
    [aux_sym_preproc_else_token1] = ACTIONS(5382),
    [aux_sym_preproc_elif_token1] = ACTIONS(5382),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3639] = {
    [sym_preproc_region] = STATE(3639),
    [sym_preproc_endregion] = STATE(3639),
    [sym_preproc_line] = STATE(3639),
    [sym_preproc_pragma] = STATE(3639),
    [sym_preproc_nullable] = STATE(3639),
    [sym_preproc_error] = STATE(3639),
    [sym_preproc_warning] = STATE(3639),
    [sym_preproc_define] = STATE(3639),
    [sym_preproc_undef] = STATE(3639),
    [anon_sym_SEMI] = ACTIONS(4472),
    [anon_sym_LBRACK] = ACTIONS(4472),
    [anon_sym_COLON] = ACTIONS(4472),
    [anon_sym_COMMA] = ACTIONS(4472),
    [anon_sym_RBRACK] = ACTIONS(4472),
    [anon_sym_LPAREN] = ACTIONS(4472),
    [anon_sym_RPAREN] = ACTIONS(4472),
    [anon_sym_LBRACE] = ACTIONS(4472),
    [anon_sym_RBRACE] = ACTIONS(4472),
    [anon_sym_LT] = ACTIONS(4470),
    [anon_sym_GT] = ACTIONS(4470),
    [anon_sym_in] = ACTIONS(4472),
    [anon_sym_where] = ACTIONS(4472),
    [anon_sym_QMARK] = ACTIONS(4470),
    [anon_sym_BANG] = ACTIONS(4470),
    [anon_sym_PLUS_PLUS] = ACTIONS(4472),
    [anon_sym_DASH_DASH] = ACTIONS(4472),
    [anon_sym_PLUS] = ACTIONS(4470),
    [anon_sym_DASH] = ACTIONS(4470),
    [anon_sym_STAR] = ACTIONS(4472),
    [anon_sym_SLASH] = ACTIONS(4470),
    [anon_sym_PERCENT] = ACTIONS(4472),
    [anon_sym_CARET] = ACTIONS(4472),
    [anon_sym_PIPE] = ACTIONS(4470),
    [anon_sym_AMP] = ACTIONS(4470),
    [anon_sym_LT_LT] = ACTIONS(4472),
    [anon_sym_GT_GT] = ACTIONS(4470),
    [anon_sym_GT_GT_GT] = ACTIONS(4472),
    [anon_sym_EQ_EQ] = ACTIONS(4472),
    [anon_sym_BANG_EQ] = ACTIONS(4472),
    [anon_sym_GT_EQ] = ACTIONS(4472),
    [anon_sym_LT_EQ] = ACTIONS(4472),
    [anon_sym_DOT] = ACTIONS(4470),
    [anon_sym_EQ_GT] = ACTIONS(4472),
    [anon_sym_switch] = ACTIONS(4472),
    [anon_sym_DOT_DOT] = ACTIONS(4472),
    [anon_sym_and] = ACTIONS(4472),
    [anon_sym_or] = ACTIONS(4470),
    [anon_sym_AMP_AMP] = ACTIONS(4472),
    [anon_sym_PIPE_PIPE] = ACTIONS(4472),
    [anon_sym_QMARK_QMARK] = ACTIONS(4472),
    [anon_sym_from] = ACTIONS(4472),
    [anon_sym_join] = ACTIONS(4472),
    [anon_sym_on] = ACTIONS(4472),
    [anon_sym_equals] = ACTIONS(4472),
    [anon_sym_let] = ACTIONS(4472),
    [anon_sym_orderby] = ACTIONS(4472),
    [anon_sym_group] = ACTIONS(4472),
    [anon_sym_by] = ACTIONS(4472),
    [anon_sym_select] = ACTIONS(4472),
    [anon_sym_as] = ACTIONS(4472),
    [anon_sym_is] = ACTIONS(4472),
    [anon_sym_DASH_GT] = ACTIONS(4472),
    [anon_sym_with] = ACTIONS(4472),
    [aux_sym_preproc_if_token3] = ACTIONS(4472),
    [aux_sym_preproc_else_token1] = ACTIONS(4472),
    [aux_sym_preproc_elif_token1] = ACTIONS(4472),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3640] = {
    [sym_preproc_region] = STATE(3640),
    [sym_preproc_endregion] = STATE(3640),
    [sym_preproc_line] = STATE(3640),
    [sym_preproc_pragma] = STATE(3640),
    [sym_preproc_nullable] = STATE(3640),
    [sym_preproc_error] = STATE(3640),
    [sym_preproc_warning] = STATE(3640),
    [sym_preproc_define] = STATE(3640),
    [sym_preproc_undef] = STATE(3640),
    [anon_sym_SEMI] = ACTIONS(5420),
    [anon_sym_LBRACK] = ACTIONS(5420),
    [anon_sym_COLON] = ACTIONS(5420),
    [anon_sym_COMMA] = ACTIONS(5420),
    [anon_sym_RBRACK] = ACTIONS(5420),
    [anon_sym_LPAREN] = ACTIONS(5420),
    [anon_sym_RPAREN] = ACTIONS(5420),
    [anon_sym_RBRACE] = ACTIONS(5420),
    [anon_sym_LT] = ACTIONS(5422),
    [anon_sym_GT] = ACTIONS(5422),
    [anon_sym_in] = ACTIONS(5422),
    [anon_sym_where] = ACTIONS(5420),
    [anon_sym_QMARK] = ACTIONS(5422),
    [anon_sym_BANG] = ACTIONS(5422),
    [anon_sym_PLUS_PLUS] = ACTIONS(5420),
    [anon_sym_DASH_DASH] = ACTIONS(5420),
    [anon_sym_PLUS] = ACTIONS(5422),
    [anon_sym_DASH] = ACTIONS(5422),
    [anon_sym_STAR] = ACTIONS(5420),
    [anon_sym_SLASH] = ACTIONS(5422),
    [anon_sym_PERCENT] = ACTIONS(5420),
    [anon_sym_CARET] = ACTIONS(5420),
    [anon_sym_PIPE] = ACTIONS(5422),
    [anon_sym_AMP] = ACTIONS(5422),
    [anon_sym_LT_LT] = ACTIONS(5420),
    [anon_sym_GT_GT] = ACTIONS(5422),
    [anon_sym_GT_GT_GT] = ACTIONS(5420),
    [anon_sym_EQ_EQ] = ACTIONS(5420),
    [anon_sym_BANG_EQ] = ACTIONS(5420),
    [anon_sym_GT_EQ] = ACTIONS(5420),
    [anon_sym_LT_EQ] = ACTIONS(5420),
    [anon_sym_DOT] = ACTIONS(5422),
    [anon_sym_EQ_GT] = ACTIONS(5420),
    [anon_sym_switch] = ACTIONS(5420),
    [anon_sym_DOT_DOT] = ACTIONS(5420),
    [anon_sym_and] = ACTIONS(5420),
    [anon_sym_or] = ACTIONS(5422),
    [anon_sym_AMP_AMP] = ACTIONS(5420),
    [anon_sym_PIPE_PIPE] = ACTIONS(5420),
    [anon_sym_QMARK_QMARK] = ACTIONS(5420),
    [anon_sym_from] = ACTIONS(5420),
    [anon_sym_into] = ACTIONS(5420),
    [anon_sym_join] = ACTIONS(5420),
    [anon_sym_on] = ACTIONS(5420),
    [anon_sym_equals] = ACTIONS(5420),
    [anon_sym_let] = ACTIONS(5420),
    [anon_sym_orderby] = ACTIONS(5420),
    [anon_sym_group] = ACTIONS(5420),
    [anon_sym_by] = ACTIONS(5420),
    [anon_sym_select] = ACTIONS(5420),
    [anon_sym_as] = ACTIONS(5420),
    [anon_sym_is] = ACTIONS(5420),
    [anon_sym_DASH_GT] = ACTIONS(5420),
    [anon_sym_with] = ACTIONS(5420),
    [aux_sym_preproc_if_token3] = ACTIONS(5420),
    [aux_sym_preproc_else_token1] = ACTIONS(5420),
    [aux_sym_preproc_elif_token1] = ACTIONS(5420),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3641] = {
    [sym_preproc_region] = STATE(3641),
    [sym_preproc_endregion] = STATE(3641),
    [sym_preproc_line] = STATE(3641),
    [sym_preproc_pragma] = STATE(3641),
    [sym_preproc_nullable] = STATE(3641),
    [sym_preproc_error] = STATE(3641),
    [sym_preproc_warning] = STATE(3641),
    [sym_preproc_define] = STATE(3641),
    [sym_preproc_undef] = STATE(3641),
    [anon_sym_SEMI] = ACTIONS(5424),
    [anon_sym_LBRACK] = ACTIONS(5424),
    [anon_sym_COLON] = ACTIONS(5424),
    [anon_sym_COMMA] = ACTIONS(5424),
    [anon_sym_RBRACK] = ACTIONS(5424),
    [anon_sym_LPAREN] = ACTIONS(5424),
    [anon_sym_RPAREN] = ACTIONS(5424),
    [anon_sym_RBRACE] = ACTIONS(5424),
    [anon_sym_LT] = ACTIONS(5426),
    [anon_sym_GT] = ACTIONS(5426),
    [anon_sym_in] = ACTIONS(5426),
    [anon_sym_where] = ACTIONS(5424),
    [anon_sym_QMARK] = ACTIONS(5426),
    [anon_sym_BANG] = ACTIONS(5426),
    [anon_sym_PLUS_PLUS] = ACTIONS(5424),
    [anon_sym_DASH_DASH] = ACTIONS(5424),
    [anon_sym_PLUS] = ACTIONS(5426),
    [anon_sym_DASH] = ACTIONS(5426),
    [anon_sym_STAR] = ACTIONS(5424),
    [anon_sym_SLASH] = ACTIONS(5426),
    [anon_sym_PERCENT] = ACTIONS(5424),
    [anon_sym_CARET] = ACTIONS(5424),
    [anon_sym_PIPE] = ACTIONS(5426),
    [anon_sym_AMP] = ACTIONS(5426),
    [anon_sym_LT_LT] = ACTIONS(5424),
    [anon_sym_GT_GT] = ACTIONS(5426),
    [anon_sym_GT_GT_GT] = ACTIONS(5424),
    [anon_sym_EQ_EQ] = ACTIONS(5424),
    [anon_sym_BANG_EQ] = ACTIONS(5424),
    [anon_sym_GT_EQ] = ACTIONS(5424),
    [anon_sym_LT_EQ] = ACTIONS(5424),
    [anon_sym_DOT] = ACTIONS(5426),
    [anon_sym_EQ_GT] = ACTIONS(5424),
    [anon_sym_switch] = ACTIONS(5424),
    [anon_sym_DOT_DOT] = ACTIONS(5424),
    [anon_sym_and] = ACTIONS(5424),
    [anon_sym_or] = ACTIONS(5426),
    [anon_sym_AMP_AMP] = ACTIONS(5424),
    [anon_sym_PIPE_PIPE] = ACTIONS(5424),
    [anon_sym_QMARK_QMARK] = ACTIONS(5424),
    [anon_sym_from] = ACTIONS(5424),
    [anon_sym_into] = ACTIONS(5424),
    [anon_sym_join] = ACTIONS(5424),
    [anon_sym_on] = ACTIONS(5424),
    [anon_sym_equals] = ACTIONS(5424),
    [anon_sym_let] = ACTIONS(5424),
    [anon_sym_orderby] = ACTIONS(5424),
    [anon_sym_group] = ACTIONS(5424),
    [anon_sym_by] = ACTIONS(5424),
    [anon_sym_select] = ACTIONS(5424),
    [anon_sym_as] = ACTIONS(5424),
    [anon_sym_is] = ACTIONS(5424),
    [anon_sym_DASH_GT] = ACTIONS(5424),
    [anon_sym_with] = ACTIONS(5424),
    [aux_sym_preproc_if_token3] = ACTIONS(5424),
    [aux_sym_preproc_else_token1] = ACTIONS(5424),
    [aux_sym_preproc_elif_token1] = ACTIONS(5424),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3642] = {
    [sym_preproc_region] = STATE(3642),
    [sym_preproc_endregion] = STATE(3642),
    [sym_preproc_line] = STATE(3642),
    [sym_preproc_pragma] = STATE(3642),
    [sym_preproc_nullable] = STATE(3642),
    [sym_preproc_error] = STATE(3642),
    [sym_preproc_warning] = STATE(3642),
    [sym_preproc_define] = STATE(3642),
    [sym_preproc_undef] = STATE(3642),
    [anon_sym_SEMI] = ACTIONS(5428),
    [anon_sym_LBRACK] = ACTIONS(5428),
    [anon_sym_COLON] = ACTIONS(5428),
    [anon_sym_COMMA] = ACTIONS(5428),
    [anon_sym_RBRACK] = ACTIONS(5428),
    [anon_sym_LPAREN] = ACTIONS(5428),
    [anon_sym_RPAREN] = ACTIONS(5428),
    [anon_sym_RBRACE] = ACTIONS(5428),
    [anon_sym_LT] = ACTIONS(5430),
    [anon_sym_GT] = ACTIONS(5430),
    [anon_sym_in] = ACTIONS(5430),
    [anon_sym_where] = ACTIONS(5428),
    [anon_sym_QMARK] = ACTIONS(5430),
    [anon_sym_BANG] = ACTIONS(5430),
    [anon_sym_PLUS_PLUS] = ACTIONS(5428),
    [anon_sym_DASH_DASH] = ACTIONS(5428),
    [anon_sym_PLUS] = ACTIONS(5430),
    [anon_sym_DASH] = ACTIONS(5430),
    [anon_sym_STAR] = ACTIONS(5428),
    [anon_sym_SLASH] = ACTIONS(5430),
    [anon_sym_PERCENT] = ACTIONS(5428),
    [anon_sym_CARET] = ACTIONS(5428),
    [anon_sym_PIPE] = ACTIONS(5430),
    [anon_sym_AMP] = ACTIONS(5430),
    [anon_sym_LT_LT] = ACTIONS(5428),
    [anon_sym_GT_GT] = ACTIONS(5430),
    [anon_sym_GT_GT_GT] = ACTIONS(5428),
    [anon_sym_EQ_EQ] = ACTIONS(5428),
    [anon_sym_BANG_EQ] = ACTIONS(5428),
    [anon_sym_GT_EQ] = ACTIONS(5428),
    [anon_sym_LT_EQ] = ACTIONS(5428),
    [anon_sym_DOT] = ACTIONS(5430),
    [anon_sym_EQ_GT] = ACTIONS(5428),
    [anon_sym_switch] = ACTIONS(5428),
    [anon_sym_DOT_DOT] = ACTIONS(5428),
    [anon_sym_and] = ACTIONS(5428),
    [anon_sym_or] = ACTIONS(5430),
    [anon_sym_AMP_AMP] = ACTIONS(5428),
    [anon_sym_PIPE_PIPE] = ACTIONS(5428),
    [anon_sym_QMARK_QMARK] = ACTIONS(5428),
    [anon_sym_from] = ACTIONS(5428),
    [anon_sym_into] = ACTIONS(5428),
    [anon_sym_join] = ACTIONS(5428),
    [anon_sym_on] = ACTIONS(5428),
    [anon_sym_equals] = ACTIONS(5428),
    [anon_sym_let] = ACTIONS(5428),
    [anon_sym_orderby] = ACTIONS(5428),
    [anon_sym_group] = ACTIONS(5428),
    [anon_sym_by] = ACTIONS(5428),
    [anon_sym_select] = ACTIONS(5428),
    [anon_sym_as] = ACTIONS(5428),
    [anon_sym_is] = ACTIONS(5428),
    [anon_sym_DASH_GT] = ACTIONS(5428),
    [anon_sym_with] = ACTIONS(5428),
    [aux_sym_preproc_if_token3] = ACTIONS(5428),
    [aux_sym_preproc_else_token1] = ACTIONS(5428),
    [aux_sym_preproc_elif_token1] = ACTIONS(5428),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3643] = {
    [sym_preproc_region] = STATE(3643),
    [sym_preproc_endregion] = STATE(3643),
    [sym_preproc_line] = STATE(3643),
    [sym_preproc_pragma] = STATE(3643),
    [sym_preproc_nullable] = STATE(3643),
    [sym_preproc_error] = STATE(3643),
    [sym_preproc_warning] = STATE(3643),
    [sym_preproc_define] = STATE(3643),
    [sym_preproc_undef] = STATE(3643),
    [anon_sym_SEMI] = ACTIONS(4455),
    [anon_sym_LBRACK] = ACTIONS(4455),
    [anon_sym_COLON] = ACTIONS(4455),
    [anon_sym_COMMA] = ACTIONS(4455),
    [anon_sym_RBRACK] = ACTIONS(4455),
    [anon_sym_LPAREN] = ACTIONS(4455),
    [anon_sym_RPAREN] = ACTIONS(4455),
    [anon_sym_LBRACE] = ACTIONS(4455),
    [anon_sym_RBRACE] = ACTIONS(4455),
    [anon_sym_LT] = ACTIONS(4453),
    [anon_sym_GT] = ACTIONS(4453),
    [anon_sym_in] = ACTIONS(4455),
    [anon_sym_where] = ACTIONS(4455),
    [anon_sym_QMARK] = ACTIONS(4453),
    [anon_sym_BANG] = ACTIONS(4453),
    [anon_sym_PLUS_PLUS] = ACTIONS(4455),
    [anon_sym_DASH_DASH] = ACTIONS(4455),
    [anon_sym_PLUS] = ACTIONS(4453),
    [anon_sym_DASH] = ACTIONS(4453),
    [anon_sym_STAR] = ACTIONS(4455),
    [anon_sym_SLASH] = ACTIONS(4453),
    [anon_sym_PERCENT] = ACTIONS(4455),
    [anon_sym_CARET] = ACTIONS(4455),
    [anon_sym_PIPE] = ACTIONS(4453),
    [anon_sym_AMP] = ACTIONS(4453),
    [anon_sym_LT_LT] = ACTIONS(4455),
    [anon_sym_GT_GT] = ACTIONS(4453),
    [anon_sym_GT_GT_GT] = ACTIONS(4455),
    [anon_sym_EQ_EQ] = ACTIONS(4455),
    [anon_sym_BANG_EQ] = ACTIONS(4455),
    [anon_sym_GT_EQ] = ACTIONS(4455),
    [anon_sym_LT_EQ] = ACTIONS(4455),
    [anon_sym_DOT] = ACTIONS(4453),
    [anon_sym_EQ_GT] = ACTIONS(4455),
    [anon_sym_switch] = ACTIONS(4455),
    [anon_sym_DOT_DOT] = ACTIONS(4455),
    [anon_sym_and] = ACTIONS(4455),
    [anon_sym_or] = ACTIONS(4453),
    [anon_sym_AMP_AMP] = ACTIONS(4455),
    [anon_sym_PIPE_PIPE] = ACTIONS(4455),
    [anon_sym_QMARK_QMARK] = ACTIONS(4455),
    [anon_sym_from] = ACTIONS(4455),
    [anon_sym_join] = ACTIONS(4455),
    [anon_sym_on] = ACTIONS(4455),
    [anon_sym_equals] = ACTIONS(4455),
    [anon_sym_let] = ACTIONS(4455),
    [anon_sym_orderby] = ACTIONS(4455),
    [anon_sym_group] = ACTIONS(4455),
    [anon_sym_by] = ACTIONS(4455),
    [anon_sym_select] = ACTIONS(4455),
    [anon_sym_as] = ACTIONS(4455),
    [anon_sym_is] = ACTIONS(4455),
    [anon_sym_DASH_GT] = ACTIONS(4455),
    [anon_sym_with] = ACTIONS(4455),
    [aux_sym_preproc_if_token3] = ACTIONS(4455),
    [aux_sym_preproc_else_token1] = ACTIONS(4455),
    [aux_sym_preproc_elif_token1] = ACTIONS(4455),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3644] = {
    [sym_attribute_list] = STATE(4448),
    [sym_modifier] = STATE(4497),
    [sym_accessor_declaration] = STATE(4355),
    [sym_identifier] = STATE(7785),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_region] = STATE(3644),
    [sym_preproc_endregion] = STATE(3644),
    [sym_preproc_line] = STATE(3644),
    [sym_preproc_pragma] = STATE(3644),
    [sym_preproc_nullable] = STATE(3644),
    [sym_preproc_error] = STATE(3644),
    [sym_preproc_warning] = STATE(3644),
    [sym_preproc_define] = STATE(3644),
    [sym_preproc_undef] = STATE(3644),
    [aux_sym_class_declaration_repeat1] = STATE(3805),
    [aux_sym_class_declaration_repeat2] = STATE(3975),
    [aux_sym_accessor_list_repeat1] = STATE(3644),
    [sym__identifier_token] = ACTIONS(5432),
    [anon_sym_extern] = ACTIONS(5435),
    [anon_sym_alias] = ACTIONS(5438),
    [anon_sym_global] = ACTIONS(5438),
    [anon_sym_unsafe] = ACTIONS(5435),
    [anon_sym_static] = ACTIONS(5435),
    [anon_sym_LBRACK] = ACTIONS(5441),
    [anon_sym_RBRACE] = ACTIONS(5444),
    [anon_sym_abstract] = ACTIONS(5435),
    [anon_sym_async] = ACTIONS(5435),
    [anon_sym_const] = ACTIONS(5435),
    [anon_sym_file] = ACTIONS(5446),
    [anon_sym_fixed] = ACTIONS(5435),
    [anon_sym_internal] = ACTIONS(5435),
    [anon_sym_new] = ACTIONS(5435),
    [anon_sym_override] = ACTIONS(5435),
    [anon_sym_partial] = ACTIONS(5435),
    [anon_sym_private] = ACTIONS(5435),
    [anon_sym_protected] = ACTIONS(5435),
    [anon_sym_public] = ACTIONS(5435),
    [anon_sym_readonly] = ACTIONS(5435),
    [anon_sym_required] = ACTIONS(5435),
    [anon_sym_sealed] = ACTIONS(5435),
    [anon_sym_virtual] = ACTIONS(5435),
    [anon_sym_volatile] = ACTIONS(5435),
    [anon_sym_where] = ACTIONS(5438),
    [anon_sym_notnull] = ACTIONS(5438),
    [anon_sym_unmanaged] = ACTIONS(5438),
    [anon_sym_get] = ACTIONS(5449),
    [anon_sym_set] = ACTIONS(5449),
    [anon_sym_add] = ACTIONS(5449),
    [anon_sym_remove] = ACTIONS(5449),
    [anon_sym_init] = ACTIONS(5449),
    [anon_sym_scoped] = ACTIONS(5438),
    [anon_sym_var] = ACTIONS(5438),
    [anon_sym_yield] = ACTIONS(5438),
    [anon_sym_when] = ACTIONS(5438),
    [anon_sym_from] = ACTIONS(5438),
    [anon_sym_into] = ACTIONS(5438),
    [anon_sym_join] = ACTIONS(5438),
    [anon_sym_on] = ACTIONS(5438),
    [anon_sym_equals] = ACTIONS(5438),
    [anon_sym_let] = ACTIONS(5438),
    [anon_sym_orderby] = ACTIONS(5438),
    [anon_sym_ascending] = ACTIONS(5438),
    [anon_sym_descending] = ACTIONS(5438),
    [anon_sym_group] = ACTIONS(5438),
    [anon_sym_by] = ACTIONS(5438),
    [anon_sym_select] = ACTIONS(5438),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3645] = {
    [sym_preproc_region] = STATE(3645),
    [sym_preproc_endregion] = STATE(3645),
    [sym_preproc_line] = STATE(3645),
    [sym_preproc_pragma] = STATE(3645),
    [sym_preproc_nullable] = STATE(3645),
    [sym_preproc_error] = STATE(3645),
    [sym_preproc_warning] = STATE(3645),
    [sym_preproc_define] = STATE(3645),
    [sym_preproc_undef] = STATE(3645),
    [anon_sym_SEMI] = ACTIONS(5452),
    [anon_sym_LBRACK] = ACTIONS(5452),
    [anon_sym_COLON] = ACTIONS(5452),
    [anon_sym_COMMA] = ACTIONS(5452),
    [anon_sym_RBRACK] = ACTIONS(5452),
    [anon_sym_LPAREN] = ACTIONS(5452),
    [anon_sym_RPAREN] = ACTIONS(5452),
    [anon_sym_RBRACE] = ACTIONS(5452),
    [anon_sym_LT] = ACTIONS(5454),
    [anon_sym_GT] = ACTIONS(5454),
    [anon_sym_in] = ACTIONS(5454),
    [anon_sym_where] = ACTIONS(5452),
    [anon_sym_QMARK] = ACTIONS(5454),
    [anon_sym_BANG] = ACTIONS(5454),
    [anon_sym_PLUS_PLUS] = ACTIONS(5452),
    [anon_sym_DASH_DASH] = ACTIONS(5452),
    [anon_sym_PLUS] = ACTIONS(5454),
    [anon_sym_DASH] = ACTIONS(5454),
    [anon_sym_STAR] = ACTIONS(5452),
    [anon_sym_SLASH] = ACTIONS(5454),
    [anon_sym_PERCENT] = ACTIONS(5452),
    [anon_sym_CARET] = ACTIONS(5452),
    [anon_sym_PIPE] = ACTIONS(5454),
    [anon_sym_AMP] = ACTIONS(5454),
    [anon_sym_LT_LT] = ACTIONS(5452),
    [anon_sym_GT_GT] = ACTIONS(5454),
    [anon_sym_GT_GT_GT] = ACTIONS(5452),
    [anon_sym_EQ_EQ] = ACTIONS(5452),
    [anon_sym_BANG_EQ] = ACTIONS(5452),
    [anon_sym_GT_EQ] = ACTIONS(5452),
    [anon_sym_LT_EQ] = ACTIONS(5452),
    [anon_sym_DOT] = ACTIONS(5454),
    [anon_sym_EQ_GT] = ACTIONS(5452),
    [anon_sym_switch] = ACTIONS(5452),
    [anon_sym_DOT_DOT] = ACTIONS(5452),
    [anon_sym_and] = ACTIONS(5452),
    [anon_sym_or] = ACTIONS(5454),
    [anon_sym_AMP_AMP] = ACTIONS(5452),
    [anon_sym_PIPE_PIPE] = ACTIONS(5452),
    [anon_sym_QMARK_QMARK] = ACTIONS(5452),
    [anon_sym_from] = ACTIONS(5452),
    [anon_sym_into] = ACTIONS(5452),
    [anon_sym_join] = ACTIONS(5452),
    [anon_sym_on] = ACTIONS(5452),
    [anon_sym_equals] = ACTIONS(5452),
    [anon_sym_let] = ACTIONS(5452),
    [anon_sym_orderby] = ACTIONS(5452),
    [anon_sym_group] = ACTIONS(5452),
    [anon_sym_by] = ACTIONS(5452),
    [anon_sym_select] = ACTIONS(5452),
    [anon_sym_as] = ACTIONS(5452),
    [anon_sym_is] = ACTIONS(5452),
    [anon_sym_DASH_GT] = ACTIONS(5452),
    [anon_sym_with] = ACTIONS(5452),
    [aux_sym_preproc_if_token3] = ACTIONS(5452),
    [aux_sym_preproc_else_token1] = ACTIONS(5452),
    [aux_sym_preproc_elif_token1] = ACTIONS(5452),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3646] = {
    [sym_attribute_list] = STATE(4448),
    [sym_modifier] = STATE(4497),
    [sym_accessor_declaration] = STATE(4355),
    [sym_identifier] = STATE(7785),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_region] = STATE(3646),
    [sym_preproc_endregion] = STATE(3646),
    [sym_preproc_line] = STATE(3646),
    [sym_preproc_pragma] = STATE(3646),
    [sym_preproc_nullable] = STATE(3646),
    [sym_preproc_error] = STATE(3646),
    [sym_preproc_warning] = STATE(3646),
    [sym_preproc_define] = STATE(3646),
    [sym_preproc_undef] = STATE(3646),
    [aux_sym_class_declaration_repeat1] = STATE(3805),
    [aux_sym_class_declaration_repeat2] = STATE(3975),
    [aux_sym_accessor_list_repeat1] = STATE(3644),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(5456),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_unsafe] = ACTIONS(5456),
    [anon_sym_static] = ACTIONS(5456),
    [anon_sym_LBRACK] = ACTIONS(5458),
    [anon_sym_RBRACE] = ACTIONS(5460),
    [anon_sym_abstract] = ACTIONS(5456),
    [anon_sym_async] = ACTIONS(5456),
    [anon_sym_const] = ACTIONS(5456),
    [anon_sym_file] = ACTIONS(5462),
    [anon_sym_fixed] = ACTIONS(5456),
    [anon_sym_internal] = ACTIONS(5456),
    [anon_sym_new] = ACTIONS(5456),
    [anon_sym_override] = ACTIONS(5456),
    [anon_sym_partial] = ACTIONS(5456),
    [anon_sym_private] = ACTIONS(5456),
    [anon_sym_protected] = ACTIONS(5456),
    [anon_sym_public] = ACTIONS(5456),
    [anon_sym_readonly] = ACTIONS(5456),
    [anon_sym_required] = ACTIONS(5456),
    [anon_sym_sealed] = ACTIONS(5456),
    [anon_sym_virtual] = ACTIONS(5456),
    [anon_sym_volatile] = ACTIONS(5456),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_get] = ACTIONS(5464),
    [anon_sym_set] = ACTIONS(5464),
    [anon_sym_add] = ACTIONS(5464),
    [anon_sym_remove] = ACTIONS(5464),
    [anon_sym_init] = ACTIONS(5464),
    [anon_sym_scoped] = ACTIONS(29),
    [anon_sym_var] = ACTIONS(29),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_from] = ACTIONS(29),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3647] = {
    [sym_preproc_region] = STATE(3647),
    [sym_preproc_endregion] = STATE(3647),
    [sym_preproc_line] = STATE(3647),
    [sym_preproc_pragma] = STATE(3647),
    [sym_preproc_nullable] = STATE(3647),
    [sym_preproc_error] = STATE(3647),
    [sym_preproc_warning] = STATE(3647),
    [sym_preproc_define] = STATE(3647),
    [sym_preproc_undef] = STATE(3647),
    [anon_sym_SEMI] = ACTIONS(4468),
    [anon_sym_LBRACK] = ACTIONS(4468),
    [anon_sym_COLON] = ACTIONS(4468),
    [anon_sym_COMMA] = ACTIONS(4468),
    [anon_sym_RBRACK] = ACTIONS(4468),
    [anon_sym_LPAREN] = ACTIONS(4468),
    [anon_sym_RPAREN] = ACTIONS(4468),
    [anon_sym_LBRACE] = ACTIONS(4468),
    [anon_sym_RBRACE] = ACTIONS(4468),
    [anon_sym_LT] = ACTIONS(4466),
    [anon_sym_GT] = ACTIONS(4466),
    [anon_sym_in] = ACTIONS(4468),
    [anon_sym_where] = ACTIONS(4468),
    [anon_sym_QMARK] = ACTIONS(4466),
    [anon_sym_BANG] = ACTIONS(4466),
    [anon_sym_PLUS_PLUS] = ACTIONS(4468),
    [anon_sym_DASH_DASH] = ACTIONS(4468),
    [anon_sym_PLUS] = ACTIONS(4466),
    [anon_sym_DASH] = ACTIONS(4466),
    [anon_sym_STAR] = ACTIONS(4468),
    [anon_sym_SLASH] = ACTIONS(4466),
    [anon_sym_PERCENT] = ACTIONS(4468),
    [anon_sym_CARET] = ACTIONS(4468),
    [anon_sym_PIPE] = ACTIONS(4466),
    [anon_sym_AMP] = ACTIONS(4466),
    [anon_sym_LT_LT] = ACTIONS(4468),
    [anon_sym_GT_GT] = ACTIONS(4466),
    [anon_sym_GT_GT_GT] = ACTIONS(4468),
    [anon_sym_EQ_EQ] = ACTIONS(4468),
    [anon_sym_BANG_EQ] = ACTIONS(4468),
    [anon_sym_GT_EQ] = ACTIONS(4468),
    [anon_sym_LT_EQ] = ACTIONS(4468),
    [anon_sym_DOT] = ACTIONS(4466),
    [anon_sym_EQ_GT] = ACTIONS(4468),
    [anon_sym_switch] = ACTIONS(4468),
    [anon_sym_DOT_DOT] = ACTIONS(4468),
    [anon_sym_and] = ACTIONS(4468),
    [anon_sym_or] = ACTIONS(4466),
    [anon_sym_AMP_AMP] = ACTIONS(4468),
    [anon_sym_PIPE_PIPE] = ACTIONS(4468),
    [anon_sym_QMARK_QMARK] = ACTIONS(4468),
    [anon_sym_from] = ACTIONS(4468),
    [anon_sym_join] = ACTIONS(4468),
    [anon_sym_on] = ACTIONS(4468),
    [anon_sym_equals] = ACTIONS(4468),
    [anon_sym_let] = ACTIONS(4468),
    [anon_sym_orderby] = ACTIONS(4468),
    [anon_sym_group] = ACTIONS(4468),
    [anon_sym_by] = ACTIONS(4468),
    [anon_sym_select] = ACTIONS(4468),
    [anon_sym_as] = ACTIONS(4468),
    [anon_sym_is] = ACTIONS(4468),
    [anon_sym_DASH_GT] = ACTIONS(4468),
    [anon_sym_with] = ACTIONS(4468),
    [aux_sym_preproc_if_token3] = ACTIONS(4468),
    [aux_sym_preproc_else_token1] = ACTIONS(4468),
    [aux_sym_preproc_elif_token1] = ACTIONS(4468),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3648] = {
    [sym_preproc_region] = STATE(3648),
    [sym_preproc_endregion] = STATE(3648),
    [sym_preproc_line] = STATE(3648),
    [sym_preproc_pragma] = STATE(3648),
    [sym_preproc_nullable] = STATE(3648),
    [sym_preproc_error] = STATE(3648),
    [sym_preproc_warning] = STATE(3648),
    [sym_preproc_define] = STATE(3648),
    [sym_preproc_undef] = STATE(3648),
    [anon_sym_SEMI] = ACTIONS(4140),
    [anon_sym_LBRACK] = ACTIONS(4140),
    [anon_sym_COLON] = ACTIONS(4140),
    [anon_sym_COMMA] = ACTIONS(4140),
    [anon_sym_RBRACK] = ACTIONS(4140),
    [anon_sym_LPAREN] = ACTIONS(4140),
    [anon_sym_RPAREN] = ACTIONS(4140),
    [anon_sym_LBRACE] = ACTIONS(4140),
    [anon_sym_RBRACE] = ACTIONS(4140),
    [anon_sym_LT] = ACTIONS(4138),
    [anon_sym_GT] = ACTIONS(4138),
    [anon_sym_in] = ACTIONS(4140),
    [anon_sym_where] = ACTIONS(4140),
    [anon_sym_QMARK] = ACTIONS(4138),
    [anon_sym_BANG] = ACTIONS(4138),
    [anon_sym_PLUS_PLUS] = ACTIONS(4140),
    [anon_sym_DASH_DASH] = ACTIONS(4140),
    [anon_sym_PLUS] = ACTIONS(4138),
    [anon_sym_DASH] = ACTIONS(4138),
    [anon_sym_STAR] = ACTIONS(4140),
    [anon_sym_SLASH] = ACTIONS(4138),
    [anon_sym_PERCENT] = ACTIONS(4140),
    [anon_sym_CARET] = ACTIONS(4140),
    [anon_sym_PIPE] = ACTIONS(4138),
    [anon_sym_AMP] = ACTIONS(4138),
    [anon_sym_LT_LT] = ACTIONS(4140),
    [anon_sym_GT_GT] = ACTIONS(4138),
    [anon_sym_GT_GT_GT] = ACTIONS(4140),
    [anon_sym_EQ_EQ] = ACTIONS(4140),
    [anon_sym_BANG_EQ] = ACTIONS(4140),
    [anon_sym_GT_EQ] = ACTIONS(4140),
    [anon_sym_LT_EQ] = ACTIONS(4140),
    [anon_sym_DOT] = ACTIONS(4138),
    [anon_sym_EQ_GT] = ACTIONS(4140),
    [anon_sym_switch] = ACTIONS(4140),
    [anon_sym_DOT_DOT] = ACTIONS(4140),
    [anon_sym_and] = ACTIONS(4140),
    [anon_sym_or] = ACTIONS(4138),
    [anon_sym_AMP_AMP] = ACTIONS(4140),
    [anon_sym_PIPE_PIPE] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK] = ACTIONS(4140),
    [anon_sym_from] = ACTIONS(4140),
    [anon_sym_join] = ACTIONS(4140),
    [anon_sym_on] = ACTIONS(4140),
    [anon_sym_equals] = ACTIONS(4140),
    [anon_sym_let] = ACTIONS(4140),
    [anon_sym_orderby] = ACTIONS(4140),
    [anon_sym_group] = ACTIONS(4140),
    [anon_sym_by] = ACTIONS(4140),
    [anon_sym_select] = ACTIONS(4140),
    [anon_sym_as] = ACTIONS(4140),
    [anon_sym_is] = ACTIONS(4140),
    [anon_sym_DASH_GT] = ACTIONS(4140),
    [anon_sym_with] = ACTIONS(4140),
    [aux_sym_preproc_if_token3] = ACTIONS(4140),
    [aux_sym_preproc_else_token1] = ACTIONS(4140),
    [aux_sym_preproc_elif_token1] = ACTIONS(4140),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3649] = {
    [sym_preproc_region] = STATE(3649),
    [sym_preproc_endregion] = STATE(3649),
    [sym_preproc_line] = STATE(3649),
    [sym_preproc_pragma] = STATE(3649),
    [sym_preproc_nullable] = STATE(3649),
    [sym_preproc_error] = STATE(3649),
    [sym_preproc_warning] = STATE(3649),
    [sym_preproc_define] = STATE(3649),
    [sym_preproc_undef] = STATE(3649),
    [anon_sym_SEMI] = ACTIONS(5466),
    [anon_sym_LBRACK] = ACTIONS(5466),
    [anon_sym_COLON] = ACTIONS(5466),
    [anon_sym_COMMA] = ACTIONS(5466),
    [anon_sym_RBRACK] = ACTIONS(5466),
    [anon_sym_LPAREN] = ACTIONS(5466),
    [anon_sym_RPAREN] = ACTIONS(5466),
    [anon_sym_RBRACE] = ACTIONS(5466),
    [anon_sym_LT] = ACTIONS(5468),
    [anon_sym_GT] = ACTIONS(5468),
    [anon_sym_in] = ACTIONS(5468),
    [anon_sym_where] = ACTIONS(5466),
    [anon_sym_QMARK] = ACTIONS(5468),
    [anon_sym_BANG] = ACTIONS(5468),
    [anon_sym_PLUS_PLUS] = ACTIONS(5466),
    [anon_sym_DASH_DASH] = ACTIONS(5466),
    [anon_sym_PLUS] = ACTIONS(5468),
    [anon_sym_DASH] = ACTIONS(5468),
    [anon_sym_STAR] = ACTIONS(5466),
    [anon_sym_SLASH] = ACTIONS(5468),
    [anon_sym_PERCENT] = ACTIONS(5466),
    [anon_sym_CARET] = ACTIONS(5466),
    [anon_sym_PIPE] = ACTIONS(5468),
    [anon_sym_AMP] = ACTIONS(5468),
    [anon_sym_LT_LT] = ACTIONS(5466),
    [anon_sym_GT_GT] = ACTIONS(5468),
    [anon_sym_GT_GT_GT] = ACTIONS(5466),
    [anon_sym_EQ_EQ] = ACTIONS(5466),
    [anon_sym_BANG_EQ] = ACTIONS(5466),
    [anon_sym_GT_EQ] = ACTIONS(5466),
    [anon_sym_LT_EQ] = ACTIONS(5466),
    [anon_sym_DOT] = ACTIONS(5468),
    [anon_sym_EQ_GT] = ACTIONS(5466),
    [anon_sym_switch] = ACTIONS(5466),
    [anon_sym_DOT_DOT] = ACTIONS(5466),
    [anon_sym_and] = ACTIONS(5466),
    [anon_sym_or] = ACTIONS(5468),
    [anon_sym_AMP_AMP] = ACTIONS(5466),
    [anon_sym_PIPE_PIPE] = ACTIONS(5466),
    [anon_sym_QMARK_QMARK] = ACTIONS(5466),
    [anon_sym_from] = ACTIONS(5466),
    [anon_sym_into] = ACTIONS(5466),
    [anon_sym_join] = ACTIONS(5466),
    [anon_sym_on] = ACTIONS(5466),
    [anon_sym_equals] = ACTIONS(5466),
    [anon_sym_let] = ACTIONS(5466),
    [anon_sym_orderby] = ACTIONS(5466),
    [anon_sym_group] = ACTIONS(5466),
    [anon_sym_by] = ACTIONS(5466),
    [anon_sym_select] = ACTIONS(5466),
    [anon_sym_as] = ACTIONS(5466),
    [anon_sym_is] = ACTIONS(5466),
    [anon_sym_DASH_GT] = ACTIONS(5466),
    [anon_sym_with] = ACTIONS(5466),
    [aux_sym_preproc_if_token3] = ACTIONS(5466),
    [aux_sym_preproc_else_token1] = ACTIONS(5466),
    [aux_sym_preproc_elif_token1] = ACTIONS(5466),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3650] = {
    [sym_preproc_region] = STATE(3650),
    [sym_preproc_endregion] = STATE(3650),
    [sym_preproc_line] = STATE(3650),
    [sym_preproc_pragma] = STATE(3650),
    [sym_preproc_nullable] = STATE(3650),
    [sym_preproc_error] = STATE(3650),
    [sym_preproc_warning] = STATE(3650),
    [sym_preproc_define] = STATE(3650),
    [sym_preproc_undef] = STATE(3650),
    [anon_sym_SEMI] = ACTIONS(5470),
    [anon_sym_LBRACK] = ACTIONS(5470),
    [anon_sym_COLON] = ACTIONS(5470),
    [anon_sym_COMMA] = ACTIONS(5470),
    [anon_sym_RBRACK] = ACTIONS(5470),
    [anon_sym_LPAREN] = ACTIONS(5470),
    [anon_sym_RPAREN] = ACTIONS(5470),
    [anon_sym_RBRACE] = ACTIONS(5470),
    [anon_sym_LT] = ACTIONS(5472),
    [anon_sym_GT] = ACTIONS(5472),
    [anon_sym_in] = ACTIONS(5472),
    [anon_sym_where] = ACTIONS(5470),
    [anon_sym_QMARK] = ACTIONS(5472),
    [anon_sym_BANG] = ACTIONS(5472),
    [anon_sym_PLUS_PLUS] = ACTIONS(5470),
    [anon_sym_DASH_DASH] = ACTIONS(5470),
    [anon_sym_PLUS] = ACTIONS(5472),
    [anon_sym_DASH] = ACTIONS(5472),
    [anon_sym_STAR] = ACTIONS(5470),
    [anon_sym_SLASH] = ACTIONS(5472),
    [anon_sym_PERCENT] = ACTIONS(5470),
    [anon_sym_CARET] = ACTIONS(5470),
    [anon_sym_PIPE] = ACTIONS(5472),
    [anon_sym_AMP] = ACTIONS(5472),
    [anon_sym_LT_LT] = ACTIONS(5470),
    [anon_sym_GT_GT] = ACTIONS(5472),
    [anon_sym_GT_GT_GT] = ACTIONS(5470),
    [anon_sym_EQ_EQ] = ACTIONS(5470),
    [anon_sym_BANG_EQ] = ACTIONS(5470),
    [anon_sym_GT_EQ] = ACTIONS(5470),
    [anon_sym_LT_EQ] = ACTIONS(5470),
    [anon_sym_DOT] = ACTIONS(5472),
    [anon_sym_EQ_GT] = ACTIONS(5470),
    [anon_sym_switch] = ACTIONS(5470),
    [anon_sym_DOT_DOT] = ACTIONS(5470),
    [anon_sym_and] = ACTIONS(5470),
    [anon_sym_or] = ACTIONS(5472),
    [anon_sym_AMP_AMP] = ACTIONS(5470),
    [anon_sym_PIPE_PIPE] = ACTIONS(5470),
    [anon_sym_QMARK_QMARK] = ACTIONS(5470),
    [anon_sym_from] = ACTIONS(5470),
    [anon_sym_into] = ACTIONS(5470),
    [anon_sym_join] = ACTIONS(5470),
    [anon_sym_on] = ACTIONS(5470),
    [anon_sym_equals] = ACTIONS(5470),
    [anon_sym_let] = ACTIONS(5470),
    [anon_sym_orderby] = ACTIONS(5470),
    [anon_sym_group] = ACTIONS(5470),
    [anon_sym_by] = ACTIONS(5470),
    [anon_sym_select] = ACTIONS(5470),
    [anon_sym_as] = ACTIONS(5470),
    [anon_sym_is] = ACTIONS(5470),
    [anon_sym_DASH_GT] = ACTIONS(5470),
    [anon_sym_with] = ACTIONS(5470),
    [aux_sym_preproc_if_token3] = ACTIONS(5470),
    [aux_sym_preproc_else_token1] = ACTIONS(5470),
    [aux_sym_preproc_elif_token1] = ACTIONS(5470),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3651] = {
    [sym_preproc_region] = STATE(3651),
    [sym_preproc_endregion] = STATE(3651),
    [sym_preproc_line] = STATE(3651),
    [sym_preproc_pragma] = STATE(3651),
    [sym_preproc_nullable] = STATE(3651),
    [sym_preproc_error] = STATE(3651),
    [sym_preproc_warning] = STATE(3651),
    [sym_preproc_define] = STATE(3651),
    [sym_preproc_undef] = STATE(3651),
    [anon_sym_SEMI] = ACTIONS(4136),
    [anon_sym_LBRACK] = ACTIONS(4136),
    [anon_sym_COLON] = ACTIONS(4136),
    [anon_sym_COMMA] = ACTIONS(4136),
    [anon_sym_RBRACK] = ACTIONS(4136),
    [anon_sym_LPAREN] = ACTIONS(4136),
    [anon_sym_RPAREN] = ACTIONS(4136),
    [anon_sym_LBRACE] = ACTIONS(4136),
    [anon_sym_RBRACE] = ACTIONS(4136),
    [anon_sym_LT] = ACTIONS(4134),
    [anon_sym_GT] = ACTIONS(4134),
    [anon_sym_in] = ACTIONS(4136),
    [anon_sym_where] = ACTIONS(4136),
    [anon_sym_QMARK] = ACTIONS(4134),
    [anon_sym_BANG] = ACTIONS(4134),
    [anon_sym_PLUS_PLUS] = ACTIONS(4136),
    [anon_sym_DASH_DASH] = ACTIONS(4136),
    [anon_sym_PLUS] = ACTIONS(4134),
    [anon_sym_DASH] = ACTIONS(4134),
    [anon_sym_STAR] = ACTIONS(4136),
    [anon_sym_SLASH] = ACTIONS(4134),
    [anon_sym_PERCENT] = ACTIONS(4136),
    [anon_sym_CARET] = ACTIONS(4136),
    [anon_sym_PIPE] = ACTIONS(4134),
    [anon_sym_AMP] = ACTIONS(4134),
    [anon_sym_LT_LT] = ACTIONS(4136),
    [anon_sym_GT_GT] = ACTIONS(4134),
    [anon_sym_GT_GT_GT] = ACTIONS(4136),
    [anon_sym_EQ_EQ] = ACTIONS(4136),
    [anon_sym_BANG_EQ] = ACTIONS(4136),
    [anon_sym_GT_EQ] = ACTIONS(4136),
    [anon_sym_LT_EQ] = ACTIONS(4136),
    [anon_sym_DOT] = ACTIONS(4134),
    [anon_sym_EQ_GT] = ACTIONS(4136),
    [anon_sym_switch] = ACTIONS(4136),
    [anon_sym_DOT_DOT] = ACTIONS(4136),
    [anon_sym_and] = ACTIONS(4136),
    [anon_sym_or] = ACTIONS(4134),
    [anon_sym_AMP_AMP] = ACTIONS(4136),
    [anon_sym_PIPE_PIPE] = ACTIONS(4136),
    [anon_sym_QMARK_QMARK] = ACTIONS(4136),
    [anon_sym_from] = ACTIONS(4136),
    [anon_sym_join] = ACTIONS(4136),
    [anon_sym_on] = ACTIONS(4136),
    [anon_sym_equals] = ACTIONS(4136),
    [anon_sym_let] = ACTIONS(4136),
    [anon_sym_orderby] = ACTIONS(4136),
    [anon_sym_group] = ACTIONS(4136),
    [anon_sym_by] = ACTIONS(4136),
    [anon_sym_select] = ACTIONS(4136),
    [anon_sym_as] = ACTIONS(4136),
    [anon_sym_is] = ACTIONS(4136),
    [anon_sym_DASH_GT] = ACTIONS(4136),
    [anon_sym_with] = ACTIONS(4136),
    [aux_sym_preproc_if_token3] = ACTIONS(4136),
    [aux_sym_preproc_else_token1] = ACTIONS(4136),
    [aux_sym_preproc_elif_token1] = ACTIONS(4136),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3652] = {
    [sym_preproc_region] = STATE(3652),
    [sym_preproc_endregion] = STATE(3652),
    [sym_preproc_line] = STATE(3652),
    [sym_preproc_pragma] = STATE(3652),
    [sym_preproc_nullable] = STATE(3652),
    [sym_preproc_error] = STATE(3652),
    [sym_preproc_warning] = STATE(3652),
    [sym_preproc_define] = STATE(3652),
    [sym_preproc_undef] = STATE(3652),
    [sym__identifier_token] = ACTIONS(4039),
    [anon_sym_extern] = ACTIONS(4042),
    [anon_sym_alias] = ACTIONS(4039),
    [anon_sym_global] = ACTIONS(4039),
    [anon_sym_unsafe] = ACTIONS(4042),
    [anon_sym_static] = ACTIONS(4042),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_LPAREN] = ACTIONS(5474),
    [anon_sym_class] = ACTIONS(4042),
    [anon_sym_ref] = ACTIONS(4042),
    [anon_sym_struct] = ACTIONS(4042),
    [anon_sym_enum] = ACTIONS(4042),
    [anon_sym_interface] = ACTIONS(4042),
    [anon_sym_delegate] = ACTIONS(4042),
    [anon_sym_record] = ACTIONS(4042),
    [anon_sym_abstract] = ACTIONS(4042),
    [anon_sym_async] = ACTIONS(4042),
    [anon_sym_const] = ACTIONS(4042),
    [anon_sym_file] = ACTIONS(4039),
    [anon_sym_fixed] = ACTIONS(4042),
    [anon_sym_internal] = ACTIONS(4042),
    [anon_sym_new] = ACTIONS(4042),
    [anon_sym_override] = ACTIONS(4042),
    [anon_sym_partial] = ACTIONS(4042),
    [anon_sym_private] = ACTIONS(4042),
    [anon_sym_protected] = ACTIONS(4042),
    [anon_sym_public] = ACTIONS(4042),
    [anon_sym_readonly] = ACTIONS(4042),
    [anon_sym_required] = ACTIONS(4042),
    [anon_sym_sealed] = ACTIONS(4042),
    [anon_sym_virtual] = ACTIONS(4042),
    [anon_sym_volatile] = ACTIONS(4042),
    [anon_sym_LT] = ACTIONS(3993),
    [anon_sym_where] = ACTIONS(4039),
    [anon_sym_QMARK] = ACTIONS(3993),
    [anon_sym_notnull] = ACTIONS(4039),
    [anon_sym_unmanaged] = ACTIONS(4039),
    [anon_sym_STAR] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3993),
    [anon_sym_scoped] = ACTIONS(4039),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(4039),
    [sym_predefined_type] = ACTIONS(4042),
    [anon_sym_yield] = ACTIONS(4039),
    [anon_sym_when] = ACTIONS(4039),
    [anon_sym_from] = ACTIONS(4039),
    [anon_sym_into] = ACTIONS(4039),
    [anon_sym_join] = ACTIONS(4039),
    [anon_sym_on] = ACTIONS(4039),
    [anon_sym_equals] = ACTIONS(4039),
    [anon_sym_let] = ACTIONS(4039),
    [anon_sym_orderby] = ACTIONS(4039),
    [anon_sym_ascending] = ACTIONS(4039),
    [anon_sym_descending] = ACTIONS(4039),
    [anon_sym_group] = ACTIONS(4039),
    [anon_sym_by] = ACTIONS(4039),
    [anon_sym_select] = ACTIONS(4039),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3653] = {
    [sym_preproc_region] = STATE(3653),
    [sym_preproc_endregion] = STATE(3653),
    [sym_preproc_line] = STATE(3653),
    [sym_preproc_pragma] = STATE(3653),
    [sym_preproc_nullable] = STATE(3653),
    [sym_preproc_error] = STATE(3653),
    [sym_preproc_warning] = STATE(3653),
    [sym_preproc_define] = STATE(3653),
    [sym_preproc_undef] = STATE(3653),
    [anon_sym_SEMI] = ACTIONS(5476),
    [anon_sym_LBRACK] = ACTIONS(5476),
    [anon_sym_COLON] = ACTIONS(5476),
    [anon_sym_COMMA] = ACTIONS(5476),
    [anon_sym_RBRACK] = ACTIONS(5476),
    [anon_sym_LPAREN] = ACTIONS(5476),
    [anon_sym_RPAREN] = ACTIONS(5476),
    [anon_sym_RBRACE] = ACTIONS(5476),
    [anon_sym_LT] = ACTIONS(5478),
    [anon_sym_GT] = ACTIONS(5478),
    [anon_sym_in] = ACTIONS(5478),
    [anon_sym_where] = ACTIONS(5476),
    [anon_sym_QMARK] = ACTIONS(5478),
    [anon_sym_BANG] = ACTIONS(5478),
    [anon_sym_PLUS_PLUS] = ACTIONS(5476),
    [anon_sym_DASH_DASH] = ACTIONS(5476),
    [anon_sym_PLUS] = ACTIONS(5478),
    [anon_sym_DASH] = ACTIONS(5478),
    [anon_sym_STAR] = ACTIONS(5476),
    [anon_sym_SLASH] = ACTIONS(5478),
    [anon_sym_PERCENT] = ACTIONS(5476),
    [anon_sym_CARET] = ACTIONS(5476),
    [anon_sym_PIPE] = ACTIONS(5478),
    [anon_sym_AMP] = ACTIONS(5478),
    [anon_sym_LT_LT] = ACTIONS(5476),
    [anon_sym_GT_GT] = ACTIONS(5478),
    [anon_sym_GT_GT_GT] = ACTIONS(5476),
    [anon_sym_EQ_EQ] = ACTIONS(5476),
    [anon_sym_BANG_EQ] = ACTIONS(5476),
    [anon_sym_GT_EQ] = ACTIONS(5476),
    [anon_sym_LT_EQ] = ACTIONS(5476),
    [anon_sym_DOT] = ACTIONS(5478),
    [anon_sym_EQ_GT] = ACTIONS(5476),
    [anon_sym_switch] = ACTIONS(5476),
    [anon_sym_DOT_DOT] = ACTIONS(5476),
    [anon_sym_and] = ACTIONS(5476),
    [anon_sym_or] = ACTIONS(5478),
    [anon_sym_AMP_AMP] = ACTIONS(5476),
    [anon_sym_PIPE_PIPE] = ACTIONS(5476),
    [anon_sym_QMARK_QMARK] = ACTIONS(5476),
    [anon_sym_from] = ACTIONS(5476),
    [anon_sym_into] = ACTIONS(5476),
    [anon_sym_join] = ACTIONS(5476),
    [anon_sym_on] = ACTIONS(5476),
    [anon_sym_equals] = ACTIONS(5476),
    [anon_sym_let] = ACTIONS(5476),
    [anon_sym_orderby] = ACTIONS(5476),
    [anon_sym_group] = ACTIONS(5476),
    [anon_sym_by] = ACTIONS(5476),
    [anon_sym_select] = ACTIONS(5476),
    [anon_sym_as] = ACTIONS(5476),
    [anon_sym_is] = ACTIONS(5476),
    [anon_sym_DASH_GT] = ACTIONS(5476),
    [anon_sym_with] = ACTIONS(5476),
    [aux_sym_preproc_if_token3] = ACTIONS(5476),
    [aux_sym_preproc_else_token1] = ACTIONS(5476),
    [aux_sym_preproc_elif_token1] = ACTIONS(5476),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3654] = {
    [sym_preproc_region] = STATE(3654),
    [sym_preproc_endregion] = STATE(3654),
    [sym_preproc_line] = STATE(3654),
    [sym_preproc_pragma] = STATE(3654),
    [sym_preproc_nullable] = STATE(3654),
    [sym_preproc_error] = STATE(3654),
    [sym_preproc_warning] = STATE(3654),
    [sym_preproc_define] = STATE(3654),
    [sym_preproc_undef] = STATE(3654),
    [anon_sym_SEMI] = ACTIONS(4480),
    [anon_sym_LBRACK] = ACTIONS(4480),
    [anon_sym_COLON] = ACTIONS(4480),
    [anon_sym_COMMA] = ACTIONS(4480),
    [anon_sym_RBRACK] = ACTIONS(4480),
    [anon_sym_LPAREN] = ACTIONS(4480),
    [anon_sym_RPAREN] = ACTIONS(4480),
    [anon_sym_LBRACE] = ACTIONS(4480),
    [anon_sym_RBRACE] = ACTIONS(4480),
    [anon_sym_LT] = ACTIONS(4478),
    [anon_sym_GT] = ACTIONS(4478),
    [anon_sym_in] = ACTIONS(4480),
    [anon_sym_where] = ACTIONS(4480),
    [anon_sym_QMARK] = ACTIONS(4478),
    [anon_sym_BANG] = ACTIONS(4478),
    [anon_sym_PLUS_PLUS] = ACTIONS(4480),
    [anon_sym_DASH_DASH] = ACTIONS(4480),
    [anon_sym_PLUS] = ACTIONS(4478),
    [anon_sym_DASH] = ACTIONS(4478),
    [anon_sym_STAR] = ACTIONS(4480),
    [anon_sym_SLASH] = ACTIONS(4478),
    [anon_sym_PERCENT] = ACTIONS(4480),
    [anon_sym_CARET] = ACTIONS(4480),
    [anon_sym_PIPE] = ACTIONS(4478),
    [anon_sym_AMP] = ACTIONS(4478),
    [anon_sym_LT_LT] = ACTIONS(4480),
    [anon_sym_GT_GT] = ACTIONS(4478),
    [anon_sym_GT_GT_GT] = ACTIONS(4480),
    [anon_sym_EQ_EQ] = ACTIONS(4480),
    [anon_sym_BANG_EQ] = ACTIONS(4480),
    [anon_sym_GT_EQ] = ACTIONS(4480),
    [anon_sym_LT_EQ] = ACTIONS(4480),
    [anon_sym_DOT] = ACTIONS(4478),
    [anon_sym_EQ_GT] = ACTIONS(4480),
    [anon_sym_switch] = ACTIONS(4480),
    [anon_sym_DOT_DOT] = ACTIONS(4480),
    [anon_sym_and] = ACTIONS(4480),
    [anon_sym_or] = ACTIONS(4478),
    [anon_sym_AMP_AMP] = ACTIONS(4480),
    [anon_sym_PIPE_PIPE] = ACTIONS(4480),
    [anon_sym_QMARK_QMARK] = ACTIONS(4480),
    [anon_sym_from] = ACTIONS(4480),
    [anon_sym_join] = ACTIONS(4480),
    [anon_sym_on] = ACTIONS(4480),
    [anon_sym_equals] = ACTIONS(4480),
    [anon_sym_let] = ACTIONS(4480),
    [anon_sym_orderby] = ACTIONS(4480),
    [anon_sym_group] = ACTIONS(4480),
    [anon_sym_by] = ACTIONS(4480),
    [anon_sym_select] = ACTIONS(4480),
    [anon_sym_as] = ACTIONS(4480),
    [anon_sym_is] = ACTIONS(4480),
    [anon_sym_DASH_GT] = ACTIONS(4480),
    [anon_sym_with] = ACTIONS(4480),
    [aux_sym_preproc_if_token3] = ACTIONS(4480),
    [aux_sym_preproc_else_token1] = ACTIONS(4480),
    [aux_sym_preproc_elif_token1] = ACTIONS(4480),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3655] = {
    [sym_preproc_region] = STATE(3655),
    [sym_preproc_endregion] = STATE(3655),
    [sym_preproc_line] = STATE(3655),
    [sym_preproc_pragma] = STATE(3655),
    [sym_preproc_nullable] = STATE(3655),
    [sym_preproc_error] = STATE(3655),
    [sym_preproc_warning] = STATE(3655),
    [sym_preproc_define] = STATE(3655),
    [sym_preproc_undef] = STATE(3655),
    [anon_sym_SEMI] = ACTIONS(4554),
    [anon_sym_LBRACK] = ACTIONS(4554),
    [anon_sym_COLON] = ACTIONS(4554),
    [anon_sym_COMMA] = ACTIONS(4554),
    [anon_sym_RBRACK] = ACTIONS(4554),
    [anon_sym_LPAREN] = ACTIONS(4554),
    [anon_sym_RPAREN] = ACTIONS(4554),
    [anon_sym_LBRACE] = ACTIONS(4554),
    [anon_sym_RBRACE] = ACTIONS(4554),
    [anon_sym_LT] = ACTIONS(4552),
    [anon_sym_GT] = ACTIONS(4552),
    [anon_sym_in] = ACTIONS(4554),
    [anon_sym_where] = ACTIONS(4554),
    [anon_sym_QMARK] = ACTIONS(4552),
    [anon_sym_BANG] = ACTIONS(4552),
    [anon_sym_PLUS_PLUS] = ACTIONS(4554),
    [anon_sym_DASH_DASH] = ACTIONS(4554),
    [anon_sym_PLUS] = ACTIONS(4552),
    [anon_sym_DASH] = ACTIONS(4552),
    [anon_sym_STAR] = ACTIONS(4554),
    [anon_sym_SLASH] = ACTIONS(4552),
    [anon_sym_PERCENT] = ACTIONS(4554),
    [anon_sym_CARET] = ACTIONS(4554),
    [anon_sym_PIPE] = ACTIONS(4552),
    [anon_sym_AMP] = ACTIONS(4552),
    [anon_sym_LT_LT] = ACTIONS(4554),
    [anon_sym_GT_GT] = ACTIONS(4552),
    [anon_sym_GT_GT_GT] = ACTIONS(4554),
    [anon_sym_EQ_EQ] = ACTIONS(4554),
    [anon_sym_BANG_EQ] = ACTIONS(4554),
    [anon_sym_GT_EQ] = ACTIONS(4554),
    [anon_sym_LT_EQ] = ACTIONS(4554),
    [anon_sym_DOT] = ACTIONS(4552),
    [anon_sym_EQ_GT] = ACTIONS(4554),
    [anon_sym_switch] = ACTIONS(4554),
    [anon_sym_DOT_DOT] = ACTIONS(4554),
    [anon_sym_and] = ACTIONS(4554),
    [anon_sym_or] = ACTIONS(4552),
    [anon_sym_AMP_AMP] = ACTIONS(4554),
    [anon_sym_PIPE_PIPE] = ACTIONS(4554),
    [anon_sym_QMARK_QMARK] = ACTIONS(4554),
    [anon_sym_from] = ACTIONS(4554),
    [anon_sym_join] = ACTIONS(4554),
    [anon_sym_on] = ACTIONS(4554),
    [anon_sym_equals] = ACTIONS(4554),
    [anon_sym_let] = ACTIONS(4554),
    [anon_sym_orderby] = ACTIONS(4554),
    [anon_sym_group] = ACTIONS(4554),
    [anon_sym_by] = ACTIONS(4554),
    [anon_sym_select] = ACTIONS(4554),
    [anon_sym_as] = ACTIONS(4554),
    [anon_sym_is] = ACTIONS(4554),
    [anon_sym_DASH_GT] = ACTIONS(4554),
    [anon_sym_with] = ACTIONS(4554),
    [aux_sym_preproc_if_token3] = ACTIONS(4554),
    [aux_sym_preproc_else_token1] = ACTIONS(4554),
    [aux_sym_preproc_elif_token1] = ACTIONS(4554),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3656] = {
    [sym_preproc_region] = STATE(3656),
    [sym_preproc_endregion] = STATE(3656),
    [sym_preproc_line] = STATE(3656),
    [sym_preproc_pragma] = STATE(3656),
    [sym_preproc_nullable] = STATE(3656),
    [sym_preproc_error] = STATE(3656),
    [sym_preproc_warning] = STATE(3656),
    [sym_preproc_define] = STATE(3656),
    [sym_preproc_undef] = STATE(3656),
    [anon_sym_SEMI] = ACTIONS(2993),
    [anon_sym_LBRACK] = ACTIONS(2993),
    [anon_sym_COLON] = ACTIONS(2993),
    [anon_sym_COMMA] = ACTIONS(2993),
    [anon_sym_RBRACK] = ACTIONS(2993),
    [anon_sym_LPAREN] = ACTIONS(2993),
    [anon_sym_RPAREN] = ACTIONS(2993),
    [anon_sym_RBRACE] = ACTIONS(2993),
    [anon_sym_LT] = ACTIONS(2991),
    [anon_sym_GT] = ACTIONS(2991),
    [anon_sym_in] = ACTIONS(2991),
    [anon_sym_where] = ACTIONS(2993),
    [anon_sym_QMARK] = ACTIONS(2991),
    [anon_sym_BANG] = ACTIONS(2991),
    [anon_sym_PLUS_PLUS] = ACTIONS(2993),
    [anon_sym_DASH_DASH] = ACTIONS(2993),
    [anon_sym_PLUS] = ACTIONS(2991),
    [anon_sym_DASH] = ACTIONS(2991),
    [anon_sym_STAR] = ACTIONS(2993),
    [anon_sym_SLASH] = ACTIONS(2991),
    [anon_sym_PERCENT] = ACTIONS(2993),
    [anon_sym_CARET] = ACTIONS(2993),
    [anon_sym_PIPE] = ACTIONS(2991),
    [anon_sym_AMP] = ACTIONS(2991),
    [anon_sym_LT_LT] = ACTIONS(2993),
    [anon_sym_GT_GT] = ACTIONS(2991),
    [anon_sym_GT_GT_GT] = ACTIONS(2993),
    [anon_sym_EQ_EQ] = ACTIONS(2993),
    [anon_sym_BANG_EQ] = ACTIONS(2993),
    [anon_sym_GT_EQ] = ACTIONS(2993),
    [anon_sym_LT_EQ] = ACTIONS(2993),
    [anon_sym_DOT] = ACTIONS(2991),
    [anon_sym_EQ_GT] = ACTIONS(2993),
    [anon_sym_switch] = ACTIONS(2993),
    [anon_sym_DOT_DOT] = ACTIONS(2993),
    [anon_sym_and] = ACTIONS(2993),
    [anon_sym_or] = ACTIONS(2991),
    [anon_sym_AMP_AMP] = ACTIONS(2993),
    [anon_sym_PIPE_PIPE] = ACTIONS(2993),
    [anon_sym_QMARK_QMARK] = ACTIONS(2993),
    [anon_sym_from] = ACTIONS(2993),
    [anon_sym_into] = ACTIONS(2993),
    [anon_sym_join] = ACTIONS(2993),
    [anon_sym_on] = ACTIONS(2993),
    [anon_sym_equals] = ACTIONS(2993),
    [anon_sym_let] = ACTIONS(2993),
    [anon_sym_orderby] = ACTIONS(2993),
    [anon_sym_group] = ACTIONS(2993),
    [anon_sym_by] = ACTIONS(2993),
    [anon_sym_select] = ACTIONS(2993),
    [anon_sym_as] = ACTIONS(2993),
    [anon_sym_is] = ACTIONS(2993),
    [anon_sym_DASH_GT] = ACTIONS(2993),
    [anon_sym_with] = ACTIONS(2993),
    [aux_sym_preproc_if_token3] = ACTIONS(2993),
    [aux_sym_preproc_else_token1] = ACTIONS(2993),
    [aux_sym_preproc_elif_token1] = ACTIONS(2993),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3657] = {
    [sym_preproc_region] = STATE(3657),
    [sym_preproc_endregion] = STATE(3657),
    [sym_preproc_line] = STATE(3657),
    [sym_preproc_pragma] = STATE(3657),
    [sym_preproc_nullable] = STATE(3657),
    [sym_preproc_error] = STATE(3657),
    [sym_preproc_warning] = STATE(3657),
    [sym_preproc_define] = STATE(3657),
    [sym_preproc_undef] = STATE(3657),
    [anon_sym_SEMI] = ACTIONS(5480),
    [anon_sym_LBRACK] = ACTIONS(5480),
    [anon_sym_COLON] = ACTIONS(5480),
    [anon_sym_COMMA] = ACTIONS(5480),
    [anon_sym_RBRACK] = ACTIONS(5480),
    [anon_sym_LPAREN] = ACTIONS(5480),
    [anon_sym_RPAREN] = ACTIONS(5480),
    [anon_sym_RBRACE] = ACTIONS(5480),
    [anon_sym_LT] = ACTIONS(5482),
    [anon_sym_GT] = ACTIONS(5482),
    [anon_sym_in] = ACTIONS(5482),
    [anon_sym_where] = ACTIONS(5480),
    [anon_sym_QMARK] = ACTIONS(5482),
    [anon_sym_BANG] = ACTIONS(5482),
    [anon_sym_PLUS_PLUS] = ACTIONS(5480),
    [anon_sym_DASH_DASH] = ACTIONS(5480),
    [anon_sym_PLUS] = ACTIONS(5482),
    [anon_sym_DASH] = ACTIONS(5482),
    [anon_sym_STAR] = ACTIONS(5480),
    [anon_sym_SLASH] = ACTIONS(5482),
    [anon_sym_PERCENT] = ACTIONS(5480),
    [anon_sym_CARET] = ACTIONS(5480),
    [anon_sym_PIPE] = ACTIONS(5482),
    [anon_sym_AMP] = ACTIONS(5482),
    [anon_sym_LT_LT] = ACTIONS(5480),
    [anon_sym_GT_GT] = ACTIONS(5482),
    [anon_sym_GT_GT_GT] = ACTIONS(5480),
    [anon_sym_EQ_EQ] = ACTIONS(5480),
    [anon_sym_BANG_EQ] = ACTIONS(5480),
    [anon_sym_GT_EQ] = ACTIONS(5480),
    [anon_sym_LT_EQ] = ACTIONS(5480),
    [anon_sym_DOT] = ACTIONS(5482),
    [anon_sym_EQ_GT] = ACTIONS(5480),
    [anon_sym_switch] = ACTIONS(5480),
    [anon_sym_DOT_DOT] = ACTIONS(5480),
    [anon_sym_and] = ACTIONS(5480),
    [anon_sym_or] = ACTIONS(5482),
    [anon_sym_AMP_AMP] = ACTIONS(5480),
    [anon_sym_PIPE_PIPE] = ACTIONS(5480),
    [anon_sym_QMARK_QMARK] = ACTIONS(5480),
    [anon_sym_from] = ACTIONS(5480),
    [anon_sym_into] = ACTIONS(5480),
    [anon_sym_join] = ACTIONS(5480),
    [anon_sym_on] = ACTIONS(5480),
    [anon_sym_equals] = ACTIONS(5480),
    [anon_sym_let] = ACTIONS(5480),
    [anon_sym_orderby] = ACTIONS(5480),
    [anon_sym_group] = ACTIONS(5480),
    [anon_sym_by] = ACTIONS(5480),
    [anon_sym_select] = ACTIONS(5480),
    [anon_sym_as] = ACTIONS(5480),
    [anon_sym_is] = ACTIONS(5480),
    [anon_sym_DASH_GT] = ACTIONS(5480),
    [anon_sym_with] = ACTIONS(5480),
    [aux_sym_preproc_if_token3] = ACTIONS(5480),
    [aux_sym_preproc_else_token1] = ACTIONS(5480),
    [aux_sym_preproc_elif_token1] = ACTIONS(5480),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3658] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter] = STATE(8629),
    [sym__parameter_array] = STATE(8634),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7375),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(6760),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3658),
    [sym_preproc_endregion] = STATE(3658),
    [sym_preproc_line] = STATE(3658),
    [sym_preproc_pragma] = STATE(3658),
    [sym_preproc_nullable] = STATE(3658),
    [sym_preproc_error] = STATE(3658),
    [sym_preproc_warning] = STATE(3658),
    [sym_preproc_define] = STATE(3658),
    [sym_preproc_undef] = STATE(3658),
    [aux_sym_class_declaration_repeat1] = STATE(3802),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LBRACK] = ACTIONS(5307),
    [anon_sym_RBRACK] = ACTIONS(5484),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(5309),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_in] = ACTIONS(1113),
    [anon_sym_out] = ACTIONS(1113),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_this] = ACTIONS(1113),
    [anon_sym_scoped] = ACTIONS(5321),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3659] = {
    [sym_preproc_region] = STATE(3659),
    [sym_preproc_endregion] = STATE(3659),
    [sym_preproc_line] = STATE(3659),
    [sym_preproc_pragma] = STATE(3659),
    [sym_preproc_nullable] = STATE(3659),
    [sym_preproc_error] = STATE(3659),
    [sym_preproc_warning] = STATE(3659),
    [sym_preproc_define] = STATE(3659),
    [sym_preproc_undef] = STATE(3659),
    [anon_sym_SEMI] = ACTIONS(5486),
    [anon_sym_LBRACK] = ACTIONS(5486),
    [anon_sym_COLON] = ACTIONS(5486),
    [anon_sym_COMMA] = ACTIONS(5486),
    [anon_sym_RBRACK] = ACTIONS(5486),
    [anon_sym_LPAREN] = ACTIONS(5486),
    [anon_sym_RPAREN] = ACTIONS(5486),
    [anon_sym_RBRACE] = ACTIONS(5486),
    [anon_sym_LT] = ACTIONS(5488),
    [anon_sym_GT] = ACTIONS(5488),
    [anon_sym_in] = ACTIONS(5488),
    [anon_sym_where] = ACTIONS(5486),
    [anon_sym_QMARK] = ACTIONS(5488),
    [anon_sym_BANG] = ACTIONS(5488),
    [anon_sym_PLUS_PLUS] = ACTIONS(5486),
    [anon_sym_DASH_DASH] = ACTIONS(5486),
    [anon_sym_PLUS] = ACTIONS(5488),
    [anon_sym_DASH] = ACTIONS(5488),
    [anon_sym_STAR] = ACTIONS(5486),
    [anon_sym_SLASH] = ACTIONS(5488),
    [anon_sym_PERCENT] = ACTIONS(5486),
    [anon_sym_CARET] = ACTIONS(5486),
    [anon_sym_PIPE] = ACTIONS(5488),
    [anon_sym_AMP] = ACTIONS(5488),
    [anon_sym_LT_LT] = ACTIONS(5486),
    [anon_sym_GT_GT] = ACTIONS(5488),
    [anon_sym_GT_GT_GT] = ACTIONS(5486),
    [anon_sym_EQ_EQ] = ACTIONS(5486),
    [anon_sym_BANG_EQ] = ACTIONS(5486),
    [anon_sym_GT_EQ] = ACTIONS(5486),
    [anon_sym_LT_EQ] = ACTIONS(5486),
    [anon_sym_DOT] = ACTIONS(5488),
    [anon_sym_EQ_GT] = ACTIONS(5486),
    [anon_sym_switch] = ACTIONS(5486),
    [anon_sym_DOT_DOT] = ACTIONS(5486),
    [anon_sym_and] = ACTIONS(5486),
    [anon_sym_or] = ACTIONS(5488),
    [anon_sym_AMP_AMP] = ACTIONS(5486),
    [anon_sym_PIPE_PIPE] = ACTIONS(5486),
    [anon_sym_QMARK_QMARK] = ACTIONS(5486),
    [anon_sym_from] = ACTIONS(5486),
    [anon_sym_into] = ACTIONS(5486),
    [anon_sym_join] = ACTIONS(5486),
    [anon_sym_on] = ACTIONS(5486),
    [anon_sym_equals] = ACTIONS(5486),
    [anon_sym_let] = ACTIONS(5486),
    [anon_sym_orderby] = ACTIONS(5486),
    [anon_sym_group] = ACTIONS(5486),
    [anon_sym_by] = ACTIONS(5486),
    [anon_sym_select] = ACTIONS(5486),
    [anon_sym_as] = ACTIONS(5486),
    [anon_sym_is] = ACTIONS(5486),
    [anon_sym_DASH_GT] = ACTIONS(5486),
    [anon_sym_with] = ACTIONS(5486),
    [aux_sym_preproc_if_token3] = ACTIONS(5486),
    [aux_sym_preproc_else_token1] = ACTIONS(5486),
    [aux_sym_preproc_elif_token1] = ACTIONS(5486),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3660] = {
    [sym_preproc_region] = STATE(3660),
    [sym_preproc_endregion] = STATE(3660),
    [sym_preproc_line] = STATE(3660),
    [sym_preproc_pragma] = STATE(3660),
    [sym_preproc_nullable] = STATE(3660),
    [sym_preproc_error] = STATE(3660),
    [sym_preproc_warning] = STATE(3660),
    [sym_preproc_define] = STATE(3660),
    [sym_preproc_undef] = STATE(3660),
    [anon_sym_SEMI] = ACTIONS(5490),
    [anon_sym_LBRACK] = ACTIONS(5490),
    [anon_sym_COLON] = ACTIONS(5490),
    [anon_sym_COMMA] = ACTIONS(5490),
    [anon_sym_RBRACK] = ACTIONS(5490),
    [anon_sym_LPAREN] = ACTIONS(5490),
    [anon_sym_RPAREN] = ACTIONS(5490),
    [anon_sym_RBRACE] = ACTIONS(5490),
    [anon_sym_LT] = ACTIONS(5492),
    [anon_sym_GT] = ACTIONS(5492),
    [anon_sym_in] = ACTIONS(5492),
    [anon_sym_where] = ACTIONS(5490),
    [anon_sym_QMARK] = ACTIONS(5492),
    [anon_sym_BANG] = ACTIONS(5492),
    [anon_sym_PLUS_PLUS] = ACTIONS(5490),
    [anon_sym_DASH_DASH] = ACTIONS(5490),
    [anon_sym_PLUS] = ACTIONS(5492),
    [anon_sym_DASH] = ACTIONS(5492),
    [anon_sym_STAR] = ACTIONS(5490),
    [anon_sym_SLASH] = ACTIONS(5492),
    [anon_sym_PERCENT] = ACTIONS(5490),
    [anon_sym_CARET] = ACTIONS(5490),
    [anon_sym_PIPE] = ACTIONS(5492),
    [anon_sym_AMP] = ACTIONS(5492),
    [anon_sym_LT_LT] = ACTIONS(5490),
    [anon_sym_GT_GT] = ACTIONS(5492),
    [anon_sym_GT_GT_GT] = ACTIONS(5490),
    [anon_sym_EQ_EQ] = ACTIONS(5490),
    [anon_sym_BANG_EQ] = ACTIONS(5490),
    [anon_sym_GT_EQ] = ACTIONS(5490),
    [anon_sym_LT_EQ] = ACTIONS(5490),
    [anon_sym_DOT] = ACTIONS(5492),
    [anon_sym_EQ_GT] = ACTIONS(5490),
    [anon_sym_switch] = ACTIONS(5490),
    [anon_sym_DOT_DOT] = ACTIONS(5490),
    [anon_sym_and] = ACTIONS(5490),
    [anon_sym_or] = ACTIONS(5492),
    [anon_sym_AMP_AMP] = ACTIONS(5490),
    [anon_sym_PIPE_PIPE] = ACTIONS(5490),
    [anon_sym_QMARK_QMARK] = ACTIONS(5490),
    [anon_sym_from] = ACTIONS(5490),
    [anon_sym_into] = ACTIONS(5490),
    [anon_sym_join] = ACTIONS(5490),
    [anon_sym_on] = ACTIONS(5490),
    [anon_sym_equals] = ACTIONS(5490),
    [anon_sym_let] = ACTIONS(5490),
    [anon_sym_orderby] = ACTIONS(5490),
    [anon_sym_group] = ACTIONS(5490),
    [anon_sym_by] = ACTIONS(5490),
    [anon_sym_select] = ACTIONS(5490),
    [anon_sym_as] = ACTIONS(5490),
    [anon_sym_is] = ACTIONS(5490),
    [anon_sym_DASH_GT] = ACTIONS(5490),
    [anon_sym_with] = ACTIONS(5490),
    [aux_sym_preproc_if_token3] = ACTIONS(5490),
    [aux_sym_preproc_else_token1] = ACTIONS(5490),
    [aux_sym_preproc_elif_token1] = ACTIONS(5490),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3661] = {
    [sym_preproc_region] = STATE(3661),
    [sym_preproc_endregion] = STATE(3661),
    [sym_preproc_line] = STATE(3661),
    [sym_preproc_pragma] = STATE(3661),
    [sym_preproc_nullable] = STATE(3661),
    [sym_preproc_error] = STATE(3661),
    [sym_preproc_warning] = STATE(3661),
    [sym_preproc_define] = STATE(3661),
    [sym_preproc_undef] = STATE(3661),
    [anon_sym_SEMI] = ACTIONS(5494),
    [anon_sym_LBRACK] = ACTIONS(5494),
    [anon_sym_COLON] = ACTIONS(5494),
    [anon_sym_COMMA] = ACTIONS(5494),
    [anon_sym_RBRACK] = ACTIONS(5494),
    [anon_sym_LPAREN] = ACTIONS(5494),
    [anon_sym_RPAREN] = ACTIONS(5494),
    [anon_sym_RBRACE] = ACTIONS(5494),
    [anon_sym_LT] = ACTIONS(5496),
    [anon_sym_GT] = ACTIONS(5496),
    [anon_sym_in] = ACTIONS(5496),
    [anon_sym_where] = ACTIONS(5494),
    [anon_sym_QMARK] = ACTIONS(5496),
    [anon_sym_BANG] = ACTIONS(5496),
    [anon_sym_PLUS_PLUS] = ACTIONS(5494),
    [anon_sym_DASH_DASH] = ACTIONS(5494),
    [anon_sym_PLUS] = ACTIONS(5496),
    [anon_sym_DASH] = ACTIONS(5496),
    [anon_sym_STAR] = ACTIONS(5494),
    [anon_sym_SLASH] = ACTIONS(5496),
    [anon_sym_PERCENT] = ACTIONS(5494),
    [anon_sym_CARET] = ACTIONS(5494),
    [anon_sym_PIPE] = ACTIONS(5496),
    [anon_sym_AMP] = ACTIONS(5496),
    [anon_sym_LT_LT] = ACTIONS(5494),
    [anon_sym_GT_GT] = ACTIONS(5496),
    [anon_sym_GT_GT_GT] = ACTIONS(5494),
    [anon_sym_EQ_EQ] = ACTIONS(5494),
    [anon_sym_BANG_EQ] = ACTIONS(5494),
    [anon_sym_GT_EQ] = ACTIONS(5494),
    [anon_sym_LT_EQ] = ACTIONS(5494),
    [anon_sym_DOT] = ACTIONS(5496),
    [anon_sym_EQ_GT] = ACTIONS(5494),
    [anon_sym_switch] = ACTIONS(5494),
    [anon_sym_DOT_DOT] = ACTIONS(5494),
    [anon_sym_and] = ACTIONS(5494),
    [anon_sym_or] = ACTIONS(5496),
    [anon_sym_AMP_AMP] = ACTIONS(5494),
    [anon_sym_PIPE_PIPE] = ACTIONS(5494),
    [anon_sym_QMARK_QMARK] = ACTIONS(5494),
    [anon_sym_from] = ACTIONS(5494),
    [anon_sym_into] = ACTIONS(5494),
    [anon_sym_join] = ACTIONS(5494),
    [anon_sym_on] = ACTIONS(5494),
    [anon_sym_equals] = ACTIONS(5494),
    [anon_sym_let] = ACTIONS(5494),
    [anon_sym_orderby] = ACTIONS(5494),
    [anon_sym_group] = ACTIONS(5494),
    [anon_sym_by] = ACTIONS(5494),
    [anon_sym_select] = ACTIONS(5494),
    [anon_sym_as] = ACTIONS(5494),
    [anon_sym_is] = ACTIONS(5494),
    [anon_sym_DASH_GT] = ACTIONS(5494),
    [anon_sym_with] = ACTIONS(5494),
    [aux_sym_preproc_if_token3] = ACTIONS(5494),
    [aux_sym_preproc_else_token1] = ACTIONS(5494),
    [aux_sym_preproc_elif_token1] = ACTIONS(5494),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3662] = {
    [sym_preproc_region] = STATE(3662),
    [sym_preproc_endregion] = STATE(3662),
    [sym_preproc_line] = STATE(3662),
    [sym_preproc_pragma] = STATE(3662),
    [sym_preproc_nullable] = STATE(3662),
    [sym_preproc_error] = STATE(3662),
    [sym_preproc_warning] = STATE(3662),
    [sym_preproc_define] = STATE(3662),
    [sym_preproc_undef] = STATE(3662),
    [anon_sym_SEMI] = ACTIONS(5498),
    [anon_sym_LBRACK] = ACTIONS(5498),
    [anon_sym_COLON] = ACTIONS(5498),
    [anon_sym_COMMA] = ACTIONS(5498),
    [anon_sym_RBRACK] = ACTIONS(5498),
    [anon_sym_LPAREN] = ACTIONS(5498),
    [anon_sym_RPAREN] = ACTIONS(5498),
    [anon_sym_RBRACE] = ACTIONS(5498),
    [anon_sym_LT] = ACTIONS(5500),
    [anon_sym_GT] = ACTIONS(5500),
    [anon_sym_in] = ACTIONS(5500),
    [anon_sym_where] = ACTIONS(5498),
    [anon_sym_QMARK] = ACTIONS(5500),
    [anon_sym_BANG] = ACTIONS(5500),
    [anon_sym_PLUS_PLUS] = ACTIONS(5498),
    [anon_sym_DASH_DASH] = ACTIONS(5498),
    [anon_sym_PLUS] = ACTIONS(5500),
    [anon_sym_DASH] = ACTIONS(5500),
    [anon_sym_STAR] = ACTIONS(5498),
    [anon_sym_SLASH] = ACTIONS(5500),
    [anon_sym_PERCENT] = ACTIONS(5498),
    [anon_sym_CARET] = ACTIONS(5498),
    [anon_sym_PIPE] = ACTIONS(5500),
    [anon_sym_AMP] = ACTIONS(5500),
    [anon_sym_LT_LT] = ACTIONS(5498),
    [anon_sym_GT_GT] = ACTIONS(5500),
    [anon_sym_GT_GT_GT] = ACTIONS(5498),
    [anon_sym_EQ_EQ] = ACTIONS(5498),
    [anon_sym_BANG_EQ] = ACTIONS(5498),
    [anon_sym_GT_EQ] = ACTIONS(5498),
    [anon_sym_LT_EQ] = ACTIONS(5498),
    [anon_sym_DOT] = ACTIONS(5500),
    [anon_sym_EQ_GT] = ACTIONS(5498),
    [anon_sym_switch] = ACTIONS(5498),
    [anon_sym_DOT_DOT] = ACTIONS(5498),
    [anon_sym_and] = ACTIONS(5498),
    [anon_sym_or] = ACTIONS(5500),
    [anon_sym_AMP_AMP] = ACTIONS(5498),
    [anon_sym_PIPE_PIPE] = ACTIONS(5498),
    [anon_sym_QMARK_QMARK] = ACTIONS(5498),
    [anon_sym_from] = ACTIONS(5498),
    [anon_sym_into] = ACTIONS(5498),
    [anon_sym_join] = ACTIONS(5498),
    [anon_sym_on] = ACTIONS(5498),
    [anon_sym_equals] = ACTIONS(5498),
    [anon_sym_let] = ACTIONS(5498),
    [anon_sym_orderby] = ACTIONS(5498),
    [anon_sym_group] = ACTIONS(5498),
    [anon_sym_by] = ACTIONS(5498),
    [anon_sym_select] = ACTIONS(5498),
    [anon_sym_as] = ACTIONS(5498),
    [anon_sym_is] = ACTIONS(5498),
    [anon_sym_DASH_GT] = ACTIONS(5498),
    [anon_sym_with] = ACTIONS(5498),
    [aux_sym_preproc_if_token3] = ACTIONS(5498),
    [aux_sym_preproc_else_token1] = ACTIONS(5498),
    [aux_sym_preproc_elif_token1] = ACTIONS(5498),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3663] = {
    [sym_preproc_region] = STATE(3663),
    [sym_preproc_endregion] = STATE(3663),
    [sym_preproc_line] = STATE(3663),
    [sym_preproc_pragma] = STATE(3663),
    [sym_preproc_nullable] = STATE(3663),
    [sym_preproc_error] = STATE(3663),
    [sym_preproc_warning] = STATE(3663),
    [sym_preproc_define] = STATE(3663),
    [sym_preproc_undef] = STATE(3663),
    [anon_sym_SEMI] = ACTIONS(5502),
    [anon_sym_LBRACK] = ACTIONS(5502),
    [anon_sym_COLON] = ACTIONS(5502),
    [anon_sym_COMMA] = ACTIONS(5502),
    [anon_sym_RBRACK] = ACTIONS(5502),
    [anon_sym_LPAREN] = ACTIONS(5502),
    [anon_sym_RPAREN] = ACTIONS(5502),
    [anon_sym_RBRACE] = ACTIONS(5502),
    [anon_sym_LT] = ACTIONS(5504),
    [anon_sym_GT] = ACTIONS(5504),
    [anon_sym_in] = ACTIONS(5504),
    [anon_sym_where] = ACTIONS(5502),
    [anon_sym_QMARK] = ACTIONS(5504),
    [anon_sym_BANG] = ACTIONS(5504),
    [anon_sym_PLUS_PLUS] = ACTIONS(5502),
    [anon_sym_DASH_DASH] = ACTIONS(5502),
    [anon_sym_PLUS] = ACTIONS(5504),
    [anon_sym_DASH] = ACTIONS(5504),
    [anon_sym_STAR] = ACTIONS(5502),
    [anon_sym_SLASH] = ACTIONS(5504),
    [anon_sym_PERCENT] = ACTIONS(5502),
    [anon_sym_CARET] = ACTIONS(5502),
    [anon_sym_PIPE] = ACTIONS(5504),
    [anon_sym_AMP] = ACTIONS(5504),
    [anon_sym_LT_LT] = ACTIONS(5502),
    [anon_sym_GT_GT] = ACTIONS(5504),
    [anon_sym_GT_GT_GT] = ACTIONS(5502),
    [anon_sym_EQ_EQ] = ACTIONS(5502),
    [anon_sym_BANG_EQ] = ACTIONS(5502),
    [anon_sym_GT_EQ] = ACTIONS(5502),
    [anon_sym_LT_EQ] = ACTIONS(5502),
    [anon_sym_DOT] = ACTIONS(5504),
    [anon_sym_EQ_GT] = ACTIONS(5502),
    [anon_sym_switch] = ACTIONS(5502),
    [anon_sym_DOT_DOT] = ACTIONS(5502),
    [anon_sym_and] = ACTIONS(5502),
    [anon_sym_or] = ACTIONS(5504),
    [anon_sym_AMP_AMP] = ACTIONS(5502),
    [anon_sym_PIPE_PIPE] = ACTIONS(5502),
    [anon_sym_QMARK_QMARK] = ACTIONS(5502),
    [anon_sym_from] = ACTIONS(5502),
    [anon_sym_into] = ACTIONS(5502),
    [anon_sym_join] = ACTIONS(5502),
    [anon_sym_on] = ACTIONS(5502),
    [anon_sym_equals] = ACTIONS(5502),
    [anon_sym_let] = ACTIONS(5502),
    [anon_sym_orderby] = ACTIONS(5502),
    [anon_sym_group] = ACTIONS(5502),
    [anon_sym_by] = ACTIONS(5502),
    [anon_sym_select] = ACTIONS(5502),
    [anon_sym_as] = ACTIONS(5502),
    [anon_sym_is] = ACTIONS(5502),
    [anon_sym_DASH_GT] = ACTIONS(5502),
    [anon_sym_with] = ACTIONS(5502),
    [aux_sym_preproc_if_token3] = ACTIONS(5502),
    [aux_sym_preproc_else_token1] = ACTIONS(5502),
    [aux_sym_preproc_elif_token1] = ACTIONS(5502),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3664] = {
    [sym_preproc_region] = STATE(3664),
    [sym_preproc_endregion] = STATE(3664),
    [sym_preproc_line] = STATE(3664),
    [sym_preproc_pragma] = STATE(3664),
    [sym_preproc_nullable] = STATE(3664),
    [sym_preproc_error] = STATE(3664),
    [sym_preproc_warning] = STATE(3664),
    [sym_preproc_define] = STATE(3664),
    [sym_preproc_undef] = STATE(3664),
    [anon_sym_SEMI] = ACTIONS(4151),
    [anon_sym_LBRACK] = ACTIONS(4151),
    [anon_sym_COLON] = ACTIONS(4151),
    [anon_sym_COMMA] = ACTIONS(4151),
    [anon_sym_RBRACK] = ACTIONS(4151),
    [anon_sym_LPAREN] = ACTIONS(4151),
    [anon_sym_RPAREN] = ACTIONS(4151),
    [anon_sym_LBRACE] = ACTIONS(4151),
    [anon_sym_RBRACE] = ACTIONS(4151),
    [anon_sym_LT] = ACTIONS(4149),
    [anon_sym_GT] = ACTIONS(4149),
    [anon_sym_in] = ACTIONS(4151),
    [anon_sym_where] = ACTIONS(4151),
    [anon_sym_QMARK] = ACTIONS(4149),
    [anon_sym_BANG] = ACTIONS(4149),
    [anon_sym_PLUS_PLUS] = ACTIONS(4151),
    [anon_sym_DASH_DASH] = ACTIONS(4151),
    [anon_sym_PLUS] = ACTIONS(4149),
    [anon_sym_DASH] = ACTIONS(4149),
    [anon_sym_STAR] = ACTIONS(4151),
    [anon_sym_SLASH] = ACTIONS(4149),
    [anon_sym_PERCENT] = ACTIONS(4151),
    [anon_sym_CARET] = ACTIONS(4151),
    [anon_sym_PIPE] = ACTIONS(4149),
    [anon_sym_AMP] = ACTIONS(4149),
    [anon_sym_LT_LT] = ACTIONS(4151),
    [anon_sym_GT_GT] = ACTIONS(4149),
    [anon_sym_GT_GT_GT] = ACTIONS(4151),
    [anon_sym_EQ_EQ] = ACTIONS(4151),
    [anon_sym_BANG_EQ] = ACTIONS(4151),
    [anon_sym_GT_EQ] = ACTIONS(4151),
    [anon_sym_LT_EQ] = ACTIONS(4151),
    [anon_sym_DOT] = ACTIONS(4149),
    [anon_sym_EQ_GT] = ACTIONS(4151),
    [anon_sym_switch] = ACTIONS(4151),
    [anon_sym_DOT_DOT] = ACTIONS(4151),
    [anon_sym_and] = ACTIONS(4151),
    [anon_sym_or] = ACTIONS(4149),
    [anon_sym_AMP_AMP] = ACTIONS(4151),
    [anon_sym_PIPE_PIPE] = ACTIONS(4151),
    [anon_sym_QMARK_QMARK] = ACTIONS(4151),
    [anon_sym_from] = ACTIONS(4151),
    [anon_sym_join] = ACTIONS(4151),
    [anon_sym_on] = ACTIONS(4151),
    [anon_sym_equals] = ACTIONS(4151),
    [anon_sym_let] = ACTIONS(4151),
    [anon_sym_orderby] = ACTIONS(4151),
    [anon_sym_group] = ACTIONS(4151),
    [anon_sym_by] = ACTIONS(4151),
    [anon_sym_select] = ACTIONS(4151),
    [anon_sym_as] = ACTIONS(4151),
    [anon_sym_is] = ACTIONS(4151),
    [anon_sym_DASH_GT] = ACTIONS(4151),
    [anon_sym_with] = ACTIONS(4151),
    [aux_sym_preproc_if_token3] = ACTIONS(4151),
    [aux_sym_preproc_else_token1] = ACTIONS(4151),
    [aux_sym_preproc_elif_token1] = ACTIONS(4151),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3665] = {
    [sym_preproc_region] = STATE(3665),
    [sym_preproc_endregion] = STATE(3665),
    [sym_preproc_line] = STATE(3665),
    [sym_preproc_pragma] = STATE(3665),
    [sym_preproc_nullable] = STATE(3665),
    [sym_preproc_error] = STATE(3665),
    [sym_preproc_warning] = STATE(3665),
    [sym_preproc_define] = STATE(3665),
    [sym_preproc_undef] = STATE(3665),
    [anon_sym_SEMI] = ACTIONS(4765),
    [anon_sym_LBRACK] = ACTIONS(4765),
    [anon_sym_COLON] = ACTIONS(4765),
    [anon_sym_COMMA] = ACTIONS(4765),
    [anon_sym_RBRACK] = ACTIONS(4765),
    [anon_sym_LPAREN] = ACTIONS(4765),
    [anon_sym_RPAREN] = ACTIONS(4765),
    [anon_sym_RBRACE] = ACTIONS(4765),
    [anon_sym_LT] = ACTIONS(4767),
    [anon_sym_GT] = ACTIONS(4767),
    [anon_sym_in] = ACTIONS(4767),
    [anon_sym_where] = ACTIONS(4765),
    [anon_sym_QMARK] = ACTIONS(4767),
    [anon_sym_BANG] = ACTIONS(4767),
    [anon_sym_PLUS_PLUS] = ACTIONS(4765),
    [anon_sym_DASH_DASH] = ACTIONS(4765),
    [anon_sym_PLUS] = ACTIONS(4767),
    [anon_sym_DASH] = ACTIONS(4767),
    [anon_sym_STAR] = ACTIONS(4765),
    [anon_sym_SLASH] = ACTIONS(4767),
    [anon_sym_PERCENT] = ACTIONS(4765),
    [anon_sym_CARET] = ACTIONS(4765),
    [anon_sym_PIPE] = ACTIONS(4767),
    [anon_sym_AMP] = ACTIONS(4767),
    [anon_sym_LT_LT] = ACTIONS(4765),
    [anon_sym_GT_GT] = ACTIONS(4767),
    [anon_sym_GT_GT_GT] = ACTIONS(4765),
    [anon_sym_EQ_EQ] = ACTIONS(4765),
    [anon_sym_BANG_EQ] = ACTIONS(4765),
    [anon_sym_GT_EQ] = ACTIONS(4765),
    [anon_sym_LT_EQ] = ACTIONS(4765),
    [anon_sym_DOT] = ACTIONS(4767),
    [anon_sym_EQ_GT] = ACTIONS(4765),
    [anon_sym_switch] = ACTIONS(4765),
    [anon_sym_DOT_DOT] = ACTIONS(4765),
    [anon_sym_and] = ACTIONS(4765),
    [anon_sym_or] = ACTIONS(4767),
    [anon_sym_AMP_AMP] = ACTIONS(4765),
    [anon_sym_PIPE_PIPE] = ACTIONS(4765),
    [anon_sym_QMARK_QMARK] = ACTIONS(4765),
    [anon_sym_from] = ACTIONS(4765),
    [anon_sym_into] = ACTIONS(4765),
    [anon_sym_join] = ACTIONS(4765),
    [anon_sym_on] = ACTIONS(4765),
    [anon_sym_equals] = ACTIONS(4765),
    [anon_sym_let] = ACTIONS(4765),
    [anon_sym_orderby] = ACTIONS(4765),
    [anon_sym_group] = ACTIONS(4765),
    [anon_sym_by] = ACTIONS(4765),
    [anon_sym_select] = ACTIONS(4765),
    [anon_sym_as] = ACTIONS(4765),
    [anon_sym_is] = ACTIONS(4765),
    [anon_sym_DASH_GT] = ACTIONS(4765),
    [anon_sym_with] = ACTIONS(4765),
    [aux_sym_preproc_if_token3] = ACTIONS(4765),
    [aux_sym_preproc_else_token1] = ACTIONS(4765),
    [aux_sym_preproc_elif_token1] = ACTIONS(4765),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3666] = {
    [sym_preproc_region] = STATE(3666),
    [sym_preproc_endregion] = STATE(3666),
    [sym_preproc_line] = STATE(3666),
    [sym_preproc_pragma] = STATE(3666),
    [sym_preproc_nullable] = STATE(3666),
    [sym_preproc_error] = STATE(3666),
    [sym_preproc_warning] = STATE(3666),
    [sym_preproc_define] = STATE(3666),
    [sym_preproc_undef] = STATE(3666),
    [anon_sym_SEMI] = ACTIONS(5506),
    [anon_sym_LBRACK] = ACTIONS(5506),
    [anon_sym_COLON] = ACTIONS(5506),
    [anon_sym_COMMA] = ACTIONS(5506),
    [anon_sym_RBRACK] = ACTIONS(5506),
    [anon_sym_LPAREN] = ACTIONS(5506),
    [anon_sym_RPAREN] = ACTIONS(5506),
    [anon_sym_RBRACE] = ACTIONS(5506),
    [anon_sym_LT] = ACTIONS(5508),
    [anon_sym_GT] = ACTIONS(5508),
    [anon_sym_in] = ACTIONS(5508),
    [anon_sym_where] = ACTIONS(5506),
    [anon_sym_QMARK] = ACTIONS(5508),
    [anon_sym_BANG] = ACTIONS(5508),
    [anon_sym_PLUS_PLUS] = ACTIONS(5506),
    [anon_sym_DASH_DASH] = ACTIONS(5506),
    [anon_sym_PLUS] = ACTIONS(5508),
    [anon_sym_DASH] = ACTIONS(5508),
    [anon_sym_STAR] = ACTIONS(5506),
    [anon_sym_SLASH] = ACTIONS(5508),
    [anon_sym_PERCENT] = ACTIONS(5506),
    [anon_sym_CARET] = ACTIONS(5506),
    [anon_sym_PIPE] = ACTIONS(5508),
    [anon_sym_AMP] = ACTIONS(5508),
    [anon_sym_LT_LT] = ACTIONS(5506),
    [anon_sym_GT_GT] = ACTIONS(5508),
    [anon_sym_GT_GT_GT] = ACTIONS(5506),
    [anon_sym_EQ_EQ] = ACTIONS(5506),
    [anon_sym_BANG_EQ] = ACTIONS(5506),
    [anon_sym_GT_EQ] = ACTIONS(5506),
    [anon_sym_LT_EQ] = ACTIONS(5506),
    [anon_sym_DOT] = ACTIONS(5508),
    [anon_sym_EQ_GT] = ACTIONS(5506),
    [anon_sym_switch] = ACTIONS(5506),
    [anon_sym_DOT_DOT] = ACTIONS(5506),
    [anon_sym_and] = ACTIONS(5506),
    [anon_sym_or] = ACTIONS(5508),
    [anon_sym_AMP_AMP] = ACTIONS(5506),
    [anon_sym_PIPE_PIPE] = ACTIONS(5506),
    [anon_sym_QMARK_QMARK] = ACTIONS(5506),
    [anon_sym_from] = ACTIONS(5506),
    [anon_sym_into] = ACTIONS(5506),
    [anon_sym_join] = ACTIONS(5506),
    [anon_sym_on] = ACTIONS(5506),
    [anon_sym_equals] = ACTIONS(5506),
    [anon_sym_let] = ACTIONS(5506),
    [anon_sym_orderby] = ACTIONS(5506),
    [anon_sym_group] = ACTIONS(5506),
    [anon_sym_by] = ACTIONS(5506),
    [anon_sym_select] = ACTIONS(5506),
    [anon_sym_as] = ACTIONS(5506),
    [anon_sym_is] = ACTIONS(5506),
    [anon_sym_DASH_GT] = ACTIONS(5506),
    [anon_sym_with] = ACTIONS(5506),
    [aux_sym_preproc_if_token3] = ACTIONS(5506),
    [aux_sym_preproc_else_token1] = ACTIONS(5506),
    [aux_sym_preproc_elif_token1] = ACTIONS(5506),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3667] = {
    [sym_preproc_region] = STATE(3667),
    [sym_preproc_endregion] = STATE(3667),
    [sym_preproc_line] = STATE(3667),
    [sym_preproc_pragma] = STATE(3667),
    [sym_preproc_nullable] = STATE(3667),
    [sym_preproc_error] = STATE(3667),
    [sym_preproc_warning] = STATE(3667),
    [sym_preproc_define] = STATE(3667),
    [sym_preproc_undef] = STATE(3667),
    [anon_sym_SEMI] = ACTIONS(5510),
    [anon_sym_LBRACK] = ACTIONS(5510),
    [anon_sym_COLON] = ACTIONS(5510),
    [anon_sym_COMMA] = ACTIONS(5510),
    [anon_sym_RBRACK] = ACTIONS(5510),
    [anon_sym_LPAREN] = ACTIONS(5510),
    [anon_sym_RPAREN] = ACTIONS(5510),
    [anon_sym_RBRACE] = ACTIONS(5510),
    [anon_sym_LT] = ACTIONS(5512),
    [anon_sym_GT] = ACTIONS(5512),
    [anon_sym_in] = ACTIONS(5512),
    [anon_sym_where] = ACTIONS(5510),
    [anon_sym_QMARK] = ACTIONS(5512),
    [anon_sym_BANG] = ACTIONS(5512),
    [anon_sym_PLUS_PLUS] = ACTIONS(5510),
    [anon_sym_DASH_DASH] = ACTIONS(5510),
    [anon_sym_PLUS] = ACTIONS(5512),
    [anon_sym_DASH] = ACTIONS(5512),
    [anon_sym_STAR] = ACTIONS(5510),
    [anon_sym_SLASH] = ACTIONS(5512),
    [anon_sym_PERCENT] = ACTIONS(5510),
    [anon_sym_CARET] = ACTIONS(5510),
    [anon_sym_PIPE] = ACTIONS(5512),
    [anon_sym_AMP] = ACTIONS(5512),
    [anon_sym_LT_LT] = ACTIONS(5510),
    [anon_sym_GT_GT] = ACTIONS(5512),
    [anon_sym_GT_GT_GT] = ACTIONS(5510),
    [anon_sym_EQ_EQ] = ACTIONS(5510),
    [anon_sym_BANG_EQ] = ACTIONS(5510),
    [anon_sym_GT_EQ] = ACTIONS(5510),
    [anon_sym_LT_EQ] = ACTIONS(5510),
    [anon_sym_DOT] = ACTIONS(5512),
    [anon_sym_EQ_GT] = ACTIONS(5510),
    [anon_sym_switch] = ACTIONS(5510),
    [anon_sym_DOT_DOT] = ACTIONS(5510),
    [anon_sym_and] = ACTIONS(5510),
    [anon_sym_or] = ACTIONS(5512),
    [anon_sym_AMP_AMP] = ACTIONS(5510),
    [anon_sym_PIPE_PIPE] = ACTIONS(5510),
    [anon_sym_QMARK_QMARK] = ACTIONS(5510),
    [anon_sym_from] = ACTIONS(5510),
    [anon_sym_into] = ACTIONS(5510),
    [anon_sym_join] = ACTIONS(5510),
    [anon_sym_on] = ACTIONS(5510),
    [anon_sym_equals] = ACTIONS(5510),
    [anon_sym_let] = ACTIONS(5510),
    [anon_sym_orderby] = ACTIONS(5510),
    [anon_sym_group] = ACTIONS(5510),
    [anon_sym_by] = ACTIONS(5510),
    [anon_sym_select] = ACTIONS(5510),
    [anon_sym_as] = ACTIONS(5510),
    [anon_sym_is] = ACTIONS(5510),
    [anon_sym_DASH_GT] = ACTIONS(5510),
    [anon_sym_with] = ACTIONS(5510),
    [aux_sym_preproc_if_token3] = ACTIONS(5510),
    [aux_sym_preproc_else_token1] = ACTIONS(5510),
    [aux_sym_preproc_elif_token1] = ACTIONS(5510),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3668] = {
    [sym_preproc_region] = STATE(3668),
    [sym_preproc_endregion] = STATE(3668),
    [sym_preproc_line] = STATE(3668),
    [sym_preproc_pragma] = STATE(3668),
    [sym_preproc_nullable] = STATE(3668),
    [sym_preproc_error] = STATE(3668),
    [sym_preproc_warning] = STATE(3668),
    [sym_preproc_define] = STATE(3668),
    [sym_preproc_undef] = STATE(3668),
    [anon_sym_SEMI] = ACTIONS(2035),
    [anon_sym_LBRACK] = ACTIONS(2035),
    [anon_sym_COLON] = ACTIONS(2035),
    [anon_sym_COMMA] = ACTIONS(2035),
    [anon_sym_RBRACK] = ACTIONS(2035),
    [anon_sym_LPAREN] = ACTIONS(2035),
    [anon_sym_RPAREN] = ACTIONS(2035),
    [anon_sym_RBRACE] = ACTIONS(2035),
    [anon_sym_LT] = ACTIONS(2037),
    [anon_sym_GT] = ACTIONS(2037),
    [anon_sym_in] = ACTIONS(2037),
    [anon_sym_where] = ACTIONS(2035),
    [anon_sym_QMARK] = ACTIONS(2037),
    [anon_sym_BANG] = ACTIONS(2037),
    [anon_sym_PLUS_PLUS] = ACTIONS(2035),
    [anon_sym_DASH_DASH] = ACTIONS(2035),
    [anon_sym_PLUS] = ACTIONS(2037),
    [anon_sym_DASH] = ACTIONS(2037),
    [anon_sym_STAR] = ACTIONS(2035),
    [anon_sym_SLASH] = ACTIONS(2037),
    [anon_sym_PERCENT] = ACTIONS(2035),
    [anon_sym_CARET] = ACTIONS(2035),
    [anon_sym_PIPE] = ACTIONS(2037),
    [anon_sym_AMP] = ACTIONS(2037),
    [anon_sym_LT_LT] = ACTIONS(2035),
    [anon_sym_GT_GT] = ACTIONS(2037),
    [anon_sym_GT_GT_GT] = ACTIONS(2035),
    [anon_sym_EQ_EQ] = ACTIONS(2035),
    [anon_sym_BANG_EQ] = ACTIONS(2035),
    [anon_sym_GT_EQ] = ACTIONS(2035),
    [anon_sym_LT_EQ] = ACTIONS(2035),
    [anon_sym_DOT] = ACTIONS(2037),
    [anon_sym_EQ_GT] = ACTIONS(2035),
    [anon_sym_switch] = ACTIONS(2035),
    [anon_sym_DOT_DOT] = ACTIONS(2035),
    [anon_sym_and] = ACTIONS(2035),
    [anon_sym_or] = ACTIONS(2037),
    [anon_sym_AMP_AMP] = ACTIONS(2035),
    [anon_sym_PIPE_PIPE] = ACTIONS(2035),
    [anon_sym_QMARK_QMARK] = ACTIONS(2035),
    [anon_sym_from] = ACTIONS(2035),
    [anon_sym_into] = ACTIONS(2035),
    [anon_sym_join] = ACTIONS(2035),
    [anon_sym_on] = ACTIONS(2035),
    [anon_sym_equals] = ACTIONS(2035),
    [anon_sym_let] = ACTIONS(2035),
    [anon_sym_orderby] = ACTIONS(2035),
    [anon_sym_group] = ACTIONS(2035),
    [anon_sym_by] = ACTIONS(2035),
    [anon_sym_select] = ACTIONS(2035),
    [anon_sym_as] = ACTIONS(2035),
    [anon_sym_is] = ACTIONS(2035),
    [anon_sym_DASH_GT] = ACTIONS(2035),
    [anon_sym_with] = ACTIONS(2035),
    [aux_sym_preproc_if_token3] = ACTIONS(2035),
    [aux_sym_preproc_else_token1] = ACTIONS(2035),
    [aux_sym_preproc_elif_token1] = ACTIONS(2035),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3669] = {
    [sym_preproc_region] = STATE(3669),
    [sym_preproc_endregion] = STATE(3669),
    [sym_preproc_line] = STATE(3669),
    [sym_preproc_pragma] = STATE(3669),
    [sym_preproc_nullable] = STATE(3669),
    [sym_preproc_error] = STATE(3669),
    [sym_preproc_warning] = STATE(3669),
    [sym_preproc_define] = STATE(3669),
    [sym_preproc_undef] = STATE(3669),
    [anon_sym_SEMI] = ACTIONS(5514),
    [anon_sym_LBRACK] = ACTIONS(5514),
    [anon_sym_COLON] = ACTIONS(5514),
    [anon_sym_COMMA] = ACTIONS(5514),
    [anon_sym_RBRACK] = ACTIONS(5514),
    [anon_sym_LPAREN] = ACTIONS(5514),
    [anon_sym_RPAREN] = ACTIONS(5514),
    [anon_sym_RBRACE] = ACTIONS(5514),
    [anon_sym_LT] = ACTIONS(5516),
    [anon_sym_GT] = ACTIONS(5516),
    [anon_sym_in] = ACTIONS(5516),
    [anon_sym_where] = ACTIONS(5514),
    [anon_sym_QMARK] = ACTIONS(5516),
    [anon_sym_BANG] = ACTIONS(5516),
    [anon_sym_PLUS_PLUS] = ACTIONS(5514),
    [anon_sym_DASH_DASH] = ACTIONS(5514),
    [anon_sym_PLUS] = ACTIONS(5516),
    [anon_sym_DASH] = ACTIONS(5516),
    [anon_sym_STAR] = ACTIONS(5514),
    [anon_sym_SLASH] = ACTIONS(5516),
    [anon_sym_PERCENT] = ACTIONS(5514),
    [anon_sym_CARET] = ACTIONS(5514),
    [anon_sym_PIPE] = ACTIONS(5516),
    [anon_sym_AMP] = ACTIONS(5516),
    [anon_sym_LT_LT] = ACTIONS(5514),
    [anon_sym_GT_GT] = ACTIONS(5516),
    [anon_sym_GT_GT_GT] = ACTIONS(5514),
    [anon_sym_EQ_EQ] = ACTIONS(5514),
    [anon_sym_BANG_EQ] = ACTIONS(5514),
    [anon_sym_GT_EQ] = ACTIONS(5514),
    [anon_sym_LT_EQ] = ACTIONS(5514),
    [anon_sym_DOT] = ACTIONS(5516),
    [anon_sym_EQ_GT] = ACTIONS(5514),
    [anon_sym_switch] = ACTIONS(5514),
    [anon_sym_DOT_DOT] = ACTIONS(5514),
    [anon_sym_and] = ACTIONS(5514),
    [anon_sym_or] = ACTIONS(5516),
    [anon_sym_AMP_AMP] = ACTIONS(5514),
    [anon_sym_PIPE_PIPE] = ACTIONS(5514),
    [anon_sym_QMARK_QMARK] = ACTIONS(5514),
    [anon_sym_from] = ACTIONS(5514),
    [anon_sym_into] = ACTIONS(5514),
    [anon_sym_join] = ACTIONS(5514),
    [anon_sym_on] = ACTIONS(5514),
    [anon_sym_equals] = ACTIONS(5514),
    [anon_sym_let] = ACTIONS(5514),
    [anon_sym_orderby] = ACTIONS(5514),
    [anon_sym_group] = ACTIONS(5514),
    [anon_sym_by] = ACTIONS(5514),
    [anon_sym_select] = ACTIONS(5514),
    [anon_sym_as] = ACTIONS(5514),
    [anon_sym_is] = ACTIONS(5514),
    [anon_sym_DASH_GT] = ACTIONS(5514),
    [anon_sym_with] = ACTIONS(5514),
    [aux_sym_preproc_if_token3] = ACTIONS(5514),
    [aux_sym_preproc_else_token1] = ACTIONS(5514),
    [aux_sym_preproc_elif_token1] = ACTIONS(5514),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3670] = {
    [sym_preproc_region] = STATE(3670),
    [sym_preproc_endregion] = STATE(3670),
    [sym_preproc_line] = STATE(3670),
    [sym_preproc_pragma] = STATE(3670),
    [sym_preproc_nullable] = STATE(3670),
    [sym_preproc_error] = STATE(3670),
    [sym_preproc_warning] = STATE(3670),
    [sym_preproc_define] = STATE(3670),
    [sym_preproc_undef] = STATE(3670),
    [anon_sym_SEMI] = ACTIONS(5518),
    [anon_sym_LBRACK] = ACTIONS(5518),
    [anon_sym_COLON] = ACTIONS(5518),
    [anon_sym_COMMA] = ACTIONS(5518),
    [anon_sym_RBRACK] = ACTIONS(5518),
    [anon_sym_LPAREN] = ACTIONS(5518),
    [anon_sym_RPAREN] = ACTIONS(5518),
    [anon_sym_RBRACE] = ACTIONS(5518),
    [anon_sym_LT] = ACTIONS(5520),
    [anon_sym_GT] = ACTIONS(5520),
    [anon_sym_in] = ACTIONS(5520),
    [anon_sym_where] = ACTIONS(5518),
    [anon_sym_QMARK] = ACTIONS(5520),
    [anon_sym_BANG] = ACTIONS(5520),
    [anon_sym_PLUS_PLUS] = ACTIONS(5518),
    [anon_sym_DASH_DASH] = ACTIONS(5518),
    [anon_sym_PLUS] = ACTIONS(5520),
    [anon_sym_DASH] = ACTIONS(5520),
    [anon_sym_STAR] = ACTIONS(5518),
    [anon_sym_SLASH] = ACTIONS(5520),
    [anon_sym_PERCENT] = ACTIONS(5518),
    [anon_sym_CARET] = ACTIONS(5518),
    [anon_sym_PIPE] = ACTIONS(5520),
    [anon_sym_AMP] = ACTIONS(5520),
    [anon_sym_LT_LT] = ACTIONS(5518),
    [anon_sym_GT_GT] = ACTIONS(5520),
    [anon_sym_GT_GT_GT] = ACTIONS(5518),
    [anon_sym_EQ_EQ] = ACTIONS(5518),
    [anon_sym_BANG_EQ] = ACTIONS(5518),
    [anon_sym_GT_EQ] = ACTIONS(5518),
    [anon_sym_LT_EQ] = ACTIONS(5518),
    [anon_sym_DOT] = ACTIONS(5520),
    [anon_sym_EQ_GT] = ACTIONS(5518),
    [anon_sym_switch] = ACTIONS(5518),
    [anon_sym_DOT_DOT] = ACTIONS(5518),
    [anon_sym_and] = ACTIONS(5518),
    [anon_sym_or] = ACTIONS(5520),
    [anon_sym_AMP_AMP] = ACTIONS(5518),
    [anon_sym_PIPE_PIPE] = ACTIONS(5518),
    [anon_sym_QMARK_QMARK] = ACTIONS(5518),
    [anon_sym_from] = ACTIONS(5518),
    [anon_sym_into] = ACTIONS(5518),
    [anon_sym_join] = ACTIONS(5518),
    [anon_sym_on] = ACTIONS(5518),
    [anon_sym_equals] = ACTIONS(5518),
    [anon_sym_let] = ACTIONS(5518),
    [anon_sym_orderby] = ACTIONS(5518),
    [anon_sym_group] = ACTIONS(5518),
    [anon_sym_by] = ACTIONS(5518),
    [anon_sym_select] = ACTIONS(5518),
    [anon_sym_as] = ACTIONS(5518),
    [anon_sym_is] = ACTIONS(5518),
    [anon_sym_DASH_GT] = ACTIONS(5518),
    [anon_sym_with] = ACTIONS(5518),
    [aux_sym_preproc_if_token3] = ACTIONS(5518),
    [aux_sym_preproc_else_token1] = ACTIONS(5518),
    [aux_sym_preproc_elif_token1] = ACTIONS(5518),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3671] = {
    [sym_preproc_region] = STATE(3671),
    [sym_preproc_endregion] = STATE(3671),
    [sym_preproc_line] = STATE(3671),
    [sym_preproc_pragma] = STATE(3671),
    [sym_preproc_nullable] = STATE(3671),
    [sym_preproc_error] = STATE(3671),
    [sym_preproc_warning] = STATE(3671),
    [sym_preproc_define] = STATE(3671),
    [sym_preproc_undef] = STATE(3671),
    [anon_sym_SEMI] = ACTIONS(5522),
    [anon_sym_LBRACK] = ACTIONS(5522),
    [anon_sym_COLON] = ACTIONS(5522),
    [anon_sym_COMMA] = ACTIONS(5522),
    [anon_sym_RBRACK] = ACTIONS(5522),
    [anon_sym_LPAREN] = ACTIONS(5522),
    [anon_sym_RPAREN] = ACTIONS(5522),
    [anon_sym_RBRACE] = ACTIONS(5522),
    [anon_sym_LT] = ACTIONS(5524),
    [anon_sym_GT] = ACTIONS(5524),
    [anon_sym_in] = ACTIONS(5524),
    [anon_sym_where] = ACTIONS(5522),
    [anon_sym_QMARK] = ACTIONS(5524),
    [anon_sym_BANG] = ACTIONS(5524),
    [anon_sym_PLUS_PLUS] = ACTIONS(5522),
    [anon_sym_DASH_DASH] = ACTIONS(5522),
    [anon_sym_PLUS] = ACTIONS(5524),
    [anon_sym_DASH] = ACTIONS(5524),
    [anon_sym_STAR] = ACTIONS(5522),
    [anon_sym_SLASH] = ACTIONS(5524),
    [anon_sym_PERCENT] = ACTIONS(5522),
    [anon_sym_CARET] = ACTIONS(5522),
    [anon_sym_PIPE] = ACTIONS(5524),
    [anon_sym_AMP] = ACTIONS(5524),
    [anon_sym_LT_LT] = ACTIONS(5522),
    [anon_sym_GT_GT] = ACTIONS(5524),
    [anon_sym_GT_GT_GT] = ACTIONS(5522),
    [anon_sym_EQ_EQ] = ACTIONS(5522),
    [anon_sym_BANG_EQ] = ACTIONS(5522),
    [anon_sym_GT_EQ] = ACTIONS(5522),
    [anon_sym_LT_EQ] = ACTIONS(5522),
    [anon_sym_DOT] = ACTIONS(5524),
    [anon_sym_EQ_GT] = ACTIONS(5522),
    [anon_sym_switch] = ACTIONS(5522),
    [anon_sym_DOT_DOT] = ACTIONS(5522),
    [anon_sym_and] = ACTIONS(5522),
    [anon_sym_or] = ACTIONS(5524),
    [anon_sym_AMP_AMP] = ACTIONS(5522),
    [anon_sym_PIPE_PIPE] = ACTIONS(5522),
    [anon_sym_QMARK_QMARK] = ACTIONS(5522),
    [anon_sym_from] = ACTIONS(5522),
    [anon_sym_into] = ACTIONS(5522),
    [anon_sym_join] = ACTIONS(5522),
    [anon_sym_on] = ACTIONS(5522),
    [anon_sym_equals] = ACTIONS(5522),
    [anon_sym_let] = ACTIONS(5522),
    [anon_sym_orderby] = ACTIONS(5522),
    [anon_sym_group] = ACTIONS(5522),
    [anon_sym_by] = ACTIONS(5522),
    [anon_sym_select] = ACTIONS(5522),
    [anon_sym_as] = ACTIONS(5522),
    [anon_sym_is] = ACTIONS(5522),
    [anon_sym_DASH_GT] = ACTIONS(5522),
    [anon_sym_with] = ACTIONS(5522),
    [aux_sym_preproc_if_token3] = ACTIONS(5522),
    [aux_sym_preproc_else_token1] = ACTIONS(5522),
    [aux_sym_preproc_elif_token1] = ACTIONS(5522),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3672] = {
    [sym_preproc_region] = STATE(3672),
    [sym_preproc_endregion] = STATE(3672),
    [sym_preproc_line] = STATE(3672),
    [sym_preproc_pragma] = STATE(3672),
    [sym_preproc_nullable] = STATE(3672),
    [sym_preproc_error] = STATE(3672),
    [sym_preproc_warning] = STATE(3672),
    [sym_preproc_define] = STATE(3672),
    [sym_preproc_undef] = STATE(3672),
    [anon_sym_SEMI] = ACTIONS(5526),
    [anon_sym_LBRACK] = ACTIONS(5526),
    [anon_sym_COLON] = ACTIONS(5526),
    [anon_sym_COMMA] = ACTIONS(5526),
    [anon_sym_RBRACK] = ACTIONS(5526),
    [anon_sym_LPAREN] = ACTIONS(5526),
    [anon_sym_RPAREN] = ACTIONS(5526),
    [anon_sym_RBRACE] = ACTIONS(5526),
    [anon_sym_LT] = ACTIONS(5528),
    [anon_sym_GT] = ACTIONS(5528),
    [anon_sym_in] = ACTIONS(5528),
    [anon_sym_where] = ACTIONS(5526),
    [anon_sym_QMARK] = ACTIONS(5528),
    [anon_sym_BANG] = ACTIONS(5528),
    [anon_sym_PLUS_PLUS] = ACTIONS(5526),
    [anon_sym_DASH_DASH] = ACTIONS(5526),
    [anon_sym_PLUS] = ACTIONS(5528),
    [anon_sym_DASH] = ACTIONS(5528),
    [anon_sym_STAR] = ACTIONS(5526),
    [anon_sym_SLASH] = ACTIONS(5528),
    [anon_sym_PERCENT] = ACTIONS(5526),
    [anon_sym_CARET] = ACTIONS(5526),
    [anon_sym_PIPE] = ACTIONS(5528),
    [anon_sym_AMP] = ACTIONS(5528),
    [anon_sym_LT_LT] = ACTIONS(5526),
    [anon_sym_GT_GT] = ACTIONS(5528),
    [anon_sym_GT_GT_GT] = ACTIONS(5526),
    [anon_sym_EQ_EQ] = ACTIONS(5526),
    [anon_sym_BANG_EQ] = ACTIONS(5526),
    [anon_sym_GT_EQ] = ACTIONS(5526),
    [anon_sym_LT_EQ] = ACTIONS(5526),
    [anon_sym_DOT] = ACTIONS(5528),
    [anon_sym_EQ_GT] = ACTIONS(5526),
    [anon_sym_switch] = ACTIONS(5526),
    [anon_sym_DOT_DOT] = ACTIONS(5526),
    [anon_sym_and] = ACTIONS(5526),
    [anon_sym_or] = ACTIONS(5528),
    [anon_sym_AMP_AMP] = ACTIONS(5526),
    [anon_sym_PIPE_PIPE] = ACTIONS(5526),
    [anon_sym_QMARK_QMARK] = ACTIONS(5526),
    [anon_sym_from] = ACTIONS(5526),
    [anon_sym_into] = ACTIONS(5526),
    [anon_sym_join] = ACTIONS(5526),
    [anon_sym_on] = ACTIONS(5526),
    [anon_sym_equals] = ACTIONS(5526),
    [anon_sym_let] = ACTIONS(5526),
    [anon_sym_orderby] = ACTIONS(5526),
    [anon_sym_group] = ACTIONS(5526),
    [anon_sym_by] = ACTIONS(5526),
    [anon_sym_select] = ACTIONS(5526),
    [anon_sym_as] = ACTIONS(5526),
    [anon_sym_is] = ACTIONS(5526),
    [anon_sym_DASH_GT] = ACTIONS(5526),
    [anon_sym_with] = ACTIONS(5526),
    [aux_sym_preproc_if_token3] = ACTIONS(5526),
    [aux_sym_preproc_else_token1] = ACTIONS(5526),
    [aux_sym_preproc_elif_token1] = ACTIONS(5526),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3673] = {
    [sym_preproc_region] = STATE(3673),
    [sym_preproc_endregion] = STATE(3673),
    [sym_preproc_line] = STATE(3673),
    [sym_preproc_pragma] = STATE(3673),
    [sym_preproc_nullable] = STATE(3673),
    [sym_preproc_error] = STATE(3673),
    [sym_preproc_warning] = STATE(3673),
    [sym_preproc_define] = STATE(3673),
    [sym_preproc_undef] = STATE(3673),
    [anon_sym_SEMI] = ACTIONS(4626),
    [anon_sym_LBRACK] = ACTIONS(4626),
    [anon_sym_COLON] = ACTIONS(4626),
    [anon_sym_COMMA] = ACTIONS(4626),
    [anon_sym_RBRACK] = ACTIONS(4626),
    [anon_sym_LPAREN] = ACTIONS(4626),
    [anon_sym_RPAREN] = ACTIONS(4626),
    [anon_sym_LBRACE] = ACTIONS(4626),
    [anon_sym_RBRACE] = ACTIONS(4626),
    [anon_sym_LT] = ACTIONS(4624),
    [anon_sym_GT] = ACTIONS(4624),
    [anon_sym_in] = ACTIONS(4626),
    [anon_sym_where] = ACTIONS(4626),
    [anon_sym_QMARK] = ACTIONS(4624),
    [anon_sym_BANG] = ACTIONS(4624),
    [anon_sym_PLUS_PLUS] = ACTIONS(4626),
    [anon_sym_DASH_DASH] = ACTIONS(4626),
    [anon_sym_PLUS] = ACTIONS(4624),
    [anon_sym_DASH] = ACTIONS(4624),
    [anon_sym_STAR] = ACTIONS(4626),
    [anon_sym_SLASH] = ACTIONS(4624),
    [anon_sym_PERCENT] = ACTIONS(4626),
    [anon_sym_CARET] = ACTIONS(4626),
    [anon_sym_PIPE] = ACTIONS(4624),
    [anon_sym_AMP] = ACTIONS(4624),
    [anon_sym_LT_LT] = ACTIONS(4626),
    [anon_sym_GT_GT] = ACTIONS(4624),
    [anon_sym_GT_GT_GT] = ACTIONS(4626),
    [anon_sym_EQ_EQ] = ACTIONS(4626),
    [anon_sym_BANG_EQ] = ACTIONS(4626),
    [anon_sym_GT_EQ] = ACTIONS(4626),
    [anon_sym_LT_EQ] = ACTIONS(4626),
    [anon_sym_DOT] = ACTIONS(4624),
    [anon_sym_EQ_GT] = ACTIONS(4626),
    [anon_sym_switch] = ACTIONS(4626),
    [anon_sym_DOT_DOT] = ACTIONS(4626),
    [anon_sym_and] = ACTIONS(4626),
    [anon_sym_or] = ACTIONS(4624),
    [anon_sym_AMP_AMP] = ACTIONS(4626),
    [anon_sym_PIPE_PIPE] = ACTIONS(4626),
    [anon_sym_QMARK_QMARK] = ACTIONS(4626),
    [anon_sym_from] = ACTIONS(4626),
    [anon_sym_join] = ACTIONS(4626),
    [anon_sym_on] = ACTIONS(4626),
    [anon_sym_equals] = ACTIONS(4626),
    [anon_sym_let] = ACTIONS(4626),
    [anon_sym_orderby] = ACTIONS(4626),
    [anon_sym_group] = ACTIONS(4626),
    [anon_sym_by] = ACTIONS(4626),
    [anon_sym_select] = ACTIONS(4626),
    [anon_sym_as] = ACTIONS(4626),
    [anon_sym_is] = ACTIONS(4626),
    [anon_sym_DASH_GT] = ACTIONS(4626),
    [anon_sym_with] = ACTIONS(4626),
    [aux_sym_preproc_if_token3] = ACTIONS(4626),
    [aux_sym_preproc_else_token1] = ACTIONS(4626),
    [aux_sym_preproc_elif_token1] = ACTIONS(4626),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3674] = {
    [sym_preproc_region] = STATE(3674),
    [sym_preproc_endregion] = STATE(3674),
    [sym_preproc_line] = STATE(3674),
    [sym_preproc_pragma] = STATE(3674),
    [sym_preproc_nullable] = STATE(3674),
    [sym_preproc_error] = STATE(3674),
    [sym_preproc_warning] = STATE(3674),
    [sym_preproc_define] = STATE(3674),
    [sym_preproc_undef] = STATE(3674),
    [anon_sym_SEMI] = ACTIONS(5530),
    [anon_sym_LBRACK] = ACTIONS(5530),
    [anon_sym_COLON] = ACTIONS(5530),
    [anon_sym_COMMA] = ACTIONS(5530),
    [anon_sym_RBRACK] = ACTIONS(5530),
    [anon_sym_LPAREN] = ACTIONS(5530),
    [anon_sym_RPAREN] = ACTIONS(5530),
    [anon_sym_RBRACE] = ACTIONS(5530),
    [anon_sym_LT] = ACTIONS(5532),
    [anon_sym_GT] = ACTIONS(5532),
    [anon_sym_in] = ACTIONS(5532),
    [anon_sym_where] = ACTIONS(5530),
    [anon_sym_QMARK] = ACTIONS(5532),
    [anon_sym_BANG] = ACTIONS(5532),
    [anon_sym_PLUS_PLUS] = ACTIONS(5530),
    [anon_sym_DASH_DASH] = ACTIONS(5530),
    [anon_sym_PLUS] = ACTIONS(5532),
    [anon_sym_DASH] = ACTIONS(5532),
    [anon_sym_STAR] = ACTIONS(5530),
    [anon_sym_SLASH] = ACTIONS(5532),
    [anon_sym_PERCENT] = ACTIONS(5530),
    [anon_sym_CARET] = ACTIONS(5530),
    [anon_sym_PIPE] = ACTIONS(5532),
    [anon_sym_AMP] = ACTIONS(5532),
    [anon_sym_LT_LT] = ACTIONS(5530),
    [anon_sym_GT_GT] = ACTIONS(5532),
    [anon_sym_GT_GT_GT] = ACTIONS(5530),
    [anon_sym_EQ_EQ] = ACTIONS(5530),
    [anon_sym_BANG_EQ] = ACTIONS(5530),
    [anon_sym_GT_EQ] = ACTIONS(5530),
    [anon_sym_LT_EQ] = ACTIONS(5530),
    [anon_sym_DOT] = ACTIONS(5532),
    [anon_sym_EQ_GT] = ACTIONS(5530),
    [anon_sym_switch] = ACTIONS(5530),
    [anon_sym_DOT_DOT] = ACTIONS(5530),
    [anon_sym_and] = ACTIONS(5530),
    [anon_sym_or] = ACTIONS(5532),
    [anon_sym_AMP_AMP] = ACTIONS(5530),
    [anon_sym_PIPE_PIPE] = ACTIONS(5530),
    [anon_sym_QMARK_QMARK] = ACTIONS(5530),
    [anon_sym_from] = ACTIONS(5530),
    [anon_sym_into] = ACTIONS(5530),
    [anon_sym_join] = ACTIONS(5530),
    [anon_sym_on] = ACTIONS(5530),
    [anon_sym_equals] = ACTIONS(5530),
    [anon_sym_let] = ACTIONS(5530),
    [anon_sym_orderby] = ACTIONS(5530),
    [anon_sym_group] = ACTIONS(5530),
    [anon_sym_by] = ACTIONS(5530),
    [anon_sym_select] = ACTIONS(5530),
    [anon_sym_as] = ACTIONS(5530),
    [anon_sym_is] = ACTIONS(5530),
    [anon_sym_DASH_GT] = ACTIONS(5530),
    [anon_sym_with] = ACTIONS(5530),
    [aux_sym_preproc_if_token3] = ACTIONS(5530),
    [aux_sym_preproc_else_token1] = ACTIONS(5530),
    [aux_sym_preproc_elif_token1] = ACTIONS(5530),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3675] = {
    [sym_preproc_region] = STATE(3675),
    [sym_preproc_endregion] = STATE(3675),
    [sym_preproc_line] = STATE(3675),
    [sym_preproc_pragma] = STATE(3675),
    [sym_preproc_nullable] = STATE(3675),
    [sym_preproc_error] = STATE(3675),
    [sym_preproc_warning] = STATE(3675),
    [sym_preproc_define] = STATE(3675),
    [sym_preproc_undef] = STATE(3675),
    [anon_sym_SEMI] = ACTIONS(5534),
    [anon_sym_LBRACK] = ACTIONS(5534),
    [anon_sym_COLON] = ACTIONS(5534),
    [anon_sym_COMMA] = ACTIONS(5534),
    [anon_sym_RBRACK] = ACTIONS(5534),
    [anon_sym_LPAREN] = ACTIONS(5534),
    [anon_sym_RPAREN] = ACTIONS(5534),
    [anon_sym_RBRACE] = ACTIONS(5534),
    [anon_sym_LT] = ACTIONS(5536),
    [anon_sym_GT] = ACTIONS(5536),
    [anon_sym_in] = ACTIONS(5536),
    [anon_sym_where] = ACTIONS(5534),
    [anon_sym_QMARK] = ACTIONS(5536),
    [anon_sym_BANG] = ACTIONS(5536),
    [anon_sym_PLUS_PLUS] = ACTIONS(5534),
    [anon_sym_DASH_DASH] = ACTIONS(5534),
    [anon_sym_PLUS] = ACTIONS(5536),
    [anon_sym_DASH] = ACTIONS(5536),
    [anon_sym_STAR] = ACTIONS(5534),
    [anon_sym_SLASH] = ACTIONS(5536),
    [anon_sym_PERCENT] = ACTIONS(5534),
    [anon_sym_CARET] = ACTIONS(5534),
    [anon_sym_PIPE] = ACTIONS(5536),
    [anon_sym_AMP] = ACTIONS(5536),
    [anon_sym_LT_LT] = ACTIONS(5534),
    [anon_sym_GT_GT] = ACTIONS(5536),
    [anon_sym_GT_GT_GT] = ACTIONS(5534),
    [anon_sym_EQ_EQ] = ACTIONS(5534),
    [anon_sym_BANG_EQ] = ACTIONS(5534),
    [anon_sym_GT_EQ] = ACTIONS(5534),
    [anon_sym_LT_EQ] = ACTIONS(5534),
    [anon_sym_DOT] = ACTIONS(5536),
    [anon_sym_EQ_GT] = ACTIONS(5534),
    [anon_sym_switch] = ACTIONS(5534),
    [anon_sym_DOT_DOT] = ACTIONS(5534),
    [anon_sym_and] = ACTIONS(5534),
    [anon_sym_or] = ACTIONS(5536),
    [anon_sym_AMP_AMP] = ACTIONS(5534),
    [anon_sym_PIPE_PIPE] = ACTIONS(5534),
    [anon_sym_QMARK_QMARK] = ACTIONS(5534),
    [anon_sym_from] = ACTIONS(5534),
    [anon_sym_into] = ACTIONS(5534),
    [anon_sym_join] = ACTIONS(5534),
    [anon_sym_on] = ACTIONS(5534),
    [anon_sym_equals] = ACTIONS(5534),
    [anon_sym_let] = ACTIONS(5534),
    [anon_sym_orderby] = ACTIONS(5534),
    [anon_sym_group] = ACTIONS(5534),
    [anon_sym_by] = ACTIONS(5534),
    [anon_sym_select] = ACTIONS(5534),
    [anon_sym_as] = ACTIONS(5534),
    [anon_sym_is] = ACTIONS(5534),
    [anon_sym_DASH_GT] = ACTIONS(5534),
    [anon_sym_with] = ACTIONS(5534),
    [aux_sym_preproc_if_token3] = ACTIONS(5534),
    [aux_sym_preproc_else_token1] = ACTIONS(5534),
    [aux_sym_preproc_elif_token1] = ACTIONS(5534),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3676] = {
    [sym_preproc_region] = STATE(3676),
    [sym_preproc_endregion] = STATE(3676),
    [sym_preproc_line] = STATE(3676),
    [sym_preproc_pragma] = STATE(3676),
    [sym_preproc_nullable] = STATE(3676),
    [sym_preproc_error] = STATE(3676),
    [sym_preproc_warning] = STATE(3676),
    [sym_preproc_define] = STATE(3676),
    [sym_preproc_undef] = STATE(3676),
    [anon_sym_SEMI] = ACTIONS(5538),
    [anon_sym_LBRACK] = ACTIONS(5538),
    [anon_sym_COLON] = ACTIONS(5538),
    [anon_sym_COMMA] = ACTIONS(5538),
    [anon_sym_RBRACK] = ACTIONS(5538),
    [anon_sym_LPAREN] = ACTIONS(5538),
    [anon_sym_RPAREN] = ACTIONS(5538),
    [anon_sym_RBRACE] = ACTIONS(5538),
    [anon_sym_LT] = ACTIONS(5540),
    [anon_sym_GT] = ACTIONS(5540),
    [anon_sym_in] = ACTIONS(5540),
    [anon_sym_where] = ACTIONS(5538),
    [anon_sym_QMARK] = ACTIONS(5540),
    [anon_sym_BANG] = ACTIONS(5540),
    [anon_sym_PLUS_PLUS] = ACTIONS(5538),
    [anon_sym_DASH_DASH] = ACTIONS(5538),
    [anon_sym_PLUS] = ACTIONS(5540),
    [anon_sym_DASH] = ACTIONS(5540),
    [anon_sym_STAR] = ACTIONS(5538),
    [anon_sym_SLASH] = ACTIONS(5540),
    [anon_sym_PERCENT] = ACTIONS(5538),
    [anon_sym_CARET] = ACTIONS(5538),
    [anon_sym_PIPE] = ACTIONS(5540),
    [anon_sym_AMP] = ACTIONS(5540),
    [anon_sym_LT_LT] = ACTIONS(5538),
    [anon_sym_GT_GT] = ACTIONS(5540),
    [anon_sym_GT_GT_GT] = ACTIONS(5538),
    [anon_sym_EQ_EQ] = ACTIONS(5538),
    [anon_sym_BANG_EQ] = ACTIONS(5538),
    [anon_sym_GT_EQ] = ACTIONS(5538),
    [anon_sym_LT_EQ] = ACTIONS(5538),
    [anon_sym_DOT] = ACTIONS(5540),
    [anon_sym_EQ_GT] = ACTIONS(5538),
    [anon_sym_switch] = ACTIONS(5538),
    [anon_sym_DOT_DOT] = ACTIONS(5538),
    [anon_sym_and] = ACTIONS(5538),
    [anon_sym_or] = ACTIONS(5540),
    [anon_sym_AMP_AMP] = ACTIONS(5538),
    [anon_sym_PIPE_PIPE] = ACTIONS(5538),
    [anon_sym_QMARK_QMARK] = ACTIONS(5538),
    [anon_sym_from] = ACTIONS(5538),
    [anon_sym_into] = ACTIONS(5538),
    [anon_sym_join] = ACTIONS(5538),
    [anon_sym_on] = ACTIONS(5538),
    [anon_sym_equals] = ACTIONS(5538),
    [anon_sym_let] = ACTIONS(5538),
    [anon_sym_orderby] = ACTIONS(5538),
    [anon_sym_group] = ACTIONS(5538),
    [anon_sym_by] = ACTIONS(5538),
    [anon_sym_select] = ACTIONS(5538),
    [anon_sym_as] = ACTIONS(5538),
    [anon_sym_is] = ACTIONS(5538),
    [anon_sym_DASH_GT] = ACTIONS(5538),
    [anon_sym_with] = ACTIONS(5538),
    [aux_sym_preproc_if_token3] = ACTIONS(5538),
    [aux_sym_preproc_else_token1] = ACTIONS(5538),
    [aux_sym_preproc_elif_token1] = ACTIONS(5538),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3677] = {
    [sym_preproc_region] = STATE(3677),
    [sym_preproc_endregion] = STATE(3677),
    [sym_preproc_line] = STATE(3677),
    [sym_preproc_pragma] = STATE(3677),
    [sym_preproc_nullable] = STATE(3677),
    [sym_preproc_error] = STATE(3677),
    [sym_preproc_warning] = STATE(3677),
    [sym_preproc_define] = STATE(3677),
    [sym_preproc_undef] = STATE(3677),
    [anon_sym_SEMI] = ACTIONS(4181),
    [anon_sym_LBRACK] = ACTIONS(4181),
    [anon_sym_COLON] = ACTIONS(4181),
    [anon_sym_COMMA] = ACTIONS(4181),
    [anon_sym_RBRACK] = ACTIONS(4181),
    [anon_sym_LPAREN] = ACTIONS(4181),
    [anon_sym_RPAREN] = ACTIONS(4181),
    [anon_sym_LBRACE] = ACTIONS(4181),
    [anon_sym_RBRACE] = ACTIONS(4181),
    [anon_sym_LT] = ACTIONS(4179),
    [anon_sym_GT] = ACTIONS(4179),
    [anon_sym_in] = ACTIONS(4181),
    [anon_sym_where] = ACTIONS(4181),
    [anon_sym_QMARK] = ACTIONS(4179),
    [anon_sym_BANG] = ACTIONS(4179),
    [anon_sym_PLUS_PLUS] = ACTIONS(4181),
    [anon_sym_DASH_DASH] = ACTIONS(4181),
    [anon_sym_PLUS] = ACTIONS(4179),
    [anon_sym_DASH] = ACTIONS(4179),
    [anon_sym_STAR] = ACTIONS(4181),
    [anon_sym_SLASH] = ACTIONS(4179),
    [anon_sym_PERCENT] = ACTIONS(4181),
    [anon_sym_CARET] = ACTIONS(4181),
    [anon_sym_PIPE] = ACTIONS(4179),
    [anon_sym_AMP] = ACTIONS(4179),
    [anon_sym_LT_LT] = ACTIONS(4181),
    [anon_sym_GT_GT] = ACTIONS(4179),
    [anon_sym_GT_GT_GT] = ACTIONS(4181),
    [anon_sym_EQ_EQ] = ACTIONS(4181),
    [anon_sym_BANG_EQ] = ACTIONS(4181),
    [anon_sym_GT_EQ] = ACTIONS(4181),
    [anon_sym_LT_EQ] = ACTIONS(4181),
    [anon_sym_DOT] = ACTIONS(4179),
    [anon_sym_EQ_GT] = ACTIONS(4181),
    [anon_sym_switch] = ACTIONS(4181),
    [anon_sym_DOT_DOT] = ACTIONS(4181),
    [anon_sym_and] = ACTIONS(4181),
    [anon_sym_or] = ACTIONS(4179),
    [anon_sym_AMP_AMP] = ACTIONS(4181),
    [anon_sym_PIPE_PIPE] = ACTIONS(4181),
    [anon_sym_QMARK_QMARK] = ACTIONS(4181),
    [anon_sym_from] = ACTIONS(4181),
    [anon_sym_join] = ACTIONS(4181),
    [anon_sym_on] = ACTIONS(4181),
    [anon_sym_equals] = ACTIONS(4181),
    [anon_sym_let] = ACTIONS(4181),
    [anon_sym_orderby] = ACTIONS(4181),
    [anon_sym_group] = ACTIONS(4181),
    [anon_sym_by] = ACTIONS(4181),
    [anon_sym_select] = ACTIONS(4181),
    [anon_sym_as] = ACTIONS(4181),
    [anon_sym_is] = ACTIONS(4181),
    [anon_sym_DASH_GT] = ACTIONS(4181),
    [anon_sym_with] = ACTIONS(4181),
    [aux_sym_preproc_if_token3] = ACTIONS(4181),
    [aux_sym_preproc_else_token1] = ACTIONS(4181),
    [aux_sym_preproc_elif_token1] = ACTIONS(4181),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3678] = {
    [sym_attribute_list] = STATE(4448),
    [sym_modifier] = STATE(4497),
    [sym_accessor_declaration] = STATE(4355),
    [sym_identifier] = STATE(7785),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_region] = STATE(3678),
    [sym_preproc_endregion] = STATE(3678),
    [sym_preproc_line] = STATE(3678),
    [sym_preproc_pragma] = STATE(3678),
    [sym_preproc_nullable] = STATE(3678),
    [sym_preproc_error] = STATE(3678),
    [sym_preproc_warning] = STATE(3678),
    [sym_preproc_define] = STATE(3678),
    [sym_preproc_undef] = STATE(3678),
    [aux_sym_class_declaration_repeat1] = STATE(3805),
    [aux_sym_class_declaration_repeat2] = STATE(3975),
    [aux_sym_accessor_list_repeat1] = STATE(3646),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(5456),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_unsafe] = ACTIONS(5456),
    [anon_sym_static] = ACTIONS(5456),
    [anon_sym_LBRACK] = ACTIONS(5458),
    [anon_sym_RBRACE] = ACTIONS(5542),
    [anon_sym_abstract] = ACTIONS(5456),
    [anon_sym_async] = ACTIONS(5456),
    [anon_sym_const] = ACTIONS(5456),
    [anon_sym_file] = ACTIONS(5462),
    [anon_sym_fixed] = ACTIONS(5456),
    [anon_sym_internal] = ACTIONS(5456),
    [anon_sym_new] = ACTIONS(5456),
    [anon_sym_override] = ACTIONS(5456),
    [anon_sym_partial] = ACTIONS(5456),
    [anon_sym_private] = ACTIONS(5456),
    [anon_sym_protected] = ACTIONS(5456),
    [anon_sym_public] = ACTIONS(5456),
    [anon_sym_readonly] = ACTIONS(5456),
    [anon_sym_required] = ACTIONS(5456),
    [anon_sym_sealed] = ACTIONS(5456),
    [anon_sym_virtual] = ACTIONS(5456),
    [anon_sym_volatile] = ACTIONS(5456),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_get] = ACTIONS(5464),
    [anon_sym_set] = ACTIONS(5464),
    [anon_sym_add] = ACTIONS(5464),
    [anon_sym_remove] = ACTIONS(5464),
    [anon_sym_init] = ACTIONS(5464),
    [anon_sym_scoped] = ACTIONS(29),
    [anon_sym_var] = ACTIONS(29),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_from] = ACTIONS(29),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3679] = {
    [sym_preproc_region] = STATE(3679),
    [sym_preproc_endregion] = STATE(3679),
    [sym_preproc_line] = STATE(3679),
    [sym_preproc_pragma] = STATE(3679),
    [sym_preproc_nullable] = STATE(3679),
    [sym_preproc_error] = STATE(3679),
    [sym_preproc_warning] = STATE(3679),
    [sym_preproc_define] = STATE(3679),
    [sym_preproc_undef] = STATE(3679),
    [anon_sym_SEMI] = ACTIONS(5544),
    [anon_sym_LBRACK] = ACTIONS(5544),
    [anon_sym_COLON] = ACTIONS(5544),
    [anon_sym_COMMA] = ACTIONS(5544),
    [anon_sym_RBRACK] = ACTIONS(5544),
    [anon_sym_LPAREN] = ACTIONS(5544),
    [anon_sym_RPAREN] = ACTIONS(5544),
    [anon_sym_RBRACE] = ACTIONS(5544),
    [anon_sym_LT] = ACTIONS(5546),
    [anon_sym_GT] = ACTIONS(5546),
    [anon_sym_in] = ACTIONS(5546),
    [anon_sym_where] = ACTIONS(5544),
    [anon_sym_QMARK] = ACTIONS(5546),
    [anon_sym_BANG] = ACTIONS(5546),
    [anon_sym_PLUS_PLUS] = ACTIONS(5544),
    [anon_sym_DASH_DASH] = ACTIONS(5544),
    [anon_sym_PLUS] = ACTIONS(5546),
    [anon_sym_DASH] = ACTIONS(5546),
    [anon_sym_STAR] = ACTIONS(5544),
    [anon_sym_SLASH] = ACTIONS(5546),
    [anon_sym_PERCENT] = ACTIONS(5544),
    [anon_sym_CARET] = ACTIONS(5544),
    [anon_sym_PIPE] = ACTIONS(5546),
    [anon_sym_AMP] = ACTIONS(5546),
    [anon_sym_LT_LT] = ACTIONS(5544),
    [anon_sym_GT_GT] = ACTIONS(5546),
    [anon_sym_GT_GT_GT] = ACTIONS(5544),
    [anon_sym_EQ_EQ] = ACTIONS(5544),
    [anon_sym_BANG_EQ] = ACTIONS(5544),
    [anon_sym_GT_EQ] = ACTIONS(5544),
    [anon_sym_LT_EQ] = ACTIONS(5544),
    [anon_sym_DOT] = ACTIONS(5546),
    [anon_sym_EQ_GT] = ACTIONS(5544),
    [anon_sym_switch] = ACTIONS(5544),
    [anon_sym_DOT_DOT] = ACTIONS(5544),
    [anon_sym_and] = ACTIONS(5544),
    [anon_sym_or] = ACTIONS(5546),
    [anon_sym_AMP_AMP] = ACTIONS(5544),
    [anon_sym_PIPE_PIPE] = ACTIONS(5544),
    [anon_sym_QMARK_QMARK] = ACTIONS(5544),
    [anon_sym_from] = ACTIONS(5544),
    [anon_sym_into] = ACTIONS(5544),
    [anon_sym_join] = ACTIONS(5544),
    [anon_sym_on] = ACTIONS(5544),
    [anon_sym_equals] = ACTIONS(5544),
    [anon_sym_let] = ACTIONS(5544),
    [anon_sym_orderby] = ACTIONS(5544),
    [anon_sym_group] = ACTIONS(5544),
    [anon_sym_by] = ACTIONS(5544),
    [anon_sym_select] = ACTIONS(5544),
    [anon_sym_as] = ACTIONS(5544),
    [anon_sym_is] = ACTIONS(5544),
    [anon_sym_DASH_GT] = ACTIONS(5544),
    [anon_sym_with] = ACTIONS(5544),
    [aux_sym_preproc_if_token3] = ACTIONS(5544),
    [aux_sym_preproc_else_token1] = ACTIONS(5544),
    [aux_sym_preproc_elif_token1] = ACTIONS(5544),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3680] = {
    [sym_preproc_region] = STATE(3680),
    [sym_preproc_endregion] = STATE(3680),
    [sym_preproc_line] = STATE(3680),
    [sym_preproc_pragma] = STATE(3680),
    [sym_preproc_nullable] = STATE(3680),
    [sym_preproc_error] = STATE(3680),
    [sym_preproc_warning] = STATE(3680),
    [sym_preproc_define] = STATE(3680),
    [sym_preproc_undef] = STATE(3680),
    [anon_sym_SEMI] = ACTIONS(4168),
    [anon_sym_LBRACK] = ACTIONS(4168),
    [anon_sym_COLON] = ACTIONS(4168),
    [anon_sym_COMMA] = ACTIONS(4168),
    [anon_sym_RBRACK] = ACTIONS(4168),
    [anon_sym_LPAREN] = ACTIONS(4168),
    [anon_sym_RPAREN] = ACTIONS(4168),
    [anon_sym_LBRACE] = ACTIONS(4168),
    [anon_sym_RBRACE] = ACTIONS(4168),
    [anon_sym_LT] = ACTIONS(4157),
    [anon_sym_GT] = ACTIONS(4157),
    [anon_sym_in] = ACTIONS(4168),
    [anon_sym_where] = ACTIONS(4168),
    [anon_sym_QMARK] = ACTIONS(4157),
    [anon_sym_BANG] = ACTIONS(4157),
    [anon_sym_PLUS_PLUS] = ACTIONS(4168),
    [anon_sym_DASH_DASH] = ACTIONS(4168),
    [anon_sym_PLUS] = ACTIONS(4157),
    [anon_sym_DASH] = ACTIONS(4157),
    [anon_sym_STAR] = ACTIONS(4168),
    [anon_sym_SLASH] = ACTIONS(4157),
    [anon_sym_PERCENT] = ACTIONS(4168),
    [anon_sym_CARET] = ACTIONS(4168),
    [anon_sym_PIPE] = ACTIONS(4157),
    [anon_sym_AMP] = ACTIONS(4157),
    [anon_sym_LT_LT] = ACTIONS(4168),
    [anon_sym_GT_GT] = ACTIONS(4157),
    [anon_sym_GT_GT_GT] = ACTIONS(4168),
    [anon_sym_EQ_EQ] = ACTIONS(4168),
    [anon_sym_BANG_EQ] = ACTIONS(4168),
    [anon_sym_GT_EQ] = ACTIONS(4168),
    [anon_sym_LT_EQ] = ACTIONS(4168),
    [anon_sym_DOT] = ACTIONS(4157),
    [anon_sym_EQ_GT] = ACTIONS(4168),
    [anon_sym_switch] = ACTIONS(4168),
    [anon_sym_DOT_DOT] = ACTIONS(4168),
    [anon_sym_and] = ACTIONS(4168),
    [anon_sym_or] = ACTIONS(4157),
    [anon_sym_AMP_AMP] = ACTIONS(4168),
    [anon_sym_PIPE_PIPE] = ACTIONS(4168),
    [anon_sym_QMARK_QMARK] = ACTIONS(4168),
    [anon_sym_from] = ACTIONS(4168),
    [anon_sym_join] = ACTIONS(4168),
    [anon_sym_on] = ACTIONS(4168),
    [anon_sym_equals] = ACTIONS(4168),
    [anon_sym_let] = ACTIONS(4168),
    [anon_sym_orderby] = ACTIONS(4168),
    [anon_sym_group] = ACTIONS(4168),
    [anon_sym_by] = ACTIONS(4168),
    [anon_sym_select] = ACTIONS(4168),
    [anon_sym_as] = ACTIONS(4168),
    [anon_sym_is] = ACTIONS(4168),
    [anon_sym_DASH_GT] = ACTIONS(4168),
    [anon_sym_with] = ACTIONS(4168),
    [aux_sym_preproc_if_token3] = ACTIONS(4168),
    [aux_sym_preproc_else_token1] = ACTIONS(4168),
    [aux_sym_preproc_elif_token1] = ACTIONS(4168),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3681] = {
    [sym_preproc_region] = STATE(3681),
    [sym_preproc_endregion] = STATE(3681),
    [sym_preproc_line] = STATE(3681),
    [sym_preproc_pragma] = STATE(3681),
    [sym_preproc_nullable] = STATE(3681),
    [sym_preproc_error] = STATE(3681),
    [sym_preproc_warning] = STATE(3681),
    [sym_preproc_define] = STATE(3681),
    [sym_preproc_undef] = STATE(3681),
    [anon_sym_SEMI] = ACTIONS(4494),
    [anon_sym_LBRACK] = ACTIONS(4593),
    [anon_sym_COLON] = ACTIONS(4494),
    [anon_sym_COMMA] = ACTIONS(4494),
    [anon_sym_RBRACK] = ACTIONS(4494),
    [anon_sym_LPAREN] = ACTIONS(4494),
    [anon_sym_RPAREN] = ACTIONS(4494),
    [anon_sym_LBRACE] = ACTIONS(4494),
    [anon_sym_RBRACE] = ACTIONS(4494),
    [anon_sym_LT] = ACTIONS(4492),
    [anon_sym_GT] = ACTIONS(4492),
    [anon_sym_in] = ACTIONS(4494),
    [anon_sym_where] = ACTIONS(4494),
    [anon_sym_QMARK] = ACTIONS(4492),
    [anon_sym_BANG] = ACTIONS(4492),
    [anon_sym_PLUS_PLUS] = ACTIONS(4494),
    [anon_sym_DASH_DASH] = ACTIONS(4494),
    [anon_sym_PLUS] = ACTIONS(4492),
    [anon_sym_DASH] = ACTIONS(4492),
    [anon_sym_STAR] = ACTIONS(4599),
    [anon_sym_SLASH] = ACTIONS(4492),
    [anon_sym_PERCENT] = ACTIONS(4494),
    [anon_sym_CARET] = ACTIONS(4494),
    [anon_sym_PIPE] = ACTIONS(4492),
    [anon_sym_AMP] = ACTIONS(4492),
    [anon_sym_LT_LT] = ACTIONS(4494),
    [anon_sym_GT_GT] = ACTIONS(4492),
    [anon_sym_GT_GT_GT] = ACTIONS(4494),
    [anon_sym_EQ_EQ] = ACTIONS(4494),
    [anon_sym_BANG_EQ] = ACTIONS(4494),
    [anon_sym_GT_EQ] = ACTIONS(4494),
    [anon_sym_LT_EQ] = ACTIONS(4494),
    [anon_sym_DOT] = ACTIONS(4492),
    [anon_sym_EQ_GT] = ACTIONS(4494),
    [anon_sym_switch] = ACTIONS(4494),
    [anon_sym_DOT_DOT] = ACTIONS(4494),
    [anon_sym_and] = ACTIONS(4494),
    [anon_sym_or] = ACTIONS(4492),
    [anon_sym_AMP_AMP] = ACTIONS(4494),
    [anon_sym_PIPE_PIPE] = ACTIONS(4494),
    [anon_sym_QMARK_QMARK] = ACTIONS(4494),
    [anon_sym_from] = ACTIONS(4494),
    [anon_sym_join] = ACTIONS(4494),
    [anon_sym_on] = ACTIONS(4494),
    [anon_sym_equals] = ACTIONS(4494),
    [anon_sym_let] = ACTIONS(4494),
    [anon_sym_orderby] = ACTIONS(4494),
    [anon_sym_group] = ACTIONS(4494),
    [anon_sym_by] = ACTIONS(4494),
    [anon_sym_select] = ACTIONS(4494),
    [anon_sym_as] = ACTIONS(4494),
    [anon_sym_is] = ACTIONS(4494),
    [anon_sym_DASH_GT] = ACTIONS(4494),
    [anon_sym_with] = ACTIONS(4494),
    [aux_sym_preproc_if_token3] = ACTIONS(4494),
    [aux_sym_preproc_else_token1] = ACTIONS(4494),
    [aux_sym_preproc_elif_token1] = ACTIONS(4494),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3682] = {
    [sym_preproc_region] = STATE(3682),
    [sym_preproc_endregion] = STATE(3682),
    [sym_preproc_line] = STATE(3682),
    [sym_preproc_pragma] = STATE(3682),
    [sym_preproc_nullable] = STATE(3682),
    [sym_preproc_error] = STATE(3682),
    [sym_preproc_warning] = STATE(3682),
    [sym_preproc_define] = STATE(3682),
    [sym_preproc_undef] = STATE(3682),
    [anon_sym_SEMI] = ACTIONS(5548),
    [anon_sym_LBRACK] = ACTIONS(5548),
    [anon_sym_COLON] = ACTIONS(5548),
    [anon_sym_COMMA] = ACTIONS(5548),
    [anon_sym_RBRACK] = ACTIONS(5548),
    [anon_sym_LPAREN] = ACTIONS(5548),
    [anon_sym_RPAREN] = ACTIONS(5548),
    [anon_sym_RBRACE] = ACTIONS(5548),
    [anon_sym_LT] = ACTIONS(5550),
    [anon_sym_GT] = ACTIONS(5550),
    [anon_sym_in] = ACTIONS(5550),
    [anon_sym_where] = ACTIONS(5548),
    [anon_sym_QMARK] = ACTIONS(5550),
    [anon_sym_BANG] = ACTIONS(5550),
    [anon_sym_PLUS_PLUS] = ACTIONS(5548),
    [anon_sym_DASH_DASH] = ACTIONS(5548),
    [anon_sym_PLUS] = ACTIONS(5550),
    [anon_sym_DASH] = ACTIONS(5550),
    [anon_sym_STAR] = ACTIONS(5548),
    [anon_sym_SLASH] = ACTIONS(5550),
    [anon_sym_PERCENT] = ACTIONS(5548),
    [anon_sym_CARET] = ACTIONS(5548),
    [anon_sym_PIPE] = ACTIONS(5550),
    [anon_sym_AMP] = ACTIONS(5550),
    [anon_sym_LT_LT] = ACTIONS(5548),
    [anon_sym_GT_GT] = ACTIONS(5550),
    [anon_sym_GT_GT_GT] = ACTIONS(5548),
    [anon_sym_EQ_EQ] = ACTIONS(5548),
    [anon_sym_BANG_EQ] = ACTIONS(5548),
    [anon_sym_GT_EQ] = ACTIONS(5548),
    [anon_sym_LT_EQ] = ACTIONS(5548),
    [anon_sym_DOT] = ACTIONS(5550),
    [anon_sym_EQ_GT] = ACTIONS(5548),
    [anon_sym_switch] = ACTIONS(5548),
    [anon_sym_DOT_DOT] = ACTIONS(5548),
    [anon_sym_and] = ACTIONS(5548),
    [anon_sym_or] = ACTIONS(5550),
    [anon_sym_AMP_AMP] = ACTIONS(5548),
    [anon_sym_PIPE_PIPE] = ACTIONS(5548),
    [anon_sym_QMARK_QMARK] = ACTIONS(5548),
    [anon_sym_from] = ACTIONS(5548),
    [anon_sym_into] = ACTIONS(5548),
    [anon_sym_join] = ACTIONS(5548),
    [anon_sym_on] = ACTIONS(5548),
    [anon_sym_equals] = ACTIONS(5548),
    [anon_sym_let] = ACTIONS(5548),
    [anon_sym_orderby] = ACTIONS(5548),
    [anon_sym_group] = ACTIONS(5548),
    [anon_sym_by] = ACTIONS(5548),
    [anon_sym_select] = ACTIONS(5548),
    [anon_sym_as] = ACTIONS(5548),
    [anon_sym_is] = ACTIONS(5548),
    [anon_sym_DASH_GT] = ACTIONS(5548),
    [anon_sym_with] = ACTIONS(5548),
    [aux_sym_preproc_if_token3] = ACTIONS(5548),
    [aux_sym_preproc_else_token1] = ACTIONS(5548),
    [aux_sym_preproc_elif_token1] = ACTIONS(5548),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3683] = {
    [sym_preproc_region] = STATE(3683),
    [sym_preproc_endregion] = STATE(3683),
    [sym_preproc_line] = STATE(3683),
    [sym_preproc_pragma] = STATE(3683),
    [sym_preproc_nullable] = STATE(3683),
    [sym_preproc_error] = STATE(3683),
    [sym_preproc_warning] = STATE(3683),
    [sym_preproc_define] = STATE(3683),
    [sym_preproc_undef] = STATE(3683),
    [anon_sym_SEMI] = ACTIONS(5552),
    [anon_sym_LBRACK] = ACTIONS(5552),
    [anon_sym_COLON] = ACTIONS(5552),
    [anon_sym_COMMA] = ACTIONS(5552),
    [anon_sym_RBRACK] = ACTIONS(5552),
    [anon_sym_LPAREN] = ACTIONS(5552),
    [anon_sym_RPAREN] = ACTIONS(5552),
    [anon_sym_RBRACE] = ACTIONS(5552),
    [anon_sym_LT] = ACTIONS(5554),
    [anon_sym_GT] = ACTIONS(5554),
    [anon_sym_in] = ACTIONS(5554),
    [anon_sym_where] = ACTIONS(5552),
    [anon_sym_QMARK] = ACTIONS(5554),
    [anon_sym_BANG] = ACTIONS(5554),
    [anon_sym_PLUS_PLUS] = ACTIONS(5552),
    [anon_sym_DASH_DASH] = ACTIONS(5552),
    [anon_sym_PLUS] = ACTIONS(5554),
    [anon_sym_DASH] = ACTIONS(5554),
    [anon_sym_STAR] = ACTIONS(5552),
    [anon_sym_SLASH] = ACTIONS(5554),
    [anon_sym_PERCENT] = ACTIONS(5552),
    [anon_sym_CARET] = ACTIONS(5552),
    [anon_sym_PIPE] = ACTIONS(5554),
    [anon_sym_AMP] = ACTIONS(5554),
    [anon_sym_LT_LT] = ACTIONS(5552),
    [anon_sym_GT_GT] = ACTIONS(5554),
    [anon_sym_GT_GT_GT] = ACTIONS(5552),
    [anon_sym_EQ_EQ] = ACTIONS(5552),
    [anon_sym_BANG_EQ] = ACTIONS(5552),
    [anon_sym_GT_EQ] = ACTIONS(5552),
    [anon_sym_LT_EQ] = ACTIONS(5552),
    [anon_sym_DOT] = ACTIONS(5554),
    [anon_sym_EQ_GT] = ACTIONS(5552),
    [anon_sym_switch] = ACTIONS(5552),
    [anon_sym_DOT_DOT] = ACTIONS(5552),
    [anon_sym_and] = ACTIONS(5552),
    [anon_sym_or] = ACTIONS(5554),
    [anon_sym_AMP_AMP] = ACTIONS(5552),
    [anon_sym_PIPE_PIPE] = ACTIONS(5552),
    [anon_sym_QMARK_QMARK] = ACTIONS(5552),
    [anon_sym_from] = ACTIONS(5552),
    [anon_sym_into] = ACTIONS(5552),
    [anon_sym_join] = ACTIONS(5552),
    [anon_sym_on] = ACTIONS(5552),
    [anon_sym_equals] = ACTIONS(5552),
    [anon_sym_let] = ACTIONS(5552),
    [anon_sym_orderby] = ACTIONS(5552),
    [anon_sym_group] = ACTIONS(5552),
    [anon_sym_by] = ACTIONS(5552),
    [anon_sym_select] = ACTIONS(5552),
    [anon_sym_as] = ACTIONS(5552),
    [anon_sym_is] = ACTIONS(5552),
    [anon_sym_DASH_GT] = ACTIONS(5552),
    [anon_sym_with] = ACTIONS(5552),
    [aux_sym_preproc_if_token3] = ACTIONS(5552),
    [aux_sym_preproc_else_token1] = ACTIONS(5552),
    [aux_sym_preproc_elif_token1] = ACTIONS(5552),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3684] = {
    [sym_preproc_region] = STATE(3684),
    [sym_preproc_endregion] = STATE(3684),
    [sym_preproc_line] = STATE(3684),
    [sym_preproc_pragma] = STATE(3684),
    [sym_preproc_nullable] = STATE(3684),
    [sym_preproc_error] = STATE(3684),
    [sym_preproc_warning] = STATE(3684),
    [sym_preproc_define] = STATE(3684),
    [sym_preproc_undef] = STATE(3684),
    [anon_sym_SEMI] = ACTIONS(5556),
    [anon_sym_LBRACK] = ACTIONS(5556),
    [anon_sym_COLON] = ACTIONS(5556),
    [anon_sym_COMMA] = ACTIONS(5556),
    [anon_sym_RBRACK] = ACTIONS(5556),
    [anon_sym_LPAREN] = ACTIONS(5556),
    [anon_sym_RPAREN] = ACTIONS(5556),
    [anon_sym_RBRACE] = ACTIONS(5556),
    [anon_sym_LT] = ACTIONS(5558),
    [anon_sym_GT] = ACTIONS(5558),
    [anon_sym_in] = ACTIONS(5558),
    [anon_sym_where] = ACTIONS(5556),
    [anon_sym_QMARK] = ACTIONS(5558),
    [anon_sym_BANG] = ACTIONS(5558),
    [anon_sym_PLUS_PLUS] = ACTIONS(5556),
    [anon_sym_DASH_DASH] = ACTIONS(5556),
    [anon_sym_PLUS] = ACTIONS(5558),
    [anon_sym_DASH] = ACTIONS(5558),
    [anon_sym_STAR] = ACTIONS(5556),
    [anon_sym_SLASH] = ACTIONS(5558),
    [anon_sym_PERCENT] = ACTIONS(5556),
    [anon_sym_CARET] = ACTIONS(5556),
    [anon_sym_PIPE] = ACTIONS(5558),
    [anon_sym_AMP] = ACTIONS(5558),
    [anon_sym_LT_LT] = ACTIONS(5556),
    [anon_sym_GT_GT] = ACTIONS(5558),
    [anon_sym_GT_GT_GT] = ACTIONS(5556),
    [anon_sym_EQ_EQ] = ACTIONS(5556),
    [anon_sym_BANG_EQ] = ACTIONS(5556),
    [anon_sym_GT_EQ] = ACTIONS(5556),
    [anon_sym_LT_EQ] = ACTIONS(5556),
    [anon_sym_DOT] = ACTIONS(5558),
    [anon_sym_EQ_GT] = ACTIONS(5556),
    [anon_sym_switch] = ACTIONS(5556),
    [anon_sym_DOT_DOT] = ACTIONS(5556),
    [anon_sym_and] = ACTIONS(5556),
    [anon_sym_or] = ACTIONS(5558),
    [anon_sym_AMP_AMP] = ACTIONS(5556),
    [anon_sym_PIPE_PIPE] = ACTIONS(5556),
    [anon_sym_QMARK_QMARK] = ACTIONS(5556),
    [anon_sym_from] = ACTIONS(5556),
    [anon_sym_into] = ACTIONS(5556),
    [anon_sym_join] = ACTIONS(5556),
    [anon_sym_on] = ACTIONS(5556),
    [anon_sym_equals] = ACTIONS(5556),
    [anon_sym_let] = ACTIONS(5556),
    [anon_sym_orderby] = ACTIONS(5556),
    [anon_sym_group] = ACTIONS(5556),
    [anon_sym_by] = ACTIONS(5556),
    [anon_sym_select] = ACTIONS(5556),
    [anon_sym_as] = ACTIONS(5556),
    [anon_sym_is] = ACTIONS(5556),
    [anon_sym_DASH_GT] = ACTIONS(5556),
    [anon_sym_with] = ACTIONS(5556),
    [aux_sym_preproc_if_token3] = ACTIONS(5556),
    [aux_sym_preproc_else_token1] = ACTIONS(5556),
    [aux_sym_preproc_elif_token1] = ACTIONS(5556),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3685] = {
    [sym_preproc_region] = STATE(3685),
    [sym_preproc_endregion] = STATE(3685),
    [sym_preproc_line] = STATE(3685),
    [sym_preproc_pragma] = STATE(3685),
    [sym_preproc_nullable] = STATE(3685),
    [sym_preproc_error] = STATE(3685),
    [sym_preproc_warning] = STATE(3685),
    [sym_preproc_define] = STATE(3685),
    [sym_preproc_undef] = STATE(3685),
    [anon_sym_SEMI] = ACTIONS(5560),
    [anon_sym_LBRACK] = ACTIONS(5560),
    [anon_sym_COLON] = ACTIONS(5560),
    [anon_sym_COMMA] = ACTIONS(5560),
    [anon_sym_RBRACK] = ACTIONS(5560),
    [anon_sym_LPAREN] = ACTIONS(5560),
    [anon_sym_RPAREN] = ACTIONS(5560),
    [anon_sym_RBRACE] = ACTIONS(5560),
    [anon_sym_LT] = ACTIONS(5562),
    [anon_sym_GT] = ACTIONS(5562),
    [anon_sym_in] = ACTIONS(5562),
    [anon_sym_where] = ACTIONS(5560),
    [anon_sym_QMARK] = ACTIONS(5562),
    [anon_sym_BANG] = ACTIONS(5562),
    [anon_sym_PLUS_PLUS] = ACTIONS(5560),
    [anon_sym_DASH_DASH] = ACTIONS(5560),
    [anon_sym_PLUS] = ACTIONS(5562),
    [anon_sym_DASH] = ACTIONS(5562),
    [anon_sym_STAR] = ACTIONS(5560),
    [anon_sym_SLASH] = ACTIONS(5562),
    [anon_sym_PERCENT] = ACTIONS(5560),
    [anon_sym_CARET] = ACTIONS(5560),
    [anon_sym_PIPE] = ACTIONS(5562),
    [anon_sym_AMP] = ACTIONS(5562),
    [anon_sym_LT_LT] = ACTIONS(5560),
    [anon_sym_GT_GT] = ACTIONS(5562),
    [anon_sym_GT_GT_GT] = ACTIONS(5560),
    [anon_sym_EQ_EQ] = ACTIONS(5560),
    [anon_sym_BANG_EQ] = ACTIONS(5560),
    [anon_sym_GT_EQ] = ACTIONS(5560),
    [anon_sym_LT_EQ] = ACTIONS(5560),
    [anon_sym_DOT] = ACTIONS(5562),
    [anon_sym_EQ_GT] = ACTIONS(5560),
    [anon_sym_switch] = ACTIONS(5560),
    [anon_sym_DOT_DOT] = ACTIONS(5560),
    [anon_sym_and] = ACTIONS(5560),
    [anon_sym_or] = ACTIONS(5562),
    [anon_sym_AMP_AMP] = ACTIONS(5560),
    [anon_sym_PIPE_PIPE] = ACTIONS(5560),
    [anon_sym_QMARK_QMARK] = ACTIONS(5560),
    [anon_sym_from] = ACTIONS(5560),
    [anon_sym_into] = ACTIONS(5560),
    [anon_sym_join] = ACTIONS(5560),
    [anon_sym_on] = ACTIONS(5560),
    [anon_sym_equals] = ACTIONS(5560),
    [anon_sym_let] = ACTIONS(5560),
    [anon_sym_orderby] = ACTIONS(5560),
    [anon_sym_group] = ACTIONS(5560),
    [anon_sym_by] = ACTIONS(5560),
    [anon_sym_select] = ACTIONS(5560),
    [anon_sym_as] = ACTIONS(5560),
    [anon_sym_is] = ACTIONS(5560),
    [anon_sym_DASH_GT] = ACTIONS(5560),
    [anon_sym_with] = ACTIONS(5560),
    [aux_sym_preproc_if_token3] = ACTIONS(5560),
    [aux_sym_preproc_else_token1] = ACTIONS(5560),
    [aux_sym_preproc_elif_token1] = ACTIONS(5560),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3686] = {
    [sym_preproc_region] = STATE(3686),
    [sym_preproc_endregion] = STATE(3686),
    [sym_preproc_line] = STATE(3686),
    [sym_preproc_pragma] = STATE(3686),
    [sym_preproc_nullable] = STATE(3686),
    [sym_preproc_error] = STATE(3686),
    [sym_preproc_warning] = STATE(3686),
    [sym_preproc_define] = STATE(3686),
    [sym_preproc_undef] = STATE(3686),
    [anon_sym_SEMI] = ACTIONS(5564),
    [anon_sym_LBRACK] = ACTIONS(5564),
    [anon_sym_COLON] = ACTIONS(5564),
    [anon_sym_COMMA] = ACTIONS(5564),
    [anon_sym_RBRACK] = ACTIONS(5564),
    [anon_sym_LPAREN] = ACTIONS(5564),
    [anon_sym_RPAREN] = ACTIONS(5564),
    [anon_sym_RBRACE] = ACTIONS(5564),
    [anon_sym_LT] = ACTIONS(5566),
    [anon_sym_GT] = ACTIONS(5566),
    [anon_sym_in] = ACTIONS(5566),
    [anon_sym_where] = ACTIONS(5564),
    [anon_sym_QMARK] = ACTIONS(5566),
    [anon_sym_BANG] = ACTIONS(5566),
    [anon_sym_PLUS_PLUS] = ACTIONS(5564),
    [anon_sym_DASH_DASH] = ACTIONS(5564),
    [anon_sym_PLUS] = ACTIONS(5566),
    [anon_sym_DASH] = ACTIONS(5566),
    [anon_sym_STAR] = ACTIONS(5564),
    [anon_sym_SLASH] = ACTIONS(5566),
    [anon_sym_PERCENT] = ACTIONS(5564),
    [anon_sym_CARET] = ACTIONS(5564),
    [anon_sym_PIPE] = ACTIONS(5566),
    [anon_sym_AMP] = ACTIONS(5566),
    [anon_sym_LT_LT] = ACTIONS(5564),
    [anon_sym_GT_GT] = ACTIONS(5566),
    [anon_sym_GT_GT_GT] = ACTIONS(5564),
    [anon_sym_EQ_EQ] = ACTIONS(5564),
    [anon_sym_BANG_EQ] = ACTIONS(5564),
    [anon_sym_GT_EQ] = ACTIONS(5564),
    [anon_sym_LT_EQ] = ACTIONS(5564),
    [anon_sym_DOT] = ACTIONS(5566),
    [anon_sym_EQ_GT] = ACTIONS(5564),
    [anon_sym_switch] = ACTIONS(5564),
    [anon_sym_DOT_DOT] = ACTIONS(5564),
    [anon_sym_and] = ACTIONS(5564),
    [anon_sym_or] = ACTIONS(5566),
    [anon_sym_AMP_AMP] = ACTIONS(5564),
    [anon_sym_PIPE_PIPE] = ACTIONS(5564),
    [anon_sym_QMARK_QMARK] = ACTIONS(5564),
    [anon_sym_from] = ACTIONS(5564),
    [anon_sym_into] = ACTIONS(5564),
    [anon_sym_join] = ACTIONS(5564),
    [anon_sym_on] = ACTIONS(5564),
    [anon_sym_equals] = ACTIONS(5564),
    [anon_sym_let] = ACTIONS(5564),
    [anon_sym_orderby] = ACTIONS(5564),
    [anon_sym_group] = ACTIONS(5564),
    [anon_sym_by] = ACTIONS(5564),
    [anon_sym_select] = ACTIONS(5564),
    [anon_sym_as] = ACTIONS(5564),
    [anon_sym_is] = ACTIONS(5564),
    [anon_sym_DASH_GT] = ACTIONS(5564),
    [anon_sym_with] = ACTIONS(5564),
    [aux_sym_preproc_if_token3] = ACTIONS(5564),
    [aux_sym_preproc_else_token1] = ACTIONS(5564),
    [aux_sym_preproc_elif_token1] = ACTIONS(5564),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3687] = {
    [sym_preproc_region] = STATE(3687),
    [sym_preproc_endregion] = STATE(3687),
    [sym_preproc_line] = STATE(3687),
    [sym_preproc_pragma] = STATE(3687),
    [sym_preproc_nullable] = STATE(3687),
    [sym_preproc_error] = STATE(3687),
    [sym_preproc_warning] = STATE(3687),
    [sym_preproc_define] = STATE(3687),
    [sym_preproc_undef] = STATE(3687),
    [anon_sym_SEMI] = ACTIONS(5568),
    [anon_sym_LBRACK] = ACTIONS(5568),
    [anon_sym_COLON] = ACTIONS(5568),
    [anon_sym_COMMA] = ACTIONS(5568),
    [anon_sym_RBRACK] = ACTIONS(5568),
    [anon_sym_LPAREN] = ACTIONS(5568),
    [anon_sym_RPAREN] = ACTIONS(5568),
    [anon_sym_RBRACE] = ACTIONS(5568),
    [anon_sym_LT] = ACTIONS(5570),
    [anon_sym_GT] = ACTIONS(5570),
    [anon_sym_in] = ACTIONS(5570),
    [anon_sym_where] = ACTIONS(5568),
    [anon_sym_QMARK] = ACTIONS(5570),
    [anon_sym_BANG] = ACTIONS(5570),
    [anon_sym_PLUS_PLUS] = ACTIONS(5568),
    [anon_sym_DASH_DASH] = ACTIONS(5568),
    [anon_sym_PLUS] = ACTIONS(5570),
    [anon_sym_DASH] = ACTIONS(5570),
    [anon_sym_STAR] = ACTIONS(5568),
    [anon_sym_SLASH] = ACTIONS(5570),
    [anon_sym_PERCENT] = ACTIONS(5568),
    [anon_sym_CARET] = ACTIONS(5568),
    [anon_sym_PIPE] = ACTIONS(5570),
    [anon_sym_AMP] = ACTIONS(5570),
    [anon_sym_LT_LT] = ACTIONS(5568),
    [anon_sym_GT_GT] = ACTIONS(5570),
    [anon_sym_GT_GT_GT] = ACTIONS(5568),
    [anon_sym_EQ_EQ] = ACTIONS(5568),
    [anon_sym_BANG_EQ] = ACTIONS(5568),
    [anon_sym_GT_EQ] = ACTIONS(5568),
    [anon_sym_LT_EQ] = ACTIONS(5568),
    [anon_sym_DOT] = ACTIONS(5570),
    [anon_sym_EQ_GT] = ACTIONS(5568),
    [anon_sym_switch] = ACTIONS(5568),
    [anon_sym_DOT_DOT] = ACTIONS(5568),
    [anon_sym_and] = ACTIONS(5568),
    [anon_sym_or] = ACTIONS(5570),
    [anon_sym_AMP_AMP] = ACTIONS(5568),
    [anon_sym_PIPE_PIPE] = ACTIONS(5568),
    [anon_sym_QMARK_QMARK] = ACTIONS(5568),
    [anon_sym_from] = ACTIONS(5568),
    [anon_sym_into] = ACTIONS(5568),
    [anon_sym_join] = ACTIONS(5568),
    [anon_sym_on] = ACTIONS(5568),
    [anon_sym_equals] = ACTIONS(5568),
    [anon_sym_let] = ACTIONS(5568),
    [anon_sym_orderby] = ACTIONS(5568),
    [anon_sym_group] = ACTIONS(5568),
    [anon_sym_by] = ACTIONS(5568),
    [anon_sym_select] = ACTIONS(5568),
    [anon_sym_as] = ACTIONS(5568),
    [anon_sym_is] = ACTIONS(5568),
    [anon_sym_DASH_GT] = ACTIONS(5568),
    [anon_sym_with] = ACTIONS(5568),
    [aux_sym_preproc_if_token3] = ACTIONS(5568),
    [aux_sym_preproc_else_token1] = ACTIONS(5568),
    [aux_sym_preproc_elif_token1] = ACTIONS(5568),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3688] = {
    [sym_preproc_region] = STATE(3688),
    [sym_preproc_endregion] = STATE(3688),
    [sym_preproc_line] = STATE(3688),
    [sym_preproc_pragma] = STATE(3688),
    [sym_preproc_nullable] = STATE(3688),
    [sym_preproc_error] = STATE(3688),
    [sym_preproc_warning] = STATE(3688),
    [sym_preproc_define] = STATE(3688),
    [sym_preproc_undef] = STATE(3688),
    [anon_sym_SEMI] = ACTIONS(5286),
    [anon_sym_LBRACK] = ACTIONS(5286),
    [anon_sym_COLON] = ACTIONS(5286),
    [anon_sym_COMMA] = ACTIONS(5286),
    [anon_sym_RBRACK] = ACTIONS(5286),
    [anon_sym_LPAREN] = ACTIONS(5286),
    [anon_sym_RPAREN] = ACTIONS(5286),
    [anon_sym_RBRACE] = ACTIONS(5286),
    [anon_sym_LT] = ACTIONS(5288),
    [anon_sym_GT] = ACTIONS(5288),
    [anon_sym_in] = ACTIONS(5288),
    [anon_sym_where] = ACTIONS(5286),
    [anon_sym_QMARK] = ACTIONS(5288),
    [anon_sym_BANG] = ACTIONS(5288),
    [anon_sym_PLUS_PLUS] = ACTIONS(5286),
    [anon_sym_DASH_DASH] = ACTIONS(5286),
    [anon_sym_PLUS] = ACTIONS(5288),
    [anon_sym_DASH] = ACTIONS(5288),
    [anon_sym_STAR] = ACTIONS(5286),
    [anon_sym_SLASH] = ACTIONS(5288),
    [anon_sym_PERCENT] = ACTIONS(5286),
    [anon_sym_CARET] = ACTIONS(5286),
    [anon_sym_PIPE] = ACTIONS(5288),
    [anon_sym_AMP] = ACTIONS(5288),
    [anon_sym_LT_LT] = ACTIONS(5286),
    [anon_sym_GT_GT] = ACTIONS(5288),
    [anon_sym_GT_GT_GT] = ACTIONS(5286),
    [anon_sym_EQ_EQ] = ACTIONS(5286),
    [anon_sym_BANG_EQ] = ACTIONS(5286),
    [anon_sym_GT_EQ] = ACTIONS(5286),
    [anon_sym_LT_EQ] = ACTIONS(5286),
    [anon_sym_DOT] = ACTIONS(5288),
    [anon_sym_EQ_GT] = ACTIONS(5286),
    [anon_sym_switch] = ACTIONS(5286),
    [anon_sym_DOT_DOT] = ACTIONS(5286),
    [anon_sym_and] = ACTIONS(5286),
    [anon_sym_or] = ACTIONS(5288),
    [anon_sym_AMP_AMP] = ACTIONS(5286),
    [anon_sym_PIPE_PIPE] = ACTIONS(5286),
    [anon_sym_QMARK_QMARK] = ACTIONS(5286),
    [anon_sym_from] = ACTIONS(5286),
    [anon_sym_into] = ACTIONS(5286),
    [anon_sym_join] = ACTIONS(5286),
    [anon_sym_on] = ACTIONS(5286),
    [anon_sym_equals] = ACTIONS(5286),
    [anon_sym_let] = ACTIONS(5286),
    [anon_sym_orderby] = ACTIONS(5286),
    [anon_sym_group] = ACTIONS(5286),
    [anon_sym_by] = ACTIONS(5286),
    [anon_sym_select] = ACTIONS(5286),
    [anon_sym_as] = ACTIONS(5286),
    [anon_sym_is] = ACTIONS(5286),
    [anon_sym_DASH_GT] = ACTIONS(5286),
    [anon_sym_with] = ACTIONS(5286),
    [aux_sym_preproc_if_token3] = ACTIONS(5286),
    [aux_sym_preproc_else_token1] = ACTIONS(5286),
    [aux_sym_preproc_elif_token1] = ACTIONS(5286),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3689] = {
    [sym_preproc_region] = STATE(3689),
    [sym_preproc_endregion] = STATE(3689),
    [sym_preproc_line] = STATE(3689),
    [sym_preproc_pragma] = STATE(3689),
    [sym_preproc_nullable] = STATE(3689),
    [sym_preproc_error] = STATE(3689),
    [sym_preproc_warning] = STATE(3689),
    [sym_preproc_define] = STATE(3689),
    [sym_preproc_undef] = STATE(3689),
    [anon_sym_SEMI] = ACTIONS(5572),
    [anon_sym_LBRACK] = ACTIONS(5572),
    [anon_sym_COLON] = ACTIONS(5572),
    [anon_sym_COMMA] = ACTIONS(5572),
    [anon_sym_RBRACK] = ACTIONS(5572),
    [anon_sym_LPAREN] = ACTIONS(5572),
    [anon_sym_RPAREN] = ACTIONS(5572),
    [anon_sym_RBRACE] = ACTIONS(5572),
    [anon_sym_LT] = ACTIONS(5574),
    [anon_sym_GT] = ACTIONS(5574),
    [anon_sym_in] = ACTIONS(5574),
    [anon_sym_where] = ACTIONS(5572),
    [anon_sym_QMARK] = ACTIONS(5574),
    [anon_sym_BANG] = ACTIONS(5574),
    [anon_sym_PLUS_PLUS] = ACTIONS(5572),
    [anon_sym_DASH_DASH] = ACTIONS(5572),
    [anon_sym_PLUS] = ACTIONS(5574),
    [anon_sym_DASH] = ACTIONS(5574),
    [anon_sym_STAR] = ACTIONS(5572),
    [anon_sym_SLASH] = ACTIONS(5574),
    [anon_sym_PERCENT] = ACTIONS(5572),
    [anon_sym_CARET] = ACTIONS(5572),
    [anon_sym_PIPE] = ACTIONS(5574),
    [anon_sym_AMP] = ACTIONS(5574),
    [anon_sym_LT_LT] = ACTIONS(5572),
    [anon_sym_GT_GT] = ACTIONS(5574),
    [anon_sym_GT_GT_GT] = ACTIONS(5572),
    [anon_sym_EQ_EQ] = ACTIONS(5572),
    [anon_sym_BANG_EQ] = ACTIONS(5572),
    [anon_sym_GT_EQ] = ACTIONS(5572),
    [anon_sym_LT_EQ] = ACTIONS(5572),
    [anon_sym_DOT] = ACTIONS(5574),
    [anon_sym_EQ_GT] = ACTIONS(5572),
    [anon_sym_switch] = ACTIONS(5572),
    [anon_sym_DOT_DOT] = ACTIONS(5572),
    [anon_sym_and] = ACTIONS(5572),
    [anon_sym_or] = ACTIONS(5574),
    [anon_sym_AMP_AMP] = ACTIONS(5572),
    [anon_sym_PIPE_PIPE] = ACTIONS(5572),
    [anon_sym_QMARK_QMARK] = ACTIONS(5572),
    [anon_sym_from] = ACTIONS(5572),
    [anon_sym_into] = ACTIONS(5572),
    [anon_sym_join] = ACTIONS(5572),
    [anon_sym_on] = ACTIONS(5572),
    [anon_sym_equals] = ACTIONS(5572),
    [anon_sym_let] = ACTIONS(5572),
    [anon_sym_orderby] = ACTIONS(5572),
    [anon_sym_group] = ACTIONS(5572),
    [anon_sym_by] = ACTIONS(5572),
    [anon_sym_select] = ACTIONS(5572),
    [anon_sym_as] = ACTIONS(5572),
    [anon_sym_is] = ACTIONS(5572),
    [anon_sym_DASH_GT] = ACTIONS(5572),
    [anon_sym_with] = ACTIONS(5572),
    [aux_sym_preproc_if_token3] = ACTIONS(5572),
    [aux_sym_preproc_else_token1] = ACTIONS(5572),
    [aux_sym_preproc_elif_token1] = ACTIONS(5572),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3690] = {
    [sym_preproc_region] = STATE(3690),
    [sym_preproc_endregion] = STATE(3690),
    [sym_preproc_line] = STATE(3690),
    [sym_preproc_pragma] = STATE(3690),
    [sym_preproc_nullable] = STATE(3690),
    [sym_preproc_error] = STATE(3690),
    [sym_preproc_warning] = STATE(3690),
    [sym_preproc_define] = STATE(3690),
    [sym_preproc_undef] = STATE(3690),
    [anon_sym_SEMI] = ACTIONS(5576),
    [anon_sym_LBRACK] = ACTIONS(5576),
    [anon_sym_COLON] = ACTIONS(5576),
    [anon_sym_COMMA] = ACTIONS(5576),
    [anon_sym_RBRACK] = ACTIONS(5576),
    [anon_sym_LPAREN] = ACTIONS(5576),
    [anon_sym_RPAREN] = ACTIONS(5576),
    [anon_sym_RBRACE] = ACTIONS(5576),
    [anon_sym_LT] = ACTIONS(5578),
    [anon_sym_GT] = ACTIONS(5578),
    [anon_sym_in] = ACTIONS(5578),
    [anon_sym_where] = ACTIONS(5576),
    [anon_sym_QMARK] = ACTIONS(5578),
    [anon_sym_BANG] = ACTIONS(5578),
    [anon_sym_PLUS_PLUS] = ACTIONS(5576),
    [anon_sym_DASH_DASH] = ACTIONS(5576),
    [anon_sym_PLUS] = ACTIONS(5578),
    [anon_sym_DASH] = ACTIONS(5578),
    [anon_sym_STAR] = ACTIONS(5576),
    [anon_sym_SLASH] = ACTIONS(5578),
    [anon_sym_PERCENT] = ACTIONS(5576),
    [anon_sym_CARET] = ACTIONS(5576),
    [anon_sym_PIPE] = ACTIONS(5578),
    [anon_sym_AMP] = ACTIONS(5578),
    [anon_sym_LT_LT] = ACTIONS(5576),
    [anon_sym_GT_GT] = ACTIONS(5578),
    [anon_sym_GT_GT_GT] = ACTIONS(5576),
    [anon_sym_EQ_EQ] = ACTIONS(5576),
    [anon_sym_BANG_EQ] = ACTIONS(5576),
    [anon_sym_GT_EQ] = ACTIONS(5576),
    [anon_sym_LT_EQ] = ACTIONS(5576),
    [anon_sym_DOT] = ACTIONS(5578),
    [anon_sym_EQ_GT] = ACTIONS(5576),
    [anon_sym_switch] = ACTIONS(5576),
    [anon_sym_DOT_DOT] = ACTIONS(5576),
    [anon_sym_and] = ACTIONS(5576),
    [anon_sym_or] = ACTIONS(5578),
    [anon_sym_AMP_AMP] = ACTIONS(5576),
    [anon_sym_PIPE_PIPE] = ACTIONS(5576),
    [anon_sym_QMARK_QMARK] = ACTIONS(5576),
    [anon_sym_from] = ACTIONS(5576),
    [anon_sym_into] = ACTIONS(5576),
    [anon_sym_join] = ACTIONS(5576),
    [anon_sym_on] = ACTIONS(5576),
    [anon_sym_equals] = ACTIONS(5576),
    [anon_sym_let] = ACTIONS(5576),
    [anon_sym_orderby] = ACTIONS(5576),
    [anon_sym_group] = ACTIONS(5576),
    [anon_sym_by] = ACTIONS(5576),
    [anon_sym_select] = ACTIONS(5576),
    [anon_sym_as] = ACTIONS(5576),
    [anon_sym_is] = ACTIONS(5576),
    [anon_sym_DASH_GT] = ACTIONS(5576),
    [anon_sym_with] = ACTIONS(5576),
    [aux_sym_preproc_if_token3] = ACTIONS(5576),
    [aux_sym_preproc_else_token1] = ACTIONS(5576),
    [aux_sym_preproc_elif_token1] = ACTIONS(5576),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3691] = {
    [sym_preproc_region] = STATE(3691),
    [sym_preproc_endregion] = STATE(3691),
    [sym_preproc_line] = STATE(3691),
    [sym_preproc_pragma] = STATE(3691),
    [sym_preproc_nullable] = STATE(3691),
    [sym_preproc_error] = STATE(3691),
    [sym_preproc_warning] = STATE(3691),
    [sym_preproc_define] = STATE(3691),
    [sym_preproc_undef] = STATE(3691),
    [anon_sym_SEMI] = ACTIONS(5580),
    [anon_sym_LBRACK] = ACTIONS(5580),
    [anon_sym_COLON] = ACTIONS(5580),
    [anon_sym_COMMA] = ACTIONS(5580),
    [anon_sym_RBRACK] = ACTIONS(5580),
    [anon_sym_LPAREN] = ACTIONS(5580),
    [anon_sym_RPAREN] = ACTIONS(5580),
    [anon_sym_RBRACE] = ACTIONS(5580),
    [anon_sym_LT] = ACTIONS(5582),
    [anon_sym_GT] = ACTIONS(5582),
    [anon_sym_in] = ACTIONS(5582),
    [anon_sym_where] = ACTIONS(5580),
    [anon_sym_QMARK] = ACTIONS(5582),
    [anon_sym_BANG] = ACTIONS(5582),
    [anon_sym_PLUS_PLUS] = ACTIONS(5580),
    [anon_sym_DASH_DASH] = ACTIONS(5580),
    [anon_sym_PLUS] = ACTIONS(5582),
    [anon_sym_DASH] = ACTIONS(5582),
    [anon_sym_STAR] = ACTIONS(5580),
    [anon_sym_SLASH] = ACTIONS(5582),
    [anon_sym_PERCENT] = ACTIONS(5580),
    [anon_sym_CARET] = ACTIONS(5580),
    [anon_sym_PIPE] = ACTIONS(5582),
    [anon_sym_AMP] = ACTIONS(5582),
    [anon_sym_LT_LT] = ACTIONS(5580),
    [anon_sym_GT_GT] = ACTIONS(5582),
    [anon_sym_GT_GT_GT] = ACTIONS(5580),
    [anon_sym_EQ_EQ] = ACTIONS(5580),
    [anon_sym_BANG_EQ] = ACTIONS(5580),
    [anon_sym_GT_EQ] = ACTIONS(5580),
    [anon_sym_LT_EQ] = ACTIONS(5580),
    [anon_sym_DOT] = ACTIONS(5582),
    [anon_sym_EQ_GT] = ACTIONS(5580),
    [anon_sym_switch] = ACTIONS(5580),
    [anon_sym_DOT_DOT] = ACTIONS(5580),
    [anon_sym_and] = ACTIONS(5580),
    [anon_sym_or] = ACTIONS(5582),
    [anon_sym_AMP_AMP] = ACTIONS(5580),
    [anon_sym_PIPE_PIPE] = ACTIONS(5580),
    [anon_sym_QMARK_QMARK] = ACTIONS(5580),
    [anon_sym_from] = ACTIONS(5580),
    [anon_sym_into] = ACTIONS(5580),
    [anon_sym_join] = ACTIONS(5580),
    [anon_sym_on] = ACTIONS(5580),
    [anon_sym_equals] = ACTIONS(5580),
    [anon_sym_let] = ACTIONS(5580),
    [anon_sym_orderby] = ACTIONS(5580),
    [anon_sym_group] = ACTIONS(5580),
    [anon_sym_by] = ACTIONS(5580),
    [anon_sym_select] = ACTIONS(5580),
    [anon_sym_as] = ACTIONS(5580),
    [anon_sym_is] = ACTIONS(5580),
    [anon_sym_DASH_GT] = ACTIONS(5580),
    [anon_sym_with] = ACTIONS(5580),
    [aux_sym_preproc_if_token3] = ACTIONS(5580),
    [aux_sym_preproc_else_token1] = ACTIONS(5580),
    [aux_sym_preproc_elif_token1] = ACTIONS(5580),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3692] = {
    [sym_preproc_region] = STATE(3692),
    [sym_preproc_endregion] = STATE(3692),
    [sym_preproc_line] = STATE(3692),
    [sym_preproc_pragma] = STATE(3692),
    [sym_preproc_nullable] = STATE(3692),
    [sym_preproc_error] = STATE(3692),
    [sym_preproc_warning] = STATE(3692),
    [sym_preproc_define] = STATE(3692),
    [sym_preproc_undef] = STATE(3692),
    [anon_sym_SEMI] = ACTIONS(5584),
    [anon_sym_LBRACK] = ACTIONS(5584),
    [anon_sym_COLON] = ACTIONS(5584),
    [anon_sym_COMMA] = ACTIONS(5584),
    [anon_sym_RBRACK] = ACTIONS(5584),
    [anon_sym_LPAREN] = ACTIONS(5584),
    [anon_sym_RPAREN] = ACTIONS(5584),
    [anon_sym_RBRACE] = ACTIONS(5584),
    [anon_sym_LT] = ACTIONS(5586),
    [anon_sym_GT] = ACTIONS(5586),
    [anon_sym_in] = ACTIONS(5586),
    [anon_sym_where] = ACTIONS(5584),
    [anon_sym_QMARK] = ACTIONS(5586),
    [anon_sym_BANG] = ACTIONS(5586),
    [anon_sym_PLUS_PLUS] = ACTIONS(5584),
    [anon_sym_DASH_DASH] = ACTIONS(5584),
    [anon_sym_PLUS] = ACTIONS(5586),
    [anon_sym_DASH] = ACTIONS(5586),
    [anon_sym_STAR] = ACTIONS(5584),
    [anon_sym_SLASH] = ACTIONS(5586),
    [anon_sym_PERCENT] = ACTIONS(5584),
    [anon_sym_CARET] = ACTIONS(5584),
    [anon_sym_PIPE] = ACTIONS(5586),
    [anon_sym_AMP] = ACTIONS(5586),
    [anon_sym_LT_LT] = ACTIONS(5584),
    [anon_sym_GT_GT] = ACTIONS(5586),
    [anon_sym_GT_GT_GT] = ACTIONS(5584),
    [anon_sym_EQ_EQ] = ACTIONS(5584),
    [anon_sym_BANG_EQ] = ACTIONS(5584),
    [anon_sym_GT_EQ] = ACTIONS(5584),
    [anon_sym_LT_EQ] = ACTIONS(5584),
    [anon_sym_DOT] = ACTIONS(5586),
    [anon_sym_EQ_GT] = ACTIONS(5584),
    [anon_sym_switch] = ACTIONS(5584),
    [anon_sym_DOT_DOT] = ACTIONS(5584),
    [anon_sym_and] = ACTIONS(5584),
    [anon_sym_or] = ACTIONS(5586),
    [anon_sym_AMP_AMP] = ACTIONS(5584),
    [anon_sym_PIPE_PIPE] = ACTIONS(5584),
    [anon_sym_QMARK_QMARK] = ACTIONS(5584),
    [anon_sym_from] = ACTIONS(5584),
    [anon_sym_into] = ACTIONS(5584),
    [anon_sym_join] = ACTIONS(5584),
    [anon_sym_on] = ACTIONS(5584),
    [anon_sym_equals] = ACTIONS(5584),
    [anon_sym_let] = ACTIONS(5584),
    [anon_sym_orderby] = ACTIONS(5584),
    [anon_sym_group] = ACTIONS(5584),
    [anon_sym_by] = ACTIONS(5584),
    [anon_sym_select] = ACTIONS(5584),
    [anon_sym_as] = ACTIONS(5584),
    [anon_sym_is] = ACTIONS(5584),
    [anon_sym_DASH_GT] = ACTIONS(5584),
    [anon_sym_with] = ACTIONS(5584),
    [aux_sym_preproc_if_token3] = ACTIONS(5584),
    [aux_sym_preproc_else_token1] = ACTIONS(5584),
    [aux_sym_preproc_elif_token1] = ACTIONS(5584),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3693] = {
    [sym_preproc_region] = STATE(3693),
    [sym_preproc_endregion] = STATE(3693),
    [sym_preproc_line] = STATE(3693),
    [sym_preproc_pragma] = STATE(3693),
    [sym_preproc_nullable] = STATE(3693),
    [sym_preproc_error] = STATE(3693),
    [sym_preproc_warning] = STATE(3693),
    [sym_preproc_define] = STATE(3693),
    [sym_preproc_undef] = STATE(3693),
    [anon_sym_SEMI] = ACTIONS(5588),
    [anon_sym_LBRACK] = ACTIONS(5588),
    [anon_sym_COLON] = ACTIONS(5588),
    [anon_sym_COMMA] = ACTIONS(5588),
    [anon_sym_RBRACK] = ACTIONS(5588),
    [anon_sym_LPAREN] = ACTIONS(5588),
    [anon_sym_RPAREN] = ACTIONS(5588),
    [anon_sym_RBRACE] = ACTIONS(5588),
    [anon_sym_LT] = ACTIONS(5590),
    [anon_sym_GT] = ACTIONS(5590),
    [anon_sym_in] = ACTIONS(5590),
    [anon_sym_where] = ACTIONS(5588),
    [anon_sym_QMARK] = ACTIONS(5590),
    [anon_sym_BANG] = ACTIONS(5590),
    [anon_sym_PLUS_PLUS] = ACTIONS(5588),
    [anon_sym_DASH_DASH] = ACTIONS(5588),
    [anon_sym_PLUS] = ACTIONS(5590),
    [anon_sym_DASH] = ACTIONS(5590),
    [anon_sym_STAR] = ACTIONS(5588),
    [anon_sym_SLASH] = ACTIONS(5590),
    [anon_sym_PERCENT] = ACTIONS(5588),
    [anon_sym_CARET] = ACTIONS(5588),
    [anon_sym_PIPE] = ACTIONS(5590),
    [anon_sym_AMP] = ACTIONS(5590),
    [anon_sym_LT_LT] = ACTIONS(5588),
    [anon_sym_GT_GT] = ACTIONS(5590),
    [anon_sym_GT_GT_GT] = ACTIONS(5588),
    [anon_sym_EQ_EQ] = ACTIONS(5588),
    [anon_sym_BANG_EQ] = ACTIONS(5588),
    [anon_sym_GT_EQ] = ACTIONS(5588),
    [anon_sym_LT_EQ] = ACTIONS(5588),
    [anon_sym_DOT] = ACTIONS(5590),
    [anon_sym_EQ_GT] = ACTIONS(5588),
    [anon_sym_switch] = ACTIONS(5588),
    [anon_sym_DOT_DOT] = ACTIONS(5588),
    [anon_sym_and] = ACTIONS(5588),
    [anon_sym_or] = ACTIONS(5590),
    [anon_sym_AMP_AMP] = ACTIONS(5588),
    [anon_sym_PIPE_PIPE] = ACTIONS(5588),
    [anon_sym_QMARK_QMARK] = ACTIONS(5588),
    [anon_sym_from] = ACTIONS(5588),
    [anon_sym_into] = ACTIONS(5588),
    [anon_sym_join] = ACTIONS(5588),
    [anon_sym_on] = ACTIONS(5588),
    [anon_sym_equals] = ACTIONS(5588),
    [anon_sym_let] = ACTIONS(5588),
    [anon_sym_orderby] = ACTIONS(5588),
    [anon_sym_group] = ACTIONS(5588),
    [anon_sym_by] = ACTIONS(5588),
    [anon_sym_select] = ACTIONS(5588),
    [anon_sym_as] = ACTIONS(5588),
    [anon_sym_is] = ACTIONS(5588),
    [anon_sym_DASH_GT] = ACTIONS(5588),
    [anon_sym_with] = ACTIONS(5588),
    [aux_sym_preproc_if_token3] = ACTIONS(5588),
    [aux_sym_preproc_else_token1] = ACTIONS(5588),
    [aux_sym_preproc_elif_token1] = ACTIONS(5588),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3694] = {
    [sym_preproc_region] = STATE(3694),
    [sym_preproc_endregion] = STATE(3694),
    [sym_preproc_line] = STATE(3694),
    [sym_preproc_pragma] = STATE(3694),
    [sym_preproc_nullable] = STATE(3694),
    [sym_preproc_error] = STATE(3694),
    [sym_preproc_warning] = STATE(3694),
    [sym_preproc_define] = STATE(3694),
    [sym_preproc_undef] = STATE(3694),
    [anon_sym_SEMI] = ACTIONS(4546),
    [anon_sym_LBRACK] = ACTIONS(4546),
    [anon_sym_COLON] = ACTIONS(4546),
    [anon_sym_COMMA] = ACTIONS(4546),
    [anon_sym_RBRACK] = ACTIONS(4546),
    [anon_sym_LPAREN] = ACTIONS(4546),
    [anon_sym_RPAREN] = ACTIONS(4546),
    [anon_sym_LBRACE] = ACTIONS(4546),
    [anon_sym_RBRACE] = ACTIONS(4546),
    [anon_sym_LT] = ACTIONS(4544),
    [anon_sym_GT] = ACTIONS(4544),
    [anon_sym_in] = ACTIONS(4546),
    [anon_sym_where] = ACTIONS(4546),
    [anon_sym_QMARK] = ACTIONS(4544),
    [anon_sym_BANG] = ACTIONS(4544),
    [anon_sym_PLUS_PLUS] = ACTIONS(4546),
    [anon_sym_DASH_DASH] = ACTIONS(4546),
    [anon_sym_PLUS] = ACTIONS(4544),
    [anon_sym_DASH] = ACTIONS(4544),
    [anon_sym_STAR] = ACTIONS(4546),
    [anon_sym_SLASH] = ACTIONS(4544),
    [anon_sym_PERCENT] = ACTIONS(4546),
    [anon_sym_CARET] = ACTIONS(4546),
    [anon_sym_PIPE] = ACTIONS(4544),
    [anon_sym_AMP] = ACTIONS(4544),
    [anon_sym_LT_LT] = ACTIONS(4546),
    [anon_sym_GT_GT] = ACTIONS(4544),
    [anon_sym_GT_GT_GT] = ACTIONS(4546),
    [anon_sym_EQ_EQ] = ACTIONS(4546),
    [anon_sym_BANG_EQ] = ACTIONS(4546),
    [anon_sym_GT_EQ] = ACTIONS(4546),
    [anon_sym_LT_EQ] = ACTIONS(4546),
    [anon_sym_DOT] = ACTIONS(4544),
    [anon_sym_EQ_GT] = ACTIONS(4546),
    [anon_sym_switch] = ACTIONS(4546),
    [anon_sym_DOT_DOT] = ACTIONS(4546),
    [anon_sym_and] = ACTIONS(4546),
    [anon_sym_or] = ACTIONS(4544),
    [anon_sym_AMP_AMP] = ACTIONS(4546),
    [anon_sym_PIPE_PIPE] = ACTIONS(4546),
    [anon_sym_QMARK_QMARK] = ACTIONS(4546),
    [anon_sym_from] = ACTIONS(4546),
    [anon_sym_join] = ACTIONS(4546),
    [anon_sym_on] = ACTIONS(4546),
    [anon_sym_equals] = ACTIONS(4546),
    [anon_sym_let] = ACTIONS(4546),
    [anon_sym_orderby] = ACTIONS(4546),
    [anon_sym_group] = ACTIONS(4546),
    [anon_sym_by] = ACTIONS(4546),
    [anon_sym_select] = ACTIONS(4546),
    [anon_sym_as] = ACTIONS(4546),
    [anon_sym_is] = ACTIONS(4546),
    [anon_sym_DASH_GT] = ACTIONS(4546),
    [anon_sym_with] = ACTIONS(4546),
    [aux_sym_preproc_if_token3] = ACTIONS(4546),
    [aux_sym_preproc_else_token1] = ACTIONS(4546),
    [aux_sym_preproc_elif_token1] = ACTIONS(4546),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3695] = {
    [sym_preproc_region] = STATE(3695),
    [sym_preproc_endregion] = STATE(3695),
    [sym_preproc_line] = STATE(3695),
    [sym_preproc_pragma] = STATE(3695),
    [sym_preproc_nullable] = STATE(3695),
    [sym_preproc_error] = STATE(3695),
    [sym_preproc_warning] = STATE(3695),
    [sym_preproc_define] = STATE(3695),
    [sym_preproc_undef] = STATE(3695),
    [anon_sym_SEMI] = ACTIONS(5592),
    [anon_sym_LBRACK] = ACTIONS(5592),
    [anon_sym_COLON] = ACTIONS(5592),
    [anon_sym_COMMA] = ACTIONS(5592),
    [anon_sym_RBRACK] = ACTIONS(5592),
    [anon_sym_LPAREN] = ACTIONS(5592),
    [anon_sym_RPAREN] = ACTIONS(5592),
    [anon_sym_RBRACE] = ACTIONS(5592),
    [anon_sym_LT] = ACTIONS(5594),
    [anon_sym_GT] = ACTIONS(5594),
    [anon_sym_in] = ACTIONS(5594),
    [anon_sym_where] = ACTIONS(5592),
    [anon_sym_QMARK] = ACTIONS(5594),
    [anon_sym_BANG] = ACTIONS(5594),
    [anon_sym_PLUS_PLUS] = ACTIONS(5592),
    [anon_sym_DASH_DASH] = ACTIONS(5592),
    [anon_sym_PLUS] = ACTIONS(5594),
    [anon_sym_DASH] = ACTIONS(5594),
    [anon_sym_STAR] = ACTIONS(5592),
    [anon_sym_SLASH] = ACTIONS(5594),
    [anon_sym_PERCENT] = ACTIONS(5592),
    [anon_sym_CARET] = ACTIONS(5592),
    [anon_sym_PIPE] = ACTIONS(5594),
    [anon_sym_AMP] = ACTIONS(5594),
    [anon_sym_LT_LT] = ACTIONS(5592),
    [anon_sym_GT_GT] = ACTIONS(5594),
    [anon_sym_GT_GT_GT] = ACTIONS(5592),
    [anon_sym_EQ_EQ] = ACTIONS(5592),
    [anon_sym_BANG_EQ] = ACTIONS(5592),
    [anon_sym_GT_EQ] = ACTIONS(5592),
    [anon_sym_LT_EQ] = ACTIONS(5592),
    [anon_sym_DOT] = ACTIONS(5594),
    [anon_sym_EQ_GT] = ACTIONS(5592),
    [anon_sym_switch] = ACTIONS(5592),
    [anon_sym_DOT_DOT] = ACTIONS(5592),
    [anon_sym_and] = ACTIONS(5592),
    [anon_sym_or] = ACTIONS(5594),
    [anon_sym_AMP_AMP] = ACTIONS(5592),
    [anon_sym_PIPE_PIPE] = ACTIONS(5592),
    [anon_sym_QMARK_QMARK] = ACTIONS(5592),
    [anon_sym_from] = ACTIONS(5592),
    [anon_sym_into] = ACTIONS(5592),
    [anon_sym_join] = ACTIONS(5592),
    [anon_sym_on] = ACTIONS(5592),
    [anon_sym_equals] = ACTIONS(5592),
    [anon_sym_let] = ACTIONS(5592),
    [anon_sym_orderby] = ACTIONS(5592),
    [anon_sym_group] = ACTIONS(5592),
    [anon_sym_by] = ACTIONS(5592),
    [anon_sym_select] = ACTIONS(5592),
    [anon_sym_as] = ACTIONS(5592),
    [anon_sym_is] = ACTIONS(5592),
    [anon_sym_DASH_GT] = ACTIONS(5592),
    [anon_sym_with] = ACTIONS(5592),
    [aux_sym_preproc_if_token3] = ACTIONS(5592),
    [aux_sym_preproc_else_token1] = ACTIONS(5592),
    [aux_sym_preproc_elif_token1] = ACTIONS(5592),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3696] = {
    [sym_preproc_region] = STATE(3696),
    [sym_preproc_endregion] = STATE(3696),
    [sym_preproc_line] = STATE(3696),
    [sym_preproc_pragma] = STATE(3696),
    [sym_preproc_nullable] = STATE(3696),
    [sym_preproc_error] = STATE(3696),
    [sym_preproc_warning] = STATE(3696),
    [sym_preproc_define] = STATE(3696),
    [sym_preproc_undef] = STATE(3696),
    [anon_sym_SEMI] = ACTIONS(5596),
    [anon_sym_LBRACK] = ACTIONS(5596),
    [anon_sym_COLON] = ACTIONS(5596),
    [anon_sym_COMMA] = ACTIONS(5596),
    [anon_sym_RBRACK] = ACTIONS(5596),
    [anon_sym_LPAREN] = ACTIONS(5596),
    [anon_sym_RPAREN] = ACTIONS(5596),
    [anon_sym_RBRACE] = ACTIONS(5596),
    [anon_sym_LT] = ACTIONS(5598),
    [anon_sym_GT] = ACTIONS(5598),
    [anon_sym_in] = ACTIONS(5598),
    [anon_sym_where] = ACTIONS(5596),
    [anon_sym_QMARK] = ACTIONS(5598),
    [anon_sym_BANG] = ACTIONS(5598),
    [anon_sym_PLUS_PLUS] = ACTIONS(5596),
    [anon_sym_DASH_DASH] = ACTIONS(5596),
    [anon_sym_PLUS] = ACTIONS(5598),
    [anon_sym_DASH] = ACTIONS(5598),
    [anon_sym_STAR] = ACTIONS(5596),
    [anon_sym_SLASH] = ACTIONS(5598),
    [anon_sym_PERCENT] = ACTIONS(5596),
    [anon_sym_CARET] = ACTIONS(5596),
    [anon_sym_PIPE] = ACTIONS(5598),
    [anon_sym_AMP] = ACTIONS(5598),
    [anon_sym_LT_LT] = ACTIONS(5596),
    [anon_sym_GT_GT] = ACTIONS(5598),
    [anon_sym_GT_GT_GT] = ACTIONS(5596),
    [anon_sym_EQ_EQ] = ACTIONS(5596),
    [anon_sym_BANG_EQ] = ACTIONS(5596),
    [anon_sym_GT_EQ] = ACTIONS(5596),
    [anon_sym_LT_EQ] = ACTIONS(5596),
    [anon_sym_DOT] = ACTIONS(5598),
    [anon_sym_EQ_GT] = ACTIONS(5596),
    [anon_sym_switch] = ACTIONS(5596),
    [anon_sym_DOT_DOT] = ACTIONS(5596),
    [anon_sym_and] = ACTIONS(5596),
    [anon_sym_or] = ACTIONS(5598),
    [anon_sym_AMP_AMP] = ACTIONS(5596),
    [anon_sym_PIPE_PIPE] = ACTIONS(5596),
    [anon_sym_QMARK_QMARK] = ACTIONS(5596),
    [anon_sym_from] = ACTIONS(5596),
    [anon_sym_into] = ACTIONS(5596),
    [anon_sym_join] = ACTIONS(5596),
    [anon_sym_on] = ACTIONS(5596),
    [anon_sym_equals] = ACTIONS(5596),
    [anon_sym_let] = ACTIONS(5596),
    [anon_sym_orderby] = ACTIONS(5596),
    [anon_sym_group] = ACTIONS(5596),
    [anon_sym_by] = ACTIONS(5596),
    [anon_sym_select] = ACTIONS(5596),
    [anon_sym_as] = ACTIONS(5596),
    [anon_sym_is] = ACTIONS(5596),
    [anon_sym_DASH_GT] = ACTIONS(5596),
    [anon_sym_with] = ACTIONS(5596),
    [aux_sym_preproc_if_token3] = ACTIONS(5596),
    [aux_sym_preproc_else_token1] = ACTIONS(5596),
    [aux_sym_preproc_elif_token1] = ACTIONS(5596),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3697] = {
    [sym_preproc_region] = STATE(3697),
    [sym_preproc_endregion] = STATE(3697),
    [sym_preproc_line] = STATE(3697),
    [sym_preproc_pragma] = STATE(3697),
    [sym_preproc_nullable] = STATE(3697),
    [sym_preproc_error] = STATE(3697),
    [sym_preproc_warning] = STATE(3697),
    [sym_preproc_define] = STATE(3697),
    [sym_preproc_undef] = STATE(3697),
    [anon_sym_SEMI] = ACTIONS(4550),
    [anon_sym_LBRACK] = ACTIONS(4550),
    [anon_sym_COLON] = ACTIONS(4550),
    [anon_sym_COMMA] = ACTIONS(4550),
    [anon_sym_RBRACK] = ACTIONS(4550),
    [anon_sym_LPAREN] = ACTIONS(4550),
    [anon_sym_RPAREN] = ACTIONS(4550),
    [anon_sym_LBRACE] = ACTIONS(4550),
    [anon_sym_RBRACE] = ACTIONS(4550),
    [anon_sym_LT] = ACTIONS(4548),
    [anon_sym_GT] = ACTIONS(4548),
    [anon_sym_in] = ACTIONS(4550),
    [anon_sym_where] = ACTIONS(4550),
    [anon_sym_QMARK] = ACTIONS(4548),
    [anon_sym_BANG] = ACTIONS(4548),
    [anon_sym_PLUS_PLUS] = ACTIONS(4550),
    [anon_sym_DASH_DASH] = ACTIONS(4550),
    [anon_sym_PLUS] = ACTIONS(4548),
    [anon_sym_DASH] = ACTIONS(4548),
    [anon_sym_STAR] = ACTIONS(4550),
    [anon_sym_SLASH] = ACTIONS(4548),
    [anon_sym_PERCENT] = ACTIONS(4550),
    [anon_sym_CARET] = ACTIONS(4550),
    [anon_sym_PIPE] = ACTIONS(4548),
    [anon_sym_AMP] = ACTIONS(4548),
    [anon_sym_LT_LT] = ACTIONS(4550),
    [anon_sym_GT_GT] = ACTIONS(4548),
    [anon_sym_GT_GT_GT] = ACTIONS(4550),
    [anon_sym_EQ_EQ] = ACTIONS(4550),
    [anon_sym_BANG_EQ] = ACTIONS(4550),
    [anon_sym_GT_EQ] = ACTIONS(4550),
    [anon_sym_LT_EQ] = ACTIONS(4550),
    [anon_sym_DOT] = ACTIONS(4548),
    [anon_sym_EQ_GT] = ACTIONS(4550),
    [anon_sym_switch] = ACTIONS(4550),
    [anon_sym_DOT_DOT] = ACTIONS(4550),
    [anon_sym_and] = ACTIONS(4550),
    [anon_sym_or] = ACTIONS(4548),
    [anon_sym_AMP_AMP] = ACTIONS(4550),
    [anon_sym_PIPE_PIPE] = ACTIONS(4550),
    [anon_sym_QMARK_QMARK] = ACTIONS(4550),
    [anon_sym_from] = ACTIONS(4550),
    [anon_sym_join] = ACTIONS(4550),
    [anon_sym_on] = ACTIONS(4550),
    [anon_sym_equals] = ACTIONS(4550),
    [anon_sym_let] = ACTIONS(4550),
    [anon_sym_orderby] = ACTIONS(4550),
    [anon_sym_group] = ACTIONS(4550),
    [anon_sym_by] = ACTIONS(4550),
    [anon_sym_select] = ACTIONS(4550),
    [anon_sym_as] = ACTIONS(4550),
    [anon_sym_is] = ACTIONS(4550),
    [anon_sym_DASH_GT] = ACTIONS(4550),
    [anon_sym_with] = ACTIONS(4550),
    [aux_sym_preproc_if_token3] = ACTIONS(4550),
    [aux_sym_preproc_else_token1] = ACTIONS(4550),
    [aux_sym_preproc_elif_token1] = ACTIONS(4550),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3698] = {
    [sym_preproc_region] = STATE(3698),
    [sym_preproc_endregion] = STATE(3698),
    [sym_preproc_line] = STATE(3698),
    [sym_preproc_pragma] = STATE(3698),
    [sym_preproc_nullable] = STATE(3698),
    [sym_preproc_error] = STATE(3698),
    [sym_preproc_warning] = STATE(3698),
    [sym_preproc_define] = STATE(3698),
    [sym_preproc_undef] = STATE(3698),
    [anon_sym_SEMI] = ACTIONS(4488),
    [anon_sym_LBRACK] = ACTIONS(4488),
    [anon_sym_COLON] = ACTIONS(4488),
    [anon_sym_COMMA] = ACTIONS(4488),
    [anon_sym_RBRACK] = ACTIONS(4488),
    [anon_sym_LPAREN] = ACTIONS(4488),
    [anon_sym_RPAREN] = ACTIONS(4488),
    [anon_sym_LBRACE] = ACTIONS(4488),
    [anon_sym_RBRACE] = ACTIONS(4488),
    [anon_sym_LT] = ACTIONS(4486),
    [anon_sym_GT] = ACTIONS(4486),
    [anon_sym_in] = ACTIONS(4488),
    [anon_sym_where] = ACTIONS(4488),
    [anon_sym_QMARK] = ACTIONS(4486),
    [anon_sym_BANG] = ACTIONS(4486),
    [anon_sym_PLUS_PLUS] = ACTIONS(4488),
    [anon_sym_DASH_DASH] = ACTIONS(4488),
    [anon_sym_PLUS] = ACTIONS(4486),
    [anon_sym_DASH] = ACTIONS(4486),
    [anon_sym_STAR] = ACTIONS(4488),
    [anon_sym_SLASH] = ACTIONS(4486),
    [anon_sym_PERCENT] = ACTIONS(4488),
    [anon_sym_CARET] = ACTIONS(4488),
    [anon_sym_PIPE] = ACTIONS(4486),
    [anon_sym_AMP] = ACTIONS(4486),
    [anon_sym_LT_LT] = ACTIONS(4488),
    [anon_sym_GT_GT] = ACTIONS(4486),
    [anon_sym_GT_GT_GT] = ACTIONS(4488),
    [anon_sym_EQ_EQ] = ACTIONS(4488),
    [anon_sym_BANG_EQ] = ACTIONS(4488),
    [anon_sym_GT_EQ] = ACTIONS(4488),
    [anon_sym_LT_EQ] = ACTIONS(4488),
    [anon_sym_DOT] = ACTIONS(4486),
    [anon_sym_EQ_GT] = ACTIONS(4488),
    [anon_sym_switch] = ACTIONS(4488),
    [anon_sym_DOT_DOT] = ACTIONS(4488),
    [anon_sym_and] = ACTIONS(4488),
    [anon_sym_or] = ACTIONS(4486),
    [anon_sym_AMP_AMP] = ACTIONS(4488),
    [anon_sym_PIPE_PIPE] = ACTIONS(4488),
    [anon_sym_QMARK_QMARK] = ACTIONS(4488),
    [anon_sym_from] = ACTIONS(4488),
    [anon_sym_join] = ACTIONS(4488),
    [anon_sym_on] = ACTIONS(4488),
    [anon_sym_equals] = ACTIONS(4488),
    [anon_sym_let] = ACTIONS(4488),
    [anon_sym_orderby] = ACTIONS(4488),
    [anon_sym_group] = ACTIONS(4488),
    [anon_sym_by] = ACTIONS(4488),
    [anon_sym_select] = ACTIONS(4488),
    [anon_sym_as] = ACTIONS(4488),
    [anon_sym_is] = ACTIONS(4488),
    [anon_sym_DASH_GT] = ACTIONS(4488),
    [anon_sym_with] = ACTIONS(4488),
    [aux_sym_preproc_if_token3] = ACTIONS(4488),
    [aux_sym_preproc_else_token1] = ACTIONS(4488),
    [aux_sym_preproc_elif_token1] = ACTIONS(4488),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3699] = {
    [sym_preproc_region] = STATE(3699),
    [sym_preproc_endregion] = STATE(3699),
    [sym_preproc_line] = STATE(3699),
    [sym_preproc_pragma] = STATE(3699),
    [sym_preproc_nullable] = STATE(3699),
    [sym_preproc_error] = STATE(3699),
    [sym_preproc_warning] = STATE(3699),
    [sym_preproc_define] = STATE(3699),
    [sym_preproc_undef] = STATE(3699),
    [anon_sym_SEMI] = ACTIONS(5600),
    [anon_sym_LBRACK] = ACTIONS(5600),
    [anon_sym_COLON] = ACTIONS(5600),
    [anon_sym_COMMA] = ACTIONS(5600),
    [anon_sym_RBRACK] = ACTIONS(5600),
    [anon_sym_LPAREN] = ACTIONS(5600),
    [anon_sym_RPAREN] = ACTIONS(5600),
    [anon_sym_RBRACE] = ACTIONS(5600),
    [anon_sym_LT] = ACTIONS(5602),
    [anon_sym_GT] = ACTIONS(5602),
    [anon_sym_in] = ACTIONS(5602),
    [anon_sym_where] = ACTIONS(5600),
    [anon_sym_QMARK] = ACTIONS(5602),
    [anon_sym_BANG] = ACTIONS(5602),
    [anon_sym_PLUS_PLUS] = ACTIONS(5600),
    [anon_sym_DASH_DASH] = ACTIONS(5600),
    [anon_sym_PLUS] = ACTIONS(5602),
    [anon_sym_DASH] = ACTIONS(5602),
    [anon_sym_STAR] = ACTIONS(5600),
    [anon_sym_SLASH] = ACTIONS(5602),
    [anon_sym_PERCENT] = ACTIONS(5600),
    [anon_sym_CARET] = ACTIONS(5600),
    [anon_sym_PIPE] = ACTIONS(5602),
    [anon_sym_AMP] = ACTIONS(5602),
    [anon_sym_LT_LT] = ACTIONS(5600),
    [anon_sym_GT_GT] = ACTIONS(5602),
    [anon_sym_GT_GT_GT] = ACTIONS(5600),
    [anon_sym_EQ_EQ] = ACTIONS(5600),
    [anon_sym_BANG_EQ] = ACTIONS(5600),
    [anon_sym_GT_EQ] = ACTIONS(5600),
    [anon_sym_LT_EQ] = ACTIONS(5600),
    [anon_sym_DOT] = ACTIONS(5602),
    [anon_sym_EQ_GT] = ACTIONS(5600),
    [anon_sym_switch] = ACTIONS(5600),
    [anon_sym_DOT_DOT] = ACTIONS(5600),
    [anon_sym_and] = ACTIONS(5600),
    [anon_sym_or] = ACTIONS(5602),
    [anon_sym_AMP_AMP] = ACTIONS(5600),
    [anon_sym_PIPE_PIPE] = ACTIONS(5600),
    [anon_sym_QMARK_QMARK] = ACTIONS(5600),
    [anon_sym_from] = ACTIONS(5600),
    [anon_sym_into] = ACTIONS(5600),
    [anon_sym_join] = ACTIONS(5600),
    [anon_sym_on] = ACTIONS(5600),
    [anon_sym_equals] = ACTIONS(5600),
    [anon_sym_let] = ACTIONS(5600),
    [anon_sym_orderby] = ACTIONS(5600),
    [anon_sym_group] = ACTIONS(5600),
    [anon_sym_by] = ACTIONS(5600),
    [anon_sym_select] = ACTIONS(5600),
    [anon_sym_as] = ACTIONS(5600),
    [anon_sym_is] = ACTIONS(5600),
    [anon_sym_DASH_GT] = ACTIONS(5600),
    [anon_sym_with] = ACTIONS(5600),
    [aux_sym_preproc_if_token3] = ACTIONS(5600),
    [aux_sym_preproc_else_token1] = ACTIONS(5600),
    [aux_sym_preproc_elif_token1] = ACTIONS(5600),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3700] = {
    [sym_preproc_region] = STATE(3700),
    [sym_preproc_endregion] = STATE(3700),
    [sym_preproc_line] = STATE(3700),
    [sym_preproc_pragma] = STATE(3700),
    [sym_preproc_nullable] = STATE(3700),
    [sym_preproc_error] = STATE(3700),
    [sym_preproc_warning] = STATE(3700),
    [sym_preproc_define] = STATE(3700),
    [sym_preproc_undef] = STATE(3700),
    [anon_sym_SEMI] = ACTIONS(5604),
    [anon_sym_LBRACK] = ACTIONS(5604),
    [anon_sym_COLON] = ACTIONS(5604),
    [anon_sym_COMMA] = ACTIONS(5604),
    [anon_sym_RBRACK] = ACTIONS(5604),
    [anon_sym_LPAREN] = ACTIONS(5604),
    [anon_sym_RPAREN] = ACTIONS(5604),
    [anon_sym_RBRACE] = ACTIONS(5604),
    [anon_sym_LT] = ACTIONS(5606),
    [anon_sym_GT] = ACTIONS(5606),
    [anon_sym_in] = ACTIONS(5606),
    [anon_sym_where] = ACTIONS(5604),
    [anon_sym_QMARK] = ACTIONS(5606),
    [anon_sym_BANG] = ACTIONS(5606),
    [anon_sym_PLUS_PLUS] = ACTIONS(5604),
    [anon_sym_DASH_DASH] = ACTIONS(5604),
    [anon_sym_PLUS] = ACTIONS(5606),
    [anon_sym_DASH] = ACTIONS(5606),
    [anon_sym_STAR] = ACTIONS(5604),
    [anon_sym_SLASH] = ACTIONS(5606),
    [anon_sym_PERCENT] = ACTIONS(5604),
    [anon_sym_CARET] = ACTIONS(5604),
    [anon_sym_PIPE] = ACTIONS(5606),
    [anon_sym_AMP] = ACTIONS(5606),
    [anon_sym_LT_LT] = ACTIONS(5604),
    [anon_sym_GT_GT] = ACTIONS(5606),
    [anon_sym_GT_GT_GT] = ACTIONS(5604),
    [anon_sym_EQ_EQ] = ACTIONS(5604),
    [anon_sym_BANG_EQ] = ACTIONS(5604),
    [anon_sym_GT_EQ] = ACTIONS(5604),
    [anon_sym_LT_EQ] = ACTIONS(5604),
    [anon_sym_DOT] = ACTIONS(5606),
    [anon_sym_EQ_GT] = ACTIONS(5604),
    [anon_sym_switch] = ACTIONS(5604),
    [anon_sym_DOT_DOT] = ACTIONS(5604),
    [anon_sym_and] = ACTIONS(5604),
    [anon_sym_or] = ACTIONS(5606),
    [anon_sym_AMP_AMP] = ACTIONS(5604),
    [anon_sym_PIPE_PIPE] = ACTIONS(5604),
    [anon_sym_QMARK_QMARK] = ACTIONS(5604),
    [anon_sym_from] = ACTIONS(5604),
    [anon_sym_into] = ACTIONS(5604),
    [anon_sym_join] = ACTIONS(5604),
    [anon_sym_on] = ACTIONS(5604),
    [anon_sym_equals] = ACTIONS(5604),
    [anon_sym_let] = ACTIONS(5604),
    [anon_sym_orderby] = ACTIONS(5604),
    [anon_sym_group] = ACTIONS(5604),
    [anon_sym_by] = ACTIONS(5604),
    [anon_sym_select] = ACTIONS(5604),
    [anon_sym_as] = ACTIONS(5604),
    [anon_sym_is] = ACTIONS(5604),
    [anon_sym_DASH_GT] = ACTIONS(5604),
    [anon_sym_with] = ACTIONS(5604),
    [aux_sym_preproc_if_token3] = ACTIONS(5604),
    [aux_sym_preproc_else_token1] = ACTIONS(5604),
    [aux_sym_preproc_elif_token1] = ACTIONS(5604),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3701] = {
    [sym_preproc_region] = STATE(3701),
    [sym_preproc_endregion] = STATE(3701),
    [sym_preproc_line] = STATE(3701),
    [sym_preproc_pragma] = STATE(3701),
    [sym_preproc_nullable] = STATE(3701),
    [sym_preproc_error] = STATE(3701),
    [sym_preproc_warning] = STATE(3701),
    [sym_preproc_define] = STATE(3701),
    [sym_preproc_undef] = STATE(3701),
    [anon_sym_SEMI] = ACTIONS(5608),
    [anon_sym_LBRACK] = ACTIONS(5608),
    [anon_sym_COLON] = ACTIONS(5608),
    [anon_sym_COMMA] = ACTIONS(5608),
    [anon_sym_RBRACK] = ACTIONS(5608),
    [anon_sym_LPAREN] = ACTIONS(5608),
    [anon_sym_RPAREN] = ACTIONS(5608),
    [anon_sym_RBRACE] = ACTIONS(5608),
    [anon_sym_LT] = ACTIONS(5610),
    [anon_sym_GT] = ACTIONS(5610),
    [anon_sym_in] = ACTIONS(5610),
    [anon_sym_where] = ACTIONS(5608),
    [anon_sym_QMARK] = ACTIONS(5610),
    [anon_sym_BANG] = ACTIONS(5610),
    [anon_sym_PLUS_PLUS] = ACTIONS(5608),
    [anon_sym_DASH_DASH] = ACTIONS(5608),
    [anon_sym_PLUS] = ACTIONS(5610),
    [anon_sym_DASH] = ACTIONS(5610),
    [anon_sym_STAR] = ACTIONS(5608),
    [anon_sym_SLASH] = ACTIONS(5610),
    [anon_sym_PERCENT] = ACTIONS(5608),
    [anon_sym_CARET] = ACTIONS(5608),
    [anon_sym_PIPE] = ACTIONS(5610),
    [anon_sym_AMP] = ACTIONS(5610),
    [anon_sym_LT_LT] = ACTIONS(5608),
    [anon_sym_GT_GT] = ACTIONS(5610),
    [anon_sym_GT_GT_GT] = ACTIONS(5608),
    [anon_sym_EQ_EQ] = ACTIONS(5608),
    [anon_sym_BANG_EQ] = ACTIONS(5608),
    [anon_sym_GT_EQ] = ACTIONS(5608),
    [anon_sym_LT_EQ] = ACTIONS(5608),
    [anon_sym_DOT] = ACTIONS(5610),
    [anon_sym_EQ_GT] = ACTIONS(5608),
    [anon_sym_switch] = ACTIONS(5608),
    [anon_sym_DOT_DOT] = ACTIONS(5608),
    [anon_sym_and] = ACTIONS(5608),
    [anon_sym_or] = ACTIONS(5610),
    [anon_sym_AMP_AMP] = ACTIONS(5608),
    [anon_sym_PIPE_PIPE] = ACTIONS(5608),
    [anon_sym_QMARK_QMARK] = ACTIONS(5608),
    [anon_sym_from] = ACTIONS(5608),
    [anon_sym_into] = ACTIONS(5608),
    [anon_sym_join] = ACTIONS(5608),
    [anon_sym_on] = ACTIONS(5608),
    [anon_sym_equals] = ACTIONS(5608),
    [anon_sym_let] = ACTIONS(5608),
    [anon_sym_orderby] = ACTIONS(5608),
    [anon_sym_group] = ACTIONS(5608),
    [anon_sym_by] = ACTIONS(5608),
    [anon_sym_select] = ACTIONS(5608),
    [anon_sym_as] = ACTIONS(5608),
    [anon_sym_is] = ACTIONS(5608),
    [anon_sym_DASH_GT] = ACTIONS(5608),
    [anon_sym_with] = ACTIONS(5608),
    [aux_sym_preproc_if_token3] = ACTIONS(5608),
    [aux_sym_preproc_else_token1] = ACTIONS(5608),
    [aux_sym_preproc_elif_token1] = ACTIONS(5608),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3702] = {
    [sym_preproc_region] = STATE(3702),
    [sym_preproc_endregion] = STATE(3702),
    [sym_preproc_line] = STATE(3702),
    [sym_preproc_pragma] = STATE(3702),
    [sym_preproc_nullable] = STATE(3702),
    [sym_preproc_error] = STATE(3702),
    [sym_preproc_warning] = STATE(3702),
    [sym_preproc_define] = STATE(3702),
    [sym_preproc_undef] = STATE(3702),
    [anon_sym_EQ] = ACTIONS(5612),
    [anon_sym_LBRACK] = ACTIONS(5286),
    [anon_sym_COMMA] = ACTIONS(5286),
    [anon_sym_LPAREN] = ACTIONS(5286),
    [anon_sym_LT] = ACTIONS(5288),
    [anon_sym_GT] = ACTIONS(5288),
    [anon_sym_where] = ACTIONS(5286),
    [anon_sym_QMARK] = ACTIONS(5288),
    [anon_sym_BANG] = ACTIONS(5288),
    [anon_sym_PLUS_PLUS] = ACTIONS(5286),
    [anon_sym_DASH_DASH] = ACTIONS(5286),
    [anon_sym_PLUS] = ACTIONS(5288),
    [anon_sym_DASH] = ACTIONS(5288),
    [anon_sym_STAR] = ACTIONS(5288),
    [anon_sym_SLASH] = ACTIONS(5288),
    [anon_sym_PERCENT] = ACTIONS(5288),
    [anon_sym_CARET] = ACTIONS(5288),
    [anon_sym_PIPE] = ACTIONS(5288),
    [anon_sym_AMP] = ACTIONS(5288),
    [anon_sym_LT_LT] = ACTIONS(5288),
    [anon_sym_GT_GT] = ACTIONS(5288),
    [anon_sym_GT_GT_GT] = ACTIONS(5288),
    [anon_sym_EQ_EQ] = ACTIONS(5286),
    [anon_sym_BANG_EQ] = ACTIONS(5286),
    [anon_sym_GT_EQ] = ACTIONS(5286),
    [anon_sym_LT_EQ] = ACTIONS(5286),
    [anon_sym_DOT] = ACTIONS(5288),
    [anon_sym_switch] = ACTIONS(5286),
    [anon_sym_DOT_DOT] = ACTIONS(5286),
    [anon_sym_PLUS_EQ] = ACTIONS(5614),
    [anon_sym_DASH_EQ] = ACTIONS(5614),
    [anon_sym_STAR_EQ] = ACTIONS(5614),
    [anon_sym_SLASH_EQ] = ACTIONS(5614),
    [anon_sym_PERCENT_EQ] = ACTIONS(5614),
    [anon_sym_AMP_EQ] = ACTIONS(5614),
    [anon_sym_CARET_EQ] = ACTIONS(5614),
    [anon_sym_PIPE_EQ] = ACTIONS(5614),
    [anon_sym_LT_LT_EQ] = ACTIONS(5614),
    [anon_sym_GT_GT_EQ] = ACTIONS(5614),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(5614),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(5614),
    [anon_sym_AMP_AMP] = ACTIONS(5286),
    [anon_sym_PIPE_PIPE] = ACTIONS(5286),
    [anon_sym_QMARK_QMARK] = ACTIONS(5288),
    [anon_sym_from] = ACTIONS(5286),
    [anon_sym_into] = ACTIONS(5286),
    [anon_sym_join] = ACTIONS(5286),
    [anon_sym_let] = ACTIONS(5286),
    [anon_sym_orderby] = ACTIONS(5286),
    [anon_sym_ascending] = ACTIONS(5286),
    [anon_sym_descending] = ACTIONS(5286),
    [anon_sym_group] = ACTIONS(5286),
    [anon_sym_select] = ACTIONS(5286),
    [anon_sym_as] = ACTIONS(5288),
    [anon_sym_is] = ACTIONS(5286),
    [anon_sym_DASH_GT] = ACTIONS(5286),
    [anon_sym_with] = ACTIONS(5286),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3703] = {
    [sym_preproc_region] = STATE(3703),
    [sym_preproc_endregion] = STATE(3703),
    [sym_preproc_line] = STATE(3703),
    [sym_preproc_pragma] = STATE(3703),
    [sym_preproc_nullable] = STATE(3703),
    [sym_preproc_error] = STATE(3703),
    [sym_preproc_warning] = STATE(3703),
    [sym_preproc_define] = STATE(3703),
    [sym_preproc_undef] = STATE(3703),
    [anon_sym_SEMI] = ACTIONS(5616),
    [anon_sym_LBRACK] = ACTIONS(5616),
    [anon_sym_COLON] = ACTIONS(5616),
    [anon_sym_COMMA] = ACTIONS(5616),
    [anon_sym_RBRACK] = ACTIONS(5616),
    [anon_sym_LPAREN] = ACTIONS(5616),
    [anon_sym_RPAREN] = ACTIONS(5616),
    [anon_sym_RBRACE] = ACTIONS(5616),
    [anon_sym_LT] = ACTIONS(5618),
    [anon_sym_GT] = ACTIONS(5618),
    [anon_sym_in] = ACTIONS(5618),
    [anon_sym_where] = ACTIONS(5616),
    [anon_sym_QMARK] = ACTIONS(5618),
    [anon_sym_BANG] = ACTIONS(5618),
    [anon_sym_PLUS_PLUS] = ACTIONS(5616),
    [anon_sym_DASH_DASH] = ACTIONS(5616),
    [anon_sym_PLUS] = ACTIONS(5618),
    [anon_sym_DASH] = ACTIONS(5618),
    [anon_sym_STAR] = ACTIONS(5616),
    [anon_sym_SLASH] = ACTIONS(5618),
    [anon_sym_PERCENT] = ACTIONS(5616),
    [anon_sym_CARET] = ACTIONS(5616),
    [anon_sym_PIPE] = ACTIONS(5618),
    [anon_sym_AMP] = ACTIONS(5618),
    [anon_sym_LT_LT] = ACTIONS(5616),
    [anon_sym_GT_GT] = ACTIONS(5618),
    [anon_sym_GT_GT_GT] = ACTIONS(5616),
    [anon_sym_EQ_EQ] = ACTIONS(5616),
    [anon_sym_BANG_EQ] = ACTIONS(5616),
    [anon_sym_GT_EQ] = ACTIONS(5616),
    [anon_sym_LT_EQ] = ACTIONS(5616),
    [anon_sym_DOT] = ACTIONS(5618),
    [anon_sym_EQ_GT] = ACTIONS(5616),
    [anon_sym_switch] = ACTIONS(5616),
    [anon_sym_DOT_DOT] = ACTIONS(5616),
    [anon_sym_and] = ACTIONS(5616),
    [anon_sym_or] = ACTIONS(5618),
    [anon_sym_AMP_AMP] = ACTIONS(5616),
    [anon_sym_PIPE_PIPE] = ACTIONS(5616),
    [anon_sym_QMARK_QMARK] = ACTIONS(5616),
    [anon_sym_from] = ACTIONS(5616),
    [anon_sym_into] = ACTIONS(5616),
    [anon_sym_join] = ACTIONS(5616),
    [anon_sym_on] = ACTIONS(5616),
    [anon_sym_equals] = ACTIONS(5616),
    [anon_sym_let] = ACTIONS(5616),
    [anon_sym_orderby] = ACTIONS(5616),
    [anon_sym_group] = ACTIONS(5616),
    [anon_sym_by] = ACTIONS(5616),
    [anon_sym_select] = ACTIONS(5616),
    [anon_sym_as] = ACTIONS(5616),
    [anon_sym_is] = ACTIONS(5616),
    [anon_sym_DASH_GT] = ACTIONS(5616),
    [anon_sym_with] = ACTIONS(5616),
    [aux_sym_preproc_if_token3] = ACTIONS(5616),
    [aux_sym_preproc_else_token1] = ACTIONS(5616),
    [aux_sym_preproc_elif_token1] = ACTIONS(5616),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3704] = {
    [sym_preproc_region] = STATE(3704),
    [sym_preproc_endregion] = STATE(3704),
    [sym_preproc_line] = STATE(3704),
    [sym_preproc_pragma] = STATE(3704),
    [sym_preproc_nullable] = STATE(3704),
    [sym_preproc_error] = STATE(3704),
    [sym_preproc_warning] = STATE(3704),
    [sym_preproc_define] = STATE(3704),
    [sym_preproc_undef] = STATE(3704),
    [anon_sym_SEMI] = ACTIONS(2997),
    [anon_sym_LBRACK] = ACTIONS(2997),
    [anon_sym_COLON] = ACTIONS(2997),
    [anon_sym_COMMA] = ACTIONS(2997),
    [anon_sym_RBRACK] = ACTIONS(2997),
    [anon_sym_LPAREN] = ACTIONS(2997),
    [anon_sym_RPAREN] = ACTIONS(2997),
    [anon_sym_RBRACE] = ACTIONS(2997),
    [anon_sym_LT] = ACTIONS(2995),
    [anon_sym_GT] = ACTIONS(2995),
    [anon_sym_in] = ACTIONS(2995),
    [anon_sym_where] = ACTIONS(2997),
    [anon_sym_QMARK] = ACTIONS(2995),
    [anon_sym_BANG] = ACTIONS(2995),
    [anon_sym_PLUS_PLUS] = ACTIONS(2997),
    [anon_sym_DASH_DASH] = ACTIONS(2997),
    [anon_sym_PLUS] = ACTIONS(2995),
    [anon_sym_DASH] = ACTIONS(2995),
    [anon_sym_STAR] = ACTIONS(2997),
    [anon_sym_SLASH] = ACTIONS(2995),
    [anon_sym_PERCENT] = ACTIONS(2997),
    [anon_sym_CARET] = ACTIONS(2997),
    [anon_sym_PIPE] = ACTIONS(2995),
    [anon_sym_AMP] = ACTIONS(2995),
    [anon_sym_LT_LT] = ACTIONS(2997),
    [anon_sym_GT_GT] = ACTIONS(2995),
    [anon_sym_GT_GT_GT] = ACTIONS(2997),
    [anon_sym_EQ_EQ] = ACTIONS(2997),
    [anon_sym_BANG_EQ] = ACTIONS(2997),
    [anon_sym_GT_EQ] = ACTIONS(2997),
    [anon_sym_LT_EQ] = ACTIONS(2997),
    [anon_sym_DOT] = ACTIONS(2995),
    [anon_sym_EQ_GT] = ACTIONS(2997),
    [anon_sym_switch] = ACTIONS(2997),
    [anon_sym_DOT_DOT] = ACTIONS(2997),
    [anon_sym_and] = ACTIONS(2997),
    [anon_sym_or] = ACTIONS(2995),
    [anon_sym_AMP_AMP] = ACTIONS(2997),
    [anon_sym_PIPE_PIPE] = ACTIONS(2997),
    [anon_sym_QMARK_QMARK] = ACTIONS(2997),
    [anon_sym_from] = ACTIONS(2997),
    [anon_sym_into] = ACTIONS(2997),
    [anon_sym_join] = ACTIONS(2997),
    [anon_sym_on] = ACTIONS(2997),
    [anon_sym_equals] = ACTIONS(2997),
    [anon_sym_let] = ACTIONS(2997),
    [anon_sym_orderby] = ACTIONS(2997),
    [anon_sym_group] = ACTIONS(2997),
    [anon_sym_by] = ACTIONS(2997),
    [anon_sym_select] = ACTIONS(2997),
    [anon_sym_as] = ACTIONS(2997),
    [anon_sym_is] = ACTIONS(2997),
    [anon_sym_DASH_GT] = ACTIONS(2997),
    [anon_sym_with] = ACTIONS(2997),
    [aux_sym_preproc_if_token3] = ACTIONS(2997),
    [aux_sym_preproc_else_token1] = ACTIONS(2997),
    [aux_sym_preproc_elif_token1] = ACTIONS(2997),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3705] = {
    [sym_preproc_region] = STATE(3705),
    [sym_preproc_endregion] = STATE(3705),
    [sym_preproc_line] = STATE(3705),
    [sym_preproc_pragma] = STATE(3705),
    [sym_preproc_nullable] = STATE(3705),
    [sym_preproc_error] = STATE(3705),
    [sym_preproc_warning] = STATE(3705),
    [sym_preproc_define] = STATE(3705),
    [sym_preproc_undef] = STATE(3705),
    [anon_sym_SEMI] = ACTIONS(5620),
    [anon_sym_LBRACK] = ACTIONS(5620),
    [anon_sym_COLON] = ACTIONS(5620),
    [anon_sym_COMMA] = ACTIONS(5620),
    [anon_sym_RBRACK] = ACTIONS(5620),
    [anon_sym_LPAREN] = ACTIONS(5620),
    [anon_sym_RPAREN] = ACTIONS(5620),
    [anon_sym_RBRACE] = ACTIONS(5620),
    [anon_sym_LT] = ACTIONS(5622),
    [anon_sym_GT] = ACTIONS(5622),
    [anon_sym_in] = ACTIONS(5622),
    [anon_sym_where] = ACTIONS(5620),
    [anon_sym_QMARK] = ACTIONS(5622),
    [anon_sym_BANG] = ACTIONS(5622),
    [anon_sym_PLUS_PLUS] = ACTIONS(5620),
    [anon_sym_DASH_DASH] = ACTIONS(5620),
    [anon_sym_PLUS] = ACTIONS(5622),
    [anon_sym_DASH] = ACTIONS(5622),
    [anon_sym_STAR] = ACTIONS(5620),
    [anon_sym_SLASH] = ACTIONS(5622),
    [anon_sym_PERCENT] = ACTIONS(5620),
    [anon_sym_CARET] = ACTIONS(5620),
    [anon_sym_PIPE] = ACTIONS(5622),
    [anon_sym_AMP] = ACTIONS(5622),
    [anon_sym_LT_LT] = ACTIONS(5620),
    [anon_sym_GT_GT] = ACTIONS(5622),
    [anon_sym_GT_GT_GT] = ACTIONS(5620),
    [anon_sym_EQ_EQ] = ACTIONS(5620),
    [anon_sym_BANG_EQ] = ACTIONS(5620),
    [anon_sym_GT_EQ] = ACTIONS(5620),
    [anon_sym_LT_EQ] = ACTIONS(5620),
    [anon_sym_DOT] = ACTIONS(5622),
    [anon_sym_EQ_GT] = ACTIONS(5620),
    [anon_sym_switch] = ACTIONS(5620),
    [anon_sym_DOT_DOT] = ACTIONS(5620),
    [anon_sym_and] = ACTIONS(5620),
    [anon_sym_or] = ACTIONS(5622),
    [anon_sym_AMP_AMP] = ACTIONS(5620),
    [anon_sym_PIPE_PIPE] = ACTIONS(5620),
    [anon_sym_QMARK_QMARK] = ACTIONS(5620),
    [anon_sym_from] = ACTIONS(5620),
    [anon_sym_into] = ACTIONS(5620),
    [anon_sym_join] = ACTIONS(5620),
    [anon_sym_on] = ACTIONS(5620),
    [anon_sym_equals] = ACTIONS(5620),
    [anon_sym_let] = ACTIONS(5620),
    [anon_sym_orderby] = ACTIONS(5620),
    [anon_sym_group] = ACTIONS(5620),
    [anon_sym_by] = ACTIONS(5620),
    [anon_sym_select] = ACTIONS(5620),
    [anon_sym_as] = ACTIONS(5620),
    [anon_sym_is] = ACTIONS(5620),
    [anon_sym_DASH_GT] = ACTIONS(5620),
    [anon_sym_with] = ACTIONS(5620),
    [aux_sym_preproc_if_token3] = ACTIONS(5620),
    [aux_sym_preproc_else_token1] = ACTIONS(5620),
    [aux_sym_preproc_elif_token1] = ACTIONS(5620),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3706] = {
    [sym_preproc_region] = STATE(3706),
    [sym_preproc_endregion] = STATE(3706),
    [sym_preproc_line] = STATE(3706),
    [sym_preproc_pragma] = STATE(3706),
    [sym_preproc_nullable] = STATE(3706),
    [sym_preproc_error] = STATE(3706),
    [sym_preproc_warning] = STATE(3706),
    [sym_preproc_define] = STATE(3706),
    [sym_preproc_undef] = STATE(3706),
    [anon_sym_SEMI] = ACTIONS(4504),
    [anon_sym_LBRACK] = ACTIONS(4504),
    [anon_sym_COLON] = ACTIONS(4504),
    [anon_sym_COMMA] = ACTIONS(4504),
    [anon_sym_RBRACK] = ACTIONS(4504),
    [anon_sym_LPAREN] = ACTIONS(4504),
    [anon_sym_RPAREN] = ACTIONS(4504),
    [anon_sym_LBRACE] = ACTIONS(4504),
    [anon_sym_RBRACE] = ACTIONS(4504),
    [anon_sym_LT] = ACTIONS(4502),
    [anon_sym_GT] = ACTIONS(4502),
    [anon_sym_in] = ACTIONS(4504),
    [anon_sym_where] = ACTIONS(4504),
    [anon_sym_QMARK] = ACTIONS(4502),
    [anon_sym_BANG] = ACTIONS(4502),
    [anon_sym_PLUS_PLUS] = ACTIONS(4504),
    [anon_sym_DASH_DASH] = ACTIONS(4504),
    [anon_sym_PLUS] = ACTIONS(4502),
    [anon_sym_DASH] = ACTIONS(4502),
    [anon_sym_STAR] = ACTIONS(4504),
    [anon_sym_SLASH] = ACTIONS(4502),
    [anon_sym_PERCENT] = ACTIONS(4504),
    [anon_sym_CARET] = ACTIONS(4504),
    [anon_sym_PIPE] = ACTIONS(4502),
    [anon_sym_AMP] = ACTIONS(4502),
    [anon_sym_LT_LT] = ACTIONS(4504),
    [anon_sym_GT_GT] = ACTIONS(4502),
    [anon_sym_GT_GT_GT] = ACTIONS(4504),
    [anon_sym_EQ_EQ] = ACTIONS(4504),
    [anon_sym_BANG_EQ] = ACTIONS(4504),
    [anon_sym_GT_EQ] = ACTIONS(4504),
    [anon_sym_LT_EQ] = ACTIONS(4504),
    [anon_sym_DOT] = ACTIONS(4502),
    [anon_sym_EQ_GT] = ACTIONS(4504),
    [anon_sym_switch] = ACTIONS(4504),
    [anon_sym_DOT_DOT] = ACTIONS(4504),
    [anon_sym_and] = ACTIONS(4504),
    [anon_sym_or] = ACTIONS(4502),
    [anon_sym_AMP_AMP] = ACTIONS(4504),
    [anon_sym_PIPE_PIPE] = ACTIONS(4504),
    [anon_sym_QMARK_QMARK] = ACTIONS(4504),
    [anon_sym_from] = ACTIONS(4504),
    [anon_sym_join] = ACTIONS(4504),
    [anon_sym_on] = ACTIONS(4504),
    [anon_sym_equals] = ACTIONS(4504),
    [anon_sym_let] = ACTIONS(4504),
    [anon_sym_orderby] = ACTIONS(4504),
    [anon_sym_group] = ACTIONS(4504),
    [anon_sym_by] = ACTIONS(4504),
    [anon_sym_select] = ACTIONS(4504),
    [anon_sym_as] = ACTIONS(4504),
    [anon_sym_is] = ACTIONS(4504),
    [anon_sym_DASH_GT] = ACTIONS(4504),
    [anon_sym_with] = ACTIONS(4504),
    [aux_sym_preproc_if_token3] = ACTIONS(4504),
    [aux_sym_preproc_else_token1] = ACTIONS(4504),
    [aux_sym_preproc_elif_token1] = ACTIONS(4504),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3707] = {
    [sym_preproc_region] = STATE(3707),
    [sym_preproc_endregion] = STATE(3707),
    [sym_preproc_line] = STATE(3707),
    [sym_preproc_pragma] = STATE(3707),
    [sym_preproc_nullable] = STATE(3707),
    [sym_preproc_error] = STATE(3707),
    [sym_preproc_warning] = STATE(3707),
    [sym_preproc_define] = STATE(3707),
    [sym_preproc_undef] = STATE(3707),
    [anon_sym_SEMI] = ACTIONS(4494),
    [anon_sym_LBRACK] = ACTIONS(4494),
    [anon_sym_COLON] = ACTIONS(4494),
    [anon_sym_COMMA] = ACTIONS(4494),
    [anon_sym_RBRACK] = ACTIONS(4494),
    [anon_sym_LPAREN] = ACTIONS(4494),
    [anon_sym_RPAREN] = ACTIONS(4494),
    [anon_sym_LBRACE] = ACTIONS(4494),
    [anon_sym_RBRACE] = ACTIONS(4494),
    [anon_sym_LT] = ACTIONS(4492),
    [anon_sym_GT] = ACTIONS(4492),
    [anon_sym_in] = ACTIONS(4494),
    [anon_sym_where] = ACTIONS(4494),
    [anon_sym_QMARK] = ACTIONS(4492),
    [anon_sym_BANG] = ACTIONS(4492),
    [anon_sym_PLUS_PLUS] = ACTIONS(4494),
    [anon_sym_DASH_DASH] = ACTIONS(4494),
    [anon_sym_PLUS] = ACTIONS(4492),
    [anon_sym_DASH] = ACTIONS(4492),
    [anon_sym_STAR] = ACTIONS(4494),
    [anon_sym_SLASH] = ACTIONS(4492),
    [anon_sym_PERCENT] = ACTIONS(4494),
    [anon_sym_CARET] = ACTIONS(4494),
    [anon_sym_PIPE] = ACTIONS(4492),
    [anon_sym_AMP] = ACTIONS(4492),
    [anon_sym_LT_LT] = ACTIONS(4494),
    [anon_sym_GT_GT] = ACTIONS(4492),
    [anon_sym_GT_GT_GT] = ACTIONS(4494),
    [anon_sym_EQ_EQ] = ACTIONS(4494),
    [anon_sym_BANG_EQ] = ACTIONS(4494),
    [anon_sym_GT_EQ] = ACTIONS(4494),
    [anon_sym_LT_EQ] = ACTIONS(4494),
    [anon_sym_DOT] = ACTIONS(4492),
    [anon_sym_EQ_GT] = ACTIONS(4494),
    [anon_sym_switch] = ACTIONS(4494),
    [anon_sym_DOT_DOT] = ACTIONS(4494),
    [anon_sym_and] = ACTIONS(4494),
    [anon_sym_or] = ACTIONS(4492),
    [anon_sym_AMP_AMP] = ACTIONS(4494),
    [anon_sym_PIPE_PIPE] = ACTIONS(4494),
    [anon_sym_QMARK_QMARK] = ACTIONS(4494),
    [anon_sym_from] = ACTIONS(4494),
    [anon_sym_join] = ACTIONS(4494),
    [anon_sym_on] = ACTIONS(4494),
    [anon_sym_equals] = ACTIONS(4494),
    [anon_sym_let] = ACTIONS(4494),
    [anon_sym_orderby] = ACTIONS(4494),
    [anon_sym_group] = ACTIONS(4494),
    [anon_sym_by] = ACTIONS(4494),
    [anon_sym_select] = ACTIONS(4494),
    [anon_sym_as] = ACTIONS(4494),
    [anon_sym_is] = ACTIONS(4494),
    [anon_sym_DASH_GT] = ACTIONS(4494),
    [anon_sym_with] = ACTIONS(4494),
    [aux_sym_preproc_if_token3] = ACTIONS(4494),
    [aux_sym_preproc_else_token1] = ACTIONS(4494),
    [aux_sym_preproc_elif_token1] = ACTIONS(4494),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3708] = {
    [sym_preproc_region] = STATE(3708),
    [sym_preproc_endregion] = STATE(3708),
    [sym_preproc_line] = STATE(3708),
    [sym_preproc_pragma] = STATE(3708),
    [sym_preproc_nullable] = STATE(3708),
    [sym_preproc_error] = STATE(3708),
    [sym_preproc_warning] = STATE(3708),
    [sym_preproc_define] = STATE(3708),
    [sym_preproc_undef] = STATE(3708),
    [anon_sym_SEMI] = ACTIONS(5624),
    [anon_sym_LBRACK] = ACTIONS(5624),
    [anon_sym_COLON] = ACTIONS(5624),
    [anon_sym_COMMA] = ACTIONS(5624),
    [anon_sym_RBRACK] = ACTIONS(5624),
    [anon_sym_LPAREN] = ACTIONS(5624),
    [anon_sym_RPAREN] = ACTIONS(5624),
    [anon_sym_RBRACE] = ACTIONS(5624),
    [anon_sym_LT] = ACTIONS(5626),
    [anon_sym_GT] = ACTIONS(5626),
    [anon_sym_in] = ACTIONS(5626),
    [anon_sym_where] = ACTIONS(5624),
    [anon_sym_QMARK] = ACTIONS(5626),
    [anon_sym_BANG] = ACTIONS(5626),
    [anon_sym_PLUS_PLUS] = ACTIONS(5624),
    [anon_sym_DASH_DASH] = ACTIONS(5624),
    [anon_sym_PLUS] = ACTIONS(5626),
    [anon_sym_DASH] = ACTIONS(5626),
    [anon_sym_STAR] = ACTIONS(5624),
    [anon_sym_SLASH] = ACTIONS(5626),
    [anon_sym_PERCENT] = ACTIONS(5624),
    [anon_sym_CARET] = ACTIONS(5624),
    [anon_sym_PIPE] = ACTIONS(5626),
    [anon_sym_AMP] = ACTIONS(5626),
    [anon_sym_LT_LT] = ACTIONS(5624),
    [anon_sym_GT_GT] = ACTIONS(5626),
    [anon_sym_GT_GT_GT] = ACTIONS(5624),
    [anon_sym_EQ_EQ] = ACTIONS(5624),
    [anon_sym_BANG_EQ] = ACTIONS(5624),
    [anon_sym_GT_EQ] = ACTIONS(5624),
    [anon_sym_LT_EQ] = ACTIONS(5624),
    [anon_sym_DOT] = ACTIONS(5626),
    [anon_sym_EQ_GT] = ACTIONS(5624),
    [anon_sym_switch] = ACTIONS(5624),
    [anon_sym_DOT_DOT] = ACTIONS(5624),
    [anon_sym_and] = ACTIONS(5624),
    [anon_sym_or] = ACTIONS(5626),
    [anon_sym_AMP_AMP] = ACTIONS(5624),
    [anon_sym_PIPE_PIPE] = ACTIONS(5624),
    [anon_sym_QMARK_QMARK] = ACTIONS(5624),
    [anon_sym_from] = ACTIONS(5624),
    [anon_sym_into] = ACTIONS(5624),
    [anon_sym_join] = ACTIONS(5624),
    [anon_sym_on] = ACTIONS(5624),
    [anon_sym_equals] = ACTIONS(5624),
    [anon_sym_let] = ACTIONS(5624),
    [anon_sym_orderby] = ACTIONS(5624),
    [anon_sym_group] = ACTIONS(5624),
    [anon_sym_by] = ACTIONS(5624),
    [anon_sym_select] = ACTIONS(5624),
    [anon_sym_as] = ACTIONS(5624),
    [anon_sym_is] = ACTIONS(5624),
    [anon_sym_DASH_GT] = ACTIONS(5624),
    [anon_sym_with] = ACTIONS(5624),
    [aux_sym_preproc_if_token3] = ACTIONS(5624),
    [aux_sym_preproc_else_token1] = ACTIONS(5624),
    [aux_sym_preproc_elif_token1] = ACTIONS(5624),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3709] = {
    [sym_preproc_region] = STATE(3709),
    [sym_preproc_endregion] = STATE(3709),
    [sym_preproc_line] = STATE(3709),
    [sym_preproc_pragma] = STATE(3709),
    [sym_preproc_nullable] = STATE(3709),
    [sym_preproc_error] = STATE(3709),
    [sym_preproc_warning] = STATE(3709),
    [sym_preproc_define] = STATE(3709),
    [sym_preproc_undef] = STATE(3709),
    [anon_sym_SEMI] = ACTIONS(5628),
    [anon_sym_LBRACK] = ACTIONS(5628),
    [anon_sym_COLON] = ACTIONS(5628),
    [anon_sym_COMMA] = ACTIONS(5628),
    [anon_sym_RBRACK] = ACTIONS(5628),
    [anon_sym_LPAREN] = ACTIONS(5628),
    [anon_sym_RPAREN] = ACTIONS(5628),
    [anon_sym_RBRACE] = ACTIONS(5628),
    [anon_sym_LT] = ACTIONS(5630),
    [anon_sym_GT] = ACTIONS(5630),
    [anon_sym_in] = ACTIONS(5630),
    [anon_sym_where] = ACTIONS(5628),
    [anon_sym_QMARK] = ACTIONS(5630),
    [anon_sym_BANG] = ACTIONS(5630),
    [anon_sym_PLUS_PLUS] = ACTIONS(5628),
    [anon_sym_DASH_DASH] = ACTIONS(5628),
    [anon_sym_PLUS] = ACTIONS(5630),
    [anon_sym_DASH] = ACTIONS(5630),
    [anon_sym_STAR] = ACTIONS(5628),
    [anon_sym_SLASH] = ACTIONS(5630),
    [anon_sym_PERCENT] = ACTIONS(5628),
    [anon_sym_CARET] = ACTIONS(5628),
    [anon_sym_PIPE] = ACTIONS(5630),
    [anon_sym_AMP] = ACTIONS(5630),
    [anon_sym_LT_LT] = ACTIONS(5628),
    [anon_sym_GT_GT] = ACTIONS(5630),
    [anon_sym_GT_GT_GT] = ACTIONS(5628),
    [anon_sym_EQ_EQ] = ACTIONS(5628),
    [anon_sym_BANG_EQ] = ACTIONS(5628),
    [anon_sym_GT_EQ] = ACTIONS(5628),
    [anon_sym_LT_EQ] = ACTIONS(5628),
    [anon_sym_DOT] = ACTIONS(5630),
    [anon_sym_EQ_GT] = ACTIONS(5628),
    [anon_sym_switch] = ACTIONS(5628),
    [anon_sym_DOT_DOT] = ACTIONS(5628),
    [anon_sym_and] = ACTIONS(5628),
    [anon_sym_or] = ACTIONS(5630),
    [anon_sym_AMP_AMP] = ACTIONS(5628),
    [anon_sym_PIPE_PIPE] = ACTIONS(5628),
    [anon_sym_QMARK_QMARK] = ACTIONS(5628),
    [anon_sym_from] = ACTIONS(5628),
    [anon_sym_into] = ACTIONS(5628),
    [anon_sym_join] = ACTIONS(5628),
    [anon_sym_on] = ACTIONS(5628),
    [anon_sym_equals] = ACTIONS(5628),
    [anon_sym_let] = ACTIONS(5628),
    [anon_sym_orderby] = ACTIONS(5628),
    [anon_sym_group] = ACTIONS(5628),
    [anon_sym_by] = ACTIONS(5628),
    [anon_sym_select] = ACTIONS(5628),
    [anon_sym_as] = ACTIONS(5628),
    [anon_sym_is] = ACTIONS(5628),
    [anon_sym_DASH_GT] = ACTIONS(5628),
    [anon_sym_with] = ACTIONS(5628),
    [aux_sym_preproc_if_token3] = ACTIONS(5628),
    [aux_sym_preproc_else_token1] = ACTIONS(5628),
    [aux_sym_preproc_elif_token1] = ACTIONS(5628),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3710] = {
    [sym_preproc_region] = STATE(3710),
    [sym_preproc_endregion] = STATE(3710),
    [sym_preproc_line] = STATE(3710),
    [sym_preproc_pragma] = STATE(3710),
    [sym_preproc_nullable] = STATE(3710),
    [sym_preproc_error] = STATE(3710),
    [sym_preproc_warning] = STATE(3710),
    [sym_preproc_define] = STATE(3710),
    [sym_preproc_undef] = STATE(3710),
    [anon_sym_SEMI] = ACTIONS(4128),
    [anon_sym_LBRACK] = ACTIONS(4128),
    [anon_sym_COLON] = ACTIONS(4128),
    [anon_sym_COMMA] = ACTIONS(4128),
    [anon_sym_RBRACK] = ACTIONS(4128),
    [anon_sym_LPAREN] = ACTIONS(4128),
    [anon_sym_RPAREN] = ACTIONS(4128),
    [anon_sym_LBRACE] = ACTIONS(4128),
    [anon_sym_RBRACE] = ACTIONS(4128),
    [anon_sym_LT] = ACTIONS(4126),
    [anon_sym_GT] = ACTIONS(4126),
    [anon_sym_in] = ACTIONS(4128),
    [anon_sym_where] = ACTIONS(4128),
    [anon_sym_QMARK] = ACTIONS(4126),
    [anon_sym_BANG] = ACTIONS(4126),
    [anon_sym_PLUS_PLUS] = ACTIONS(4128),
    [anon_sym_DASH_DASH] = ACTIONS(4128),
    [anon_sym_PLUS] = ACTIONS(4126),
    [anon_sym_DASH] = ACTIONS(4126),
    [anon_sym_STAR] = ACTIONS(4128),
    [anon_sym_SLASH] = ACTIONS(4126),
    [anon_sym_PERCENT] = ACTIONS(4128),
    [anon_sym_CARET] = ACTIONS(4128),
    [anon_sym_PIPE] = ACTIONS(4126),
    [anon_sym_AMP] = ACTIONS(4126),
    [anon_sym_LT_LT] = ACTIONS(4128),
    [anon_sym_GT_GT] = ACTIONS(4126),
    [anon_sym_GT_GT_GT] = ACTIONS(4128),
    [anon_sym_EQ_EQ] = ACTIONS(4128),
    [anon_sym_BANG_EQ] = ACTIONS(4128),
    [anon_sym_GT_EQ] = ACTIONS(4128),
    [anon_sym_LT_EQ] = ACTIONS(4128),
    [anon_sym_DOT] = ACTIONS(4126),
    [anon_sym_EQ_GT] = ACTIONS(4128),
    [anon_sym_switch] = ACTIONS(4128),
    [anon_sym_DOT_DOT] = ACTIONS(4128),
    [anon_sym_and] = ACTIONS(4128),
    [anon_sym_or] = ACTIONS(4126),
    [anon_sym_AMP_AMP] = ACTIONS(4128),
    [anon_sym_PIPE_PIPE] = ACTIONS(4128),
    [anon_sym_QMARK_QMARK] = ACTIONS(4128),
    [anon_sym_from] = ACTIONS(4128),
    [anon_sym_join] = ACTIONS(4128),
    [anon_sym_on] = ACTIONS(4128),
    [anon_sym_equals] = ACTIONS(4128),
    [anon_sym_let] = ACTIONS(4128),
    [anon_sym_orderby] = ACTIONS(4128),
    [anon_sym_group] = ACTIONS(4128),
    [anon_sym_by] = ACTIONS(4128),
    [anon_sym_select] = ACTIONS(4128),
    [anon_sym_as] = ACTIONS(4128),
    [anon_sym_is] = ACTIONS(4128),
    [anon_sym_DASH_GT] = ACTIONS(4128),
    [anon_sym_with] = ACTIONS(4128),
    [aux_sym_preproc_if_token3] = ACTIONS(4128),
    [aux_sym_preproc_else_token1] = ACTIONS(4128),
    [aux_sym_preproc_elif_token1] = ACTIONS(4128),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3711] = {
    [sym_preproc_region] = STATE(3711),
    [sym_preproc_endregion] = STATE(3711),
    [sym_preproc_line] = STATE(3711),
    [sym_preproc_pragma] = STATE(3711),
    [sym_preproc_nullable] = STATE(3711),
    [sym_preproc_error] = STATE(3711),
    [sym_preproc_warning] = STATE(3711),
    [sym_preproc_define] = STATE(3711),
    [sym_preproc_undef] = STATE(3711),
    [anon_sym_SEMI] = ACTIONS(5632),
    [anon_sym_LBRACK] = ACTIONS(5632),
    [anon_sym_COLON] = ACTIONS(5632),
    [anon_sym_COMMA] = ACTIONS(5632),
    [anon_sym_RBRACK] = ACTIONS(5632),
    [anon_sym_LPAREN] = ACTIONS(5632),
    [anon_sym_RPAREN] = ACTIONS(5632),
    [anon_sym_RBRACE] = ACTIONS(5632),
    [anon_sym_LT] = ACTIONS(5634),
    [anon_sym_GT] = ACTIONS(5634),
    [anon_sym_in] = ACTIONS(5634),
    [anon_sym_where] = ACTIONS(5632),
    [anon_sym_QMARK] = ACTIONS(5634),
    [anon_sym_BANG] = ACTIONS(5634),
    [anon_sym_PLUS_PLUS] = ACTIONS(5632),
    [anon_sym_DASH_DASH] = ACTIONS(5632),
    [anon_sym_PLUS] = ACTIONS(5634),
    [anon_sym_DASH] = ACTIONS(5634),
    [anon_sym_STAR] = ACTIONS(5632),
    [anon_sym_SLASH] = ACTIONS(5634),
    [anon_sym_PERCENT] = ACTIONS(5632),
    [anon_sym_CARET] = ACTIONS(5632),
    [anon_sym_PIPE] = ACTIONS(5634),
    [anon_sym_AMP] = ACTIONS(5634),
    [anon_sym_LT_LT] = ACTIONS(5632),
    [anon_sym_GT_GT] = ACTIONS(5634),
    [anon_sym_GT_GT_GT] = ACTIONS(5632),
    [anon_sym_EQ_EQ] = ACTIONS(5632),
    [anon_sym_BANG_EQ] = ACTIONS(5632),
    [anon_sym_GT_EQ] = ACTIONS(5632),
    [anon_sym_LT_EQ] = ACTIONS(5632),
    [anon_sym_DOT] = ACTIONS(5634),
    [anon_sym_EQ_GT] = ACTIONS(5632),
    [anon_sym_switch] = ACTIONS(5632),
    [anon_sym_DOT_DOT] = ACTIONS(5632),
    [anon_sym_and] = ACTIONS(5632),
    [anon_sym_or] = ACTIONS(5634),
    [anon_sym_AMP_AMP] = ACTIONS(5632),
    [anon_sym_PIPE_PIPE] = ACTIONS(5632),
    [anon_sym_QMARK_QMARK] = ACTIONS(5632),
    [anon_sym_from] = ACTIONS(5632),
    [anon_sym_into] = ACTIONS(5632),
    [anon_sym_join] = ACTIONS(5632),
    [anon_sym_on] = ACTIONS(5632),
    [anon_sym_equals] = ACTIONS(5632),
    [anon_sym_let] = ACTIONS(5632),
    [anon_sym_orderby] = ACTIONS(5632),
    [anon_sym_group] = ACTIONS(5632),
    [anon_sym_by] = ACTIONS(5632),
    [anon_sym_select] = ACTIONS(5632),
    [anon_sym_as] = ACTIONS(5632),
    [anon_sym_is] = ACTIONS(5632),
    [anon_sym_DASH_GT] = ACTIONS(5632),
    [anon_sym_with] = ACTIONS(5632),
    [aux_sym_preproc_if_token3] = ACTIONS(5632),
    [aux_sym_preproc_else_token1] = ACTIONS(5632),
    [aux_sym_preproc_elif_token1] = ACTIONS(5632),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3712] = {
    [sym_preproc_region] = STATE(3712),
    [sym_preproc_endregion] = STATE(3712),
    [sym_preproc_line] = STATE(3712),
    [sym_preproc_pragma] = STATE(3712),
    [sym_preproc_nullable] = STATE(3712),
    [sym_preproc_error] = STATE(3712),
    [sym_preproc_warning] = STATE(3712),
    [sym_preproc_define] = STATE(3712),
    [sym_preproc_undef] = STATE(3712),
    [anon_sym_SEMI] = ACTIONS(5636),
    [anon_sym_LBRACK] = ACTIONS(5636),
    [anon_sym_COLON] = ACTIONS(5636),
    [anon_sym_COMMA] = ACTIONS(5636),
    [anon_sym_RBRACK] = ACTIONS(5636),
    [anon_sym_LPAREN] = ACTIONS(5636),
    [anon_sym_RPAREN] = ACTIONS(5636),
    [anon_sym_RBRACE] = ACTIONS(5636),
    [anon_sym_LT] = ACTIONS(5638),
    [anon_sym_GT] = ACTIONS(5638),
    [anon_sym_in] = ACTIONS(5638),
    [anon_sym_where] = ACTIONS(5636),
    [anon_sym_QMARK] = ACTIONS(5638),
    [anon_sym_BANG] = ACTIONS(5638),
    [anon_sym_PLUS_PLUS] = ACTIONS(5636),
    [anon_sym_DASH_DASH] = ACTIONS(5636),
    [anon_sym_PLUS] = ACTIONS(5638),
    [anon_sym_DASH] = ACTIONS(5638),
    [anon_sym_STAR] = ACTIONS(5636),
    [anon_sym_SLASH] = ACTIONS(5638),
    [anon_sym_PERCENT] = ACTIONS(5636),
    [anon_sym_CARET] = ACTIONS(5636),
    [anon_sym_PIPE] = ACTIONS(5638),
    [anon_sym_AMP] = ACTIONS(5638),
    [anon_sym_LT_LT] = ACTIONS(5636),
    [anon_sym_GT_GT] = ACTIONS(5638),
    [anon_sym_GT_GT_GT] = ACTIONS(5636),
    [anon_sym_EQ_EQ] = ACTIONS(5636),
    [anon_sym_BANG_EQ] = ACTIONS(5636),
    [anon_sym_GT_EQ] = ACTIONS(5636),
    [anon_sym_LT_EQ] = ACTIONS(5636),
    [anon_sym_DOT] = ACTIONS(5638),
    [anon_sym_EQ_GT] = ACTIONS(5636),
    [anon_sym_switch] = ACTIONS(5636),
    [anon_sym_DOT_DOT] = ACTIONS(5636),
    [anon_sym_and] = ACTIONS(5636),
    [anon_sym_or] = ACTIONS(5638),
    [anon_sym_AMP_AMP] = ACTIONS(5636),
    [anon_sym_PIPE_PIPE] = ACTIONS(5636),
    [anon_sym_QMARK_QMARK] = ACTIONS(5636),
    [anon_sym_from] = ACTIONS(5636),
    [anon_sym_into] = ACTIONS(5636),
    [anon_sym_join] = ACTIONS(5636),
    [anon_sym_on] = ACTIONS(5636),
    [anon_sym_equals] = ACTIONS(5636),
    [anon_sym_let] = ACTIONS(5636),
    [anon_sym_orderby] = ACTIONS(5636),
    [anon_sym_group] = ACTIONS(5636),
    [anon_sym_by] = ACTIONS(5636),
    [anon_sym_select] = ACTIONS(5636),
    [anon_sym_as] = ACTIONS(5636),
    [anon_sym_is] = ACTIONS(5636),
    [anon_sym_DASH_GT] = ACTIONS(5636),
    [anon_sym_with] = ACTIONS(5636),
    [aux_sym_preproc_if_token3] = ACTIONS(5636),
    [aux_sym_preproc_else_token1] = ACTIONS(5636),
    [aux_sym_preproc_elif_token1] = ACTIONS(5636),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3713] = {
    [sym_preproc_region] = STATE(3713),
    [sym_preproc_endregion] = STATE(3713),
    [sym_preproc_line] = STATE(3713),
    [sym_preproc_pragma] = STATE(3713),
    [sym_preproc_nullable] = STATE(3713),
    [sym_preproc_error] = STATE(3713),
    [sym_preproc_warning] = STATE(3713),
    [sym_preproc_define] = STATE(3713),
    [sym_preproc_undef] = STATE(3713),
    [anon_sym_SEMI] = ACTIONS(5640),
    [anon_sym_LBRACK] = ACTIONS(5640),
    [anon_sym_COLON] = ACTIONS(5640),
    [anon_sym_COMMA] = ACTIONS(5640),
    [anon_sym_RBRACK] = ACTIONS(5640),
    [anon_sym_LPAREN] = ACTIONS(5640),
    [anon_sym_RPAREN] = ACTIONS(5640),
    [anon_sym_RBRACE] = ACTIONS(5640),
    [anon_sym_LT] = ACTIONS(5642),
    [anon_sym_GT] = ACTIONS(5642),
    [anon_sym_in] = ACTIONS(5642),
    [anon_sym_where] = ACTIONS(5640),
    [anon_sym_QMARK] = ACTIONS(5642),
    [anon_sym_BANG] = ACTIONS(5642),
    [anon_sym_PLUS_PLUS] = ACTIONS(5640),
    [anon_sym_DASH_DASH] = ACTIONS(5640),
    [anon_sym_PLUS] = ACTIONS(5642),
    [anon_sym_DASH] = ACTIONS(5642),
    [anon_sym_STAR] = ACTIONS(5640),
    [anon_sym_SLASH] = ACTIONS(5642),
    [anon_sym_PERCENT] = ACTIONS(5640),
    [anon_sym_CARET] = ACTIONS(5640),
    [anon_sym_PIPE] = ACTIONS(5642),
    [anon_sym_AMP] = ACTIONS(5642),
    [anon_sym_LT_LT] = ACTIONS(5640),
    [anon_sym_GT_GT] = ACTIONS(5642),
    [anon_sym_GT_GT_GT] = ACTIONS(5640),
    [anon_sym_EQ_EQ] = ACTIONS(5640),
    [anon_sym_BANG_EQ] = ACTIONS(5640),
    [anon_sym_GT_EQ] = ACTIONS(5640),
    [anon_sym_LT_EQ] = ACTIONS(5640),
    [anon_sym_DOT] = ACTIONS(5642),
    [anon_sym_EQ_GT] = ACTIONS(5640),
    [anon_sym_switch] = ACTIONS(5640),
    [anon_sym_DOT_DOT] = ACTIONS(5640),
    [anon_sym_and] = ACTIONS(5640),
    [anon_sym_or] = ACTIONS(5642),
    [anon_sym_AMP_AMP] = ACTIONS(5640),
    [anon_sym_PIPE_PIPE] = ACTIONS(5640),
    [anon_sym_QMARK_QMARK] = ACTIONS(5640),
    [anon_sym_from] = ACTIONS(5640),
    [anon_sym_into] = ACTIONS(5640),
    [anon_sym_join] = ACTIONS(5640),
    [anon_sym_on] = ACTIONS(5640),
    [anon_sym_equals] = ACTIONS(5640),
    [anon_sym_let] = ACTIONS(5640),
    [anon_sym_orderby] = ACTIONS(5640),
    [anon_sym_group] = ACTIONS(5640),
    [anon_sym_by] = ACTIONS(5640),
    [anon_sym_select] = ACTIONS(5640),
    [anon_sym_as] = ACTIONS(5640),
    [anon_sym_is] = ACTIONS(5640),
    [anon_sym_DASH_GT] = ACTIONS(5640),
    [anon_sym_with] = ACTIONS(5640),
    [aux_sym_preproc_if_token3] = ACTIONS(5640),
    [aux_sym_preproc_else_token1] = ACTIONS(5640),
    [aux_sym_preproc_elif_token1] = ACTIONS(5640),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3714] = {
    [sym_preproc_region] = STATE(3714),
    [sym_preproc_endregion] = STATE(3714),
    [sym_preproc_line] = STATE(3714),
    [sym_preproc_pragma] = STATE(3714),
    [sym_preproc_nullable] = STATE(3714),
    [sym_preproc_error] = STATE(3714),
    [sym_preproc_warning] = STATE(3714),
    [sym_preproc_define] = STATE(3714),
    [sym_preproc_undef] = STATE(3714),
    [anon_sym_SEMI] = ACTIONS(5644),
    [anon_sym_LBRACK] = ACTIONS(5644),
    [anon_sym_COLON] = ACTIONS(5644),
    [anon_sym_COMMA] = ACTIONS(5644),
    [anon_sym_RBRACK] = ACTIONS(5644),
    [anon_sym_LPAREN] = ACTIONS(5644),
    [anon_sym_RPAREN] = ACTIONS(5644),
    [anon_sym_RBRACE] = ACTIONS(5644),
    [anon_sym_LT] = ACTIONS(5646),
    [anon_sym_GT] = ACTIONS(5646),
    [anon_sym_in] = ACTIONS(5646),
    [anon_sym_where] = ACTIONS(5644),
    [anon_sym_QMARK] = ACTIONS(5646),
    [anon_sym_BANG] = ACTIONS(5646),
    [anon_sym_PLUS_PLUS] = ACTIONS(5644),
    [anon_sym_DASH_DASH] = ACTIONS(5644),
    [anon_sym_PLUS] = ACTIONS(5646),
    [anon_sym_DASH] = ACTIONS(5646),
    [anon_sym_STAR] = ACTIONS(5644),
    [anon_sym_SLASH] = ACTIONS(5646),
    [anon_sym_PERCENT] = ACTIONS(5644),
    [anon_sym_CARET] = ACTIONS(5644),
    [anon_sym_PIPE] = ACTIONS(5646),
    [anon_sym_AMP] = ACTIONS(5646),
    [anon_sym_LT_LT] = ACTIONS(5644),
    [anon_sym_GT_GT] = ACTIONS(5646),
    [anon_sym_GT_GT_GT] = ACTIONS(5644),
    [anon_sym_EQ_EQ] = ACTIONS(5644),
    [anon_sym_BANG_EQ] = ACTIONS(5644),
    [anon_sym_GT_EQ] = ACTIONS(5644),
    [anon_sym_LT_EQ] = ACTIONS(5644),
    [anon_sym_DOT] = ACTIONS(5646),
    [anon_sym_EQ_GT] = ACTIONS(5644),
    [anon_sym_switch] = ACTIONS(5644),
    [anon_sym_DOT_DOT] = ACTIONS(5644),
    [anon_sym_and] = ACTIONS(5644),
    [anon_sym_or] = ACTIONS(5646),
    [anon_sym_AMP_AMP] = ACTIONS(5644),
    [anon_sym_PIPE_PIPE] = ACTIONS(5644),
    [anon_sym_QMARK_QMARK] = ACTIONS(5644),
    [anon_sym_from] = ACTIONS(5644),
    [anon_sym_into] = ACTIONS(5644),
    [anon_sym_join] = ACTIONS(5644),
    [anon_sym_on] = ACTIONS(5644),
    [anon_sym_equals] = ACTIONS(5644),
    [anon_sym_let] = ACTIONS(5644),
    [anon_sym_orderby] = ACTIONS(5644),
    [anon_sym_group] = ACTIONS(5644),
    [anon_sym_by] = ACTIONS(5644),
    [anon_sym_select] = ACTIONS(5644),
    [anon_sym_as] = ACTIONS(5644),
    [anon_sym_is] = ACTIONS(5644),
    [anon_sym_DASH_GT] = ACTIONS(5644),
    [anon_sym_with] = ACTIONS(5644),
    [aux_sym_preproc_if_token3] = ACTIONS(5644),
    [aux_sym_preproc_else_token1] = ACTIONS(5644),
    [aux_sym_preproc_elif_token1] = ACTIONS(5644),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3715] = {
    [sym_preproc_region] = STATE(3715),
    [sym_preproc_endregion] = STATE(3715),
    [sym_preproc_line] = STATE(3715),
    [sym_preproc_pragma] = STATE(3715),
    [sym_preproc_nullable] = STATE(3715),
    [sym_preproc_error] = STATE(3715),
    [sym_preproc_warning] = STATE(3715),
    [sym_preproc_define] = STATE(3715),
    [sym_preproc_undef] = STATE(3715),
    [anon_sym_SEMI] = ACTIONS(4132),
    [anon_sym_LBRACK] = ACTIONS(4132),
    [anon_sym_COLON] = ACTIONS(4132),
    [anon_sym_COMMA] = ACTIONS(4132),
    [anon_sym_RBRACK] = ACTIONS(4132),
    [anon_sym_LPAREN] = ACTIONS(4132),
    [anon_sym_RPAREN] = ACTIONS(4132),
    [anon_sym_LBRACE] = ACTIONS(4132),
    [anon_sym_RBRACE] = ACTIONS(4132),
    [anon_sym_LT] = ACTIONS(4130),
    [anon_sym_GT] = ACTIONS(4130),
    [anon_sym_in] = ACTIONS(4132),
    [anon_sym_where] = ACTIONS(4132),
    [anon_sym_QMARK] = ACTIONS(4130),
    [anon_sym_BANG] = ACTIONS(4130),
    [anon_sym_PLUS_PLUS] = ACTIONS(4132),
    [anon_sym_DASH_DASH] = ACTIONS(4132),
    [anon_sym_PLUS] = ACTIONS(4130),
    [anon_sym_DASH] = ACTIONS(4130),
    [anon_sym_STAR] = ACTIONS(4132),
    [anon_sym_SLASH] = ACTIONS(4130),
    [anon_sym_PERCENT] = ACTIONS(4132),
    [anon_sym_CARET] = ACTIONS(4132),
    [anon_sym_PIPE] = ACTIONS(4130),
    [anon_sym_AMP] = ACTIONS(4130),
    [anon_sym_LT_LT] = ACTIONS(4132),
    [anon_sym_GT_GT] = ACTIONS(4130),
    [anon_sym_GT_GT_GT] = ACTIONS(4132),
    [anon_sym_EQ_EQ] = ACTIONS(4132),
    [anon_sym_BANG_EQ] = ACTIONS(4132),
    [anon_sym_GT_EQ] = ACTIONS(4132),
    [anon_sym_LT_EQ] = ACTIONS(4132),
    [anon_sym_DOT] = ACTIONS(4130),
    [anon_sym_EQ_GT] = ACTIONS(4132),
    [anon_sym_switch] = ACTIONS(4132),
    [anon_sym_DOT_DOT] = ACTIONS(4132),
    [anon_sym_and] = ACTIONS(4132),
    [anon_sym_or] = ACTIONS(4130),
    [anon_sym_AMP_AMP] = ACTIONS(4132),
    [anon_sym_PIPE_PIPE] = ACTIONS(4132),
    [anon_sym_QMARK_QMARK] = ACTIONS(4132),
    [anon_sym_from] = ACTIONS(4132),
    [anon_sym_join] = ACTIONS(4132),
    [anon_sym_on] = ACTIONS(4132),
    [anon_sym_equals] = ACTIONS(4132),
    [anon_sym_let] = ACTIONS(4132),
    [anon_sym_orderby] = ACTIONS(4132),
    [anon_sym_group] = ACTIONS(4132),
    [anon_sym_by] = ACTIONS(4132),
    [anon_sym_select] = ACTIONS(4132),
    [anon_sym_as] = ACTIONS(4132),
    [anon_sym_is] = ACTIONS(4132),
    [anon_sym_DASH_GT] = ACTIONS(4132),
    [anon_sym_with] = ACTIONS(4132),
    [aux_sym_preproc_if_token3] = ACTIONS(4132),
    [aux_sym_preproc_else_token1] = ACTIONS(4132),
    [aux_sym_preproc_elif_token1] = ACTIONS(4132),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3716] = {
    [sym_preproc_region] = STATE(3716),
    [sym_preproc_endregion] = STATE(3716),
    [sym_preproc_line] = STATE(3716),
    [sym_preproc_pragma] = STATE(3716),
    [sym_preproc_nullable] = STATE(3716),
    [sym_preproc_error] = STATE(3716),
    [sym_preproc_warning] = STATE(3716),
    [sym_preproc_define] = STATE(3716),
    [sym_preproc_undef] = STATE(3716),
    [anon_sym_SEMI] = ACTIONS(5648),
    [anon_sym_LBRACK] = ACTIONS(5648),
    [anon_sym_COLON] = ACTIONS(5648),
    [anon_sym_COMMA] = ACTIONS(5648),
    [anon_sym_RBRACK] = ACTIONS(5648),
    [anon_sym_LPAREN] = ACTIONS(5648),
    [anon_sym_RPAREN] = ACTIONS(5648),
    [anon_sym_RBRACE] = ACTIONS(5648),
    [anon_sym_LT] = ACTIONS(5650),
    [anon_sym_GT] = ACTIONS(5650),
    [anon_sym_in] = ACTIONS(5650),
    [anon_sym_where] = ACTIONS(5648),
    [anon_sym_QMARK] = ACTIONS(5650),
    [anon_sym_BANG] = ACTIONS(5650),
    [anon_sym_PLUS_PLUS] = ACTIONS(5648),
    [anon_sym_DASH_DASH] = ACTIONS(5648),
    [anon_sym_PLUS] = ACTIONS(5650),
    [anon_sym_DASH] = ACTIONS(5650),
    [anon_sym_STAR] = ACTIONS(5648),
    [anon_sym_SLASH] = ACTIONS(5650),
    [anon_sym_PERCENT] = ACTIONS(5648),
    [anon_sym_CARET] = ACTIONS(5648),
    [anon_sym_PIPE] = ACTIONS(5650),
    [anon_sym_AMP] = ACTIONS(5650),
    [anon_sym_LT_LT] = ACTIONS(5648),
    [anon_sym_GT_GT] = ACTIONS(5650),
    [anon_sym_GT_GT_GT] = ACTIONS(5648),
    [anon_sym_EQ_EQ] = ACTIONS(5648),
    [anon_sym_BANG_EQ] = ACTIONS(5648),
    [anon_sym_GT_EQ] = ACTIONS(5648),
    [anon_sym_LT_EQ] = ACTIONS(5648),
    [anon_sym_DOT] = ACTIONS(5650),
    [anon_sym_EQ_GT] = ACTIONS(5648),
    [anon_sym_switch] = ACTIONS(5648),
    [anon_sym_DOT_DOT] = ACTIONS(5648),
    [anon_sym_and] = ACTIONS(5648),
    [anon_sym_or] = ACTIONS(5650),
    [anon_sym_AMP_AMP] = ACTIONS(5648),
    [anon_sym_PIPE_PIPE] = ACTIONS(5648),
    [anon_sym_QMARK_QMARK] = ACTIONS(5648),
    [anon_sym_from] = ACTIONS(5648),
    [anon_sym_into] = ACTIONS(5648),
    [anon_sym_join] = ACTIONS(5648),
    [anon_sym_on] = ACTIONS(5648),
    [anon_sym_equals] = ACTIONS(5648),
    [anon_sym_let] = ACTIONS(5648),
    [anon_sym_orderby] = ACTIONS(5648),
    [anon_sym_group] = ACTIONS(5648),
    [anon_sym_by] = ACTIONS(5648),
    [anon_sym_select] = ACTIONS(5648),
    [anon_sym_as] = ACTIONS(5648),
    [anon_sym_is] = ACTIONS(5648),
    [anon_sym_DASH_GT] = ACTIONS(5648),
    [anon_sym_with] = ACTIONS(5648),
    [aux_sym_preproc_if_token3] = ACTIONS(5648),
    [aux_sym_preproc_else_token1] = ACTIONS(5648),
    [aux_sym_preproc_elif_token1] = ACTIONS(5648),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3717] = {
    [sym_preproc_region] = STATE(3717),
    [sym_preproc_endregion] = STATE(3717),
    [sym_preproc_line] = STATE(3717),
    [sym_preproc_pragma] = STATE(3717),
    [sym_preproc_nullable] = STATE(3717),
    [sym_preproc_error] = STATE(3717),
    [sym_preproc_warning] = STATE(3717),
    [sym_preproc_define] = STATE(3717),
    [sym_preproc_undef] = STATE(3717),
    [anon_sym_SEMI] = ACTIONS(5652),
    [anon_sym_LBRACK] = ACTIONS(5652),
    [anon_sym_COLON] = ACTIONS(5652),
    [anon_sym_COMMA] = ACTIONS(5652),
    [anon_sym_RBRACK] = ACTIONS(5652),
    [anon_sym_LPAREN] = ACTIONS(5652),
    [anon_sym_RPAREN] = ACTIONS(5652),
    [anon_sym_RBRACE] = ACTIONS(5652),
    [anon_sym_LT] = ACTIONS(5654),
    [anon_sym_GT] = ACTIONS(5654),
    [anon_sym_in] = ACTIONS(5654),
    [anon_sym_where] = ACTIONS(5652),
    [anon_sym_QMARK] = ACTIONS(5654),
    [anon_sym_BANG] = ACTIONS(5654),
    [anon_sym_PLUS_PLUS] = ACTIONS(5652),
    [anon_sym_DASH_DASH] = ACTIONS(5652),
    [anon_sym_PLUS] = ACTIONS(5654),
    [anon_sym_DASH] = ACTIONS(5654),
    [anon_sym_STAR] = ACTIONS(5652),
    [anon_sym_SLASH] = ACTIONS(5654),
    [anon_sym_PERCENT] = ACTIONS(5652),
    [anon_sym_CARET] = ACTIONS(5652),
    [anon_sym_PIPE] = ACTIONS(5654),
    [anon_sym_AMP] = ACTIONS(5654),
    [anon_sym_LT_LT] = ACTIONS(5652),
    [anon_sym_GT_GT] = ACTIONS(5654),
    [anon_sym_GT_GT_GT] = ACTIONS(5652),
    [anon_sym_EQ_EQ] = ACTIONS(5652),
    [anon_sym_BANG_EQ] = ACTIONS(5652),
    [anon_sym_GT_EQ] = ACTIONS(5652),
    [anon_sym_LT_EQ] = ACTIONS(5652),
    [anon_sym_DOT] = ACTIONS(5654),
    [anon_sym_EQ_GT] = ACTIONS(5652),
    [anon_sym_switch] = ACTIONS(5652),
    [anon_sym_DOT_DOT] = ACTIONS(5652),
    [anon_sym_and] = ACTIONS(5652),
    [anon_sym_or] = ACTIONS(5654),
    [anon_sym_AMP_AMP] = ACTIONS(5652),
    [anon_sym_PIPE_PIPE] = ACTIONS(5652),
    [anon_sym_QMARK_QMARK] = ACTIONS(5652),
    [anon_sym_from] = ACTIONS(5652),
    [anon_sym_into] = ACTIONS(5652),
    [anon_sym_join] = ACTIONS(5652),
    [anon_sym_on] = ACTIONS(5652),
    [anon_sym_equals] = ACTIONS(5652),
    [anon_sym_let] = ACTIONS(5652),
    [anon_sym_orderby] = ACTIONS(5652),
    [anon_sym_group] = ACTIONS(5652),
    [anon_sym_by] = ACTIONS(5652),
    [anon_sym_select] = ACTIONS(5652),
    [anon_sym_as] = ACTIONS(5652),
    [anon_sym_is] = ACTIONS(5652),
    [anon_sym_DASH_GT] = ACTIONS(5652),
    [anon_sym_with] = ACTIONS(5652),
    [aux_sym_preproc_if_token3] = ACTIONS(5652),
    [aux_sym_preproc_else_token1] = ACTIONS(5652),
    [aux_sym_preproc_elif_token1] = ACTIONS(5652),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3718] = {
    [sym_preproc_region] = STATE(3718),
    [sym_preproc_endregion] = STATE(3718),
    [sym_preproc_line] = STATE(3718),
    [sym_preproc_pragma] = STATE(3718),
    [sym_preproc_nullable] = STATE(3718),
    [sym_preproc_error] = STATE(3718),
    [sym_preproc_warning] = STATE(3718),
    [sym_preproc_define] = STATE(3718),
    [sym_preproc_undef] = STATE(3718),
    [anon_sym_SEMI] = ACTIONS(4484),
    [anon_sym_LBRACK] = ACTIONS(4484),
    [anon_sym_COLON] = ACTIONS(4484),
    [anon_sym_COMMA] = ACTIONS(4484),
    [anon_sym_RBRACK] = ACTIONS(4484),
    [anon_sym_LPAREN] = ACTIONS(4484),
    [anon_sym_RPAREN] = ACTIONS(4484),
    [anon_sym_LBRACE] = ACTIONS(4484),
    [anon_sym_RBRACE] = ACTIONS(4484),
    [anon_sym_LT] = ACTIONS(4482),
    [anon_sym_GT] = ACTIONS(4482),
    [anon_sym_in] = ACTIONS(4484),
    [anon_sym_where] = ACTIONS(4484),
    [anon_sym_QMARK] = ACTIONS(4482),
    [anon_sym_BANG] = ACTIONS(4482),
    [anon_sym_PLUS_PLUS] = ACTIONS(4484),
    [anon_sym_DASH_DASH] = ACTIONS(4484),
    [anon_sym_PLUS] = ACTIONS(4482),
    [anon_sym_DASH] = ACTIONS(4482),
    [anon_sym_STAR] = ACTIONS(4484),
    [anon_sym_SLASH] = ACTIONS(4482),
    [anon_sym_PERCENT] = ACTIONS(4484),
    [anon_sym_CARET] = ACTIONS(4484),
    [anon_sym_PIPE] = ACTIONS(4482),
    [anon_sym_AMP] = ACTIONS(4482),
    [anon_sym_LT_LT] = ACTIONS(4484),
    [anon_sym_GT_GT] = ACTIONS(4482),
    [anon_sym_GT_GT_GT] = ACTIONS(4484),
    [anon_sym_EQ_EQ] = ACTIONS(4484),
    [anon_sym_BANG_EQ] = ACTIONS(4484),
    [anon_sym_GT_EQ] = ACTIONS(4484),
    [anon_sym_LT_EQ] = ACTIONS(4484),
    [anon_sym_DOT] = ACTIONS(4482),
    [anon_sym_EQ_GT] = ACTIONS(4484),
    [anon_sym_switch] = ACTIONS(4484),
    [anon_sym_DOT_DOT] = ACTIONS(4484),
    [anon_sym_and] = ACTIONS(4484),
    [anon_sym_or] = ACTIONS(4482),
    [anon_sym_AMP_AMP] = ACTIONS(4484),
    [anon_sym_PIPE_PIPE] = ACTIONS(4484),
    [anon_sym_QMARK_QMARK] = ACTIONS(4484),
    [anon_sym_from] = ACTIONS(4484),
    [anon_sym_join] = ACTIONS(4484),
    [anon_sym_on] = ACTIONS(4484),
    [anon_sym_equals] = ACTIONS(4484),
    [anon_sym_let] = ACTIONS(4484),
    [anon_sym_orderby] = ACTIONS(4484),
    [anon_sym_group] = ACTIONS(4484),
    [anon_sym_by] = ACTIONS(4484),
    [anon_sym_select] = ACTIONS(4484),
    [anon_sym_as] = ACTIONS(4484),
    [anon_sym_is] = ACTIONS(4484),
    [anon_sym_DASH_GT] = ACTIONS(4484),
    [anon_sym_with] = ACTIONS(4484),
    [aux_sym_preproc_if_token3] = ACTIONS(4484),
    [aux_sym_preproc_else_token1] = ACTIONS(4484),
    [aux_sym_preproc_elif_token1] = ACTIONS(4484),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3719] = {
    [sym_preproc_region] = STATE(3719),
    [sym_preproc_endregion] = STATE(3719),
    [sym_preproc_line] = STATE(3719),
    [sym_preproc_pragma] = STATE(3719),
    [sym_preproc_nullable] = STATE(3719),
    [sym_preproc_error] = STATE(3719),
    [sym_preproc_warning] = STATE(3719),
    [sym_preproc_define] = STATE(3719),
    [sym_preproc_undef] = STATE(3719),
    [anon_sym_SEMI] = ACTIONS(5656),
    [anon_sym_LBRACK] = ACTIONS(5656),
    [anon_sym_COLON] = ACTIONS(5656),
    [anon_sym_COMMA] = ACTIONS(5656),
    [anon_sym_RBRACK] = ACTIONS(5656),
    [anon_sym_LPAREN] = ACTIONS(5656),
    [anon_sym_RPAREN] = ACTIONS(5656),
    [anon_sym_RBRACE] = ACTIONS(5656),
    [anon_sym_LT] = ACTIONS(5658),
    [anon_sym_GT] = ACTIONS(5658),
    [anon_sym_in] = ACTIONS(5658),
    [anon_sym_where] = ACTIONS(5656),
    [anon_sym_QMARK] = ACTIONS(5658),
    [anon_sym_BANG] = ACTIONS(5658),
    [anon_sym_PLUS_PLUS] = ACTIONS(5656),
    [anon_sym_DASH_DASH] = ACTIONS(5656),
    [anon_sym_PLUS] = ACTIONS(5658),
    [anon_sym_DASH] = ACTIONS(5658),
    [anon_sym_STAR] = ACTIONS(5656),
    [anon_sym_SLASH] = ACTIONS(5658),
    [anon_sym_PERCENT] = ACTIONS(5656),
    [anon_sym_CARET] = ACTIONS(5656),
    [anon_sym_PIPE] = ACTIONS(5658),
    [anon_sym_AMP] = ACTIONS(5658),
    [anon_sym_LT_LT] = ACTIONS(5656),
    [anon_sym_GT_GT] = ACTIONS(5658),
    [anon_sym_GT_GT_GT] = ACTIONS(5656),
    [anon_sym_EQ_EQ] = ACTIONS(5656),
    [anon_sym_BANG_EQ] = ACTIONS(5656),
    [anon_sym_GT_EQ] = ACTIONS(5656),
    [anon_sym_LT_EQ] = ACTIONS(5656),
    [anon_sym_DOT] = ACTIONS(5658),
    [anon_sym_EQ_GT] = ACTIONS(5656),
    [anon_sym_switch] = ACTIONS(5656),
    [anon_sym_DOT_DOT] = ACTIONS(5656),
    [anon_sym_and] = ACTIONS(5656),
    [anon_sym_or] = ACTIONS(5658),
    [anon_sym_AMP_AMP] = ACTIONS(5656),
    [anon_sym_PIPE_PIPE] = ACTIONS(5656),
    [anon_sym_QMARK_QMARK] = ACTIONS(5656),
    [anon_sym_from] = ACTIONS(5656),
    [anon_sym_into] = ACTIONS(5656),
    [anon_sym_join] = ACTIONS(5656),
    [anon_sym_on] = ACTIONS(5656),
    [anon_sym_equals] = ACTIONS(5656),
    [anon_sym_let] = ACTIONS(5656),
    [anon_sym_orderby] = ACTIONS(5656),
    [anon_sym_group] = ACTIONS(5656),
    [anon_sym_by] = ACTIONS(5656),
    [anon_sym_select] = ACTIONS(5656),
    [anon_sym_as] = ACTIONS(5656),
    [anon_sym_is] = ACTIONS(5656),
    [anon_sym_DASH_GT] = ACTIONS(5656),
    [anon_sym_with] = ACTIONS(5656),
    [aux_sym_preproc_if_token3] = ACTIONS(5656),
    [aux_sym_preproc_else_token1] = ACTIONS(5656),
    [aux_sym_preproc_elif_token1] = ACTIONS(5656),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3720] = {
    [sym_preproc_region] = STATE(3720),
    [sym_preproc_endregion] = STATE(3720),
    [sym_preproc_line] = STATE(3720),
    [sym_preproc_pragma] = STATE(3720),
    [sym_preproc_nullable] = STATE(3720),
    [sym_preproc_error] = STATE(3720),
    [sym_preproc_warning] = STATE(3720),
    [sym_preproc_define] = STATE(3720),
    [sym_preproc_undef] = STATE(3720),
    [anon_sym_SEMI] = ACTIONS(5660),
    [anon_sym_LBRACK] = ACTIONS(5660),
    [anon_sym_COLON] = ACTIONS(5660),
    [anon_sym_COMMA] = ACTIONS(5660),
    [anon_sym_RBRACK] = ACTIONS(5660),
    [anon_sym_LPAREN] = ACTIONS(5660),
    [anon_sym_RPAREN] = ACTIONS(5660),
    [anon_sym_RBRACE] = ACTIONS(5660),
    [anon_sym_LT] = ACTIONS(5662),
    [anon_sym_GT] = ACTIONS(5662),
    [anon_sym_in] = ACTIONS(5662),
    [anon_sym_where] = ACTIONS(5660),
    [anon_sym_QMARK] = ACTIONS(5662),
    [anon_sym_BANG] = ACTIONS(5662),
    [anon_sym_PLUS_PLUS] = ACTIONS(5660),
    [anon_sym_DASH_DASH] = ACTIONS(5660),
    [anon_sym_PLUS] = ACTIONS(5662),
    [anon_sym_DASH] = ACTIONS(5662),
    [anon_sym_STAR] = ACTIONS(5660),
    [anon_sym_SLASH] = ACTIONS(5662),
    [anon_sym_PERCENT] = ACTIONS(5660),
    [anon_sym_CARET] = ACTIONS(5660),
    [anon_sym_PIPE] = ACTIONS(5662),
    [anon_sym_AMP] = ACTIONS(5662),
    [anon_sym_LT_LT] = ACTIONS(5660),
    [anon_sym_GT_GT] = ACTIONS(5662),
    [anon_sym_GT_GT_GT] = ACTIONS(5660),
    [anon_sym_EQ_EQ] = ACTIONS(5660),
    [anon_sym_BANG_EQ] = ACTIONS(5660),
    [anon_sym_GT_EQ] = ACTIONS(5660),
    [anon_sym_LT_EQ] = ACTIONS(5660),
    [anon_sym_DOT] = ACTIONS(5662),
    [anon_sym_EQ_GT] = ACTIONS(5660),
    [anon_sym_switch] = ACTIONS(5660),
    [anon_sym_DOT_DOT] = ACTIONS(5660),
    [anon_sym_and] = ACTIONS(5660),
    [anon_sym_or] = ACTIONS(5662),
    [anon_sym_AMP_AMP] = ACTIONS(5660),
    [anon_sym_PIPE_PIPE] = ACTIONS(5660),
    [anon_sym_QMARK_QMARK] = ACTIONS(5660),
    [anon_sym_from] = ACTIONS(5660),
    [anon_sym_into] = ACTIONS(5660),
    [anon_sym_join] = ACTIONS(5660),
    [anon_sym_on] = ACTIONS(5660),
    [anon_sym_equals] = ACTIONS(5660),
    [anon_sym_let] = ACTIONS(5660),
    [anon_sym_orderby] = ACTIONS(5660),
    [anon_sym_group] = ACTIONS(5660),
    [anon_sym_by] = ACTIONS(5660),
    [anon_sym_select] = ACTIONS(5660),
    [anon_sym_as] = ACTIONS(5660),
    [anon_sym_is] = ACTIONS(5660),
    [anon_sym_DASH_GT] = ACTIONS(5660),
    [anon_sym_with] = ACTIONS(5660),
    [aux_sym_preproc_if_token3] = ACTIONS(5660),
    [aux_sym_preproc_else_token1] = ACTIONS(5660),
    [aux_sym_preproc_elif_token1] = ACTIONS(5660),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3721] = {
    [sym_preproc_region] = STATE(3721),
    [sym_preproc_endregion] = STATE(3721),
    [sym_preproc_line] = STATE(3721),
    [sym_preproc_pragma] = STATE(3721),
    [sym_preproc_nullable] = STATE(3721),
    [sym_preproc_error] = STATE(3721),
    [sym_preproc_warning] = STATE(3721),
    [sym_preproc_define] = STATE(3721),
    [sym_preproc_undef] = STATE(3721),
    [anon_sym_SEMI] = ACTIONS(5664),
    [anon_sym_LBRACK] = ACTIONS(5664),
    [anon_sym_COLON] = ACTIONS(5664),
    [anon_sym_COMMA] = ACTIONS(5664),
    [anon_sym_RBRACK] = ACTIONS(5664),
    [anon_sym_LPAREN] = ACTIONS(5664),
    [anon_sym_RPAREN] = ACTIONS(5664),
    [anon_sym_RBRACE] = ACTIONS(5664),
    [anon_sym_LT] = ACTIONS(5666),
    [anon_sym_GT] = ACTIONS(5666),
    [anon_sym_in] = ACTIONS(5666),
    [anon_sym_where] = ACTIONS(5664),
    [anon_sym_QMARK] = ACTIONS(5666),
    [anon_sym_BANG] = ACTIONS(5666),
    [anon_sym_PLUS_PLUS] = ACTIONS(5664),
    [anon_sym_DASH_DASH] = ACTIONS(5664),
    [anon_sym_PLUS] = ACTIONS(5666),
    [anon_sym_DASH] = ACTIONS(5666),
    [anon_sym_STAR] = ACTIONS(5664),
    [anon_sym_SLASH] = ACTIONS(5666),
    [anon_sym_PERCENT] = ACTIONS(5664),
    [anon_sym_CARET] = ACTIONS(5664),
    [anon_sym_PIPE] = ACTIONS(5666),
    [anon_sym_AMP] = ACTIONS(5666),
    [anon_sym_LT_LT] = ACTIONS(5664),
    [anon_sym_GT_GT] = ACTIONS(5666),
    [anon_sym_GT_GT_GT] = ACTIONS(5664),
    [anon_sym_EQ_EQ] = ACTIONS(5664),
    [anon_sym_BANG_EQ] = ACTIONS(5664),
    [anon_sym_GT_EQ] = ACTIONS(5664),
    [anon_sym_LT_EQ] = ACTIONS(5664),
    [anon_sym_DOT] = ACTIONS(5666),
    [anon_sym_EQ_GT] = ACTIONS(5664),
    [anon_sym_switch] = ACTIONS(5664),
    [anon_sym_DOT_DOT] = ACTIONS(5664),
    [anon_sym_and] = ACTIONS(5664),
    [anon_sym_or] = ACTIONS(5666),
    [anon_sym_AMP_AMP] = ACTIONS(5664),
    [anon_sym_PIPE_PIPE] = ACTIONS(5664),
    [anon_sym_QMARK_QMARK] = ACTIONS(5664),
    [anon_sym_from] = ACTIONS(5664),
    [anon_sym_into] = ACTIONS(5664),
    [anon_sym_join] = ACTIONS(5664),
    [anon_sym_on] = ACTIONS(5664),
    [anon_sym_equals] = ACTIONS(5664),
    [anon_sym_let] = ACTIONS(5664),
    [anon_sym_orderby] = ACTIONS(5664),
    [anon_sym_group] = ACTIONS(5664),
    [anon_sym_by] = ACTIONS(5664),
    [anon_sym_select] = ACTIONS(5664),
    [anon_sym_as] = ACTIONS(5664),
    [anon_sym_is] = ACTIONS(5664),
    [anon_sym_DASH_GT] = ACTIONS(5664),
    [anon_sym_with] = ACTIONS(5664),
    [aux_sym_preproc_if_token3] = ACTIONS(5664),
    [aux_sym_preproc_else_token1] = ACTIONS(5664),
    [aux_sym_preproc_elif_token1] = ACTIONS(5664),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3722] = {
    [sym_preproc_region] = STATE(3722),
    [sym_preproc_endregion] = STATE(3722),
    [sym_preproc_line] = STATE(3722),
    [sym_preproc_pragma] = STATE(3722),
    [sym_preproc_nullable] = STATE(3722),
    [sym_preproc_error] = STATE(3722),
    [sym_preproc_warning] = STATE(3722),
    [sym_preproc_define] = STATE(3722),
    [sym_preproc_undef] = STATE(3722),
    [anon_sym_SEMI] = ACTIONS(2031),
    [anon_sym_LBRACK] = ACTIONS(2031),
    [anon_sym_COLON] = ACTIONS(2031),
    [anon_sym_COMMA] = ACTIONS(2031),
    [anon_sym_RBRACK] = ACTIONS(2031),
    [anon_sym_LPAREN] = ACTIONS(5668),
    [anon_sym_RPAREN] = ACTIONS(2031),
    [anon_sym_RBRACE] = ACTIONS(2031),
    [anon_sym_LT] = ACTIONS(2029),
    [anon_sym_GT] = ACTIONS(2029),
    [anon_sym_in] = ACTIONS(2029),
    [anon_sym_where] = ACTIONS(2031),
    [anon_sym_QMARK] = ACTIONS(2029),
    [anon_sym_BANG] = ACTIONS(2029),
    [anon_sym_PLUS_PLUS] = ACTIONS(2031),
    [anon_sym_DASH_DASH] = ACTIONS(2031),
    [anon_sym_PLUS] = ACTIONS(2029),
    [anon_sym_DASH] = ACTIONS(2029),
    [anon_sym_STAR] = ACTIONS(2031),
    [anon_sym_SLASH] = ACTIONS(2029),
    [anon_sym_PERCENT] = ACTIONS(2031),
    [anon_sym_CARET] = ACTIONS(2031),
    [anon_sym_PIPE] = ACTIONS(2029),
    [anon_sym_AMP] = ACTIONS(2029),
    [anon_sym_LT_LT] = ACTIONS(2031),
    [anon_sym_GT_GT] = ACTIONS(2029),
    [anon_sym_GT_GT_GT] = ACTIONS(2031),
    [anon_sym_EQ_EQ] = ACTIONS(2031),
    [anon_sym_BANG_EQ] = ACTIONS(2031),
    [anon_sym_GT_EQ] = ACTIONS(2031),
    [anon_sym_LT_EQ] = ACTIONS(2031),
    [anon_sym_DOT] = ACTIONS(2029),
    [anon_sym_EQ_GT] = ACTIONS(2031),
    [anon_sym_switch] = ACTIONS(2031),
    [anon_sym_DOT_DOT] = ACTIONS(2031),
    [anon_sym_and] = ACTIONS(2031),
    [anon_sym_or] = ACTIONS(2029),
    [anon_sym_AMP_AMP] = ACTIONS(2031),
    [anon_sym_PIPE_PIPE] = ACTIONS(2031),
    [anon_sym_QMARK_QMARK] = ACTIONS(2031),
    [anon_sym_from] = ACTIONS(2031),
    [anon_sym_into] = ACTIONS(2031),
    [anon_sym_join] = ACTIONS(2031),
    [anon_sym_on] = ACTIONS(2031),
    [anon_sym_equals] = ACTIONS(2031),
    [anon_sym_let] = ACTIONS(2031),
    [anon_sym_orderby] = ACTIONS(2031),
    [anon_sym_group] = ACTIONS(2031),
    [anon_sym_by] = ACTIONS(2031),
    [anon_sym_select] = ACTIONS(2031),
    [anon_sym_as] = ACTIONS(2031),
    [anon_sym_is] = ACTIONS(2031),
    [anon_sym_DASH_GT] = ACTIONS(2031),
    [anon_sym_with] = ACTIONS(2031),
    [aux_sym_preproc_if_token3] = ACTIONS(2031),
    [aux_sym_preproc_else_token1] = ACTIONS(2031),
    [aux_sym_preproc_elif_token1] = ACTIONS(2031),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3723] = {
    [sym_preproc_region] = STATE(3723),
    [sym_preproc_endregion] = STATE(3723),
    [sym_preproc_line] = STATE(3723),
    [sym_preproc_pragma] = STATE(3723),
    [sym_preproc_nullable] = STATE(3723),
    [sym_preproc_error] = STATE(3723),
    [sym_preproc_warning] = STATE(3723),
    [sym_preproc_define] = STATE(3723),
    [sym_preproc_undef] = STATE(3723),
    [anon_sym_SEMI] = ACTIONS(5670),
    [anon_sym_LBRACK] = ACTIONS(5670),
    [anon_sym_COLON] = ACTIONS(5670),
    [anon_sym_COMMA] = ACTIONS(5670),
    [anon_sym_RBRACK] = ACTIONS(5670),
    [anon_sym_LPAREN] = ACTIONS(5670),
    [anon_sym_RPAREN] = ACTIONS(5670),
    [anon_sym_RBRACE] = ACTIONS(5670),
    [anon_sym_LT] = ACTIONS(5672),
    [anon_sym_GT] = ACTIONS(5672),
    [anon_sym_in] = ACTIONS(5672),
    [anon_sym_where] = ACTIONS(5670),
    [anon_sym_QMARK] = ACTIONS(5672),
    [anon_sym_BANG] = ACTIONS(5672),
    [anon_sym_PLUS_PLUS] = ACTIONS(5670),
    [anon_sym_DASH_DASH] = ACTIONS(5670),
    [anon_sym_PLUS] = ACTIONS(5672),
    [anon_sym_DASH] = ACTIONS(5672),
    [anon_sym_STAR] = ACTIONS(5670),
    [anon_sym_SLASH] = ACTIONS(5672),
    [anon_sym_PERCENT] = ACTIONS(5670),
    [anon_sym_CARET] = ACTIONS(5670),
    [anon_sym_PIPE] = ACTIONS(5672),
    [anon_sym_AMP] = ACTIONS(5672),
    [anon_sym_LT_LT] = ACTIONS(5670),
    [anon_sym_GT_GT] = ACTIONS(5672),
    [anon_sym_GT_GT_GT] = ACTIONS(5670),
    [anon_sym_EQ_EQ] = ACTIONS(5670),
    [anon_sym_BANG_EQ] = ACTIONS(5670),
    [anon_sym_GT_EQ] = ACTIONS(5670),
    [anon_sym_LT_EQ] = ACTIONS(5670),
    [anon_sym_DOT] = ACTIONS(5672),
    [anon_sym_EQ_GT] = ACTIONS(5670),
    [anon_sym_switch] = ACTIONS(5670),
    [anon_sym_DOT_DOT] = ACTIONS(5670),
    [anon_sym_and] = ACTIONS(5670),
    [anon_sym_or] = ACTIONS(5672),
    [anon_sym_AMP_AMP] = ACTIONS(5670),
    [anon_sym_PIPE_PIPE] = ACTIONS(5670),
    [anon_sym_QMARK_QMARK] = ACTIONS(5670),
    [anon_sym_from] = ACTIONS(5670),
    [anon_sym_into] = ACTIONS(5670),
    [anon_sym_join] = ACTIONS(5670),
    [anon_sym_on] = ACTIONS(5670),
    [anon_sym_equals] = ACTIONS(5670),
    [anon_sym_let] = ACTIONS(5670),
    [anon_sym_orderby] = ACTIONS(5670),
    [anon_sym_group] = ACTIONS(5670),
    [anon_sym_by] = ACTIONS(5670),
    [anon_sym_select] = ACTIONS(5670),
    [anon_sym_as] = ACTIONS(5670),
    [anon_sym_is] = ACTIONS(5670),
    [anon_sym_DASH_GT] = ACTIONS(5670),
    [anon_sym_with] = ACTIONS(5670),
    [aux_sym_preproc_if_token3] = ACTIONS(5670),
    [aux_sym_preproc_else_token1] = ACTIONS(5670),
    [aux_sym_preproc_elif_token1] = ACTIONS(5670),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3724] = {
    [sym_preproc_region] = STATE(3724),
    [sym_preproc_endregion] = STATE(3724),
    [sym_preproc_line] = STATE(3724),
    [sym_preproc_pragma] = STATE(3724),
    [sym_preproc_nullable] = STATE(3724),
    [sym_preproc_error] = STATE(3724),
    [sym_preproc_warning] = STATE(3724),
    [sym_preproc_define] = STATE(3724),
    [sym_preproc_undef] = STATE(3724),
    [anon_sym_SEMI] = ACTIONS(2997),
    [anon_sym_LBRACK] = ACTIONS(2997),
    [anon_sym_COLON] = ACTIONS(2997),
    [anon_sym_COMMA] = ACTIONS(2997),
    [anon_sym_RBRACK] = ACTIONS(2997),
    [anon_sym_LPAREN] = ACTIONS(2997),
    [anon_sym_RPAREN] = ACTIONS(2997),
    [anon_sym_RBRACE] = ACTIONS(2997),
    [anon_sym_LT] = ACTIONS(2995),
    [anon_sym_GT] = ACTIONS(2995),
    [anon_sym_in] = ACTIONS(2995),
    [anon_sym_where] = ACTIONS(2997),
    [anon_sym_QMARK] = ACTIONS(2995),
    [anon_sym_BANG] = ACTIONS(2995),
    [anon_sym_PLUS_PLUS] = ACTIONS(2997),
    [anon_sym_DASH_DASH] = ACTIONS(2997),
    [anon_sym_PLUS] = ACTIONS(2995),
    [anon_sym_DASH] = ACTIONS(2995),
    [anon_sym_STAR] = ACTIONS(2997),
    [anon_sym_SLASH] = ACTIONS(2995),
    [anon_sym_PERCENT] = ACTIONS(2997),
    [anon_sym_CARET] = ACTIONS(2997),
    [anon_sym_PIPE] = ACTIONS(2995),
    [anon_sym_AMP] = ACTIONS(2995),
    [anon_sym_LT_LT] = ACTIONS(2997),
    [anon_sym_GT_GT] = ACTIONS(2995),
    [anon_sym_GT_GT_GT] = ACTIONS(2997),
    [anon_sym_EQ_EQ] = ACTIONS(2997),
    [anon_sym_BANG_EQ] = ACTIONS(2997),
    [anon_sym_GT_EQ] = ACTIONS(2997),
    [anon_sym_LT_EQ] = ACTIONS(2997),
    [anon_sym_DOT] = ACTIONS(2995),
    [anon_sym_EQ_GT] = ACTIONS(2997),
    [anon_sym_switch] = ACTIONS(2997),
    [anon_sym_DOT_DOT] = ACTIONS(2997),
    [anon_sym_and] = ACTIONS(2997),
    [anon_sym_or] = ACTIONS(2995),
    [anon_sym_AMP_AMP] = ACTIONS(2997),
    [anon_sym_PIPE_PIPE] = ACTIONS(2997),
    [anon_sym_QMARK_QMARK] = ACTIONS(2997),
    [anon_sym_from] = ACTIONS(2997),
    [anon_sym_into] = ACTIONS(2997),
    [anon_sym_join] = ACTIONS(2997),
    [anon_sym_on] = ACTIONS(2997),
    [anon_sym_equals] = ACTIONS(2997),
    [anon_sym_let] = ACTIONS(2997),
    [anon_sym_orderby] = ACTIONS(2997),
    [anon_sym_group] = ACTIONS(2997),
    [anon_sym_by] = ACTIONS(2997),
    [anon_sym_select] = ACTIONS(2997),
    [anon_sym_as] = ACTIONS(2997),
    [anon_sym_is] = ACTIONS(2997),
    [anon_sym_DASH_GT] = ACTIONS(2997),
    [anon_sym_with] = ACTIONS(2997),
    [aux_sym_preproc_if_token3] = ACTIONS(2997),
    [aux_sym_preproc_else_token1] = ACTIONS(2997),
    [aux_sym_preproc_elif_token1] = ACTIONS(2997),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3725] = {
    [sym_preproc_region] = STATE(3725),
    [sym_preproc_endregion] = STATE(3725),
    [sym_preproc_line] = STATE(3725),
    [sym_preproc_pragma] = STATE(3725),
    [sym_preproc_nullable] = STATE(3725),
    [sym_preproc_error] = STATE(3725),
    [sym_preproc_warning] = STATE(3725),
    [sym_preproc_define] = STATE(3725),
    [sym_preproc_undef] = STATE(3725),
    [anon_sym_SEMI] = ACTIONS(4494),
    [anon_sym_LBRACK] = ACTIONS(4593),
    [anon_sym_COLON] = ACTIONS(4494),
    [anon_sym_COMMA] = ACTIONS(4494),
    [anon_sym_RBRACK] = ACTIONS(4494),
    [anon_sym_LPAREN] = ACTIONS(4494),
    [anon_sym_RPAREN] = ACTIONS(4494),
    [anon_sym_LBRACE] = ACTIONS(4494),
    [anon_sym_RBRACE] = ACTIONS(4494),
    [anon_sym_LT] = ACTIONS(4492),
    [anon_sym_GT] = ACTIONS(4492),
    [anon_sym_in] = ACTIONS(4494),
    [anon_sym_where] = ACTIONS(4494),
    [anon_sym_QMARK] = ACTIONS(5405),
    [anon_sym_BANG] = ACTIONS(4492),
    [anon_sym_PLUS_PLUS] = ACTIONS(4494),
    [anon_sym_DASH_DASH] = ACTIONS(4494),
    [anon_sym_PLUS] = ACTIONS(4492),
    [anon_sym_DASH] = ACTIONS(4492),
    [anon_sym_STAR] = ACTIONS(4494),
    [anon_sym_SLASH] = ACTIONS(4492),
    [anon_sym_PERCENT] = ACTIONS(4494),
    [anon_sym_CARET] = ACTIONS(4494),
    [anon_sym_PIPE] = ACTIONS(4492),
    [anon_sym_AMP] = ACTIONS(4492),
    [anon_sym_LT_LT] = ACTIONS(4494),
    [anon_sym_GT_GT] = ACTIONS(4492),
    [anon_sym_GT_GT_GT] = ACTIONS(4494),
    [anon_sym_EQ_EQ] = ACTIONS(4494),
    [anon_sym_BANG_EQ] = ACTIONS(4494),
    [anon_sym_GT_EQ] = ACTIONS(4494),
    [anon_sym_LT_EQ] = ACTIONS(4494),
    [anon_sym_DOT] = ACTIONS(4492),
    [anon_sym_EQ_GT] = ACTIONS(4494),
    [anon_sym_switch] = ACTIONS(4494),
    [anon_sym_DOT_DOT] = ACTIONS(4494),
    [anon_sym_and] = ACTIONS(4494),
    [anon_sym_or] = ACTIONS(4492),
    [anon_sym_AMP_AMP] = ACTIONS(4494),
    [anon_sym_PIPE_PIPE] = ACTIONS(4494),
    [anon_sym_QMARK_QMARK] = ACTIONS(4494),
    [anon_sym_from] = ACTIONS(4494),
    [anon_sym_join] = ACTIONS(4494),
    [anon_sym_on] = ACTIONS(4494),
    [anon_sym_equals] = ACTIONS(4494),
    [anon_sym_let] = ACTIONS(4494),
    [anon_sym_orderby] = ACTIONS(4494),
    [anon_sym_group] = ACTIONS(4494),
    [anon_sym_by] = ACTIONS(4494),
    [anon_sym_select] = ACTIONS(4494),
    [anon_sym_as] = ACTIONS(4494),
    [anon_sym_is] = ACTIONS(4494),
    [anon_sym_DASH_GT] = ACTIONS(4494),
    [anon_sym_with] = ACTIONS(4494),
    [aux_sym_preproc_if_token3] = ACTIONS(4494),
    [aux_sym_preproc_else_token1] = ACTIONS(4494),
    [aux_sym_preproc_elif_token1] = ACTIONS(4494),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3726] = {
    [sym_preproc_region] = STATE(3726),
    [sym_preproc_endregion] = STATE(3726),
    [sym_preproc_line] = STATE(3726),
    [sym_preproc_pragma] = STATE(3726),
    [sym_preproc_nullable] = STATE(3726),
    [sym_preproc_error] = STATE(3726),
    [sym_preproc_warning] = STATE(3726),
    [sym_preproc_define] = STATE(3726),
    [sym_preproc_undef] = STATE(3726),
    [anon_sym_SEMI] = ACTIONS(4585),
    [anon_sym_LBRACK] = ACTIONS(4585),
    [anon_sym_COLON] = ACTIONS(4585),
    [anon_sym_COMMA] = ACTIONS(4585),
    [anon_sym_RBRACK] = ACTIONS(4585),
    [anon_sym_LPAREN] = ACTIONS(4585),
    [anon_sym_RPAREN] = ACTIONS(4585),
    [anon_sym_LBRACE] = ACTIONS(4585),
    [anon_sym_RBRACE] = ACTIONS(4585),
    [anon_sym_LT] = ACTIONS(4583),
    [anon_sym_GT] = ACTIONS(4583),
    [anon_sym_in] = ACTIONS(4585),
    [anon_sym_where] = ACTIONS(4585),
    [anon_sym_QMARK] = ACTIONS(4583),
    [anon_sym_BANG] = ACTIONS(4583),
    [anon_sym_PLUS_PLUS] = ACTIONS(4585),
    [anon_sym_DASH_DASH] = ACTIONS(4585),
    [anon_sym_PLUS] = ACTIONS(4583),
    [anon_sym_DASH] = ACTIONS(4583),
    [anon_sym_STAR] = ACTIONS(4585),
    [anon_sym_SLASH] = ACTIONS(4583),
    [anon_sym_PERCENT] = ACTIONS(4585),
    [anon_sym_CARET] = ACTIONS(4585),
    [anon_sym_PIPE] = ACTIONS(4583),
    [anon_sym_AMP] = ACTIONS(4583),
    [anon_sym_LT_LT] = ACTIONS(4585),
    [anon_sym_GT_GT] = ACTIONS(4583),
    [anon_sym_GT_GT_GT] = ACTIONS(4585),
    [anon_sym_EQ_EQ] = ACTIONS(4585),
    [anon_sym_BANG_EQ] = ACTIONS(4585),
    [anon_sym_GT_EQ] = ACTIONS(4585),
    [anon_sym_LT_EQ] = ACTIONS(4585),
    [anon_sym_DOT] = ACTIONS(4583),
    [anon_sym_EQ_GT] = ACTIONS(4585),
    [anon_sym_switch] = ACTIONS(4585),
    [anon_sym_DOT_DOT] = ACTIONS(4585),
    [anon_sym_and] = ACTIONS(4585),
    [anon_sym_or] = ACTIONS(4583),
    [anon_sym_AMP_AMP] = ACTIONS(4585),
    [anon_sym_PIPE_PIPE] = ACTIONS(4585),
    [anon_sym_QMARK_QMARK] = ACTIONS(4585),
    [anon_sym_from] = ACTIONS(4585),
    [anon_sym_join] = ACTIONS(4585),
    [anon_sym_on] = ACTIONS(4585),
    [anon_sym_equals] = ACTIONS(4585),
    [anon_sym_let] = ACTIONS(4585),
    [anon_sym_orderby] = ACTIONS(4585),
    [anon_sym_group] = ACTIONS(4585),
    [anon_sym_by] = ACTIONS(4585),
    [anon_sym_select] = ACTIONS(4585),
    [anon_sym_as] = ACTIONS(4585),
    [anon_sym_is] = ACTIONS(4585),
    [anon_sym_DASH_GT] = ACTIONS(4585),
    [anon_sym_with] = ACTIONS(4585),
    [aux_sym_preproc_if_token3] = ACTIONS(4585),
    [aux_sym_preproc_else_token1] = ACTIONS(4585),
    [aux_sym_preproc_elif_token1] = ACTIONS(4585),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3727] = {
    [sym_preproc_region] = STATE(3727),
    [sym_preproc_endregion] = STATE(3727),
    [sym_preproc_line] = STATE(3727),
    [sym_preproc_pragma] = STATE(3727),
    [sym_preproc_nullable] = STATE(3727),
    [sym_preproc_error] = STATE(3727),
    [sym_preproc_warning] = STATE(3727),
    [sym_preproc_define] = STATE(3727),
    [sym_preproc_undef] = STATE(3727),
    [anon_sym_SEMI] = ACTIONS(5674),
    [anon_sym_LBRACK] = ACTIONS(5674),
    [anon_sym_COLON] = ACTIONS(5674),
    [anon_sym_COMMA] = ACTIONS(5674),
    [anon_sym_RBRACK] = ACTIONS(5674),
    [anon_sym_LPAREN] = ACTIONS(5674),
    [anon_sym_RPAREN] = ACTIONS(5674),
    [anon_sym_RBRACE] = ACTIONS(5674),
    [anon_sym_LT] = ACTIONS(5676),
    [anon_sym_GT] = ACTIONS(5676),
    [anon_sym_in] = ACTIONS(5676),
    [anon_sym_where] = ACTIONS(5674),
    [anon_sym_QMARK] = ACTIONS(5676),
    [anon_sym_BANG] = ACTIONS(5676),
    [anon_sym_PLUS_PLUS] = ACTIONS(5674),
    [anon_sym_DASH_DASH] = ACTIONS(5674),
    [anon_sym_PLUS] = ACTIONS(5676),
    [anon_sym_DASH] = ACTIONS(5676),
    [anon_sym_STAR] = ACTIONS(5674),
    [anon_sym_SLASH] = ACTIONS(5676),
    [anon_sym_PERCENT] = ACTIONS(5674),
    [anon_sym_CARET] = ACTIONS(5674),
    [anon_sym_PIPE] = ACTIONS(5676),
    [anon_sym_AMP] = ACTIONS(5676),
    [anon_sym_LT_LT] = ACTIONS(5674),
    [anon_sym_GT_GT] = ACTIONS(5676),
    [anon_sym_GT_GT_GT] = ACTIONS(5674),
    [anon_sym_EQ_EQ] = ACTIONS(5674),
    [anon_sym_BANG_EQ] = ACTIONS(5674),
    [anon_sym_GT_EQ] = ACTIONS(5674),
    [anon_sym_LT_EQ] = ACTIONS(5674),
    [anon_sym_DOT] = ACTIONS(5676),
    [anon_sym_EQ_GT] = ACTIONS(5674),
    [anon_sym_switch] = ACTIONS(5674),
    [anon_sym_DOT_DOT] = ACTIONS(5674),
    [anon_sym_and] = ACTIONS(5674),
    [anon_sym_or] = ACTIONS(5676),
    [anon_sym_AMP_AMP] = ACTIONS(5674),
    [anon_sym_PIPE_PIPE] = ACTIONS(5674),
    [anon_sym_QMARK_QMARK] = ACTIONS(5674),
    [anon_sym_from] = ACTIONS(5674),
    [anon_sym_into] = ACTIONS(5674),
    [anon_sym_join] = ACTIONS(5674),
    [anon_sym_on] = ACTIONS(5674),
    [anon_sym_equals] = ACTIONS(5674),
    [anon_sym_let] = ACTIONS(5674),
    [anon_sym_orderby] = ACTIONS(5674),
    [anon_sym_group] = ACTIONS(5674),
    [anon_sym_by] = ACTIONS(5674),
    [anon_sym_select] = ACTIONS(5674),
    [anon_sym_as] = ACTIONS(5674),
    [anon_sym_is] = ACTIONS(5674),
    [anon_sym_DASH_GT] = ACTIONS(5674),
    [anon_sym_with] = ACTIONS(5674),
    [aux_sym_preproc_if_token3] = ACTIONS(5674),
    [aux_sym_preproc_else_token1] = ACTIONS(5674),
    [aux_sym_preproc_elif_token1] = ACTIONS(5674),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3728] = {
    [sym_preproc_region] = STATE(3728),
    [sym_preproc_endregion] = STATE(3728),
    [sym_preproc_line] = STATE(3728),
    [sym_preproc_pragma] = STATE(3728),
    [sym_preproc_nullable] = STATE(3728),
    [sym_preproc_error] = STATE(3728),
    [sym_preproc_warning] = STATE(3728),
    [sym_preproc_define] = STATE(3728),
    [sym_preproc_undef] = STATE(3728),
    [anon_sym_SEMI] = ACTIONS(5678),
    [anon_sym_LBRACK] = ACTIONS(5678),
    [anon_sym_COLON] = ACTIONS(5678),
    [anon_sym_COMMA] = ACTIONS(5678),
    [anon_sym_RBRACK] = ACTIONS(5678),
    [anon_sym_LPAREN] = ACTIONS(5678),
    [anon_sym_RPAREN] = ACTIONS(5678),
    [anon_sym_RBRACE] = ACTIONS(5678),
    [anon_sym_LT] = ACTIONS(5680),
    [anon_sym_GT] = ACTIONS(5680),
    [anon_sym_in] = ACTIONS(5680),
    [anon_sym_where] = ACTIONS(5678),
    [anon_sym_QMARK] = ACTIONS(5680),
    [anon_sym_BANG] = ACTIONS(5680),
    [anon_sym_PLUS_PLUS] = ACTIONS(5678),
    [anon_sym_DASH_DASH] = ACTIONS(5678),
    [anon_sym_PLUS] = ACTIONS(5680),
    [anon_sym_DASH] = ACTIONS(5680),
    [anon_sym_STAR] = ACTIONS(5678),
    [anon_sym_SLASH] = ACTIONS(5680),
    [anon_sym_PERCENT] = ACTIONS(5678),
    [anon_sym_CARET] = ACTIONS(5678),
    [anon_sym_PIPE] = ACTIONS(5680),
    [anon_sym_AMP] = ACTIONS(5680),
    [anon_sym_LT_LT] = ACTIONS(5678),
    [anon_sym_GT_GT] = ACTIONS(5680),
    [anon_sym_GT_GT_GT] = ACTIONS(5678),
    [anon_sym_EQ_EQ] = ACTIONS(5678),
    [anon_sym_BANG_EQ] = ACTIONS(5678),
    [anon_sym_GT_EQ] = ACTIONS(5678),
    [anon_sym_LT_EQ] = ACTIONS(5678),
    [anon_sym_DOT] = ACTIONS(5680),
    [anon_sym_EQ_GT] = ACTIONS(5678),
    [anon_sym_switch] = ACTIONS(5678),
    [anon_sym_DOT_DOT] = ACTIONS(5678),
    [anon_sym_and] = ACTIONS(5678),
    [anon_sym_or] = ACTIONS(5680),
    [anon_sym_AMP_AMP] = ACTIONS(5678),
    [anon_sym_PIPE_PIPE] = ACTIONS(5678),
    [anon_sym_QMARK_QMARK] = ACTIONS(5678),
    [anon_sym_from] = ACTIONS(5678),
    [anon_sym_into] = ACTIONS(5678),
    [anon_sym_join] = ACTIONS(5678),
    [anon_sym_on] = ACTIONS(5678),
    [anon_sym_equals] = ACTIONS(5678),
    [anon_sym_let] = ACTIONS(5678),
    [anon_sym_orderby] = ACTIONS(5678),
    [anon_sym_group] = ACTIONS(5678),
    [anon_sym_by] = ACTIONS(5678),
    [anon_sym_select] = ACTIONS(5678),
    [anon_sym_as] = ACTIONS(5678),
    [anon_sym_is] = ACTIONS(5678),
    [anon_sym_DASH_GT] = ACTIONS(5678),
    [anon_sym_with] = ACTIONS(5678),
    [aux_sym_preproc_if_token3] = ACTIONS(5678),
    [aux_sym_preproc_else_token1] = ACTIONS(5678),
    [aux_sym_preproc_elif_token1] = ACTIONS(5678),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3729] = {
    [sym_preproc_region] = STATE(3729),
    [sym_preproc_endregion] = STATE(3729),
    [sym_preproc_line] = STATE(3729),
    [sym_preproc_pragma] = STATE(3729),
    [sym_preproc_nullable] = STATE(3729),
    [sym_preproc_error] = STATE(3729),
    [sym_preproc_warning] = STATE(3729),
    [sym_preproc_define] = STATE(3729),
    [sym_preproc_undef] = STATE(3729),
    [anon_sym_SEMI] = ACTIONS(5682),
    [anon_sym_LBRACK] = ACTIONS(5682),
    [anon_sym_COLON] = ACTIONS(5682),
    [anon_sym_COMMA] = ACTIONS(5682),
    [anon_sym_RBRACK] = ACTIONS(5682),
    [anon_sym_LPAREN] = ACTIONS(5682),
    [anon_sym_RPAREN] = ACTIONS(5682),
    [anon_sym_RBRACE] = ACTIONS(5682),
    [anon_sym_LT] = ACTIONS(5684),
    [anon_sym_GT] = ACTIONS(5684),
    [anon_sym_in] = ACTIONS(5684),
    [anon_sym_where] = ACTIONS(5682),
    [anon_sym_QMARK] = ACTIONS(5684),
    [anon_sym_BANG] = ACTIONS(5684),
    [anon_sym_PLUS_PLUS] = ACTIONS(5682),
    [anon_sym_DASH_DASH] = ACTIONS(5682),
    [anon_sym_PLUS] = ACTIONS(5684),
    [anon_sym_DASH] = ACTIONS(5684),
    [anon_sym_STAR] = ACTIONS(5682),
    [anon_sym_SLASH] = ACTIONS(5684),
    [anon_sym_PERCENT] = ACTIONS(5682),
    [anon_sym_CARET] = ACTIONS(5682),
    [anon_sym_PIPE] = ACTIONS(5684),
    [anon_sym_AMP] = ACTIONS(5684),
    [anon_sym_LT_LT] = ACTIONS(5682),
    [anon_sym_GT_GT] = ACTIONS(5684),
    [anon_sym_GT_GT_GT] = ACTIONS(5682),
    [anon_sym_EQ_EQ] = ACTIONS(5682),
    [anon_sym_BANG_EQ] = ACTIONS(5682),
    [anon_sym_GT_EQ] = ACTIONS(5682),
    [anon_sym_LT_EQ] = ACTIONS(5682),
    [anon_sym_DOT] = ACTIONS(5684),
    [anon_sym_EQ_GT] = ACTIONS(5682),
    [anon_sym_switch] = ACTIONS(5682),
    [anon_sym_DOT_DOT] = ACTIONS(5682),
    [anon_sym_and] = ACTIONS(5682),
    [anon_sym_or] = ACTIONS(5684),
    [anon_sym_AMP_AMP] = ACTIONS(5682),
    [anon_sym_PIPE_PIPE] = ACTIONS(5682),
    [anon_sym_QMARK_QMARK] = ACTIONS(5682),
    [anon_sym_from] = ACTIONS(5682),
    [anon_sym_into] = ACTIONS(5682),
    [anon_sym_join] = ACTIONS(5682),
    [anon_sym_on] = ACTIONS(5682),
    [anon_sym_equals] = ACTIONS(5682),
    [anon_sym_let] = ACTIONS(5682),
    [anon_sym_orderby] = ACTIONS(5682),
    [anon_sym_group] = ACTIONS(5682),
    [anon_sym_by] = ACTIONS(5682),
    [anon_sym_select] = ACTIONS(5682),
    [anon_sym_as] = ACTIONS(5682),
    [anon_sym_is] = ACTIONS(5682),
    [anon_sym_DASH_GT] = ACTIONS(5682),
    [anon_sym_with] = ACTIONS(5682),
    [aux_sym_preproc_if_token3] = ACTIONS(5682),
    [aux_sym_preproc_else_token1] = ACTIONS(5682),
    [aux_sym_preproc_elif_token1] = ACTIONS(5682),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3730] = {
    [sym_preproc_region] = STATE(3730),
    [sym_preproc_endregion] = STATE(3730),
    [sym_preproc_line] = STATE(3730),
    [sym_preproc_pragma] = STATE(3730),
    [sym_preproc_nullable] = STATE(3730),
    [sym_preproc_error] = STATE(3730),
    [sym_preproc_warning] = STATE(3730),
    [sym_preproc_define] = STATE(3730),
    [sym_preproc_undef] = STATE(3730),
    [anon_sym_SEMI] = ACTIONS(5686),
    [anon_sym_LBRACK] = ACTIONS(5686),
    [anon_sym_COLON] = ACTIONS(5686),
    [anon_sym_COMMA] = ACTIONS(5686),
    [anon_sym_RBRACK] = ACTIONS(5686),
    [anon_sym_LPAREN] = ACTIONS(5686),
    [anon_sym_RPAREN] = ACTIONS(5686),
    [anon_sym_RBRACE] = ACTIONS(5686),
    [anon_sym_LT] = ACTIONS(5688),
    [anon_sym_GT] = ACTIONS(5688),
    [anon_sym_in] = ACTIONS(5688),
    [anon_sym_where] = ACTIONS(5686),
    [anon_sym_QMARK] = ACTIONS(5688),
    [anon_sym_BANG] = ACTIONS(5688),
    [anon_sym_PLUS_PLUS] = ACTIONS(5686),
    [anon_sym_DASH_DASH] = ACTIONS(5686),
    [anon_sym_PLUS] = ACTIONS(5688),
    [anon_sym_DASH] = ACTIONS(5688),
    [anon_sym_STAR] = ACTIONS(5686),
    [anon_sym_SLASH] = ACTIONS(5688),
    [anon_sym_PERCENT] = ACTIONS(5686),
    [anon_sym_CARET] = ACTIONS(5686),
    [anon_sym_PIPE] = ACTIONS(5688),
    [anon_sym_AMP] = ACTIONS(5688),
    [anon_sym_LT_LT] = ACTIONS(5686),
    [anon_sym_GT_GT] = ACTIONS(5688),
    [anon_sym_GT_GT_GT] = ACTIONS(5686),
    [anon_sym_EQ_EQ] = ACTIONS(5686),
    [anon_sym_BANG_EQ] = ACTIONS(5686),
    [anon_sym_GT_EQ] = ACTIONS(5686),
    [anon_sym_LT_EQ] = ACTIONS(5686),
    [anon_sym_DOT] = ACTIONS(5688),
    [anon_sym_EQ_GT] = ACTIONS(5686),
    [anon_sym_switch] = ACTIONS(5686),
    [anon_sym_DOT_DOT] = ACTIONS(5686),
    [anon_sym_and] = ACTIONS(5686),
    [anon_sym_or] = ACTIONS(5688),
    [anon_sym_AMP_AMP] = ACTIONS(5686),
    [anon_sym_PIPE_PIPE] = ACTIONS(5686),
    [anon_sym_QMARK_QMARK] = ACTIONS(5686),
    [anon_sym_from] = ACTIONS(5686),
    [anon_sym_into] = ACTIONS(5686),
    [anon_sym_join] = ACTIONS(5686),
    [anon_sym_on] = ACTIONS(5686),
    [anon_sym_equals] = ACTIONS(5686),
    [anon_sym_let] = ACTIONS(5686),
    [anon_sym_orderby] = ACTIONS(5686),
    [anon_sym_group] = ACTIONS(5686),
    [anon_sym_by] = ACTIONS(5686),
    [anon_sym_select] = ACTIONS(5686),
    [anon_sym_as] = ACTIONS(5686),
    [anon_sym_is] = ACTIONS(5686),
    [anon_sym_DASH_GT] = ACTIONS(5686),
    [anon_sym_with] = ACTIONS(5686),
    [aux_sym_preproc_if_token3] = ACTIONS(5686),
    [aux_sym_preproc_else_token1] = ACTIONS(5686),
    [aux_sym_preproc_elif_token1] = ACTIONS(5686),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3731] = {
    [sym_preproc_region] = STATE(3731),
    [sym_preproc_endregion] = STATE(3731),
    [sym_preproc_line] = STATE(3731),
    [sym_preproc_pragma] = STATE(3731),
    [sym_preproc_nullable] = STATE(3731),
    [sym_preproc_error] = STATE(3731),
    [sym_preproc_warning] = STATE(3731),
    [sym_preproc_define] = STATE(3731),
    [sym_preproc_undef] = STATE(3731),
    [anon_sym_SEMI] = ACTIONS(4433),
    [anon_sym_LBRACK] = ACTIONS(4433),
    [anon_sym_COLON] = ACTIONS(4433),
    [anon_sym_COMMA] = ACTIONS(4433),
    [anon_sym_RBRACK] = ACTIONS(4433),
    [anon_sym_LPAREN] = ACTIONS(4433),
    [anon_sym_RPAREN] = ACTIONS(4433),
    [anon_sym_LBRACE] = ACTIONS(4433),
    [anon_sym_RBRACE] = ACTIONS(4433),
    [anon_sym_LT] = ACTIONS(4431),
    [anon_sym_GT] = ACTIONS(4431),
    [anon_sym_in] = ACTIONS(4433),
    [anon_sym_where] = ACTIONS(4433),
    [anon_sym_QMARK] = ACTIONS(4431),
    [anon_sym_BANG] = ACTIONS(4431),
    [anon_sym_PLUS_PLUS] = ACTIONS(4433),
    [anon_sym_DASH_DASH] = ACTIONS(4433),
    [anon_sym_PLUS] = ACTIONS(4431),
    [anon_sym_DASH] = ACTIONS(4431),
    [anon_sym_STAR] = ACTIONS(4433),
    [anon_sym_SLASH] = ACTIONS(4431),
    [anon_sym_PERCENT] = ACTIONS(4433),
    [anon_sym_CARET] = ACTIONS(4433),
    [anon_sym_PIPE] = ACTIONS(4431),
    [anon_sym_AMP] = ACTIONS(4431),
    [anon_sym_LT_LT] = ACTIONS(4433),
    [anon_sym_GT_GT] = ACTIONS(4431),
    [anon_sym_GT_GT_GT] = ACTIONS(4433),
    [anon_sym_EQ_EQ] = ACTIONS(4433),
    [anon_sym_BANG_EQ] = ACTIONS(4433),
    [anon_sym_GT_EQ] = ACTIONS(4433),
    [anon_sym_LT_EQ] = ACTIONS(4433),
    [anon_sym_DOT] = ACTIONS(4431),
    [anon_sym_EQ_GT] = ACTIONS(4433),
    [anon_sym_switch] = ACTIONS(4433),
    [anon_sym_DOT_DOT] = ACTIONS(4433),
    [anon_sym_and] = ACTIONS(4433),
    [anon_sym_or] = ACTIONS(4431),
    [anon_sym_AMP_AMP] = ACTIONS(4433),
    [anon_sym_PIPE_PIPE] = ACTIONS(4433),
    [anon_sym_QMARK_QMARK] = ACTIONS(4433),
    [anon_sym_from] = ACTIONS(4433),
    [anon_sym_join] = ACTIONS(4433),
    [anon_sym_on] = ACTIONS(4433),
    [anon_sym_equals] = ACTIONS(4433),
    [anon_sym_let] = ACTIONS(4433),
    [anon_sym_orderby] = ACTIONS(4433),
    [anon_sym_group] = ACTIONS(4433),
    [anon_sym_by] = ACTIONS(4433),
    [anon_sym_select] = ACTIONS(4433),
    [anon_sym_as] = ACTIONS(4433),
    [anon_sym_is] = ACTIONS(4433),
    [anon_sym_DASH_GT] = ACTIONS(4433),
    [anon_sym_with] = ACTIONS(4433),
    [aux_sym_preproc_if_token3] = ACTIONS(4433),
    [aux_sym_preproc_else_token1] = ACTIONS(4433),
    [aux_sym_preproc_elif_token1] = ACTIONS(4433),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3732] = {
    [sym_preproc_region] = STATE(3732),
    [sym_preproc_endregion] = STATE(3732),
    [sym_preproc_line] = STATE(3732),
    [sym_preproc_pragma] = STATE(3732),
    [sym_preproc_nullable] = STATE(3732),
    [sym_preproc_error] = STATE(3732),
    [sym_preproc_warning] = STATE(3732),
    [sym_preproc_define] = STATE(3732),
    [sym_preproc_undef] = STATE(3732),
    [anon_sym_SEMI] = ACTIONS(4630),
    [anon_sym_LBRACK] = ACTIONS(4630),
    [anon_sym_COLON] = ACTIONS(4630),
    [anon_sym_COMMA] = ACTIONS(4630),
    [anon_sym_RBRACK] = ACTIONS(4630),
    [anon_sym_LPAREN] = ACTIONS(4630),
    [anon_sym_RPAREN] = ACTIONS(4630),
    [anon_sym_LBRACE] = ACTIONS(4630),
    [anon_sym_RBRACE] = ACTIONS(4630),
    [anon_sym_LT] = ACTIONS(4628),
    [anon_sym_GT] = ACTIONS(4628),
    [anon_sym_in] = ACTIONS(4630),
    [anon_sym_where] = ACTIONS(4630),
    [anon_sym_QMARK] = ACTIONS(4628),
    [anon_sym_BANG] = ACTIONS(4628),
    [anon_sym_PLUS_PLUS] = ACTIONS(4630),
    [anon_sym_DASH_DASH] = ACTIONS(4630),
    [anon_sym_PLUS] = ACTIONS(4628),
    [anon_sym_DASH] = ACTIONS(4628),
    [anon_sym_STAR] = ACTIONS(4630),
    [anon_sym_SLASH] = ACTIONS(4628),
    [anon_sym_PERCENT] = ACTIONS(4630),
    [anon_sym_CARET] = ACTIONS(4630),
    [anon_sym_PIPE] = ACTIONS(4628),
    [anon_sym_AMP] = ACTIONS(4628),
    [anon_sym_LT_LT] = ACTIONS(4630),
    [anon_sym_GT_GT] = ACTIONS(4628),
    [anon_sym_GT_GT_GT] = ACTIONS(4630),
    [anon_sym_EQ_EQ] = ACTIONS(4630),
    [anon_sym_BANG_EQ] = ACTIONS(4630),
    [anon_sym_GT_EQ] = ACTIONS(4630),
    [anon_sym_LT_EQ] = ACTIONS(4630),
    [anon_sym_DOT] = ACTIONS(4628),
    [anon_sym_EQ_GT] = ACTIONS(4630),
    [anon_sym_switch] = ACTIONS(4630),
    [anon_sym_DOT_DOT] = ACTIONS(4630),
    [anon_sym_and] = ACTIONS(4630),
    [anon_sym_or] = ACTIONS(4628),
    [anon_sym_AMP_AMP] = ACTIONS(4630),
    [anon_sym_PIPE_PIPE] = ACTIONS(4630),
    [anon_sym_QMARK_QMARK] = ACTIONS(4630),
    [anon_sym_from] = ACTIONS(4630),
    [anon_sym_join] = ACTIONS(4630),
    [anon_sym_on] = ACTIONS(4630),
    [anon_sym_equals] = ACTIONS(4630),
    [anon_sym_let] = ACTIONS(4630),
    [anon_sym_orderby] = ACTIONS(4630),
    [anon_sym_group] = ACTIONS(4630),
    [anon_sym_by] = ACTIONS(4630),
    [anon_sym_select] = ACTIONS(4630),
    [anon_sym_as] = ACTIONS(4630),
    [anon_sym_is] = ACTIONS(4630),
    [anon_sym_DASH_GT] = ACTIONS(4630),
    [anon_sym_with] = ACTIONS(4630),
    [aux_sym_preproc_if_token3] = ACTIONS(4630),
    [aux_sym_preproc_else_token1] = ACTIONS(4630),
    [aux_sym_preproc_elif_token1] = ACTIONS(4630),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3733] = {
    [sym_modifier] = STATE(3807),
    [sym_preproc_region] = STATE(3733),
    [sym_preproc_endregion] = STATE(3733),
    [sym_preproc_line] = STATE(3733),
    [sym_preproc_pragma] = STATE(3733),
    [sym_preproc_nullable] = STATE(3733),
    [sym_preproc_error] = STATE(3733),
    [sym_preproc_warning] = STATE(3733),
    [sym_preproc_define] = STATE(3733),
    [sym_preproc_undef] = STATE(3733),
    [aux_sym_class_declaration_repeat2] = STATE(3733),
    [sym__identifier_token] = ACTIONS(5690),
    [anon_sym_extern] = ACTIONS(5692),
    [anon_sym_alias] = ACTIONS(5690),
    [anon_sym_global] = ACTIONS(5690),
    [anon_sym_unsafe] = ACTIONS(5692),
    [anon_sym_static] = ACTIONS(5692),
    [anon_sym_LPAREN] = ACTIONS(5695),
    [anon_sym_event] = ACTIONS(5690),
    [anon_sym_class] = ACTIONS(5690),
    [anon_sym_ref] = ACTIONS(5690),
    [anon_sym_struct] = ACTIONS(5690),
    [anon_sym_enum] = ACTIONS(5690),
    [anon_sym_interface] = ACTIONS(5690),
    [anon_sym_delegate] = ACTIONS(5690),
    [anon_sym_record] = ACTIONS(5690),
    [anon_sym_abstract] = ACTIONS(5692),
    [anon_sym_async] = ACTIONS(5692),
    [anon_sym_const] = ACTIONS(5692),
    [anon_sym_file] = ACTIONS(5692),
    [anon_sym_fixed] = ACTIONS(5692),
    [anon_sym_internal] = ACTIONS(5692),
    [anon_sym_new] = ACTIONS(5692),
    [anon_sym_override] = ACTIONS(5692),
    [anon_sym_partial] = ACTIONS(5692),
    [anon_sym_private] = ACTIONS(5692),
    [anon_sym_protected] = ACTIONS(5692),
    [anon_sym_public] = ACTIONS(5692),
    [anon_sym_readonly] = ACTIONS(5692),
    [anon_sym_required] = ACTIONS(5692),
    [anon_sym_sealed] = ACTIONS(5692),
    [anon_sym_virtual] = ACTIONS(5692),
    [anon_sym_volatile] = ACTIONS(5692),
    [anon_sym_where] = ACTIONS(5690),
    [anon_sym_notnull] = ACTIONS(5690),
    [anon_sym_unmanaged] = ACTIONS(5690),
    [anon_sym_implicit] = ACTIONS(5690),
    [anon_sym_explicit] = ACTIONS(5690),
    [anon_sym_scoped] = ACTIONS(5690),
    [anon_sym_var] = ACTIONS(5690),
    [sym_predefined_type] = ACTIONS(5690),
    [anon_sym_yield] = ACTIONS(5690),
    [anon_sym_when] = ACTIONS(5690),
    [anon_sym_from] = ACTIONS(5690),
    [anon_sym_into] = ACTIONS(5690),
    [anon_sym_join] = ACTIONS(5690),
    [anon_sym_on] = ACTIONS(5690),
    [anon_sym_equals] = ACTIONS(5690),
    [anon_sym_let] = ACTIONS(5690),
    [anon_sym_orderby] = ACTIONS(5690),
    [anon_sym_ascending] = ACTIONS(5690),
    [anon_sym_descending] = ACTIONS(5690),
    [anon_sym_group] = ACTIONS(5690),
    [anon_sym_by] = ACTIONS(5690),
    [anon_sym_select] = ACTIONS(5690),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3734] = {
    [sym_preproc_region] = STATE(3734),
    [sym_preproc_endregion] = STATE(3734),
    [sym_preproc_line] = STATE(3734),
    [sym_preproc_pragma] = STATE(3734),
    [sym_preproc_nullable] = STATE(3734),
    [sym_preproc_error] = STATE(3734),
    [sym_preproc_warning] = STATE(3734),
    [sym_preproc_define] = STATE(3734),
    [sym_preproc_undef] = STATE(3734),
    [anon_sym_SEMI] = ACTIONS(5620),
    [anon_sym_LBRACK] = ACTIONS(5620),
    [anon_sym_COLON] = ACTIONS(5620),
    [anon_sym_COMMA] = ACTIONS(5620),
    [anon_sym_RBRACK] = ACTIONS(5620),
    [anon_sym_LPAREN] = ACTIONS(5620),
    [anon_sym_RPAREN] = ACTIONS(5620),
    [anon_sym_RBRACE] = ACTIONS(5620),
    [anon_sym_LT] = ACTIONS(5622),
    [anon_sym_GT] = ACTIONS(5622),
    [anon_sym_in] = ACTIONS(5620),
    [anon_sym_where] = ACTIONS(5620),
    [anon_sym_QMARK] = ACTIONS(5622),
    [anon_sym_BANG] = ACTIONS(5622),
    [anon_sym_PLUS_PLUS] = ACTIONS(5620),
    [anon_sym_DASH_DASH] = ACTIONS(5620),
    [anon_sym_PLUS] = ACTIONS(5622),
    [anon_sym_DASH] = ACTIONS(5622),
    [anon_sym_STAR] = ACTIONS(5620),
    [anon_sym_SLASH] = ACTIONS(5622),
    [anon_sym_PERCENT] = ACTIONS(5620),
    [anon_sym_CARET] = ACTIONS(5620),
    [anon_sym_PIPE] = ACTIONS(5622),
    [anon_sym_AMP] = ACTIONS(5622),
    [anon_sym_LT_LT] = ACTIONS(5620),
    [anon_sym_GT_GT] = ACTIONS(5622),
    [anon_sym_GT_GT_GT] = ACTIONS(5620),
    [anon_sym_EQ_EQ] = ACTIONS(5620),
    [anon_sym_BANG_EQ] = ACTIONS(5620),
    [anon_sym_GT_EQ] = ACTIONS(5620),
    [anon_sym_LT_EQ] = ACTIONS(5620),
    [anon_sym_DOT] = ACTIONS(5622),
    [anon_sym_EQ_GT] = ACTIONS(5620),
    [anon_sym_switch] = ACTIONS(5620),
    [anon_sym_DOT_DOT] = ACTIONS(5620),
    [anon_sym_and] = ACTIONS(5620),
    [anon_sym_or] = ACTIONS(5622),
    [anon_sym_AMP_AMP] = ACTIONS(5620),
    [anon_sym_PIPE_PIPE] = ACTIONS(5620),
    [anon_sym_QMARK_QMARK] = ACTIONS(5620),
    [anon_sym_from] = ACTIONS(5620),
    [anon_sym_join] = ACTIONS(5620),
    [anon_sym_on] = ACTIONS(5620),
    [anon_sym_equals] = ACTIONS(5620),
    [anon_sym_let] = ACTIONS(5620),
    [anon_sym_orderby] = ACTIONS(5620),
    [anon_sym_group] = ACTIONS(5620),
    [anon_sym_by] = ACTIONS(5620),
    [anon_sym_select] = ACTIONS(5620),
    [anon_sym_as] = ACTIONS(5620),
    [anon_sym_is] = ACTIONS(5620),
    [anon_sym_DASH_GT] = ACTIONS(5620),
    [anon_sym_with] = ACTIONS(5620),
    [aux_sym_preproc_if_token3] = ACTIONS(5620),
    [aux_sym_preproc_else_token1] = ACTIONS(5620),
    [aux_sym_preproc_elif_token1] = ACTIONS(5620),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3735] = {
    [sym_preproc_region] = STATE(3735),
    [sym_preproc_endregion] = STATE(3735),
    [sym_preproc_line] = STATE(3735),
    [sym_preproc_pragma] = STATE(3735),
    [sym_preproc_nullable] = STATE(3735),
    [sym_preproc_error] = STATE(3735),
    [sym_preproc_warning] = STATE(3735),
    [sym_preproc_define] = STATE(3735),
    [sym_preproc_undef] = STATE(3735),
    [anon_sym_SEMI] = ACTIONS(5572),
    [anon_sym_LBRACK] = ACTIONS(5572),
    [anon_sym_COLON] = ACTIONS(5572),
    [anon_sym_COMMA] = ACTIONS(5572),
    [anon_sym_RBRACK] = ACTIONS(5572),
    [anon_sym_LPAREN] = ACTIONS(5572),
    [anon_sym_RPAREN] = ACTIONS(5572),
    [anon_sym_RBRACE] = ACTIONS(5572),
    [anon_sym_LT] = ACTIONS(5574),
    [anon_sym_GT] = ACTIONS(5574),
    [anon_sym_in] = ACTIONS(5572),
    [anon_sym_where] = ACTIONS(5572),
    [anon_sym_QMARK] = ACTIONS(5574),
    [anon_sym_BANG] = ACTIONS(5574),
    [anon_sym_PLUS_PLUS] = ACTIONS(5572),
    [anon_sym_DASH_DASH] = ACTIONS(5572),
    [anon_sym_PLUS] = ACTIONS(5574),
    [anon_sym_DASH] = ACTIONS(5574),
    [anon_sym_STAR] = ACTIONS(5572),
    [anon_sym_SLASH] = ACTIONS(5574),
    [anon_sym_PERCENT] = ACTIONS(5572),
    [anon_sym_CARET] = ACTIONS(5572),
    [anon_sym_PIPE] = ACTIONS(5574),
    [anon_sym_AMP] = ACTIONS(5574),
    [anon_sym_LT_LT] = ACTIONS(5572),
    [anon_sym_GT_GT] = ACTIONS(5574),
    [anon_sym_GT_GT_GT] = ACTIONS(5572),
    [anon_sym_EQ_EQ] = ACTIONS(5572),
    [anon_sym_BANG_EQ] = ACTIONS(5572),
    [anon_sym_GT_EQ] = ACTIONS(5572),
    [anon_sym_LT_EQ] = ACTIONS(5572),
    [anon_sym_DOT] = ACTIONS(5574),
    [anon_sym_EQ_GT] = ACTIONS(5572),
    [anon_sym_switch] = ACTIONS(5572),
    [anon_sym_DOT_DOT] = ACTIONS(5572),
    [anon_sym_and] = ACTIONS(5572),
    [anon_sym_or] = ACTIONS(5574),
    [anon_sym_AMP_AMP] = ACTIONS(5572),
    [anon_sym_PIPE_PIPE] = ACTIONS(5572),
    [anon_sym_QMARK_QMARK] = ACTIONS(5572),
    [anon_sym_from] = ACTIONS(5572),
    [anon_sym_join] = ACTIONS(5572),
    [anon_sym_on] = ACTIONS(5572),
    [anon_sym_equals] = ACTIONS(5572),
    [anon_sym_let] = ACTIONS(5572),
    [anon_sym_orderby] = ACTIONS(5572),
    [anon_sym_group] = ACTIONS(5572),
    [anon_sym_by] = ACTIONS(5572),
    [anon_sym_select] = ACTIONS(5572),
    [anon_sym_as] = ACTIONS(5572),
    [anon_sym_is] = ACTIONS(5572),
    [anon_sym_DASH_GT] = ACTIONS(5572),
    [anon_sym_with] = ACTIONS(5572),
    [aux_sym_preproc_if_token3] = ACTIONS(5572),
    [aux_sym_preproc_else_token1] = ACTIONS(5572),
    [aux_sym_preproc_elif_token1] = ACTIONS(5572),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3736] = {
    [sym_preproc_region] = STATE(3736),
    [sym_preproc_endregion] = STATE(3736),
    [sym_preproc_line] = STATE(3736),
    [sym_preproc_pragma] = STATE(3736),
    [sym_preproc_nullable] = STATE(3736),
    [sym_preproc_error] = STATE(3736),
    [sym_preproc_warning] = STATE(3736),
    [sym_preproc_define] = STATE(3736),
    [sym_preproc_undef] = STATE(3736),
    [anon_sym_SEMI] = ACTIONS(5592),
    [anon_sym_LBRACK] = ACTIONS(5592),
    [anon_sym_COLON] = ACTIONS(5592),
    [anon_sym_COMMA] = ACTIONS(5592),
    [anon_sym_RBRACK] = ACTIONS(5592),
    [anon_sym_LPAREN] = ACTIONS(5592),
    [anon_sym_RPAREN] = ACTIONS(5592),
    [anon_sym_RBRACE] = ACTIONS(5592),
    [anon_sym_LT] = ACTIONS(5594),
    [anon_sym_GT] = ACTIONS(5594),
    [anon_sym_in] = ACTIONS(5592),
    [anon_sym_where] = ACTIONS(5592),
    [anon_sym_QMARK] = ACTIONS(5594),
    [anon_sym_BANG] = ACTIONS(5594),
    [anon_sym_PLUS_PLUS] = ACTIONS(5592),
    [anon_sym_DASH_DASH] = ACTIONS(5592),
    [anon_sym_PLUS] = ACTIONS(5594),
    [anon_sym_DASH] = ACTIONS(5594),
    [anon_sym_STAR] = ACTIONS(5592),
    [anon_sym_SLASH] = ACTIONS(5594),
    [anon_sym_PERCENT] = ACTIONS(5592),
    [anon_sym_CARET] = ACTIONS(5592),
    [anon_sym_PIPE] = ACTIONS(5594),
    [anon_sym_AMP] = ACTIONS(5594),
    [anon_sym_LT_LT] = ACTIONS(5592),
    [anon_sym_GT_GT] = ACTIONS(5594),
    [anon_sym_GT_GT_GT] = ACTIONS(5592),
    [anon_sym_EQ_EQ] = ACTIONS(5592),
    [anon_sym_BANG_EQ] = ACTIONS(5592),
    [anon_sym_GT_EQ] = ACTIONS(5592),
    [anon_sym_LT_EQ] = ACTIONS(5592),
    [anon_sym_DOT] = ACTIONS(5594),
    [anon_sym_EQ_GT] = ACTIONS(5592),
    [anon_sym_switch] = ACTIONS(5592),
    [anon_sym_DOT_DOT] = ACTIONS(5592),
    [anon_sym_and] = ACTIONS(5592),
    [anon_sym_or] = ACTIONS(5594),
    [anon_sym_AMP_AMP] = ACTIONS(5592),
    [anon_sym_PIPE_PIPE] = ACTIONS(5592),
    [anon_sym_QMARK_QMARK] = ACTIONS(5592),
    [anon_sym_from] = ACTIONS(5592),
    [anon_sym_join] = ACTIONS(5592),
    [anon_sym_on] = ACTIONS(5592),
    [anon_sym_equals] = ACTIONS(5592),
    [anon_sym_let] = ACTIONS(5592),
    [anon_sym_orderby] = ACTIONS(5592),
    [anon_sym_group] = ACTIONS(5592),
    [anon_sym_by] = ACTIONS(5592),
    [anon_sym_select] = ACTIONS(5592),
    [anon_sym_as] = ACTIONS(5592),
    [anon_sym_is] = ACTIONS(5592),
    [anon_sym_DASH_GT] = ACTIONS(5592),
    [anon_sym_with] = ACTIONS(5592),
    [aux_sym_preproc_if_token3] = ACTIONS(5592),
    [aux_sym_preproc_else_token1] = ACTIONS(5592),
    [aux_sym_preproc_elif_token1] = ACTIONS(5592),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3737] = {
    [sym_preproc_region] = STATE(3737),
    [sym_preproc_endregion] = STATE(3737),
    [sym_preproc_line] = STATE(3737),
    [sym_preproc_pragma] = STATE(3737),
    [sym_preproc_nullable] = STATE(3737),
    [sym_preproc_error] = STATE(3737),
    [sym_preproc_warning] = STATE(3737),
    [sym_preproc_define] = STATE(3737),
    [sym_preproc_undef] = STATE(3737),
    [sym__identifier_token] = ACTIONS(5697),
    [anon_sym_extern] = ACTIONS(5697),
    [anon_sym_alias] = ACTIONS(5697),
    [anon_sym_global] = ACTIONS(5697),
    [anon_sym_unsafe] = ACTIONS(5697),
    [anon_sym_static] = ACTIONS(5697),
    [anon_sym_LBRACK] = ACTIONS(5699),
    [anon_sym_LPAREN] = ACTIONS(5699),
    [anon_sym_event] = ACTIONS(5697),
    [anon_sym_class] = ACTIONS(5697),
    [anon_sym_ref] = ACTIONS(5697),
    [anon_sym_struct] = ACTIONS(5697),
    [anon_sym_enum] = ACTIONS(5697),
    [anon_sym_interface] = ACTIONS(5697),
    [anon_sym_delegate] = ACTIONS(5697),
    [anon_sym_record] = ACTIONS(5697),
    [anon_sym_abstract] = ACTIONS(5697),
    [anon_sym_async] = ACTIONS(5697),
    [anon_sym_const] = ACTIONS(5697),
    [anon_sym_file] = ACTIONS(5697),
    [anon_sym_fixed] = ACTIONS(5697),
    [anon_sym_internal] = ACTIONS(5697),
    [anon_sym_new] = ACTIONS(5697),
    [anon_sym_override] = ACTIONS(5697),
    [anon_sym_partial] = ACTIONS(5697),
    [anon_sym_private] = ACTIONS(5697),
    [anon_sym_protected] = ACTIONS(5697),
    [anon_sym_public] = ACTIONS(5697),
    [anon_sym_readonly] = ACTIONS(5697),
    [anon_sym_required] = ACTIONS(5697),
    [anon_sym_sealed] = ACTIONS(5697),
    [anon_sym_virtual] = ACTIONS(5697),
    [anon_sym_volatile] = ACTIONS(5697),
    [anon_sym_where] = ACTIONS(5697),
    [anon_sym_notnull] = ACTIONS(5697),
    [anon_sym_unmanaged] = ACTIONS(5697),
    [anon_sym_TILDE] = ACTIONS(5699),
    [anon_sym_implicit] = ACTIONS(5697),
    [anon_sym_explicit] = ACTIONS(5697),
    [anon_sym_scoped] = ACTIONS(5697),
    [anon_sym_var] = ACTIONS(5697),
    [sym_predefined_type] = ACTIONS(5697),
    [anon_sym_yield] = ACTIONS(5697),
    [anon_sym_when] = ACTIONS(5697),
    [anon_sym_from] = ACTIONS(5697),
    [anon_sym_into] = ACTIONS(5697),
    [anon_sym_join] = ACTIONS(5697),
    [anon_sym_on] = ACTIONS(5697),
    [anon_sym_equals] = ACTIONS(5697),
    [anon_sym_let] = ACTIONS(5697),
    [anon_sym_orderby] = ACTIONS(5697),
    [anon_sym_ascending] = ACTIONS(5697),
    [anon_sym_descending] = ACTIONS(5697),
    [anon_sym_group] = ACTIONS(5697),
    [anon_sym_by] = ACTIONS(5697),
    [anon_sym_select] = ACTIONS(5697),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3738] = {
    [sym_preproc_region] = STATE(3738),
    [sym_preproc_endregion] = STATE(3738),
    [sym_preproc_line] = STATE(3738),
    [sym_preproc_pragma] = STATE(3738),
    [sym_preproc_nullable] = STATE(3738),
    [sym_preproc_error] = STATE(3738),
    [sym_preproc_warning] = STATE(3738),
    [sym_preproc_define] = STATE(3738),
    [sym_preproc_undef] = STATE(3738),
    [anon_sym_SEMI] = ACTIONS(5522),
    [anon_sym_LBRACK] = ACTIONS(5522),
    [anon_sym_COLON] = ACTIONS(5522),
    [anon_sym_COMMA] = ACTIONS(5522),
    [anon_sym_RBRACK] = ACTIONS(5522),
    [anon_sym_LPAREN] = ACTIONS(5522),
    [anon_sym_RPAREN] = ACTIONS(5522),
    [anon_sym_RBRACE] = ACTIONS(5522),
    [anon_sym_LT] = ACTIONS(5524),
    [anon_sym_GT] = ACTIONS(5524),
    [anon_sym_in] = ACTIONS(5522),
    [anon_sym_where] = ACTIONS(5522),
    [anon_sym_QMARK] = ACTIONS(5524),
    [anon_sym_BANG] = ACTIONS(5524),
    [anon_sym_PLUS_PLUS] = ACTIONS(5522),
    [anon_sym_DASH_DASH] = ACTIONS(5522),
    [anon_sym_PLUS] = ACTIONS(5524),
    [anon_sym_DASH] = ACTIONS(5524),
    [anon_sym_STAR] = ACTIONS(5522),
    [anon_sym_SLASH] = ACTIONS(5524),
    [anon_sym_PERCENT] = ACTIONS(5522),
    [anon_sym_CARET] = ACTIONS(5522),
    [anon_sym_PIPE] = ACTIONS(5524),
    [anon_sym_AMP] = ACTIONS(5524),
    [anon_sym_LT_LT] = ACTIONS(5522),
    [anon_sym_GT_GT] = ACTIONS(5524),
    [anon_sym_GT_GT_GT] = ACTIONS(5522),
    [anon_sym_EQ_EQ] = ACTIONS(5522),
    [anon_sym_BANG_EQ] = ACTIONS(5522),
    [anon_sym_GT_EQ] = ACTIONS(5522),
    [anon_sym_LT_EQ] = ACTIONS(5522),
    [anon_sym_DOT] = ACTIONS(5524),
    [anon_sym_EQ_GT] = ACTIONS(5522),
    [anon_sym_switch] = ACTIONS(5522),
    [anon_sym_DOT_DOT] = ACTIONS(5522),
    [anon_sym_and] = ACTIONS(5522),
    [anon_sym_or] = ACTIONS(5524),
    [anon_sym_AMP_AMP] = ACTIONS(5522),
    [anon_sym_PIPE_PIPE] = ACTIONS(5522),
    [anon_sym_QMARK_QMARK] = ACTIONS(5522),
    [anon_sym_from] = ACTIONS(5522),
    [anon_sym_join] = ACTIONS(5522),
    [anon_sym_on] = ACTIONS(5522),
    [anon_sym_equals] = ACTIONS(5522),
    [anon_sym_let] = ACTIONS(5522),
    [anon_sym_orderby] = ACTIONS(5522),
    [anon_sym_group] = ACTIONS(5522),
    [anon_sym_by] = ACTIONS(5522),
    [anon_sym_select] = ACTIONS(5522),
    [anon_sym_as] = ACTIONS(5522),
    [anon_sym_is] = ACTIONS(5522),
    [anon_sym_DASH_GT] = ACTIONS(5522),
    [anon_sym_with] = ACTIONS(5522),
    [aux_sym_preproc_if_token3] = ACTIONS(5522),
    [aux_sym_preproc_else_token1] = ACTIONS(5522),
    [aux_sym_preproc_elif_token1] = ACTIONS(5522),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3739] = {
    [sym_preproc_region] = STATE(3739),
    [sym_preproc_endregion] = STATE(3739),
    [sym_preproc_line] = STATE(3739),
    [sym_preproc_pragma] = STATE(3739),
    [sym_preproc_nullable] = STATE(3739),
    [sym_preproc_error] = STATE(3739),
    [sym_preproc_warning] = STATE(3739),
    [sym_preproc_define] = STATE(3739),
    [sym_preproc_undef] = STATE(3739),
    [anon_sym_EQ] = ACTIONS(4162),
    [anon_sym_LBRACK] = ACTIONS(4808),
    [anon_sym_LPAREN] = ACTIONS(4808),
    [anon_sym_LT] = ACTIONS(4811),
    [anon_sym_GT] = ACTIONS(4811),
    [anon_sym_where] = ACTIONS(4806),
    [anon_sym_QMARK] = ACTIONS(4811),
    [anon_sym_BANG] = ACTIONS(4811),
    [anon_sym_PLUS_PLUS] = ACTIONS(4808),
    [anon_sym_DASH_DASH] = ACTIONS(4808),
    [anon_sym_PLUS] = ACTIONS(4811),
    [anon_sym_DASH] = ACTIONS(4811),
    [anon_sym_STAR] = ACTIONS(4811),
    [anon_sym_SLASH] = ACTIONS(4811),
    [anon_sym_PERCENT] = ACTIONS(4811),
    [anon_sym_CARET] = ACTIONS(4811),
    [anon_sym_PIPE] = ACTIONS(4811),
    [anon_sym_AMP] = ACTIONS(4811),
    [anon_sym_LT_LT] = ACTIONS(4811),
    [anon_sym_GT_GT] = ACTIONS(4811),
    [anon_sym_GT_GT_GT] = ACTIONS(4811),
    [anon_sym_EQ_EQ] = ACTIONS(4808),
    [anon_sym_BANG_EQ] = ACTIONS(4808),
    [anon_sym_GT_EQ] = ACTIONS(4808),
    [anon_sym_LT_EQ] = ACTIONS(4808),
    [anon_sym_DOT] = ACTIONS(4811),
    [anon_sym_switch] = ACTIONS(4808),
    [anon_sym_DOT_DOT] = ACTIONS(4808),
    [anon_sym_and] = ACTIONS(4806),
    [anon_sym_or] = ACTIONS(4814),
    [anon_sym_PLUS_EQ] = ACTIONS(4177),
    [anon_sym_DASH_EQ] = ACTIONS(4177),
    [anon_sym_STAR_EQ] = ACTIONS(4177),
    [anon_sym_SLASH_EQ] = ACTIONS(4177),
    [anon_sym_PERCENT_EQ] = ACTIONS(4177),
    [anon_sym_AMP_EQ] = ACTIONS(4177),
    [anon_sym_CARET_EQ] = ACTIONS(4177),
    [anon_sym_PIPE_EQ] = ACTIONS(4177),
    [anon_sym_LT_LT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4177),
    [anon_sym_AMP_AMP] = ACTIONS(4808),
    [anon_sym_PIPE_PIPE] = ACTIONS(4808),
    [anon_sym_QMARK_QMARK] = ACTIONS(4811),
    [anon_sym_from] = ACTIONS(4806),
    [anon_sym_into] = ACTIONS(4806),
    [anon_sym_join] = ACTIONS(4806),
    [anon_sym_let] = ACTIONS(4806),
    [anon_sym_orderby] = ACTIONS(4806),
    [anon_sym_group] = ACTIONS(4806),
    [anon_sym_select] = ACTIONS(4806),
    [anon_sym_as] = ACTIONS(4808),
    [anon_sym_is] = ACTIONS(4808),
    [anon_sym_DASH_GT] = ACTIONS(4808),
    [anon_sym_with] = ACTIONS(4808),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3740] = {
    [sym_preproc_region] = STATE(3740),
    [sym_preproc_endregion] = STATE(3740),
    [sym_preproc_line] = STATE(3740),
    [sym_preproc_pragma] = STATE(3740),
    [sym_preproc_nullable] = STATE(3740),
    [sym_preproc_error] = STATE(3740),
    [sym_preproc_warning] = STATE(3740),
    [sym_preproc_define] = STATE(3740),
    [sym_preproc_undef] = STATE(3740),
    [sym__identifier_token] = ACTIONS(5701),
    [anon_sym_extern] = ACTIONS(5701),
    [anon_sym_alias] = ACTIONS(5701),
    [anon_sym_global] = ACTIONS(5701),
    [anon_sym_unsafe] = ACTIONS(5701),
    [anon_sym_static] = ACTIONS(5701),
    [anon_sym_LBRACK] = ACTIONS(5703),
    [anon_sym_LPAREN] = ACTIONS(5703),
    [anon_sym_event] = ACTIONS(5701),
    [anon_sym_class] = ACTIONS(5701),
    [anon_sym_ref] = ACTIONS(5701),
    [anon_sym_struct] = ACTIONS(5701),
    [anon_sym_enum] = ACTIONS(5701),
    [anon_sym_interface] = ACTIONS(5701),
    [anon_sym_delegate] = ACTIONS(5701),
    [anon_sym_record] = ACTIONS(5701),
    [anon_sym_abstract] = ACTIONS(5701),
    [anon_sym_async] = ACTIONS(5701),
    [anon_sym_const] = ACTIONS(5701),
    [anon_sym_file] = ACTIONS(5701),
    [anon_sym_fixed] = ACTIONS(5701),
    [anon_sym_internal] = ACTIONS(5701),
    [anon_sym_new] = ACTIONS(5701),
    [anon_sym_override] = ACTIONS(5701),
    [anon_sym_partial] = ACTIONS(5701),
    [anon_sym_private] = ACTIONS(5701),
    [anon_sym_protected] = ACTIONS(5701),
    [anon_sym_public] = ACTIONS(5701),
    [anon_sym_readonly] = ACTIONS(5701),
    [anon_sym_required] = ACTIONS(5701),
    [anon_sym_sealed] = ACTIONS(5701),
    [anon_sym_virtual] = ACTIONS(5701),
    [anon_sym_volatile] = ACTIONS(5701),
    [anon_sym_where] = ACTIONS(5701),
    [anon_sym_notnull] = ACTIONS(5701),
    [anon_sym_unmanaged] = ACTIONS(5701),
    [anon_sym_TILDE] = ACTIONS(5703),
    [anon_sym_implicit] = ACTIONS(5701),
    [anon_sym_explicit] = ACTIONS(5701),
    [anon_sym_scoped] = ACTIONS(5701),
    [anon_sym_var] = ACTIONS(5701),
    [sym_predefined_type] = ACTIONS(5701),
    [anon_sym_yield] = ACTIONS(5701),
    [anon_sym_when] = ACTIONS(5701),
    [anon_sym_from] = ACTIONS(5701),
    [anon_sym_into] = ACTIONS(5701),
    [anon_sym_join] = ACTIONS(5701),
    [anon_sym_on] = ACTIONS(5701),
    [anon_sym_equals] = ACTIONS(5701),
    [anon_sym_let] = ACTIONS(5701),
    [anon_sym_orderby] = ACTIONS(5701),
    [anon_sym_ascending] = ACTIONS(5701),
    [anon_sym_descending] = ACTIONS(5701),
    [anon_sym_group] = ACTIONS(5701),
    [anon_sym_by] = ACTIONS(5701),
    [anon_sym_select] = ACTIONS(5701),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3741] = {
    [sym_preproc_region] = STATE(3741),
    [sym_preproc_endregion] = STATE(3741),
    [sym_preproc_line] = STATE(3741),
    [sym_preproc_pragma] = STATE(3741),
    [sym_preproc_nullable] = STATE(3741),
    [sym_preproc_error] = STATE(3741),
    [sym_preproc_warning] = STATE(3741),
    [sym_preproc_define] = STATE(3741),
    [sym_preproc_undef] = STATE(3741),
    [anon_sym_SEMI] = ACTIONS(5584),
    [anon_sym_LBRACK] = ACTIONS(5584),
    [anon_sym_COLON] = ACTIONS(5584),
    [anon_sym_COMMA] = ACTIONS(5584),
    [anon_sym_RBRACK] = ACTIONS(5584),
    [anon_sym_LPAREN] = ACTIONS(5584),
    [anon_sym_RPAREN] = ACTIONS(5584),
    [anon_sym_RBRACE] = ACTIONS(5584),
    [anon_sym_LT] = ACTIONS(5586),
    [anon_sym_GT] = ACTIONS(5586),
    [anon_sym_in] = ACTIONS(5584),
    [anon_sym_where] = ACTIONS(5584),
    [anon_sym_QMARK] = ACTIONS(5586),
    [anon_sym_BANG] = ACTIONS(5586),
    [anon_sym_PLUS_PLUS] = ACTIONS(5584),
    [anon_sym_DASH_DASH] = ACTIONS(5584),
    [anon_sym_PLUS] = ACTIONS(5586),
    [anon_sym_DASH] = ACTIONS(5586),
    [anon_sym_STAR] = ACTIONS(5584),
    [anon_sym_SLASH] = ACTIONS(5586),
    [anon_sym_PERCENT] = ACTIONS(5584),
    [anon_sym_CARET] = ACTIONS(5584),
    [anon_sym_PIPE] = ACTIONS(5586),
    [anon_sym_AMP] = ACTIONS(5586),
    [anon_sym_LT_LT] = ACTIONS(5584),
    [anon_sym_GT_GT] = ACTIONS(5586),
    [anon_sym_GT_GT_GT] = ACTIONS(5584),
    [anon_sym_EQ_EQ] = ACTIONS(5584),
    [anon_sym_BANG_EQ] = ACTIONS(5584),
    [anon_sym_GT_EQ] = ACTIONS(5584),
    [anon_sym_LT_EQ] = ACTIONS(5584),
    [anon_sym_DOT] = ACTIONS(5586),
    [anon_sym_EQ_GT] = ACTIONS(5584),
    [anon_sym_switch] = ACTIONS(5584),
    [anon_sym_DOT_DOT] = ACTIONS(5584),
    [anon_sym_and] = ACTIONS(5584),
    [anon_sym_or] = ACTIONS(5586),
    [anon_sym_AMP_AMP] = ACTIONS(5584),
    [anon_sym_PIPE_PIPE] = ACTIONS(5584),
    [anon_sym_QMARK_QMARK] = ACTIONS(5584),
    [anon_sym_from] = ACTIONS(5584),
    [anon_sym_join] = ACTIONS(5584),
    [anon_sym_on] = ACTIONS(5584),
    [anon_sym_equals] = ACTIONS(5584),
    [anon_sym_let] = ACTIONS(5584),
    [anon_sym_orderby] = ACTIONS(5584),
    [anon_sym_group] = ACTIONS(5584),
    [anon_sym_by] = ACTIONS(5584),
    [anon_sym_select] = ACTIONS(5584),
    [anon_sym_as] = ACTIONS(5584),
    [anon_sym_is] = ACTIONS(5584),
    [anon_sym_DASH_GT] = ACTIONS(5584),
    [anon_sym_with] = ACTIONS(5584),
    [aux_sym_preproc_if_token3] = ACTIONS(5584),
    [aux_sym_preproc_else_token1] = ACTIONS(5584),
    [aux_sym_preproc_elif_token1] = ACTIONS(5584),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3742] = {
    [sym_preproc_region] = STATE(3742),
    [sym_preproc_endregion] = STATE(3742),
    [sym_preproc_line] = STATE(3742),
    [sym_preproc_pragma] = STATE(3742),
    [sym_preproc_nullable] = STATE(3742),
    [sym_preproc_error] = STATE(3742),
    [sym_preproc_warning] = STATE(3742),
    [sym_preproc_define] = STATE(3742),
    [sym_preproc_undef] = STATE(3742),
    [anon_sym_EQ] = ACTIONS(5705),
    [anon_sym_LBRACK] = ACTIONS(5286),
    [anon_sym_COMMA] = ACTIONS(5286),
    [anon_sym_LPAREN] = ACTIONS(5286),
    [anon_sym_LT] = ACTIONS(5288),
    [anon_sym_GT] = ACTIONS(5288),
    [anon_sym_where] = ACTIONS(5286),
    [anon_sym_QMARK] = ACTIONS(5288),
    [anon_sym_BANG] = ACTIONS(5288),
    [anon_sym_PLUS_PLUS] = ACTIONS(5286),
    [anon_sym_DASH_DASH] = ACTIONS(5286),
    [anon_sym_PLUS] = ACTIONS(5288),
    [anon_sym_DASH] = ACTIONS(5288),
    [anon_sym_STAR] = ACTIONS(5288),
    [anon_sym_SLASH] = ACTIONS(5288),
    [anon_sym_PERCENT] = ACTIONS(5288),
    [anon_sym_CARET] = ACTIONS(5288),
    [anon_sym_PIPE] = ACTIONS(5288),
    [anon_sym_AMP] = ACTIONS(5288),
    [anon_sym_LT_LT] = ACTIONS(5288),
    [anon_sym_GT_GT] = ACTIONS(5288),
    [anon_sym_GT_GT_GT] = ACTIONS(5288),
    [anon_sym_EQ_EQ] = ACTIONS(5286),
    [anon_sym_BANG_EQ] = ACTIONS(5286),
    [anon_sym_GT_EQ] = ACTIONS(5286),
    [anon_sym_LT_EQ] = ACTIONS(5286),
    [anon_sym_DOT] = ACTIONS(5288),
    [anon_sym_switch] = ACTIONS(5286),
    [anon_sym_DOT_DOT] = ACTIONS(5286),
    [anon_sym_PLUS_EQ] = ACTIONS(5707),
    [anon_sym_DASH_EQ] = ACTIONS(5707),
    [anon_sym_STAR_EQ] = ACTIONS(5707),
    [anon_sym_SLASH_EQ] = ACTIONS(5707),
    [anon_sym_PERCENT_EQ] = ACTIONS(5707),
    [anon_sym_AMP_EQ] = ACTIONS(5707),
    [anon_sym_CARET_EQ] = ACTIONS(5707),
    [anon_sym_PIPE_EQ] = ACTIONS(5707),
    [anon_sym_LT_LT_EQ] = ACTIONS(5707),
    [anon_sym_GT_GT_EQ] = ACTIONS(5707),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(5707),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(5707),
    [anon_sym_AMP_AMP] = ACTIONS(5286),
    [anon_sym_PIPE_PIPE] = ACTIONS(5286),
    [anon_sym_QMARK_QMARK] = ACTIONS(5288),
    [anon_sym_from] = ACTIONS(5286),
    [anon_sym_join] = ACTIONS(5286),
    [anon_sym_let] = ACTIONS(5286),
    [anon_sym_orderby] = ACTIONS(5286),
    [anon_sym_ascending] = ACTIONS(5286),
    [anon_sym_descending] = ACTIONS(5286),
    [anon_sym_group] = ACTIONS(5286),
    [anon_sym_select] = ACTIONS(5286),
    [anon_sym_as] = ACTIONS(5288),
    [anon_sym_is] = ACTIONS(5286),
    [anon_sym_DASH_GT] = ACTIONS(5286),
    [anon_sym_with] = ACTIONS(5286),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3743] = {
    [sym_preproc_region] = STATE(3743),
    [sym_preproc_endregion] = STATE(3743),
    [sym_preproc_line] = STATE(3743),
    [sym_preproc_pragma] = STATE(3743),
    [sym_preproc_nullable] = STATE(3743),
    [sym_preproc_error] = STATE(3743),
    [sym_preproc_warning] = STATE(3743),
    [sym_preproc_define] = STATE(3743),
    [sym_preproc_undef] = STATE(3743),
    [anon_sym_SEMI] = ACTIONS(5576),
    [anon_sym_LBRACK] = ACTIONS(5576),
    [anon_sym_COLON] = ACTIONS(5576),
    [anon_sym_COMMA] = ACTIONS(5576),
    [anon_sym_RBRACK] = ACTIONS(5576),
    [anon_sym_LPAREN] = ACTIONS(5576),
    [anon_sym_RPAREN] = ACTIONS(5576),
    [anon_sym_RBRACE] = ACTIONS(5576),
    [anon_sym_LT] = ACTIONS(5578),
    [anon_sym_GT] = ACTIONS(5578),
    [anon_sym_in] = ACTIONS(5576),
    [anon_sym_where] = ACTIONS(5576),
    [anon_sym_QMARK] = ACTIONS(5578),
    [anon_sym_BANG] = ACTIONS(5578),
    [anon_sym_PLUS_PLUS] = ACTIONS(5576),
    [anon_sym_DASH_DASH] = ACTIONS(5576),
    [anon_sym_PLUS] = ACTIONS(5578),
    [anon_sym_DASH] = ACTIONS(5578),
    [anon_sym_STAR] = ACTIONS(5576),
    [anon_sym_SLASH] = ACTIONS(5578),
    [anon_sym_PERCENT] = ACTIONS(5576),
    [anon_sym_CARET] = ACTIONS(5576),
    [anon_sym_PIPE] = ACTIONS(5578),
    [anon_sym_AMP] = ACTIONS(5578),
    [anon_sym_LT_LT] = ACTIONS(5576),
    [anon_sym_GT_GT] = ACTIONS(5578),
    [anon_sym_GT_GT_GT] = ACTIONS(5576),
    [anon_sym_EQ_EQ] = ACTIONS(5576),
    [anon_sym_BANG_EQ] = ACTIONS(5576),
    [anon_sym_GT_EQ] = ACTIONS(5576),
    [anon_sym_LT_EQ] = ACTIONS(5576),
    [anon_sym_DOT] = ACTIONS(5578),
    [anon_sym_EQ_GT] = ACTIONS(5576),
    [anon_sym_switch] = ACTIONS(5576),
    [anon_sym_DOT_DOT] = ACTIONS(5576),
    [anon_sym_and] = ACTIONS(5576),
    [anon_sym_or] = ACTIONS(5578),
    [anon_sym_AMP_AMP] = ACTIONS(5576),
    [anon_sym_PIPE_PIPE] = ACTIONS(5576),
    [anon_sym_QMARK_QMARK] = ACTIONS(5576),
    [anon_sym_from] = ACTIONS(5576),
    [anon_sym_join] = ACTIONS(5576),
    [anon_sym_on] = ACTIONS(5576),
    [anon_sym_equals] = ACTIONS(5576),
    [anon_sym_let] = ACTIONS(5576),
    [anon_sym_orderby] = ACTIONS(5576),
    [anon_sym_group] = ACTIONS(5576),
    [anon_sym_by] = ACTIONS(5576),
    [anon_sym_select] = ACTIONS(5576),
    [anon_sym_as] = ACTIONS(5576),
    [anon_sym_is] = ACTIONS(5576),
    [anon_sym_DASH_GT] = ACTIONS(5576),
    [anon_sym_with] = ACTIONS(5576),
    [aux_sym_preproc_if_token3] = ACTIONS(5576),
    [aux_sym_preproc_else_token1] = ACTIONS(5576),
    [aux_sym_preproc_elif_token1] = ACTIONS(5576),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3744] = {
    [sym_preproc_region] = STATE(3744),
    [sym_preproc_endregion] = STATE(3744),
    [sym_preproc_line] = STATE(3744),
    [sym_preproc_pragma] = STATE(3744),
    [sym_preproc_nullable] = STATE(3744),
    [sym_preproc_error] = STATE(3744),
    [sym_preproc_warning] = STATE(3744),
    [sym_preproc_define] = STATE(3744),
    [sym_preproc_undef] = STATE(3744),
    [anon_sym_SEMI] = ACTIONS(4494),
    [anon_sym_LBRACK] = ACTIONS(4593),
    [anon_sym_COMMA] = ACTIONS(4494),
    [anon_sym_RBRACK] = ACTIONS(4494),
    [anon_sym_LPAREN] = ACTIONS(4494),
    [anon_sym_RPAREN] = ACTIONS(4494),
    [anon_sym_LBRACE] = ACTIONS(4494),
    [anon_sym_RBRACE] = ACTIONS(4494),
    [anon_sym_LT] = ACTIONS(4492),
    [anon_sym_GT] = ACTIONS(4492),
    [anon_sym_in] = ACTIONS(4494),
    [anon_sym_where] = ACTIONS(4494),
    [anon_sym_QMARK] = ACTIONS(5405),
    [anon_sym_BANG] = ACTIONS(4492),
    [anon_sym_PLUS_PLUS] = ACTIONS(4494),
    [anon_sym_DASH_DASH] = ACTIONS(4494),
    [anon_sym_PLUS] = ACTIONS(4492),
    [anon_sym_DASH] = ACTIONS(4492),
    [anon_sym_STAR] = ACTIONS(4599),
    [anon_sym_SLASH] = ACTIONS(4492),
    [anon_sym_PERCENT] = ACTIONS(4494),
    [anon_sym_CARET] = ACTIONS(4494),
    [anon_sym_PIPE] = ACTIONS(4492),
    [anon_sym_AMP] = ACTIONS(4492),
    [anon_sym_LT_LT] = ACTIONS(4494),
    [anon_sym_GT_GT] = ACTIONS(4492),
    [anon_sym_GT_GT_GT] = ACTIONS(4494),
    [anon_sym_EQ_EQ] = ACTIONS(4494),
    [anon_sym_BANG_EQ] = ACTIONS(4494),
    [anon_sym_GT_EQ] = ACTIONS(4494),
    [anon_sym_LT_EQ] = ACTIONS(4494),
    [anon_sym_DOT] = ACTIONS(5709),
    [anon_sym_EQ_GT] = ACTIONS(4494),
    [anon_sym_switch] = ACTIONS(4494),
    [anon_sym_DOT_DOT] = ACTIONS(4494),
    [anon_sym_and] = ACTIONS(4494),
    [anon_sym_or] = ACTIONS(4492),
    [anon_sym_AMP_AMP] = ACTIONS(4494),
    [anon_sym_PIPE_PIPE] = ACTIONS(4494),
    [anon_sym_QMARK_QMARK] = ACTIONS(4494),
    [anon_sym_from] = ACTIONS(4494),
    [anon_sym_join] = ACTIONS(4494),
    [anon_sym_on] = ACTIONS(4494),
    [anon_sym_equals] = ACTIONS(4494),
    [anon_sym_let] = ACTIONS(4494),
    [anon_sym_orderby] = ACTIONS(4494),
    [anon_sym_group] = ACTIONS(4494),
    [anon_sym_by] = ACTIONS(4494),
    [anon_sym_select] = ACTIONS(4494),
    [anon_sym_as] = ACTIONS(4494),
    [anon_sym_is] = ACTIONS(4494),
    [anon_sym_DASH_GT] = ACTIONS(4494),
    [anon_sym_with] = ACTIONS(4494),
    [aux_sym_preproc_if_token3] = ACTIONS(4494),
    [aux_sym_preproc_else_token1] = ACTIONS(4494),
    [aux_sym_preproc_elif_token1] = ACTIONS(4494),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3745] = {
    [sym_preproc_region] = STATE(3745),
    [sym_preproc_endregion] = STATE(3745),
    [sym_preproc_line] = STATE(3745),
    [sym_preproc_pragma] = STATE(3745),
    [sym_preproc_nullable] = STATE(3745),
    [sym_preproc_error] = STATE(3745),
    [sym_preproc_warning] = STATE(3745),
    [sym_preproc_define] = STATE(3745),
    [sym_preproc_undef] = STATE(3745),
    [anon_sym_SEMI] = ACTIONS(5466),
    [anon_sym_LBRACK] = ACTIONS(5466),
    [anon_sym_COLON] = ACTIONS(5466),
    [anon_sym_COMMA] = ACTIONS(5466),
    [anon_sym_RBRACK] = ACTIONS(5466),
    [anon_sym_LPAREN] = ACTIONS(5466),
    [anon_sym_RPAREN] = ACTIONS(5466),
    [anon_sym_RBRACE] = ACTIONS(5466),
    [anon_sym_LT] = ACTIONS(5468),
    [anon_sym_GT] = ACTIONS(5468),
    [anon_sym_in] = ACTIONS(5466),
    [anon_sym_where] = ACTIONS(5466),
    [anon_sym_QMARK] = ACTIONS(5468),
    [anon_sym_BANG] = ACTIONS(5468),
    [anon_sym_PLUS_PLUS] = ACTIONS(5466),
    [anon_sym_DASH_DASH] = ACTIONS(5466),
    [anon_sym_PLUS] = ACTIONS(5468),
    [anon_sym_DASH] = ACTIONS(5468),
    [anon_sym_STAR] = ACTIONS(5466),
    [anon_sym_SLASH] = ACTIONS(5468),
    [anon_sym_PERCENT] = ACTIONS(5466),
    [anon_sym_CARET] = ACTIONS(5466),
    [anon_sym_PIPE] = ACTIONS(5468),
    [anon_sym_AMP] = ACTIONS(5468),
    [anon_sym_LT_LT] = ACTIONS(5466),
    [anon_sym_GT_GT] = ACTIONS(5468),
    [anon_sym_GT_GT_GT] = ACTIONS(5466),
    [anon_sym_EQ_EQ] = ACTIONS(5466),
    [anon_sym_BANG_EQ] = ACTIONS(5466),
    [anon_sym_GT_EQ] = ACTIONS(5466),
    [anon_sym_LT_EQ] = ACTIONS(5466),
    [anon_sym_DOT] = ACTIONS(5468),
    [anon_sym_EQ_GT] = ACTIONS(5466),
    [anon_sym_switch] = ACTIONS(5466),
    [anon_sym_DOT_DOT] = ACTIONS(5466),
    [anon_sym_and] = ACTIONS(5466),
    [anon_sym_or] = ACTIONS(5468),
    [anon_sym_AMP_AMP] = ACTIONS(5466),
    [anon_sym_PIPE_PIPE] = ACTIONS(5466),
    [anon_sym_QMARK_QMARK] = ACTIONS(5466),
    [anon_sym_from] = ACTIONS(5466),
    [anon_sym_join] = ACTIONS(5466),
    [anon_sym_on] = ACTIONS(5466),
    [anon_sym_equals] = ACTIONS(5466),
    [anon_sym_let] = ACTIONS(5466),
    [anon_sym_orderby] = ACTIONS(5466),
    [anon_sym_group] = ACTIONS(5466),
    [anon_sym_by] = ACTIONS(5466),
    [anon_sym_select] = ACTIONS(5466),
    [anon_sym_as] = ACTIONS(5466),
    [anon_sym_is] = ACTIONS(5466),
    [anon_sym_DASH_GT] = ACTIONS(5466),
    [anon_sym_with] = ACTIONS(5466),
    [aux_sym_preproc_if_token3] = ACTIONS(5466),
    [aux_sym_preproc_else_token1] = ACTIONS(5466),
    [aux_sym_preproc_elif_token1] = ACTIONS(5466),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3746] = {
    [sym_preproc_region] = STATE(3746),
    [sym_preproc_endregion] = STATE(3746),
    [sym_preproc_line] = STATE(3746),
    [sym_preproc_pragma] = STATE(3746),
    [sym_preproc_nullable] = STATE(3746),
    [sym_preproc_error] = STATE(3746),
    [sym_preproc_warning] = STATE(3746),
    [sym_preproc_define] = STATE(3746),
    [sym_preproc_undef] = STATE(3746),
    [sym__identifier_token] = ACTIONS(5711),
    [anon_sym_extern] = ACTIONS(5711),
    [anon_sym_alias] = ACTIONS(5711),
    [anon_sym_global] = ACTIONS(5711),
    [anon_sym_unsafe] = ACTIONS(5711),
    [anon_sym_static] = ACTIONS(5711),
    [anon_sym_LBRACK] = ACTIONS(5713),
    [anon_sym_LPAREN] = ACTIONS(5713),
    [anon_sym_event] = ACTIONS(5711),
    [anon_sym_class] = ACTIONS(5711),
    [anon_sym_ref] = ACTIONS(5711),
    [anon_sym_struct] = ACTIONS(5711),
    [anon_sym_enum] = ACTIONS(5711),
    [anon_sym_interface] = ACTIONS(5711),
    [anon_sym_delegate] = ACTIONS(5711),
    [anon_sym_record] = ACTIONS(5711),
    [anon_sym_abstract] = ACTIONS(5711),
    [anon_sym_async] = ACTIONS(5711),
    [anon_sym_const] = ACTIONS(5711),
    [anon_sym_file] = ACTIONS(5711),
    [anon_sym_fixed] = ACTIONS(5711),
    [anon_sym_internal] = ACTIONS(5711),
    [anon_sym_new] = ACTIONS(5711),
    [anon_sym_override] = ACTIONS(5711),
    [anon_sym_partial] = ACTIONS(5711),
    [anon_sym_private] = ACTIONS(5711),
    [anon_sym_protected] = ACTIONS(5711),
    [anon_sym_public] = ACTIONS(5711),
    [anon_sym_readonly] = ACTIONS(5711),
    [anon_sym_required] = ACTIONS(5711),
    [anon_sym_sealed] = ACTIONS(5711),
    [anon_sym_virtual] = ACTIONS(5711),
    [anon_sym_volatile] = ACTIONS(5711),
    [anon_sym_where] = ACTIONS(5711),
    [anon_sym_notnull] = ACTIONS(5711),
    [anon_sym_unmanaged] = ACTIONS(5711),
    [anon_sym_TILDE] = ACTIONS(5713),
    [anon_sym_implicit] = ACTIONS(5711),
    [anon_sym_explicit] = ACTIONS(5711),
    [anon_sym_scoped] = ACTIONS(5711),
    [anon_sym_var] = ACTIONS(5711),
    [sym_predefined_type] = ACTIONS(5711),
    [anon_sym_yield] = ACTIONS(5711),
    [anon_sym_when] = ACTIONS(5711),
    [anon_sym_from] = ACTIONS(5711),
    [anon_sym_into] = ACTIONS(5711),
    [anon_sym_join] = ACTIONS(5711),
    [anon_sym_on] = ACTIONS(5711),
    [anon_sym_equals] = ACTIONS(5711),
    [anon_sym_let] = ACTIONS(5711),
    [anon_sym_orderby] = ACTIONS(5711),
    [anon_sym_ascending] = ACTIONS(5711),
    [anon_sym_descending] = ACTIONS(5711),
    [anon_sym_group] = ACTIONS(5711),
    [anon_sym_by] = ACTIONS(5711),
    [anon_sym_select] = ACTIONS(5711),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3747] = {
    [sym_preproc_region] = STATE(3747),
    [sym_preproc_endregion] = STATE(3747),
    [sym_preproc_line] = STATE(3747),
    [sym_preproc_pragma] = STATE(3747),
    [sym_preproc_nullable] = STATE(3747),
    [sym_preproc_error] = STATE(3747),
    [sym_preproc_warning] = STATE(3747),
    [sym_preproc_define] = STATE(3747),
    [sym_preproc_undef] = STATE(3747),
    [anon_sym_SEMI] = ACTIONS(5486),
    [anon_sym_LBRACK] = ACTIONS(5486),
    [anon_sym_COLON] = ACTIONS(5486),
    [anon_sym_COMMA] = ACTIONS(5486),
    [anon_sym_RBRACK] = ACTIONS(5486),
    [anon_sym_LPAREN] = ACTIONS(5486),
    [anon_sym_RPAREN] = ACTIONS(5486),
    [anon_sym_RBRACE] = ACTIONS(5486),
    [anon_sym_LT] = ACTIONS(5488),
    [anon_sym_GT] = ACTIONS(5488),
    [anon_sym_in] = ACTIONS(5486),
    [anon_sym_where] = ACTIONS(5486),
    [anon_sym_QMARK] = ACTIONS(5488),
    [anon_sym_BANG] = ACTIONS(5488),
    [anon_sym_PLUS_PLUS] = ACTIONS(5486),
    [anon_sym_DASH_DASH] = ACTIONS(5486),
    [anon_sym_PLUS] = ACTIONS(5488),
    [anon_sym_DASH] = ACTIONS(5488),
    [anon_sym_STAR] = ACTIONS(5486),
    [anon_sym_SLASH] = ACTIONS(5488),
    [anon_sym_PERCENT] = ACTIONS(5486),
    [anon_sym_CARET] = ACTIONS(5486),
    [anon_sym_PIPE] = ACTIONS(5488),
    [anon_sym_AMP] = ACTIONS(5488),
    [anon_sym_LT_LT] = ACTIONS(5486),
    [anon_sym_GT_GT] = ACTIONS(5488),
    [anon_sym_GT_GT_GT] = ACTIONS(5486),
    [anon_sym_EQ_EQ] = ACTIONS(5486),
    [anon_sym_BANG_EQ] = ACTIONS(5486),
    [anon_sym_GT_EQ] = ACTIONS(5486),
    [anon_sym_LT_EQ] = ACTIONS(5486),
    [anon_sym_DOT] = ACTIONS(5488),
    [anon_sym_EQ_GT] = ACTIONS(5486),
    [anon_sym_switch] = ACTIONS(5486),
    [anon_sym_DOT_DOT] = ACTIONS(5486),
    [anon_sym_and] = ACTIONS(5486),
    [anon_sym_or] = ACTIONS(5488),
    [anon_sym_AMP_AMP] = ACTIONS(5486),
    [anon_sym_PIPE_PIPE] = ACTIONS(5486),
    [anon_sym_QMARK_QMARK] = ACTIONS(5486),
    [anon_sym_from] = ACTIONS(5486),
    [anon_sym_join] = ACTIONS(5486),
    [anon_sym_on] = ACTIONS(5486),
    [anon_sym_equals] = ACTIONS(5486),
    [anon_sym_let] = ACTIONS(5486),
    [anon_sym_orderby] = ACTIONS(5486),
    [anon_sym_group] = ACTIONS(5486),
    [anon_sym_by] = ACTIONS(5486),
    [anon_sym_select] = ACTIONS(5486),
    [anon_sym_as] = ACTIONS(5486),
    [anon_sym_is] = ACTIONS(5486),
    [anon_sym_DASH_GT] = ACTIONS(5486),
    [anon_sym_with] = ACTIONS(5486),
    [aux_sym_preproc_if_token3] = ACTIONS(5486),
    [aux_sym_preproc_else_token1] = ACTIONS(5486),
    [aux_sym_preproc_elif_token1] = ACTIONS(5486),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3748] = {
    [sym_preproc_region] = STATE(3748),
    [sym_preproc_endregion] = STATE(3748),
    [sym_preproc_line] = STATE(3748),
    [sym_preproc_pragma] = STATE(3748),
    [sym_preproc_nullable] = STATE(3748),
    [sym_preproc_error] = STATE(3748),
    [sym_preproc_warning] = STATE(3748),
    [sym_preproc_define] = STATE(3748),
    [sym_preproc_undef] = STATE(3748),
    [anon_sym_SEMI] = ACTIONS(4455),
    [anon_sym_LBRACK] = ACTIONS(4455),
    [anon_sym_COMMA] = ACTIONS(4455),
    [anon_sym_RBRACK] = ACTIONS(4455),
    [anon_sym_LPAREN] = ACTIONS(4455),
    [anon_sym_RPAREN] = ACTIONS(4455),
    [anon_sym_LBRACE] = ACTIONS(4455),
    [anon_sym_RBRACE] = ACTIONS(4455),
    [anon_sym_LT] = ACTIONS(4453),
    [anon_sym_GT] = ACTIONS(4453),
    [anon_sym_in] = ACTIONS(4455),
    [anon_sym_where] = ACTIONS(4455),
    [anon_sym_QMARK] = ACTIONS(4453),
    [anon_sym_BANG] = ACTIONS(4453),
    [anon_sym_PLUS_PLUS] = ACTIONS(4455),
    [anon_sym_DASH_DASH] = ACTIONS(4455),
    [anon_sym_PLUS] = ACTIONS(4453),
    [anon_sym_DASH] = ACTIONS(4453),
    [anon_sym_STAR] = ACTIONS(4455),
    [anon_sym_SLASH] = ACTIONS(4453),
    [anon_sym_PERCENT] = ACTIONS(4455),
    [anon_sym_CARET] = ACTIONS(4455),
    [anon_sym_PIPE] = ACTIONS(4453),
    [anon_sym_AMP] = ACTIONS(4453),
    [anon_sym_LT_LT] = ACTIONS(4455),
    [anon_sym_GT_GT] = ACTIONS(4453),
    [anon_sym_GT_GT_GT] = ACTIONS(4455),
    [anon_sym_EQ_EQ] = ACTIONS(4455),
    [anon_sym_BANG_EQ] = ACTIONS(4455),
    [anon_sym_GT_EQ] = ACTIONS(4455),
    [anon_sym_LT_EQ] = ACTIONS(4455),
    [anon_sym_DOT] = ACTIONS(5709),
    [anon_sym_EQ_GT] = ACTIONS(4455),
    [anon_sym_switch] = ACTIONS(4455),
    [anon_sym_DOT_DOT] = ACTIONS(4455),
    [anon_sym_and] = ACTIONS(4455),
    [anon_sym_or] = ACTIONS(4453),
    [anon_sym_AMP_AMP] = ACTIONS(4455),
    [anon_sym_PIPE_PIPE] = ACTIONS(4455),
    [anon_sym_QMARK_QMARK] = ACTIONS(4455),
    [anon_sym_from] = ACTIONS(4455),
    [anon_sym_join] = ACTIONS(4455),
    [anon_sym_on] = ACTIONS(4455),
    [anon_sym_equals] = ACTIONS(4455),
    [anon_sym_let] = ACTIONS(4455),
    [anon_sym_orderby] = ACTIONS(4455),
    [anon_sym_group] = ACTIONS(4455),
    [anon_sym_by] = ACTIONS(4455),
    [anon_sym_select] = ACTIONS(4455),
    [anon_sym_as] = ACTIONS(4455),
    [anon_sym_is] = ACTIONS(4455),
    [anon_sym_DASH_GT] = ACTIONS(4455),
    [anon_sym_with] = ACTIONS(4455),
    [aux_sym_preproc_if_token3] = ACTIONS(4455),
    [aux_sym_preproc_else_token1] = ACTIONS(4455),
    [aux_sym_preproc_elif_token1] = ACTIONS(4455),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3749] = {
    [sym_preproc_region] = STATE(3749),
    [sym_preproc_endregion] = STATE(3749),
    [sym_preproc_line] = STATE(3749),
    [sym_preproc_pragma] = STATE(3749),
    [sym_preproc_nullable] = STATE(3749),
    [sym_preproc_error] = STATE(3749),
    [sym_preproc_warning] = STATE(3749),
    [sym_preproc_define] = STATE(3749),
    [sym_preproc_undef] = STATE(3749),
    [anon_sym_SEMI] = ACTIONS(5494),
    [anon_sym_LBRACK] = ACTIONS(5494),
    [anon_sym_COLON] = ACTIONS(5494),
    [anon_sym_COMMA] = ACTIONS(5494),
    [anon_sym_RBRACK] = ACTIONS(5494),
    [anon_sym_LPAREN] = ACTIONS(5494),
    [anon_sym_RPAREN] = ACTIONS(5494),
    [anon_sym_RBRACE] = ACTIONS(5494),
    [anon_sym_LT] = ACTIONS(5496),
    [anon_sym_GT] = ACTIONS(5496),
    [anon_sym_in] = ACTIONS(5494),
    [anon_sym_where] = ACTIONS(5494),
    [anon_sym_QMARK] = ACTIONS(5496),
    [anon_sym_BANG] = ACTIONS(5496),
    [anon_sym_PLUS_PLUS] = ACTIONS(5494),
    [anon_sym_DASH_DASH] = ACTIONS(5494),
    [anon_sym_PLUS] = ACTIONS(5496),
    [anon_sym_DASH] = ACTIONS(5496),
    [anon_sym_STAR] = ACTIONS(5494),
    [anon_sym_SLASH] = ACTIONS(5496),
    [anon_sym_PERCENT] = ACTIONS(5494),
    [anon_sym_CARET] = ACTIONS(5494),
    [anon_sym_PIPE] = ACTIONS(5496),
    [anon_sym_AMP] = ACTIONS(5496),
    [anon_sym_LT_LT] = ACTIONS(5494),
    [anon_sym_GT_GT] = ACTIONS(5496),
    [anon_sym_GT_GT_GT] = ACTIONS(5494),
    [anon_sym_EQ_EQ] = ACTIONS(5494),
    [anon_sym_BANG_EQ] = ACTIONS(5494),
    [anon_sym_GT_EQ] = ACTIONS(5494),
    [anon_sym_LT_EQ] = ACTIONS(5494),
    [anon_sym_DOT] = ACTIONS(5496),
    [anon_sym_EQ_GT] = ACTIONS(5494),
    [anon_sym_switch] = ACTIONS(5494),
    [anon_sym_DOT_DOT] = ACTIONS(5494),
    [anon_sym_and] = ACTIONS(5494),
    [anon_sym_or] = ACTIONS(5496),
    [anon_sym_AMP_AMP] = ACTIONS(5494),
    [anon_sym_PIPE_PIPE] = ACTIONS(5494),
    [anon_sym_QMARK_QMARK] = ACTIONS(5494),
    [anon_sym_from] = ACTIONS(5494),
    [anon_sym_join] = ACTIONS(5494),
    [anon_sym_on] = ACTIONS(5494),
    [anon_sym_equals] = ACTIONS(5494),
    [anon_sym_let] = ACTIONS(5494),
    [anon_sym_orderby] = ACTIONS(5494),
    [anon_sym_group] = ACTIONS(5494),
    [anon_sym_by] = ACTIONS(5494),
    [anon_sym_select] = ACTIONS(5494),
    [anon_sym_as] = ACTIONS(5494),
    [anon_sym_is] = ACTIONS(5494),
    [anon_sym_DASH_GT] = ACTIONS(5494),
    [anon_sym_with] = ACTIONS(5494),
    [aux_sym_preproc_if_token3] = ACTIONS(5494),
    [aux_sym_preproc_else_token1] = ACTIONS(5494),
    [aux_sym_preproc_elif_token1] = ACTIONS(5494),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3750] = {
    [sym_preproc_region] = STATE(3750),
    [sym_preproc_endregion] = STATE(3750),
    [sym_preproc_line] = STATE(3750),
    [sym_preproc_pragma] = STATE(3750),
    [sym_preproc_nullable] = STATE(3750),
    [sym_preproc_error] = STATE(3750),
    [sym_preproc_warning] = STATE(3750),
    [sym_preproc_define] = STATE(3750),
    [sym_preproc_undef] = STATE(3750),
    [anon_sym_SEMI] = ACTIONS(5502),
    [anon_sym_LBRACK] = ACTIONS(5502),
    [anon_sym_COLON] = ACTIONS(5502),
    [anon_sym_COMMA] = ACTIONS(5502),
    [anon_sym_RBRACK] = ACTIONS(5502),
    [anon_sym_LPAREN] = ACTIONS(5502),
    [anon_sym_RPAREN] = ACTIONS(5502),
    [anon_sym_RBRACE] = ACTIONS(5502),
    [anon_sym_LT] = ACTIONS(5504),
    [anon_sym_GT] = ACTIONS(5504),
    [anon_sym_in] = ACTIONS(5502),
    [anon_sym_where] = ACTIONS(5502),
    [anon_sym_QMARK] = ACTIONS(5504),
    [anon_sym_BANG] = ACTIONS(5504),
    [anon_sym_PLUS_PLUS] = ACTIONS(5502),
    [anon_sym_DASH_DASH] = ACTIONS(5502),
    [anon_sym_PLUS] = ACTIONS(5504),
    [anon_sym_DASH] = ACTIONS(5504),
    [anon_sym_STAR] = ACTIONS(5502),
    [anon_sym_SLASH] = ACTIONS(5504),
    [anon_sym_PERCENT] = ACTIONS(5502),
    [anon_sym_CARET] = ACTIONS(5502),
    [anon_sym_PIPE] = ACTIONS(5504),
    [anon_sym_AMP] = ACTIONS(5504),
    [anon_sym_LT_LT] = ACTIONS(5502),
    [anon_sym_GT_GT] = ACTIONS(5504),
    [anon_sym_GT_GT_GT] = ACTIONS(5502),
    [anon_sym_EQ_EQ] = ACTIONS(5502),
    [anon_sym_BANG_EQ] = ACTIONS(5502),
    [anon_sym_GT_EQ] = ACTIONS(5502),
    [anon_sym_LT_EQ] = ACTIONS(5502),
    [anon_sym_DOT] = ACTIONS(5504),
    [anon_sym_EQ_GT] = ACTIONS(5502),
    [anon_sym_switch] = ACTIONS(5502),
    [anon_sym_DOT_DOT] = ACTIONS(5502),
    [anon_sym_and] = ACTIONS(5502),
    [anon_sym_or] = ACTIONS(5504),
    [anon_sym_AMP_AMP] = ACTIONS(5502),
    [anon_sym_PIPE_PIPE] = ACTIONS(5502),
    [anon_sym_QMARK_QMARK] = ACTIONS(5502),
    [anon_sym_from] = ACTIONS(5502),
    [anon_sym_join] = ACTIONS(5502),
    [anon_sym_on] = ACTIONS(5502),
    [anon_sym_equals] = ACTIONS(5502),
    [anon_sym_let] = ACTIONS(5502),
    [anon_sym_orderby] = ACTIONS(5502),
    [anon_sym_group] = ACTIONS(5502),
    [anon_sym_by] = ACTIONS(5502),
    [anon_sym_select] = ACTIONS(5502),
    [anon_sym_as] = ACTIONS(5502),
    [anon_sym_is] = ACTIONS(5502),
    [anon_sym_DASH_GT] = ACTIONS(5502),
    [anon_sym_with] = ACTIONS(5502),
    [aux_sym_preproc_if_token3] = ACTIONS(5502),
    [aux_sym_preproc_else_token1] = ACTIONS(5502),
    [aux_sym_preproc_elif_token1] = ACTIONS(5502),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3751] = {
    [sym_preproc_region] = STATE(3751),
    [sym_preproc_endregion] = STATE(3751),
    [sym_preproc_line] = STATE(3751),
    [sym_preproc_pragma] = STATE(3751),
    [sym_preproc_nullable] = STATE(3751),
    [sym_preproc_error] = STATE(3751),
    [sym_preproc_warning] = STATE(3751),
    [sym_preproc_define] = STATE(3751),
    [sym_preproc_undef] = STATE(3751),
    [anon_sym_SEMI] = ACTIONS(5530),
    [anon_sym_LBRACK] = ACTIONS(5530),
    [anon_sym_COLON] = ACTIONS(5530),
    [anon_sym_COMMA] = ACTIONS(5530),
    [anon_sym_RBRACK] = ACTIONS(5530),
    [anon_sym_LPAREN] = ACTIONS(5530),
    [anon_sym_RPAREN] = ACTIONS(5530),
    [anon_sym_RBRACE] = ACTIONS(5530),
    [anon_sym_LT] = ACTIONS(5532),
    [anon_sym_GT] = ACTIONS(5532),
    [anon_sym_in] = ACTIONS(5530),
    [anon_sym_where] = ACTIONS(5530),
    [anon_sym_QMARK] = ACTIONS(5532),
    [anon_sym_BANG] = ACTIONS(5532),
    [anon_sym_PLUS_PLUS] = ACTIONS(5530),
    [anon_sym_DASH_DASH] = ACTIONS(5530),
    [anon_sym_PLUS] = ACTIONS(5532),
    [anon_sym_DASH] = ACTIONS(5532),
    [anon_sym_STAR] = ACTIONS(5530),
    [anon_sym_SLASH] = ACTIONS(5532),
    [anon_sym_PERCENT] = ACTIONS(5530),
    [anon_sym_CARET] = ACTIONS(5530),
    [anon_sym_PIPE] = ACTIONS(5532),
    [anon_sym_AMP] = ACTIONS(5532),
    [anon_sym_LT_LT] = ACTIONS(5530),
    [anon_sym_GT_GT] = ACTIONS(5532),
    [anon_sym_GT_GT_GT] = ACTIONS(5530),
    [anon_sym_EQ_EQ] = ACTIONS(5530),
    [anon_sym_BANG_EQ] = ACTIONS(5530),
    [anon_sym_GT_EQ] = ACTIONS(5530),
    [anon_sym_LT_EQ] = ACTIONS(5530),
    [anon_sym_DOT] = ACTIONS(5532),
    [anon_sym_EQ_GT] = ACTIONS(5530),
    [anon_sym_switch] = ACTIONS(5530),
    [anon_sym_DOT_DOT] = ACTIONS(5530),
    [anon_sym_and] = ACTIONS(5530),
    [anon_sym_or] = ACTIONS(5532),
    [anon_sym_AMP_AMP] = ACTIONS(5530),
    [anon_sym_PIPE_PIPE] = ACTIONS(5530),
    [anon_sym_QMARK_QMARK] = ACTIONS(5530),
    [anon_sym_from] = ACTIONS(5530),
    [anon_sym_join] = ACTIONS(5530),
    [anon_sym_on] = ACTIONS(5530),
    [anon_sym_equals] = ACTIONS(5530),
    [anon_sym_let] = ACTIONS(5530),
    [anon_sym_orderby] = ACTIONS(5530),
    [anon_sym_group] = ACTIONS(5530),
    [anon_sym_by] = ACTIONS(5530),
    [anon_sym_select] = ACTIONS(5530),
    [anon_sym_as] = ACTIONS(5530),
    [anon_sym_is] = ACTIONS(5530),
    [anon_sym_DASH_GT] = ACTIONS(5530),
    [anon_sym_with] = ACTIONS(5530),
    [aux_sym_preproc_if_token3] = ACTIONS(5530),
    [aux_sym_preproc_else_token1] = ACTIONS(5530),
    [aux_sym_preproc_elif_token1] = ACTIONS(5530),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3752] = {
    [sym_preproc_region] = STATE(3752),
    [sym_preproc_endregion] = STATE(3752),
    [sym_preproc_line] = STATE(3752),
    [sym_preproc_pragma] = STATE(3752),
    [sym_preproc_nullable] = STATE(3752),
    [sym_preproc_error] = STATE(3752),
    [sym_preproc_warning] = STATE(3752),
    [sym_preproc_define] = STATE(3752),
    [sym_preproc_undef] = STATE(3752),
    [anon_sym_SEMI] = ACTIONS(5286),
    [anon_sym_EQ] = ACTIONS(5715),
    [anon_sym_LBRACK] = ACTIONS(5286),
    [anon_sym_COMMA] = ACTIONS(5286),
    [anon_sym_RBRACK] = ACTIONS(5286),
    [anon_sym_LPAREN] = ACTIONS(5286),
    [anon_sym_RPAREN] = ACTIONS(5286),
    [anon_sym_RBRACE] = ACTIONS(5286),
    [anon_sym_LT] = ACTIONS(5288),
    [anon_sym_GT] = ACTIONS(5288),
    [anon_sym_in] = ACTIONS(5288),
    [anon_sym_QMARK] = ACTIONS(5288),
    [anon_sym_BANG] = ACTIONS(5288),
    [anon_sym_PLUS_PLUS] = ACTIONS(5286),
    [anon_sym_DASH_DASH] = ACTIONS(5286),
    [anon_sym_PLUS] = ACTIONS(5288),
    [anon_sym_DASH] = ACTIONS(5288),
    [anon_sym_STAR] = ACTIONS(5288),
    [anon_sym_SLASH] = ACTIONS(5288),
    [anon_sym_PERCENT] = ACTIONS(5288),
    [anon_sym_CARET] = ACTIONS(5288),
    [anon_sym_PIPE] = ACTIONS(5288),
    [anon_sym_AMP] = ACTIONS(5288),
    [anon_sym_LT_LT] = ACTIONS(5288),
    [anon_sym_GT_GT] = ACTIONS(5288),
    [anon_sym_GT_GT_GT] = ACTIONS(5288),
    [anon_sym_EQ_EQ] = ACTIONS(5286),
    [anon_sym_BANG_EQ] = ACTIONS(5286),
    [anon_sym_GT_EQ] = ACTIONS(5286),
    [anon_sym_LT_EQ] = ACTIONS(5286),
    [anon_sym_DOT] = ACTIONS(5288),
    [anon_sym_switch] = ACTIONS(5286),
    [anon_sym_DOT_DOT] = ACTIONS(5286),
    [anon_sym_PLUS_EQ] = ACTIONS(5717),
    [anon_sym_DASH_EQ] = ACTIONS(5717),
    [anon_sym_STAR_EQ] = ACTIONS(5717),
    [anon_sym_SLASH_EQ] = ACTIONS(5717),
    [anon_sym_PERCENT_EQ] = ACTIONS(5717),
    [anon_sym_AMP_EQ] = ACTIONS(5717),
    [anon_sym_CARET_EQ] = ACTIONS(5717),
    [anon_sym_PIPE_EQ] = ACTIONS(5717),
    [anon_sym_LT_LT_EQ] = ACTIONS(5717),
    [anon_sym_GT_GT_EQ] = ACTIONS(5717),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(5717),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(5717),
    [anon_sym_AMP_AMP] = ACTIONS(5286),
    [anon_sym_PIPE_PIPE] = ACTIONS(5286),
    [anon_sym_QMARK_QMARK] = ACTIONS(5288),
    [anon_sym_into] = ACTIONS(5286),
    [anon_sym_as] = ACTIONS(5286),
    [anon_sym_is] = ACTIONS(5286),
    [anon_sym_DASH_GT] = ACTIONS(5286),
    [anon_sym_with] = ACTIONS(5286),
    [aux_sym_preproc_if_token3] = ACTIONS(5286),
    [aux_sym_preproc_else_token1] = ACTIONS(5286),
    [aux_sym_preproc_elif_token1] = ACTIONS(5286),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3753] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter] = STATE(8492),
    [sym__parameter_array] = STATE(8493),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7375),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(6760),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3753),
    [sym_preproc_endregion] = STATE(3753),
    [sym_preproc_line] = STATE(3753),
    [sym_preproc_pragma] = STATE(3753),
    [sym_preproc_nullable] = STATE(3753),
    [sym_preproc_error] = STATE(3753),
    [sym_preproc_warning] = STATE(3753),
    [sym_preproc_define] = STATE(3753),
    [sym_preproc_undef] = STATE(3753),
    [aux_sym_class_declaration_repeat1] = STATE(3802),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4294),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LBRACK] = ACTIONS(5307),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(5309),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_in] = ACTIONS(1113),
    [anon_sym_out] = ACTIONS(1113),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_this] = ACTIONS(1113),
    [anon_sym_scoped] = ACTIONS(5321),
    [anon_sym_params] = ACTIONS(1127),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3754] = {
    [sym_preproc_region] = STATE(3754),
    [sym_preproc_endregion] = STATE(3754),
    [sym_preproc_line] = STATE(3754),
    [sym_preproc_pragma] = STATE(3754),
    [sym_preproc_nullable] = STATE(3754),
    [sym_preproc_error] = STATE(3754),
    [sym_preproc_warning] = STATE(3754),
    [sym_preproc_define] = STATE(3754),
    [sym_preproc_undef] = STATE(3754),
    [anon_sym_SEMI] = ACTIONS(5624),
    [anon_sym_LBRACK] = ACTIONS(5624),
    [anon_sym_COLON] = ACTIONS(5624),
    [anon_sym_COMMA] = ACTIONS(5624),
    [anon_sym_RBRACK] = ACTIONS(5624),
    [anon_sym_LPAREN] = ACTIONS(5624),
    [anon_sym_RPAREN] = ACTIONS(5624),
    [anon_sym_RBRACE] = ACTIONS(5624),
    [anon_sym_LT] = ACTIONS(5626),
    [anon_sym_GT] = ACTIONS(5626),
    [anon_sym_in] = ACTIONS(5624),
    [anon_sym_where] = ACTIONS(5624),
    [anon_sym_QMARK] = ACTIONS(5626),
    [anon_sym_BANG] = ACTIONS(5626),
    [anon_sym_PLUS_PLUS] = ACTIONS(5624),
    [anon_sym_DASH_DASH] = ACTIONS(5624),
    [anon_sym_PLUS] = ACTIONS(5626),
    [anon_sym_DASH] = ACTIONS(5626),
    [anon_sym_STAR] = ACTIONS(5624),
    [anon_sym_SLASH] = ACTIONS(5626),
    [anon_sym_PERCENT] = ACTIONS(5624),
    [anon_sym_CARET] = ACTIONS(5624),
    [anon_sym_PIPE] = ACTIONS(5626),
    [anon_sym_AMP] = ACTIONS(5626),
    [anon_sym_LT_LT] = ACTIONS(5624),
    [anon_sym_GT_GT] = ACTIONS(5626),
    [anon_sym_GT_GT_GT] = ACTIONS(5624),
    [anon_sym_EQ_EQ] = ACTIONS(5624),
    [anon_sym_BANG_EQ] = ACTIONS(5624),
    [anon_sym_GT_EQ] = ACTIONS(5624),
    [anon_sym_LT_EQ] = ACTIONS(5624),
    [anon_sym_DOT] = ACTIONS(5626),
    [anon_sym_EQ_GT] = ACTIONS(5624),
    [anon_sym_switch] = ACTIONS(5624),
    [anon_sym_DOT_DOT] = ACTIONS(5624),
    [anon_sym_and] = ACTIONS(5624),
    [anon_sym_or] = ACTIONS(5626),
    [anon_sym_AMP_AMP] = ACTIONS(5624),
    [anon_sym_PIPE_PIPE] = ACTIONS(5624),
    [anon_sym_QMARK_QMARK] = ACTIONS(5624),
    [anon_sym_from] = ACTIONS(5624),
    [anon_sym_join] = ACTIONS(5624),
    [anon_sym_on] = ACTIONS(5624),
    [anon_sym_equals] = ACTIONS(5624),
    [anon_sym_let] = ACTIONS(5624),
    [anon_sym_orderby] = ACTIONS(5624),
    [anon_sym_group] = ACTIONS(5624),
    [anon_sym_by] = ACTIONS(5624),
    [anon_sym_select] = ACTIONS(5624),
    [anon_sym_as] = ACTIONS(5624),
    [anon_sym_is] = ACTIONS(5624),
    [anon_sym_DASH_GT] = ACTIONS(5624),
    [anon_sym_with] = ACTIONS(5624),
    [aux_sym_preproc_if_token3] = ACTIONS(5624),
    [aux_sym_preproc_else_token1] = ACTIONS(5624),
    [aux_sym_preproc_elif_token1] = ACTIONS(5624),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3755] = {
    [sym_preproc_region] = STATE(3755),
    [sym_preproc_endregion] = STATE(3755),
    [sym_preproc_line] = STATE(3755),
    [sym_preproc_pragma] = STATE(3755),
    [sym_preproc_nullable] = STATE(3755),
    [sym_preproc_error] = STATE(3755),
    [sym_preproc_warning] = STATE(3755),
    [sym_preproc_define] = STATE(3755),
    [sym_preproc_undef] = STATE(3755),
    [anon_sym_SEMI] = ACTIONS(5544),
    [anon_sym_LBRACK] = ACTIONS(5544),
    [anon_sym_COLON] = ACTIONS(5544),
    [anon_sym_COMMA] = ACTIONS(5544),
    [anon_sym_RBRACK] = ACTIONS(5544),
    [anon_sym_LPAREN] = ACTIONS(5544),
    [anon_sym_RPAREN] = ACTIONS(5544),
    [anon_sym_RBRACE] = ACTIONS(5544),
    [anon_sym_LT] = ACTIONS(5546),
    [anon_sym_GT] = ACTIONS(5546),
    [anon_sym_in] = ACTIONS(5544),
    [anon_sym_where] = ACTIONS(5544),
    [anon_sym_QMARK] = ACTIONS(5546),
    [anon_sym_BANG] = ACTIONS(5546),
    [anon_sym_PLUS_PLUS] = ACTIONS(5544),
    [anon_sym_DASH_DASH] = ACTIONS(5544),
    [anon_sym_PLUS] = ACTIONS(5546),
    [anon_sym_DASH] = ACTIONS(5546),
    [anon_sym_STAR] = ACTIONS(5544),
    [anon_sym_SLASH] = ACTIONS(5546),
    [anon_sym_PERCENT] = ACTIONS(5544),
    [anon_sym_CARET] = ACTIONS(5544),
    [anon_sym_PIPE] = ACTIONS(5546),
    [anon_sym_AMP] = ACTIONS(5546),
    [anon_sym_LT_LT] = ACTIONS(5544),
    [anon_sym_GT_GT] = ACTIONS(5546),
    [anon_sym_GT_GT_GT] = ACTIONS(5544),
    [anon_sym_EQ_EQ] = ACTIONS(5544),
    [anon_sym_BANG_EQ] = ACTIONS(5544),
    [anon_sym_GT_EQ] = ACTIONS(5544),
    [anon_sym_LT_EQ] = ACTIONS(5544),
    [anon_sym_DOT] = ACTIONS(5546),
    [anon_sym_EQ_GT] = ACTIONS(5544),
    [anon_sym_switch] = ACTIONS(5544),
    [anon_sym_DOT_DOT] = ACTIONS(5544),
    [anon_sym_and] = ACTIONS(5544),
    [anon_sym_or] = ACTIONS(5546),
    [anon_sym_AMP_AMP] = ACTIONS(5544),
    [anon_sym_PIPE_PIPE] = ACTIONS(5544),
    [anon_sym_QMARK_QMARK] = ACTIONS(5544),
    [anon_sym_from] = ACTIONS(5544),
    [anon_sym_join] = ACTIONS(5544),
    [anon_sym_on] = ACTIONS(5544),
    [anon_sym_equals] = ACTIONS(5544),
    [anon_sym_let] = ACTIONS(5544),
    [anon_sym_orderby] = ACTIONS(5544),
    [anon_sym_group] = ACTIONS(5544),
    [anon_sym_by] = ACTIONS(5544),
    [anon_sym_select] = ACTIONS(5544),
    [anon_sym_as] = ACTIONS(5544),
    [anon_sym_is] = ACTIONS(5544),
    [anon_sym_DASH_GT] = ACTIONS(5544),
    [anon_sym_with] = ACTIONS(5544),
    [aux_sym_preproc_if_token3] = ACTIONS(5544),
    [aux_sym_preproc_else_token1] = ACTIONS(5544),
    [aux_sym_preproc_elif_token1] = ACTIONS(5544),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3756] = {
    [sym_preproc_region] = STATE(3756),
    [sym_preproc_endregion] = STATE(3756),
    [sym_preproc_line] = STATE(3756),
    [sym_preproc_pragma] = STATE(3756),
    [sym_preproc_nullable] = STATE(3756),
    [sym_preproc_error] = STATE(3756),
    [sym_preproc_warning] = STATE(3756),
    [sym_preproc_define] = STATE(3756),
    [sym_preproc_undef] = STATE(3756),
    [anon_sym_SEMI] = ACTIONS(5534),
    [anon_sym_LBRACK] = ACTIONS(5534),
    [anon_sym_COLON] = ACTIONS(5534),
    [anon_sym_COMMA] = ACTIONS(5534),
    [anon_sym_RBRACK] = ACTIONS(5534),
    [anon_sym_LPAREN] = ACTIONS(5534),
    [anon_sym_RPAREN] = ACTIONS(5534),
    [anon_sym_RBRACE] = ACTIONS(5534),
    [anon_sym_LT] = ACTIONS(5536),
    [anon_sym_GT] = ACTIONS(5536),
    [anon_sym_in] = ACTIONS(5534),
    [anon_sym_where] = ACTIONS(5534),
    [anon_sym_QMARK] = ACTIONS(5536),
    [anon_sym_BANG] = ACTIONS(5536),
    [anon_sym_PLUS_PLUS] = ACTIONS(5534),
    [anon_sym_DASH_DASH] = ACTIONS(5534),
    [anon_sym_PLUS] = ACTIONS(5536),
    [anon_sym_DASH] = ACTIONS(5536),
    [anon_sym_STAR] = ACTIONS(5534),
    [anon_sym_SLASH] = ACTIONS(5536),
    [anon_sym_PERCENT] = ACTIONS(5534),
    [anon_sym_CARET] = ACTIONS(5534),
    [anon_sym_PIPE] = ACTIONS(5536),
    [anon_sym_AMP] = ACTIONS(5536),
    [anon_sym_LT_LT] = ACTIONS(5534),
    [anon_sym_GT_GT] = ACTIONS(5536),
    [anon_sym_GT_GT_GT] = ACTIONS(5534),
    [anon_sym_EQ_EQ] = ACTIONS(5534),
    [anon_sym_BANG_EQ] = ACTIONS(5534),
    [anon_sym_GT_EQ] = ACTIONS(5534),
    [anon_sym_LT_EQ] = ACTIONS(5534),
    [anon_sym_DOT] = ACTIONS(5536),
    [anon_sym_EQ_GT] = ACTIONS(5534),
    [anon_sym_switch] = ACTIONS(5534),
    [anon_sym_DOT_DOT] = ACTIONS(5534),
    [anon_sym_and] = ACTIONS(5534),
    [anon_sym_or] = ACTIONS(5536),
    [anon_sym_AMP_AMP] = ACTIONS(5534),
    [anon_sym_PIPE_PIPE] = ACTIONS(5534),
    [anon_sym_QMARK_QMARK] = ACTIONS(5534),
    [anon_sym_from] = ACTIONS(5534),
    [anon_sym_join] = ACTIONS(5534),
    [anon_sym_on] = ACTIONS(5534),
    [anon_sym_equals] = ACTIONS(5534),
    [anon_sym_let] = ACTIONS(5534),
    [anon_sym_orderby] = ACTIONS(5534),
    [anon_sym_group] = ACTIONS(5534),
    [anon_sym_by] = ACTIONS(5534),
    [anon_sym_select] = ACTIONS(5534),
    [anon_sym_as] = ACTIONS(5534),
    [anon_sym_is] = ACTIONS(5534),
    [anon_sym_DASH_GT] = ACTIONS(5534),
    [anon_sym_with] = ACTIONS(5534),
    [aux_sym_preproc_if_token3] = ACTIONS(5534),
    [aux_sym_preproc_else_token1] = ACTIONS(5534),
    [aux_sym_preproc_elif_token1] = ACTIONS(5534),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3757] = {
    [sym_preproc_region] = STATE(3757),
    [sym_preproc_endregion] = STATE(3757),
    [sym_preproc_line] = STATE(3757),
    [sym_preproc_pragma] = STATE(3757),
    [sym_preproc_nullable] = STATE(3757),
    [sym_preproc_error] = STATE(3757),
    [sym_preproc_warning] = STATE(3757),
    [sym_preproc_define] = STATE(3757),
    [sym_preproc_undef] = STATE(3757),
    [anon_sym_SEMI] = ACTIONS(5632),
    [anon_sym_LBRACK] = ACTIONS(5632),
    [anon_sym_COLON] = ACTIONS(5632),
    [anon_sym_COMMA] = ACTIONS(5632),
    [anon_sym_RBRACK] = ACTIONS(5632),
    [anon_sym_LPAREN] = ACTIONS(5632),
    [anon_sym_RPAREN] = ACTIONS(5632),
    [anon_sym_RBRACE] = ACTIONS(5632),
    [anon_sym_LT] = ACTIONS(5634),
    [anon_sym_GT] = ACTIONS(5634),
    [anon_sym_in] = ACTIONS(5632),
    [anon_sym_where] = ACTIONS(5632),
    [anon_sym_QMARK] = ACTIONS(5634),
    [anon_sym_BANG] = ACTIONS(5634),
    [anon_sym_PLUS_PLUS] = ACTIONS(5632),
    [anon_sym_DASH_DASH] = ACTIONS(5632),
    [anon_sym_PLUS] = ACTIONS(5634),
    [anon_sym_DASH] = ACTIONS(5634),
    [anon_sym_STAR] = ACTIONS(5632),
    [anon_sym_SLASH] = ACTIONS(5634),
    [anon_sym_PERCENT] = ACTIONS(5632),
    [anon_sym_CARET] = ACTIONS(5632),
    [anon_sym_PIPE] = ACTIONS(5634),
    [anon_sym_AMP] = ACTIONS(5634),
    [anon_sym_LT_LT] = ACTIONS(5632),
    [anon_sym_GT_GT] = ACTIONS(5634),
    [anon_sym_GT_GT_GT] = ACTIONS(5632),
    [anon_sym_EQ_EQ] = ACTIONS(5632),
    [anon_sym_BANG_EQ] = ACTIONS(5632),
    [anon_sym_GT_EQ] = ACTIONS(5632),
    [anon_sym_LT_EQ] = ACTIONS(5632),
    [anon_sym_DOT] = ACTIONS(5634),
    [anon_sym_EQ_GT] = ACTIONS(5632),
    [anon_sym_switch] = ACTIONS(5632),
    [anon_sym_DOT_DOT] = ACTIONS(5632),
    [anon_sym_and] = ACTIONS(5632),
    [anon_sym_or] = ACTIONS(5634),
    [anon_sym_AMP_AMP] = ACTIONS(5632),
    [anon_sym_PIPE_PIPE] = ACTIONS(5632),
    [anon_sym_QMARK_QMARK] = ACTIONS(5632),
    [anon_sym_from] = ACTIONS(5632),
    [anon_sym_join] = ACTIONS(5632),
    [anon_sym_on] = ACTIONS(5632),
    [anon_sym_equals] = ACTIONS(5632),
    [anon_sym_let] = ACTIONS(5632),
    [anon_sym_orderby] = ACTIONS(5632),
    [anon_sym_group] = ACTIONS(5632),
    [anon_sym_by] = ACTIONS(5632),
    [anon_sym_select] = ACTIONS(5632),
    [anon_sym_as] = ACTIONS(5632),
    [anon_sym_is] = ACTIONS(5632),
    [anon_sym_DASH_GT] = ACTIONS(5632),
    [anon_sym_with] = ACTIONS(5632),
    [aux_sym_preproc_if_token3] = ACTIONS(5632),
    [aux_sym_preproc_else_token1] = ACTIONS(5632),
    [aux_sym_preproc_elif_token1] = ACTIONS(5632),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3758] = {
    [sym_preproc_region] = STATE(3758),
    [sym_preproc_endregion] = STATE(3758),
    [sym_preproc_line] = STATE(3758),
    [sym_preproc_pragma] = STATE(3758),
    [sym_preproc_nullable] = STATE(3758),
    [sym_preproc_error] = STATE(3758),
    [sym_preproc_warning] = STATE(3758),
    [sym_preproc_define] = STATE(3758),
    [sym_preproc_undef] = STATE(3758),
    [anon_sym_SEMI] = ACTIONS(5640),
    [anon_sym_LBRACK] = ACTIONS(5640),
    [anon_sym_COLON] = ACTIONS(5640),
    [anon_sym_COMMA] = ACTIONS(5640),
    [anon_sym_RBRACK] = ACTIONS(5640),
    [anon_sym_LPAREN] = ACTIONS(5640),
    [anon_sym_RPAREN] = ACTIONS(5640),
    [anon_sym_RBRACE] = ACTIONS(5640),
    [anon_sym_LT] = ACTIONS(5642),
    [anon_sym_GT] = ACTIONS(5642),
    [anon_sym_in] = ACTIONS(5640),
    [anon_sym_where] = ACTIONS(5640),
    [anon_sym_QMARK] = ACTIONS(5642),
    [anon_sym_BANG] = ACTIONS(5642),
    [anon_sym_PLUS_PLUS] = ACTIONS(5640),
    [anon_sym_DASH_DASH] = ACTIONS(5640),
    [anon_sym_PLUS] = ACTIONS(5642),
    [anon_sym_DASH] = ACTIONS(5642),
    [anon_sym_STAR] = ACTIONS(5640),
    [anon_sym_SLASH] = ACTIONS(5642),
    [anon_sym_PERCENT] = ACTIONS(5640),
    [anon_sym_CARET] = ACTIONS(5640),
    [anon_sym_PIPE] = ACTIONS(5642),
    [anon_sym_AMP] = ACTIONS(5642),
    [anon_sym_LT_LT] = ACTIONS(5640),
    [anon_sym_GT_GT] = ACTIONS(5642),
    [anon_sym_GT_GT_GT] = ACTIONS(5640),
    [anon_sym_EQ_EQ] = ACTIONS(5640),
    [anon_sym_BANG_EQ] = ACTIONS(5640),
    [anon_sym_GT_EQ] = ACTIONS(5640),
    [anon_sym_LT_EQ] = ACTIONS(5640),
    [anon_sym_DOT] = ACTIONS(5642),
    [anon_sym_EQ_GT] = ACTIONS(5640),
    [anon_sym_switch] = ACTIONS(5640),
    [anon_sym_DOT_DOT] = ACTIONS(5640),
    [anon_sym_and] = ACTIONS(5640),
    [anon_sym_or] = ACTIONS(5642),
    [anon_sym_AMP_AMP] = ACTIONS(5640),
    [anon_sym_PIPE_PIPE] = ACTIONS(5640),
    [anon_sym_QMARK_QMARK] = ACTIONS(5640),
    [anon_sym_from] = ACTIONS(5640),
    [anon_sym_join] = ACTIONS(5640),
    [anon_sym_on] = ACTIONS(5640),
    [anon_sym_equals] = ACTIONS(5640),
    [anon_sym_let] = ACTIONS(5640),
    [anon_sym_orderby] = ACTIONS(5640),
    [anon_sym_group] = ACTIONS(5640),
    [anon_sym_by] = ACTIONS(5640),
    [anon_sym_select] = ACTIONS(5640),
    [anon_sym_as] = ACTIONS(5640),
    [anon_sym_is] = ACTIONS(5640),
    [anon_sym_DASH_GT] = ACTIONS(5640),
    [anon_sym_with] = ACTIONS(5640),
    [aux_sym_preproc_if_token3] = ACTIONS(5640),
    [aux_sym_preproc_else_token1] = ACTIONS(5640),
    [aux_sym_preproc_elif_token1] = ACTIONS(5640),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3759] = {
    [sym_preproc_region] = STATE(3759),
    [sym_preproc_endregion] = STATE(3759),
    [sym_preproc_line] = STATE(3759),
    [sym_preproc_pragma] = STATE(3759),
    [sym_preproc_nullable] = STATE(3759),
    [sym_preproc_error] = STATE(3759),
    [sym_preproc_warning] = STATE(3759),
    [sym_preproc_define] = STATE(3759),
    [sym_preproc_undef] = STATE(3759),
    [anon_sym_SEMI] = ACTIONS(5526),
    [anon_sym_LBRACK] = ACTIONS(5526),
    [anon_sym_COLON] = ACTIONS(5526),
    [anon_sym_COMMA] = ACTIONS(5526),
    [anon_sym_RBRACK] = ACTIONS(5526),
    [anon_sym_LPAREN] = ACTIONS(5526),
    [anon_sym_RPAREN] = ACTIONS(5526),
    [anon_sym_RBRACE] = ACTIONS(5526),
    [anon_sym_LT] = ACTIONS(5528),
    [anon_sym_GT] = ACTIONS(5528),
    [anon_sym_in] = ACTIONS(5526),
    [anon_sym_where] = ACTIONS(5526),
    [anon_sym_QMARK] = ACTIONS(5528),
    [anon_sym_BANG] = ACTIONS(5528),
    [anon_sym_PLUS_PLUS] = ACTIONS(5526),
    [anon_sym_DASH_DASH] = ACTIONS(5526),
    [anon_sym_PLUS] = ACTIONS(5528),
    [anon_sym_DASH] = ACTIONS(5528),
    [anon_sym_STAR] = ACTIONS(5526),
    [anon_sym_SLASH] = ACTIONS(5528),
    [anon_sym_PERCENT] = ACTIONS(5526),
    [anon_sym_CARET] = ACTIONS(5526),
    [anon_sym_PIPE] = ACTIONS(5528),
    [anon_sym_AMP] = ACTIONS(5528),
    [anon_sym_LT_LT] = ACTIONS(5526),
    [anon_sym_GT_GT] = ACTIONS(5528),
    [anon_sym_GT_GT_GT] = ACTIONS(5526),
    [anon_sym_EQ_EQ] = ACTIONS(5526),
    [anon_sym_BANG_EQ] = ACTIONS(5526),
    [anon_sym_GT_EQ] = ACTIONS(5526),
    [anon_sym_LT_EQ] = ACTIONS(5526),
    [anon_sym_DOT] = ACTIONS(5528),
    [anon_sym_EQ_GT] = ACTIONS(5526),
    [anon_sym_switch] = ACTIONS(5526),
    [anon_sym_DOT_DOT] = ACTIONS(5526),
    [anon_sym_and] = ACTIONS(5526),
    [anon_sym_or] = ACTIONS(5528),
    [anon_sym_AMP_AMP] = ACTIONS(5526),
    [anon_sym_PIPE_PIPE] = ACTIONS(5526),
    [anon_sym_QMARK_QMARK] = ACTIONS(5526),
    [anon_sym_from] = ACTIONS(5526),
    [anon_sym_join] = ACTIONS(5526),
    [anon_sym_on] = ACTIONS(5526),
    [anon_sym_equals] = ACTIONS(5526),
    [anon_sym_let] = ACTIONS(5526),
    [anon_sym_orderby] = ACTIONS(5526),
    [anon_sym_group] = ACTIONS(5526),
    [anon_sym_by] = ACTIONS(5526),
    [anon_sym_select] = ACTIONS(5526),
    [anon_sym_as] = ACTIONS(5526),
    [anon_sym_is] = ACTIONS(5526),
    [anon_sym_DASH_GT] = ACTIONS(5526),
    [anon_sym_with] = ACTIONS(5526),
    [aux_sym_preproc_if_token3] = ACTIONS(5526),
    [aux_sym_preproc_else_token1] = ACTIONS(5526),
    [aux_sym_preproc_elif_token1] = ACTIONS(5526),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3760] = {
    [sym_preproc_region] = STATE(3760),
    [sym_preproc_endregion] = STATE(3760),
    [sym_preproc_line] = STATE(3760),
    [sym_preproc_pragma] = STATE(3760),
    [sym_preproc_nullable] = STATE(3760),
    [sym_preproc_error] = STATE(3760),
    [sym_preproc_warning] = STATE(3760),
    [sym_preproc_define] = STATE(3760),
    [sym_preproc_undef] = STATE(3760),
    [anon_sym_SEMI] = ACTIONS(5518),
    [anon_sym_LBRACK] = ACTIONS(5518),
    [anon_sym_COLON] = ACTIONS(5518),
    [anon_sym_COMMA] = ACTIONS(5518),
    [anon_sym_RBRACK] = ACTIONS(5518),
    [anon_sym_LPAREN] = ACTIONS(5518),
    [anon_sym_RPAREN] = ACTIONS(5518),
    [anon_sym_RBRACE] = ACTIONS(5518),
    [anon_sym_LT] = ACTIONS(5520),
    [anon_sym_GT] = ACTIONS(5520),
    [anon_sym_in] = ACTIONS(5518),
    [anon_sym_where] = ACTIONS(5518),
    [anon_sym_QMARK] = ACTIONS(5520),
    [anon_sym_BANG] = ACTIONS(5520),
    [anon_sym_PLUS_PLUS] = ACTIONS(5518),
    [anon_sym_DASH_DASH] = ACTIONS(5518),
    [anon_sym_PLUS] = ACTIONS(5520),
    [anon_sym_DASH] = ACTIONS(5520),
    [anon_sym_STAR] = ACTIONS(5518),
    [anon_sym_SLASH] = ACTIONS(5520),
    [anon_sym_PERCENT] = ACTIONS(5518),
    [anon_sym_CARET] = ACTIONS(5518),
    [anon_sym_PIPE] = ACTIONS(5520),
    [anon_sym_AMP] = ACTIONS(5520),
    [anon_sym_LT_LT] = ACTIONS(5518),
    [anon_sym_GT_GT] = ACTIONS(5520),
    [anon_sym_GT_GT_GT] = ACTIONS(5518),
    [anon_sym_EQ_EQ] = ACTIONS(5518),
    [anon_sym_BANG_EQ] = ACTIONS(5518),
    [anon_sym_GT_EQ] = ACTIONS(5518),
    [anon_sym_LT_EQ] = ACTIONS(5518),
    [anon_sym_DOT] = ACTIONS(5520),
    [anon_sym_EQ_GT] = ACTIONS(5518),
    [anon_sym_switch] = ACTIONS(5518),
    [anon_sym_DOT_DOT] = ACTIONS(5518),
    [anon_sym_and] = ACTIONS(5518),
    [anon_sym_or] = ACTIONS(5520),
    [anon_sym_AMP_AMP] = ACTIONS(5518),
    [anon_sym_PIPE_PIPE] = ACTIONS(5518),
    [anon_sym_QMARK_QMARK] = ACTIONS(5518),
    [anon_sym_from] = ACTIONS(5518),
    [anon_sym_join] = ACTIONS(5518),
    [anon_sym_on] = ACTIONS(5518),
    [anon_sym_equals] = ACTIONS(5518),
    [anon_sym_let] = ACTIONS(5518),
    [anon_sym_orderby] = ACTIONS(5518),
    [anon_sym_group] = ACTIONS(5518),
    [anon_sym_by] = ACTIONS(5518),
    [anon_sym_select] = ACTIONS(5518),
    [anon_sym_as] = ACTIONS(5518),
    [anon_sym_is] = ACTIONS(5518),
    [anon_sym_DASH_GT] = ACTIONS(5518),
    [anon_sym_with] = ACTIONS(5518),
    [aux_sym_preproc_if_token3] = ACTIONS(5518),
    [aux_sym_preproc_else_token1] = ACTIONS(5518),
    [aux_sym_preproc_elif_token1] = ACTIONS(5518),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3761] = {
    [sym_preproc_region] = STATE(3761),
    [sym_preproc_endregion] = STATE(3761),
    [sym_preproc_line] = STATE(3761),
    [sym_preproc_pragma] = STATE(3761),
    [sym_preproc_nullable] = STATE(3761),
    [sym_preproc_error] = STATE(3761),
    [sym_preproc_warning] = STATE(3761),
    [sym_preproc_define] = STATE(3761),
    [sym_preproc_undef] = STATE(3761),
    [anon_sym_SEMI] = ACTIONS(2997),
    [anon_sym_LBRACK] = ACTIONS(2997),
    [anon_sym_COLON] = ACTIONS(2997),
    [anon_sym_COMMA] = ACTIONS(2997),
    [anon_sym_RBRACK] = ACTIONS(2997),
    [anon_sym_LPAREN] = ACTIONS(2997),
    [anon_sym_RPAREN] = ACTIONS(2997),
    [anon_sym_RBRACE] = ACTIONS(2997),
    [anon_sym_LT] = ACTIONS(2995),
    [anon_sym_GT] = ACTIONS(2995),
    [anon_sym_in] = ACTIONS(2997),
    [anon_sym_where] = ACTIONS(2997),
    [anon_sym_QMARK] = ACTIONS(2995),
    [anon_sym_BANG] = ACTIONS(2995),
    [anon_sym_PLUS_PLUS] = ACTIONS(2997),
    [anon_sym_DASH_DASH] = ACTIONS(2997),
    [anon_sym_PLUS] = ACTIONS(2995),
    [anon_sym_DASH] = ACTIONS(2995),
    [anon_sym_STAR] = ACTIONS(2997),
    [anon_sym_SLASH] = ACTIONS(2995),
    [anon_sym_PERCENT] = ACTIONS(2997),
    [anon_sym_CARET] = ACTIONS(2997),
    [anon_sym_PIPE] = ACTIONS(2995),
    [anon_sym_AMP] = ACTIONS(2995),
    [anon_sym_LT_LT] = ACTIONS(2997),
    [anon_sym_GT_GT] = ACTIONS(2995),
    [anon_sym_GT_GT_GT] = ACTIONS(2997),
    [anon_sym_EQ_EQ] = ACTIONS(2997),
    [anon_sym_BANG_EQ] = ACTIONS(2997),
    [anon_sym_GT_EQ] = ACTIONS(2997),
    [anon_sym_LT_EQ] = ACTIONS(2997),
    [anon_sym_DOT] = ACTIONS(2995),
    [anon_sym_EQ_GT] = ACTIONS(2997),
    [anon_sym_switch] = ACTIONS(2997),
    [anon_sym_DOT_DOT] = ACTIONS(2997),
    [anon_sym_and] = ACTIONS(2997),
    [anon_sym_or] = ACTIONS(2995),
    [anon_sym_AMP_AMP] = ACTIONS(2997),
    [anon_sym_PIPE_PIPE] = ACTIONS(2997),
    [anon_sym_QMARK_QMARK] = ACTIONS(2997),
    [anon_sym_from] = ACTIONS(2997),
    [anon_sym_join] = ACTIONS(2997),
    [anon_sym_on] = ACTIONS(2997),
    [anon_sym_equals] = ACTIONS(2997),
    [anon_sym_let] = ACTIONS(2997),
    [anon_sym_orderby] = ACTIONS(2997),
    [anon_sym_group] = ACTIONS(2997),
    [anon_sym_by] = ACTIONS(2997),
    [anon_sym_select] = ACTIONS(2997),
    [anon_sym_as] = ACTIONS(2997),
    [anon_sym_is] = ACTIONS(2997),
    [anon_sym_DASH_GT] = ACTIONS(2997),
    [anon_sym_with] = ACTIONS(2997),
    [aux_sym_preproc_if_token3] = ACTIONS(2997),
    [aux_sym_preproc_else_token1] = ACTIONS(2997),
    [aux_sym_preproc_elif_token1] = ACTIONS(2997),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3762] = {
    [sym_preproc_region] = STATE(3762),
    [sym_preproc_endregion] = STATE(3762),
    [sym_preproc_line] = STATE(3762),
    [sym_preproc_pragma] = STATE(3762),
    [sym_preproc_nullable] = STATE(3762),
    [sym_preproc_error] = STATE(3762),
    [sym_preproc_warning] = STATE(3762),
    [sym_preproc_define] = STATE(3762),
    [sym_preproc_undef] = STATE(3762),
    [anon_sym_SEMI] = ACTIONS(5286),
    [anon_sym_LBRACK] = ACTIONS(5286),
    [anon_sym_COLON] = ACTIONS(5286),
    [anon_sym_COMMA] = ACTIONS(5286),
    [anon_sym_RBRACK] = ACTIONS(5286),
    [anon_sym_LPAREN] = ACTIONS(5286),
    [anon_sym_RPAREN] = ACTIONS(5286),
    [anon_sym_RBRACE] = ACTIONS(5286),
    [anon_sym_LT] = ACTIONS(5288),
    [anon_sym_GT] = ACTIONS(5288),
    [anon_sym_in] = ACTIONS(5286),
    [anon_sym_where] = ACTIONS(5286),
    [anon_sym_QMARK] = ACTIONS(5288),
    [anon_sym_BANG] = ACTIONS(5288),
    [anon_sym_PLUS_PLUS] = ACTIONS(5286),
    [anon_sym_DASH_DASH] = ACTIONS(5286),
    [anon_sym_PLUS] = ACTIONS(5288),
    [anon_sym_DASH] = ACTIONS(5288),
    [anon_sym_STAR] = ACTIONS(5286),
    [anon_sym_SLASH] = ACTIONS(5288),
    [anon_sym_PERCENT] = ACTIONS(5286),
    [anon_sym_CARET] = ACTIONS(5286),
    [anon_sym_PIPE] = ACTIONS(5288),
    [anon_sym_AMP] = ACTIONS(5288),
    [anon_sym_LT_LT] = ACTIONS(5286),
    [anon_sym_GT_GT] = ACTIONS(5288),
    [anon_sym_GT_GT_GT] = ACTIONS(5286),
    [anon_sym_EQ_EQ] = ACTIONS(5286),
    [anon_sym_BANG_EQ] = ACTIONS(5286),
    [anon_sym_GT_EQ] = ACTIONS(5286),
    [anon_sym_LT_EQ] = ACTIONS(5286),
    [anon_sym_DOT] = ACTIONS(5288),
    [anon_sym_EQ_GT] = ACTIONS(5286),
    [anon_sym_switch] = ACTIONS(5286),
    [anon_sym_DOT_DOT] = ACTIONS(5286),
    [anon_sym_and] = ACTIONS(5286),
    [anon_sym_or] = ACTIONS(5288),
    [anon_sym_AMP_AMP] = ACTIONS(5286),
    [anon_sym_PIPE_PIPE] = ACTIONS(5286),
    [anon_sym_QMARK_QMARK] = ACTIONS(5286),
    [anon_sym_from] = ACTIONS(5286),
    [anon_sym_join] = ACTIONS(5286),
    [anon_sym_on] = ACTIONS(5286),
    [anon_sym_equals] = ACTIONS(5286),
    [anon_sym_let] = ACTIONS(5286),
    [anon_sym_orderby] = ACTIONS(5286),
    [anon_sym_group] = ACTIONS(5286),
    [anon_sym_by] = ACTIONS(5286),
    [anon_sym_select] = ACTIONS(5286),
    [anon_sym_as] = ACTIONS(5286),
    [anon_sym_is] = ACTIONS(5286),
    [anon_sym_DASH_GT] = ACTIONS(5286),
    [anon_sym_with] = ACTIONS(5286),
    [aux_sym_preproc_if_token3] = ACTIONS(5286),
    [aux_sym_preproc_else_token1] = ACTIONS(5286),
    [aux_sym_preproc_elif_token1] = ACTIONS(5286),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3763] = {
    [sym_preproc_region] = STATE(3763),
    [sym_preproc_endregion] = STATE(3763),
    [sym_preproc_line] = STATE(3763),
    [sym_preproc_pragma] = STATE(3763),
    [sym_preproc_nullable] = STATE(3763),
    [sym_preproc_error] = STATE(3763),
    [sym_preproc_warning] = STATE(3763),
    [sym_preproc_define] = STATE(3763),
    [sym_preproc_undef] = STATE(3763),
    [anon_sym_SEMI] = ACTIONS(5416),
    [anon_sym_LBRACK] = ACTIONS(5416),
    [anon_sym_COLON] = ACTIONS(5416),
    [anon_sym_COMMA] = ACTIONS(5416),
    [anon_sym_RBRACK] = ACTIONS(5416),
    [anon_sym_LPAREN] = ACTIONS(5416),
    [anon_sym_RPAREN] = ACTIONS(5416),
    [anon_sym_RBRACE] = ACTIONS(5416),
    [anon_sym_LT] = ACTIONS(5418),
    [anon_sym_GT] = ACTIONS(5418),
    [anon_sym_in] = ACTIONS(5416),
    [anon_sym_where] = ACTIONS(5416),
    [anon_sym_QMARK] = ACTIONS(5418),
    [anon_sym_BANG] = ACTIONS(5418),
    [anon_sym_PLUS_PLUS] = ACTIONS(5416),
    [anon_sym_DASH_DASH] = ACTIONS(5416),
    [anon_sym_PLUS] = ACTIONS(5418),
    [anon_sym_DASH] = ACTIONS(5418),
    [anon_sym_STAR] = ACTIONS(5416),
    [anon_sym_SLASH] = ACTIONS(5418),
    [anon_sym_PERCENT] = ACTIONS(5416),
    [anon_sym_CARET] = ACTIONS(5416),
    [anon_sym_PIPE] = ACTIONS(5418),
    [anon_sym_AMP] = ACTIONS(5418),
    [anon_sym_LT_LT] = ACTIONS(5416),
    [anon_sym_GT_GT] = ACTIONS(5418),
    [anon_sym_GT_GT_GT] = ACTIONS(5416),
    [anon_sym_EQ_EQ] = ACTIONS(5416),
    [anon_sym_BANG_EQ] = ACTIONS(5416),
    [anon_sym_GT_EQ] = ACTIONS(5416),
    [anon_sym_LT_EQ] = ACTIONS(5416),
    [anon_sym_DOT] = ACTIONS(5418),
    [anon_sym_EQ_GT] = ACTIONS(5416),
    [anon_sym_switch] = ACTIONS(5416),
    [anon_sym_DOT_DOT] = ACTIONS(5416),
    [anon_sym_and] = ACTIONS(5416),
    [anon_sym_or] = ACTIONS(5418),
    [anon_sym_AMP_AMP] = ACTIONS(5416),
    [anon_sym_PIPE_PIPE] = ACTIONS(5416),
    [anon_sym_QMARK_QMARK] = ACTIONS(5416),
    [anon_sym_from] = ACTIONS(5416),
    [anon_sym_join] = ACTIONS(5416),
    [anon_sym_on] = ACTIONS(5416),
    [anon_sym_equals] = ACTIONS(5416),
    [anon_sym_let] = ACTIONS(5416),
    [anon_sym_orderby] = ACTIONS(5416),
    [anon_sym_group] = ACTIONS(5416),
    [anon_sym_by] = ACTIONS(5416),
    [anon_sym_select] = ACTIONS(5416),
    [anon_sym_as] = ACTIONS(5416),
    [anon_sym_is] = ACTIONS(5416),
    [anon_sym_DASH_GT] = ACTIONS(5416),
    [anon_sym_with] = ACTIONS(5416),
    [aux_sym_preproc_if_token3] = ACTIONS(5416),
    [aux_sym_preproc_else_token1] = ACTIONS(5416),
    [aux_sym_preproc_elif_token1] = ACTIONS(5416),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3764] = {
    [sym_preproc_region] = STATE(3764),
    [sym_preproc_endregion] = STATE(3764),
    [sym_preproc_line] = STATE(3764),
    [sym_preproc_pragma] = STATE(3764),
    [sym_preproc_nullable] = STATE(3764),
    [sym_preproc_error] = STATE(3764),
    [sym_preproc_warning] = STATE(3764),
    [sym_preproc_define] = STATE(3764),
    [sym_preproc_undef] = STATE(3764),
    [anon_sym_SEMI] = ACTIONS(5644),
    [anon_sym_LBRACK] = ACTIONS(5644),
    [anon_sym_COLON] = ACTIONS(5644),
    [anon_sym_COMMA] = ACTIONS(5644),
    [anon_sym_RBRACK] = ACTIONS(5644),
    [anon_sym_LPAREN] = ACTIONS(5644),
    [anon_sym_RPAREN] = ACTIONS(5644),
    [anon_sym_RBRACE] = ACTIONS(5644),
    [anon_sym_LT] = ACTIONS(5646),
    [anon_sym_GT] = ACTIONS(5646),
    [anon_sym_in] = ACTIONS(5644),
    [anon_sym_where] = ACTIONS(5644),
    [anon_sym_QMARK] = ACTIONS(5646),
    [anon_sym_BANG] = ACTIONS(5646),
    [anon_sym_PLUS_PLUS] = ACTIONS(5644),
    [anon_sym_DASH_DASH] = ACTIONS(5644),
    [anon_sym_PLUS] = ACTIONS(5646),
    [anon_sym_DASH] = ACTIONS(5646),
    [anon_sym_STAR] = ACTIONS(5644),
    [anon_sym_SLASH] = ACTIONS(5646),
    [anon_sym_PERCENT] = ACTIONS(5644),
    [anon_sym_CARET] = ACTIONS(5644),
    [anon_sym_PIPE] = ACTIONS(5646),
    [anon_sym_AMP] = ACTIONS(5646),
    [anon_sym_LT_LT] = ACTIONS(5644),
    [anon_sym_GT_GT] = ACTIONS(5646),
    [anon_sym_GT_GT_GT] = ACTIONS(5644),
    [anon_sym_EQ_EQ] = ACTIONS(5644),
    [anon_sym_BANG_EQ] = ACTIONS(5644),
    [anon_sym_GT_EQ] = ACTIONS(5644),
    [anon_sym_LT_EQ] = ACTIONS(5644),
    [anon_sym_DOT] = ACTIONS(5646),
    [anon_sym_EQ_GT] = ACTIONS(5644),
    [anon_sym_switch] = ACTIONS(5644),
    [anon_sym_DOT_DOT] = ACTIONS(5644),
    [anon_sym_and] = ACTIONS(5644),
    [anon_sym_or] = ACTIONS(5646),
    [anon_sym_AMP_AMP] = ACTIONS(5644),
    [anon_sym_PIPE_PIPE] = ACTIONS(5644),
    [anon_sym_QMARK_QMARK] = ACTIONS(5644),
    [anon_sym_from] = ACTIONS(5644),
    [anon_sym_join] = ACTIONS(5644),
    [anon_sym_on] = ACTIONS(5644),
    [anon_sym_equals] = ACTIONS(5644),
    [anon_sym_let] = ACTIONS(5644),
    [anon_sym_orderby] = ACTIONS(5644),
    [anon_sym_group] = ACTIONS(5644),
    [anon_sym_by] = ACTIONS(5644),
    [anon_sym_select] = ACTIONS(5644),
    [anon_sym_as] = ACTIONS(5644),
    [anon_sym_is] = ACTIONS(5644),
    [anon_sym_DASH_GT] = ACTIONS(5644),
    [anon_sym_with] = ACTIONS(5644),
    [aux_sym_preproc_if_token3] = ACTIONS(5644),
    [aux_sym_preproc_else_token1] = ACTIONS(5644),
    [aux_sym_preproc_elif_token1] = ACTIONS(5644),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3765] = {
    [sym_preproc_region] = STATE(3765),
    [sym_preproc_endregion] = STATE(3765),
    [sym_preproc_line] = STATE(3765),
    [sym_preproc_pragma] = STATE(3765),
    [sym_preproc_nullable] = STATE(3765),
    [sym_preproc_error] = STATE(3765),
    [sym_preproc_warning] = STATE(3765),
    [sym_preproc_define] = STATE(3765),
    [sym_preproc_undef] = STATE(3765),
    [anon_sym_SEMI] = ACTIONS(5652),
    [anon_sym_LBRACK] = ACTIONS(5652),
    [anon_sym_COLON] = ACTIONS(5652),
    [anon_sym_COMMA] = ACTIONS(5652),
    [anon_sym_RBRACK] = ACTIONS(5652),
    [anon_sym_LPAREN] = ACTIONS(5652),
    [anon_sym_RPAREN] = ACTIONS(5652),
    [anon_sym_RBRACE] = ACTIONS(5652),
    [anon_sym_LT] = ACTIONS(5654),
    [anon_sym_GT] = ACTIONS(5654),
    [anon_sym_in] = ACTIONS(5652),
    [anon_sym_where] = ACTIONS(5652),
    [anon_sym_QMARK] = ACTIONS(5654),
    [anon_sym_BANG] = ACTIONS(5654),
    [anon_sym_PLUS_PLUS] = ACTIONS(5652),
    [anon_sym_DASH_DASH] = ACTIONS(5652),
    [anon_sym_PLUS] = ACTIONS(5654),
    [anon_sym_DASH] = ACTIONS(5654),
    [anon_sym_STAR] = ACTIONS(5652),
    [anon_sym_SLASH] = ACTIONS(5654),
    [anon_sym_PERCENT] = ACTIONS(5652),
    [anon_sym_CARET] = ACTIONS(5652),
    [anon_sym_PIPE] = ACTIONS(5654),
    [anon_sym_AMP] = ACTIONS(5654),
    [anon_sym_LT_LT] = ACTIONS(5652),
    [anon_sym_GT_GT] = ACTIONS(5654),
    [anon_sym_GT_GT_GT] = ACTIONS(5652),
    [anon_sym_EQ_EQ] = ACTIONS(5652),
    [anon_sym_BANG_EQ] = ACTIONS(5652),
    [anon_sym_GT_EQ] = ACTIONS(5652),
    [anon_sym_LT_EQ] = ACTIONS(5652),
    [anon_sym_DOT] = ACTIONS(5654),
    [anon_sym_EQ_GT] = ACTIONS(5652),
    [anon_sym_switch] = ACTIONS(5652),
    [anon_sym_DOT_DOT] = ACTIONS(5652),
    [anon_sym_and] = ACTIONS(5652),
    [anon_sym_or] = ACTIONS(5654),
    [anon_sym_AMP_AMP] = ACTIONS(5652),
    [anon_sym_PIPE_PIPE] = ACTIONS(5652),
    [anon_sym_QMARK_QMARK] = ACTIONS(5652),
    [anon_sym_from] = ACTIONS(5652),
    [anon_sym_join] = ACTIONS(5652),
    [anon_sym_on] = ACTIONS(5652),
    [anon_sym_equals] = ACTIONS(5652),
    [anon_sym_let] = ACTIONS(5652),
    [anon_sym_orderby] = ACTIONS(5652),
    [anon_sym_group] = ACTIONS(5652),
    [anon_sym_by] = ACTIONS(5652),
    [anon_sym_select] = ACTIONS(5652),
    [anon_sym_as] = ACTIONS(5652),
    [anon_sym_is] = ACTIONS(5652),
    [anon_sym_DASH_GT] = ACTIONS(5652),
    [anon_sym_with] = ACTIONS(5652),
    [aux_sym_preproc_if_token3] = ACTIONS(5652),
    [aux_sym_preproc_else_token1] = ACTIONS(5652),
    [aux_sym_preproc_elif_token1] = ACTIONS(5652),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3766] = {
    [sym_preproc_region] = STATE(3766),
    [sym_preproc_endregion] = STATE(3766),
    [sym_preproc_line] = STATE(3766),
    [sym_preproc_pragma] = STATE(3766),
    [sym_preproc_nullable] = STATE(3766),
    [sym_preproc_error] = STATE(3766),
    [sym_preproc_warning] = STATE(3766),
    [sym_preproc_define] = STATE(3766),
    [sym_preproc_undef] = STATE(3766),
    [anon_sym_SEMI] = ACTIONS(5490),
    [anon_sym_LBRACK] = ACTIONS(5490),
    [anon_sym_COLON] = ACTIONS(5490),
    [anon_sym_COMMA] = ACTIONS(5490),
    [anon_sym_RBRACK] = ACTIONS(5490),
    [anon_sym_LPAREN] = ACTIONS(5490),
    [anon_sym_RPAREN] = ACTIONS(5490),
    [anon_sym_RBRACE] = ACTIONS(5490),
    [anon_sym_LT] = ACTIONS(5492),
    [anon_sym_GT] = ACTIONS(5492),
    [anon_sym_in] = ACTIONS(5490),
    [anon_sym_where] = ACTIONS(5490),
    [anon_sym_QMARK] = ACTIONS(5492),
    [anon_sym_BANG] = ACTIONS(5492),
    [anon_sym_PLUS_PLUS] = ACTIONS(5490),
    [anon_sym_DASH_DASH] = ACTIONS(5490),
    [anon_sym_PLUS] = ACTIONS(5492),
    [anon_sym_DASH] = ACTIONS(5492),
    [anon_sym_STAR] = ACTIONS(5490),
    [anon_sym_SLASH] = ACTIONS(5492),
    [anon_sym_PERCENT] = ACTIONS(5490),
    [anon_sym_CARET] = ACTIONS(5490),
    [anon_sym_PIPE] = ACTIONS(5492),
    [anon_sym_AMP] = ACTIONS(5492),
    [anon_sym_LT_LT] = ACTIONS(5490),
    [anon_sym_GT_GT] = ACTIONS(5492),
    [anon_sym_GT_GT_GT] = ACTIONS(5490),
    [anon_sym_EQ_EQ] = ACTIONS(5490),
    [anon_sym_BANG_EQ] = ACTIONS(5490),
    [anon_sym_GT_EQ] = ACTIONS(5490),
    [anon_sym_LT_EQ] = ACTIONS(5490),
    [anon_sym_DOT] = ACTIONS(5492),
    [anon_sym_EQ_GT] = ACTIONS(5490),
    [anon_sym_switch] = ACTIONS(5490),
    [anon_sym_DOT_DOT] = ACTIONS(5490),
    [anon_sym_and] = ACTIONS(5490),
    [anon_sym_or] = ACTIONS(5492),
    [anon_sym_AMP_AMP] = ACTIONS(5490),
    [anon_sym_PIPE_PIPE] = ACTIONS(5490),
    [anon_sym_QMARK_QMARK] = ACTIONS(5490),
    [anon_sym_from] = ACTIONS(5490),
    [anon_sym_join] = ACTIONS(5490),
    [anon_sym_on] = ACTIONS(5490),
    [anon_sym_equals] = ACTIONS(5490),
    [anon_sym_let] = ACTIONS(5490),
    [anon_sym_orderby] = ACTIONS(5490),
    [anon_sym_group] = ACTIONS(5490),
    [anon_sym_by] = ACTIONS(5490),
    [anon_sym_select] = ACTIONS(5490),
    [anon_sym_as] = ACTIONS(5490),
    [anon_sym_is] = ACTIONS(5490),
    [anon_sym_DASH_GT] = ACTIONS(5490),
    [anon_sym_with] = ACTIONS(5490),
    [aux_sym_preproc_if_token3] = ACTIONS(5490),
    [aux_sym_preproc_else_token1] = ACTIONS(5490),
    [aux_sym_preproc_elif_token1] = ACTIONS(5490),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3767] = {
    [sym_preproc_region] = STATE(3767),
    [sym_preproc_endregion] = STATE(3767),
    [sym_preproc_line] = STATE(3767),
    [sym_preproc_pragma] = STATE(3767),
    [sym_preproc_nullable] = STATE(3767),
    [sym_preproc_error] = STATE(3767),
    [sym_preproc_warning] = STATE(3767),
    [sym_preproc_define] = STATE(3767),
    [sym_preproc_undef] = STATE(3767),
    [anon_sym_SEMI] = ACTIONS(5552),
    [anon_sym_LBRACK] = ACTIONS(5552),
    [anon_sym_COLON] = ACTIONS(5552),
    [anon_sym_COMMA] = ACTIONS(5552),
    [anon_sym_RBRACK] = ACTIONS(5552),
    [anon_sym_LPAREN] = ACTIONS(5552),
    [anon_sym_RPAREN] = ACTIONS(5552),
    [anon_sym_RBRACE] = ACTIONS(5552),
    [anon_sym_LT] = ACTIONS(5554),
    [anon_sym_GT] = ACTIONS(5554),
    [anon_sym_in] = ACTIONS(5552),
    [anon_sym_where] = ACTIONS(5552),
    [anon_sym_QMARK] = ACTIONS(5554),
    [anon_sym_BANG] = ACTIONS(5554),
    [anon_sym_PLUS_PLUS] = ACTIONS(5552),
    [anon_sym_DASH_DASH] = ACTIONS(5552),
    [anon_sym_PLUS] = ACTIONS(5554),
    [anon_sym_DASH] = ACTIONS(5554),
    [anon_sym_STAR] = ACTIONS(5552),
    [anon_sym_SLASH] = ACTIONS(5554),
    [anon_sym_PERCENT] = ACTIONS(5552),
    [anon_sym_CARET] = ACTIONS(5552),
    [anon_sym_PIPE] = ACTIONS(5554),
    [anon_sym_AMP] = ACTIONS(5554),
    [anon_sym_LT_LT] = ACTIONS(5552),
    [anon_sym_GT_GT] = ACTIONS(5554),
    [anon_sym_GT_GT_GT] = ACTIONS(5552),
    [anon_sym_EQ_EQ] = ACTIONS(5552),
    [anon_sym_BANG_EQ] = ACTIONS(5552),
    [anon_sym_GT_EQ] = ACTIONS(5552),
    [anon_sym_LT_EQ] = ACTIONS(5552),
    [anon_sym_DOT] = ACTIONS(5554),
    [anon_sym_EQ_GT] = ACTIONS(5552),
    [anon_sym_switch] = ACTIONS(5552),
    [anon_sym_DOT_DOT] = ACTIONS(5552),
    [anon_sym_and] = ACTIONS(5552),
    [anon_sym_or] = ACTIONS(5554),
    [anon_sym_AMP_AMP] = ACTIONS(5552),
    [anon_sym_PIPE_PIPE] = ACTIONS(5552),
    [anon_sym_QMARK_QMARK] = ACTIONS(5552),
    [anon_sym_from] = ACTIONS(5552),
    [anon_sym_join] = ACTIONS(5552),
    [anon_sym_on] = ACTIONS(5552),
    [anon_sym_equals] = ACTIONS(5552),
    [anon_sym_let] = ACTIONS(5552),
    [anon_sym_orderby] = ACTIONS(5552),
    [anon_sym_group] = ACTIONS(5552),
    [anon_sym_by] = ACTIONS(5552),
    [anon_sym_select] = ACTIONS(5552),
    [anon_sym_as] = ACTIONS(5552),
    [anon_sym_is] = ACTIONS(5552),
    [anon_sym_DASH_GT] = ACTIONS(5552),
    [anon_sym_with] = ACTIONS(5552),
    [aux_sym_preproc_if_token3] = ACTIONS(5552),
    [aux_sym_preproc_else_token1] = ACTIONS(5552),
    [aux_sym_preproc_elif_token1] = ACTIONS(5552),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3768] = {
    [sym_preproc_region] = STATE(3768),
    [sym_preproc_endregion] = STATE(3768),
    [sym_preproc_line] = STATE(3768),
    [sym_preproc_pragma] = STATE(3768),
    [sym_preproc_nullable] = STATE(3768),
    [sym_preproc_error] = STATE(3768),
    [sym_preproc_warning] = STATE(3768),
    [sym_preproc_define] = STATE(3768),
    [sym_preproc_undef] = STATE(3768),
    [anon_sym_SEMI] = ACTIONS(5670),
    [anon_sym_LBRACK] = ACTIONS(5670),
    [anon_sym_COLON] = ACTIONS(5670),
    [anon_sym_COMMA] = ACTIONS(5670),
    [anon_sym_RBRACK] = ACTIONS(5670),
    [anon_sym_LPAREN] = ACTIONS(5670),
    [anon_sym_RPAREN] = ACTIONS(5670),
    [anon_sym_RBRACE] = ACTIONS(5670),
    [anon_sym_LT] = ACTIONS(5672),
    [anon_sym_GT] = ACTIONS(5672),
    [anon_sym_in] = ACTIONS(5670),
    [anon_sym_where] = ACTIONS(5670),
    [anon_sym_QMARK] = ACTIONS(5672),
    [anon_sym_BANG] = ACTIONS(5672),
    [anon_sym_PLUS_PLUS] = ACTIONS(5670),
    [anon_sym_DASH_DASH] = ACTIONS(5670),
    [anon_sym_PLUS] = ACTIONS(5672),
    [anon_sym_DASH] = ACTIONS(5672),
    [anon_sym_STAR] = ACTIONS(5670),
    [anon_sym_SLASH] = ACTIONS(5672),
    [anon_sym_PERCENT] = ACTIONS(5670),
    [anon_sym_CARET] = ACTIONS(5670),
    [anon_sym_PIPE] = ACTIONS(5672),
    [anon_sym_AMP] = ACTIONS(5672),
    [anon_sym_LT_LT] = ACTIONS(5670),
    [anon_sym_GT_GT] = ACTIONS(5672),
    [anon_sym_GT_GT_GT] = ACTIONS(5670),
    [anon_sym_EQ_EQ] = ACTIONS(5670),
    [anon_sym_BANG_EQ] = ACTIONS(5670),
    [anon_sym_GT_EQ] = ACTIONS(5670),
    [anon_sym_LT_EQ] = ACTIONS(5670),
    [anon_sym_DOT] = ACTIONS(5672),
    [anon_sym_EQ_GT] = ACTIONS(5670),
    [anon_sym_switch] = ACTIONS(5670),
    [anon_sym_DOT_DOT] = ACTIONS(5670),
    [anon_sym_and] = ACTIONS(5670),
    [anon_sym_or] = ACTIONS(5672),
    [anon_sym_AMP_AMP] = ACTIONS(5670),
    [anon_sym_PIPE_PIPE] = ACTIONS(5670),
    [anon_sym_QMARK_QMARK] = ACTIONS(5670),
    [anon_sym_from] = ACTIONS(5670),
    [anon_sym_join] = ACTIONS(5670),
    [anon_sym_on] = ACTIONS(5670),
    [anon_sym_equals] = ACTIONS(5670),
    [anon_sym_let] = ACTIONS(5670),
    [anon_sym_orderby] = ACTIONS(5670),
    [anon_sym_group] = ACTIONS(5670),
    [anon_sym_by] = ACTIONS(5670),
    [anon_sym_select] = ACTIONS(5670),
    [anon_sym_as] = ACTIONS(5670),
    [anon_sym_is] = ACTIONS(5670),
    [anon_sym_DASH_GT] = ACTIONS(5670),
    [anon_sym_with] = ACTIONS(5670),
    [aux_sym_preproc_if_token3] = ACTIONS(5670),
    [aux_sym_preproc_else_token1] = ACTIONS(5670),
    [aux_sym_preproc_elif_token1] = ACTIONS(5670),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3769] = {
    [sym_preproc_region] = STATE(3769),
    [sym_preproc_endregion] = STATE(3769),
    [sym_preproc_line] = STATE(3769),
    [sym_preproc_pragma] = STATE(3769),
    [sym_preproc_nullable] = STATE(3769),
    [sym_preproc_error] = STATE(3769),
    [sym_preproc_warning] = STATE(3769),
    [sym_preproc_define] = STATE(3769),
    [sym_preproc_undef] = STATE(3769),
    [anon_sym_SEMI] = ACTIONS(5514),
    [anon_sym_LBRACK] = ACTIONS(5514),
    [anon_sym_COLON] = ACTIONS(5514),
    [anon_sym_COMMA] = ACTIONS(5514),
    [anon_sym_RBRACK] = ACTIONS(5514),
    [anon_sym_LPAREN] = ACTIONS(5514),
    [anon_sym_RPAREN] = ACTIONS(5514),
    [anon_sym_RBRACE] = ACTIONS(5514),
    [anon_sym_LT] = ACTIONS(5516),
    [anon_sym_GT] = ACTIONS(5516),
    [anon_sym_in] = ACTIONS(5514),
    [anon_sym_where] = ACTIONS(5514),
    [anon_sym_QMARK] = ACTIONS(5516),
    [anon_sym_BANG] = ACTIONS(5516),
    [anon_sym_PLUS_PLUS] = ACTIONS(5514),
    [anon_sym_DASH_DASH] = ACTIONS(5514),
    [anon_sym_PLUS] = ACTIONS(5516),
    [anon_sym_DASH] = ACTIONS(5516),
    [anon_sym_STAR] = ACTIONS(5514),
    [anon_sym_SLASH] = ACTIONS(5516),
    [anon_sym_PERCENT] = ACTIONS(5514),
    [anon_sym_CARET] = ACTIONS(5514),
    [anon_sym_PIPE] = ACTIONS(5516),
    [anon_sym_AMP] = ACTIONS(5516),
    [anon_sym_LT_LT] = ACTIONS(5514),
    [anon_sym_GT_GT] = ACTIONS(5516),
    [anon_sym_GT_GT_GT] = ACTIONS(5514),
    [anon_sym_EQ_EQ] = ACTIONS(5514),
    [anon_sym_BANG_EQ] = ACTIONS(5514),
    [anon_sym_GT_EQ] = ACTIONS(5514),
    [anon_sym_LT_EQ] = ACTIONS(5514),
    [anon_sym_DOT] = ACTIONS(5516),
    [anon_sym_EQ_GT] = ACTIONS(5514),
    [anon_sym_switch] = ACTIONS(5514),
    [anon_sym_DOT_DOT] = ACTIONS(5514),
    [anon_sym_and] = ACTIONS(5514),
    [anon_sym_or] = ACTIONS(5516),
    [anon_sym_AMP_AMP] = ACTIONS(5514),
    [anon_sym_PIPE_PIPE] = ACTIONS(5514),
    [anon_sym_QMARK_QMARK] = ACTIONS(5514),
    [anon_sym_from] = ACTIONS(5514),
    [anon_sym_join] = ACTIONS(5514),
    [anon_sym_on] = ACTIONS(5514),
    [anon_sym_equals] = ACTIONS(5514),
    [anon_sym_let] = ACTIONS(5514),
    [anon_sym_orderby] = ACTIONS(5514),
    [anon_sym_group] = ACTIONS(5514),
    [anon_sym_by] = ACTIONS(5514),
    [anon_sym_select] = ACTIONS(5514),
    [anon_sym_as] = ACTIONS(5514),
    [anon_sym_is] = ACTIONS(5514),
    [anon_sym_DASH_GT] = ACTIONS(5514),
    [anon_sym_with] = ACTIONS(5514),
    [aux_sym_preproc_if_token3] = ACTIONS(5514),
    [aux_sym_preproc_else_token1] = ACTIONS(5514),
    [aux_sym_preproc_elif_token1] = ACTIONS(5514),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3770] = {
    [sym_preproc_region] = STATE(3770),
    [sym_preproc_endregion] = STATE(3770),
    [sym_preproc_line] = STATE(3770),
    [sym_preproc_pragma] = STATE(3770),
    [sym_preproc_nullable] = STATE(3770),
    [sym_preproc_error] = STATE(3770),
    [sym_preproc_warning] = STATE(3770),
    [sym_preproc_define] = STATE(3770),
    [sym_preproc_undef] = STATE(3770),
    [anon_sym_SEMI] = ACTIONS(5588),
    [anon_sym_LBRACK] = ACTIONS(5588),
    [anon_sym_COLON] = ACTIONS(5588),
    [anon_sym_COMMA] = ACTIONS(5588),
    [anon_sym_RBRACK] = ACTIONS(5588),
    [anon_sym_LPAREN] = ACTIONS(5588),
    [anon_sym_RPAREN] = ACTIONS(5588),
    [anon_sym_RBRACE] = ACTIONS(5588),
    [anon_sym_LT] = ACTIONS(5590),
    [anon_sym_GT] = ACTIONS(5590),
    [anon_sym_in] = ACTIONS(5588),
    [anon_sym_where] = ACTIONS(5588),
    [anon_sym_QMARK] = ACTIONS(5590),
    [anon_sym_BANG] = ACTIONS(5590),
    [anon_sym_PLUS_PLUS] = ACTIONS(5588),
    [anon_sym_DASH_DASH] = ACTIONS(5588),
    [anon_sym_PLUS] = ACTIONS(5590),
    [anon_sym_DASH] = ACTIONS(5590),
    [anon_sym_STAR] = ACTIONS(5588),
    [anon_sym_SLASH] = ACTIONS(5590),
    [anon_sym_PERCENT] = ACTIONS(5588),
    [anon_sym_CARET] = ACTIONS(5588),
    [anon_sym_PIPE] = ACTIONS(5590),
    [anon_sym_AMP] = ACTIONS(5590),
    [anon_sym_LT_LT] = ACTIONS(5588),
    [anon_sym_GT_GT] = ACTIONS(5590),
    [anon_sym_GT_GT_GT] = ACTIONS(5588),
    [anon_sym_EQ_EQ] = ACTIONS(5588),
    [anon_sym_BANG_EQ] = ACTIONS(5588),
    [anon_sym_GT_EQ] = ACTIONS(5588),
    [anon_sym_LT_EQ] = ACTIONS(5588),
    [anon_sym_DOT] = ACTIONS(5590),
    [anon_sym_EQ_GT] = ACTIONS(5588),
    [anon_sym_switch] = ACTIONS(5588),
    [anon_sym_DOT_DOT] = ACTIONS(5588),
    [anon_sym_and] = ACTIONS(5588),
    [anon_sym_or] = ACTIONS(5590),
    [anon_sym_AMP_AMP] = ACTIONS(5588),
    [anon_sym_PIPE_PIPE] = ACTIONS(5588),
    [anon_sym_QMARK_QMARK] = ACTIONS(5588),
    [anon_sym_from] = ACTIONS(5588),
    [anon_sym_join] = ACTIONS(5588),
    [anon_sym_on] = ACTIONS(5588),
    [anon_sym_equals] = ACTIONS(5588),
    [anon_sym_let] = ACTIONS(5588),
    [anon_sym_orderby] = ACTIONS(5588),
    [anon_sym_group] = ACTIONS(5588),
    [anon_sym_by] = ACTIONS(5588),
    [anon_sym_select] = ACTIONS(5588),
    [anon_sym_as] = ACTIONS(5588),
    [anon_sym_is] = ACTIONS(5588),
    [anon_sym_DASH_GT] = ACTIONS(5588),
    [anon_sym_with] = ACTIONS(5588),
    [aux_sym_preproc_if_token3] = ACTIONS(5588),
    [aux_sym_preproc_else_token1] = ACTIONS(5588),
    [aux_sym_preproc_elif_token1] = ACTIONS(5588),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3771] = {
    [sym_preproc_region] = STATE(3771),
    [sym_preproc_endregion] = STATE(3771),
    [sym_preproc_line] = STATE(3771),
    [sym_preproc_pragma] = STATE(3771),
    [sym_preproc_nullable] = STATE(3771),
    [sym_preproc_error] = STATE(3771),
    [sym_preproc_warning] = STATE(3771),
    [sym_preproc_define] = STATE(3771),
    [sym_preproc_undef] = STATE(3771),
    [anon_sym_SEMI] = ACTIONS(5628),
    [anon_sym_LBRACK] = ACTIONS(5628),
    [anon_sym_COLON] = ACTIONS(5628),
    [anon_sym_COMMA] = ACTIONS(5628),
    [anon_sym_RBRACK] = ACTIONS(5628),
    [anon_sym_LPAREN] = ACTIONS(5628),
    [anon_sym_RPAREN] = ACTIONS(5628),
    [anon_sym_RBRACE] = ACTIONS(5628),
    [anon_sym_LT] = ACTIONS(5630),
    [anon_sym_GT] = ACTIONS(5630),
    [anon_sym_in] = ACTIONS(5628),
    [anon_sym_where] = ACTIONS(5628),
    [anon_sym_QMARK] = ACTIONS(5630),
    [anon_sym_BANG] = ACTIONS(5630),
    [anon_sym_PLUS_PLUS] = ACTIONS(5628),
    [anon_sym_DASH_DASH] = ACTIONS(5628),
    [anon_sym_PLUS] = ACTIONS(5630),
    [anon_sym_DASH] = ACTIONS(5630),
    [anon_sym_STAR] = ACTIONS(5628),
    [anon_sym_SLASH] = ACTIONS(5630),
    [anon_sym_PERCENT] = ACTIONS(5628),
    [anon_sym_CARET] = ACTIONS(5628),
    [anon_sym_PIPE] = ACTIONS(5630),
    [anon_sym_AMP] = ACTIONS(5630),
    [anon_sym_LT_LT] = ACTIONS(5628),
    [anon_sym_GT_GT] = ACTIONS(5630),
    [anon_sym_GT_GT_GT] = ACTIONS(5628),
    [anon_sym_EQ_EQ] = ACTIONS(5628),
    [anon_sym_BANG_EQ] = ACTIONS(5628),
    [anon_sym_GT_EQ] = ACTIONS(5628),
    [anon_sym_LT_EQ] = ACTIONS(5628),
    [anon_sym_DOT] = ACTIONS(5630),
    [anon_sym_EQ_GT] = ACTIONS(5628),
    [anon_sym_switch] = ACTIONS(5628),
    [anon_sym_DOT_DOT] = ACTIONS(5628),
    [anon_sym_and] = ACTIONS(5628),
    [anon_sym_or] = ACTIONS(5630),
    [anon_sym_AMP_AMP] = ACTIONS(5628),
    [anon_sym_PIPE_PIPE] = ACTIONS(5628),
    [anon_sym_QMARK_QMARK] = ACTIONS(5628),
    [anon_sym_from] = ACTIONS(5628),
    [anon_sym_join] = ACTIONS(5628),
    [anon_sym_on] = ACTIONS(5628),
    [anon_sym_equals] = ACTIONS(5628),
    [anon_sym_let] = ACTIONS(5628),
    [anon_sym_orderby] = ACTIONS(5628),
    [anon_sym_group] = ACTIONS(5628),
    [anon_sym_by] = ACTIONS(5628),
    [anon_sym_select] = ACTIONS(5628),
    [anon_sym_as] = ACTIONS(5628),
    [anon_sym_is] = ACTIONS(5628),
    [anon_sym_DASH_GT] = ACTIONS(5628),
    [anon_sym_with] = ACTIONS(5628),
    [aux_sym_preproc_if_token3] = ACTIONS(5628),
    [aux_sym_preproc_else_token1] = ACTIONS(5628),
    [aux_sym_preproc_elif_token1] = ACTIONS(5628),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3772] = {
    [sym_preproc_region] = STATE(3772),
    [sym_preproc_endregion] = STATE(3772),
    [sym_preproc_line] = STATE(3772),
    [sym_preproc_pragma] = STATE(3772),
    [sym_preproc_nullable] = STATE(3772),
    [sym_preproc_error] = STATE(3772),
    [sym_preproc_warning] = STATE(3772),
    [sym_preproc_define] = STATE(3772),
    [sym_preproc_undef] = STATE(3772),
    [anon_sym_SEMI] = ACTIONS(5636),
    [anon_sym_LBRACK] = ACTIONS(5636),
    [anon_sym_COLON] = ACTIONS(5636),
    [anon_sym_COMMA] = ACTIONS(5636),
    [anon_sym_RBRACK] = ACTIONS(5636),
    [anon_sym_LPAREN] = ACTIONS(5636),
    [anon_sym_RPAREN] = ACTIONS(5636),
    [anon_sym_RBRACE] = ACTIONS(5636),
    [anon_sym_LT] = ACTIONS(5638),
    [anon_sym_GT] = ACTIONS(5638),
    [anon_sym_in] = ACTIONS(5636),
    [anon_sym_where] = ACTIONS(5636),
    [anon_sym_QMARK] = ACTIONS(5638),
    [anon_sym_BANG] = ACTIONS(5638),
    [anon_sym_PLUS_PLUS] = ACTIONS(5636),
    [anon_sym_DASH_DASH] = ACTIONS(5636),
    [anon_sym_PLUS] = ACTIONS(5638),
    [anon_sym_DASH] = ACTIONS(5638),
    [anon_sym_STAR] = ACTIONS(5636),
    [anon_sym_SLASH] = ACTIONS(5638),
    [anon_sym_PERCENT] = ACTIONS(5636),
    [anon_sym_CARET] = ACTIONS(5636),
    [anon_sym_PIPE] = ACTIONS(5638),
    [anon_sym_AMP] = ACTIONS(5638),
    [anon_sym_LT_LT] = ACTIONS(5636),
    [anon_sym_GT_GT] = ACTIONS(5638),
    [anon_sym_GT_GT_GT] = ACTIONS(5636),
    [anon_sym_EQ_EQ] = ACTIONS(5636),
    [anon_sym_BANG_EQ] = ACTIONS(5636),
    [anon_sym_GT_EQ] = ACTIONS(5636),
    [anon_sym_LT_EQ] = ACTIONS(5636),
    [anon_sym_DOT] = ACTIONS(5638),
    [anon_sym_EQ_GT] = ACTIONS(5636),
    [anon_sym_switch] = ACTIONS(5636),
    [anon_sym_DOT_DOT] = ACTIONS(5636),
    [anon_sym_and] = ACTIONS(5636),
    [anon_sym_or] = ACTIONS(5638),
    [anon_sym_AMP_AMP] = ACTIONS(5636),
    [anon_sym_PIPE_PIPE] = ACTIONS(5636),
    [anon_sym_QMARK_QMARK] = ACTIONS(5636),
    [anon_sym_from] = ACTIONS(5636),
    [anon_sym_join] = ACTIONS(5636),
    [anon_sym_on] = ACTIONS(5636),
    [anon_sym_equals] = ACTIONS(5636),
    [anon_sym_let] = ACTIONS(5636),
    [anon_sym_orderby] = ACTIONS(5636),
    [anon_sym_group] = ACTIONS(5636),
    [anon_sym_by] = ACTIONS(5636),
    [anon_sym_select] = ACTIONS(5636),
    [anon_sym_as] = ACTIONS(5636),
    [anon_sym_is] = ACTIONS(5636),
    [anon_sym_DASH_GT] = ACTIONS(5636),
    [anon_sym_with] = ACTIONS(5636),
    [aux_sym_preproc_if_token3] = ACTIONS(5636),
    [aux_sym_preproc_else_token1] = ACTIONS(5636),
    [aux_sym_preproc_elif_token1] = ACTIONS(5636),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3773] = {
    [sym_preproc_region] = STATE(3773),
    [sym_preproc_endregion] = STATE(3773),
    [sym_preproc_line] = STATE(3773),
    [sym_preproc_pragma] = STATE(3773),
    [sym_preproc_nullable] = STATE(3773),
    [sym_preproc_error] = STATE(3773),
    [sym_preproc_warning] = STATE(3773),
    [sym_preproc_define] = STATE(3773),
    [sym_preproc_undef] = STATE(3773),
    [anon_sym_SEMI] = ACTIONS(5556),
    [anon_sym_LBRACK] = ACTIONS(5556),
    [anon_sym_COLON] = ACTIONS(5556),
    [anon_sym_COMMA] = ACTIONS(5556),
    [anon_sym_RBRACK] = ACTIONS(5556),
    [anon_sym_LPAREN] = ACTIONS(5556),
    [anon_sym_RPAREN] = ACTIONS(5556),
    [anon_sym_RBRACE] = ACTIONS(5556),
    [anon_sym_LT] = ACTIONS(5558),
    [anon_sym_GT] = ACTIONS(5558),
    [anon_sym_in] = ACTIONS(5556),
    [anon_sym_where] = ACTIONS(5556),
    [anon_sym_QMARK] = ACTIONS(5558),
    [anon_sym_BANG] = ACTIONS(5558),
    [anon_sym_PLUS_PLUS] = ACTIONS(5556),
    [anon_sym_DASH_DASH] = ACTIONS(5556),
    [anon_sym_PLUS] = ACTIONS(5558),
    [anon_sym_DASH] = ACTIONS(5558),
    [anon_sym_STAR] = ACTIONS(5556),
    [anon_sym_SLASH] = ACTIONS(5558),
    [anon_sym_PERCENT] = ACTIONS(5556),
    [anon_sym_CARET] = ACTIONS(5556),
    [anon_sym_PIPE] = ACTIONS(5558),
    [anon_sym_AMP] = ACTIONS(5558),
    [anon_sym_LT_LT] = ACTIONS(5556),
    [anon_sym_GT_GT] = ACTIONS(5558),
    [anon_sym_GT_GT_GT] = ACTIONS(5556),
    [anon_sym_EQ_EQ] = ACTIONS(5556),
    [anon_sym_BANG_EQ] = ACTIONS(5556),
    [anon_sym_GT_EQ] = ACTIONS(5556),
    [anon_sym_LT_EQ] = ACTIONS(5556),
    [anon_sym_DOT] = ACTIONS(5558),
    [anon_sym_EQ_GT] = ACTIONS(5556),
    [anon_sym_switch] = ACTIONS(5556),
    [anon_sym_DOT_DOT] = ACTIONS(5556),
    [anon_sym_and] = ACTIONS(5556),
    [anon_sym_or] = ACTIONS(5558),
    [anon_sym_AMP_AMP] = ACTIONS(5556),
    [anon_sym_PIPE_PIPE] = ACTIONS(5556),
    [anon_sym_QMARK_QMARK] = ACTIONS(5556),
    [anon_sym_from] = ACTIONS(5556),
    [anon_sym_join] = ACTIONS(5556),
    [anon_sym_on] = ACTIONS(5556),
    [anon_sym_equals] = ACTIONS(5556),
    [anon_sym_let] = ACTIONS(5556),
    [anon_sym_orderby] = ACTIONS(5556),
    [anon_sym_group] = ACTIONS(5556),
    [anon_sym_by] = ACTIONS(5556),
    [anon_sym_select] = ACTIONS(5556),
    [anon_sym_as] = ACTIONS(5556),
    [anon_sym_is] = ACTIONS(5556),
    [anon_sym_DASH_GT] = ACTIONS(5556),
    [anon_sym_with] = ACTIONS(5556),
    [aux_sym_preproc_if_token3] = ACTIONS(5556),
    [aux_sym_preproc_else_token1] = ACTIONS(5556),
    [aux_sym_preproc_elif_token1] = ACTIONS(5556),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3774] = {
    [sym_preproc_region] = STATE(3774),
    [sym_preproc_endregion] = STATE(3774),
    [sym_preproc_line] = STATE(3774),
    [sym_preproc_pragma] = STATE(3774),
    [sym_preproc_nullable] = STATE(3774),
    [sym_preproc_error] = STATE(3774),
    [sym_preproc_warning] = STATE(3774),
    [sym_preproc_define] = STATE(3774),
    [sym_preproc_undef] = STATE(3774),
    [anon_sym_SEMI] = ACTIONS(5428),
    [anon_sym_LBRACK] = ACTIONS(5428),
    [anon_sym_COLON] = ACTIONS(5428),
    [anon_sym_COMMA] = ACTIONS(5428),
    [anon_sym_RBRACK] = ACTIONS(5428),
    [anon_sym_LPAREN] = ACTIONS(5428),
    [anon_sym_RPAREN] = ACTIONS(5428),
    [anon_sym_RBRACE] = ACTIONS(5428),
    [anon_sym_LT] = ACTIONS(5430),
    [anon_sym_GT] = ACTIONS(5430),
    [anon_sym_in] = ACTIONS(5428),
    [anon_sym_where] = ACTIONS(5428),
    [anon_sym_QMARK] = ACTIONS(5430),
    [anon_sym_BANG] = ACTIONS(5430),
    [anon_sym_PLUS_PLUS] = ACTIONS(5428),
    [anon_sym_DASH_DASH] = ACTIONS(5428),
    [anon_sym_PLUS] = ACTIONS(5430),
    [anon_sym_DASH] = ACTIONS(5430),
    [anon_sym_STAR] = ACTIONS(5428),
    [anon_sym_SLASH] = ACTIONS(5430),
    [anon_sym_PERCENT] = ACTIONS(5428),
    [anon_sym_CARET] = ACTIONS(5428),
    [anon_sym_PIPE] = ACTIONS(5430),
    [anon_sym_AMP] = ACTIONS(5430),
    [anon_sym_LT_LT] = ACTIONS(5428),
    [anon_sym_GT_GT] = ACTIONS(5430),
    [anon_sym_GT_GT_GT] = ACTIONS(5428),
    [anon_sym_EQ_EQ] = ACTIONS(5428),
    [anon_sym_BANG_EQ] = ACTIONS(5428),
    [anon_sym_GT_EQ] = ACTIONS(5428),
    [anon_sym_LT_EQ] = ACTIONS(5428),
    [anon_sym_DOT] = ACTIONS(5430),
    [anon_sym_EQ_GT] = ACTIONS(5428),
    [anon_sym_switch] = ACTIONS(5428),
    [anon_sym_DOT_DOT] = ACTIONS(5428),
    [anon_sym_and] = ACTIONS(5428),
    [anon_sym_or] = ACTIONS(5430),
    [anon_sym_AMP_AMP] = ACTIONS(5428),
    [anon_sym_PIPE_PIPE] = ACTIONS(5428),
    [anon_sym_QMARK_QMARK] = ACTIONS(5428),
    [anon_sym_from] = ACTIONS(5428),
    [anon_sym_join] = ACTIONS(5428),
    [anon_sym_on] = ACTIONS(5428),
    [anon_sym_equals] = ACTIONS(5428),
    [anon_sym_let] = ACTIONS(5428),
    [anon_sym_orderby] = ACTIONS(5428),
    [anon_sym_group] = ACTIONS(5428),
    [anon_sym_by] = ACTIONS(5428),
    [anon_sym_select] = ACTIONS(5428),
    [anon_sym_as] = ACTIONS(5428),
    [anon_sym_is] = ACTIONS(5428),
    [anon_sym_DASH_GT] = ACTIONS(5428),
    [anon_sym_with] = ACTIONS(5428),
    [aux_sym_preproc_if_token3] = ACTIONS(5428),
    [aux_sym_preproc_else_token1] = ACTIONS(5428),
    [aux_sym_preproc_elif_token1] = ACTIONS(5428),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3775] = {
    [sym_preproc_region] = STATE(3775),
    [sym_preproc_endregion] = STATE(3775),
    [sym_preproc_line] = STATE(3775),
    [sym_preproc_pragma] = STATE(3775),
    [sym_preproc_nullable] = STATE(3775),
    [sym_preproc_error] = STATE(3775),
    [sym_preproc_warning] = STATE(3775),
    [sym_preproc_define] = STATE(3775),
    [sym_preproc_undef] = STATE(3775),
    [anon_sym_SEMI] = ACTIONS(4765),
    [anon_sym_LBRACK] = ACTIONS(4765),
    [anon_sym_COLON] = ACTIONS(4765),
    [anon_sym_COMMA] = ACTIONS(4765),
    [anon_sym_RBRACK] = ACTIONS(4765),
    [anon_sym_LPAREN] = ACTIONS(4765),
    [anon_sym_RPAREN] = ACTIONS(4765),
    [anon_sym_RBRACE] = ACTIONS(4765),
    [anon_sym_LT] = ACTIONS(4767),
    [anon_sym_GT] = ACTIONS(4767),
    [anon_sym_in] = ACTIONS(4765),
    [anon_sym_where] = ACTIONS(4765),
    [anon_sym_QMARK] = ACTIONS(4767),
    [anon_sym_BANG] = ACTIONS(4767),
    [anon_sym_PLUS_PLUS] = ACTIONS(4765),
    [anon_sym_DASH_DASH] = ACTIONS(4765),
    [anon_sym_PLUS] = ACTIONS(4767),
    [anon_sym_DASH] = ACTIONS(4767),
    [anon_sym_STAR] = ACTIONS(4765),
    [anon_sym_SLASH] = ACTIONS(4767),
    [anon_sym_PERCENT] = ACTIONS(4765),
    [anon_sym_CARET] = ACTIONS(4765),
    [anon_sym_PIPE] = ACTIONS(4767),
    [anon_sym_AMP] = ACTIONS(4767),
    [anon_sym_LT_LT] = ACTIONS(4765),
    [anon_sym_GT_GT] = ACTIONS(4767),
    [anon_sym_GT_GT_GT] = ACTIONS(4765),
    [anon_sym_EQ_EQ] = ACTIONS(4765),
    [anon_sym_BANG_EQ] = ACTIONS(4765),
    [anon_sym_GT_EQ] = ACTIONS(4765),
    [anon_sym_LT_EQ] = ACTIONS(4765),
    [anon_sym_DOT] = ACTIONS(4767),
    [anon_sym_EQ_GT] = ACTIONS(4765),
    [anon_sym_switch] = ACTIONS(4765),
    [anon_sym_DOT_DOT] = ACTIONS(4765),
    [anon_sym_and] = ACTIONS(4765),
    [anon_sym_or] = ACTIONS(4767),
    [anon_sym_AMP_AMP] = ACTIONS(4765),
    [anon_sym_PIPE_PIPE] = ACTIONS(4765),
    [anon_sym_QMARK_QMARK] = ACTIONS(4765),
    [anon_sym_from] = ACTIONS(4765),
    [anon_sym_join] = ACTIONS(4765),
    [anon_sym_on] = ACTIONS(4765),
    [anon_sym_equals] = ACTIONS(4765),
    [anon_sym_let] = ACTIONS(4765),
    [anon_sym_orderby] = ACTIONS(4765),
    [anon_sym_group] = ACTIONS(4765),
    [anon_sym_by] = ACTIONS(4765),
    [anon_sym_select] = ACTIONS(4765),
    [anon_sym_as] = ACTIONS(4765),
    [anon_sym_is] = ACTIONS(4765),
    [anon_sym_DASH_GT] = ACTIONS(4765),
    [anon_sym_with] = ACTIONS(4765),
    [aux_sym_preproc_if_token3] = ACTIONS(4765),
    [aux_sym_preproc_else_token1] = ACTIONS(4765),
    [aux_sym_preproc_elif_token1] = ACTIONS(4765),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3776] = {
    [sym_preproc_region] = STATE(3776),
    [sym_preproc_endregion] = STATE(3776),
    [sym_preproc_line] = STATE(3776),
    [sym_preproc_pragma] = STATE(3776),
    [sym_preproc_nullable] = STATE(3776),
    [sym_preproc_error] = STATE(3776),
    [sym_preproc_warning] = STATE(3776),
    [sym_preproc_define] = STATE(3776),
    [sym_preproc_undef] = STATE(3776),
    [anon_sym_SEMI] = ACTIONS(3001),
    [anon_sym_LBRACK] = ACTIONS(3001),
    [anon_sym_COLON] = ACTIONS(3001),
    [anon_sym_COMMA] = ACTIONS(3001),
    [anon_sym_RBRACK] = ACTIONS(3001),
    [anon_sym_LPAREN] = ACTIONS(3001),
    [anon_sym_RPAREN] = ACTIONS(3001),
    [anon_sym_RBRACE] = ACTIONS(3001),
    [anon_sym_LT] = ACTIONS(2999),
    [anon_sym_GT] = ACTIONS(2999),
    [anon_sym_in] = ACTIONS(3001),
    [anon_sym_where] = ACTIONS(3001),
    [anon_sym_QMARK] = ACTIONS(2999),
    [anon_sym_BANG] = ACTIONS(2999),
    [anon_sym_PLUS_PLUS] = ACTIONS(3001),
    [anon_sym_DASH_DASH] = ACTIONS(3001),
    [anon_sym_PLUS] = ACTIONS(2999),
    [anon_sym_DASH] = ACTIONS(2999),
    [anon_sym_STAR] = ACTIONS(3001),
    [anon_sym_SLASH] = ACTIONS(2999),
    [anon_sym_PERCENT] = ACTIONS(3001),
    [anon_sym_CARET] = ACTIONS(3001),
    [anon_sym_PIPE] = ACTIONS(2999),
    [anon_sym_AMP] = ACTIONS(2999),
    [anon_sym_LT_LT] = ACTIONS(3001),
    [anon_sym_GT_GT] = ACTIONS(2999),
    [anon_sym_GT_GT_GT] = ACTIONS(3001),
    [anon_sym_EQ_EQ] = ACTIONS(3001),
    [anon_sym_BANG_EQ] = ACTIONS(3001),
    [anon_sym_GT_EQ] = ACTIONS(3001),
    [anon_sym_LT_EQ] = ACTIONS(3001),
    [anon_sym_DOT] = ACTIONS(2999),
    [anon_sym_EQ_GT] = ACTIONS(3001),
    [anon_sym_switch] = ACTIONS(3001),
    [anon_sym_DOT_DOT] = ACTIONS(3001),
    [anon_sym_and] = ACTIONS(3001),
    [anon_sym_or] = ACTIONS(2999),
    [anon_sym_AMP_AMP] = ACTIONS(3001),
    [anon_sym_PIPE_PIPE] = ACTIONS(3001),
    [anon_sym_QMARK_QMARK] = ACTIONS(3001),
    [anon_sym_from] = ACTIONS(3001),
    [anon_sym_join] = ACTIONS(3001),
    [anon_sym_on] = ACTIONS(3001),
    [anon_sym_equals] = ACTIONS(3001),
    [anon_sym_let] = ACTIONS(3001),
    [anon_sym_orderby] = ACTIONS(3001),
    [anon_sym_group] = ACTIONS(3001),
    [anon_sym_by] = ACTIONS(3001),
    [anon_sym_select] = ACTIONS(3001),
    [anon_sym_as] = ACTIONS(3001),
    [anon_sym_is] = ACTIONS(3001),
    [anon_sym_DASH_GT] = ACTIONS(3001),
    [anon_sym_with] = ACTIONS(3001),
    [aux_sym_preproc_if_token3] = ACTIONS(3001),
    [aux_sym_preproc_else_token1] = ACTIONS(3001),
    [aux_sym_preproc_elif_token1] = ACTIONS(3001),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3777] = {
    [sym_preproc_region] = STATE(3777),
    [sym_preproc_endregion] = STATE(3777),
    [sym_preproc_line] = STATE(3777),
    [sym_preproc_pragma] = STATE(3777),
    [sym_preproc_nullable] = STATE(3777),
    [sym_preproc_error] = STATE(3777),
    [sym_preproc_warning] = STATE(3777),
    [sym_preproc_define] = STATE(3777),
    [sym_preproc_undef] = STATE(3777),
    [anon_sym_SEMI] = ACTIONS(5596),
    [anon_sym_LBRACK] = ACTIONS(5596),
    [anon_sym_COLON] = ACTIONS(5596),
    [anon_sym_COMMA] = ACTIONS(5596),
    [anon_sym_RBRACK] = ACTIONS(5596),
    [anon_sym_LPAREN] = ACTIONS(5596),
    [anon_sym_RPAREN] = ACTIONS(5596),
    [anon_sym_RBRACE] = ACTIONS(5596),
    [anon_sym_LT] = ACTIONS(5598),
    [anon_sym_GT] = ACTIONS(5598),
    [anon_sym_in] = ACTIONS(5596),
    [anon_sym_where] = ACTIONS(5596),
    [anon_sym_QMARK] = ACTIONS(5598),
    [anon_sym_BANG] = ACTIONS(5598),
    [anon_sym_PLUS_PLUS] = ACTIONS(5596),
    [anon_sym_DASH_DASH] = ACTIONS(5596),
    [anon_sym_PLUS] = ACTIONS(5598),
    [anon_sym_DASH] = ACTIONS(5598),
    [anon_sym_STAR] = ACTIONS(5596),
    [anon_sym_SLASH] = ACTIONS(5598),
    [anon_sym_PERCENT] = ACTIONS(5596),
    [anon_sym_CARET] = ACTIONS(5596),
    [anon_sym_PIPE] = ACTIONS(5598),
    [anon_sym_AMP] = ACTIONS(5598),
    [anon_sym_LT_LT] = ACTIONS(5596),
    [anon_sym_GT_GT] = ACTIONS(5598),
    [anon_sym_GT_GT_GT] = ACTIONS(5596),
    [anon_sym_EQ_EQ] = ACTIONS(5596),
    [anon_sym_BANG_EQ] = ACTIONS(5596),
    [anon_sym_GT_EQ] = ACTIONS(5596),
    [anon_sym_LT_EQ] = ACTIONS(5596),
    [anon_sym_DOT] = ACTIONS(5598),
    [anon_sym_EQ_GT] = ACTIONS(5596),
    [anon_sym_switch] = ACTIONS(5596),
    [anon_sym_DOT_DOT] = ACTIONS(5596),
    [anon_sym_and] = ACTIONS(5596),
    [anon_sym_or] = ACTIONS(5598),
    [anon_sym_AMP_AMP] = ACTIONS(5596),
    [anon_sym_PIPE_PIPE] = ACTIONS(5596),
    [anon_sym_QMARK_QMARK] = ACTIONS(5596),
    [anon_sym_from] = ACTIONS(5596),
    [anon_sym_join] = ACTIONS(5596),
    [anon_sym_on] = ACTIONS(5596),
    [anon_sym_equals] = ACTIONS(5596),
    [anon_sym_let] = ACTIONS(5596),
    [anon_sym_orderby] = ACTIONS(5596),
    [anon_sym_group] = ACTIONS(5596),
    [anon_sym_by] = ACTIONS(5596),
    [anon_sym_select] = ACTIONS(5596),
    [anon_sym_as] = ACTIONS(5596),
    [anon_sym_is] = ACTIONS(5596),
    [anon_sym_DASH_GT] = ACTIONS(5596),
    [anon_sym_with] = ACTIONS(5596),
    [aux_sym_preproc_if_token3] = ACTIONS(5596),
    [aux_sym_preproc_else_token1] = ACTIONS(5596),
    [aux_sym_preproc_elif_token1] = ACTIONS(5596),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3778] = {
    [sym_preproc_region] = STATE(3778),
    [sym_preproc_endregion] = STATE(3778),
    [sym_preproc_line] = STATE(3778),
    [sym_preproc_pragma] = STATE(3778),
    [sym_preproc_nullable] = STATE(3778),
    [sym_preproc_error] = STATE(3778),
    [sym_preproc_warning] = STATE(3778),
    [sym_preproc_define] = STATE(3778),
    [sym_preproc_undef] = STATE(3778),
    [anon_sym_SEMI] = ACTIONS(5412),
    [anon_sym_LBRACK] = ACTIONS(5412),
    [anon_sym_COLON] = ACTIONS(5412),
    [anon_sym_COMMA] = ACTIONS(5412),
    [anon_sym_RBRACK] = ACTIONS(5412),
    [anon_sym_LPAREN] = ACTIONS(5412),
    [anon_sym_RPAREN] = ACTIONS(5412),
    [anon_sym_RBRACE] = ACTIONS(5412),
    [anon_sym_LT] = ACTIONS(5414),
    [anon_sym_GT] = ACTIONS(5414),
    [anon_sym_in] = ACTIONS(5412),
    [anon_sym_where] = ACTIONS(5412),
    [anon_sym_QMARK] = ACTIONS(5414),
    [anon_sym_BANG] = ACTIONS(5414),
    [anon_sym_PLUS_PLUS] = ACTIONS(5412),
    [anon_sym_DASH_DASH] = ACTIONS(5412),
    [anon_sym_PLUS] = ACTIONS(5414),
    [anon_sym_DASH] = ACTIONS(5414),
    [anon_sym_STAR] = ACTIONS(5412),
    [anon_sym_SLASH] = ACTIONS(5414),
    [anon_sym_PERCENT] = ACTIONS(5412),
    [anon_sym_CARET] = ACTIONS(5412),
    [anon_sym_PIPE] = ACTIONS(5414),
    [anon_sym_AMP] = ACTIONS(5414),
    [anon_sym_LT_LT] = ACTIONS(5412),
    [anon_sym_GT_GT] = ACTIONS(5414),
    [anon_sym_GT_GT_GT] = ACTIONS(5412),
    [anon_sym_EQ_EQ] = ACTIONS(5412),
    [anon_sym_BANG_EQ] = ACTIONS(5412),
    [anon_sym_GT_EQ] = ACTIONS(5412),
    [anon_sym_LT_EQ] = ACTIONS(5412),
    [anon_sym_DOT] = ACTIONS(5414),
    [anon_sym_EQ_GT] = ACTIONS(5412),
    [anon_sym_switch] = ACTIONS(5412),
    [anon_sym_DOT_DOT] = ACTIONS(5412),
    [anon_sym_and] = ACTIONS(5412),
    [anon_sym_or] = ACTIONS(5414),
    [anon_sym_AMP_AMP] = ACTIONS(5412),
    [anon_sym_PIPE_PIPE] = ACTIONS(5412),
    [anon_sym_QMARK_QMARK] = ACTIONS(5412),
    [anon_sym_from] = ACTIONS(5412),
    [anon_sym_join] = ACTIONS(5412),
    [anon_sym_on] = ACTIONS(5412),
    [anon_sym_equals] = ACTIONS(5412),
    [anon_sym_let] = ACTIONS(5412),
    [anon_sym_orderby] = ACTIONS(5412),
    [anon_sym_group] = ACTIONS(5412),
    [anon_sym_by] = ACTIONS(5412),
    [anon_sym_select] = ACTIONS(5412),
    [anon_sym_as] = ACTIONS(5412),
    [anon_sym_is] = ACTIONS(5412),
    [anon_sym_DASH_GT] = ACTIONS(5412),
    [anon_sym_with] = ACTIONS(5412),
    [aux_sym_preproc_if_token3] = ACTIONS(5412),
    [aux_sym_preproc_else_token1] = ACTIONS(5412),
    [aux_sym_preproc_elif_token1] = ACTIONS(5412),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3779] = {
    [sym_preproc_region] = STATE(3779),
    [sym_preproc_endregion] = STATE(3779),
    [sym_preproc_line] = STATE(3779),
    [sym_preproc_pragma] = STATE(3779),
    [sym_preproc_nullable] = STATE(3779),
    [sym_preproc_error] = STATE(3779),
    [sym_preproc_warning] = STATE(3779),
    [sym_preproc_define] = STATE(3779),
    [sym_preproc_undef] = STATE(3779),
    [sym__identifier_token] = ACTIONS(5719),
    [anon_sym_extern] = ACTIONS(5719),
    [anon_sym_alias] = ACTIONS(5719),
    [anon_sym_global] = ACTIONS(5719),
    [anon_sym_unsafe] = ACTIONS(5719),
    [anon_sym_static] = ACTIONS(5719),
    [anon_sym_LBRACK] = ACTIONS(5721),
    [anon_sym_LPAREN] = ACTIONS(5721),
    [anon_sym_event] = ACTIONS(5719),
    [anon_sym_class] = ACTIONS(5719),
    [anon_sym_ref] = ACTIONS(5719),
    [anon_sym_struct] = ACTIONS(5719),
    [anon_sym_enum] = ACTIONS(5719),
    [anon_sym_interface] = ACTIONS(5719),
    [anon_sym_delegate] = ACTIONS(5719),
    [anon_sym_record] = ACTIONS(5719),
    [anon_sym_abstract] = ACTIONS(5719),
    [anon_sym_async] = ACTIONS(5719),
    [anon_sym_const] = ACTIONS(5719),
    [anon_sym_file] = ACTIONS(5719),
    [anon_sym_fixed] = ACTIONS(5719),
    [anon_sym_internal] = ACTIONS(5719),
    [anon_sym_new] = ACTIONS(5719),
    [anon_sym_override] = ACTIONS(5719),
    [anon_sym_partial] = ACTIONS(5719),
    [anon_sym_private] = ACTIONS(5719),
    [anon_sym_protected] = ACTIONS(5719),
    [anon_sym_public] = ACTIONS(5719),
    [anon_sym_readonly] = ACTIONS(5719),
    [anon_sym_required] = ACTIONS(5719),
    [anon_sym_sealed] = ACTIONS(5719),
    [anon_sym_virtual] = ACTIONS(5719),
    [anon_sym_volatile] = ACTIONS(5719),
    [anon_sym_where] = ACTIONS(5719),
    [anon_sym_notnull] = ACTIONS(5719),
    [anon_sym_unmanaged] = ACTIONS(5719),
    [anon_sym_TILDE] = ACTIONS(5721),
    [anon_sym_implicit] = ACTIONS(5719),
    [anon_sym_explicit] = ACTIONS(5719),
    [anon_sym_scoped] = ACTIONS(5719),
    [anon_sym_var] = ACTIONS(5719),
    [sym_predefined_type] = ACTIONS(5719),
    [anon_sym_yield] = ACTIONS(5719),
    [anon_sym_when] = ACTIONS(5719),
    [anon_sym_from] = ACTIONS(5719),
    [anon_sym_into] = ACTIONS(5719),
    [anon_sym_join] = ACTIONS(5719),
    [anon_sym_on] = ACTIONS(5719),
    [anon_sym_equals] = ACTIONS(5719),
    [anon_sym_let] = ACTIONS(5719),
    [anon_sym_orderby] = ACTIONS(5719),
    [anon_sym_ascending] = ACTIONS(5719),
    [anon_sym_descending] = ACTIONS(5719),
    [anon_sym_group] = ACTIONS(5719),
    [anon_sym_by] = ACTIONS(5719),
    [anon_sym_select] = ACTIONS(5719),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3780] = {
    [sym_preproc_region] = STATE(3780),
    [sym_preproc_endregion] = STATE(3780),
    [sym_preproc_line] = STATE(3780),
    [sym_preproc_pragma] = STATE(3780),
    [sym_preproc_nullable] = STATE(3780),
    [sym_preproc_error] = STATE(3780),
    [sym_preproc_warning] = STATE(3780),
    [sym_preproc_define] = STATE(3780),
    [sym_preproc_undef] = STATE(3780),
    [anon_sym_SEMI] = ACTIONS(5424),
    [anon_sym_LBRACK] = ACTIONS(5424),
    [anon_sym_COLON] = ACTIONS(5424),
    [anon_sym_COMMA] = ACTIONS(5424),
    [anon_sym_RBRACK] = ACTIONS(5424),
    [anon_sym_LPAREN] = ACTIONS(5424),
    [anon_sym_RPAREN] = ACTIONS(5424),
    [anon_sym_RBRACE] = ACTIONS(5424),
    [anon_sym_LT] = ACTIONS(5426),
    [anon_sym_GT] = ACTIONS(5426),
    [anon_sym_in] = ACTIONS(5424),
    [anon_sym_where] = ACTIONS(5424),
    [anon_sym_QMARK] = ACTIONS(5426),
    [anon_sym_BANG] = ACTIONS(5426),
    [anon_sym_PLUS_PLUS] = ACTIONS(5424),
    [anon_sym_DASH_DASH] = ACTIONS(5424),
    [anon_sym_PLUS] = ACTIONS(5426),
    [anon_sym_DASH] = ACTIONS(5426),
    [anon_sym_STAR] = ACTIONS(5424),
    [anon_sym_SLASH] = ACTIONS(5426),
    [anon_sym_PERCENT] = ACTIONS(5424),
    [anon_sym_CARET] = ACTIONS(5424),
    [anon_sym_PIPE] = ACTIONS(5426),
    [anon_sym_AMP] = ACTIONS(5426),
    [anon_sym_LT_LT] = ACTIONS(5424),
    [anon_sym_GT_GT] = ACTIONS(5426),
    [anon_sym_GT_GT_GT] = ACTIONS(5424),
    [anon_sym_EQ_EQ] = ACTIONS(5424),
    [anon_sym_BANG_EQ] = ACTIONS(5424),
    [anon_sym_GT_EQ] = ACTIONS(5424),
    [anon_sym_LT_EQ] = ACTIONS(5424),
    [anon_sym_DOT] = ACTIONS(5426),
    [anon_sym_EQ_GT] = ACTIONS(5424),
    [anon_sym_switch] = ACTIONS(5424),
    [anon_sym_DOT_DOT] = ACTIONS(5424),
    [anon_sym_and] = ACTIONS(5424),
    [anon_sym_or] = ACTIONS(5426),
    [anon_sym_AMP_AMP] = ACTIONS(5424),
    [anon_sym_PIPE_PIPE] = ACTIONS(5424),
    [anon_sym_QMARK_QMARK] = ACTIONS(5424),
    [anon_sym_from] = ACTIONS(5424),
    [anon_sym_join] = ACTIONS(5424),
    [anon_sym_on] = ACTIONS(5424),
    [anon_sym_equals] = ACTIONS(5424),
    [anon_sym_let] = ACTIONS(5424),
    [anon_sym_orderby] = ACTIONS(5424),
    [anon_sym_group] = ACTIONS(5424),
    [anon_sym_by] = ACTIONS(5424),
    [anon_sym_select] = ACTIONS(5424),
    [anon_sym_as] = ACTIONS(5424),
    [anon_sym_is] = ACTIONS(5424),
    [anon_sym_DASH_GT] = ACTIONS(5424),
    [anon_sym_with] = ACTIONS(5424),
    [aux_sym_preproc_if_token3] = ACTIONS(5424),
    [aux_sym_preproc_else_token1] = ACTIONS(5424),
    [aux_sym_preproc_elif_token1] = ACTIONS(5424),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3781] = {
    [sym_preproc_region] = STATE(3781),
    [sym_preproc_endregion] = STATE(3781),
    [sym_preproc_line] = STATE(3781),
    [sym_preproc_pragma] = STATE(3781),
    [sym_preproc_nullable] = STATE(3781),
    [sym_preproc_error] = STATE(3781),
    [sym_preproc_warning] = STATE(3781),
    [sym_preproc_define] = STATE(3781),
    [sym_preproc_undef] = STATE(3781),
    [anon_sym_SEMI] = ACTIONS(5656),
    [anon_sym_LBRACK] = ACTIONS(5656),
    [anon_sym_COLON] = ACTIONS(5656),
    [anon_sym_COMMA] = ACTIONS(5656),
    [anon_sym_RBRACK] = ACTIONS(5656),
    [anon_sym_LPAREN] = ACTIONS(5656),
    [anon_sym_RPAREN] = ACTIONS(5656),
    [anon_sym_RBRACE] = ACTIONS(5656),
    [anon_sym_LT] = ACTIONS(5658),
    [anon_sym_GT] = ACTIONS(5658),
    [anon_sym_in] = ACTIONS(5656),
    [anon_sym_where] = ACTIONS(5656),
    [anon_sym_QMARK] = ACTIONS(5658),
    [anon_sym_BANG] = ACTIONS(5658),
    [anon_sym_PLUS_PLUS] = ACTIONS(5656),
    [anon_sym_DASH_DASH] = ACTIONS(5656),
    [anon_sym_PLUS] = ACTIONS(5658),
    [anon_sym_DASH] = ACTIONS(5658),
    [anon_sym_STAR] = ACTIONS(5656),
    [anon_sym_SLASH] = ACTIONS(5658),
    [anon_sym_PERCENT] = ACTIONS(5656),
    [anon_sym_CARET] = ACTIONS(5656),
    [anon_sym_PIPE] = ACTIONS(5658),
    [anon_sym_AMP] = ACTIONS(5658),
    [anon_sym_LT_LT] = ACTIONS(5656),
    [anon_sym_GT_GT] = ACTIONS(5658),
    [anon_sym_GT_GT_GT] = ACTIONS(5656),
    [anon_sym_EQ_EQ] = ACTIONS(5656),
    [anon_sym_BANG_EQ] = ACTIONS(5656),
    [anon_sym_GT_EQ] = ACTIONS(5656),
    [anon_sym_LT_EQ] = ACTIONS(5656),
    [anon_sym_DOT] = ACTIONS(5658),
    [anon_sym_EQ_GT] = ACTIONS(5656),
    [anon_sym_switch] = ACTIONS(5656),
    [anon_sym_DOT_DOT] = ACTIONS(5656),
    [anon_sym_and] = ACTIONS(5656),
    [anon_sym_or] = ACTIONS(5658),
    [anon_sym_AMP_AMP] = ACTIONS(5656),
    [anon_sym_PIPE_PIPE] = ACTIONS(5656),
    [anon_sym_QMARK_QMARK] = ACTIONS(5656),
    [anon_sym_from] = ACTIONS(5656),
    [anon_sym_join] = ACTIONS(5656),
    [anon_sym_on] = ACTIONS(5656),
    [anon_sym_equals] = ACTIONS(5656),
    [anon_sym_let] = ACTIONS(5656),
    [anon_sym_orderby] = ACTIONS(5656),
    [anon_sym_group] = ACTIONS(5656),
    [anon_sym_by] = ACTIONS(5656),
    [anon_sym_select] = ACTIONS(5656),
    [anon_sym_as] = ACTIONS(5656),
    [anon_sym_is] = ACTIONS(5656),
    [anon_sym_DASH_GT] = ACTIONS(5656),
    [anon_sym_with] = ACTIONS(5656),
    [aux_sym_preproc_if_token3] = ACTIONS(5656),
    [aux_sym_preproc_else_token1] = ACTIONS(5656),
    [aux_sym_preproc_elif_token1] = ACTIONS(5656),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3782] = {
    [sym_preproc_region] = STATE(3782),
    [sym_preproc_endregion] = STATE(3782),
    [sym_preproc_line] = STATE(3782),
    [sym_preproc_pragma] = STATE(3782),
    [sym_preproc_nullable] = STATE(3782),
    [sym_preproc_error] = STATE(3782),
    [sym_preproc_warning] = STATE(3782),
    [sym_preproc_define] = STATE(3782),
    [sym_preproc_undef] = STATE(3782),
    [anon_sym_SEMI] = ACTIONS(5452),
    [anon_sym_LBRACK] = ACTIONS(5452),
    [anon_sym_COLON] = ACTIONS(5452),
    [anon_sym_COMMA] = ACTIONS(5452),
    [anon_sym_RBRACK] = ACTIONS(5452),
    [anon_sym_LPAREN] = ACTIONS(5452),
    [anon_sym_RPAREN] = ACTIONS(5452),
    [anon_sym_RBRACE] = ACTIONS(5452),
    [anon_sym_LT] = ACTIONS(5454),
    [anon_sym_GT] = ACTIONS(5454),
    [anon_sym_in] = ACTIONS(5452),
    [anon_sym_where] = ACTIONS(5452),
    [anon_sym_QMARK] = ACTIONS(5454),
    [anon_sym_BANG] = ACTIONS(5454),
    [anon_sym_PLUS_PLUS] = ACTIONS(5452),
    [anon_sym_DASH_DASH] = ACTIONS(5452),
    [anon_sym_PLUS] = ACTIONS(5454),
    [anon_sym_DASH] = ACTIONS(5454),
    [anon_sym_STAR] = ACTIONS(5452),
    [anon_sym_SLASH] = ACTIONS(5454),
    [anon_sym_PERCENT] = ACTIONS(5452),
    [anon_sym_CARET] = ACTIONS(5452),
    [anon_sym_PIPE] = ACTIONS(5454),
    [anon_sym_AMP] = ACTIONS(5454),
    [anon_sym_LT_LT] = ACTIONS(5452),
    [anon_sym_GT_GT] = ACTIONS(5454),
    [anon_sym_GT_GT_GT] = ACTIONS(5452),
    [anon_sym_EQ_EQ] = ACTIONS(5452),
    [anon_sym_BANG_EQ] = ACTIONS(5452),
    [anon_sym_GT_EQ] = ACTIONS(5452),
    [anon_sym_LT_EQ] = ACTIONS(5452),
    [anon_sym_DOT] = ACTIONS(5454),
    [anon_sym_EQ_GT] = ACTIONS(5452),
    [anon_sym_switch] = ACTIONS(5452),
    [anon_sym_DOT_DOT] = ACTIONS(5452),
    [anon_sym_and] = ACTIONS(5452),
    [anon_sym_or] = ACTIONS(5454),
    [anon_sym_AMP_AMP] = ACTIONS(5452),
    [anon_sym_PIPE_PIPE] = ACTIONS(5452),
    [anon_sym_QMARK_QMARK] = ACTIONS(5452),
    [anon_sym_from] = ACTIONS(5452),
    [anon_sym_join] = ACTIONS(5452),
    [anon_sym_on] = ACTIONS(5452),
    [anon_sym_equals] = ACTIONS(5452),
    [anon_sym_let] = ACTIONS(5452),
    [anon_sym_orderby] = ACTIONS(5452),
    [anon_sym_group] = ACTIONS(5452),
    [anon_sym_by] = ACTIONS(5452),
    [anon_sym_select] = ACTIONS(5452),
    [anon_sym_as] = ACTIONS(5452),
    [anon_sym_is] = ACTIONS(5452),
    [anon_sym_DASH_GT] = ACTIONS(5452),
    [anon_sym_with] = ACTIONS(5452),
    [aux_sym_preproc_if_token3] = ACTIONS(5452),
    [aux_sym_preproc_else_token1] = ACTIONS(5452),
    [aux_sym_preproc_elif_token1] = ACTIONS(5452),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3783] = {
    [sym_preproc_region] = STATE(3783),
    [sym_preproc_endregion] = STATE(3783),
    [sym_preproc_line] = STATE(3783),
    [sym_preproc_pragma] = STATE(3783),
    [sym_preproc_nullable] = STATE(3783),
    [sym_preproc_error] = STATE(3783),
    [sym_preproc_warning] = STATE(3783),
    [sym_preproc_define] = STATE(3783),
    [sym_preproc_undef] = STATE(3783),
    [anon_sym_SEMI] = ACTIONS(5564),
    [anon_sym_LBRACK] = ACTIONS(5564),
    [anon_sym_COLON] = ACTIONS(5564),
    [anon_sym_COMMA] = ACTIONS(5564),
    [anon_sym_RBRACK] = ACTIONS(5564),
    [anon_sym_LPAREN] = ACTIONS(5564),
    [anon_sym_RPAREN] = ACTIONS(5564),
    [anon_sym_RBRACE] = ACTIONS(5564),
    [anon_sym_LT] = ACTIONS(5566),
    [anon_sym_GT] = ACTIONS(5566),
    [anon_sym_in] = ACTIONS(5564),
    [anon_sym_where] = ACTIONS(5564),
    [anon_sym_QMARK] = ACTIONS(5566),
    [anon_sym_BANG] = ACTIONS(5566),
    [anon_sym_PLUS_PLUS] = ACTIONS(5564),
    [anon_sym_DASH_DASH] = ACTIONS(5564),
    [anon_sym_PLUS] = ACTIONS(5566),
    [anon_sym_DASH] = ACTIONS(5566),
    [anon_sym_STAR] = ACTIONS(5564),
    [anon_sym_SLASH] = ACTIONS(5566),
    [anon_sym_PERCENT] = ACTIONS(5564),
    [anon_sym_CARET] = ACTIONS(5564),
    [anon_sym_PIPE] = ACTIONS(5566),
    [anon_sym_AMP] = ACTIONS(5566),
    [anon_sym_LT_LT] = ACTIONS(5564),
    [anon_sym_GT_GT] = ACTIONS(5566),
    [anon_sym_GT_GT_GT] = ACTIONS(5564),
    [anon_sym_EQ_EQ] = ACTIONS(5564),
    [anon_sym_BANG_EQ] = ACTIONS(5564),
    [anon_sym_GT_EQ] = ACTIONS(5564),
    [anon_sym_LT_EQ] = ACTIONS(5564),
    [anon_sym_DOT] = ACTIONS(5566),
    [anon_sym_EQ_GT] = ACTIONS(5564),
    [anon_sym_switch] = ACTIONS(5564),
    [anon_sym_DOT_DOT] = ACTIONS(5564),
    [anon_sym_and] = ACTIONS(5564),
    [anon_sym_or] = ACTIONS(5566),
    [anon_sym_AMP_AMP] = ACTIONS(5564),
    [anon_sym_PIPE_PIPE] = ACTIONS(5564),
    [anon_sym_QMARK_QMARK] = ACTIONS(5564),
    [anon_sym_from] = ACTIONS(5564),
    [anon_sym_join] = ACTIONS(5564),
    [anon_sym_on] = ACTIONS(5564),
    [anon_sym_equals] = ACTIONS(5564),
    [anon_sym_let] = ACTIONS(5564),
    [anon_sym_orderby] = ACTIONS(5564),
    [anon_sym_group] = ACTIONS(5564),
    [anon_sym_by] = ACTIONS(5564),
    [anon_sym_select] = ACTIONS(5564),
    [anon_sym_as] = ACTIONS(5564),
    [anon_sym_is] = ACTIONS(5564),
    [anon_sym_DASH_GT] = ACTIONS(5564),
    [anon_sym_with] = ACTIONS(5564),
    [aux_sym_preproc_if_token3] = ACTIONS(5564),
    [aux_sym_preproc_else_token1] = ACTIONS(5564),
    [aux_sym_preproc_elif_token1] = ACTIONS(5564),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3784] = {
    [sym_preproc_region] = STATE(3784),
    [sym_preproc_endregion] = STATE(3784),
    [sym_preproc_line] = STATE(3784),
    [sym_preproc_pragma] = STATE(3784),
    [sym_preproc_nullable] = STATE(3784),
    [sym_preproc_error] = STATE(3784),
    [sym_preproc_warning] = STATE(3784),
    [sym_preproc_define] = STATE(3784),
    [sym_preproc_undef] = STATE(3784),
    [anon_sym_SEMI] = ACTIONS(5568),
    [anon_sym_LBRACK] = ACTIONS(5568),
    [anon_sym_COLON] = ACTIONS(5568),
    [anon_sym_COMMA] = ACTIONS(5568),
    [anon_sym_RBRACK] = ACTIONS(5568),
    [anon_sym_LPAREN] = ACTIONS(5568),
    [anon_sym_RPAREN] = ACTIONS(5568),
    [anon_sym_RBRACE] = ACTIONS(5568),
    [anon_sym_LT] = ACTIONS(5570),
    [anon_sym_GT] = ACTIONS(5570),
    [anon_sym_in] = ACTIONS(5568),
    [anon_sym_where] = ACTIONS(5568),
    [anon_sym_QMARK] = ACTIONS(5570),
    [anon_sym_BANG] = ACTIONS(5570),
    [anon_sym_PLUS_PLUS] = ACTIONS(5568),
    [anon_sym_DASH_DASH] = ACTIONS(5568),
    [anon_sym_PLUS] = ACTIONS(5570),
    [anon_sym_DASH] = ACTIONS(5570),
    [anon_sym_STAR] = ACTIONS(5568),
    [anon_sym_SLASH] = ACTIONS(5570),
    [anon_sym_PERCENT] = ACTIONS(5568),
    [anon_sym_CARET] = ACTIONS(5568),
    [anon_sym_PIPE] = ACTIONS(5570),
    [anon_sym_AMP] = ACTIONS(5570),
    [anon_sym_LT_LT] = ACTIONS(5568),
    [anon_sym_GT_GT] = ACTIONS(5570),
    [anon_sym_GT_GT_GT] = ACTIONS(5568),
    [anon_sym_EQ_EQ] = ACTIONS(5568),
    [anon_sym_BANG_EQ] = ACTIONS(5568),
    [anon_sym_GT_EQ] = ACTIONS(5568),
    [anon_sym_LT_EQ] = ACTIONS(5568),
    [anon_sym_DOT] = ACTIONS(5570),
    [anon_sym_EQ_GT] = ACTIONS(5568),
    [anon_sym_switch] = ACTIONS(5568),
    [anon_sym_DOT_DOT] = ACTIONS(5568),
    [anon_sym_and] = ACTIONS(5568),
    [anon_sym_or] = ACTIONS(5570),
    [anon_sym_AMP_AMP] = ACTIONS(5568),
    [anon_sym_PIPE_PIPE] = ACTIONS(5568),
    [anon_sym_QMARK_QMARK] = ACTIONS(5568),
    [anon_sym_from] = ACTIONS(5568),
    [anon_sym_join] = ACTIONS(5568),
    [anon_sym_on] = ACTIONS(5568),
    [anon_sym_equals] = ACTIONS(5568),
    [anon_sym_let] = ACTIONS(5568),
    [anon_sym_orderby] = ACTIONS(5568),
    [anon_sym_group] = ACTIONS(5568),
    [anon_sym_by] = ACTIONS(5568),
    [anon_sym_select] = ACTIONS(5568),
    [anon_sym_as] = ACTIONS(5568),
    [anon_sym_is] = ACTIONS(5568),
    [anon_sym_DASH_GT] = ACTIONS(5568),
    [anon_sym_with] = ACTIONS(5568),
    [aux_sym_preproc_if_token3] = ACTIONS(5568),
    [aux_sym_preproc_else_token1] = ACTIONS(5568),
    [aux_sym_preproc_elif_token1] = ACTIONS(5568),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3785] = {
    [sym_preproc_region] = STATE(3785),
    [sym_preproc_endregion] = STATE(3785),
    [sym_preproc_line] = STATE(3785),
    [sym_preproc_pragma] = STATE(3785),
    [sym_preproc_nullable] = STATE(3785),
    [sym_preproc_error] = STATE(3785),
    [sym_preproc_warning] = STATE(3785),
    [sym_preproc_define] = STATE(3785),
    [sym_preproc_undef] = STATE(3785),
    [anon_sym_SEMI] = ACTIONS(2993),
    [anon_sym_LBRACK] = ACTIONS(2993),
    [anon_sym_COLON] = ACTIONS(2993),
    [anon_sym_COMMA] = ACTIONS(2993),
    [anon_sym_RBRACK] = ACTIONS(2993),
    [anon_sym_LPAREN] = ACTIONS(2993),
    [anon_sym_RPAREN] = ACTIONS(2993),
    [anon_sym_RBRACE] = ACTIONS(2993),
    [anon_sym_LT] = ACTIONS(2991),
    [anon_sym_GT] = ACTIONS(2991),
    [anon_sym_in] = ACTIONS(2993),
    [anon_sym_where] = ACTIONS(2993),
    [anon_sym_QMARK] = ACTIONS(2991),
    [anon_sym_BANG] = ACTIONS(2991),
    [anon_sym_PLUS_PLUS] = ACTIONS(2993),
    [anon_sym_DASH_DASH] = ACTIONS(2993),
    [anon_sym_PLUS] = ACTIONS(2991),
    [anon_sym_DASH] = ACTIONS(2991),
    [anon_sym_STAR] = ACTIONS(2993),
    [anon_sym_SLASH] = ACTIONS(2991),
    [anon_sym_PERCENT] = ACTIONS(2993),
    [anon_sym_CARET] = ACTIONS(2993),
    [anon_sym_PIPE] = ACTIONS(2991),
    [anon_sym_AMP] = ACTIONS(2991),
    [anon_sym_LT_LT] = ACTIONS(2993),
    [anon_sym_GT_GT] = ACTIONS(2991),
    [anon_sym_GT_GT_GT] = ACTIONS(2993),
    [anon_sym_EQ_EQ] = ACTIONS(2993),
    [anon_sym_BANG_EQ] = ACTIONS(2993),
    [anon_sym_GT_EQ] = ACTIONS(2993),
    [anon_sym_LT_EQ] = ACTIONS(2993),
    [anon_sym_DOT] = ACTIONS(2991),
    [anon_sym_EQ_GT] = ACTIONS(2993),
    [anon_sym_switch] = ACTIONS(2993),
    [anon_sym_DOT_DOT] = ACTIONS(2993),
    [anon_sym_and] = ACTIONS(2993),
    [anon_sym_or] = ACTIONS(2991),
    [anon_sym_AMP_AMP] = ACTIONS(2993),
    [anon_sym_PIPE_PIPE] = ACTIONS(2993),
    [anon_sym_QMARK_QMARK] = ACTIONS(2993),
    [anon_sym_from] = ACTIONS(2993),
    [anon_sym_join] = ACTIONS(2993),
    [anon_sym_on] = ACTIONS(2993),
    [anon_sym_equals] = ACTIONS(2993),
    [anon_sym_let] = ACTIONS(2993),
    [anon_sym_orderby] = ACTIONS(2993),
    [anon_sym_group] = ACTIONS(2993),
    [anon_sym_by] = ACTIONS(2993),
    [anon_sym_select] = ACTIONS(2993),
    [anon_sym_as] = ACTIONS(2993),
    [anon_sym_is] = ACTIONS(2993),
    [anon_sym_DASH_GT] = ACTIONS(2993),
    [anon_sym_with] = ACTIONS(2993),
    [aux_sym_preproc_if_token3] = ACTIONS(2993),
    [aux_sym_preproc_else_token1] = ACTIONS(2993),
    [aux_sym_preproc_elif_token1] = ACTIONS(2993),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3786] = {
    [sym_preproc_region] = STATE(3786),
    [sym_preproc_endregion] = STATE(3786),
    [sym_preproc_line] = STATE(3786),
    [sym_preproc_pragma] = STATE(3786),
    [sym_preproc_nullable] = STATE(3786),
    [sym_preproc_error] = STATE(3786),
    [sym_preproc_warning] = STATE(3786),
    [sym_preproc_define] = STATE(3786),
    [sym_preproc_undef] = STATE(3786),
    [sym__identifier_token] = ACTIONS(5723),
    [anon_sym_extern] = ACTIONS(5723),
    [anon_sym_alias] = ACTIONS(5723),
    [anon_sym_global] = ACTIONS(5723),
    [anon_sym_unsafe] = ACTIONS(5723),
    [anon_sym_static] = ACTIONS(5723),
    [anon_sym_LBRACK] = ACTIONS(5725),
    [anon_sym_LPAREN] = ACTIONS(5725),
    [anon_sym_event] = ACTIONS(5723),
    [anon_sym_class] = ACTIONS(5723),
    [anon_sym_ref] = ACTIONS(5723),
    [anon_sym_struct] = ACTIONS(5723),
    [anon_sym_enum] = ACTIONS(5723),
    [anon_sym_interface] = ACTIONS(5723),
    [anon_sym_delegate] = ACTIONS(5723),
    [anon_sym_record] = ACTIONS(5723),
    [anon_sym_abstract] = ACTIONS(5723),
    [anon_sym_async] = ACTIONS(5723),
    [anon_sym_const] = ACTIONS(5723),
    [anon_sym_file] = ACTIONS(5723),
    [anon_sym_fixed] = ACTIONS(5723),
    [anon_sym_internal] = ACTIONS(5723),
    [anon_sym_new] = ACTIONS(5723),
    [anon_sym_override] = ACTIONS(5723),
    [anon_sym_partial] = ACTIONS(5723),
    [anon_sym_private] = ACTIONS(5723),
    [anon_sym_protected] = ACTIONS(5723),
    [anon_sym_public] = ACTIONS(5723),
    [anon_sym_readonly] = ACTIONS(5723),
    [anon_sym_required] = ACTIONS(5723),
    [anon_sym_sealed] = ACTIONS(5723),
    [anon_sym_virtual] = ACTIONS(5723),
    [anon_sym_volatile] = ACTIONS(5723),
    [anon_sym_where] = ACTIONS(5723),
    [anon_sym_notnull] = ACTIONS(5723),
    [anon_sym_unmanaged] = ACTIONS(5723),
    [anon_sym_TILDE] = ACTIONS(5725),
    [anon_sym_implicit] = ACTIONS(5723),
    [anon_sym_explicit] = ACTIONS(5723),
    [anon_sym_scoped] = ACTIONS(5723),
    [anon_sym_var] = ACTIONS(5723),
    [sym_predefined_type] = ACTIONS(5723),
    [anon_sym_yield] = ACTIONS(5723),
    [anon_sym_when] = ACTIONS(5723),
    [anon_sym_from] = ACTIONS(5723),
    [anon_sym_into] = ACTIONS(5723),
    [anon_sym_join] = ACTIONS(5723),
    [anon_sym_on] = ACTIONS(5723),
    [anon_sym_equals] = ACTIONS(5723),
    [anon_sym_let] = ACTIONS(5723),
    [anon_sym_orderby] = ACTIONS(5723),
    [anon_sym_ascending] = ACTIONS(5723),
    [anon_sym_descending] = ACTIONS(5723),
    [anon_sym_group] = ACTIONS(5723),
    [anon_sym_by] = ACTIONS(5723),
    [anon_sym_select] = ACTIONS(5723),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3787] = {
    [sym_preproc_region] = STATE(3787),
    [sym_preproc_endregion] = STATE(3787),
    [sym_preproc_line] = STATE(3787),
    [sym_preproc_pragma] = STATE(3787),
    [sym_preproc_nullable] = STATE(3787),
    [sym_preproc_error] = STATE(3787),
    [sym_preproc_warning] = STATE(3787),
    [sym_preproc_define] = STATE(3787),
    [sym_preproc_undef] = STATE(3787),
    [anon_sym_SEMI] = ACTIONS(5560),
    [anon_sym_LBRACK] = ACTIONS(5560),
    [anon_sym_COLON] = ACTIONS(5560),
    [anon_sym_COMMA] = ACTIONS(5560),
    [anon_sym_RBRACK] = ACTIONS(5560),
    [anon_sym_LPAREN] = ACTIONS(5560),
    [anon_sym_RPAREN] = ACTIONS(5560),
    [anon_sym_RBRACE] = ACTIONS(5560),
    [anon_sym_LT] = ACTIONS(5562),
    [anon_sym_GT] = ACTIONS(5562),
    [anon_sym_in] = ACTIONS(5560),
    [anon_sym_where] = ACTIONS(5560),
    [anon_sym_QMARK] = ACTIONS(5562),
    [anon_sym_BANG] = ACTIONS(5562),
    [anon_sym_PLUS_PLUS] = ACTIONS(5560),
    [anon_sym_DASH_DASH] = ACTIONS(5560),
    [anon_sym_PLUS] = ACTIONS(5562),
    [anon_sym_DASH] = ACTIONS(5562),
    [anon_sym_STAR] = ACTIONS(5560),
    [anon_sym_SLASH] = ACTIONS(5562),
    [anon_sym_PERCENT] = ACTIONS(5560),
    [anon_sym_CARET] = ACTIONS(5560),
    [anon_sym_PIPE] = ACTIONS(5562),
    [anon_sym_AMP] = ACTIONS(5562),
    [anon_sym_LT_LT] = ACTIONS(5560),
    [anon_sym_GT_GT] = ACTIONS(5562),
    [anon_sym_GT_GT_GT] = ACTIONS(5560),
    [anon_sym_EQ_EQ] = ACTIONS(5560),
    [anon_sym_BANG_EQ] = ACTIONS(5560),
    [anon_sym_GT_EQ] = ACTIONS(5560),
    [anon_sym_LT_EQ] = ACTIONS(5560),
    [anon_sym_DOT] = ACTIONS(5562),
    [anon_sym_EQ_GT] = ACTIONS(5560),
    [anon_sym_switch] = ACTIONS(5560),
    [anon_sym_DOT_DOT] = ACTIONS(5560),
    [anon_sym_and] = ACTIONS(5560),
    [anon_sym_or] = ACTIONS(5562),
    [anon_sym_AMP_AMP] = ACTIONS(5560),
    [anon_sym_PIPE_PIPE] = ACTIONS(5560),
    [anon_sym_QMARK_QMARK] = ACTIONS(5560),
    [anon_sym_from] = ACTIONS(5560),
    [anon_sym_join] = ACTIONS(5560),
    [anon_sym_on] = ACTIONS(5560),
    [anon_sym_equals] = ACTIONS(5560),
    [anon_sym_let] = ACTIONS(5560),
    [anon_sym_orderby] = ACTIONS(5560),
    [anon_sym_group] = ACTIONS(5560),
    [anon_sym_by] = ACTIONS(5560),
    [anon_sym_select] = ACTIONS(5560),
    [anon_sym_as] = ACTIONS(5560),
    [anon_sym_is] = ACTIONS(5560),
    [anon_sym_DASH_GT] = ACTIONS(5560),
    [anon_sym_with] = ACTIONS(5560),
    [aux_sym_preproc_if_token3] = ACTIONS(5560),
    [aux_sym_preproc_else_token1] = ACTIONS(5560),
    [aux_sym_preproc_elif_token1] = ACTIONS(5560),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3788] = {
    [sym_preproc_region] = STATE(3788),
    [sym_preproc_endregion] = STATE(3788),
    [sym_preproc_line] = STATE(3788),
    [sym_preproc_pragma] = STATE(3788),
    [sym_preproc_nullable] = STATE(3788),
    [sym_preproc_error] = STATE(3788),
    [sym_preproc_warning] = STATE(3788),
    [sym_preproc_define] = STATE(3788),
    [sym_preproc_undef] = STATE(3788),
    [anon_sym_SEMI] = ACTIONS(5498),
    [anon_sym_LBRACK] = ACTIONS(5498),
    [anon_sym_COLON] = ACTIONS(5498),
    [anon_sym_COMMA] = ACTIONS(5498),
    [anon_sym_RBRACK] = ACTIONS(5498),
    [anon_sym_LPAREN] = ACTIONS(5498),
    [anon_sym_RPAREN] = ACTIONS(5498),
    [anon_sym_RBRACE] = ACTIONS(5498),
    [anon_sym_LT] = ACTIONS(5500),
    [anon_sym_GT] = ACTIONS(5500),
    [anon_sym_in] = ACTIONS(5498),
    [anon_sym_where] = ACTIONS(5498),
    [anon_sym_QMARK] = ACTIONS(5500),
    [anon_sym_BANG] = ACTIONS(5500),
    [anon_sym_PLUS_PLUS] = ACTIONS(5498),
    [anon_sym_DASH_DASH] = ACTIONS(5498),
    [anon_sym_PLUS] = ACTIONS(5500),
    [anon_sym_DASH] = ACTIONS(5500),
    [anon_sym_STAR] = ACTIONS(5498),
    [anon_sym_SLASH] = ACTIONS(5500),
    [anon_sym_PERCENT] = ACTIONS(5498),
    [anon_sym_CARET] = ACTIONS(5498),
    [anon_sym_PIPE] = ACTIONS(5500),
    [anon_sym_AMP] = ACTIONS(5500),
    [anon_sym_LT_LT] = ACTIONS(5498),
    [anon_sym_GT_GT] = ACTIONS(5500),
    [anon_sym_GT_GT_GT] = ACTIONS(5498),
    [anon_sym_EQ_EQ] = ACTIONS(5498),
    [anon_sym_BANG_EQ] = ACTIONS(5498),
    [anon_sym_GT_EQ] = ACTIONS(5498),
    [anon_sym_LT_EQ] = ACTIONS(5498),
    [anon_sym_DOT] = ACTIONS(5500),
    [anon_sym_EQ_GT] = ACTIONS(5498),
    [anon_sym_switch] = ACTIONS(5498),
    [anon_sym_DOT_DOT] = ACTIONS(5498),
    [anon_sym_and] = ACTIONS(5498),
    [anon_sym_or] = ACTIONS(5500),
    [anon_sym_AMP_AMP] = ACTIONS(5498),
    [anon_sym_PIPE_PIPE] = ACTIONS(5498),
    [anon_sym_QMARK_QMARK] = ACTIONS(5498),
    [anon_sym_from] = ACTIONS(5498),
    [anon_sym_join] = ACTIONS(5498),
    [anon_sym_on] = ACTIONS(5498),
    [anon_sym_equals] = ACTIONS(5498),
    [anon_sym_let] = ACTIONS(5498),
    [anon_sym_orderby] = ACTIONS(5498),
    [anon_sym_group] = ACTIONS(5498),
    [anon_sym_by] = ACTIONS(5498),
    [anon_sym_select] = ACTIONS(5498),
    [anon_sym_as] = ACTIONS(5498),
    [anon_sym_is] = ACTIONS(5498),
    [anon_sym_DASH_GT] = ACTIONS(5498),
    [anon_sym_with] = ACTIONS(5498),
    [aux_sym_preproc_if_token3] = ACTIONS(5498),
    [aux_sym_preproc_else_token1] = ACTIONS(5498),
    [aux_sym_preproc_elif_token1] = ACTIONS(5498),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3789] = {
    [sym_preproc_region] = STATE(3789),
    [sym_preproc_endregion] = STATE(3789),
    [sym_preproc_line] = STATE(3789),
    [sym_preproc_pragma] = STATE(3789),
    [sym_preproc_nullable] = STATE(3789),
    [sym_preproc_error] = STATE(3789),
    [sym_preproc_warning] = STATE(3789),
    [sym_preproc_define] = STATE(3789),
    [sym_preproc_undef] = STATE(3789),
    [anon_sym_EQ] = ACTIONS(5727),
    [anon_sym_LBRACK] = ACTIONS(5286),
    [anon_sym_LPAREN] = ACTIONS(5286),
    [anon_sym_LT] = ACTIONS(5288),
    [anon_sym_GT] = ACTIONS(5288),
    [anon_sym_where] = ACTIONS(5286),
    [anon_sym_QMARK] = ACTIONS(5288),
    [anon_sym_BANG] = ACTIONS(5288),
    [anon_sym_PLUS_PLUS] = ACTIONS(5286),
    [anon_sym_DASH_DASH] = ACTIONS(5286),
    [anon_sym_PLUS] = ACTIONS(5288),
    [anon_sym_DASH] = ACTIONS(5288),
    [anon_sym_STAR] = ACTIONS(5288),
    [anon_sym_SLASH] = ACTIONS(5288),
    [anon_sym_PERCENT] = ACTIONS(5288),
    [anon_sym_CARET] = ACTIONS(5288),
    [anon_sym_PIPE] = ACTIONS(5288),
    [anon_sym_AMP] = ACTIONS(5288),
    [anon_sym_LT_LT] = ACTIONS(5288),
    [anon_sym_GT_GT] = ACTIONS(5288),
    [anon_sym_GT_GT_GT] = ACTIONS(5288),
    [anon_sym_EQ_EQ] = ACTIONS(5286),
    [anon_sym_BANG_EQ] = ACTIONS(5286),
    [anon_sym_GT_EQ] = ACTIONS(5286),
    [anon_sym_LT_EQ] = ACTIONS(5286),
    [anon_sym_DOT] = ACTIONS(5288),
    [anon_sym_switch] = ACTIONS(5286),
    [anon_sym_DOT_DOT] = ACTIONS(5286),
    [anon_sym_and] = ACTIONS(5286),
    [anon_sym_or] = ACTIONS(5288),
    [anon_sym_PLUS_EQ] = ACTIONS(5729),
    [anon_sym_DASH_EQ] = ACTIONS(5729),
    [anon_sym_STAR_EQ] = ACTIONS(5729),
    [anon_sym_SLASH_EQ] = ACTIONS(5729),
    [anon_sym_PERCENT_EQ] = ACTIONS(5729),
    [anon_sym_AMP_EQ] = ACTIONS(5729),
    [anon_sym_CARET_EQ] = ACTIONS(5729),
    [anon_sym_PIPE_EQ] = ACTIONS(5729),
    [anon_sym_LT_LT_EQ] = ACTIONS(5729),
    [anon_sym_GT_GT_EQ] = ACTIONS(5729),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(5729),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(5729),
    [anon_sym_AMP_AMP] = ACTIONS(5286),
    [anon_sym_PIPE_PIPE] = ACTIONS(5286),
    [anon_sym_QMARK_QMARK] = ACTIONS(5288),
    [anon_sym_from] = ACTIONS(5286),
    [anon_sym_into] = ACTIONS(5286),
    [anon_sym_join] = ACTIONS(5286),
    [anon_sym_let] = ACTIONS(5286),
    [anon_sym_orderby] = ACTIONS(5286),
    [anon_sym_group] = ACTIONS(5286),
    [anon_sym_select] = ACTIONS(5286),
    [anon_sym_as] = ACTIONS(5286),
    [anon_sym_is] = ACTIONS(5286),
    [anon_sym_DASH_GT] = ACTIONS(5286),
    [anon_sym_with] = ACTIONS(5286),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3790] = {
    [sym_preproc_region] = STATE(3790),
    [sym_preproc_endregion] = STATE(3790),
    [sym_preproc_line] = STATE(3790),
    [sym_preproc_pragma] = STATE(3790),
    [sym_preproc_nullable] = STATE(3790),
    [sym_preproc_error] = STATE(3790),
    [sym_preproc_warning] = STATE(3790),
    [sym_preproc_define] = STATE(3790),
    [sym_preproc_undef] = STATE(3790),
    [anon_sym_SEMI] = ACTIONS(5600),
    [anon_sym_LBRACK] = ACTIONS(5600),
    [anon_sym_COLON] = ACTIONS(5600),
    [anon_sym_COMMA] = ACTIONS(5600),
    [anon_sym_RBRACK] = ACTIONS(5600),
    [anon_sym_LPAREN] = ACTIONS(5600),
    [anon_sym_RPAREN] = ACTIONS(5600),
    [anon_sym_RBRACE] = ACTIONS(5600),
    [anon_sym_LT] = ACTIONS(5602),
    [anon_sym_GT] = ACTIONS(5602),
    [anon_sym_in] = ACTIONS(5600),
    [anon_sym_where] = ACTIONS(5600),
    [anon_sym_QMARK] = ACTIONS(5602),
    [anon_sym_BANG] = ACTIONS(5602),
    [anon_sym_PLUS_PLUS] = ACTIONS(5600),
    [anon_sym_DASH_DASH] = ACTIONS(5600),
    [anon_sym_PLUS] = ACTIONS(5602),
    [anon_sym_DASH] = ACTIONS(5602),
    [anon_sym_STAR] = ACTIONS(5600),
    [anon_sym_SLASH] = ACTIONS(5602),
    [anon_sym_PERCENT] = ACTIONS(5600),
    [anon_sym_CARET] = ACTIONS(5600),
    [anon_sym_PIPE] = ACTIONS(5602),
    [anon_sym_AMP] = ACTIONS(5602),
    [anon_sym_LT_LT] = ACTIONS(5600),
    [anon_sym_GT_GT] = ACTIONS(5602),
    [anon_sym_GT_GT_GT] = ACTIONS(5600),
    [anon_sym_EQ_EQ] = ACTIONS(5600),
    [anon_sym_BANG_EQ] = ACTIONS(5600),
    [anon_sym_GT_EQ] = ACTIONS(5600),
    [anon_sym_LT_EQ] = ACTIONS(5600),
    [anon_sym_DOT] = ACTIONS(5602),
    [anon_sym_EQ_GT] = ACTIONS(5600),
    [anon_sym_switch] = ACTIONS(5600),
    [anon_sym_DOT_DOT] = ACTIONS(5600),
    [anon_sym_and] = ACTIONS(5600),
    [anon_sym_or] = ACTIONS(5602),
    [anon_sym_AMP_AMP] = ACTIONS(5600),
    [anon_sym_PIPE_PIPE] = ACTIONS(5600),
    [anon_sym_QMARK_QMARK] = ACTIONS(5600),
    [anon_sym_from] = ACTIONS(5600),
    [anon_sym_join] = ACTIONS(5600),
    [anon_sym_on] = ACTIONS(5600),
    [anon_sym_equals] = ACTIONS(5600),
    [anon_sym_let] = ACTIONS(5600),
    [anon_sym_orderby] = ACTIONS(5600),
    [anon_sym_group] = ACTIONS(5600),
    [anon_sym_by] = ACTIONS(5600),
    [anon_sym_select] = ACTIONS(5600),
    [anon_sym_as] = ACTIONS(5600),
    [anon_sym_is] = ACTIONS(5600),
    [anon_sym_DASH_GT] = ACTIONS(5600),
    [anon_sym_with] = ACTIONS(5600),
    [aux_sym_preproc_if_token3] = ACTIONS(5600),
    [aux_sym_preproc_else_token1] = ACTIONS(5600),
    [aux_sym_preproc_elif_token1] = ACTIONS(5600),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3791] = {
    [sym_preproc_region] = STATE(3791),
    [sym_preproc_endregion] = STATE(3791),
    [sym_preproc_line] = STATE(3791),
    [sym_preproc_pragma] = STATE(3791),
    [sym_preproc_nullable] = STATE(3791),
    [sym_preproc_error] = STATE(3791),
    [sym_preproc_warning] = STATE(3791),
    [sym_preproc_define] = STATE(3791),
    [sym_preproc_undef] = STATE(3791),
    [anon_sym_SEMI] = ACTIONS(5604),
    [anon_sym_LBRACK] = ACTIONS(5604),
    [anon_sym_COLON] = ACTIONS(5604),
    [anon_sym_COMMA] = ACTIONS(5604),
    [anon_sym_RBRACK] = ACTIONS(5604),
    [anon_sym_LPAREN] = ACTIONS(5604),
    [anon_sym_RPAREN] = ACTIONS(5604),
    [anon_sym_RBRACE] = ACTIONS(5604),
    [anon_sym_LT] = ACTIONS(5606),
    [anon_sym_GT] = ACTIONS(5606),
    [anon_sym_in] = ACTIONS(5604),
    [anon_sym_where] = ACTIONS(5604),
    [anon_sym_QMARK] = ACTIONS(5606),
    [anon_sym_BANG] = ACTIONS(5606),
    [anon_sym_PLUS_PLUS] = ACTIONS(5604),
    [anon_sym_DASH_DASH] = ACTIONS(5604),
    [anon_sym_PLUS] = ACTIONS(5606),
    [anon_sym_DASH] = ACTIONS(5606),
    [anon_sym_STAR] = ACTIONS(5604),
    [anon_sym_SLASH] = ACTIONS(5606),
    [anon_sym_PERCENT] = ACTIONS(5604),
    [anon_sym_CARET] = ACTIONS(5604),
    [anon_sym_PIPE] = ACTIONS(5606),
    [anon_sym_AMP] = ACTIONS(5606),
    [anon_sym_LT_LT] = ACTIONS(5604),
    [anon_sym_GT_GT] = ACTIONS(5606),
    [anon_sym_GT_GT_GT] = ACTIONS(5604),
    [anon_sym_EQ_EQ] = ACTIONS(5604),
    [anon_sym_BANG_EQ] = ACTIONS(5604),
    [anon_sym_GT_EQ] = ACTIONS(5604),
    [anon_sym_LT_EQ] = ACTIONS(5604),
    [anon_sym_DOT] = ACTIONS(5606),
    [anon_sym_EQ_GT] = ACTIONS(5604),
    [anon_sym_switch] = ACTIONS(5604),
    [anon_sym_DOT_DOT] = ACTIONS(5604),
    [anon_sym_and] = ACTIONS(5604),
    [anon_sym_or] = ACTIONS(5606),
    [anon_sym_AMP_AMP] = ACTIONS(5604),
    [anon_sym_PIPE_PIPE] = ACTIONS(5604),
    [anon_sym_QMARK_QMARK] = ACTIONS(5604),
    [anon_sym_from] = ACTIONS(5604),
    [anon_sym_join] = ACTIONS(5604),
    [anon_sym_on] = ACTIONS(5604),
    [anon_sym_equals] = ACTIONS(5604),
    [anon_sym_let] = ACTIONS(5604),
    [anon_sym_orderby] = ACTIONS(5604),
    [anon_sym_group] = ACTIONS(5604),
    [anon_sym_by] = ACTIONS(5604),
    [anon_sym_select] = ACTIONS(5604),
    [anon_sym_as] = ACTIONS(5604),
    [anon_sym_is] = ACTIONS(5604),
    [anon_sym_DASH_GT] = ACTIONS(5604),
    [anon_sym_with] = ACTIONS(5604),
    [aux_sym_preproc_if_token3] = ACTIONS(5604),
    [aux_sym_preproc_else_token1] = ACTIONS(5604),
    [aux_sym_preproc_elif_token1] = ACTIONS(5604),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3792] = {
    [sym_preproc_region] = STATE(3792),
    [sym_preproc_endregion] = STATE(3792),
    [sym_preproc_line] = STATE(3792),
    [sym_preproc_pragma] = STATE(3792),
    [sym_preproc_nullable] = STATE(3792),
    [sym_preproc_error] = STATE(3792),
    [sym_preproc_warning] = STATE(3792),
    [sym_preproc_define] = STATE(3792),
    [sym_preproc_undef] = STATE(3792),
    [anon_sym_SEMI] = ACTIONS(5616),
    [anon_sym_LBRACK] = ACTIONS(5616),
    [anon_sym_COLON] = ACTIONS(5616),
    [anon_sym_COMMA] = ACTIONS(5616),
    [anon_sym_RBRACK] = ACTIONS(5616),
    [anon_sym_LPAREN] = ACTIONS(5616),
    [anon_sym_RPAREN] = ACTIONS(5616),
    [anon_sym_RBRACE] = ACTIONS(5616),
    [anon_sym_LT] = ACTIONS(5618),
    [anon_sym_GT] = ACTIONS(5618),
    [anon_sym_in] = ACTIONS(5616),
    [anon_sym_where] = ACTIONS(5616),
    [anon_sym_QMARK] = ACTIONS(5618),
    [anon_sym_BANG] = ACTIONS(5618),
    [anon_sym_PLUS_PLUS] = ACTIONS(5616),
    [anon_sym_DASH_DASH] = ACTIONS(5616),
    [anon_sym_PLUS] = ACTIONS(5618),
    [anon_sym_DASH] = ACTIONS(5618),
    [anon_sym_STAR] = ACTIONS(5616),
    [anon_sym_SLASH] = ACTIONS(5618),
    [anon_sym_PERCENT] = ACTIONS(5616),
    [anon_sym_CARET] = ACTIONS(5616),
    [anon_sym_PIPE] = ACTIONS(5618),
    [anon_sym_AMP] = ACTIONS(5618),
    [anon_sym_LT_LT] = ACTIONS(5616),
    [anon_sym_GT_GT] = ACTIONS(5618),
    [anon_sym_GT_GT_GT] = ACTIONS(5616),
    [anon_sym_EQ_EQ] = ACTIONS(5616),
    [anon_sym_BANG_EQ] = ACTIONS(5616),
    [anon_sym_GT_EQ] = ACTIONS(5616),
    [anon_sym_LT_EQ] = ACTIONS(5616),
    [anon_sym_DOT] = ACTIONS(5618),
    [anon_sym_EQ_GT] = ACTIONS(5616),
    [anon_sym_switch] = ACTIONS(5616),
    [anon_sym_DOT_DOT] = ACTIONS(5616),
    [anon_sym_and] = ACTIONS(5616),
    [anon_sym_or] = ACTIONS(5618),
    [anon_sym_AMP_AMP] = ACTIONS(5616),
    [anon_sym_PIPE_PIPE] = ACTIONS(5616),
    [anon_sym_QMARK_QMARK] = ACTIONS(5616),
    [anon_sym_from] = ACTIONS(5616),
    [anon_sym_join] = ACTIONS(5616),
    [anon_sym_on] = ACTIONS(5616),
    [anon_sym_equals] = ACTIONS(5616),
    [anon_sym_let] = ACTIONS(5616),
    [anon_sym_orderby] = ACTIONS(5616),
    [anon_sym_group] = ACTIONS(5616),
    [anon_sym_by] = ACTIONS(5616),
    [anon_sym_select] = ACTIONS(5616),
    [anon_sym_as] = ACTIONS(5616),
    [anon_sym_is] = ACTIONS(5616),
    [anon_sym_DASH_GT] = ACTIONS(5616),
    [anon_sym_with] = ACTIONS(5616),
    [aux_sym_preproc_if_token3] = ACTIONS(5616),
    [aux_sym_preproc_else_token1] = ACTIONS(5616),
    [aux_sym_preproc_elif_token1] = ACTIONS(5616),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3793] = {
    [sym_preproc_region] = STATE(3793),
    [sym_preproc_endregion] = STATE(3793),
    [sym_preproc_line] = STATE(3793),
    [sym_preproc_pragma] = STATE(3793),
    [sym_preproc_nullable] = STATE(3793),
    [sym_preproc_error] = STATE(3793),
    [sym_preproc_warning] = STATE(3793),
    [sym_preproc_define] = STATE(3793),
    [sym_preproc_undef] = STATE(3793),
    [anon_sym_SEMI] = ACTIONS(5480),
    [anon_sym_LBRACK] = ACTIONS(5480),
    [anon_sym_COLON] = ACTIONS(5480),
    [anon_sym_COMMA] = ACTIONS(5480),
    [anon_sym_RBRACK] = ACTIONS(5480),
    [anon_sym_LPAREN] = ACTIONS(5480),
    [anon_sym_RPAREN] = ACTIONS(5480),
    [anon_sym_RBRACE] = ACTIONS(5480),
    [anon_sym_LT] = ACTIONS(5482),
    [anon_sym_GT] = ACTIONS(5482),
    [anon_sym_in] = ACTIONS(5480),
    [anon_sym_where] = ACTIONS(5480),
    [anon_sym_QMARK] = ACTIONS(5482),
    [anon_sym_BANG] = ACTIONS(5482),
    [anon_sym_PLUS_PLUS] = ACTIONS(5480),
    [anon_sym_DASH_DASH] = ACTIONS(5480),
    [anon_sym_PLUS] = ACTIONS(5482),
    [anon_sym_DASH] = ACTIONS(5482),
    [anon_sym_STAR] = ACTIONS(5480),
    [anon_sym_SLASH] = ACTIONS(5482),
    [anon_sym_PERCENT] = ACTIONS(5480),
    [anon_sym_CARET] = ACTIONS(5480),
    [anon_sym_PIPE] = ACTIONS(5482),
    [anon_sym_AMP] = ACTIONS(5482),
    [anon_sym_LT_LT] = ACTIONS(5480),
    [anon_sym_GT_GT] = ACTIONS(5482),
    [anon_sym_GT_GT_GT] = ACTIONS(5480),
    [anon_sym_EQ_EQ] = ACTIONS(5480),
    [anon_sym_BANG_EQ] = ACTIONS(5480),
    [anon_sym_GT_EQ] = ACTIONS(5480),
    [anon_sym_LT_EQ] = ACTIONS(5480),
    [anon_sym_DOT] = ACTIONS(5482),
    [anon_sym_EQ_GT] = ACTIONS(5480),
    [anon_sym_switch] = ACTIONS(5480),
    [anon_sym_DOT_DOT] = ACTIONS(5480),
    [anon_sym_and] = ACTIONS(5480),
    [anon_sym_or] = ACTIONS(5482),
    [anon_sym_AMP_AMP] = ACTIONS(5480),
    [anon_sym_PIPE_PIPE] = ACTIONS(5480),
    [anon_sym_QMARK_QMARK] = ACTIONS(5480),
    [anon_sym_from] = ACTIONS(5480),
    [anon_sym_join] = ACTIONS(5480),
    [anon_sym_on] = ACTIONS(5480),
    [anon_sym_equals] = ACTIONS(5480),
    [anon_sym_let] = ACTIONS(5480),
    [anon_sym_orderby] = ACTIONS(5480),
    [anon_sym_group] = ACTIONS(5480),
    [anon_sym_by] = ACTIONS(5480),
    [anon_sym_select] = ACTIONS(5480),
    [anon_sym_as] = ACTIONS(5480),
    [anon_sym_is] = ACTIONS(5480),
    [anon_sym_DASH_GT] = ACTIONS(5480),
    [anon_sym_with] = ACTIONS(5480),
    [aux_sym_preproc_if_token3] = ACTIONS(5480),
    [aux_sym_preproc_else_token1] = ACTIONS(5480),
    [aux_sym_preproc_elif_token1] = ACTIONS(5480),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3794] = {
    [sym_preproc_region] = STATE(3794),
    [sym_preproc_endregion] = STATE(3794),
    [sym_preproc_line] = STATE(3794),
    [sym_preproc_pragma] = STATE(3794),
    [sym_preproc_nullable] = STATE(3794),
    [sym_preproc_error] = STATE(3794),
    [sym_preproc_warning] = STATE(3794),
    [sym_preproc_define] = STATE(3794),
    [sym_preproc_undef] = STATE(3794),
    [anon_sym_SEMI] = ACTIONS(5686),
    [anon_sym_LBRACK] = ACTIONS(5686),
    [anon_sym_COLON] = ACTIONS(5686),
    [anon_sym_COMMA] = ACTIONS(5686),
    [anon_sym_RBRACK] = ACTIONS(5686),
    [anon_sym_LPAREN] = ACTIONS(5686),
    [anon_sym_RPAREN] = ACTIONS(5686),
    [anon_sym_RBRACE] = ACTIONS(5686),
    [anon_sym_LT] = ACTIONS(5688),
    [anon_sym_GT] = ACTIONS(5688),
    [anon_sym_in] = ACTIONS(5686),
    [anon_sym_where] = ACTIONS(5686),
    [anon_sym_QMARK] = ACTIONS(5688),
    [anon_sym_BANG] = ACTIONS(5688),
    [anon_sym_PLUS_PLUS] = ACTIONS(5686),
    [anon_sym_DASH_DASH] = ACTIONS(5686),
    [anon_sym_PLUS] = ACTIONS(5688),
    [anon_sym_DASH] = ACTIONS(5688),
    [anon_sym_STAR] = ACTIONS(5686),
    [anon_sym_SLASH] = ACTIONS(5688),
    [anon_sym_PERCENT] = ACTIONS(5686),
    [anon_sym_CARET] = ACTIONS(5686),
    [anon_sym_PIPE] = ACTIONS(5688),
    [anon_sym_AMP] = ACTIONS(5688),
    [anon_sym_LT_LT] = ACTIONS(5686),
    [anon_sym_GT_GT] = ACTIONS(5688),
    [anon_sym_GT_GT_GT] = ACTIONS(5686),
    [anon_sym_EQ_EQ] = ACTIONS(5686),
    [anon_sym_BANG_EQ] = ACTIONS(5686),
    [anon_sym_GT_EQ] = ACTIONS(5686),
    [anon_sym_LT_EQ] = ACTIONS(5686),
    [anon_sym_DOT] = ACTIONS(5688),
    [anon_sym_EQ_GT] = ACTIONS(5686),
    [anon_sym_switch] = ACTIONS(5686),
    [anon_sym_DOT_DOT] = ACTIONS(5686),
    [anon_sym_and] = ACTIONS(5686),
    [anon_sym_or] = ACTIONS(5688),
    [anon_sym_AMP_AMP] = ACTIONS(5686),
    [anon_sym_PIPE_PIPE] = ACTIONS(5686),
    [anon_sym_QMARK_QMARK] = ACTIONS(5686),
    [anon_sym_from] = ACTIONS(5686),
    [anon_sym_join] = ACTIONS(5686),
    [anon_sym_on] = ACTIONS(5686),
    [anon_sym_equals] = ACTIONS(5686),
    [anon_sym_let] = ACTIONS(5686),
    [anon_sym_orderby] = ACTIONS(5686),
    [anon_sym_group] = ACTIONS(5686),
    [anon_sym_by] = ACTIONS(5686),
    [anon_sym_select] = ACTIONS(5686),
    [anon_sym_as] = ACTIONS(5686),
    [anon_sym_is] = ACTIONS(5686),
    [anon_sym_DASH_GT] = ACTIONS(5686),
    [anon_sym_with] = ACTIONS(5686),
    [aux_sym_preproc_if_token3] = ACTIONS(5686),
    [aux_sym_preproc_else_token1] = ACTIONS(5686),
    [aux_sym_preproc_elif_token1] = ACTIONS(5686),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3795] = {
    [sym_preproc_region] = STATE(3795),
    [sym_preproc_endregion] = STATE(3795),
    [sym_preproc_line] = STATE(3795),
    [sym_preproc_pragma] = STATE(3795),
    [sym_preproc_nullable] = STATE(3795),
    [sym_preproc_error] = STATE(3795),
    [sym_preproc_warning] = STATE(3795),
    [sym_preproc_define] = STATE(3795),
    [sym_preproc_undef] = STATE(3795),
    [anon_sym_EQ] = ACTIONS(5731),
    [anon_sym_LBRACK] = ACTIONS(5286),
    [anon_sym_LPAREN] = ACTIONS(5286),
    [anon_sym_LT] = ACTIONS(5288),
    [anon_sym_GT] = ACTIONS(5288),
    [anon_sym_where] = ACTIONS(5286),
    [anon_sym_QMARK] = ACTIONS(5288),
    [anon_sym_BANG] = ACTIONS(5288),
    [anon_sym_PLUS_PLUS] = ACTIONS(5286),
    [anon_sym_DASH_DASH] = ACTIONS(5286),
    [anon_sym_PLUS] = ACTIONS(5288),
    [anon_sym_DASH] = ACTIONS(5288),
    [anon_sym_STAR] = ACTIONS(5288),
    [anon_sym_SLASH] = ACTIONS(5288),
    [anon_sym_PERCENT] = ACTIONS(5288),
    [anon_sym_CARET] = ACTIONS(5288),
    [anon_sym_PIPE] = ACTIONS(5288),
    [anon_sym_AMP] = ACTIONS(5288),
    [anon_sym_LT_LT] = ACTIONS(5288),
    [anon_sym_GT_GT] = ACTIONS(5288),
    [anon_sym_GT_GT_GT] = ACTIONS(5288),
    [anon_sym_EQ_EQ] = ACTIONS(5286),
    [anon_sym_BANG_EQ] = ACTIONS(5286),
    [anon_sym_GT_EQ] = ACTIONS(5286),
    [anon_sym_LT_EQ] = ACTIONS(5286),
    [anon_sym_DOT] = ACTIONS(5288),
    [anon_sym_switch] = ACTIONS(5286),
    [anon_sym_DOT_DOT] = ACTIONS(5286),
    [anon_sym_and] = ACTIONS(5286),
    [anon_sym_or] = ACTIONS(5288),
    [anon_sym_PLUS_EQ] = ACTIONS(5733),
    [anon_sym_DASH_EQ] = ACTIONS(5733),
    [anon_sym_STAR_EQ] = ACTIONS(5733),
    [anon_sym_SLASH_EQ] = ACTIONS(5733),
    [anon_sym_PERCENT_EQ] = ACTIONS(5733),
    [anon_sym_AMP_EQ] = ACTIONS(5733),
    [anon_sym_CARET_EQ] = ACTIONS(5733),
    [anon_sym_PIPE_EQ] = ACTIONS(5733),
    [anon_sym_LT_LT_EQ] = ACTIONS(5733),
    [anon_sym_GT_GT_EQ] = ACTIONS(5733),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(5733),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(5733),
    [anon_sym_AMP_AMP] = ACTIONS(5286),
    [anon_sym_PIPE_PIPE] = ACTIONS(5286),
    [anon_sym_QMARK_QMARK] = ACTIONS(5288),
    [anon_sym_from] = ACTIONS(5286),
    [anon_sym_join] = ACTIONS(5286),
    [anon_sym_let] = ACTIONS(5286),
    [anon_sym_orderby] = ACTIONS(5286),
    [anon_sym_group] = ACTIONS(5286),
    [anon_sym_select] = ACTIONS(5286),
    [anon_sym_as] = ACTIONS(5286),
    [anon_sym_is] = ACTIONS(5286),
    [anon_sym_DASH_GT] = ACTIONS(5286),
    [anon_sym_with] = ACTIONS(5286),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3796] = {
    [sym_preproc_region] = STATE(3796),
    [sym_preproc_endregion] = STATE(3796),
    [sym_preproc_line] = STATE(3796),
    [sym_preproc_pragma] = STATE(3796),
    [sym_preproc_nullable] = STATE(3796),
    [sym_preproc_error] = STATE(3796),
    [sym_preproc_warning] = STATE(3796),
    [sym_preproc_define] = STATE(3796),
    [sym_preproc_undef] = STATE(3796),
    [sym__identifier_token] = ACTIONS(4039),
    [anon_sym_extern] = ACTIONS(4042),
    [anon_sym_alias] = ACTIONS(4039),
    [anon_sym_SEMI] = ACTIONS(3993),
    [anon_sym_global] = ACTIONS(4039),
    [anon_sym_unsafe] = ACTIONS(4042),
    [anon_sym_EQ] = ACTIONS(3995),
    [anon_sym_static] = ACTIONS(4042),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_LPAREN] = ACTIONS(4044),
    [anon_sym_ref] = ACTIONS(4042),
    [anon_sym_delegate] = ACTIONS(4042),
    [anon_sym_abstract] = ACTIONS(4042),
    [anon_sym_async] = ACTIONS(4042),
    [anon_sym_const] = ACTIONS(4042),
    [anon_sym_file] = ACTIONS(4039),
    [anon_sym_fixed] = ACTIONS(4042),
    [anon_sym_internal] = ACTIONS(4042),
    [anon_sym_new] = ACTIONS(4042),
    [anon_sym_override] = ACTIONS(4042),
    [anon_sym_partial] = ACTIONS(4042),
    [anon_sym_private] = ACTIONS(4042),
    [anon_sym_protected] = ACTIONS(4042),
    [anon_sym_public] = ACTIONS(4042),
    [anon_sym_readonly] = ACTIONS(4042),
    [anon_sym_required] = ACTIONS(4042),
    [anon_sym_sealed] = ACTIONS(4042),
    [anon_sym_virtual] = ACTIONS(4042),
    [anon_sym_volatile] = ACTIONS(4042),
    [anon_sym_LT] = ACTIONS(3993),
    [anon_sym_where] = ACTIONS(4039),
    [anon_sym_QMARK] = ACTIONS(3993),
    [anon_sym_notnull] = ACTIONS(4039),
    [anon_sym_unmanaged] = ACTIONS(4039),
    [anon_sym_STAR] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3993),
    [anon_sym_scoped] = ACTIONS(4039),
    [anon_sym_EQ_GT] = ACTIONS(3993),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(4039),
    [sym_predefined_type] = ACTIONS(4042),
    [anon_sym_yield] = ACTIONS(4039),
    [anon_sym_when] = ACTIONS(4039),
    [anon_sym_from] = ACTIONS(4039),
    [anon_sym_into] = ACTIONS(4039),
    [anon_sym_join] = ACTIONS(4039),
    [anon_sym_on] = ACTIONS(4039),
    [anon_sym_equals] = ACTIONS(4039),
    [anon_sym_let] = ACTIONS(4039),
    [anon_sym_orderby] = ACTIONS(4039),
    [anon_sym_ascending] = ACTIONS(4039),
    [anon_sym_descending] = ACTIONS(4039),
    [anon_sym_group] = ACTIONS(4039),
    [anon_sym_by] = ACTIONS(4039),
    [anon_sym_select] = ACTIONS(4039),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3797] = {
    [sym_preproc_region] = STATE(3797),
    [sym_preproc_endregion] = STATE(3797),
    [sym_preproc_line] = STATE(3797),
    [sym_preproc_pragma] = STATE(3797),
    [sym_preproc_nullable] = STATE(3797),
    [sym_preproc_error] = STATE(3797),
    [sym_preproc_warning] = STATE(3797),
    [sym_preproc_define] = STATE(3797),
    [sym_preproc_undef] = STATE(3797),
    [anon_sym_EQ] = ACTIONS(4162),
    [anon_sym_LBRACK] = ACTIONS(4177),
    [anon_sym_COLON] = ACTIONS(4177),
    [anon_sym_COMMA] = ACTIONS(4808),
    [anon_sym_RBRACK] = ACTIONS(4808),
    [anon_sym_LPAREN] = ACTIONS(4177),
    [anon_sym_RPAREN] = ACTIONS(4808),
    [anon_sym_RBRACE] = ACTIONS(4808),
    [anon_sym_LT] = ACTIONS(4162),
    [anon_sym_GT] = ACTIONS(4162),
    [anon_sym_QMARK] = ACTIONS(4162),
    [anon_sym_BANG] = ACTIONS(4162),
    [anon_sym_PLUS_PLUS] = ACTIONS(4177),
    [anon_sym_DASH_DASH] = ACTIONS(4177),
    [anon_sym_PLUS] = ACTIONS(4162),
    [anon_sym_DASH] = ACTIONS(4162),
    [anon_sym_STAR] = ACTIONS(4162),
    [anon_sym_SLASH] = ACTIONS(4162),
    [anon_sym_PERCENT] = ACTIONS(4162),
    [anon_sym_CARET] = ACTIONS(4162),
    [anon_sym_PIPE] = ACTIONS(4162),
    [anon_sym_AMP] = ACTIONS(4162),
    [anon_sym_LT_LT] = ACTIONS(4162),
    [anon_sym_GT_GT] = ACTIONS(4162),
    [anon_sym_GT_GT_GT] = ACTIONS(4162),
    [anon_sym_EQ_EQ] = ACTIONS(4177),
    [anon_sym_BANG_EQ] = ACTIONS(4177),
    [anon_sym_GT_EQ] = ACTIONS(4177),
    [anon_sym_LT_EQ] = ACTIONS(4177),
    [anon_sym_DOT] = ACTIONS(4162),
    [anon_sym_EQ_GT] = ACTIONS(4806),
    [anon_sym_switch] = ACTIONS(4177),
    [anon_sym_when] = ACTIONS(4806),
    [anon_sym_DOT_DOT] = ACTIONS(4177),
    [anon_sym_and] = ACTIONS(4806),
    [anon_sym_or] = ACTIONS(4806),
    [anon_sym_PLUS_EQ] = ACTIONS(4177),
    [anon_sym_DASH_EQ] = ACTIONS(4177),
    [anon_sym_STAR_EQ] = ACTIONS(4177),
    [anon_sym_SLASH_EQ] = ACTIONS(4177),
    [anon_sym_PERCENT_EQ] = ACTIONS(4177),
    [anon_sym_AMP_EQ] = ACTIONS(4177),
    [anon_sym_CARET_EQ] = ACTIONS(4177),
    [anon_sym_PIPE_EQ] = ACTIONS(4177),
    [anon_sym_LT_LT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4177),
    [anon_sym_AMP_AMP] = ACTIONS(4177),
    [anon_sym_PIPE_PIPE] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK] = ACTIONS(4162),
    [anon_sym_as] = ACTIONS(4177),
    [anon_sym_is] = ACTIONS(4177),
    [anon_sym_DASH_GT] = ACTIONS(4177),
    [anon_sym_with] = ACTIONS(4177),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3798] = {
    [sym_preproc_region] = STATE(3798),
    [sym_preproc_endregion] = STATE(3798),
    [sym_preproc_line] = STATE(3798),
    [sym_preproc_pragma] = STATE(3798),
    [sym_preproc_nullable] = STATE(3798),
    [sym_preproc_error] = STATE(3798),
    [sym_preproc_warning] = STATE(3798),
    [sym_preproc_define] = STATE(3798),
    [sym_preproc_undef] = STATE(3798),
    [sym__identifier_token] = ACTIONS(4042),
    [anon_sym_extern] = ACTIONS(4042),
    [anon_sym_alias] = ACTIONS(4042),
    [anon_sym_global] = ACTIONS(4042),
    [anon_sym_unsafe] = ACTIONS(4042),
    [anon_sym_static] = ACTIONS(4042),
    [anon_sym_LPAREN] = ACTIONS(5474),
    [anon_sym_event] = ACTIONS(4042),
    [anon_sym_class] = ACTIONS(4042),
    [anon_sym_ref] = ACTIONS(4042),
    [anon_sym_struct] = ACTIONS(4042),
    [anon_sym_enum] = ACTIONS(4042),
    [anon_sym_interface] = ACTIONS(4042),
    [anon_sym_delegate] = ACTIONS(4042),
    [anon_sym_record] = ACTIONS(4042),
    [anon_sym_abstract] = ACTIONS(4042),
    [anon_sym_async] = ACTIONS(4042),
    [anon_sym_const] = ACTIONS(4042),
    [anon_sym_file] = ACTIONS(4042),
    [anon_sym_fixed] = ACTIONS(4042),
    [anon_sym_internal] = ACTIONS(4042),
    [anon_sym_new] = ACTIONS(4042),
    [anon_sym_override] = ACTIONS(4042),
    [anon_sym_partial] = ACTIONS(4042),
    [anon_sym_private] = ACTIONS(4042),
    [anon_sym_protected] = ACTIONS(4042),
    [anon_sym_public] = ACTIONS(4042),
    [anon_sym_readonly] = ACTIONS(4042),
    [anon_sym_required] = ACTIONS(4042),
    [anon_sym_sealed] = ACTIONS(4042),
    [anon_sym_virtual] = ACTIONS(4042),
    [anon_sym_volatile] = ACTIONS(4042),
    [anon_sym_where] = ACTIONS(4042),
    [anon_sym_notnull] = ACTIONS(4042),
    [anon_sym_unmanaged] = ACTIONS(4042),
    [anon_sym_TILDE] = ACTIONS(4290),
    [anon_sym_implicit] = ACTIONS(4042),
    [anon_sym_explicit] = ACTIONS(4042),
    [anon_sym_scoped] = ACTIONS(4042),
    [anon_sym_var] = ACTIONS(4042),
    [sym_predefined_type] = ACTIONS(4042),
    [anon_sym_yield] = ACTIONS(4042),
    [anon_sym_when] = ACTIONS(4042),
    [anon_sym_from] = ACTIONS(4042),
    [anon_sym_into] = ACTIONS(4042),
    [anon_sym_join] = ACTIONS(4042),
    [anon_sym_on] = ACTIONS(4042),
    [anon_sym_equals] = ACTIONS(4042),
    [anon_sym_let] = ACTIONS(4042),
    [anon_sym_orderby] = ACTIONS(4042),
    [anon_sym_ascending] = ACTIONS(4042),
    [anon_sym_descending] = ACTIONS(4042),
    [anon_sym_group] = ACTIONS(4042),
    [anon_sym_by] = ACTIONS(4042),
    [anon_sym_select] = ACTIONS(4042),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3799] = {
    [sym_preproc_region] = STATE(3799),
    [sym_preproc_endregion] = STATE(3799),
    [sym_preproc_line] = STATE(3799),
    [sym_preproc_pragma] = STATE(3799),
    [sym_preproc_nullable] = STATE(3799),
    [sym_preproc_error] = STATE(3799),
    [sym_preproc_warning] = STATE(3799),
    [sym_preproc_define] = STATE(3799),
    [sym_preproc_undef] = STATE(3799),
    [sym__identifier_token] = ACTIONS(4042),
    [anon_sym_extern] = ACTIONS(4042),
    [anon_sym_alias] = ACTIONS(4042),
    [anon_sym_global] = ACTIONS(4042),
    [anon_sym_unsafe] = ACTIONS(4042),
    [anon_sym_static] = ACTIONS(4042),
    [anon_sym_LPAREN] = ACTIONS(5474),
    [anon_sym_event] = ACTIONS(4042),
    [anon_sym_class] = ACTIONS(4042),
    [anon_sym_ref] = ACTIONS(4042),
    [anon_sym_struct] = ACTIONS(4042),
    [anon_sym_enum] = ACTIONS(4042),
    [anon_sym_interface] = ACTIONS(4042),
    [anon_sym_delegate] = ACTIONS(4042),
    [anon_sym_record] = ACTIONS(4042),
    [anon_sym_abstract] = ACTIONS(4042),
    [anon_sym_async] = ACTIONS(4042),
    [anon_sym_const] = ACTIONS(4042),
    [anon_sym_file] = ACTIONS(4042),
    [anon_sym_fixed] = ACTIONS(4042),
    [anon_sym_internal] = ACTIONS(4042),
    [anon_sym_new] = ACTIONS(4042),
    [anon_sym_override] = ACTIONS(4042),
    [anon_sym_partial] = ACTIONS(4042),
    [anon_sym_private] = ACTIONS(4042),
    [anon_sym_protected] = ACTIONS(4042),
    [anon_sym_public] = ACTIONS(4042),
    [anon_sym_readonly] = ACTIONS(4042),
    [anon_sym_required] = ACTIONS(4042),
    [anon_sym_sealed] = ACTIONS(4042),
    [anon_sym_virtual] = ACTIONS(4042),
    [anon_sym_volatile] = ACTIONS(4042),
    [anon_sym_where] = ACTIONS(4042),
    [anon_sym_notnull] = ACTIONS(4042),
    [anon_sym_unmanaged] = ACTIONS(4042),
    [anon_sym_TILDE] = ACTIONS(5735),
    [anon_sym_implicit] = ACTIONS(4042),
    [anon_sym_explicit] = ACTIONS(4042),
    [anon_sym_scoped] = ACTIONS(4042),
    [anon_sym_var] = ACTIONS(4042),
    [sym_predefined_type] = ACTIONS(4042),
    [anon_sym_yield] = ACTIONS(4042),
    [anon_sym_when] = ACTIONS(4042),
    [anon_sym_from] = ACTIONS(4042),
    [anon_sym_into] = ACTIONS(4042),
    [anon_sym_join] = ACTIONS(4042),
    [anon_sym_on] = ACTIONS(4042),
    [anon_sym_equals] = ACTIONS(4042),
    [anon_sym_let] = ACTIONS(4042),
    [anon_sym_orderby] = ACTIONS(4042),
    [anon_sym_ascending] = ACTIONS(4042),
    [anon_sym_descending] = ACTIONS(4042),
    [anon_sym_group] = ACTIONS(4042),
    [anon_sym_by] = ACTIONS(4042),
    [anon_sym_select] = ACTIONS(4042),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3800] = {
    [sym_preproc_region] = STATE(3800),
    [sym_preproc_endregion] = STATE(3800),
    [sym_preproc_line] = STATE(3800),
    [sym_preproc_pragma] = STATE(3800),
    [sym_preproc_nullable] = STATE(3800),
    [sym_preproc_error] = STATE(3800),
    [sym_preproc_warning] = STATE(3800),
    [sym_preproc_define] = STATE(3800),
    [sym_preproc_undef] = STATE(3800),
    [anon_sym_EQ] = ACTIONS(5737),
    [anon_sym_LBRACK] = ACTIONS(5286),
    [anon_sym_LPAREN] = ACTIONS(5286),
    [anon_sym_LT] = ACTIONS(5288),
    [anon_sym_GT] = ACTIONS(5288),
    [anon_sym_where] = ACTIONS(5286),
    [anon_sym_QMARK] = ACTIONS(5288),
    [anon_sym_BANG] = ACTIONS(5288),
    [anon_sym_PLUS_PLUS] = ACTIONS(5286),
    [anon_sym_DASH_DASH] = ACTIONS(5286),
    [anon_sym_PLUS] = ACTIONS(5288),
    [anon_sym_DASH] = ACTIONS(5288),
    [anon_sym_STAR] = ACTIONS(5288),
    [anon_sym_SLASH] = ACTIONS(5288),
    [anon_sym_PERCENT] = ACTIONS(5288),
    [anon_sym_CARET] = ACTIONS(5288),
    [anon_sym_PIPE] = ACTIONS(5288),
    [anon_sym_AMP] = ACTIONS(5288),
    [anon_sym_LT_LT] = ACTIONS(5288),
    [anon_sym_GT_GT] = ACTIONS(5288),
    [anon_sym_GT_GT_GT] = ACTIONS(5288),
    [anon_sym_EQ_EQ] = ACTIONS(5286),
    [anon_sym_BANG_EQ] = ACTIONS(5286),
    [anon_sym_GT_EQ] = ACTIONS(5286),
    [anon_sym_LT_EQ] = ACTIONS(5286),
    [anon_sym_DOT] = ACTIONS(5288),
    [anon_sym_switch] = ACTIONS(5286),
    [anon_sym_DOT_DOT] = ACTIONS(5286),
    [anon_sym_PLUS_EQ] = ACTIONS(5739),
    [anon_sym_DASH_EQ] = ACTIONS(5739),
    [anon_sym_STAR_EQ] = ACTIONS(5739),
    [anon_sym_SLASH_EQ] = ACTIONS(5739),
    [anon_sym_PERCENT_EQ] = ACTIONS(5739),
    [anon_sym_AMP_EQ] = ACTIONS(5739),
    [anon_sym_CARET_EQ] = ACTIONS(5739),
    [anon_sym_PIPE_EQ] = ACTIONS(5739),
    [anon_sym_LT_LT_EQ] = ACTIONS(5739),
    [anon_sym_GT_GT_EQ] = ACTIONS(5739),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(5739),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(5739),
    [anon_sym_AMP_AMP] = ACTIONS(5286),
    [anon_sym_PIPE_PIPE] = ACTIONS(5286),
    [anon_sym_QMARK_QMARK] = ACTIONS(5288),
    [anon_sym_from] = ACTIONS(5286),
    [anon_sym_into] = ACTIONS(5286),
    [anon_sym_join] = ACTIONS(5286),
    [anon_sym_let] = ACTIONS(5286),
    [anon_sym_orderby] = ACTIONS(5286),
    [anon_sym_group] = ACTIONS(5286),
    [anon_sym_select] = ACTIONS(5286),
    [anon_sym_as] = ACTIONS(5286),
    [anon_sym_is] = ACTIONS(5286),
    [anon_sym_DASH_GT] = ACTIONS(5286),
    [anon_sym_with] = ACTIONS(5286),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3801] = {
    [sym_preproc_region] = STATE(3801),
    [sym_preproc_endregion] = STATE(3801),
    [sym_preproc_line] = STATE(3801),
    [sym_preproc_pragma] = STATE(3801),
    [sym_preproc_nullable] = STATE(3801),
    [sym_preproc_error] = STATE(3801),
    [sym_preproc_warning] = STATE(3801),
    [sym_preproc_define] = STATE(3801),
    [sym_preproc_undef] = STATE(3801),
    [anon_sym_EQ] = ACTIONS(4672),
    [anon_sym_LBRACK] = ACTIONS(4703),
    [anon_sym_COLON] = ACTIONS(4703),
    [anon_sym_COMMA] = ACTIONS(4703),
    [anon_sym_LPAREN] = ACTIONS(4703),
    [anon_sym_RPAREN] = ACTIONS(4703),
    [anon_sym_RBRACE] = ACTIONS(4703),
    [anon_sym_LT] = ACTIONS(4705),
    [anon_sym_GT] = ACTIONS(4705),
    [anon_sym_QMARK] = ACTIONS(4705),
    [anon_sym_BANG] = ACTIONS(4705),
    [anon_sym_PLUS_PLUS] = ACTIONS(4703),
    [anon_sym_DASH_DASH] = ACTIONS(4703),
    [anon_sym_PLUS] = ACTIONS(4705),
    [anon_sym_DASH] = ACTIONS(4705),
    [anon_sym_STAR] = ACTIONS(4705),
    [anon_sym_SLASH] = ACTIONS(4705),
    [anon_sym_PERCENT] = ACTIONS(4705),
    [anon_sym_CARET] = ACTIONS(4705),
    [anon_sym_PIPE] = ACTIONS(4705),
    [anon_sym_AMP] = ACTIONS(4705),
    [anon_sym_LT_LT] = ACTIONS(4705),
    [anon_sym_GT_GT] = ACTIONS(4705),
    [anon_sym_GT_GT_GT] = ACTIONS(4705),
    [anon_sym_EQ_EQ] = ACTIONS(4703),
    [anon_sym_BANG_EQ] = ACTIONS(4703),
    [anon_sym_GT_EQ] = ACTIONS(4703),
    [anon_sym_LT_EQ] = ACTIONS(4703),
    [anon_sym_DOT] = ACTIONS(4705),
    [anon_sym_switch] = ACTIONS(4703),
    [anon_sym_when] = ACTIONS(4703),
    [anon_sym_DOT_DOT] = ACTIONS(4703),
    [anon_sym_and] = ACTIONS(4703),
    [anon_sym_or] = ACTIONS(4703),
    [anon_sym_PLUS_EQ] = ACTIONS(4670),
    [anon_sym_DASH_EQ] = ACTIONS(4670),
    [anon_sym_STAR_EQ] = ACTIONS(4670),
    [anon_sym_SLASH_EQ] = ACTIONS(4670),
    [anon_sym_PERCENT_EQ] = ACTIONS(4670),
    [anon_sym_AMP_EQ] = ACTIONS(4670),
    [anon_sym_CARET_EQ] = ACTIONS(4670),
    [anon_sym_PIPE_EQ] = ACTIONS(4670),
    [anon_sym_LT_LT_EQ] = ACTIONS(4670),
    [anon_sym_GT_GT_EQ] = ACTIONS(4670),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4670),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4670),
    [anon_sym_AMP_AMP] = ACTIONS(4703),
    [anon_sym_PIPE_PIPE] = ACTIONS(4703),
    [anon_sym_QMARK_QMARK] = ACTIONS(4705),
    [anon_sym_into] = ACTIONS(4703),
    [anon_sym_as] = ACTIONS(4703),
    [anon_sym_is] = ACTIONS(4703),
    [anon_sym_DASH_GT] = ACTIONS(4703),
    [anon_sym_with] = ACTIONS(4703),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3802] = {
    [sym_attribute_list] = STATE(6699),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7396),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(6749),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3802),
    [sym_preproc_endregion] = STATE(3802),
    [sym_preproc_line] = STATE(3802),
    [sym_preproc_pragma] = STATE(3802),
    [sym_preproc_nullable] = STATE(3802),
    [sym_preproc_error] = STATE(3802),
    [sym_preproc_warning] = STATE(3802),
    [sym_preproc_define] = STATE(3802),
    [sym_preproc_undef] = STATE(3802),
    [aux_sym_class_declaration_repeat1] = STATE(6149),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(4312),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LBRACK] = ACTIONS(5307),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(5309),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_in] = ACTIONS(1113),
    [anon_sym_out] = ACTIONS(1113),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_this] = ACTIONS(1113),
    [anon_sym_scoped] = ACTIONS(5321),
    [anon_sym_params] = ACTIONS(5313),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3803] = {
    [sym_preproc_region] = STATE(3803),
    [sym_preproc_endregion] = STATE(3803),
    [sym_preproc_line] = STATE(3803),
    [sym_preproc_pragma] = STATE(3803),
    [sym_preproc_nullable] = STATE(3803),
    [sym_preproc_error] = STATE(3803),
    [sym_preproc_warning] = STATE(3803),
    [sym_preproc_define] = STATE(3803),
    [sym_preproc_undef] = STATE(3803),
    [sym__identifier_token] = ACTIONS(4042),
    [anon_sym_extern] = ACTIONS(4042),
    [anon_sym_alias] = ACTIONS(4042),
    [anon_sym_global] = ACTIONS(4042),
    [anon_sym_unsafe] = ACTIONS(4042),
    [anon_sym_static] = ACTIONS(4042),
    [anon_sym_LPAREN] = ACTIONS(5474),
    [anon_sym_event] = ACTIONS(4042),
    [anon_sym_class] = ACTIONS(4042),
    [anon_sym_ref] = ACTIONS(4042),
    [anon_sym_struct] = ACTIONS(4042),
    [anon_sym_enum] = ACTIONS(4042),
    [anon_sym_interface] = ACTIONS(4042),
    [anon_sym_delegate] = ACTIONS(4042),
    [anon_sym_record] = ACTIONS(4042),
    [anon_sym_abstract] = ACTIONS(4042),
    [anon_sym_async] = ACTIONS(4042),
    [anon_sym_const] = ACTIONS(4042),
    [anon_sym_file] = ACTIONS(4042),
    [anon_sym_fixed] = ACTIONS(4042),
    [anon_sym_internal] = ACTIONS(4042),
    [anon_sym_new] = ACTIONS(4042),
    [anon_sym_override] = ACTIONS(4042),
    [anon_sym_partial] = ACTIONS(4042),
    [anon_sym_private] = ACTIONS(4042),
    [anon_sym_protected] = ACTIONS(4042),
    [anon_sym_public] = ACTIONS(4042),
    [anon_sym_readonly] = ACTIONS(4042),
    [anon_sym_required] = ACTIONS(4042),
    [anon_sym_sealed] = ACTIONS(4042),
    [anon_sym_virtual] = ACTIONS(4042),
    [anon_sym_volatile] = ACTIONS(4042),
    [anon_sym_where] = ACTIONS(4042),
    [anon_sym_notnull] = ACTIONS(4042),
    [anon_sym_unmanaged] = ACTIONS(4042),
    [anon_sym_implicit] = ACTIONS(4042),
    [anon_sym_explicit] = ACTIONS(4042),
    [anon_sym_scoped] = ACTIONS(4042),
    [anon_sym_var] = ACTIONS(4042),
    [sym_predefined_type] = ACTIONS(4042),
    [anon_sym_yield] = ACTIONS(4042),
    [anon_sym_when] = ACTIONS(4042),
    [anon_sym_from] = ACTIONS(4042),
    [anon_sym_into] = ACTIONS(4042),
    [anon_sym_join] = ACTIONS(4042),
    [anon_sym_on] = ACTIONS(4042),
    [anon_sym_equals] = ACTIONS(4042),
    [anon_sym_let] = ACTIONS(4042),
    [anon_sym_orderby] = ACTIONS(4042),
    [anon_sym_ascending] = ACTIONS(4042),
    [anon_sym_descending] = ACTIONS(4042),
    [anon_sym_group] = ACTIONS(4042),
    [anon_sym_by] = ACTIONS(4042),
    [anon_sym_select] = ACTIONS(4042),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3804] = {
    [sym_attribute_list] = STATE(7300),
    [sym_type_parameter] = STATE(8576),
    [sym__name] = STATE(7943),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(8421),
    [sym_implicit_type] = STATE(8787),
    [sym_array_type] = STATE(8347),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9367),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(8787),
    [sym_scoped_type] = STATE(8787),
    [sym_tuple_type] = STATE(8173),
    [sym_identifier] = STATE(7609),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3804),
    [sym_preproc_endregion] = STATE(3804),
    [sym_preproc_line] = STATE(3804),
    [sym_preproc_pragma] = STATE(3804),
    [sym_preproc_nullable] = STATE(3804),
    [sym_preproc_error] = STATE(3804),
    [sym_preproc_warning] = STATE(3804),
    [sym_preproc_define] = STATE(3804),
    [sym_preproc_undef] = STATE(3804),
    [aux_sym_class_declaration_repeat1] = STATE(6864),
    [aux_sym_type_argument_list_repeat1] = STATE(8426),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LBRACK] = ACTIONS(5741),
    [anon_sym_COMMA] = ACTIONS(5743),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(5745),
    [anon_sym_delegate] = ACTIONS(5747),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_GT] = ACTIONS(5749),
    [anon_sym_in] = ACTIONS(5751),
    [anon_sym_out] = ACTIONS(5751),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(5753),
    [anon_sym_var] = ACTIONS(5369),
    [sym_predefined_type] = ACTIONS(5755),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3805] = {
    [sym_attribute_list] = STATE(4448),
    [sym_modifier] = STATE(4497),
    [sym_identifier] = STATE(7872),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_region] = STATE(3805),
    [sym_preproc_endregion] = STATE(3805),
    [sym_preproc_line] = STATE(3805),
    [sym_preproc_pragma] = STATE(3805),
    [sym_preproc_nullable] = STATE(3805),
    [sym_preproc_error] = STATE(3805),
    [sym_preproc_warning] = STATE(3805),
    [sym_preproc_define] = STATE(3805),
    [sym_preproc_undef] = STATE(3805),
    [aux_sym_class_declaration_repeat1] = STATE(4296),
    [aux_sym_class_declaration_repeat2] = STATE(4087),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(5456),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_unsafe] = ACTIONS(5456),
    [anon_sym_static] = ACTIONS(5456),
    [anon_sym_LBRACK] = ACTIONS(5458),
    [anon_sym_abstract] = ACTIONS(5456),
    [anon_sym_async] = ACTIONS(5456),
    [anon_sym_const] = ACTIONS(5456),
    [anon_sym_file] = ACTIONS(5462),
    [anon_sym_fixed] = ACTIONS(5456),
    [anon_sym_internal] = ACTIONS(5456),
    [anon_sym_new] = ACTIONS(5456),
    [anon_sym_override] = ACTIONS(5456),
    [anon_sym_partial] = ACTIONS(5456),
    [anon_sym_private] = ACTIONS(5456),
    [anon_sym_protected] = ACTIONS(5456),
    [anon_sym_public] = ACTIONS(5456),
    [anon_sym_readonly] = ACTIONS(5456),
    [anon_sym_required] = ACTIONS(5456),
    [anon_sym_sealed] = ACTIONS(5456),
    [anon_sym_virtual] = ACTIONS(5456),
    [anon_sym_volatile] = ACTIONS(5456),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_get] = ACTIONS(5757),
    [anon_sym_set] = ACTIONS(5757),
    [anon_sym_add] = ACTIONS(5757),
    [anon_sym_remove] = ACTIONS(5757),
    [anon_sym_init] = ACTIONS(5757),
    [anon_sym_scoped] = ACTIONS(29),
    [anon_sym_var] = ACTIONS(29),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_from] = ACTIONS(29),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3806] = {
    [sym_argument_list] = STATE(3852),
    [sym_initializer_expression] = STATE(4061),
    [sym_preproc_region] = STATE(3806),
    [sym_preproc_endregion] = STATE(3806),
    [sym_preproc_line] = STATE(3806),
    [sym_preproc_pragma] = STATE(3806),
    [sym_preproc_nullable] = STATE(3806),
    [sym_preproc_error] = STATE(3806),
    [sym_preproc_warning] = STATE(3806),
    [sym_preproc_define] = STATE(3806),
    [sym_preproc_undef] = STATE(3806),
    [anon_sym_SEMI] = ACTIONS(5263),
    [anon_sym_LBRACK] = ACTIONS(5263),
    [anon_sym_COLON] = ACTIONS(5263),
    [anon_sym_COMMA] = ACTIONS(5263),
    [anon_sym_RBRACK] = ACTIONS(5263),
    [anon_sym_LPAREN] = ACTIONS(5759),
    [anon_sym_RPAREN] = ACTIONS(5263),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_RBRACE] = ACTIONS(5263),
    [anon_sym_LT] = ACTIONS(5267),
    [anon_sym_GT] = ACTIONS(5267),
    [anon_sym_in] = ACTIONS(5267),
    [anon_sym_QMARK] = ACTIONS(5267),
    [anon_sym_BANG] = ACTIONS(5267),
    [anon_sym_PLUS_PLUS] = ACTIONS(5263),
    [anon_sym_DASH_DASH] = ACTIONS(5263),
    [anon_sym_PLUS] = ACTIONS(5267),
    [anon_sym_DASH] = ACTIONS(5267),
    [anon_sym_STAR] = ACTIONS(5263),
    [anon_sym_SLASH] = ACTIONS(5267),
    [anon_sym_PERCENT] = ACTIONS(5263),
    [anon_sym_CARET] = ACTIONS(5263),
    [anon_sym_PIPE] = ACTIONS(5267),
    [anon_sym_AMP] = ACTIONS(5267),
    [anon_sym_LT_LT] = ACTIONS(5263),
    [anon_sym_GT_GT] = ACTIONS(5267),
    [anon_sym_GT_GT_GT] = ACTIONS(5263),
    [anon_sym_EQ_EQ] = ACTIONS(5263),
    [anon_sym_BANG_EQ] = ACTIONS(5263),
    [anon_sym_GT_EQ] = ACTIONS(5263),
    [anon_sym_LT_EQ] = ACTIONS(5263),
    [anon_sym_DOT] = ACTIONS(5267),
    [anon_sym_EQ_GT] = ACTIONS(5263),
    [anon_sym_switch] = ACTIONS(5263),
    [anon_sym_when] = ACTIONS(5263),
    [anon_sym_DOT_DOT] = ACTIONS(5263),
    [anon_sym_and] = ACTIONS(5263),
    [anon_sym_or] = ACTIONS(5263),
    [anon_sym_AMP_AMP] = ACTIONS(5263),
    [anon_sym_PIPE_PIPE] = ACTIONS(5263),
    [anon_sym_QMARK_QMARK] = ACTIONS(5263),
    [anon_sym_into] = ACTIONS(5263),
    [anon_sym_on] = ACTIONS(5263),
    [anon_sym_equals] = ACTIONS(5263),
    [anon_sym_by] = ACTIONS(5263),
    [anon_sym_as] = ACTIONS(5263),
    [anon_sym_is] = ACTIONS(5263),
    [anon_sym_DASH_GT] = ACTIONS(5263),
    [anon_sym_with] = ACTIONS(5263),
    [aux_sym_preproc_if_token3] = ACTIONS(5263),
    [aux_sym_preproc_else_token1] = ACTIONS(5263),
    [aux_sym_preproc_elif_token1] = ACTIONS(5263),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3807] = {
    [sym_preproc_region] = STATE(3807),
    [sym_preproc_endregion] = STATE(3807),
    [sym_preproc_line] = STATE(3807),
    [sym_preproc_pragma] = STATE(3807),
    [sym_preproc_nullable] = STATE(3807),
    [sym_preproc_error] = STATE(3807),
    [sym_preproc_warning] = STATE(3807),
    [sym_preproc_define] = STATE(3807),
    [sym_preproc_undef] = STATE(3807),
    [sym__identifier_token] = ACTIONS(5761),
    [anon_sym_extern] = ACTIONS(5761),
    [anon_sym_alias] = ACTIONS(5761),
    [anon_sym_global] = ACTIONS(5761),
    [anon_sym_unsafe] = ACTIONS(5761),
    [anon_sym_static] = ACTIONS(5761),
    [anon_sym_LPAREN] = ACTIONS(5763),
    [anon_sym_event] = ACTIONS(5761),
    [anon_sym_class] = ACTIONS(5761),
    [anon_sym_ref] = ACTIONS(5761),
    [anon_sym_struct] = ACTIONS(5761),
    [anon_sym_enum] = ACTIONS(5761),
    [anon_sym_interface] = ACTIONS(5761),
    [anon_sym_delegate] = ACTIONS(5761),
    [anon_sym_record] = ACTIONS(5761),
    [anon_sym_abstract] = ACTIONS(5761),
    [anon_sym_async] = ACTIONS(5761),
    [anon_sym_const] = ACTIONS(5761),
    [anon_sym_file] = ACTIONS(5761),
    [anon_sym_fixed] = ACTIONS(5761),
    [anon_sym_internal] = ACTIONS(5761),
    [anon_sym_new] = ACTIONS(5761),
    [anon_sym_override] = ACTIONS(5761),
    [anon_sym_partial] = ACTIONS(5761),
    [anon_sym_private] = ACTIONS(5761),
    [anon_sym_protected] = ACTIONS(5761),
    [anon_sym_public] = ACTIONS(5761),
    [anon_sym_readonly] = ACTIONS(5761),
    [anon_sym_required] = ACTIONS(5761),
    [anon_sym_sealed] = ACTIONS(5761),
    [anon_sym_virtual] = ACTIONS(5761),
    [anon_sym_volatile] = ACTIONS(5761),
    [anon_sym_where] = ACTIONS(5761),
    [anon_sym_notnull] = ACTIONS(5761),
    [anon_sym_unmanaged] = ACTIONS(5761),
    [anon_sym_implicit] = ACTIONS(5761),
    [anon_sym_explicit] = ACTIONS(5761),
    [anon_sym_scoped] = ACTIONS(5761),
    [anon_sym_var] = ACTIONS(5761),
    [sym_predefined_type] = ACTIONS(5761),
    [anon_sym_yield] = ACTIONS(5761),
    [anon_sym_when] = ACTIONS(5761),
    [anon_sym_from] = ACTIONS(5761),
    [anon_sym_into] = ACTIONS(5761),
    [anon_sym_join] = ACTIONS(5761),
    [anon_sym_on] = ACTIONS(5761),
    [anon_sym_equals] = ACTIONS(5761),
    [anon_sym_let] = ACTIONS(5761),
    [anon_sym_orderby] = ACTIONS(5761),
    [anon_sym_ascending] = ACTIONS(5761),
    [anon_sym_descending] = ACTIONS(5761),
    [anon_sym_group] = ACTIONS(5761),
    [anon_sym_by] = ACTIONS(5761),
    [anon_sym_select] = ACTIONS(5761),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3808] = {
    [sym_type_argument_list] = STATE(3901),
    [sym_preproc_region] = STATE(3808),
    [sym_preproc_endregion] = STATE(3808),
    [sym_preproc_line] = STATE(3808),
    [sym_preproc_pragma] = STATE(3808),
    [sym_preproc_nullable] = STATE(3808),
    [sym_preproc_error] = STATE(3808),
    [sym_preproc_warning] = STATE(3808),
    [sym_preproc_define] = STATE(3808),
    [sym_preproc_undef] = STATE(3808),
    [anon_sym_SEMI] = ACTIONS(4140),
    [anon_sym_LBRACK] = ACTIONS(4140),
    [anon_sym_COLON] = ACTIONS(4138),
    [anon_sym_COMMA] = ACTIONS(4140),
    [anon_sym_RBRACK] = ACTIONS(4140),
    [anon_sym_LPAREN] = ACTIONS(4140),
    [anon_sym_RPAREN] = ACTIONS(4140),
    [anon_sym_LBRACE] = ACTIONS(4140),
    [anon_sym_RBRACE] = ACTIONS(4140),
    [anon_sym_LT] = ACTIONS(5765),
    [anon_sym_GT] = ACTIONS(4138),
    [anon_sym_in] = ACTIONS(4138),
    [anon_sym_QMARK] = ACTIONS(4138),
    [anon_sym_BANG] = ACTIONS(4138),
    [anon_sym_PLUS_PLUS] = ACTIONS(4140),
    [anon_sym_DASH_DASH] = ACTIONS(4140),
    [anon_sym_PLUS] = ACTIONS(4138),
    [anon_sym_DASH] = ACTIONS(4138),
    [anon_sym_STAR] = ACTIONS(4140),
    [anon_sym_SLASH] = ACTIONS(4138),
    [anon_sym_PERCENT] = ACTIONS(4140),
    [anon_sym_CARET] = ACTIONS(4140),
    [anon_sym_PIPE] = ACTIONS(4138),
    [anon_sym_AMP] = ACTIONS(4138),
    [anon_sym_LT_LT] = ACTIONS(4140),
    [anon_sym_GT_GT] = ACTIONS(4138),
    [anon_sym_GT_GT_GT] = ACTIONS(4140),
    [anon_sym_EQ_EQ] = ACTIONS(4140),
    [anon_sym_BANG_EQ] = ACTIONS(4140),
    [anon_sym_GT_EQ] = ACTIONS(4140),
    [anon_sym_LT_EQ] = ACTIONS(4140),
    [anon_sym_DOT] = ACTIONS(4138),
    [anon_sym_EQ_GT] = ACTIONS(4140),
    [anon_sym_COLON_COLON] = ACTIONS(5768),
    [anon_sym_switch] = ACTIONS(4140),
    [anon_sym_when] = ACTIONS(4140),
    [anon_sym_DOT_DOT] = ACTIONS(4140),
    [anon_sym_and] = ACTIONS(4140),
    [anon_sym_or] = ACTIONS(4140),
    [anon_sym_AMP_AMP] = ACTIONS(4140),
    [anon_sym_PIPE_PIPE] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK] = ACTIONS(4140),
    [anon_sym_into] = ACTIONS(4140),
    [anon_sym_on] = ACTIONS(4140),
    [anon_sym_equals] = ACTIONS(4140),
    [anon_sym_by] = ACTIONS(4140),
    [anon_sym_as] = ACTIONS(4140),
    [anon_sym_is] = ACTIONS(4140),
    [anon_sym_DASH_GT] = ACTIONS(4140),
    [anon_sym_with] = ACTIONS(4140),
    [aux_sym_preproc_if_token3] = ACTIONS(4140),
    [aux_sym_preproc_else_token1] = ACTIONS(4140),
    [aux_sym_preproc_elif_token1] = ACTIONS(4140),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3809] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7145),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9021),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3809),
    [sym_preproc_endregion] = STATE(3809),
    [sym_preproc_line] = STATE(3809),
    [sym_preproc_pragma] = STATE(3809),
    [sym_preproc_nullable] = STATE(3809),
    [sym_preproc_error] = STATE(3809),
    [sym_preproc_warning] = STATE(3809),
    [sym_preproc_define] = STATE(3809),
    [sym_preproc_undef] = STATE(3809),
    [aux_sym_class_declaration_repeat1] = STATE(6149),
    [aux_sym_lambda_expression_repeat1] = STATE(4310),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(5307),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3810] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(6960),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9128),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3810),
    [sym_preproc_endregion] = STATE(3810),
    [sym_preproc_line] = STATE(3810),
    [sym_preproc_pragma] = STATE(3810),
    [sym_preproc_nullable] = STATE(3810),
    [sym_preproc_error] = STATE(3810),
    [sym_preproc_warning] = STATE(3810),
    [sym_preproc_define] = STATE(3810),
    [sym_preproc_undef] = STATE(3810),
    [aux_sym_class_declaration_repeat1] = STATE(6149),
    [aux_sym_lambda_expression_repeat1] = STATE(4193),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(5307),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3811] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(6965),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9023),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3811),
    [sym_preproc_endregion] = STATE(3811),
    [sym_preproc_line] = STATE(3811),
    [sym_preproc_pragma] = STATE(3811),
    [sym_preproc_nullable] = STATE(3811),
    [sym_preproc_error] = STATE(3811),
    [sym_preproc_warning] = STATE(3811),
    [sym_preproc_define] = STATE(3811),
    [sym_preproc_undef] = STATE(3811),
    [aux_sym_class_declaration_repeat1] = STATE(6149),
    [aux_sym_lambda_expression_repeat1] = STATE(4202),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(5307),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3812] = {
    [sym__name] = STATE(8818),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_identifier] = STATE(7937),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_region] = STATE(3812),
    [sym_preproc_endregion] = STATE(3812),
    [sym_preproc_line] = STATE(3812),
    [sym_preproc_pragma] = STATE(3812),
    [sym_preproc_nullable] = STATE(3812),
    [sym_preproc_error] = STATE(3812),
    [sym_preproc_warning] = STATE(3812),
    [sym_preproc_define] = STATE(3812),
    [sym_preproc_undef] = STATE(3812),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(4042),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_unsafe] = ACTIONS(4042),
    [anon_sym_static] = ACTIONS(4042),
    [anon_sym_LPAREN] = ACTIONS(5474),
    [anon_sym_ref] = ACTIONS(4042),
    [anon_sym_delegate] = ACTIONS(4042),
    [anon_sym_abstract] = ACTIONS(4042),
    [anon_sym_async] = ACTIONS(4042),
    [anon_sym_const] = ACTIONS(4042),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_fixed] = ACTIONS(4042),
    [anon_sym_internal] = ACTIONS(4042),
    [anon_sym_new] = ACTIONS(4042),
    [anon_sym_override] = ACTIONS(4042),
    [anon_sym_partial] = ACTIONS(4042),
    [anon_sym_private] = ACTIONS(4042),
    [anon_sym_protected] = ACTIONS(4042),
    [anon_sym_public] = ACTIONS(4042),
    [anon_sym_readonly] = ACTIONS(4042),
    [anon_sym_required] = ACTIONS(4042),
    [anon_sym_sealed] = ACTIONS(4042),
    [anon_sym_virtual] = ACTIONS(4042),
    [anon_sym_volatile] = ACTIONS(4042),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_scoped] = ACTIONS(29),
    [anon_sym_var] = ACTIONS(29),
    [sym_predefined_type] = ACTIONS(4042),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_from] = ACTIONS(29),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3813] = {
    [sym_preproc_region] = STATE(3813),
    [sym_preproc_endregion] = STATE(3813),
    [sym_preproc_line] = STATE(3813),
    [sym_preproc_pragma] = STATE(3813),
    [sym_preproc_nullable] = STATE(3813),
    [sym_preproc_error] = STATE(3813),
    [sym_preproc_warning] = STATE(3813),
    [sym_preproc_define] = STATE(3813),
    [sym_preproc_undef] = STATE(3813),
    [anon_sym_SEMI] = ACTIONS(5286),
    [anon_sym_EQ] = ACTIONS(5770),
    [anon_sym_LBRACK] = ACTIONS(5286),
    [anon_sym_COMMA] = ACTIONS(5286),
    [anon_sym_RBRACK] = ACTIONS(5286),
    [anon_sym_LPAREN] = ACTIONS(5286),
    [anon_sym_RPAREN] = ACTIONS(5286),
    [anon_sym_RBRACE] = ACTIONS(5286),
    [anon_sym_LT] = ACTIONS(5288),
    [anon_sym_GT] = ACTIONS(5288),
    [anon_sym_QMARK] = ACTIONS(5288),
    [anon_sym_BANG] = ACTIONS(5288),
    [anon_sym_PLUS_PLUS] = ACTIONS(5286),
    [anon_sym_DASH_DASH] = ACTIONS(5286),
    [anon_sym_PLUS] = ACTIONS(5288),
    [anon_sym_DASH] = ACTIONS(5288),
    [anon_sym_STAR] = ACTIONS(5288),
    [anon_sym_SLASH] = ACTIONS(5288),
    [anon_sym_PERCENT] = ACTIONS(5288),
    [anon_sym_CARET] = ACTIONS(5288),
    [anon_sym_PIPE] = ACTIONS(5288),
    [anon_sym_AMP] = ACTIONS(5288),
    [anon_sym_LT_LT] = ACTIONS(5288),
    [anon_sym_GT_GT] = ACTIONS(5288),
    [anon_sym_GT_GT_GT] = ACTIONS(5288),
    [anon_sym_EQ_EQ] = ACTIONS(5286),
    [anon_sym_BANG_EQ] = ACTIONS(5286),
    [anon_sym_GT_EQ] = ACTIONS(5286),
    [anon_sym_LT_EQ] = ACTIONS(5286),
    [anon_sym_DOT] = ACTIONS(5288),
    [anon_sym_switch] = ACTIONS(5286),
    [anon_sym_DOT_DOT] = ACTIONS(5286),
    [anon_sym_and] = ACTIONS(5286),
    [anon_sym_or] = ACTIONS(5286),
    [anon_sym_PLUS_EQ] = ACTIONS(5772),
    [anon_sym_DASH_EQ] = ACTIONS(5772),
    [anon_sym_STAR_EQ] = ACTIONS(5772),
    [anon_sym_SLASH_EQ] = ACTIONS(5772),
    [anon_sym_PERCENT_EQ] = ACTIONS(5772),
    [anon_sym_AMP_EQ] = ACTIONS(5772),
    [anon_sym_CARET_EQ] = ACTIONS(5772),
    [anon_sym_PIPE_EQ] = ACTIONS(5772),
    [anon_sym_LT_LT_EQ] = ACTIONS(5772),
    [anon_sym_GT_GT_EQ] = ACTIONS(5772),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(5772),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(5772),
    [anon_sym_AMP_AMP] = ACTIONS(5286),
    [anon_sym_PIPE_PIPE] = ACTIONS(5286),
    [anon_sym_QMARK_QMARK] = ACTIONS(5288),
    [anon_sym_as] = ACTIONS(5286),
    [anon_sym_is] = ACTIONS(5286),
    [anon_sym_DASH_GT] = ACTIONS(5286),
    [anon_sym_with] = ACTIONS(5286),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3814] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(6969),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9968),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3814),
    [sym_preproc_endregion] = STATE(3814),
    [sym_preproc_line] = STATE(3814),
    [sym_preproc_pragma] = STATE(3814),
    [sym_preproc_nullable] = STATE(3814),
    [sym_preproc_error] = STATE(3814),
    [sym_preproc_warning] = STATE(3814),
    [sym_preproc_define] = STATE(3814),
    [sym_preproc_undef] = STATE(3814),
    [aux_sym_class_declaration_repeat1] = STATE(6149),
    [aux_sym_lambda_expression_repeat1] = STATE(4210),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(5307),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3815] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(6975),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9777),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3815),
    [sym_preproc_endregion] = STATE(3815),
    [sym_preproc_line] = STATE(3815),
    [sym_preproc_pragma] = STATE(3815),
    [sym_preproc_nullable] = STATE(3815),
    [sym_preproc_error] = STATE(3815),
    [sym_preproc_warning] = STATE(3815),
    [sym_preproc_define] = STATE(3815),
    [sym_preproc_undef] = STATE(3815),
    [aux_sym_class_declaration_repeat1] = STATE(6149),
    [aux_sym_lambda_expression_repeat1] = STATE(4219),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(5307),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3816] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(6981),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9226),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3816),
    [sym_preproc_endregion] = STATE(3816),
    [sym_preproc_line] = STATE(3816),
    [sym_preproc_pragma] = STATE(3816),
    [sym_preproc_nullable] = STATE(3816),
    [sym_preproc_error] = STATE(3816),
    [sym_preproc_warning] = STATE(3816),
    [sym_preproc_define] = STATE(3816),
    [sym_preproc_undef] = STATE(3816),
    [aux_sym_class_declaration_repeat1] = STATE(6149),
    [aux_sym_lambda_expression_repeat1] = STATE(4226),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(5307),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3817] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(6986),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9395),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3817),
    [sym_preproc_endregion] = STATE(3817),
    [sym_preproc_line] = STATE(3817),
    [sym_preproc_pragma] = STATE(3817),
    [sym_preproc_nullable] = STATE(3817),
    [sym_preproc_error] = STATE(3817),
    [sym_preproc_warning] = STATE(3817),
    [sym_preproc_define] = STATE(3817),
    [sym_preproc_undef] = STATE(3817),
    [aux_sym_class_declaration_repeat1] = STATE(6149),
    [aux_sym_lambda_expression_repeat1] = STATE(4228),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(5307),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3818] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(6990),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9593),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3818),
    [sym_preproc_endregion] = STATE(3818),
    [sym_preproc_line] = STATE(3818),
    [sym_preproc_pragma] = STATE(3818),
    [sym_preproc_nullable] = STATE(3818),
    [sym_preproc_error] = STATE(3818),
    [sym_preproc_warning] = STATE(3818),
    [sym_preproc_define] = STATE(3818),
    [sym_preproc_undef] = STATE(3818),
    [aux_sym_class_declaration_repeat1] = STATE(6149),
    [aux_sym_lambda_expression_repeat1] = STATE(4231),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(5307),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3819] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(6994),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9649),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3819),
    [sym_preproc_endregion] = STATE(3819),
    [sym_preproc_line] = STATE(3819),
    [sym_preproc_pragma] = STATE(3819),
    [sym_preproc_nullable] = STATE(3819),
    [sym_preproc_error] = STATE(3819),
    [sym_preproc_warning] = STATE(3819),
    [sym_preproc_define] = STATE(3819),
    [sym_preproc_undef] = STATE(3819),
    [aux_sym_class_declaration_repeat1] = STATE(6149),
    [aux_sym_lambda_expression_repeat1] = STATE(4233),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(5307),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3820] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(6998),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9709),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3820),
    [sym_preproc_endregion] = STATE(3820),
    [sym_preproc_line] = STATE(3820),
    [sym_preproc_pragma] = STATE(3820),
    [sym_preproc_nullable] = STATE(3820),
    [sym_preproc_error] = STATE(3820),
    [sym_preproc_warning] = STATE(3820),
    [sym_preproc_define] = STATE(3820),
    [sym_preproc_undef] = STATE(3820),
    [aux_sym_class_declaration_repeat1] = STATE(6149),
    [aux_sym_lambda_expression_repeat1] = STATE(4235),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(5307),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3821] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7003),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9781),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3821),
    [sym_preproc_endregion] = STATE(3821),
    [sym_preproc_line] = STATE(3821),
    [sym_preproc_pragma] = STATE(3821),
    [sym_preproc_nullable] = STATE(3821),
    [sym_preproc_error] = STATE(3821),
    [sym_preproc_warning] = STATE(3821),
    [sym_preproc_define] = STATE(3821),
    [sym_preproc_undef] = STATE(3821),
    [aux_sym_class_declaration_repeat1] = STATE(6149),
    [aux_sym_lambda_expression_repeat1] = STATE(4237),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(5307),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3822] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7008),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9834),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3822),
    [sym_preproc_endregion] = STATE(3822),
    [sym_preproc_line] = STATE(3822),
    [sym_preproc_pragma] = STATE(3822),
    [sym_preproc_nullable] = STATE(3822),
    [sym_preproc_error] = STATE(3822),
    [sym_preproc_warning] = STATE(3822),
    [sym_preproc_define] = STATE(3822),
    [sym_preproc_undef] = STATE(3822),
    [aux_sym_class_declaration_repeat1] = STATE(6149),
    [aux_sym_lambda_expression_repeat1] = STATE(4239),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(5307),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3823] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7012),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9273),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3823),
    [sym_preproc_endregion] = STATE(3823),
    [sym_preproc_line] = STATE(3823),
    [sym_preproc_pragma] = STATE(3823),
    [sym_preproc_nullable] = STATE(3823),
    [sym_preproc_error] = STATE(3823),
    [sym_preproc_warning] = STATE(3823),
    [sym_preproc_define] = STATE(3823),
    [sym_preproc_undef] = STATE(3823),
    [aux_sym_class_declaration_repeat1] = STATE(6149),
    [aux_sym_lambda_expression_repeat1] = STATE(4241),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(5307),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3824] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7016),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9879),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3824),
    [sym_preproc_endregion] = STATE(3824),
    [sym_preproc_line] = STATE(3824),
    [sym_preproc_pragma] = STATE(3824),
    [sym_preproc_nullable] = STATE(3824),
    [sym_preproc_error] = STATE(3824),
    [sym_preproc_warning] = STATE(3824),
    [sym_preproc_define] = STATE(3824),
    [sym_preproc_undef] = STATE(3824),
    [aux_sym_class_declaration_repeat1] = STATE(6149),
    [aux_sym_lambda_expression_repeat1] = STATE(4243),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(5307),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3825] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7020),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9952),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3825),
    [sym_preproc_endregion] = STATE(3825),
    [sym_preproc_line] = STATE(3825),
    [sym_preproc_pragma] = STATE(3825),
    [sym_preproc_nullable] = STATE(3825),
    [sym_preproc_error] = STATE(3825),
    [sym_preproc_warning] = STATE(3825),
    [sym_preproc_define] = STATE(3825),
    [sym_preproc_undef] = STATE(3825),
    [aux_sym_class_declaration_repeat1] = STATE(6149),
    [aux_sym_lambda_expression_repeat1] = STATE(4245),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(5307),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3826] = {
    [sym__name] = STATE(8818),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_identifier] = STATE(5346),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_region] = STATE(3826),
    [sym_preproc_endregion] = STATE(3826),
    [sym_preproc_line] = STATE(3826),
    [sym_preproc_pragma] = STATE(3826),
    [sym_preproc_nullable] = STATE(3826),
    [sym_preproc_error] = STATE(3826),
    [sym_preproc_warning] = STATE(3826),
    [sym_preproc_define] = STATE(3826),
    [sym_preproc_undef] = STATE(3826),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(4042),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_unsafe] = ACTIONS(5774),
    [anon_sym_static] = ACTIONS(4042),
    [anon_sym_LPAREN] = ACTIONS(5474),
    [anon_sym_ref] = ACTIONS(4042),
    [anon_sym_delegate] = ACTIONS(4042),
    [anon_sym_abstract] = ACTIONS(4042),
    [anon_sym_async] = ACTIONS(4042),
    [anon_sym_const] = ACTIONS(4042),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_fixed] = ACTIONS(4042),
    [anon_sym_internal] = ACTIONS(4042),
    [anon_sym_new] = ACTIONS(4042),
    [anon_sym_override] = ACTIONS(4042),
    [anon_sym_partial] = ACTIONS(4042),
    [anon_sym_private] = ACTIONS(4042),
    [anon_sym_protected] = ACTIONS(4042),
    [anon_sym_public] = ACTIONS(4042),
    [anon_sym_readonly] = ACTIONS(4042),
    [anon_sym_required] = ACTIONS(4042),
    [anon_sym_sealed] = ACTIONS(4042),
    [anon_sym_virtual] = ACTIONS(4042),
    [anon_sym_volatile] = ACTIONS(4042),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_scoped] = ACTIONS(29),
    [anon_sym_var] = ACTIONS(29),
    [sym_predefined_type] = ACTIONS(4042),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_from] = ACTIONS(29),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3827] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7024),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9066),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3827),
    [sym_preproc_endregion] = STATE(3827),
    [sym_preproc_line] = STATE(3827),
    [sym_preproc_pragma] = STATE(3827),
    [sym_preproc_nullable] = STATE(3827),
    [sym_preproc_error] = STATE(3827),
    [sym_preproc_warning] = STATE(3827),
    [sym_preproc_define] = STATE(3827),
    [sym_preproc_undef] = STATE(3827),
    [aux_sym_class_declaration_repeat1] = STATE(6149),
    [aux_sym_lambda_expression_repeat1] = STATE(4247),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(5307),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3828] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7029),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9919),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3828),
    [sym_preproc_endregion] = STATE(3828),
    [sym_preproc_line] = STATE(3828),
    [sym_preproc_pragma] = STATE(3828),
    [sym_preproc_nullable] = STATE(3828),
    [sym_preproc_error] = STATE(3828),
    [sym_preproc_warning] = STATE(3828),
    [sym_preproc_define] = STATE(3828),
    [sym_preproc_undef] = STATE(3828),
    [aux_sym_class_declaration_repeat1] = STATE(6149),
    [aux_sym_lambda_expression_repeat1] = STATE(4250),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(5307),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3829] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7034),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9637),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3829),
    [sym_preproc_endregion] = STATE(3829),
    [sym_preproc_line] = STATE(3829),
    [sym_preproc_pragma] = STATE(3829),
    [sym_preproc_nullable] = STATE(3829),
    [sym_preproc_error] = STATE(3829),
    [sym_preproc_warning] = STATE(3829),
    [sym_preproc_define] = STATE(3829),
    [sym_preproc_undef] = STATE(3829),
    [aux_sym_class_declaration_repeat1] = STATE(6149),
    [aux_sym_lambda_expression_repeat1] = STATE(4254),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(5307),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3830] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7038),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9230),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3830),
    [sym_preproc_endregion] = STATE(3830),
    [sym_preproc_line] = STATE(3830),
    [sym_preproc_pragma] = STATE(3830),
    [sym_preproc_nullable] = STATE(3830),
    [sym_preproc_error] = STATE(3830),
    [sym_preproc_warning] = STATE(3830),
    [sym_preproc_define] = STATE(3830),
    [sym_preproc_undef] = STATE(3830),
    [aux_sym_class_declaration_repeat1] = STATE(6149),
    [aux_sym_lambda_expression_repeat1] = STATE(4256),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(5307),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3831] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7042),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9304),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3831),
    [sym_preproc_endregion] = STATE(3831),
    [sym_preproc_line] = STATE(3831),
    [sym_preproc_pragma] = STATE(3831),
    [sym_preproc_nullable] = STATE(3831),
    [sym_preproc_error] = STATE(3831),
    [sym_preproc_warning] = STATE(3831),
    [sym_preproc_define] = STATE(3831),
    [sym_preproc_undef] = STATE(3831),
    [aux_sym_class_declaration_repeat1] = STATE(6149),
    [aux_sym_lambda_expression_repeat1] = STATE(4258),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(5307),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3832] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7046),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9561),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3832),
    [sym_preproc_endregion] = STATE(3832),
    [sym_preproc_line] = STATE(3832),
    [sym_preproc_pragma] = STATE(3832),
    [sym_preproc_nullable] = STATE(3832),
    [sym_preproc_error] = STATE(3832),
    [sym_preproc_warning] = STATE(3832),
    [sym_preproc_define] = STATE(3832),
    [sym_preproc_undef] = STATE(3832),
    [aux_sym_class_declaration_repeat1] = STATE(6149),
    [aux_sym_lambda_expression_repeat1] = STATE(4260),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(5307),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3833] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7051),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9036),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3833),
    [sym_preproc_endregion] = STATE(3833),
    [sym_preproc_line] = STATE(3833),
    [sym_preproc_pragma] = STATE(3833),
    [sym_preproc_nullable] = STATE(3833),
    [sym_preproc_error] = STATE(3833),
    [sym_preproc_warning] = STATE(3833),
    [sym_preproc_define] = STATE(3833),
    [sym_preproc_undef] = STATE(3833),
    [aux_sym_class_declaration_repeat1] = STATE(6149),
    [aux_sym_lambda_expression_repeat1] = STATE(4262),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(5307),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3834] = {
    [sym_argument_list] = STATE(3952),
    [sym_initializer_expression] = STATE(4326),
    [sym_preproc_region] = STATE(3834),
    [sym_preproc_endregion] = STATE(3834),
    [sym_preproc_line] = STATE(3834),
    [sym_preproc_pragma] = STATE(3834),
    [sym_preproc_nullable] = STATE(3834),
    [sym_preproc_error] = STATE(3834),
    [sym_preproc_warning] = STATE(3834),
    [sym_preproc_define] = STATE(3834),
    [sym_preproc_undef] = STATE(3834),
    [anon_sym_SEMI] = ACTIONS(5263),
    [anon_sym_LBRACK] = ACTIONS(5263),
    [anon_sym_COLON] = ACTIONS(5263),
    [anon_sym_COMMA] = ACTIONS(5263),
    [anon_sym_RBRACK] = ACTIONS(5263),
    [anon_sym_LPAREN] = ACTIONS(5776),
    [anon_sym_RPAREN] = ACTIONS(5263),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_RBRACE] = ACTIONS(5263),
    [anon_sym_LT] = ACTIONS(5267),
    [anon_sym_GT] = ACTIONS(5267),
    [anon_sym_in] = ACTIONS(5263),
    [anon_sym_QMARK] = ACTIONS(5267),
    [anon_sym_BANG] = ACTIONS(5267),
    [anon_sym_PLUS_PLUS] = ACTIONS(5263),
    [anon_sym_DASH_DASH] = ACTIONS(5263),
    [anon_sym_PLUS] = ACTIONS(5267),
    [anon_sym_DASH] = ACTIONS(5267),
    [anon_sym_STAR] = ACTIONS(5263),
    [anon_sym_SLASH] = ACTIONS(5267),
    [anon_sym_PERCENT] = ACTIONS(5263),
    [anon_sym_CARET] = ACTIONS(5263),
    [anon_sym_PIPE] = ACTIONS(5267),
    [anon_sym_AMP] = ACTIONS(5267),
    [anon_sym_LT_LT] = ACTIONS(5263),
    [anon_sym_GT_GT] = ACTIONS(5267),
    [anon_sym_GT_GT_GT] = ACTIONS(5263),
    [anon_sym_EQ_EQ] = ACTIONS(5263),
    [anon_sym_BANG_EQ] = ACTIONS(5263),
    [anon_sym_GT_EQ] = ACTIONS(5263),
    [anon_sym_LT_EQ] = ACTIONS(5263),
    [anon_sym_DOT] = ACTIONS(5267),
    [anon_sym_EQ_GT] = ACTIONS(5263),
    [anon_sym_switch] = ACTIONS(5263),
    [anon_sym_when] = ACTIONS(5263),
    [anon_sym_DOT_DOT] = ACTIONS(5263),
    [anon_sym_and] = ACTIONS(5263),
    [anon_sym_or] = ACTIONS(5263),
    [anon_sym_AMP_AMP] = ACTIONS(5263),
    [anon_sym_PIPE_PIPE] = ACTIONS(5263),
    [anon_sym_QMARK_QMARK] = ACTIONS(5263),
    [anon_sym_on] = ACTIONS(5263),
    [anon_sym_equals] = ACTIONS(5263),
    [anon_sym_by] = ACTIONS(5263),
    [anon_sym_as] = ACTIONS(5263),
    [anon_sym_is] = ACTIONS(5263),
    [anon_sym_DASH_GT] = ACTIONS(5263),
    [anon_sym_with] = ACTIONS(5263),
    [aux_sym_preproc_if_token3] = ACTIONS(5263),
    [aux_sym_preproc_else_token1] = ACTIONS(5263),
    [aux_sym_preproc_elif_token1] = ACTIONS(5263),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3835] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7055),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9197),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3835),
    [sym_preproc_endregion] = STATE(3835),
    [sym_preproc_line] = STATE(3835),
    [sym_preproc_pragma] = STATE(3835),
    [sym_preproc_nullable] = STATE(3835),
    [sym_preproc_error] = STATE(3835),
    [sym_preproc_warning] = STATE(3835),
    [sym_preproc_define] = STATE(3835),
    [sym_preproc_undef] = STATE(3835),
    [aux_sym_class_declaration_repeat1] = STATE(6149),
    [aux_sym_lambda_expression_repeat1] = STATE(4264),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(5307),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3836] = {
    [sym_argument_list] = STATE(4044),
    [sym_bracketed_argument_list] = STATE(3189),
    [sym_preproc_region] = STATE(3836),
    [sym_preproc_endregion] = STATE(3836),
    [sym_preproc_line] = STATE(3836),
    [sym_preproc_pragma] = STATE(3836),
    [sym_preproc_nullable] = STATE(3836),
    [sym_preproc_error] = STATE(3836),
    [sym_preproc_warning] = STATE(3836),
    [sym_preproc_define] = STATE(3836),
    [sym_preproc_undef] = STATE(3836),
    [anon_sym_SEMI] = ACTIONS(5271),
    [anon_sym_LBRACK] = ACTIONS(5778),
    [anon_sym_COLON] = ACTIONS(5271),
    [anon_sym_COMMA] = ACTIONS(5271),
    [anon_sym_RBRACK] = ACTIONS(5271),
    [anon_sym_LPAREN] = ACTIONS(5759),
    [anon_sym_RPAREN] = ACTIONS(5271),
    [anon_sym_RBRACE] = ACTIONS(5271),
    [anon_sym_LT] = ACTIONS(5275),
    [anon_sym_GT] = ACTIONS(5275),
    [anon_sym_in] = ACTIONS(5275),
    [anon_sym_QMARK] = ACTIONS(5275),
    [anon_sym_BANG] = ACTIONS(5780),
    [anon_sym_PLUS_PLUS] = ACTIONS(5782),
    [anon_sym_DASH_DASH] = ACTIONS(5782),
    [anon_sym_PLUS] = ACTIONS(5275),
    [anon_sym_DASH] = ACTIONS(5275),
    [anon_sym_STAR] = ACTIONS(5271),
    [anon_sym_SLASH] = ACTIONS(5275),
    [anon_sym_PERCENT] = ACTIONS(5271),
    [anon_sym_CARET] = ACTIONS(5271),
    [anon_sym_PIPE] = ACTIONS(5275),
    [anon_sym_AMP] = ACTIONS(5275),
    [anon_sym_LT_LT] = ACTIONS(5271),
    [anon_sym_GT_GT] = ACTIONS(5275),
    [anon_sym_GT_GT_GT] = ACTIONS(5271),
    [anon_sym_EQ_EQ] = ACTIONS(5271),
    [anon_sym_BANG_EQ] = ACTIONS(5271),
    [anon_sym_GT_EQ] = ACTIONS(5271),
    [anon_sym_LT_EQ] = ACTIONS(5271),
    [anon_sym_DOT] = ACTIONS(4634),
    [anon_sym_EQ_GT] = ACTIONS(5271),
    [anon_sym_switch] = ACTIONS(5271),
    [anon_sym_when] = ACTIONS(5271),
    [anon_sym_DOT_DOT] = ACTIONS(5271),
    [anon_sym_and] = ACTIONS(5271),
    [anon_sym_or] = ACTIONS(5271),
    [anon_sym_AMP_AMP] = ACTIONS(5271),
    [anon_sym_PIPE_PIPE] = ACTIONS(5271),
    [anon_sym_QMARK_QMARK] = ACTIONS(5271),
    [anon_sym_into] = ACTIONS(5271),
    [anon_sym_on] = ACTIONS(5271),
    [anon_sym_equals] = ACTIONS(5271),
    [anon_sym_by] = ACTIONS(5271),
    [anon_sym_as] = ACTIONS(5271),
    [anon_sym_is] = ACTIONS(5271),
    [anon_sym_DASH_GT] = ACTIONS(4636),
    [anon_sym_with] = ACTIONS(5271),
    [aux_sym_preproc_if_token3] = ACTIONS(5271),
    [aux_sym_preproc_else_token1] = ACTIONS(5271),
    [aux_sym_preproc_elif_token1] = ACTIONS(5271),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3837] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7059),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9244),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3837),
    [sym_preproc_endregion] = STATE(3837),
    [sym_preproc_line] = STATE(3837),
    [sym_preproc_pragma] = STATE(3837),
    [sym_preproc_nullable] = STATE(3837),
    [sym_preproc_error] = STATE(3837),
    [sym_preproc_warning] = STATE(3837),
    [sym_preproc_define] = STATE(3837),
    [sym_preproc_undef] = STATE(3837),
    [aux_sym_class_declaration_repeat1] = STATE(6149),
    [aux_sym_lambda_expression_repeat1] = STATE(4266),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(5307),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3838] = {
    [sym_argument_list] = STATE(4044),
    [sym_bracketed_argument_list] = STATE(3189),
    [sym_preproc_region] = STATE(3838),
    [sym_preproc_endregion] = STATE(3838),
    [sym_preproc_line] = STATE(3838),
    [sym_preproc_pragma] = STATE(3838),
    [sym_preproc_nullable] = STATE(3838),
    [sym_preproc_error] = STATE(3838),
    [sym_preproc_warning] = STATE(3838),
    [sym_preproc_define] = STATE(3838),
    [sym_preproc_undef] = STATE(3838),
    [anon_sym_SEMI] = ACTIONS(5292),
    [anon_sym_LBRACK] = ACTIONS(5778),
    [anon_sym_COLON] = ACTIONS(5292),
    [anon_sym_COMMA] = ACTIONS(5292),
    [anon_sym_RBRACK] = ACTIONS(5292),
    [anon_sym_LPAREN] = ACTIONS(5759),
    [anon_sym_RPAREN] = ACTIONS(5292),
    [anon_sym_RBRACE] = ACTIONS(5292),
    [anon_sym_LT] = ACTIONS(5294),
    [anon_sym_GT] = ACTIONS(5294),
    [anon_sym_in] = ACTIONS(5294),
    [anon_sym_QMARK] = ACTIONS(5294),
    [anon_sym_BANG] = ACTIONS(5780),
    [anon_sym_PLUS_PLUS] = ACTIONS(5782),
    [anon_sym_DASH_DASH] = ACTIONS(5782),
    [anon_sym_PLUS] = ACTIONS(5294),
    [anon_sym_DASH] = ACTIONS(5294),
    [anon_sym_STAR] = ACTIONS(5292),
    [anon_sym_SLASH] = ACTIONS(5294),
    [anon_sym_PERCENT] = ACTIONS(5292),
    [anon_sym_CARET] = ACTIONS(5292),
    [anon_sym_PIPE] = ACTIONS(5294),
    [anon_sym_AMP] = ACTIONS(5294),
    [anon_sym_LT_LT] = ACTIONS(5292),
    [anon_sym_GT_GT] = ACTIONS(5294),
    [anon_sym_GT_GT_GT] = ACTIONS(5292),
    [anon_sym_EQ_EQ] = ACTIONS(5292),
    [anon_sym_BANG_EQ] = ACTIONS(5292),
    [anon_sym_GT_EQ] = ACTIONS(5292),
    [anon_sym_LT_EQ] = ACTIONS(5292),
    [anon_sym_DOT] = ACTIONS(4634),
    [anon_sym_EQ_GT] = ACTIONS(5292),
    [anon_sym_switch] = ACTIONS(5292),
    [anon_sym_when] = ACTIONS(5292),
    [anon_sym_DOT_DOT] = ACTIONS(5292),
    [anon_sym_and] = ACTIONS(5292),
    [anon_sym_or] = ACTIONS(5292),
    [anon_sym_AMP_AMP] = ACTIONS(5292),
    [anon_sym_PIPE_PIPE] = ACTIONS(5292),
    [anon_sym_QMARK_QMARK] = ACTIONS(5292),
    [anon_sym_into] = ACTIONS(5292),
    [anon_sym_on] = ACTIONS(5292),
    [anon_sym_equals] = ACTIONS(5292),
    [anon_sym_by] = ACTIONS(5292),
    [anon_sym_as] = ACTIONS(5292),
    [anon_sym_is] = ACTIONS(5292),
    [anon_sym_DASH_GT] = ACTIONS(4636),
    [anon_sym_with] = ACTIONS(5292),
    [aux_sym_preproc_if_token3] = ACTIONS(5292),
    [aux_sym_preproc_else_token1] = ACTIONS(5292),
    [aux_sym_preproc_elif_token1] = ACTIONS(5292),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3839] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7063),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9296),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3839),
    [sym_preproc_endregion] = STATE(3839),
    [sym_preproc_line] = STATE(3839),
    [sym_preproc_pragma] = STATE(3839),
    [sym_preproc_nullable] = STATE(3839),
    [sym_preproc_error] = STATE(3839),
    [sym_preproc_warning] = STATE(3839),
    [sym_preproc_define] = STATE(3839),
    [sym_preproc_undef] = STATE(3839),
    [aux_sym_class_declaration_repeat1] = STATE(6149),
    [aux_sym_lambda_expression_repeat1] = STATE(4268),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(5307),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3840] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7067),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9394),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3840),
    [sym_preproc_endregion] = STATE(3840),
    [sym_preproc_line] = STATE(3840),
    [sym_preproc_pragma] = STATE(3840),
    [sym_preproc_nullable] = STATE(3840),
    [sym_preproc_error] = STATE(3840),
    [sym_preproc_warning] = STATE(3840),
    [sym_preproc_define] = STATE(3840),
    [sym_preproc_undef] = STATE(3840),
    [aux_sym_class_declaration_repeat1] = STATE(6149),
    [aux_sym_lambda_expression_repeat1] = STATE(4270),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(5307),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3841] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7071),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9655),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3841),
    [sym_preproc_endregion] = STATE(3841),
    [sym_preproc_line] = STATE(3841),
    [sym_preproc_pragma] = STATE(3841),
    [sym_preproc_nullable] = STATE(3841),
    [sym_preproc_error] = STATE(3841),
    [sym_preproc_warning] = STATE(3841),
    [sym_preproc_define] = STATE(3841),
    [sym_preproc_undef] = STATE(3841),
    [aux_sym_class_declaration_repeat1] = STATE(6149),
    [aux_sym_lambda_expression_repeat1] = STATE(4272),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(5307),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3842] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7075),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9337),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3842),
    [sym_preproc_endregion] = STATE(3842),
    [sym_preproc_line] = STATE(3842),
    [sym_preproc_pragma] = STATE(3842),
    [sym_preproc_nullable] = STATE(3842),
    [sym_preproc_error] = STATE(3842),
    [sym_preproc_warning] = STATE(3842),
    [sym_preproc_define] = STATE(3842),
    [sym_preproc_undef] = STATE(3842),
    [aux_sym_class_declaration_repeat1] = STATE(6149),
    [aux_sym_lambda_expression_repeat1] = STATE(4274),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(5307),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3843] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7079),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9853),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3843),
    [sym_preproc_endregion] = STATE(3843),
    [sym_preproc_line] = STATE(3843),
    [sym_preproc_pragma] = STATE(3843),
    [sym_preproc_nullable] = STATE(3843),
    [sym_preproc_error] = STATE(3843),
    [sym_preproc_warning] = STATE(3843),
    [sym_preproc_define] = STATE(3843),
    [sym_preproc_undef] = STATE(3843),
    [aux_sym_class_declaration_repeat1] = STATE(6149),
    [aux_sym_lambda_expression_repeat1] = STATE(4276),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(5307),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3844] = {
    [sym__name] = STATE(8730),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_identifier] = STATE(5346),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_region] = STATE(3844),
    [sym_preproc_endregion] = STATE(3844),
    [sym_preproc_line] = STATE(3844),
    [sym_preproc_pragma] = STATE(3844),
    [sym_preproc_nullable] = STATE(3844),
    [sym_preproc_error] = STATE(3844),
    [sym_preproc_warning] = STATE(3844),
    [sym_preproc_define] = STATE(3844),
    [sym_preproc_undef] = STATE(3844),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(4042),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_unsafe] = ACTIONS(5784),
    [anon_sym_static] = ACTIONS(4042),
    [anon_sym_LPAREN] = ACTIONS(5474),
    [anon_sym_ref] = ACTIONS(4042),
    [anon_sym_delegate] = ACTIONS(4042),
    [anon_sym_abstract] = ACTIONS(4042),
    [anon_sym_async] = ACTIONS(4042),
    [anon_sym_const] = ACTIONS(4042),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_fixed] = ACTIONS(4042),
    [anon_sym_internal] = ACTIONS(4042),
    [anon_sym_new] = ACTIONS(4042),
    [anon_sym_override] = ACTIONS(4042),
    [anon_sym_partial] = ACTIONS(4042),
    [anon_sym_private] = ACTIONS(4042),
    [anon_sym_protected] = ACTIONS(4042),
    [anon_sym_public] = ACTIONS(4042),
    [anon_sym_readonly] = ACTIONS(4042),
    [anon_sym_required] = ACTIONS(4042),
    [anon_sym_sealed] = ACTIONS(4042),
    [anon_sym_virtual] = ACTIONS(4042),
    [anon_sym_volatile] = ACTIONS(4042),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_scoped] = ACTIONS(29),
    [anon_sym_var] = ACTIONS(29),
    [sym_predefined_type] = ACTIONS(4042),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_from] = ACTIONS(29),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3845] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7137),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9363),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3845),
    [sym_preproc_endregion] = STATE(3845),
    [sym_preproc_line] = STATE(3845),
    [sym_preproc_pragma] = STATE(3845),
    [sym_preproc_nullable] = STATE(3845),
    [sym_preproc_error] = STATE(3845),
    [sym_preproc_warning] = STATE(3845),
    [sym_preproc_define] = STATE(3845),
    [sym_preproc_undef] = STATE(3845),
    [aux_sym_class_declaration_repeat1] = STATE(6149),
    [aux_sym_lambda_expression_repeat1] = STATE(4185),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(5307),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3846] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7087),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9037),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3846),
    [sym_preproc_endregion] = STATE(3846),
    [sym_preproc_line] = STATE(3846),
    [sym_preproc_pragma] = STATE(3846),
    [sym_preproc_nullable] = STATE(3846),
    [sym_preproc_error] = STATE(3846),
    [sym_preproc_warning] = STATE(3846),
    [sym_preproc_define] = STATE(3846),
    [sym_preproc_undef] = STATE(3846),
    [aux_sym_class_declaration_repeat1] = STATE(6149),
    [aux_sym_lambda_expression_repeat1] = STATE(4279),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(5307),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3847] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7093),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9083),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3847),
    [sym_preproc_endregion] = STATE(3847),
    [sym_preproc_line] = STATE(3847),
    [sym_preproc_pragma] = STATE(3847),
    [sym_preproc_nullable] = STATE(3847),
    [sym_preproc_error] = STATE(3847),
    [sym_preproc_warning] = STATE(3847),
    [sym_preproc_define] = STATE(3847),
    [sym_preproc_undef] = STATE(3847),
    [aux_sym_class_declaration_repeat1] = STATE(6149),
    [aux_sym_lambda_expression_repeat1] = STATE(4281),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(5307),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3848] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7097),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9125),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3848),
    [sym_preproc_endregion] = STATE(3848),
    [sym_preproc_line] = STATE(3848),
    [sym_preproc_pragma] = STATE(3848),
    [sym_preproc_nullable] = STATE(3848),
    [sym_preproc_error] = STATE(3848),
    [sym_preproc_warning] = STATE(3848),
    [sym_preproc_define] = STATE(3848),
    [sym_preproc_undef] = STATE(3848),
    [aux_sym_class_declaration_repeat1] = STATE(6149),
    [aux_sym_lambda_expression_repeat1] = STATE(4283),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(5307),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3849] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7101),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9199),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3849),
    [sym_preproc_endregion] = STATE(3849),
    [sym_preproc_line] = STATE(3849),
    [sym_preproc_pragma] = STATE(3849),
    [sym_preproc_nullable] = STATE(3849),
    [sym_preproc_error] = STATE(3849),
    [sym_preproc_warning] = STATE(3849),
    [sym_preproc_define] = STATE(3849),
    [sym_preproc_undef] = STATE(3849),
    [aux_sym_class_declaration_repeat1] = STATE(6149),
    [aux_sym_lambda_expression_repeat1] = STATE(4285),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(5307),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3850] = {
    [sym_type_argument_list] = STATE(3901),
    [sym_preproc_region] = STATE(3850),
    [sym_preproc_endregion] = STATE(3850),
    [sym_preproc_line] = STATE(3850),
    [sym_preproc_pragma] = STATE(3850),
    [sym_preproc_nullable] = STATE(3850),
    [sym_preproc_error] = STATE(3850),
    [sym_preproc_warning] = STATE(3850),
    [sym_preproc_define] = STATE(3850),
    [sym_preproc_undef] = STATE(3850),
    [anon_sym_SEMI] = ACTIONS(4140),
    [anon_sym_LBRACK] = ACTIONS(4140),
    [anon_sym_COLON] = ACTIONS(4140),
    [anon_sym_COMMA] = ACTIONS(4140),
    [anon_sym_RBRACK] = ACTIONS(4140),
    [anon_sym_LPAREN] = ACTIONS(4140),
    [anon_sym_RPAREN] = ACTIONS(4140),
    [anon_sym_LBRACE] = ACTIONS(4140),
    [anon_sym_RBRACE] = ACTIONS(4140),
    [anon_sym_LT] = ACTIONS(5765),
    [anon_sym_GT] = ACTIONS(4138),
    [anon_sym_in] = ACTIONS(4138),
    [anon_sym_QMARK] = ACTIONS(4138),
    [anon_sym_BANG] = ACTIONS(4138),
    [anon_sym_PLUS_PLUS] = ACTIONS(4140),
    [anon_sym_DASH_DASH] = ACTIONS(4140),
    [anon_sym_PLUS] = ACTIONS(4138),
    [anon_sym_DASH] = ACTIONS(4138),
    [anon_sym_STAR] = ACTIONS(4140),
    [anon_sym_SLASH] = ACTIONS(4138),
    [anon_sym_PERCENT] = ACTIONS(4140),
    [anon_sym_CARET] = ACTIONS(4140),
    [anon_sym_PIPE] = ACTIONS(4138),
    [anon_sym_AMP] = ACTIONS(4138),
    [anon_sym_LT_LT] = ACTIONS(4140),
    [anon_sym_GT_GT] = ACTIONS(4138),
    [anon_sym_GT_GT_GT] = ACTIONS(4140),
    [anon_sym_EQ_EQ] = ACTIONS(4140),
    [anon_sym_BANG_EQ] = ACTIONS(4140),
    [anon_sym_GT_EQ] = ACTIONS(4140),
    [anon_sym_LT_EQ] = ACTIONS(4140),
    [anon_sym_DOT] = ACTIONS(4138),
    [anon_sym_EQ_GT] = ACTIONS(4140),
    [anon_sym_switch] = ACTIONS(4140),
    [anon_sym_when] = ACTIONS(4140),
    [anon_sym_DOT_DOT] = ACTIONS(4140),
    [anon_sym_and] = ACTIONS(4140),
    [anon_sym_or] = ACTIONS(4140),
    [anon_sym_AMP_AMP] = ACTIONS(4140),
    [anon_sym_PIPE_PIPE] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK] = ACTIONS(4140),
    [anon_sym_into] = ACTIONS(4140),
    [anon_sym_on] = ACTIONS(4140),
    [anon_sym_equals] = ACTIONS(4140),
    [anon_sym_by] = ACTIONS(4140),
    [anon_sym_as] = ACTIONS(4140),
    [anon_sym_is] = ACTIONS(4140),
    [anon_sym_DASH_GT] = ACTIONS(4140),
    [anon_sym_with] = ACTIONS(4140),
    [aux_sym_preproc_if_token3] = ACTIONS(4140),
    [aux_sym_preproc_else_token1] = ACTIONS(4140),
    [aux_sym_preproc_elif_token1] = ACTIONS(4140),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3851] = {
    [sym_initializer_expression] = STATE(3974),
    [sym_preproc_region] = STATE(3851),
    [sym_preproc_endregion] = STATE(3851),
    [sym_preproc_line] = STATE(3851),
    [sym_preproc_pragma] = STATE(3851),
    [sym_preproc_nullable] = STATE(3851),
    [sym_preproc_error] = STATE(3851),
    [sym_preproc_warning] = STATE(3851),
    [sym_preproc_define] = STATE(3851),
    [sym_preproc_undef] = STATE(3851),
    [anon_sym_SEMI] = ACTIONS(5296),
    [anon_sym_LBRACK] = ACTIONS(5298),
    [anon_sym_COLON] = ACTIONS(5296),
    [anon_sym_COMMA] = ACTIONS(5296),
    [anon_sym_RBRACK] = ACTIONS(5296),
    [anon_sym_LPAREN] = ACTIONS(5296),
    [anon_sym_RPAREN] = ACTIONS(5296),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_RBRACE] = ACTIONS(5296),
    [anon_sym_LT] = ACTIONS(5301),
    [anon_sym_GT] = ACTIONS(5301),
    [anon_sym_in] = ACTIONS(5301),
    [anon_sym_QMARK] = ACTIONS(5301),
    [anon_sym_BANG] = ACTIONS(5301),
    [anon_sym_PLUS_PLUS] = ACTIONS(5296),
    [anon_sym_DASH_DASH] = ACTIONS(5296),
    [anon_sym_PLUS] = ACTIONS(5301),
    [anon_sym_DASH] = ACTIONS(5301),
    [anon_sym_STAR] = ACTIONS(5296),
    [anon_sym_SLASH] = ACTIONS(5301),
    [anon_sym_PERCENT] = ACTIONS(5296),
    [anon_sym_CARET] = ACTIONS(5296),
    [anon_sym_PIPE] = ACTIONS(5301),
    [anon_sym_AMP] = ACTIONS(5301),
    [anon_sym_LT_LT] = ACTIONS(5296),
    [anon_sym_GT_GT] = ACTIONS(5301),
    [anon_sym_GT_GT_GT] = ACTIONS(5296),
    [anon_sym_EQ_EQ] = ACTIONS(5296),
    [anon_sym_BANG_EQ] = ACTIONS(5296),
    [anon_sym_GT_EQ] = ACTIONS(5296),
    [anon_sym_LT_EQ] = ACTIONS(5296),
    [anon_sym_DOT] = ACTIONS(5301),
    [anon_sym_EQ_GT] = ACTIONS(5296),
    [anon_sym_switch] = ACTIONS(5296),
    [anon_sym_when] = ACTIONS(5296),
    [anon_sym_DOT_DOT] = ACTIONS(5296),
    [anon_sym_and] = ACTIONS(5296),
    [anon_sym_or] = ACTIONS(5296),
    [anon_sym_AMP_AMP] = ACTIONS(5296),
    [anon_sym_PIPE_PIPE] = ACTIONS(5296),
    [anon_sym_QMARK_QMARK] = ACTIONS(5296),
    [anon_sym_into] = ACTIONS(5296),
    [anon_sym_on] = ACTIONS(5296),
    [anon_sym_equals] = ACTIONS(5296),
    [anon_sym_by] = ACTIONS(5296),
    [anon_sym_as] = ACTIONS(5296),
    [anon_sym_is] = ACTIONS(5296),
    [anon_sym_DASH_GT] = ACTIONS(5296),
    [anon_sym_with] = ACTIONS(5296),
    [aux_sym_preproc_if_token3] = ACTIONS(5296),
    [aux_sym_preproc_else_token1] = ACTIONS(5296),
    [aux_sym_preproc_elif_token1] = ACTIONS(5296),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3852] = {
    [sym_initializer_expression] = STATE(4012),
    [sym_preproc_region] = STATE(3852),
    [sym_preproc_endregion] = STATE(3852),
    [sym_preproc_line] = STATE(3852),
    [sym_preproc_pragma] = STATE(3852),
    [sym_preproc_nullable] = STATE(3852),
    [sym_preproc_error] = STATE(3852),
    [sym_preproc_warning] = STATE(3852),
    [sym_preproc_define] = STATE(3852),
    [sym_preproc_undef] = STATE(3852),
    [anon_sym_SEMI] = ACTIONS(5303),
    [anon_sym_LBRACK] = ACTIONS(5303),
    [anon_sym_COLON] = ACTIONS(5303),
    [anon_sym_COMMA] = ACTIONS(5303),
    [anon_sym_RBRACK] = ACTIONS(5303),
    [anon_sym_LPAREN] = ACTIONS(5303),
    [anon_sym_RPAREN] = ACTIONS(5303),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_RBRACE] = ACTIONS(5303),
    [anon_sym_LT] = ACTIONS(5305),
    [anon_sym_GT] = ACTIONS(5305),
    [anon_sym_in] = ACTIONS(5305),
    [anon_sym_QMARK] = ACTIONS(5305),
    [anon_sym_BANG] = ACTIONS(5305),
    [anon_sym_PLUS_PLUS] = ACTIONS(5303),
    [anon_sym_DASH_DASH] = ACTIONS(5303),
    [anon_sym_PLUS] = ACTIONS(5305),
    [anon_sym_DASH] = ACTIONS(5305),
    [anon_sym_STAR] = ACTIONS(5303),
    [anon_sym_SLASH] = ACTIONS(5305),
    [anon_sym_PERCENT] = ACTIONS(5303),
    [anon_sym_CARET] = ACTIONS(5303),
    [anon_sym_PIPE] = ACTIONS(5305),
    [anon_sym_AMP] = ACTIONS(5305),
    [anon_sym_LT_LT] = ACTIONS(5303),
    [anon_sym_GT_GT] = ACTIONS(5305),
    [anon_sym_GT_GT_GT] = ACTIONS(5303),
    [anon_sym_EQ_EQ] = ACTIONS(5303),
    [anon_sym_BANG_EQ] = ACTIONS(5303),
    [anon_sym_GT_EQ] = ACTIONS(5303),
    [anon_sym_LT_EQ] = ACTIONS(5303),
    [anon_sym_DOT] = ACTIONS(5305),
    [anon_sym_EQ_GT] = ACTIONS(5303),
    [anon_sym_switch] = ACTIONS(5303),
    [anon_sym_when] = ACTIONS(5303),
    [anon_sym_DOT_DOT] = ACTIONS(5303),
    [anon_sym_and] = ACTIONS(5303),
    [anon_sym_or] = ACTIONS(5303),
    [anon_sym_AMP_AMP] = ACTIONS(5303),
    [anon_sym_PIPE_PIPE] = ACTIONS(5303),
    [anon_sym_QMARK_QMARK] = ACTIONS(5303),
    [anon_sym_into] = ACTIONS(5303),
    [anon_sym_on] = ACTIONS(5303),
    [anon_sym_equals] = ACTIONS(5303),
    [anon_sym_by] = ACTIONS(5303),
    [anon_sym_as] = ACTIONS(5303),
    [anon_sym_is] = ACTIONS(5303),
    [anon_sym_DASH_GT] = ACTIONS(5303),
    [anon_sym_with] = ACTIONS(5303),
    [aux_sym_preproc_if_token3] = ACTIONS(5303),
    [aux_sym_preproc_else_token1] = ACTIONS(5303),
    [aux_sym_preproc_elif_token1] = ACTIONS(5303),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3853] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7126),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9707),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3853),
    [sym_preproc_endregion] = STATE(3853),
    [sym_preproc_line] = STATE(3853),
    [sym_preproc_pragma] = STATE(3853),
    [sym_preproc_nullable] = STATE(3853),
    [sym_preproc_error] = STATE(3853),
    [sym_preproc_warning] = STATE(3853),
    [sym_preproc_define] = STATE(3853),
    [sym_preproc_undef] = STATE(3853),
    [aux_sym_class_declaration_repeat1] = STATE(6149),
    [aux_sym_lambda_expression_repeat1] = STATE(4301),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(5307),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3854] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7111),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9132),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3854),
    [sym_preproc_endregion] = STATE(3854),
    [sym_preproc_line] = STATE(3854),
    [sym_preproc_pragma] = STATE(3854),
    [sym_preproc_nullable] = STATE(3854),
    [sym_preproc_error] = STATE(3854),
    [sym_preproc_warning] = STATE(3854),
    [sym_preproc_define] = STATE(3854),
    [sym_preproc_undef] = STATE(3854),
    [aux_sym_class_declaration_repeat1] = STATE(6149),
    [aux_sym_lambda_expression_repeat1] = STATE(4141),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(5307),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3855] = {
    [sym_block] = STATE(2271),
    [sym_preproc_region] = STATE(3855),
    [sym_preproc_endregion] = STATE(3855),
    [sym_preproc_line] = STATE(3855),
    [sym_preproc_pragma] = STATE(3855),
    [sym_preproc_nullable] = STATE(3855),
    [sym_preproc_error] = STATE(3855),
    [sym_preproc_warning] = STATE(3855),
    [sym_preproc_define] = STATE(3855),
    [sym_preproc_undef] = STATE(3855),
    [sym__identifier_token] = ACTIONS(4042),
    [anon_sym_extern] = ACTIONS(4042),
    [anon_sym_alias] = ACTIONS(4042),
    [anon_sym_global] = ACTIONS(4042),
    [anon_sym_unsafe] = ACTIONS(4042),
    [anon_sym_static] = ACTIONS(4042),
    [anon_sym_LPAREN] = ACTIONS(5474),
    [anon_sym_class] = ACTIONS(4042),
    [anon_sym_ref] = ACTIONS(4042),
    [anon_sym_struct] = ACTIONS(4042),
    [anon_sym_enum] = ACTIONS(4042),
    [anon_sym_LBRACE] = ACTIONS(5786),
    [anon_sym_interface] = ACTIONS(4042),
    [anon_sym_delegate] = ACTIONS(4042),
    [anon_sym_record] = ACTIONS(4042),
    [anon_sym_abstract] = ACTIONS(4042),
    [anon_sym_async] = ACTIONS(4042),
    [anon_sym_const] = ACTIONS(4042),
    [anon_sym_file] = ACTIONS(4042),
    [anon_sym_fixed] = ACTIONS(4042),
    [anon_sym_internal] = ACTIONS(4042),
    [anon_sym_new] = ACTIONS(4042),
    [anon_sym_override] = ACTIONS(4042),
    [anon_sym_partial] = ACTIONS(4042),
    [anon_sym_private] = ACTIONS(4042),
    [anon_sym_protected] = ACTIONS(4042),
    [anon_sym_public] = ACTIONS(4042),
    [anon_sym_readonly] = ACTIONS(4042),
    [anon_sym_required] = ACTIONS(4042),
    [anon_sym_sealed] = ACTIONS(4042),
    [anon_sym_virtual] = ACTIONS(4042),
    [anon_sym_volatile] = ACTIONS(4042),
    [anon_sym_where] = ACTIONS(4042),
    [anon_sym_notnull] = ACTIONS(4042),
    [anon_sym_unmanaged] = ACTIONS(4042),
    [anon_sym_scoped] = ACTIONS(4042),
    [anon_sym_var] = ACTIONS(4042),
    [sym_predefined_type] = ACTIONS(4042),
    [anon_sym_yield] = ACTIONS(4042),
    [anon_sym_when] = ACTIONS(4042),
    [anon_sym_from] = ACTIONS(4042),
    [anon_sym_into] = ACTIONS(4042),
    [anon_sym_join] = ACTIONS(4042),
    [anon_sym_on] = ACTIONS(4042),
    [anon_sym_equals] = ACTIONS(4042),
    [anon_sym_let] = ACTIONS(4042),
    [anon_sym_orderby] = ACTIONS(4042),
    [anon_sym_ascending] = ACTIONS(4042),
    [anon_sym_descending] = ACTIONS(4042),
    [anon_sym_group] = ACTIONS(4042),
    [anon_sym_by] = ACTIONS(4042),
    [anon_sym_select] = ACTIONS(4042),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3856] = {
    [sym_block] = STATE(2503),
    [sym_preproc_region] = STATE(3856),
    [sym_preproc_endregion] = STATE(3856),
    [sym_preproc_line] = STATE(3856),
    [sym_preproc_pragma] = STATE(3856),
    [sym_preproc_nullable] = STATE(3856),
    [sym_preproc_error] = STATE(3856),
    [sym_preproc_warning] = STATE(3856),
    [sym_preproc_define] = STATE(3856),
    [sym_preproc_undef] = STATE(3856),
    [sym__identifier_token] = ACTIONS(4042),
    [anon_sym_extern] = ACTIONS(4042),
    [anon_sym_alias] = ACTIONS(4042),
    [anon_sym_global] = ACTIONS(4042),
    [anon_sym_unsafe] = ACTIONS(4042),
    [anon_sym_static] = ACTIONS(4042),
    [anon_sym_LPAREN] = ACTIONS(5474),
    [anon_sym_class] = ACTIONS(4042),
    [anon_sym_ref] = ACTIONS(4042),
    [anon_sym_struct] = ACTIONS(4042),
    [anon_sym_enum] = ACTIONS(4042),
    [anon_sym_LBRACE] = ACTIONS(5788),
    [anon_sym_interface] = ACTIONS(4042),
    [anon_sym_delegate] = ACTIONS(4042),
    [anon_sym_record] = ACTIONS(4042),
    [anon_sym_abstract] = ACTIONS(4042),
    [anon_sym_async] = ACTIONS(4042),
    [anon_sym_const] = ACTIONS(4042),
    [anon_sym_file] = ACTIONS(4042),
    [anon_sym_fixed] = ACTIONS(4042),
    [anon_sym_internal] = ACTIONS(4042),
    [anon_sym_new] = ACTIONS(4042),
    [anon_sym_override] = ACTIONS(4042),
    [anon_sym_partial] = ACTIONS(4042),
    [anon_sym_private] = ACTIONS(4042),
    [anon_sym_protected] = ACTIONS(4042),
    [anon_sym_public] = ACTIONS(4042),
    [anon_sym_readonly] = ACTIONS(4042),
    [anon_sym_required] = ACTIONS(4042),
    [anon_sym_sealed] = ACTIONS(4042),
    [anon_sym_virtual] = ACTIONS(4042),
    [anon_sym_volatile] = ACTIONS(4042),
    [anon_sym_where] = ACTIONS(4042),
    [anon_sym_notnull] = ACTIONS(4042),
    [anon_sym_unmanaged] = ACTIONS(4042),
    [anon_sym_scoped] = ACTIONS(4042),
    [anon_sym_var] = ACTIONS(4042),
    [sym_predefined_type] = ACTIONS(4042),
    [anon_sym_yield] = ACTIONS(4042),
    [anon_sym_when] = ACTIONS(4042),
    [anon_sym_from] = ACTIONS(4042),
    [anon_sym_into] = ACTIONS(4042),
    [anon_sym_join] = ACTIONS(4042),
    [anon_sym_on] = ACTIONS(4042),
    [anon_sym_equals] = ACTIONS(4042),
    [anon_sym_let] = ACTIONS(4042),
    [anon_sym_orderby] = ACTIONS(4042),
    [anon_sym_ascending] = ACTIONS(4042),
    [anon_sym_descending] = ACTIONS(4042),
    [anon_sym_group] = ACTIONS(4042),
    [anon_sym_by] = ACTIONS(4042),
    [anon_sym_select] = ACTIONS(4042),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3857] = {
    [sym_preproc_region] = STATE(3857),
    [sym_preproc_endregion] = STATE(3857),
    [sym_preproc_line] = STATE(3857),
    [sym_preproc_pragma] = STATE(3857),
    [sym_preproc_nullable] = STATE(3857),
    [sym_preproc_error] = STATE(3857),
    [sym_preproc_warning] = STATE(3857),
    [sym_preproc_define] = STATE(3857),
    [sym_preproc_undef] = STATE(3857),
    [anon_sym_EQ] = ACTIONS(5790),
    [anon_sym_LBRACK] = ACTIONS(5286),
    [anon_sym_LPAREN] = ACTIONS(5286),
    [anon_sym_LT] = ACTIONS(5288),
    [anon_sym_GT] = ACTIONS(5288),
    [anon_sym_where] = ACTIONS(5286),
    [anon_sym_QMARK] = ACTIONS(5288),
    [anon_sym_BANG] = ACTIONS(5288),
    [anon_sym_PLUS_PLUS] = ACTIONS(5286),
    [anon_sym_DASH_DASH] = ACTIONS(5286),
    [anon_sym_PLUS] = ACTIONS(5288),
    [anon_sym_DASH] = ACTIONS(5288),
    [anon_sym_STAR] = ACTIONS(5288),
    [anon_sym_SLASH] = ACTIONS(5288),
    [anon_sym_PERCENT] = ACTIONS(5288),
    [anon_sym_CARET] = ACTIONS(5288),
    [anon_sym_PIPE] = ACTIONS(5288),
    [anon_sym_AMP] = ACTIONS(5288),
    [anon_sym_LT_LT] = ACTIONS(5288),
    [anon_sym_GT_GT] = ACTIONS(5288),
    [anon_sym_GT_GT_GT] = ACTIONS(5288),
    [anon_sym_EQ_EQ] = ACTIONS(5286),
    [anon_sym_BANG_EQ] = ACTIONS(5286),
    [anon_sym_GT_EQ] = ACTIONS(5286),
    [anon_sym_LT_EQ] = ACTIONS(5286),
    [anon_sym_DOT] = ACTIONS(5288),
    [anon_sym_switch] = ACTIONS(5286),
    [anon_sym_DOT_DOT] = ACTIONS(5286),
    [anon_sym_PLUS_EQ] = ACTIONS(5792),
    [anon_sym_DASH_EQ] = ACTIONS(5792),
    [anon_sym_STAR_EQ] = ACTIONS(5792),
    [anon_sym_SLASH_EQ] = ACTIONS(5792),
    [anon_sym_PERCENT_EQ] = ACTIONS(5792),
    [anon_sym_AMP_EQ] = ACTIONS(5792),
    [anon_sym_CARET_EQ] = ACTIONS(5792),
    [anon_sym_PIPE_EQ] = ACTIONS(5792),
    [anon_sym_LT_LT_EQ] = ACTIONS(5792),
    [anon_sym_GT_GT_EQ] = ACTIONS(5792),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(5792),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(5792),
    [anon_sym_AMP_AMP] = ACTIONS(5286),
    [anon_sym_PIPE_PIPE] = ACTIONS(5286),
    [anon_sym_QMARK_QMARK] = ACTIONS(5288),
    [anon_sym_from] = ACTIONS(5286),
    [anon_sym_join] = ACTIONS(5286),
    [anon_sym_let] = ACTIONS(5286),
    [anon_sym_orderby] = ACTIONS(5286),
    [anon_sym_group] = ACTIONS(5286),
    [anon_sym_select] = ACTIONS(5286),
    [anon_sym_as] = ACTIONS(5286),
    [anon_sym_is] = ACTIONS(5286),
    [anon_sym_DASH_GT] = ACTIONS(5286),
    [anon_sym_with] = ACTIONS(5286),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3858] = {
    [sym__name] = STATE(8730),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_identifier] = STATE(7796),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_region] = STATE(3858),
    [sym_preproc_endregion] = STATE(3858),
    [sym_preproc_line] = STATE(3858),
    [sym_preproc_pragma] = STATE(3858),
    [sym_preproc_nullable] = STATE(3858),
    [sym_preproc_error] = STATE(3858),
    [sym_preproc_warning] = STATE(3858),
    [sym_preproc_define] = STATE(3858),
    [sym_preproc_undef] = STATE(3858),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(4042),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_unsafe] = ACTIONS(4042),
    [anon_sym_static] = ACTIONS(4042),
    [anon_sym_LPAREN] = ACTIONS(5474),
    [anon_sym_ref] = ACTIONS(4042),
    [anon_sym_delegate] = ACTIONS(4042),
    [anon_sym_abstract] = ACTIONS(4042),
    [anon_sym_async] = ACTIONS(4042),
    [anon_sym_const] = ACTIONS(4042),
    [anon_sym_file] = ACTIONS(29),
    [anon_sym_fixed] = ACTIONS(4042),
    [anon_sym_internal] = ACTIONS(4042),
    [anon_sym_new] = ACTIONS(4042),
    [anon_sym_override] = ACTIONS(4042),
    [anon_sym_partial] = ACTIONS(4042),
    [anon_sym_private] = ACTIONS(4042),
    [anon_sym_protected] = ACTIONS(4042),
    [anon_sym_public] = ACTIONS(4042),
    [anon_sym_readonly] = ACTIONS(4042),
    [anon_sym_required] = ACTIONS(4042),
    [anon_sym_sealed] = ACTIONS(4042),
    [anon_sym_virtual] = ACTIONS(4042),
    [anon_sym_volatile] = ACTIONS(4042),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_scoped] = ACTIONS(29),
    [anon_sym_var] = ACTIONS(29),
    [sym_predefined_type] = ACTIONS(4042),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_from] = ACTIONS(29),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3859] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7108),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9821),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3859),
    [sym_preproc_endregion] = STATE(3859),
    [sym_preproc_line] = STATE(3859),
    [sym_preproc_pragma] = STATE(3859),
    [sym_preproc_nullable] = STATE(3859),
    [sym_preproc_error] = STATE(3859),
    [sym_preproc_warning] = STATE(3859),
    [sym_preproc_define] = STATE(3859),
    [sym_preproc_undef] = STATE(3859),
    [aux_sym_class_declaration_repeat1] = STATE(6149),
    [aux_sym_lambda_expression_repeat1] = STATE(4289),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(5307),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3860] = {
    [sym_type_argument_list] = STATE(3925),
    [sym_preproc_region] = STATE(3860),
    [sym_preproc_endregion] = STATE(3860),
    [sym_preproc_line] = STATE(3860),
    [sym_preproc_pragma] = STATE(3860),
    [sym_preproc_nullable] = STATE(3860),
    [sym_preproc_error] = STATE(3860),
    [sym_preproc_warning] = STATE(3860),
    [sym_preproc_define] = STATE(3860),
    [sym_preproc_undef] = STATE(3860),
    [anon_sym_EQ] = ACTIONS(4138),
    [anon_sym_LBRACK] = ACTIONS(4140),
    [anon_sym_COLON] = ACTIONS(4140),
    [anon_sym_COMMA] = ACTIONS(4140),
    [anon_sym_LPAREN] = ACTIONS(4140),
    [anon_sym_LT] = ACTIONS(5794),
    [anon_sym_GT] = ACTIONS(4138),
    [anon_sym_QMARK] = ACTIONS(4138),
    [anon_sym_BANG] = ACTIONS(4138),
    [anon_sym_PLUS_PLUS] = ACTIONS(4140),
    [anon_sym_DASH_DASH] = ACTIONS(4140),
    [anon_sym_PLUS] = ACTIONS(4138),
    [anon_sym_DASH] = ACTIONS(4138),
    [anon_sym_STAR] = ACTIONS(4138),
    [anon_sym_SLASH] = ACTIONS(4138),
    [anon_sym_PERCENT] = ACTIONS(4138),
    [anon_sym_CARET] = ACTIONS(4138),
    [anon_sym_PIPE] = ACTIONS(4138),
    [anon_sym_AMP] = ACTIONS(4138),
    [anon_sym_LT_LT] = ACTIONS(4138),
    [anon_sym_GT_GT] = ACTIONS(4138),
    [anon_sym_GT_GT_GT] = ACTIONS(4138),
    [anon_sym_EQ_EQ] = ACTIONS(4140),
    [anon_sym_BANG_EQ] = ACTIONS(4140),
    [anon_sym_GT_EQ] = ACTIONS(4140),
    [anon_sym_LT_EQ] = ACTIONS(4140),
    [anon_sym_DOT] = ACTIONS(4138),
    [anon_sym_switch] = ACTIONS(4140),
    [anon_sym_DOT_DOT] = ACTIONS(4140),
    [anon_sym_and] = ACTIONS(4140),
    [anon_sym_or] = ACTIONS(4140),
    [anon_sym_PLUS_EQ] = ACTIONS(4140),
    [anon_sym_DASH_EQ] = ACTIONS(4140),
    [anon_sym_STAR_EQ] = ACTIONS(4140),
    [anon_sym_SLASH_EQ] = ACTIONS(4140),
    [anon_sym_PERCENT_EQ] = ACTIONS(4140),
    [anon_sym_AMP_EQ] = ACTIONS(4140),
    [anon_sym_CARET_EQ] = ACTIONS(4140),
    [anon_sym_PIPE_EQ] = ACTIONS(4140),
    [anon_sym_LT_LT_EQ] = ACTIONS(4140),
    [anon_sym_GT_GT_EQ] = ACTIONS(4140),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4140),
    [anon_sym_AMP_AMP] = ACTIONS(4140),
    [anon_sym_PIPE_PIPE] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK] = ACTIONS(4138),
    [anon_sym_into] = ACTIONS(4140),
    [anon_sym_as] = ACTIONS(4140),
    [anon_sym_is] = ACTIONS(4140),
    [anon_sym_DASH_GT] = ACTIONS(4140),
    [anon_sym_with] = ACTIONS(4140),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4140),
  },
  [3861] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7103),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9498),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3861),
    [sym_preproc_endregion] = STATE(3861),
    [sym_preproc_line] = STATE(3861),
    [sym_preproc_pragma] = STATE(3861),
    [sym_preproc_nullable] = STATE(3861),
    [sym_preproc_error] = STATE(3861),
    [sym_preproc_warning] = STATE(3861),
    [sym_preproc_define] = STATE(3861),
    [sym_preproc_undef] = STATE(3861),
    [aux_sym_class_declaration_repeat1] = STATE(6149),
    [aux_sym_lambda_expression_repeat1] = STATE(4171),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(5307),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3862] = {
    [sym_preproc_region] = STATE(3862),
    [sym_preproc_endregion] = STATE(3862),
    [sym_preproc_line] = STATE(3862),
    [sym_preproc_pragma] = STATE(3862),
    [sym_preproc_nullable] = STATE(3862),
    [sym_preproc_error] = STATE(3862),
    [sym_preproc_warning] = STATE(3862),
    [sym_preproc_define] = STATE(3862),
    [sym_preproc_undef] = STATE(3862),
    [anon_sym_EQ] = ACTIONS(4162),
    [anon_sym_LBRACK] = ACTIONS(4177),
    [anon_sym_COLON] = ACTIONS(4177),
    [anon_sym_COMMA] = ACTIONS(4806),
    [anon_sym_RBRACK] = ACTIONS(4806),
    [anon_sym_LPAREN] = ACTIONS(4177),
    [anon_sym_RPAREN] = ACTIONS(4806),
    [anon_sym_RBRACE] = ACTIONS(4806),
    [anon_sym_LT] = ACTIONS(4162),
    [anon_sym_GT] = ACTIONS(4162),
    [anon_sym_QMARK] = ACTIONS(4162),
    [anon_sym_BANG] = ACTIONS(4162),
    [anon_sym_PLUS_PLUS] = ACTIONS(4177),
    [anon_sym_DASH_DASH] = ACTIONS(4177),
    [anon_sym_PLUS] = ACTIONS(4162),
    [anon_sym_DASH] = ACTIONS(4162),
    [anon_sym_STAR] = ACTIONS(4162),
    [anon_sym_SLASH] = ACTIONS(4162),
    [anon_sym_PERCENT] = ACTIONS(4162),
    [anon_sym_CARET] = ACTIONS(4162),
    [anon_sym_PIPE] = ACTIONS(4162),
    [anon_sym_AMP] = ACTIONS(4162),
    [anon_sym_LT_LT] = ACTIONS(4162),
    [anon_sym_GT_GT] = ACTIONS(4162),
    [anon_sym_GT_GT_GT] = ACTIONS(4162),
    [anon_sym_EQ_EQ] = ACTIONS(4177),
    [anon_sym_BANG_EQ] = ACTIONS(4177),
    [anon_sym_GT_EQ] = ACTIONS(4177),
    [anon_sym_LT_EQ] = ACTIONS(4177),
    [anon_sym_DOT] = ACTIONS(4162),
    [anon_sym_switch] = ACTIONS(4177),
    [anon_sym_DOT_DOT] = ACTIONS(4177),
    [anon_sym_and] = ACTIONS(4806),
    [anon_sym_or] = ACTIONS(4806),
    [anon_sym_PLUS_EQ] = ACTIONS(4177),
    [anon_sym_DASH_EQ] = ACTIONS(4177),
    [anon_sym_STAR_EQ] = ACTIONS(4177),
    [anon_sym_SLASH_EQ] = ACTIONS(4177),
    [anon_sym_PERCENT_EQ] = ACTIONS(4177),
    [anon_sym_AMP_EQ] = ACTIONS(4177),
    [anon_sym_CARET_EQ] = ACTIONS(4177),
    [anon_sym_PIPE_EQ] = ACTIONS(4177),
    [anon_sym_LT_LT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4177),
    [anon_sym_AMP_AMP] = ACTIONS(4177),
    [anon_sym_PIPE_PIPE] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK] = ACTIONS(4162),
    [anon_sym_as] = ACTIONS(4177),
    [anon_sym_is] = ACTIONS(4177),
    [anon_sym_DASH_GT] = ACTIONS(4177),
    [anon_sym_with] = ACTIONS(4177),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3863] = {
    [sym_initializer_expression] = STATE(4037),
    [sym_preproc_region] = STATE(3863),
    [sym_preproc_endregion] = STATE(3863),
    [sym_preproc_line] = STATE(3863),
    [sym_preproc_pragma] = STATE(3863),
    [sym_preproc_nullable] = STATE(3863),
    [sym_preproc_error] = STATE(3863),
    [sym_preproc_warning] = STATE(3863),
    [sym_preproc_define] = STATE(3863),
    [sym_preproc_undef] = STATE(3863),
    [anon_sym_SEMI] = ACTIONS(5315),
    [anon_sym_LBRACK] = ACTIONS(5315),
    [anon_sym_COLON] = ACTIONS(5315),
    [anon_sym_COMMA] = ACTIONS(5315),
    [anon_sym_RBRACK] = ACTIONS(5315),
    [anon_sym_LPAREN] = ACTIONS(5315),
    [anon_sym_RPAREN] = ACTIONS(5315),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_RBRACE] = ACTIONS(5315),
    [anon_sym_LT] = ACTIONS(5317),
    [anon_sym_GT] = ACTIONS(5317),
    [anon_sym_in] = ACTIONS(5317),
    [anon_sym_QMARK] = ACTIONS(5317),
    [anon_sym_BANG] = ACTIONS(5317),
    [anon_sym_PLUS_PLUS] = ACTIONS(5315),
    [anon_sym_DASH_DASH] = ACTIONS(5315),
    [anon_sym_PLUS] = ACTIONS(5317),
    [anon_sym_DASH] = ACTIONS(5317),
    [anon_sym_STAR] = ACTIONS(5315),
    [anon_sym_SLASH] = ACTIONS(5317),
    [anon_sym_PERCENT] = ACTIONS(5315),
    [anon_sym_CARET] = ACTIONS(5315),
    [anon_sym_PIPE] = ACTIONS(5317),
    [anon_sym_AMP] = ACTIONS(5317),
    [anon_sym_LT_LT] = ACTIONS(5315),
    [anon_sym_GT_GT] = ACTIONS(5317),
    [anon_sym_GT_GT_GT] = ACTIONS(5315),
    [anon_sym_EQ_EQ] = ACTIONS(5315),
    [anon_sym_BANG_EQ] = ACTIONS(5315),
    [anon_sym_GT_EQ] = ACTIONS(5315),
    [anon_sym_LT_EQ] = ACTIONS(5315),
    [anon_sym_DOT] = ACTIONS(5317),
    [anon_sym_EQ_GT] = ACTIONS(5315),
    [anon_sym_switch] = ACTIONS(5315),
    [anon_sym_when] = ACTIONS(5315),
    [anon_sym_DOT_DOT] = ACTIONS(5315),
    [anon_sym_and] = ACTIONS(5315),
    [anon_sym_or] = ACTIONS(5315),
    [anon_sym_AMP_AMP] = ACTIONS(5315),
    [anon_sym_PIPE_PIPE] = ACTIONS(5315),
    [anon_sym_QMARK_QMARK] = ACTIONS(5315),
    [anon_sym_into] = ACTIONS(5315),
    [anon_sym_on] = ACTIONS(5315),
    [anon_sym_equals] = ACTIONS(5315),
    [anon_sym_by] = ACTIONS(5315),
    [anon_sym_as] = ACTIONS(5315),
    [anon_sym_is] = ACTIONS(5315),
    [anon_sym_DASH_GT] = ACTIONS(5315),
    [anon_sym_with] = ACTIONS(5315),
    [aux_sym_preproc_if_token3] = ACTIONS(5315),
    [aux_sym_preproc_else_token1] = ACTIONS(5315),
    [aux_sym_preproc_elif_token1] = ACTIONS(5315),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3864] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7122),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9628),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3864),
    [sym_preproc_endregion] = STATE(3864),
    [sym_preproc_line] = STATE(3864),
    [sym_preproc_pragma] = STATE(3864),
    [sym_preproc_nullable] = STATE(3864),
    [sym_preproc_error] = STATE(3864),
    [sym_preproc_warning] = STATE(3864),
    [sym_preproc_define] = STATE(3864),
    [sym_preproc_undef] = STATE(3864),
    [aux_sym_class_declaration_repeat1] = STATE(6149),
    [aux_sym_lambda_expression_repeat1] = STATE(4298),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(5307),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3865] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7116),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9876),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3865),
    [sym_preproc_endregion] = STATE(3865),
    [sym_preproc_line] = STATE(3865),
    [sym_preproc_pragma] = STATE(3865),
    [sym_preproc_nullable] = STATE(3865),
    [sym_preproc_error] = STATE(3865),
    [sym_preproc_warning] = STATE(3865),
    [sym_preproc_define] = STATE(3865),
    [sym_preproc_undef] = STATE(3865),
    [aux_sym_class_declaration_repeat1] = STATE(6149),
    [aux_sym_lambda_expression_repeat1] = STATE(4288),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(5307),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3866] = {
    [sym_initializer_expression] = STATE(4063),
    [sym_preproc_region] = STATE(3866),
    [sym_preproc_endregion] = STATE(3866),
    [sym_preproc_line] = STATE(3866),
    [sym_preproc_pragma] = STATE(3866),
    [sym_preproc_nullable] = STATE(3866),
    [sym_preproc_error] = STATE(3866),
    [sym_preproc_warning] = STATE(3866),
    [sym_preproc_define] = STATE(3866),
    [sym_preproc_undef] = STATE(3866),
    [anon_sym_SEMI] = ACTIONS(5340),
    [anon_sym_LBRACK] = ACTIONS(5336),
    [anon_sym_COLON] = ACTIONS(5340),
    [anon_sym_COMMA] = ACTIONS(5340),
    [anon_sym_RBRACK] = ACTIONS(5340),
    [anon_sym_LPAREN] = ACTIONS(5340),
    [anon_sym_RPAREN] = ACTIONS(5340),
    [anon_sym_LBRACE] = ACTIONS(5797),
    [anon_sym_RBRACE] = ACTIONS(5340),
    [anon_sym_LT] = ACTIONS(5346),
    [anon_sym_GT] = ACTIONS(5346),
    [anon_sym_in] = ACTIONS(5346),
    [anon_sym_QMARK] = ACTIONS(5800),
    [anon_sym_BANG] = ACTIONS(5346),
    [anon_sym_PLUS_PLUS] = ACTIONS(5340),
    [anon_sym_DASH_DASH] = ACTIONS(5340),
    [anon_sym_PLUS] = ACTIONS(5346),
    [anon_sym_DASH] = ACTIONS(5346),
    [anon_sym_STAR] = ACTIONS(5340),
    [anon_sym_SLASH] = ACTIONS(5346),
    [anon_sym_PERCENT] = ACTIONS(5340),
    [anon_sym_CARET] = ACTIONS(5340),
    [anon_sym_PIPE] = ACTIONS(5346),
    [anon_sym_AMP] = ACTIONS(5346),
    [anon_sym_LT_LT] = ACTIONS(5340),
    [anon_sym_GT_GT] = ACTIONS(5346),
    [anon_sym_GT_GT_GT] = ACTIONS(5340),
    [anon_sym_EQ_EQ] = ACTIONS(5340),
    [anon_sym_BANG_EQ] = ACTIONS(5340),
    [anon_sym_GT_EQ] = ACTIONS(5340),
    [anon_sym_LT_EQ] = ACTIONS(5340),
    [anon_sym_DOT] = ACTIONS(5346),
    [anon_sym_EQ_GT] = ACTIONS(5340),
    [anon_sym_switch] = ACTIONS(5340),
    [anon_sym_when] = ACTIONS(5340),
    [anon_sym_DOT_DOT] = ACTIONS(5340),
    [anon_sym_and] = ACTIONS(5340),
    [anon_sym_or] = ACTIONS(5340),
    [anon_sym_AMP_AMP] = ACTIONS(5340),
    [anon_sym_PIPE_PIPE] = ACTIONS(5340),
    [anon_sym_QMARK_QMARK] = ACTIONS(5340),
    [anon_sym_into] = ACTIONS(5340),
    [anon_sym_on] = ACTIONS(5340),
    [anon_sym_equals] = ACTIONS(5340),
    [anon_sym_by] = ACTIONS(5340),
    [anon_sym_as] = ACTIONS(5340),
    [anon_sym_is] = ACTIONS(5340),
    [anon_sym_DASH_GT] = ACTIONS(5340),
    [anon_sym_with] = ACTIONS(5340),
    [aux_sym_preproc_if_token3] = ACTIONS(5340),
    [aux_sym_preproc_else_token1] = ACTIONS(5340),
    [aux_sym_preproc_elif_token1] = ACTIONS(5340),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3867] = {
    [sym_argument_list] = STATE(4044),
    [sym_bracketed_argument_list] = STATE(3189),
    [sym_preproc_region] = STATE(3867),
    [sym_preproc_endregion] = STATE(3867),
    [sym_preproc_line] = STATE(3867),
    [sym_preproc_pragma] = STATE(3867),
    [sym_preproc_nullable] = STATE(3867),
    [sym_preproc_error] = STATE(3867),
    [sym_preproc_warning] = STATE(3867),
    [sym_preproc_define] = STATE(3867),
    [sym_preproc_undef] = STATE(3867),
    [anon_sym_SEMI] = ACTIONS(5325),
    [anon_sym_LBRACK] = ACTIONS(5778),
    [anon_sym_COLON] = ACTIONS(5325),
    [anon_sym_COMMA] = ACTIONS(5325),
    [anon_sym_RBRACK] = ACTIONS(5325),
    [anon_sym_LPAREN] = ACTIONS(5759),
    [anon_sym_RPAREN] = ACTIONS(5325),
    [anon_sym_RBRACE] = ACTIONS(5325),
    [anon_sym_LT] = ACTIONS(5327),
    [anon_sym_GT] = ACTIONS(5327),
    [anon_sym_in] = ACTIONS(5327),
    [anon_sym_QMARK] = ACTIONS(5327),
    [anon_sym_BANG] = ACTIONS(5780),
    [anon_sym_PLUS_PLUS] = ACTIONS(5782),
    [anon_sym_DASH_DASH] = ACTIONS(5782),
    [anon_sym_PLUS] = ACTIONS(5327),
    [anon_sym_DASH] = ACTIONS(5327),
    [anon_sym_STAR] = ACTIONS(5325),
    [anon_sym_SLASH] = ACTIONS(5327),
    [anon_sym_PERCENT] = ACTIONS(5325),
    [anon_sym_CARET] = ACTIONS(5325),
    [anon_sym_PIPE] = ACTIONS(5327),
    [anon_sym_AMP] = ACTIONS(5327),
    [anon_sym_LT_LT] = ACTIONS(5325),
    [anon_sym_GT_GT] = ACTIONS(5327),
    [anon_sym_GT_GT_GT] = ACTIONS(5325),
    [anon_sym_EQ_EQ] = ACTIONS(5325),
    [anon_sym_BANG_EQ] = ACTIONS(5325),
    [anon_sym_GT_EQ] = ACTIONS(5325),
    [anon_sym_LT_EQ] = ACTIONS(5325),
    [anon_sym_DOT] = ACTIONS(4634),
    [anon_sym_EQ_GT] = ACTIONS(5325),
    [anon_sym_switch] = ACTIONS(5325),
    [anon_sym_when] = ACTIONS(5325),
    [anon_sym_DOT_DOT] = ACTIONS(5325),
    [anon_sym_and] = ACTIONS(5325),
    [anon_sym_or] = ACTIONS(5325),
    [anon_sym_AMP_AMP] = ACTIONS(5325),
    [anon_sym_PIPE_PIPE] = ACTIONS(5325),
    [anon_sym_QMARK_QMARK] = ACTIONS(5325),
    [anon_sym_into] = ACTIONS(5325),
    [anon_sym_on] = ACTIONS(5325),
    [anon_sym_equals] = ACTIONS(5325),
    [anon_sym_by] = ACTIONS(5325),
    [anon_sym_as] = ACTIONS(5325),
    [anon_sym_is] = ACTIONS(5325),
    [anon_sym_DASH_GT] = ACTIONS(4636),
    [anon_sym_with] = ACTIONS(5325),
    [aux_sym_preproc_if_token3] = ACTIONS(5325),
    [aux_sym_preproc_else_token1] = ACTIONS(5325),
    [aux_sym_preproc_elif_token1] = ACTIONS(5325),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3868] = {
    [sym_preproc_region] = STATE(3868),
    [sym_preproc_endregion] = STATE(3868),
    [sym_preproc_line] = STATE(3868),
    [sym_preproc_pragma] = STATE(3868),
    [sym_preproc_nullable] = STATE(3868),
    [sym_preproc_error] = STATE(3868),
    [sym_preproc_warning] = STATE(3868),
    [sym_preproc_define] = STATE(3868),
    [sym_preproc_undef] = STATE(3868),
    [anon_sym_EQ] = ACTIONS(5804),
    [anon_sym_LBRACK] = ACTIONS(5286),
    [anon_sym_COLON] = ACTIONS(5286),
    [anon_sym_COMMA] = ACTIONS(5286),
    [anon_sym_LPAREN] = ACTIONS(5286),
    [anon_sym_RPAREN] = ACTIONS(5286),
    [anon_sym_RBRACE] = ACTIONS(5286),
    [anon_sym_LT] = ACTIONS(5288),
    [anon_sym_GT] = ACTIONS(5288),
    [anon_sym_QMARK] = ACTIONS(5288),
    [anon_sym_BANG] = ACTIONS(5288),
    [anon_sym_PLUS_PLUS] = ACTIONS(5286),
    [anon_sym_DASH_DASH] = ACTIONS(5286),
    [anon_sym_PLUS] = ACTIONS(5288),
    [anon_sym_DASH] = ACTIONS(5288),
    [anon_sym_STAR] = ACTIONS(5288),
    [anon_sym_SLASH] = ACTIONS(5288),
    [anon_sym_PERCENT] = ACTIONS(5288),
    [anon_sym_CARET] = ACTIONS(5288),
    [anon_sym_PIPE] = ACTIONS(5288),
    [anon_sym_AMP] = ACTIONS(5288),
    [anon_sym_LT_LT] = ACTIONS(5288),
    [anon_sym_GT_GT] = ACTIONS(5288),
    [anon_sym_GT_GT_GT] = ACTIONS(5288),
    [anon_sym_EQ_EQ] = ACTIONS(5286),
    [anon_sym_BANG_EQ] = ACTIONS(5286),
    [anon_sym_GT_EQ] = ACTIONS(5286),
    [anon_sym_LT_EQ] = ACTIONS(5286),
    [anon_sym_DOT] = ACTIONS(5288),
    [anon_sym_switch] = ACTIONS(5286),
    [anon_sym_DOT_DOT] = ACTIONS(5286),
    [anon_sym_and] = ACTIONS(5286),
    [anon_sym_or] = ACTIONS(5286),
    [anon_sym_PLUS_EQ] = ACTIONS(5806),
    [anon_sym_DASH_EQ] = ACTIONS(5806),
    [anon_sym_STAR_EQ] = ACTIONS(5806),
    [anon_sym_SLASH_EQ] = ACTIONS(5806),
    [anon_sym_PERCENT_EQ] = ACTIONS(5806),
    [anon_sym_AMP_EQ] = ACTIONS(5806),
    [anon_sym_CARET_EQ] = ACTIONS(5806),
    [anon_sym_PIPE_EQ] = ACTIONS(5806),
    [anon_sym_LT_LT_EQ] = ACTIONS(5806),
    [anon_sym_GT_GT_EQ] = ACTIONS(5806),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(5806),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(5806),
    [anon_sym_AMP_AMP] = ACTIONS(5286),
    [anon_sym_PIPE_PIPE] = ACTIONS(5286),
    [anon_sym_QMARK_QMARK] = ACTIONS(5288),
    [anon_sym_into] = ACTIONS(5286),
    [anon_sym_as] = ACTIONS(5286),
    [anon_sym_is] = ACTIONS(5286),
    [anon_sym_DASH_GT] = ACTIONS(5286),
    [anon_sym_with] = ACTIONS(5286),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3869] = {
    [sym_preproc_region] = STATE(3869),
    [sym_preproc_endregion] = STATE(3869),
    [sym_preproc_line] = STATE(3869),
    [sym_preproc_pragma] = STATE(3869),
    [sym_preproc_nullable] = STATE(3869),
    [sym_preproc_error] = STATE(3869),
    [sym_preproc_warning] = STATE(3869),
    [sym_preproc_define] = STATE(3869),
    [sym_preproc_undef] = STATE(3869),
    [anon_sym_SEMI] = ACTIONS(3993),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_COLON] = ACTIONS(3995),
    [anon_sym_COMMA] = ACTIONS(3993),
    [anon_sym_RBRACK] = ACTIONS(3993),
    [anon_sym_LPAREN] = ACTIONS(3993),
    [anon_sym_RPAREN] = ACTIONS(3993),
    [anon_sym_LBRACE] = ACTIONS(3993),
    [anon_sym_RBRACE] = ACTIONS(3993),
    [anon_sym_LT] = ACTIONS(3995),
    [anon_sym_GT] = ACTIONS(3995),
    [anon_sym_in] = ACTIONS(3995),
    [anon_sym_QMARK] = ACTIONS(3995),
    [anon_sym_BANG] = ACTIONS(3995),
    [anon_sym_PLUS_PLUS] = ACTIONS(3993),
    [anon_sym_DASH_DASH] = ACTIONS(3993),
    [anon_sym_PLUS] = ACTIONS(3995),
    [anon_sym_DASH] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3993),
    [anon_sym_SLASH] = ACTIONS(3995),
    [anon_sym_PERCENT] = ACTIONS(3993),
    [anon_sym_CARET] = ACTIONS(3993),
    [anon_sym_PIPE] = ACTIONS(3995),
    [anon_sym_AMP] = ACTIONS(3995),
    [anon_sym_LT_LT] = ACTIONS(3993),
    [anon_sym_GT_GT] = ACTIONS(3995),
    [anon_sym_GT_GT_GT] = ACTIONS(3993),
    [anon_sym_EQ_EQ] = ACTIONS(3993),
    [anon_sym_BANG_EQ] = ACTIONS(3993),
    [anon_sym_GT_EQ] = ACTIONS(3993),
    [anon_sym_LT_EQ] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3995),
    [anon_sym_EQ_GT] = ACTIONS(3993),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_switch] = ACTIONS(3993),
    [anon_sym_when] = ACTIONS(3993),
    [anon_sym_DOT_DOT] = ACTIONS(3993),
    [anon_sym_and] = ACTIONS(3993),
    [anon_sym_or] = ACTIONS(3993),
    [anon_sym_AMP_AMP] = ACTIONS(3993),
    [anon_sym_PIPE_PIPE] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK] = ACTIONS(3993),
    [anon_sym_into] = ACTIONS(3993),
    [anon_sym_on] = ACTIONS(3993),
    [anon_sym_equals] = ACTIONS(3993),
    [anon_sym_by] = ACTIONS(3993),
    [anon_sym_as] = ACTIONS(3993),
    [anon_sym_is] = ACTIONS(3993),
    [anon_sym_DASH_GT] = ACTIONS(3993),
    [anon_sym_with] = ACTIONS(3993),
    [aux_sym_preproc_if_token3] = ACTIONS(3993),
    [aux_sym_preproc_else_token1] = ACTIONS(3993),
    [aux_sym_preproc_elif_token1] = ACTIONS(3993),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3870] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7133),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9546),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3870),
    [sym_preproc_endregion] = STATE(3870),
    [sym_preproc_line] = STATE(3870),
    [sym_preproc_pragma] = STATE(3870),
    [sym_preproc_nullable] = STATE(3870),
    [sym_preproc_error] = STATE(3870),
    [sym_preproc_warning] = STATE(3870),
    [sym_preproc_define] = STATE(3870),
    [sym_preproc_undef] = STATE(3870),
    [aux_sym_class_declaration_repeat1] = STATE(6149),
    [aux_sym_lambda_expression_repeat1] = STATE(4305),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(5307),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3871] = {
    [sym_preproc_region] = STATE(3871),
    [sym_preproc_endregion] = STATE(3871),
    [sym_preproc_line] = STATE(3871),
    [sym_preproc_pragma] = STATE(3871),
    [sym_preproc_nullable] = STATE(3871),
    [sym_preproc_error] = STATE(3871),
    [sym_preproc_warning] = STATE(3871),
    [sym_preproc_define] = STATE(3871),
    [sym_preproc_undef] = STATE(3871),
    [anon_sym_SEMI] = ACTIONS(4124),
    [anon_sym_LBRACK] = ACTIONS(4124),
    [anon_sym_COLON] = ACTIONS(4122),
    [anon_sym_COMMA] = ACTIONS(4124),
    [anon_sym_RBRACK] = ACTIONS(4124),
    [anon_sym_LPAREN] = ACTIONS(4124),
    [anon_sym_RPAREN] = ACTIONS(4124),
    [anon_sym_LBRACE] = ACTIONS(4124),
    [anon_sym_RBRACE] = ACTIONS(4124),
    [anon_sym_LT] = ACTIONS(4122),
    [anon_sym_GT] = ACTIONS(4122),
    [anon_sym_in] = ACTIONS(4122),
    [anon_sym_QMARK] = ACTIONS(4122),
    [anon_sym_BANG] = ACTIONS(4122),
    [anon_sym_PLUS_PLUS] = ACTIONS(4124),
    [anon_sym_DASH_DASH] = ACTIONS(4124),
    [anon_sym_PLUS] = ACTIONS(4122),
    [anon_sym_DASH] = ACTIONS(4122),
    [anon_sym_STAR] = ACTIONS(4124),
    [anon_sym_SLASH] = ACTIONS(4122),
    [anon_sym_PERCENT] = ACTIONS(4124),
    [anon_sym_CARET] = ACTIONS(4124),
    [anon_sym_PIPE] = ACTIONS(4122),
    [anon_sym_AMP] = ACTIONS(4122),
    [anon_sym_LT_LT] = ACTIONS(4124),
    [anon_sym_GT_GT] = ACTIONS(4122),
    [anon_sym_GT_GT_GT] = ACTIONS(4124),
    [anon_sym_EQ_EQ] = ACTIONS(4124),
    [anon_sym_BANG_EQ] = ACTIONS(4124),
    [anon_sym_GT_EQ] = ACTIONS(4124),
    [anon_sym_LT_EQ] = ACTIONS(4124),
    [anon_sym_DOT] = ACTIONS(4122),
    [anon_sym_EQ_GT] = ACTIONS(4124),
    [anon_sym_COLON_COLON] = ACTIONS(4124),
    [anon_sym_switch] = ACTIONS(4124),
    [anon_sym_when] = ACTIONS(4124),
    [anon_sym_DOT_DOT] = ACTIONS(4124),
    [anon_sym_and] = ACTIONS(4124),
    [anon_sym_or] = ACTIONS(4124),
    [anon_sym_AMP_AMP] = ACTIONS(4124),
    [anon_sym_PIPE_PIPE] = ACTIONS(4124),
    [anon_sym_QMARK_QMARK] = ACTIONS(4124),
    [anon_sym_into] = ACTIONS(4124),
    [anon_sym_on] = ACTIONS(4124),
    [anon_sym_equals] = ACTIONS(4124),
    [anon_sym_by] = ACTIONS(4124),
    [anon_sym_as] = ACTIONS(4124),
    [anon_sym_is] = ACTIONS(4124),
    [anon_sym_DASH_GT] = ACTIONS(4124),
    [anon_sym_with] = ACTIONS(4124),
    [aux_sym_preproc_if_token3] = ACTIONS(4124),
    [aux_sym_preproc_else_token1] = ACTIONS(4124),
    [aux_sym_preproc_elif_token1] = ACTIONS(4124),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3872] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7141),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9841),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3872),
    [sym_preproc_endregion] = STATE(3872),
    [sym_preproc_line] = STATE(3872),
    [sym_preproc_pragma] = STATE(3872),
    [sym_preproc_nullable] = STATE(3872),
    [sym_preproc_error] = STATE(3872),
    [sym_preproc_warning] = STATE(3872),
    [sym_preproc_define] = STATE(3872),
    [sym_preproc_undef] = STATE(3872),
    [aux_sym_class_declaration_repeat1] = STATE(6149),
    [aux_sym_lambda_expression_repeat1] = STATE(4307),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(5307),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3873] = {
    [sym_preproc_region] = STATE(3873),
    [sym_preproc_endregion] = STATE(3873),
    [sym_preproc_line] = STATE(3873),
    [sym_preproc_pragma] = STATE(3873),
    [sym_preproc_nullable] = STATE(3873),
    [sym_preproc_error] = STATE(3873),
    [sym_preproc_warning] = STATE(3873),
    [sym_preproc_define] = STATE(3873),
    [sym_preproc_undef] = STATE(3873),
    [anon_sym_SEMI] = ACTIONS(4088),
    [anon_sym_LBRACK] = ACTIONS(4088),
    [anon_sym_COLON] = ACTIONS(4091),
    [anon_sym_COMMA] = ACTIONS(4088),
    [anon_sym_RBRACK] = ACTIONS(4088),
    [anon_sym_LPAREN] = ACTIONS(4088),
    [anon_sym_RPAREN] = ACTIONS(4088),
    [anon_sym_LBRACE] = ACTIONS(4088),
    [anon_sym_RBRACE] = ACTIONS(4088),
    [anon_sym_LT] = ACTIONS(4091),
    [anon_sym_GT] = ACTIONS(4091),
    [anon_sym_in] = ACTIONS(4091),
    [anon_sym_QMARK] = ACTIONS(4091),
    [anon_sym_BANG] = ACTIONS(4091),
    [anon_sym_PLUS_PLUS] = ACTIONS(4088),
    [anon_sym_DASH_DASH] = ACTIONS(4088),
    [anon_sym_PLUS] = ACTIONS(4091),
    [anon_sym_DASH] = ACTIONS(4091),
    [anon_sym_STAR] = ACTIONS(4088),
    [anon_sym_SLASH] = ACTIONS(4091),
    [anon_sym_PERCENT] = ACTIONS(4088),
    [anon_sym_CARET] = ACTIONS(4088),
    [anon_sym_PIPE] = ACTIONS(4091),
    [anon_sym_AMP] = ACTIONS(4091),
    [anon_sym_LT_LT] = ACTIONS(4088),
    [anon_sym_GT_GT] = ACTIONS(4091),
    [anon_sym_GT_GT_GT] = ACTIONS(4088),
    [anon_sym_EQ_EQ] = ACTIONS(4088),
    [anon_sym_BANG_EQ] = ACTIONS(4088),
    [anon_sym_GT_EQ] = ACTIONS(4088),
    [anon_sym_LT_EQ] = ACTIONS(4088),
    [anon_sym_DOT] = ACTIONS(4091),
    [anon_sym_EQ_GT] = ACTIONS(4088),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_switch] = ACTIONS(4088),
    [anon_sym_when] = ACTIONS(4088),
    [anon_sym_DOT_DOT] = ACTIONS(4088),
    [anon_sym_and] = ACTIONS(4088),
    [anon_sym_or] = ACTIONS(4088),
    [anon_sym_AMP_AMP] = ACTIONS(4088),
    [anon_sym_PIPE_PIPE] = ACTIONS(4088),
    [anon_sym_QMARK_QMARK] = ACTIONS(4088),
    [anon_sym_into] = ACTIONS(4088),
    [anon_sym_on] = ACTIONS(4088),
    [anon_sym_equals] = ACTIONS(4088),
    [anon_sym_by] = ACTIONS(4088),
    [anon_sym_as] = ACTIONS(4088),
    [anon_sym_is] = ACTIONS(4088),
    [anon_sym_DASH_GT] = ACTIONS(4088),
    [anon_sym_with] = ACTIONS(4088),
    [aux_sym_preproc_if_token3] = ACTIONS(4088),
    [aux_sym_preproc_else_token1] = ACTIONS(4088),
    [aux_sym_preproc_elif_token1] = ACTIONS(4088),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3874] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7149),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9077),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3874),
    [sym_preproc_endregion] = STATE(3874),
    [sym_preproc_line] = STATE(3874),
    [sym_preproc_pragma] = STATE(3874),
    [sym_preproc_nullable] = STATE(3874),
    [sym_preproc_error] = STATE(3874),
    [sym_preproc_warning] = STATE(3874),
    [sym_preproc_define] = STATE(3874),
    [sym_preproc_undef] = STATE(3874),
    [aux_sym_class_declaration_repeat1] = STATE(6149),
    [aux_sym_lambda_expression_repeat1] = STATE(4314),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(5307),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3875] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7153),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9121),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3875),
    [sym_preproc_endregion] = STATE(3875),
    [sym_preproc_line] = STATE(3875),
    [sym_preproc_pragma] = STATE(3875),
    [sym_preproc_nullable] = STATE(3875),
    [sym_preproc_error] = STATE(3875),
    [sym_preproc_warning] = STATE(3875),
    [sym_preproc_define] = STATE(3875),
    [sym_preproc_undef] = STATE(3875),
    [aux_sym_class_declaration_repeat1] = STATE(6149),
    [aux_sym_lambda_expression_repeat1] = STATE(4316),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(5307),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3876] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7157),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9157),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3876),
    [sym_preproc_endregion] = STATE(3876),
    [sym_preproc_line] = STATE(3876),
    [sym_preproc_pragma] = STATE(3876),
    [sym_preproc_nullable] = STATE(3876),
    [sym_preproc_error] = STATE(3876),
    [sym_preproc_warning] = STATE(3876),
    [sym_preproc_define] = STATE(3876),
    [sym_preproc_undef] = STATE(3876),
    [aux_sym_class_declaration_repeat1] = STATE(6149),
    [aux_sym_lambda_expression_repeat1] = STATE(4319),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(5307),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3877] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7161),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9185),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3877),
    [sym_preproc_endregion] = STATE(3877),
    [sym_preproc_line] = STATE(3877),
    [sym_preproc_pragma] = STATE(3877),
    [sym_preproc_nullable] = STATE(3877),
    [sym_preproc_error] = STATE(3877),
    [sym_preproc_warning] = STATE(3877),
    [sym_preproc_define] = STATE(3877),
    [sym_preproc_undef] = STATE(3877),
    [aux_sym_class_declaration_repeat1] = STATE(6149),
    [aux_sym_lambda_expression_repeat1] = STATE(4321),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(5307),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3878] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7072),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9914),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3878),
    [sym_preproc_endregion] = STATE(3878),
    [sym_preproc_line] = STATE(3878),
    [sym_preproc_pragma] = STATE(3878),
    [sym_preproc_nullable] = STATE(3878),
    [sym_preproc_error] = STATE(3878),
    [sym_preproc_warning] = STATE(3878),
    [sym_preproc_define] = STATE(3878),
    [sym_preproc_undef] = STATE(3878),
    [aux_sym_class_declaration_repeat1] = STATE(6149),
    [aux_sym_lambda_expression_repeat1] = STATE(4093),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(5307),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3879] = {
    [sym_attribute_list] = STATE(6699),
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7083),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9364),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(3879),
    [sym_preproc_endregion] = STATE(3879),
    [sym_preproc_line] = STATE(3879),
    [sym_preproc_pragma] = STATE(3879),
    [sym_preproc_nullable] = STATE(3879),
    [sym_preproc_error] = STATE(3879),
    [sym_preproc_warning] = STATE(3879),
    [sym_preproc_define] = STATE(3879),
    [sym_preproc_undef] = STATE(3879),
    [aux_sym_class_declaration_repeat1] = STATE(6149),
    [aux_sym_lambda_expression_repeat1] = STATE(4277),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LBRACK] = ACTIONS(5307),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3880] = {
    [sym_preproc_region] = STATE(3880),
    [sym_preproc_endregion] = STATE(3880),
    [sym_preproc_line] = STATE(3880),
    [sym_preproc_pragma] = STATE(3880),
    [sym_preproc_nullable] = STATE(3880),
    [sym_preproc_error] = STATE(3880),
    [sym_preproc_warning] = STATE(3880),
    [sym_preproc_define] = STATE(3880),
    [sym_preproc_undef] = STATE(3880),
    [anon_sym_SEMI] = ACTIONS(4494),
    [anon_sym_LBRACK] = ACTIONS(4593),
    [anon_sym_COLON] = ACTIONS(4494),
    [anon_sym_COMMA] = ACTIONS(4494),
    [anon_sym_RBRACK] = ACTIONS(4494),
    [anon_sym_LPAREN] = ACTIONS(4494),
    [anon_sym_RPAREN] = ACTIONS(4494),
    [anon_sym_LBRACE] = ACTIONS(4494),
    [anon_sym_RBRACE] = ACTIONS(4494),
    [anon_sym_LT] = ACTIONS(4492),
    [anon_sym_GT] = ACTIONS(4492),
    [anon_sym_in] = ACTIONS(4492),
    [anon_sym_QMARK] = ACTIONS(5808),
    [anon_sym_BANG] = ACTIONS(4492),
    [anon_sym_PLUS_PLUS] = ACTIONS(4494),
    [anon_sym_DASH_DASH] = ACTIONS(4494),
    [anon_sym_PLUS] = ACTIONS(4492),
    [anon_sym_DASH] = ACTIONS(4492),
    [anon_sym_STAR] = ACTIONS(4599),
    [anon_sym_SLASH] = ACTIONS(4492),
    [anon_sym_PERCENT] = ACTIONS(4494),
    [anon_sym_CARET] = ACTIONS(4494),
    [anon_sym_PIPE] = ACTIONS(4492),
    [anon_sym_AMP] = ACTIONS(4492),
    [anon_sym_LT_LT] = ACTIONS(4494),
    [anon_sym_GT_GT] = ACTIONS(4492),
    [anon_sym_GT_GT_GT] = ACTIONS(4494),
    [anon_sym_EQ_EQ] = ACTIONS(4494),
    [anon_sym_BANG_EQ] = ACTIONS(4494),
    [anon_sym_GT_EQ] = ACTIONS(4494),
    [anon_sym_LT_EQ] = ACTIONS(4494),
    [anon_sym_DOT] = ACTIONS(4492),
    [anon_sym_EQ_GT] = ACTIONS(4494),
    [anon_sym_switch] = ACTIONS(4494),
    [anon_sym_when] = ACTIONS(4494),
    [anon_sym_DOT_DOT] = ACTIONS(4494),
    [anon_sym_and] = ACTIONS(4494),
    [anon_sym_or] = ACTIONS(4494),
    [anon_sym_AMP_AMP] = ACTIONS(4494),
    [anon_sym_PIPE_PIPE] = ACTIONS(4494),
    [anon_sym_QMARK_QMARK] = ACTIONS(4494),
    [anon_sym_into] = ACTIONS(4494),
    [anon_sym_on] = ACTIONS(4494),
    [anon_sym_equals] = ACTIONS(4494),
    [anon_sym_by] = ACTIONS(4494),
    [anon_sym_as] = ACTIONS(4494),
    [anon_sym_is] = ACTIONS(4494),
    [anon_sym_DASH_GT] = ACTIONS(4494),
    [anon_sym_with] = ACTIONS(4494),
    [aux_sym_preproc_if_token3] = ACTIONS(4494),
    [aux_sym_preproc_else_token1] = ACTIONS(4494),
    [aux_sym_preproc_elif_token1] = ACTIONS(4494),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3881] = {
    [sym_preproc_region] = STATE(3881),
    [sym_preproc_endregion] = STATE(3881),
    [sym_preproc_line] = STATE(3881),
    [sym_preproc_pragma] = STATE(3881),
    [sym_preproc_nullable] = STATE(3881),
    [sym_preproc_error] = STATE(3881),
    [sym_preproc_warning] = STATE(3881),
    [sym_preproc_define] = STATE(3881),
    [sym_preproc_undef] = STATE(3881),
    [anon_sym_SEMI] = ACTIONS(4546),
    [anon_sym_LBRACK] = ACTIONS(4546),
    [anon_sym_COLON] = ACTIONS(4546),
    [anon_sym_COMMA] = ACTIONS(4546),
    [anon_sym_RBRACK] = ACTIONS(4546),
    [anon_sym_LPAREN] = ACTIONS(4546),
    [anon_sym_RPAREN] = ACTIONS(4546),
    [anon_sym_LBRACE] = ACTIONS(4546),
    [anon_sym_RBRACE] = ACTIONS(4546),
    [anon_sym_LT] = ACTIONS(4544),
    [anon_sym_GT] = ACTIONS(4544),
    [anon_sym_in] = ACTIONS(4544),
    [anon_sym_QMARK] = ACTIONS(4544),
    [anon_sym_BANG] = ACTIONS(4544),
    [anon_sym_PLUS_PLUS] = ACTIONS(4546),
    [anon_sym_DASH_DASH] = ACTIONS(4546),
    [anon_sym_PLUS] = ACTIONS(4544),
    [anon_sym_DASH] = ACTIONS(4544),
    [anon_sym_STAR] = ACTIONS(4546),
    [anon_sym_SLASH] = ACTIONS(4544),
    [anon_sym_PERCENT] = ACTIONS(4546),
    [anon_sym_CARET] = ACTIONS(4546),
    [anon_sym_PIPE] = ACTIONS(4544),
    [anon_sym_AMP] = ACTIONS(4544),
    [anon_sym_LT_LT] = ACTIONS(4546),
    [anon_sym_GT_GT] = ACTIONS(4544),
    [anon_sym_GT_GT_GT] = ACTIONS(4546),
    [anon_sym_EQ_EQ] = ACTIONS(4546),
    [anon_sym_BANG_EQ] = ACTIONS(4546),
    [anon_sym_GT_EQ] = ACTIONS(4546),
    [anon_sym_LT_EQ] = ACTIONS(4546),
    [anon_sym_DOT] = ACTIONS(4544),
    [anon_sym_EQ_GT] = ACTIONS(4546),
    [anon_sym_switch] = ACTIONS(4546),
    [anon_sym_when] = ACTIONS(4546),
    [anon_sym_DOT_DOT] = ACTIONS(4546),
    [anon_sym_and] = ACTIONS(4546),
    [anon_sym_or] = ACTIONS(4546),
    [anon_sym_AMP_AMP] = ACTIONS(4546),
    [anon_sym_PIPE_PIPE] = ACTIONS(4546),
    [anon_sym_QMARK_QMARK] = ACTIONS(4546),
    [anon_sym_into] = ACTIONS(4546),
    [anon_sym_on] = ACTIONS(4546),
    [anon_sym_equals] = ACTIONS(4546),
    [anon_sym_by] = ACTIONS(4546),
    [anon_sym_as] = ACTIONS(4546),
    [anon_sym_is] = ACTIONS(4546),
    [anon_sym_DASH_GT] = ACTIONS(4546),
    [anon_sym_with] = ACTIONS(4546),
    [aux_sym_preproc_if_token3] = ACTIONS(4546),
    [aux_sym_preproc_else_token1] = ACTIONS(4546),
    [aux_sym_preproc_elif_token1] = ACTIONS(4546),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3882] = {
    [sym_preproc_region] = STATE(3882),
    [sym_preproc_endregion] = STATE(3882),
    [sym_preproc_line] = STATE(3882),
    [sym_preproc_pragma] = STATE(3882),
    [sym_preproc_nullable] = STATE(3882),
    [sym_preproc_error] = STATE(3882),
    [sym_preproc_warning] = STATE(3882),
    [sym_preproc_define] = STATE(3882),
    [sym_preproc_undef] = STATE(3882),
    [anon_sym_EQ] = ACTIONS(4713),
    [anon_sym_LBRACK] = ACTIONS(4711),
    [anon_sym_COLON] = ACTIONS(4711),
    [anon_sym_COMMA] = ACTIONS(4711),
    [anon_sym_LPAREN] = ACTIONS(4711),
    [anon_sym_LT] = ACTIONS(4713),
    [anon_sym_GT] = ACTIONS(4713),
    [anon_sym_QMARK] = ACTIONS(4713),
    [anon_sym_BANG] = ACTIONS(4713),
    [anon_sym_PLUS_PLUS] = ACTIONS(4711),
    [anon_sym_DASH_DASH] = ACTIONS(4711),
    [anon_sym_PLUS] = ACTIONS(4713),
    [anon_sym_DASH] = ACTIONS(4713),
    [anon_sym_STAR] = ACTIONS(4713),
    [anon_sym_SLASH] = ACTIONS(4713),
    [anon_sym_PERCENT] = ACTIONS(4713),
    [anon_sym_CARET] = ACTIONS(4713),
    [anon_sym_PIPE] = ACTIONS(4713),
    [anon_sym_AMP] = ACTIONS(4713),
    [anon_sym_LT_LT] = ACTIONS(4713),
    [anon_sym_GT_GT] = ACTIONS(4713),
    [anon_sym_GT_GT_GT] = ACTIONS(4713),
    [anon_sym_EQ_EQ] = ACTIONS(4711),
    [anon_sym_BANG_EQ] = ACTIONS(4711),
    [anon_sym_GT_EQ] = ACTIONS(4711),
    [anon_sym_LT_EQ] = ACTIONS(4711),
    [anon_sym_DOT] = ACTIONS(4713),
    [anon_sym_switch] = ACTIONS(4711),
    [anon_sym_DOT_DOT] = ACTIONS(4711),
    [anon_sym_and] = ACTIONS(4711),
    [anon_sym_or] = ACTIONS(4711),
    [anon_sym_PLUS_EQ] = ACTIONS(4711),
    [anon_sym_DASH_EQ] = ACTIONS(4711),
    [anon_sym_STAR_EQ] = ACTIONS(4711),
    [anon_sym_SLASH_EQ] = ACTIONS(4711),
    [anon_sym_PERCENT_EQ] = ACTIONS(4711),
    [anon_sym_AMP_EQ] = ACTIONS(4711),
    [anon_sym_CARET_EQ] = ACTIONS(4711),
    [anon_sym_PIPE_EQ] = ACTIONS(4711),
    [anon_sym_LT_LT_EQ] = ACTIONS(4711),
    [anon_sym_GT_GT_EQ] = ACTIONS(4711),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4711),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4711),
    [anon_sym_AMP_AMP] = ACTIONS(4711),
    [anon_sym_PIPE_PIPE] = ACTIONS(4711),
    [anon_sym_QMARK_QMARK] = ACTIONS(4713),
    [anon_sym_into] = ACTIONS(4711),
    [anon_sym_as] = ACTIONS(4711),
    [anon_sym_is] = ACTIONS(4711),
    [anon_sym_DASH_GT] = ACTIONS(4711),
    [anon_sym_with] = ACTIONS(4711),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4711),
  },
  [3883] = {
    [sym_preproc_region] = STATE(3883),
    [sym_preproc_endregion] = STATE(3883),
    [sym_preproc_line] = STATE(3883),
    [sym_preproc_pragma] = STATE(3883),
    [sym_preproc_nullable] = STATE(3883),
    [sym_preproc_error] = STATE(3883),
    [sym_preproc_warning] = STATE(3883),
    [sym_preproc_define] = STATE(3883),
    [sym_preproc_undef] = STATE(3883),
    [anon_sym_SEMI] = ACTIONS(5382),
    [anon_sym_LBRACK] = ACTIONS(5382),
    [anon_sym_COLON] = ACTIONS(5382),
    [anon_sym_COMMA] = ACTIONS(5382),
    [anon_sym_RBRACK] = ACTIONS(5382),
    [anon_sym_LPAREN] = ACTIONS(5382),
    [anon_sym_RPAREN] = ACTIONS(5382),
    [anon_sym_RBRACE] = ACTIONS(5382),
    [anon_sym_LT] = ACTIONS(5384),
    [anon_sym_GT] = ACTIONS(5384),
    [anon_sym_in] = ACTIONS(5384),
    [anon_sym_QMARK] = ACTIONS(5384),
    [anon_sym_BANG] = ACTIONS(5384),
    [anon_sym_PLUS_PLUS] = ACTIONS(5382),
    [anon_sym_DASH_DASH] = ACTIONS(5382),
    [anon_sym_PLUS] = ACTIONS(5384),
    [anon_sym_DASH] = ACTIONS(5384),
    [anon_sym_STAR] = ACTIONS(5382),
    [anon_sym_SLASH] = ACTIONS(5384),
    [anon_sym_PERCENT] = ACTIONS(5382),
    [anon_sym_CARET] = ACTIONS(5382),
    [anon_sym_PIPE] = ACTIONS(5384),
    [anon_sym_AMP] = ACTIONS(5384),
    [anon_sym_LT_LT] = ACTIONS(5382),
    [anon_sym_GT_GT] = ACTIONS(5384),
    [anon_sym_GT_GT_GT] = ACTIONS(5382),
    [anon_sym_EQ_EQ] = ACTIONS(5382),
    [anon_sym_BANG_EQ] = ACTIONS(5382),
    [anon_sym_GT_EQ] = ACTIONS(5382),
    [anon_sym_LT_EQ] = ACTIONS(5382),
    [anon_sym_DOT] = ACTIONS(5384),
    [anon_sym_EQ_GT] = ACTIONS(5382),
    [anon_sym_switch] = ACTIONS(5382),
    [anon_sym_when] = ACTIONS(5382),
    [anon_sym_DOT_DOT] = ACTIONS(5382),
    [anon_sym_and] = ACTIONS(5382),
    [anon_sym_or] = ACTIONS(5382),
    [anon_sym_AMP_AMP] = ACTIONS(5382),
    [anon_sym_PIPE_PIPE] = ACTIONS(5382),
    [anon_sym_QMARK_QMARK] = ACTIONS(5382),
    [anon_sym_into] = ACTIONS(5382),
    [anon_sym_on] = ACTIONS(5382),
    [anon_sym_equals] = ACTIONS(5382),
    [anon_sym_by] = ACTIONS(5382),
    [anon_sym_as] = ACTIONS(5382),
    [anon_sym_is] = ACTIONS(5382),
    [anon_sym_DASH_GT] = ACTIONS(5382),
    [anon_sym_with] = ACTIONS(5382),
    [sym_string_literal_encoding] = ACTIONS(5811),
    [aux_sym_preproc_if_token3] = ACTIONS(5382),
    [aux_sym_preproc_else_token1] = ACTIONS(5382),
    [aux_sym_preproc_elif_token1] = ACTIONS(5382),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3884] = {
    [sym_preproc_region] = STATE(3884),
    [sym_preproc_endregion] = STATE(3884),
    [sym_preproc_line] = STATE(3884),
    [sym_preproc_pragma] = STATE(3884),
    [sym_preproc_nullable] = STATE(3884),
    [sym_preproc_error] = STATE(3884),
    [sym_preproc_warning] = STATE(3884),
    [sym_preproc_define] = STATE(3884),
    [sym_preproc_undef] = STATE(3884),
    [anon_sym_EQ] = ACTIONS(4642),
    [anon_sym_LBRACK] = ACTIONS(4640),
    [anon_sym_COLON] = ACTIONS(4640),
    [anon_sym_COMMA] = ACTIONS(4640),
    [anon_sym_LPAREN] = ACTIONS(4640),
    [anon_sym_LT] = ACTIONS(4642),
    [anon_sym_GT] = ACTIONS(4642),
    [anon_sym_QMARK] = ACTIONS(4642),
    [anon_sym_BANG] = ACTIONS(4642),
    [anon_sym_PLUS_PLUS] = ACTIONS(4640),
    [anon_sym_DASH_DASH] = ACTIONS(4640),
    [anon_sym_PLUS] = ACTIONS(4642),
    [anon_sym_DASH] = ACTIONS(4642),
    [anon_sym_STAR] = ACTIONS(4642),
    [anon_sym_SLASH] = ACTIONS(4642),
    [anon_sym_PERCENT] = ACTIONS(4642),
    [anon_sym_CARET] = ACTIONS(4642),
    [anon_sym_PIPE] = ACTIONS(4642),
    [anon_sym_AMP] = ACTIONS(4642),
    [anon_sym_LT_LT] = ACTIONS(4642),
    [anon_sym_GT_GT] = ACTIONS(4642),
    [anon_sym_GT_GT_GT] = ACTIONS(4642),
    [anon_sym_EQ_EQ] = ACTIONS(4640),
    [anon_sym_BANG_EQ] = ACTIONS(4640),
    [anon_sym_GT_EQ] = ACTIONS(4640),
    [anon_sym_LT_EQ] = ACTIONS(4640),
    [anon_sym_DOT] = ACTIONS(4642),
    [anon_sym_switch] = ACTIONS(4640),
    [anon_sym_DOT_DOT] = ACTIONS(4640),
    [anon_sym_and] = ACTIONS(4640),
    [anon_sym_or] = ACTIONS(4640),
    [anon_sym_PLUS_EQ] = ACTIONS(4640),
    [anon_sym_DASH_EQ] = ACTIONS(4640),
    [anon_sym_STAR_EQ] = ACTIONS(4640),
    [anon_sym_SLASH_EQ] = ACTIONS(4640),
    [anon_sym_PERCENT_EQ] = ACTIONS(4640),
    [anon_sym_AMP_EQ] = ACTIONS(4640),
    [anon_sym_CARET_EQ] = ACTIONS(4640),
    [anon_sym_PIPE_EQ] = ACTIONS(4640),
    [anon_sym_LT_LT_EQ] = ACTIONS(4640),
    [anon_sym_GT_GT_EQ] = ACTIONS(4640),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4640),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4640),
    [anon_sym_AMP_AMP] = ACTIONS(4640),
    [anon_sym_PIPE_PIPE] = ACTIONS(4640),
    [anon_sym_QMARK_QMARK] = ACTIONS(4642),
    [anon_sym_into] = ACTIONS(4640),
    [anon_sym_as] = ACTIONS(4640),
    [anon_sym_is] = ACTIONS(4640),
    [anon_sym_DASH_GT] = ACTIONS(4640),
    [anon_sym_with] = ACTIONS(4640),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4640),
  },
  [3885] = {
    [sym_preproc_region] = STATE(3885),
    [sym_preproc_endregion] = STATE(3885),
    [sym_preproc_line] = STATE(3885),
    [sym_preproc_pragma] = STATE(3885),
    [sym_preproc_nullable] = STATE(3885),
    [sym_preproc_error] = STATE(3885),
    [sym_preproc_warning] = STATE(3885),
    [sym_preproc_define] = STATE(3885),
    [sym_preproc_undef] = STATE(3885),
    [anon_sym_SEMI] = ACTIONS(4494),
    [anon_sym_LBRACK] = ACTIONS(4593),
    [anon_sym_COLON] = ACTIONS(4494),
    [anon_sym_COMMA] = ACTIONS(4494),
    [anon_sym_RBRACK] = ACTIONS(4494),
    [anon_sym_LPAREN] = ACTIONS(4494),
    [anon_sym_RPAREN] = ACTIONS(4494),
    [anon_sym_LBRACE] = ACTIONS(4494),
    [anon_sym_RBRACE] = ACTIONS(4494),
    [anon_sym_LT] = ACTIONS(4492),
    [anon_sym_GT] = ACTIONS(4492),
    [anon_sym_in] = ACTIONS(4492),
    [anon_sym_QMARK] = ACTIONS(4492),
    [anon_sym_BANG] = ACTIONS(4492),
    [anon_sym_PLUS_PLUS] = ACTIONS(4494),
    [anon_sym_DASH_DASH] = ACTIONS(4494),
    [anon_sym_PLUS] = ACTIONS(4492),
    [anon_sym_DASH] = ACTIONS(4492),
    [anon_sym_STAR] = ACTIONS(4599),
    [anon_sym_SLASH] = ACTIONS(4492),
    [anon_sym_PERCENT] = ACTIONS(4494),
    [anon_sym_CARET] = ACTIONS(4494),
    [anon_sym_PIPE] = ACTIONS(4492),
    [anon_sym_AMP] = ACTIONS(4492),
    [anon_sym_LT_LT] = ACTIONS(4494),
    [anon_sym_GT_GT] = ACTIONS(4492),
    [anon_sym_GT_GT_GT] = ACTIONS(4494),
    [anon_sym_EQ_EQ] = ACTIONS(4494),
    [anon_sym_BANG_EQ] = ACTIONS(4494),
    [anon_sym_GT_EQ] = ACTIONS(4494),
    [anon_sym_LT_EQ] = ACTIONS(4494),
    [anon_sym_DOT] = ACTIONS(4492),
    [anon_sym_EQ_GT] = ACTIONS(4494),
    [anon_sym_switch] = ACTIONS(4494),
    [anon_sym_when] = ACTIONS(4494),
    [anon_sym_DOT_DOT] = ACTIONS(4494),
    [anon_sym_and] = ACTIONS(4494),
    [anon_sym_or] = ACTIONS(4494),
    [anon_sym_AMP_AMP] = ACTIONS(4494),
    [anon_sym_PIPE_PIPE] = ACTIONS(4494),
    [anon_sym_QMARK_QMARK] = ACTIONS(4494),
    [anon_sym_into] = ACTIONS(4494),
    [anon_sym_on] = ACTIONS(4494),
    [anon_sym_equals] = ACTIONS(4494),
    [anon_sym_by] = ACTIONS(4494),
    [anon_sym_as] = ACTIONS(4494),
    [anon_sym_is] = ACTIONS(4494),
    [anon_sym_DASH_GT] = ACTIONS(4494),
    [anon_sym_with] = ACTIONS(4494),
    [aux_sym_preproc_if_token3] = ACTIONS(4494),
    [aux_sym_preproc_else_token1] = ACTIONS(4494),
    [aux_sym_preproc_elif_token1] = ACTIONS(4494),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3886] = {
    [sym_preproc_region] = STATE(3886),
    [sym_preproc_endregion] = STATE(3886),
    [sym_preproc_line] = STATE(3886),
    [sym_preproc_pragma] = STATE(3886),
    [sym_preproc_nullable] = STATE(3886),
    [sym_preproc_error] = STATE(3886),
    [sym_preproc_warning] = STATE(3886),
    [sym_preproc_define] = STATE(3886),
    [sym_preproc_undef] = STATE(3886),
    [anon_sym_EQ] = ACTIONS(4126),
    [anon_sym_LBRACK] = ACTIONS(4128),
    [anon_sym_COLON] = ACTIONS(4128),
    [anon_sym_COMMA] = ACTIONS(4128),
    [anon_sym_LPAREN] = ACTIONS(4128),
    [anon_sym_LT] = ACTIONS(4126),
    [anon_sym_GT] = ACTIONS(4126),
    [anon_sym_QMARK] = ACTIONS(4126),
    [anon_sym_BANG] = ACTIONS(4126),
    [anon_sym_PLUS_PLUS] = ACTIONS(4128),
    [anon_sym_DASH_DASH] = ACTIONS(4128),
    [anon_sym_PLUS] = ACTIONS(4126),
    [anon_sym_DASH] = ACTIONS(4126),
    [anon_sym_STAR] = ACTIONS(4126),
    [anon_sym_SLASH] = ACTIONS(4126),
    [anon_sym_PERCENT] = ACTIONS(4126),
    [anon_sym_CARET] = ACTIONS(4126),
    [anon_sym_PIPE] = ACTIONS(4126),
    [anon_sym_AMP] = ACTIONS(4126),
    [anon_sym_LT_LT] = ACTIONS(4126),
    [anon_sym_GT_GT] = ACTIONS(4126),
    [anon_sym_GT_GT_GT] = ACTIONS(4126),
    [anon_sym_EQ_EQ] = ACTIONS(4128),
    [anon_sym_BANG_EQ] = ACTIONS(4128),
    [anon_sym_GT_EQ] = ACTIONS(4128),
    [anon_sym_LT_EQ] = ACTIONS(4128),
    [anon_sym_DOT] = ACTIONS(4126),
    [anon_sym_switch] = ACTIONS(4128),
    [anon_sym_DOT_DOT] = ACTIONS(4128),
    [anon_sym_and] = ACTIONS(4128),
    [anon_sym_or] = ACTIONS(4128),
    [anon_sym_PLUS_EQ] = ACTIONS(4128),
    [anon_sym_DASH_EQ] = ACTIONS(4128),
    [anon_sym_STAR_EQ] = ACTIONS(4128),
    [anon_sym_SLASH_EQ] = ACTIONS(4128),
    [anon_sym_PERCENT_EQ] = ACTIONS(4128),
    [anon_sym_AMP_EQ] = ACTIONS(4128),
    [anon_sym_CARET_EQ] = ACTIONS(4128),
    [anon_sym_PIPE_EQ] = ACTIONS(4128),
    [anon_sym_LT_LT_EQ] = ACTIONS(4128),
    [anon_sym_GT_GT_EQ] = ACTIONS(4128),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4128),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4128),
    [anon_sym_AMP_AMP] = ACTIONS(4128),
    [anon_sym_PIPE_PIPE] = ACTIONS(4128),
    [anon_sym_QMARK_QMARK] = ACTIONS(4126),
    [anon_sym_into] = ACTIONS(4128),
    [anon_sym_as] = ACTIONS(4128),
    [anon_sym_is] = ACTIONS(4128),
    [anon_sym_DASH_GT] = ACTIONS(4128),
    [anon_sym_with] = ACTIONS(4128),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4128),
  },
  [3887] = {
    [sym_preproc_region] = STATE(3887),
    [sym_preproc_endregion] = STATE(3887),
    [sym_preproc_line] = STATE(3887),
    [sym_preproc_pragma] = STATE(3887),
    [sym_preproc_nullable] = STATE(3887),
    [sym_preproc_error] = STATE(3887),
    [sym_preproc_warning] = STATE(3887),
    [sym_preproc_define] = STATE(3887),
    [sym_preproc_undef] = STATE(3887),
    [anon_sym_SEMI] = ACTIONS(4484),
    [anon_sym_LBRACK] = ACTIONS(4484),
    [anon_sym_COLON] = ACTIONS(4484),
    [anon_sym_COMMA] = ACTIONS(4484),
    [anon_sym_RBRACK] = ACTIONS(4484),
    [anon_sym_LPAREN] = ACTIONS(4484),
    [anon_sym_RPAREN] = ACTIONS(4484),
    [anon_sym_LBRACE] = ACTIONS(4484),
    [anon_sym_RBRACE] = ACTIONS(4484),
    [anon_sym_LT] = ACTIONS(4482),
    [anon_sym_GT] = ACTIONS(4482),
    [anon_sym_in] = ACTIONS(4482),
    [anon_sym_QMARK] = ACTIONS(4482),
    [anon_sym_BANG] = ACTIONS(4482),
    [anon_sym_PLUS_PLUS] = ACTIONS(4484),
    [anon_sym_DASH_DASH] = ACTIONS(4484),
    [anon_sym_PLUS] = ACTIONS(4482),
    [anon_sym_DASH] = ACTIONS(4482),
    [anon_sym_STAR] = ACTIONS(4484),
    [anon_sym_SLASH] = ACTIONS(4482),
    [anon_sym_PERCENT] = ACTIONS(4484),
    [anon_sym_CARET] = ACTIONS(4484),
    [anon_sym_PIPE] = ACTIONS(4482),
    [anon_sym_AMP] = ACTIONS(4482),
    [anon_sym_LT_LT] = ACTIONS(4484),
    [anon_sym_GT_GT] = ACTIONS(4482),
    [anon_sym_GT_GT_GT] = ACTIONS(4484),
    [anon_sym_EQ_EQ] = ACTIONS(4484),
    [anon_sym_BANG_EQ] = ACTIONS(4484),
    [anon_sym_GT_EQ] = ACTIONS(4484),
    [anon_sym_LT_EQ] = ACTIONS(4484),
    [anon_sym_DOT] = ACTIONS(4482),
    [anon_sym_EQ_GT] = ACTIONS(4484),
    [anon_sym_switch] = ACTIONS(4484),
    [anon_sym_when] = ACTIONS(4484),
    [anon_sym_DOT_DOT] = ACTIONS(4484),
    [anon_sym_and] = ACTIONS(4484),
    [anon_sym_or] = ACTIONS(4484),
    [anon_sym_AMP_AMP] = ACTIONS(4484),
    [anon_sym_PIPE_PIPE] = ACTIONS(4484),
    [anon_sym_QMARK_QMARK] = ACTIONS(4484),
    [anon_sym_into] = ACTIONS(4484),
    [anon_sym_on] = ACTIONS(4484),
    [anon_sym_equals] = ACTIONS(4484),
    [anon_sym_by] = ACTIONS(4484),
    [anon_sym_as] = ACTIONS(4484),
    [anon_sym_is] = ACTIONS(4484),
    [anon_sym_DASH_GT] = ACTIONS(4484),
    [anon_sym_with] = ACTIONS(4484),
    [aux_sym_preproc_if_token3] = ACTIONS(4484),
    [aux_sym_preproc_else_token1] = ACTIONS(4484),
    [aux_sym_preproc_elif_token1] = ACTIONS(4484),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3888] = {
    [sym_preproc_region] = STATE(3888),
    [sym_preproc_endregion] = STATE(3888),
    [sym_preproc_line] = STATE(3888),
    [sym_preproc_pragma] = STATE(3888),
    [sym_preproc_nullable] = STATE(3888),
    [sym_preproc_error] = STATE(3888),
    [sym_preproc_warning] = STATE(3888),
    [sym_preproc_define] = STATE(3888),
    [sym_preproc_undef] = STATE(3888),
    [anon_sym_EQ] = ACTIONS(4668),
    [anon_sym_LBRACK] = ACTIONS(4666),
    [anon_sym_COLON] = ACTIONS(4666),
    [anon_sym_COMMA] = ACTIONS(4666),
    [anon_sym_LPAREN] = ACTIONS(4666),
    [anon_sym_LT] = ACTIONS(4668),
    [anon_sym_GT] = ACTIONS(4668),
    [anon_sym_QMARK] = ACTIONS(4668),
    [anon_sym_BANG] = ACTIONS(4668),
    [anon_sym_PLUS_PLUS] = ACTIONS(4666),
    [anon_sym_DASH_DASH] = ACTIONS(4666),
    [anon_sym_PLUS] = ACTIONS(4668),
    [anon_sym_DASH] = ACTIONS(4668),
    [anon_sym_STAR] = ACTIONS(4668),
    [anon_sym_SLASH] = ACTIONS(4668),
    [anon_sym_PERCENT] = ACTIONS(4668),
    [anon_sym_CARET] = ACTIONS(4668),
    [anon_sym_PIPE] = ACTIONS(4668),
    [anon_sym_AMP] = ACTIONS(4668),
    [anon_sym_LT_LT] = ACTIONS(4668),
    [anon_sym_GT_GT] = ACTIONS(4668),
    [anon_sym_GT_GT_GT] = ACTIONS(4668),
    [anon_sym_EQ_EQ] = ACTIONS(4666),
    [anon_sym_BANG_EQ] = ACTIONS(4666),
    [anon_sym_GT_EQ] = ACTIONS(4666),
    [anon_sym_LT_EQ] = ACTIONS(4666),
    [anon_sym_DOT] = ACTIONS(4668),
    [anon_sym_switch] = ACTIONS(4666),
    [anon_sym_DOT_DOT] = ACTIONS(4666),
    [anon_sym_and] = ACTIONS(4666),
    [anon_sym_or] = ACTIONS(4666),
    [anon_sym_PLUS_EQ] = ACTIONS(4666),
    [anon_sym_DASH_EQ] = ACTIONS(4666),
    [anon_sym_STAR_EQ] = ACTIONS(4666),
    [anon_sym_SLASH_EQ] = ACTIONS(4666),
    [anon_sym_PERCENT_EQ] = ACTIONS(4666),
    [anon_sym_AMP_EQ] = ACTIONS(4666),
    [anon_sym_CARET_EQ] = ACTIONS(4666),
    [anon_sym_PIPE_EQ] = ACTIONS(4666),
    [anon_sym_LT_LT_EQ] = ACTIONS(4666),
    [anon_sym_GT_GT_EQ] = ACTIONS(4666),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4666),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4666),
    [anon_sym_AMP_AMP] = ACTIONS(4666),
    [anon_sym_PIPE_PIPE] = ACTIONS(4666),
    [anon_sym_QMARK_QMARK] = ACTIONS(4668),
    [anon_sym_into] = ACTIONS(4666),
    [anon_sym_as] = ACTIONS(4666),
    [anon_sym_is] = ACTIONS(4666),
    [anon_sym_DASH_GT] = ACTIONS(4666),
    [anon_sym_with] = ACTIONS(4666),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4666),
  },
  [3889] = {
    [sym_type_argument_list] = STATE(3964),
    [sym_preproc_region] = STATE(3889),
    [sym_preproc_endregion] = STATE(3889),
    [sym_preproc_line] = STATE(3889),
    [sym_preproc_pragma] = STATE(3889),
    [sym_preproc_nullable] = STATE(3889),
    [sym_preproc_error] = STATE(3889),
    [sym_preproc_warning] = STATE(3889),
    [sym_preproc_define] = STATE(3889),
    [sym_preproc_undef] = STATE(3889),
    [anon_sym_SEMI] = ACTIONS(4140),
    [anon_sym_LBRACK] = ACTIONS(4140),
    [anon_sym_COLON] = ACTIONS(4138),
    [anon_sym_COMMA] = ACTIONS(4140),
    [anon_sym_RBRACK] = ACTIONS(4140),
    [anon_sym_LPAREN] = ACTIONS(4140),
    [anon_sym_RPAREN] = ACTIONS(4140),
    [anon_sym_LBRACE] = ACTIONS(4140),
    [anon_sym_RBRACE] = ACTIONS(4140),
    [anon_sym_LT] = ACTIONS(5813),
    [anon_sym_GT] = ACTIONS(4138),
    [anon_sym_QMARK] = ACTIONS(4138),
    [anon_sym_BANG] = ACTIONS(4138),
    [anon_sym_PLUS_PLUS] = ACTIONS(4140),
    [anon_sym_DASH_DASH] = ACTIONS(4140),
    [anon_sym_PLUS] = ACTIONS(4138),
    [anon_sym_DASH] = ACTIONS(4138),
    [anon_sym_STAR] = ACTIONS(4140),
    [anon_sym_SLASH] = ACTIONS(4138),
    [anon_sym_PERCENT] = ACTIONS(4140),
    [anon_sym_CARET] = ACTIONS(4140),
    [anon_sym_PIPE] = ACTIONS(4138),
    [anon_sym_AMP] = ACTIONS(4138),
    [anon_sym_LT_LT] = ACTIONS(4140),
    [anon_sym_GT_GT] = ACTIONS(4138),
    [anon_sym_GT_GT_GT] = ACTIONS(4140),
    [anon_sym_EQ_EQ] = ACTIONS(4140),
    [anon_sym_BANG_EQ] = ACTIONS(4140),
    [anon_sym_GT_EQ] = ACTIONS(4140),
    [anon_sym_LT_EQ] = ACTIONS(4140),
    [anon_sym_DOT] = ACTIONS(4138),
    [anon_sym_EQ_GT] = ACTIONS(4140),
    [anon_sym_COLON_COLON] = ACTIONS(5816),
    [anon_sym_switch] = ACTIONS(4140),
    [anon_sym_when] = ACTIONS(4140),
    [anon_sym_DOT_DOT] = ACTIONS(4140),
    [anon_sym_and] = ACTIONS(4140),
    [anon_sym_or] = ACTIONS(4140),
    [anon_sym_AMP_AMP] = ACTIONS(4140),
    [anon_sym_PIPE_PIPE] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK] = ACTIONS(4140),
    [anon_sym_on] = ACTIONS(4140),
    [anon_sym_equals] = ACTIONS(4140),
    [anon_sym_by] = ACTIONS(4140),
    [anon_sym_as] = ACTIONS(4140),
    [anon_sym_is] = ACTIONS(4140),
    [anon_sym_DASH_GT] = ACTIONS(4140),
    [anon_sym_with] = ACTIONS(4140),
    [aux_sym_preproc_if_token3] = ACTIONS(4140),
    [aux_sym_preproc_else_token1] = ACTIONS(4140),
    [aux_sym_preproc_elif_token1] = ACTIONS(4140),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3890] = {
    [sym_preproc_region] = STATE(3890),
    [sym_preproc_endregion] = STATE(3890),
    [sym_preproc_line] = STATE(3890),
    [sym_preproc_pragma] = STATE(3890),
    [sym_preproc_nullable] = STATE(3890),
    [sym_preproc_error] = STATE(3890),
    [sym_preproc_warning] = STATE(3890),
    [sym_preproc_define] = STATE(3890),
    [sym_preproc_undef] = STATE(3890),
    [anon_sym_SEMI] = ACTIONS(4585),
    [anon_sym_LBRACK] = ACTIONS(4585),
    [anon_sym_COLON] = ACTIONS(4585),
    [anon_sym_COMMA] = ACTIONS(4585),
    [anon_sym_RBRACK] = ACTIONS(4585),
    [anon_sym_LPAREN] = ACTIONS(4585),
    [anon_sym_RPAREN] = ACTIONS(4585),
    [anon_sym_LBRACE] = ACTIONS(4585),
    [anon_sym_RBRACE] = ACTIONS(4585),
    [anon_sym_LT] = ACTIONS(4583),
    [anon_sym_GT] = ACTIONS(4583),
    [anon_sym_in] = ACTIONS(4583),
    [anon_sym_QMARK] = ACTIONS(4583),
    [anon_sym_BANG] = ACTIONS(4583),
    [anon_sym_PLUS_PLUS] = ACTIONS(4585),
    [anon_sym_DASH_DASH] = ACTIONS(4585),
    [anon_sym_PLUS] = ACTIONS(4583),
    [anon_sym_DASH] = ACTIONS(4583),
    [anon_sym_STAR] = ACTIONS(4585),
    [anon_sym_SLASH] = ACTIONS(4583),
    [anon_sym_PERCENT] = ACTIONS(4585),
    [anon_sym_CARET] = ACTIONS(4585),
    [anon_sym_PIPE] = ACTIONS(4583),
    [anon_sym_AMP] = ACTIONS(4583),
    [anon_sym_LT_LT] = ACTIONS(4585),
    [anon_sym_GT_GT] = ACTIONS(4583),
    [anon_sym_GT_GT_GT] = ACTIONS(4585),
    [anon_sym_EQ_EQ] = ACTIONS(4585),
    [anon_sym_BANG_EQ] = ACTIONS(4585),
    [anon_sym_GT_EQ] = ACTIONS(4585),
    [anon_sym_LT_EQ] = ACTIONS(4585),
    [anon_sym_DOT] = ACTIONS(4583),
    [anon_sym_EQ_GT] = ACTIONS(4585),
    [anon_sym_switch] = ACTIONS(4585),
    [anon_sym_when] = ACTIONS(4585),
    [anon_sym_DOT_DOT] = ACTIONS(4585),
    [anon_sym_and] = ACTIONS(4585),
    [anon_sym_or] = ACTIONS(4585),
    [anon_sym_AMP_AMP] = ACTIONS(4585),
    [anon_sym_PIPE_PIPE] = ACTIONS(4585),
    [anon_sym_QMARK_QMARK] = ACTIONS(4585),
    [anon_sym_into] = ACTIONS(4585),
    [anon_sym_on] = ACTIONS(4585),
    [anon_sym_equals] = ACTIONS(4585),
    [anon_sym_by] = ACTIONS(4585),
    [anon_sym_as] = ACTIONS(4585),
    [anon_sym_is] = ACTIONS(4585),
    [anon_sym_DASH_GT] = ACTIONS(4585),
    [anon_sym_with] = ACTIONS(4585),
    [aux_sym_preproc_if_token3] = ACTIONS(4585),
    [aux_sym_preproc_else_token1] = ACTIONS(4585),
    [aux_sym_preproc_elif_token1] = ACTIONS(4585),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3891] = {
    [sym_preproc_region] = STATE(3891),
    [sym_preproc_endregion] = STATE(3891),
    [sym_preproc_line] = STATE(3891),
    [sym_preproc_pragma] = STATE(3891),
    [sym_preproc_nullable] = STATE(3891),
    [sym_preproc_error] = STATE(3891),
    [sym_preproc_warning] = STATE(3891),
    [sym_preproc_define] = STATE(3891),
    [sym_preproc_undef] = STATE(3891),
    [anon_sym_EQ] = ACTIONS(4134),
    [anon_sym_LBRACK] = ACTIONS(4136),
    [anon_sym_COLON] = ACTIONS(4136),
    [anon_sym_COMMA] = ACTIONS(4136),
    [anon_sym_LPAREN] = ACTIONS(4136),
    [anon_sym_LT] = ACTIONS(4134),
    [anon_sym_GT] = ACTIONS(4134),
    [anon_sym_QMARK] = ACTIONS(4134),
    [anon_sym_BANG] = ACTIONS(4134),
    [anon_sym_PLUS_PLUS] = ACTIONS(4136),
    [anon_sym_DASH_DASH] = ACTIONS(4136),
    [anon_sym_PLUS] = ACTIONS(4134),
    [anon_sym_DASH] = ACTIONS(4134),
    [anon_sym_STAR] = ACTIONS(4134),
    [anon_sym_SLASH] = ACTIONS(4134),
    [anon_sym_PERCENT] = ACTIONS(4134),
    [anon_sym_CARET] = ACTIONS(4134),
    [anon_sym_PIPE] = ACTIONS(4134),
    [anon_sym_AMP] = ACTIONS(4134),
    [anon_sym_LT_LT] = ACTIONS(4134),
    [anon_sym_GT_GT] = ACTIONS(4134),
    [anon_sym_GT_GT_GT] = ACTIONS(4134),
    [anon_sym_EQ_EQ] = ACTIONS(4136),
    [anon_sym_BANG_EQ] = ACTIONS(4136),
    [anon_sym_GT_EQ] = ACTIONS(4136),
    [anon_sym_LT_EQ] = ACTIONS(4136),
    [anon_sym_DOT] = ACTIONS(4134),
    [anon_sym_switch] = ACTIONS(4136),
    [anon_sym_DOT_DOT] = ACTIONS(4136),
    [anon_sym_and] = ACTIONS(4136),
    [anon_sym_or] = ACTIONS(4136),
    [anon_sym_PLUS_EQ] = ACTIONS(4136),
    [anon_sym_DASH_EQ] = ACTIONS(4136),
    [anon_sym_STAR_EQ] = ACTIONS(4136),
    [anon_sym_SLASH_EQ] = ACTIONS(4136),
    [anon_sym_PERCENT_EQ] = ACTIONS(4136),
    [anon_sym_AMP_EQ] = ACTIONS(4136),
    [anon_sym_CARET_EQ] = ACTIONS(4136),
    [anon_sym_PIPE_EQ] = ACTIONS(4136),
    [anon_sym_LT_LT_EQ] = ACTIONS(4136),
    [anon_sym_GT_GT_EQ] = ACTIONS(4136),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4136),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4136),
    [anon_sym_AMP_AMP] = ACTIONS(4136),
    [anon_sym_PIPE_PIPE] = ACTIONS(4136),
    [anon_sym_QMARK_QMARK] = ACTIONS(4134),
    [anon_sym_into] = ACTIONS(4136),
    [anon_sym_as] = ACTIONS(4136),
    [anon_sym_is] = ACTIONS(4136),
    [anon_sym_DASH_GT] = ACTIONS(4136),
    [anon_sym_with] = ACTIONS(4136),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4136),
  },
  [3892] = {
    [sym_preproc_region] = STATE(3892),
    [sym_preproc_endregion] = STATE(3892),
    [sym_preproc_line] = STATE(3892),
    [sym_preproc_pragma] = STATE(3892),
    [sym_preproc_nullable] = STATE(3892),
    [sym_preproc_error] = STATE(3892),
    [sym_preproc_warning] = STATE(3892),
    [sym_preproc_define] = STATE(3892),
    [sym_preproc_undef] = STATE(3892),
    [anon_sym_SEMI] = ACTIONS(4500),
    [anon_sym_LBRACK] = ACTIONS(4500),
    [anon_sym_COLON] = ACTIONS(4500),
    [anon_sym_COMMA] = ACTIONS(4500),
    [anon_sym_RBRACK] = ACTIONS(4500),
    [anon_sym_LPAREN] = ACTIONS(4500),
    [anon_sym_RPAREN] = ACTIONS(4500),
    [anon_sym_LBRACE] = ACTIONS(4500),
    [anon_sym_RBRACE] = ACTIONS(4500),
    [anon_sym_LT] = ACTIONS(4498),
    [anon_sym_GT] = ACTIONS(4498),
    [anon_sym_in] = ACTIONS(4498),
    [anon_sym_QMARK] = ACTIONS(4498),
    [anon_sym_BANG] = ACTIONS(4498),
    [anon_sym_PLUS_PLUS] = ACTIONS(4500),
    [anon_sym_DASH_DASH] = ACTIONS(4500),
    [anon_sym_PLUS] = ACTIONS(4498),
    [anon_sym_DASH] = ACTIONS(4498),
    [anon_sym_STAR] = ACTIONS(4500),
    [anon_sym_SLASH] = ACTIONS(4498),
    [anon_sym_PERCENT] = ACTIONS(4500),
    [anon_sym_CARET] = ACTIONS(4500),
    [anon_sym_PIPE] = ACTIONS(4498),
    [anon_sym_AMP] = ACTIONS(4498),
    [anon_sym_LT_LT] = ACTIONS(4500),
    [anon_sym_GT_GT] = ACTIONS(4498),
    [anon_sym_GT_GT_GT] = ACTIONS(4500),
    [anon_sym_EQ_EQ] = ACTIONS(4500),
    [anon_sym_BANG_EQ] = ACTIONS(4500),
    [anon_sym_GT_EQ] = ACTIONS(4500),
    [anon_sym_LT_EQ] = ACTIONS(4500),
    [anon_sym_DOT] = ACTIONS(4498),
    [anon_sym_EQ_GT] = ACTIONS(4500),
    [anon_sym_switch] = ACTIONS(4500),
    [anon_sym_when] = ACTIONS(4500),
    [anon_sym_DOT_DOT] = ACTIONS(4500),
    [anon_sym_and] = ACTIONS(4500),
    [anon_sym_or] = ACTIONS(4500),
    [anon_sym_AMP_AMP] = ACTIONS(4500),
    [anon_sym_PIPE_PIPE] = ACTIONS(4500),
    [anon_sym_QMARK_QMARK] = ACTIONS(4500),
    [anon_sym_into] = ACTIONS(4500),
    [anon_sym_on] = ACTIONS(4500),
    [anon_sym_equals] = ACTIONS(4500),
    [anon_sym_by] = ACTIONS(4500),
    [anon_sym_as] = ACTIONS(4500),
    [anon_sym_is] = ACTIONS(4500),
    [anon_sym_DASH_GT] = ACTIONS(4500),
    [anon_sym_with] = ACTIONS(4500),
    [aux_sym_preproc_if_token3] = ACTIONS(4500),
    [aux_sym_preproc_else_token1] = ACTIONS(4500),
    [aux_sym_preproc_elif_token1] = ACTIONS(4500),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3893] = {
    [sym_preproc_region] = STATE(3893),
    [sym_preproc_endregion] = STATE(3893),
    [sym_preproc_line] = STATE(3893),
    [sym_preproc_pragma] = STATE(3893),
    [sym_preproc_nullable] = STATE(3893),
    [sym_preproc_error] = STATE(3893),
    [sym_preproc_warning] = STATE(3893),
    [sym_preproc_define] = STATE(3893),
    [sym_preproc_undef] = STATE(3893),
    [anon_sym_SEMI] = ACTIONS(4504),
    [anon_sym_LBRACK] = ACTIONS(4504),
    [anon_sym_COLON] = ACTIONS(4504),
    [anon_sym_COMMA] = ACTIONS(4504),
    [anon_sym_RBRACK] = ACTIONS(4504),
    [anon_sym_LPAREN] = ACTIONS(4504),
    [anon_sym_RPAREN] = ACTIONS(4504),
    [anon_sym_LBRACE] = ACTIONS(4504),
    [anon_sym_RBRACE] = ACTIONS(4504),
    [anon_sym_LT] = ACTIONS(4502),
    [anon_sym_GT] = ACTIONS(4502),
    [anon_sym_in] = ACTIONS(4502),
    [anon_sym_QMARK] = ACTIONS(4502),
    [anon_sym_BANG] = ACTIONS(4502),
    [anon_sym_PLUS_PLUS] = ACTIONS(4504),
    [anon_sym_DASH_DASH] = ACTIONS(4504),
    [anon_sym_PLUS] = ACTIONS(4502),
    [anon_sym_DASH] = ACTIONS(4502),
    [anon_sym_STAR] = ACTIONS(4504),
    [anon_sym_SLASH] = ACTIONS(4502),
    [anon_sym_PERCENT] = ACTIONS(4504),
    [anon_sym_CARET] = ACTIONS(4504),
    [anon_sym_PIPE] = ACTIONS(4502),
    [anon_sym_AMP] = ACTIONS(4502),
    [anon_sym_LT_LT] = ACTIONS(4504),
    [anon_sym_GT_GT] = ACTIONS(4502),
    [anon_sym_GT_GT_GT] = ACTIONS(4504),
    [anon_sym_EQ_EQ] = ACTIONS(4504),
    [anon_sym_BANG_EQ] = ACTIONS(4504),
    [anon_sym_GT_EQ] = ACTIONS(4504),
    [anon_sym_LT_EQ] = ACTIONS(4504),
    [anon_sym_DOT] = ACTIONS(4502),
    [anon_sym_EQ_GT] = ACTIONS(4504),
    [anon_sym_switch] = ACTIONS(4504),
    [anon_sym_when] = ACTIONS(4504),
    [anon_sym_DOT_DOT] = ACTIONS(4504),
    [anon_sym_and] = ACTIONS(4504),
    [anon_sym_or] = ACTIONS(4504),
    [anon_sym_AMP_AMP] = ACTIONS(4504),
    [anon_sym_PIPE_PIPE] = ACTIONS(4504),
    [anon_sym_QMARK_QMARK] = ACTIONS(4504),
    [anon_sym_into] = ACTIONS(4504),
    [anon_sym_on] = ACTIONS(4504),
    [anon_sym_equals] = ACTIONS(4504),
    [anon_sym_by] = ACTIONS(4504),
    [anon_sym_as] = ACTIONS(4504),
    [anon_sym_is] = ACTIONS(4504),
    [anon_sym_DASH_GT] = ACTIONS(4504),
    [anon_sym_with] = ACTIONS(4504),
    [aux_sym_preproc_if_token3] = ACTIONS(4504),
    [aux_sym_preproc_else_token1] = ACTIONS(4504),
    [aux_sym_preproc_elif_token1] = ACTIONS(4504),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3894] = {
    [sym_type_argument_list] = STATE(3964),
    [sym_preproc_region] = STATE(3894),
    [sym_preproc_endregion] = STATE(3894),
    [sym_preproc_line] = STATE(3894),
    [sym_preproc_pragma] = STATE(3894),
    [sym_preproc_nullable] = STATE(3894),
    [sym_preproc_error] = STATE(3894),
    [sym_preproc_warning] = STATE(3894),
    [sym_preproc_define] = STATE(3894),
    [sym_preproc_undef] = STATE(3894),
    [anon_sym_SEMI] = ACTIONS(4140),
    [anon_sym_LBRACK] = ACTIONS(4140),
    [anon_sym_COLON] = ACTIONS(4140),
    [anon_sym_COMMA] = ACTIONS(4140),
    [anon_sym_RBRACK] = ACTIONS(4140),
    [anon_sym_LPAREN] = ACTIONS(4140),
    [anon_sym_RPAREN] = ACTIONS(4140),
    [anon_sym_LBRACE] = ACTIONS(4140),
    [anon_sym_RBRACE] = ACTIONS(4140),
    [anon_sym_LT] = ACTIONS(5813),
    [anon_sym_GT] = ACTIONS(4138),
    [anon_sym_in] = ACTIONS(4140),
    [anon_sym_QMARK] = ACTIONS(4138),
    [anon_sym_BANG] = ACTIONS(4138),
    [anon_sym_PLUS_PLUS] = ACTIONS(4140),
    [anon_sym_DASH_DASH] = ACTIONS(4140),
    [anon_sym_PLUS] = ACTIONS(4138),
    [anon_sym_DASH] = ACTIONS(4138),
    [anon_sym_STAR] = ACTIONS(4140),
    [anon_sym_SLASH] = ACTIONS(4138),
    [anon_sym_PERCENT] = ACTIONS(4140),
    [anon_sym_CARET] = ACTIONS(4140),
    [anon_sym_PIPE] = ACTIONS(4138),
    [anon_sym_AMP] = ACTIONS(4138),
    [anon_sym_LT_LT] = ACTIONS(4140),
    [anon_sym_GT_GT] = ACTIONS(4138),
    [anon_sym_GT_GT_GT] = ACTIONS(4140),
    [anon_sym_EQ_EQ] = ACTIONS(4140),
    [anon_sym_BANG_EQ] = ACTIONS(4140),
    [anon_sym_GT_EQ] = ACTIONS(4140),
    [anon_sym_LT_EQ] = ACTIONS(4140),
    [anon_sym_DOT] = ACTIONS(4138),
    [anon_sym_EQ_GT] = ACTIONS(4140),
    [anon_sym_switch] = ACTIONS(4140),
    [anon_sym_when] = ACTIONS(4140),
    [anon_sym_DOT_DOT] = ACTIONS(4140),
    [anon_sym_and] = ACTIONS(4140),
    [anon_sym_or] = ACTIONS(4140),
    [anon_sym_AMP_AMP] = ACTIONS(4140),
    [anon_sym_PIPE_PIPE] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK] = ACTIONS(4140),
    [anon_sym_on] = ACTIONS(4140),
    [anon_sym_equals] = ACTIONS(4140),
    [anon_sym_by] = ACTIONS(4140),
    [anon_sym_as] = ACTIONS(4140),
    [anon_sym_is] = ACTIONS(4140),
    [anon_sym_DASH_GT] = ACTIONS(4140),
    [anon_sym_with] = ACTIONS(4140),
    [aux_sym_preproc_if_token3] = ACTIONS(4140),
    [aux_sym_preproc_else_token1] = ACTIONS(4140),
    [aux_sym_preproc_elif_token1] = ACTIONS(4140),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3895] = {
    [sym_preproc_region] = STATE(3895),
    [sym_preproc_endregion] = STATE(3895),
    [sym_preproc_line] = STATE(3895),
    [sym_preproc_pragma] = STATE(3895),
    [sym_preproc_nullable] = STATE(3895),
    [sym_preproc_error] = STATE(3895),
    [sym_preproc_warning] = STATE(3895),
    [sym_preproc_define] = STATE(3895),
    [sym_preproc_undef] = STATE(3895),
    [anon_sym_EQ] = ACTIONS(3995),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_COLON] = ACTIONS(3993),
    [anon_sym_COMMA] = ACTIONS(3993),
    [anon_sym_LPAREN] = ACTIONS(3993),
    [anon_sym_LT] = ACTIONS(3995),
    [anon_sym_GT] = ACTIONS(3995),
    [anon_sym_QMARK] = ACTIONS(3995),
    [anon_sym_BANG] = ACTIONS(3995),
    [anon_sym_PLUS_PLUS] = ACTIONS(3993),
    [anon_sym_DASH_DASH] = ACTIONS(3993),
    [anon_sym_PLUS] = ACTIONS(3995),
    [anon_sym_DASH] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3995),
    [anon_sym_SLASH] = ACTIONS(3995),
    [anon_sym_PERCENT] = ACTIONS(3995),
    [anon_sym_CARET] = ACTIONS(3995),
    [anon_sym_PIPE] = ACTIONS(3995),
    [anon_sym_AMP] = ACTIONS(3995),
    [anon_sym_LT_LT] = ACTIONS(3995),
    [anon_sym_GT_GT] = ACTIONS(3995),
    [anon_sym_GT_GT_GT] = ACTIONS(3995),
    [anon_sym_EQ_EQ] = ACTIONS(3993),
    [anon_sym_BANG_EQ] = ACTIONS(3993),
    [anon_sym_GT_EQ] = ACTIONS(3993),
    [anon_sym_LT_EQ] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3995),
    [anon_sym_switch] = ACTIONS(3993),
    [anon_sym_DOT_DOT] = ACTIONS(3993),
    [anon_sym_and] = ACTIONS(3993),
    [anon_sym_or] = ACTIONS(3993),
    [anon_sym_PLUS_EQ] = ACTIONS(3993),
    [anon_sym_DASH_EQ] = ACTIONS(3993),
    [anon_sym_STAR_EQ] = ACTIONS(3993),
    [anon_sym_SLASH_EQ] = ACTIONS(3993),
    [anon_sym_PERCENT_EQ] = ACTIONS(3993),
    [anon_sym_AMP_EQ] = ACTIONS(3993),
    [anon_sym_CARET_EQ] = ACTIONS(3993),
    [anon_sym_PIPE_EQ] = ACTIONS(3993),
    [anon_sym_LT_LT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(3993),
    [anon_sym_AMP_AMP] = ACTIONS(3993),
    [anon_sym_PIPE_PIPE] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK] = ACTIONS(3995),
    [anon_sym_into] = ACTIONS(3993),
    [anon_sym_as] = ACTIONS(3993),
    [anon_sym_is] = ACTIONS(3993),
    [anon_sym_DASH_GT] = ACTIONS(3993),
    [anon_sym_with] = ACTIONS(3993),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(3993),
  },
  [3896] = {
    [sym_preproc_region] = STATE(3896),
    [sym_preproc_endregion] = STATE(3896),
    [sym_preproc_line] = STATE(3896),
    [sym_preproc_pragma] = STATE(3896),
    [sym_preproc_nullable] = STATE(3896),
    [sym_preproc_error] = STATE(3896),
    [sym_preproc_warning] = STATE(3896),
    [sym_preproc_define] = STATE(3896),
    [sym_preproc_undef] = STATE(3896),
    [anon_sym_EQ] = ACTIONS(4685),
    [anon_sym_LBRACK] = ACTIONS(4683),
    [anon_sym_COLON] = ACTIONS(4683),
    [anon_sym_COMMA] = ACTIONS(4683),
    [anon_sym_LPAREN] = ACTIONS(4683),
    [anon_sym_LT] = ACTIONS(4685),
    [anon_sym_GT] = ACTIONS(4685),
    [anon_sym_QMARK] = ACTIONS(4685),
    [anon_sym_BANG] = ACTIONS(4685),
    [anon_sym_PLUS_PLUS] = ACTIONS(4683),
    [anon_sym_DASH_DASH] = ACTIONS(4683),
    [anon_sym_PLUS] = ACTIONS(4685),
    [anon_sym_DASH] = ACTIONS(4685),
    [anon_sym_STAR] = ACTIONS(4685),
    [anon_sym_SLASH] = ACTIONS(4685),
    [anon_sym_PERCENT] = ACTIONS(4685),
    [anon_sym_CARET] = ACTIONS(4685),
    [anon_sym_PIPE] = ACTIONS(4685),
    [anon_sym_AMP] = ACTIONS(4685),
    [anon_sym_LT_LT] = ACTIONS(4685),
    [anon_sym_GT_GT] = ACTIONS(4685),
    [anon_sym_GT_GT_GT] = ACTIONS(4685),
    [anon_sym_EQ_EQ] = ACTIONS(4683),
    [anon_sym_BANG_EQ] = ACTIONS(4683),
    [anon_sym_GT_EQ] = ACTIONS(4683),
    [anon_sym_LT_EQ] = ACTIONS(4683),
    [anon_sym_DOT] = ACTIONS(4685),
    [anon_sym_switch] = ACTIONS(4683),
    [anon_sym_DOT_DOT] = ACTIONS(4683),
    [anon_sym_and] = ACTIONS(4683),
    [anon_sym_or] = ACTIONS(4683),
    [anon_sym_PLUS_EQ] = ACTIONS(4683),
    [anon_sym_DASH_EQ] = ACTIONS(4683),
    [anon_sym_STAR_EQ] = ACTIONS(4683),
    [anon_sym_SLASH_EQ] = ACTIONS(4683),
    [anon_sym_PERCENT_EQ] = ACTIONS(4683),
    [anon_sym_AMP_EQ] = ACTIONS(4683),
    [anon_sym_CARET_EQ] = ACTIONS(4683),
    [anon_sym_PIPE_EQ] = ACTIONS(4683),
    [anon_sym_LT_LT_EQ] = ACTIONS(4683),
    [anon_sym_GT_GT_EQ] = ACTIONS(4683),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4683),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4683),
    [anon_sym_AMP_AMP] = ACTIONS(4683),
    [anon_sym_PIPE_PIPE] = ACTIONS(4683),
    [anon_sym_QMARK_QMARK] = ACTIONS(4685),
    [anon_sym_into] = ACTIONS(4683),
    [anon_sym_as] = ACTIONS(4683),
    [anon_sym_is] = ACTIONS(4683),
    [anon_sym_DASH_GT] = ACTIONS(4683),
    [anon_sym_with] = ACTIONS(4683),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4683),
  },
  [3897] = {
    [sym_preproc_region] = STATE(3897),
    [sym_preproc_endregion] = STATE(3897),
    [sym_preproc_line] = STATE(3897),
    [sym_preproc_pragma] = STATE(3897),
    [sym_preproc_nullable] = STATE(3897),
    [sym_preproc_error] = STATE(3897),
    [sym_preproc_warning] = STATE(3897),
    [sym_preproc_define] = STATE(3897),
    [sym_preproc_undef] = STATE(3897),
    [anon_sym_EQ] = ACTIONS(4689),
    [anon_sym_LBRACK] = ACTIONS(4687),
    [anon_sym_COLON] = ACTIONS(4687),
    [anon_sym_COMMA] = ACTIONS(4687),
    [anon_sym_LPAREN] = ACTIONS(4687),
    [anon_sym_LT] = ACTIONS(4689),
    [anon_sym_GT] = ACTIONS(4689),
    [anon_sym_QMARK] = ACTIONS(4689),
    [anon_sym_BANG] = ACTIONS(4689),
    [anon_sym_PLUS_PLUS] = ACTIONS(4687),
    [anon_sym_DASH_DASH] = ACTIONS(4687),
    [anon_sym_PLUS] = ACTIONS(4689),
    [anon_sym_DASH] = ACTIONS(4689),
    [anon_sym_STAR] = ACTIONS(4689),
    [anon_sym_SLASH] = ACTIONS(4689),
    [anon_sym_PERCENT] = ACTIONS(4689),
    [anon_sym_CARET] = ACTIONS(4689),
    [anon_sym_PIPE] = ACTIONS(4689),
    [anon_sym_AMP] = ACTIONS(4689),
    [anon_sym_LT_LT] = ACTIONS(4689),
    [anon_sym_GT_GT] = ACTIONS(4689),
    [anon_sym_GT_GT_GT] = ACTIONS(4689),
    [anon_sym_EQ_EQ] = ACTIONS(4687),
    [anon_sym_BANG_EQ] = ACTIONS(4687),
    [anon_sym_GT_EQ] = ACTIONS(4687),
    [anon_sym_LT_EQ] = ACTIONS(4687),
    [anon_sym_DOT] = ACTIONS(4689),
    [anon_sym_switch] = ACTIONS(4687),
    [anon_sym_DOT_DOT] = ACTIONS(4687),
    [anon_sym_and] = ACTIONS(4687),
    [anon_sym_or] = ACTIONS(4687),
    [anon_sym_PLUS_EQ] = ACTIONS(4687),
    [anon_sym_DASH_EQ] = ACTIONS(4687),
    [anon_sym_STAR_EQ] = ACTIONS(4687),
    [anon_sym_SLASH_EQ] = ACTIONS(4687),
    [anon_sym_PERCENT_EQ] = ACTIONS(4687),
    [anon_sym_AMP_EQ] = ACTIONS(4687),
    [anon_sym_CARET_EQ] = ACTIONS(4687),
    [anon_sym_PIPE_EQ] = ACTIONS(4687),
    [anon_sym_LT_LT_EQ] = ACTIONS(4687),
    [anon_sym_GT_GT_EQ] = ACTIONS(4687),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4687),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4687),
    [anon_sym_AMP_AMP] = ACTIONS(4687),
    [anon_sym_PIPE_PIPE] = ACTIONS(4687),
    [anon_sym_QMARK_QMARK] = ACTIONS(4689),
    [anon_sym_into] = ACTIONS(4687),
    [anon_sym_as] = ACTIONS(4687),
    [anon_sym_is] = ACTIONS(4687),
    [anon_sym_DASH_GT] = ACTIONS(4687),
    [anon_sym_with] = ACTIONS(4687),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4687),
  },
  [3898] = {
    [sym_preproc_region] = STATE(3898),
    [sym_preproc_endregion] = STATE(3898),
    [sym_preproc_line] = STATE(3898),
    [sym_preproc_pragma] = STATE(3898),
    [sym_preproc_nullable] = STATE(3898),
    [sym_preproc_error] = STATE(3898),
    [sym_preproc_warning] = STATE(3898),
    [sym_preproc_define] = STATE(3898),
    [sym_preproc_undef] = STATE(3898),
    [anon_sym_EQ] = ACTIONS(5818),
    [anon_sym_LBRACK] = ACTIONS(5286),
    [anon_sym_COLON] = ACTIONS(5286),
    [anon_sym_COMMA] = ACTIONS(5286),
    [anon_sym_LPAREN] = ACTIONS(5286),
    [anon_sym_LT] = ACTIONS(5288),
    [anon_sym_GT] = ACTIONS(5288),
    [anon_sym_QMARK] = ACTIONS(5288),
    [anon_sym_BANG] = ACTIONS(5288),
    [anon_sym_PLUS_PLUS] = ACTIONS(5286),
    [anon_sym_DASH_DASH] = ACTIONS(5286),
    [anon_sym_PLUS] = ACTIONS(5288),
    [anon_sym_DASH] = ACTIONS(5288),
    [anon_sym_STAR] = ACTIONS(5288),
    [anon_sym_SLASH] = ACTIONS(5288),
    [anon_sym_PERCENT] = ACTIONS(5288),
    [anon_sym_CARET] = ACTIONS(5288),
    [anon_sym_PIPE] = ACTIONS(5288),
    [anon_sym_AMP] = ACTIONS(5288),
    [anon_sym_LT_LT] = ACTIONS(5288),
    [anon_sym_GT_GT] = ACTIONS(5288),
    [anon_sym_GT_GT_GT] = ACTIONS(5288),
    [anon_sym_EQ_EQ] = ACTIONS(5286),
    [anon_sym_BANG_EQ] = ACTIONS(5286),
    [anon_sym_GT_EQ] = ACTIONS(5286),
    [anon_sym_LT_EQ] = ACTIONS(5286),
    [anon_sym_DOT] = ACTIONS(5288),
    [anon_sym_switch] = ACTIONS(5286),
    [anon_sym_DOT_DOT] = ACTIONS(5286),
    [anon_sym_and] = ACTIONS(5286),
    [anon_sym_or] = ACTIONS(5286),
    [anon_sym_PLUS_EQ] = ACTIONS(5820),
    [anon_sym_DASH_EQ] = ACTIONS(5820),
    [anon_sym_STAR_EQ] = ACTIONS(5820),
    [anon_sym_SLASH_EQ] = ACTIONS(5820),
    [anon_sym_PERCENT_EQ] = ACTIONS(5820),
    [anon_sym_AMP_EQ] = ACTIONS(5820),
    [anon_sym_CARET_EQ] = ACTIONS(5820),
    [anon_sym_PIPE_EQ] = ACTIONS(5820),
    [anon_sym_LT_LT_EQ] = ACTIONS(5820),
    [anon_sym_GT_GT_EQ] = ACTIONS(5820),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(5820),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(5820),
    [anon_sym_AMP_AMP] = ACTIONS(5286),
    [anon_sym_PIPE_PIPE] = ACTIONS(5286),
    [anon_sym_QMARK_QMARK] = ACTIONS(5288),
    [anon_sym_into] = ACTIONS(5286),
    [anon_sym_as] = ACTIONS(5286),
    [anon_sym_is] = ACTIONS(5286),
    [anon_sym_DASH_GT] = ACTIONS(5286),
    [anon_sym_with] = ACTIONS(5286),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(5286),
  },
  [3899] = {
    [sym_preproc_region] = STATE(3899),
    [sym_preproc_endregion] = STATE(3899),
    [sym_preproc_line] = STATE(3899),
    [sym_preproc_pragma] = STATE(3899),
    [sym_preproc_nullable] = STATE(3899),
    [sym_preproc_error] = STATE(3899),
    [sym_preproc_warning] = STATE(3899),
    [sym_preproc_define] = STATE(3899),
    [sym_preproc_undef] = STATE(3899),
    [anon_sym_EQ] = ACTIONS(4122),
    [anon_sym_LBRACK] = ACTIONS(4124),
    [anon_sym_COLON] = ACTIONS(4124),
    [anon_sym_COMMA] = ACTIONS(4124),
    [anon_sym_LPAREN] = ACTIONS(4124),
    [anon_sym_LT] = ACTIONS(4122),
    [anon_sym_GT] = ACTIONS(4122),
    [anon_sym_QMARK] = ACTIONS(4122),
    [anon_sym_BANG] = ACTIONS(4122),
    [anon_sym_PLUS_PLUS] = ACTIONS(4124),
    [anon_sym_DASH_DASH] = ACTIONS(4124),
    [anon_sym_PLUS] = ACTIONS(4122),
    [anon_sym_DASH] = ACTIONS(4122),
    [anon_sym_STAR] = ACTIONS(4122),
    [anon_sym_SLASH] = ACTIONS(4122),
    [anon_sym_PERCENT] = ACTIONS(4122),
    [anon_sym_CARET] = ACTIONS(4122),
    [anon_sym_PIPE] = ACTIONS(4122),
    [anon_sym_AMP] = ACTIONS(4122),
    [anon_sym_LT_LT] = ACTIONS(4122),
    [anon_sym_GT_GT] = ACTIONS(4122),
    [anon_sym_GT_GT_GT] = ACTIONS(4122),
    [anon_sym_EQ_EQ] = ACTIONS(4124),
    [anon_sym_BANG_EQ] = ACTIONS(4124),
    [anon_sym_GT_EQ] = ACTIONS(4124),
    [anon_sym_LT_EQ] = ACTIONS(4124),
    [anon_sym_DOT] = ACTIONS(4122),
    [anon_sym_switch] = ACTIONS(4124),
    [anon_sym_DOT_DOT] = ACTIONS(4124),
    [anon_sym_and] = ACTIONS(4124),
    [anon_sym_or] = ACTIONS(4124),
    [anon_sym_PLUS_EQ] = ACTIONS(4124),
    [anon_sym_DASH_EQ] = ACTIONS(4124),
    [anon_sym_STAR_EQ] = ACTIONS(4124),
    [anon_sym_SLASH_EQ] = ACTIONS(4124),
    [anon_sym_PERCENT_EQ] = ACTIONS(4124),
    [anon_sym_AMP_EQ] = ACTIONS(4124),
    [anon_sym_CARET_EQ] = ACTIONS(4124),
    [anon_sym_PIPE_EQ] = ACTIONS(4124),
    [anon_sym_LT_LT_EQ] = ACTIONS(4124),
    [anon_sym_GT_GT_EQ] = ACTIONS(4124),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4124),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4124),
    [anon_sym_AMP_AMP] = ACTIONS(4124),
    [anon_sym_PIPE_PIPE] = ACTIONS(4124),
    [anon_sym_QMARK_QMARK] = ACTIONS(4122),
    [anon_sym_into] = ACTIONS(4124),
    [anon_sym_as] = ACTIONS(4124),
    [anon_sym_is] = ACTIONS(4124),
    [anon_sym_DASH_GT] = ACTIONS(4124),
    [anon_sym_with] = ACTIONS(4124),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4124),
  },
  [3900] = {
    [sym_preproc_region] = STATE(3900),
    [sym_preproc_endregion] = STATE(3900),
    [sym_preproc_line] = STATE(3900),
    [sym_preproc_pragma] = STATE(3900),
    [sym_preproc_nullable] = STATE(3900),
    [sym_preproc_error] = STATE(3900),
    [sym_preproc_warning] = STATE(3900),
    [sym_preproc_define] = STATE(3900),
    [sym_preproc_undef] = STATE(3900),
    [anon_sym_SEMI] = ACTIONS(4140),
    [anon_sym_LBRACK] = ACTIONS(4140),
    [anon_sym_COLON] = ACTIONS(4140),
    [anon_sym_COMMA] = ACTIONS(4140),
    [anon_sym_RBRACK] = ACTIONS(4140),
    [anon_sym_LPAREN] = ACTIONS(4140),
    [anon_sym_RPAREN] = ACTIONS(4140),
    [anon_sym_LBRACE] = ACTIONS(4140),
    [anon_sym_RBRACE] = ACTIONS(4140),
    [anon_sym_LT] = ACTIONS(4138),
    [anon_sym_GT] = ACTIONS(4138),
    [anon_sym_in] = ACTIONS(4138),
    [anon_sym_QMARK] = ACTIONS(4138),
    [anon_sym_BANG] = ACTIONS(4138),
    [anon_sym_PLUS_PLUS] = ACTIONS(4140),
    [anon_sym_DASH_DASH] = ACTIONS(4140),
    [anon_sym_PLUS] = ACTIONS(4138),
    [anon_sym_DASH] = ACTIONS(4138),
    [anon_sym_STAR] = ACTIONS(4140),
    [anon_sym_SLASH] = ACTIONS(4138),
    [anon_sym_PERCENT] = ACTIONS(4140),
    [anon_sym_CARET] = ACTIONS(4140),
    [anon_sym_PIPE] = ACTIONS(4138),
    [anon_sym_AMP] = ACTIONS(4138),
    [anon_sym_LT_LT] = ACTIONS(4140),
    [anon_sym_GT_GT] = ACTIONS(4138),
    [anon_sym_GT_GT_GT] = ACTIONS(4140),
    [anon_sym_EQ_EQ] = ACTIONS(4140),
    [anon_sym_BANG_EQ] = ACTIONS(4140),
    [anon_sym_GT_EQ] = ACTIONS(4140),
    [anon_sym_LT_EQ] = ACTIONS(4140),
    [anon_sym_DOT] = ACTIONS(4138),
    [anon_sym_EQ_GT] = ACTIONS(4140),
    [anon_sym_switch] = ACTIONS(4140),
    [anon_sym_when] = ACTIONS(4140),
    [anon_sym_DOT_DOT] = ACTIONS(4140),
    [anon_sym_and] = ACTIONS(4140),
    [anon_sym_or] = ACTIONS(4140),
    [anon_sym_AMP_AMP] = ACTIONS(4140),
    [anon_sym_PIPE_PIPE] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK] = ACTIONS(4140),
    [anon_sym_into] = ACTIONS(4140),
    [anon_sym_on] = ACTIONS(4140),
    [anon_sym_equals] = ACTIONS(4140),
    [anon_sym_by] = ACTIONS(4140),
    [anon_sym_as] = ACTIONS(4140),
    [anon_sym_is] = ACTIONS(4140),
    [anon_sym_DASH_GT] = ACTIONS(4140),
    [anon_sym_with] = ACTIONS(4140),
    [aux_sym_preproc_if_token3] = ACTIONS(4140),
    [aux_sym_preproc_else_token1] = ACTIONS(4140),
    [aux_sym_preproc_elif_token1] = ACTIONS(4140),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3901] = {
    [sym_preproc_region] = STATE(3901),
    [sym_preproc_endregion] = STATE(3901),
    [sym_preproc_line] = STATE(3901),
    [sym_preproc_pragma] = STATE(3901),
    [sym_preproc_nullable] = STATE(3901),
    [sym_preproc_error] = STATE(3901),
    [sym_preproc_warning] = STATE(3901),
    [sym_preproc_define] = STATE(3901),
    [sym_preproc_undef] = STATE(3901),
    [anon_sym_SEMI] = ACTIONS(4132),
    [anon_sym_LBRACK] = ACTIONS(4132),
    [anon_sym_COLON] = ACTIONS(4132),
    [anon_sym_COMMA] = ACTIONS(4132),
    [anon_sym_RBRACK] = ACTIONS(4132),
    [anon_sym_LPAREN] = ACTIONS(4132),
    [anon_sym_RPAREN] = ACTIONS(4132),
    [anon_sym_LBRACE] = ACTIONS(4132),
    [anon_sym_RBRACE] = ACTIONS(4132),
    [anon_sym_LT] = ACTIONS(4130),
    [anon_sym_GT] = ACTIONS(4130),
    [anon_sym_in] = ACTIONS(4130),
    [anon_sym_QMARK] = ACTIONS(4130),
    [anon_sym_BANG] = ACTIONS(4130),
    [anon_sym_PLUS_PLUS] = ACTIONS(4132),
    [anon_sym_DASH_DASH] = ACTIONS(4132),
    [anon_sym_PLUS] = ACTIONS(4130),
    [anon_sym_DASH] = ACTIONS(4130),
    [anon_sym_STAR] = ACTIONS(4132),
    [anon_sym_SLASH] = ACTIONS(4130),
    [anon_sym_PERCENT] = ACTIONS(4132),
    [anon_sym_CARET] = ACTIONS(4132),
    [anon_sym_PIPE] = ACTIONS(4130),
    [anon_sym_AMP] = ACTIONS(4130),
    [anon_sym_LT_LT] = ACTIONS(4132),
    [anon_sym_GT_GT] = ACTIONS(4130),
    [anon_sym_GT_GT_GT] = ACTIONS(4132),
    [anon_sym_EQ_EQ] = ACTIONS(4132),
    [anon_sym_BANG_EQ] = ACTIONS(4132),
    [anon_sym_GT_EQ] = ACTIONS(4132),
    [anon_sym_LT_EQ] = ACTIONS(4132),
    [anon_sym_DOT] = ACTIONS(4130),
    [anon_sym_EQ_GT] = ACTIONS(4132),
    [anon_sym_switch] = ACTIONS(4132),
    [anon_sym_when] = ACTIONS(4132),
    [anon_sym_DOT_DOT] = ACTIONS(4132),
    [anon_sym_and] = ACTIONS(4132),
    [anon_sym_or] = ACTIONS(4132),
    [anon_sym_AMP_AMP] = ACTIONS(4132),
    [anon_sym_PIPE_PIPE] = ACTIONS(4132),
    [anon_sym_QMARK_QMARK] = ACTIONS(4132),
    [anon_sym_into] = ACTIONS(4132),
    [anon_sym_on] = ACTIONS(4132),
    [anon_sym_equals] = ACTIONS(4132),
    [anon_sym_by] = ACTIONS(4132),
    [anon_sym_as] = ACTIONS(4132),
    [anon_sym_is] = ACTIONS(4132),
    [anon_sym_DASH_GT] = ACTIONS(4132),
    [anon_sym_with] = ACTIONS(4132),
    [aux_sym_preproc_if_token3] = ACTIONS(4132),
    [aux_sym_preproc_else_token1] = ACTIONS(4132),
    [aux_sym_preproc_elif_token1] = ACTIONS(4132),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3902] = {
    [sym_preproc_region] = STATE(3902),
    [sym_preproc_endregion] = STATE(3902),
    [sym_preproc_line] = STATE(3902),
    [sym_preproc_pragma] = STATE(3902),
    [sym_preproc_nullable] = STATE(3902),
    [sym_preproc_error] = STATE(3902),
    [sym_preproc_warning] = STATE(3902),
    [sym_preproc_define] = STATE(3902),
    [sym_preproc_undef] = STATE(3902),
    [anon_sym_EQ] = ACTIONS(4183),
    [anon_sym_LBRACK] = ACTIONS(4191),
    [anon_sym_COLON] = ACTIONS(4191),
    [anon_sym_COMMA] = ACTIONS(4191),
    [anon_sym_LPAREN] = ACTIONS(4191),
    [anon_sym_LT] = ACTIONS(4183),
    [anon_sym_GT] = ACTIONS(4183),
    [anon_sym_QMARK] = ACTIONS(4183),
    [anon_sym_BANG] = ACTIONS(4183),
    [anon_sym_PLUS_PLUS] = ACTIONS(4191),
    [anon_sym_DASH_DASH] = ACTIONS(4191),
    [anon_sym_PLUS] = ACTIONS(4183),
    [anon_sym_DASH] = ACTIONS(4183),
    [anon_sym_STAR] = ACTIONS(4183),
    [anon_sym_SLASH] = ACTIONS(4183),
    [anon_sym_PERCENT] = ACTIONS(4183),
    [anon_sym_CARET] = ACTIONS(4183),
    [anon_sym_PIPE] = ACTIONS(4183),
    [anon_sym_AMP] = ACTIONS(4183),
    [anon_sym_LT_LT] = ACTIONS(4183),
    [anon_sym_GT_GT] = ACTIONS(4183),
    [anon_sym_GT_GT_GT] = ACTIONS(4183),
    [anon_sym_EQ_EQ] = ACTIONS(4191),
    [anon_sym_BANG_EQ] = ACTIONS(4191),
    [anon_sym_GT_EQ] = ACTIONS(4191),
    [anon_sym_LT_EQ] = ACTIONS(4191),
    [anon_sym_DOT] = ACTIONS(4183),
    [anon_sym_switch] = ACTIONS(4191),
    [anon_sym_DOT_DOT] = ACTIONS(4191),
    [anon_sym_and] = ACTIONS(4191),
    [anon_sym_or] = ACTIONS(4191),
    [anon_sym_PLUS_EQ] = ACTIONS(4191),
    [anon_sym_DASH_EQ] = ACTIONS(4191),
    [anon_sym_STAR_EQ] = ACTIONS(4191),
    [anon_sym_SLASH_EQ] = ACTIONS(4191),
    [anon_sym_PERCENT_EQ] = ACTIONS(4191),
    [anon_sym_AMP_EQ] = ACTIONS(4191),
    [anon_sym_CARET_EQ] = ACTIONS(4191),
    [anon_sym_PIPE_EQ] = ACTIONS(4191),
    [anon_sym_LT_LT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4191),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4191),
    [anon_sym_AMP_AMP] = ACTIONS(4191),
    [anon_sym_PIPE_PIPE] = ACTIONS(4191),
    [anon_sym_QMARK_QMARK] = ACTIONS(4183),
    [anon_sym_into] = ACTIONS(4191),
    [anon_sym_as] = ACTIONS(4191),
    [anon_sym_is] = ACTIONS(4191),
    [anon_sym_DASH_GT] = ACTIONS(4191),
    [anon_sym_with] = ACTIONS(4191),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4191),
  },
  [3903] = {
    [sym_preproc_region] = STATE(3903),
    [sym_preproc_endregion] = STATE(3903),
    [sym_preproc_line] = STATE(3903),
    [sym_preproc_pragma] = STATE(3903),
    [sym_preproc_nullable] = STATE(3903),
    [sym_preproc_error] = STATE(3903),
    [sym_preproc_warning] = STATE(3903),
    [sym_preproc_define] = STATE(3903),
    [sym_preproc_undef] = STATE(3903),
    [anon_sym_EQ] = ACTIONS(5822),
    [anon_sym_LBRACK] = ACTIONS(5286),
    [anon_sym_COLON] = ACTIONS(5286),
    [anon_sym_COMMA] = ACTIONS(5286),
    [anon_sym_LPAREN] = ACTIONS(5286),
    [anon_sym_RPAREN] = ACTIONS(5286),
    [anon_sym_RBRACE] = ACTIONS(5286),
    [anon_sym_LT] = ACTIONS(5288),
    [anon_sym_GT] = ACTIONS(5288),
    [anon_sym_QMARK] = ACTIONS(5288),
    [anon_sym_BANG] = ACTIONS(5288),
    [anon_sym_PLUS_PLUS] = ACTIONS(5286),
    [anon_sym_DASH_DASH] = ACTIONS(5286),
    [anon_sym_PLUS] = ACTIONS(5288),
    [anon_sym_DASH] = ACTIONS(5288),
    [anon_sym_STAR] = ACTIONS(5288),
    [anon_sym_SLASH] = ACTIONS(5288),
    [anon_sym_PERCENT] = ACTIONS(5288),
    [anon_sym_CARET] = ACTIONS(5288),
    [anon_sym_PIPE] = ACTIONS(5288),
    [anon_sym_AMP] = ACTIONS(5288),
    [anon_sym_LT_LT] = ACTIONS(5288),
    [anon_sym_GT_GT] = ACTIONS(5288),
    [anon_sym_GT_GT_GT] = ACTIONS(5288),
    [anon_sym_EQ_EQ] = ACTIONS(5286),
    [anon_sym_BANG_EQ] = ACTIONS(5286),
    [anon_sym_GT_EQ] = ACTIONS(5286),
    [anon_sym_LT_EQ] = ACTIONS(5286),
    [anon_sym_DOT] = ACTIONS(5288),
    [anon_sym_switch] = ACTIONS(5286),
    [anon_sym_DOT_DOT] = ACTIONS(5286),
    [anon_sym_and] = ACTIONS(5286),
    [anon_sym_or] = ACTIONS(5286),
    [anon_sym_PLUS_EQ] = ACTIONS(5824),
    [anon_sym_DASH_EQ] = ACTIONS(5824),
    [anon_sym_STAR_EQ] = ACTIONS(5824),
    [anon_sym_SLASH_EQ] = ACTIONS(5824),
    [anon_sym_PERCENT_EQ] = ACTIONS(5824),
    [anon_sym_AMP_EQ] = ACTIONS(5824),
    [anon_sym_CARET_EQ] = ACTIONS(5824),
    [anon_sym_PIPE_EQ] = ACTIONS(5824),
    [anon_sym_LT_LT_EQ] = ACTIONS(5824),
    [anon_sym_GT_GT_EQ] = ACTIONS(5824),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(5824),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(5824),
    [anon_sym_AMP_AMP] = ACTIONS(5286),
    [anon_sym_PIPE_PIPE] = ACTIONS(5286),
    [anon_sym_QMARK_QMARK] = ACTIONS(5288),
    [anon_sym_as] = ACTIONS(5286),
    [anon_sym_is] = ACTIONS(5286),
    [anon_sym_DASH_GT] = ACTIONS(5286),
    [anon_sym_with] = ACTIONS(5286),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3904] = {
    [sym_preproc_region] = STATE(3904),
    [sym_preproc_endregion] = STATE(3904),
    [sym_preproc_line] = STATE(3904),
    [sym_preproc_pragma] = STATE(3904),
    [sym_preproc_nullable] = STATE(3904),
    [sym_preproc_error] = STATE(3904),
    [sym_preproc_warning] = STATE(3904),
    [sym_preproc_define] = STATE(3904),
    [sym_preproc_undef] = STATE(3904),
    [anon_sym_SEMI] = ACTIONS(4494),
    [anon_sym_LBRACK] = ACTIONS(4593),
    [anon_sym_COLON] = ACTIONS(4494),
    [anon_sym_COMMA] = ACTIONS(4494),
    [anon_sym_RBRACK] = ACTIONS(4494),
    [anon_sym_LPAREN] = ACTIONS(4494),
    [anon_sym_RPAREN] = ACTIONS(4494),
    [anon_sym_LBRACE] = ACTIONS(4494),
    [anon_sym_RBRACE] = ACTIONS(4494),
    [anon_sym_LT] = ACTIONS(4492),
    [anon_sym_GT] = ACTIONS(4492),
    [anon_sym_in] = ACTIONS(4492),
    [anon_sym_QMARK] = ACTIONS(5808),
    [anon_sym_BANG] = ACTIONS(4492),
    [anon_sym_PLUS_PLUS] = ACTIONS(4494),
    [anon_sym_DASH_DASH] = ACTIONS(4494),
    [anon_sym_PLUS] = ACTIONS(4492),
    [anon_sym_DASH] = ACTIONS(4492),
    [anon_sym_STAR] = ACTIONS(4599),
    [anon_sym_SLASH] = ACTIONS(4492),
    [anon_sym_PERCENT] = ACTIONS(4494),
    [anon_sym_CARET] = ACTIONS(4494),
    [anon_sym_PIPE] = ACTIONS(4492),
    [anon_sym_AMP] = ACTIONS(4492),
    [anon_sym_LT_LT] = ACTIONS(4494),
    [anon_sym_GT_GT] = ACTIONS(4492),
    [anon_sym_GT_GT_GT] = ACTIONS(4494),
    [anon_sym_EQ_EQ] = ACTIONS(4494),
    [anon_sym_BANG_EQ] = ACTIONS(4494),
    [anon_sym_GT_EQ] = ACTIONS(4494),
    [anon_sym_LT_EQ] = ACTIONS(4494),
    [anon_sym_DOT] = ACTIONS(5826),
    [anon_sym_EQ_GT] = ACTIONS(4494),
    [anon_sym_switch] = ACTIONS(4494),
    [anon_sym_when] = ACTIONS(4494),
    [anon_sym_DOT_DOT] = ACTIONS(4494),
    [anon_sym_and] = ACTIONS(4494),
    [anon_sym_or] = ACTIONS(4494),
    [anon_sym_AMP_AMP] = ACTIONS(4494),
    [anon_sym_PIPE_PIPE] = ACTIONS(4494),
    [anon_sym_QMARK_QMARK] = ACTIONS(4494),
    [anon_sym_into] = ACTIONS(4494),
    [anon_sym_on] = ACTIONS(4494),
    [anon_sym_equals] = ACTIONS(4494),
    [anon_sym_by] = ACTIONS(4494),
    [anon_sym_as] = ACTIONS(4494),
    [anon_sym_is] = ACTIONS(4494),
    [anon_sym_DASH_GT] = ACTIONS(4494),
    [anon_sym_with] = ACTIONS(4494),
    [aux_sym_preproc_if_token3] = ACTIONS(4494),
    [aux_sym_preproc_else_token1] = ACTIONS(4494),
    [aux_sym_preproc_elif_token1] = ACTIONS(4494),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3905] = {
    [sym_preproc_region] = STATE(3905),
    [sym_preproc_endregion] = STATE(3905),
    [sym_preproc_line] = STATE(3905),
    [sym_preproc_pragma] = STATE(3905),
    [sym_preproc_nullable] = STATE(3905),
    [sym_preproc_error] = STATE(3905),
    [sym_preproc_warning] = STATE(3905),
    [sym_preproc_define] = STATE(3905),
    [sym_preproc_undef] = STATE(3905),
    [anon_sym_SEMI] = ACTIONS(4151),
    [anon_sym_LBRACK] = ACTIONS(4151),
    [anon_sym_COLON] = ACTIONS(4151),
    [anon_sym_COMMA] = ACTIONS(4151),
    [anon_sym_RBRACK] = ACTIONS(4151),
    [anon_sym_LPAREN] = ACTIONS(4151),
    [anon_sym_RPAREN] = ACTIONS(4151),
    [anon_sym_LBRACE] = ACTIONS(4151),
    [anon_sym_RBRACE] = ACTIONS(4151),
    [anon_sym_LT] = ACTIONS(4149),
    [anon_sym_GT] = ACTIONS(4149),
    [anon_sym_in] = ACTIONS(4149),
    [anon_sym_QMARK] = ACTIONS(4149),
    [anon_sym_BANG] = ACTIONS(4149),
    [anon_sym_PLUS_PLUS] = ACTIONS(4151),
    [anon_sym_DASH_DASH] = ACTIONS(4151),
    [anon_sym_PLUS] = ACTIONS(4149),
    [anon_sym_DASH] = ACTIONS(4149),
    [anon_sym_STAR] = ACTIONS(4151),
    [anon_sym_SLASH] = ACTIONS(4149),
    [anon_sym_PERCENT] = ACTIONS(4151),
    [anon_sym_CARET] = ACTIONS(4151),
    [anon_sym_PIPE] = ACTIONS(4149),
    [anon_sym_AMP] = ACTIONS(4149),
    [anon_sym_LT_LT] = ACTIONS(4151),
    [anon_sym_GT_GT] = ACTIONS(4149),
    [anon_sym_GT_GT_GT] = ACTIONS(4151),
    [anon_sym_EQ_EQ] = ACTIONS(4151),
    [anon_sym_BANG_EQ] = ACTIONS(4151),
    [anon_sym_GT_EQ] = ACTIONS(4151),
    [anon_sym_LT_EQ] = ACTIONS(4151),
    [anon_sym_DOT] = ACTIONS(4149),
    [anon_sym_EQ_GT] = ACTIONS(4151),
    [anon_sym_switch] = ACTIONS(4151),
    [anon_sym_when] = ACTIONS(4151),
    [anon_sym_DOT_DOT] = ACTIONS(4151),
    [anon_sym_and] = ACTIONS(4151),
    [anon_sym_or] = ACTIONS(4151),
    [anon_sym_AMP_AMP] = ACTIONS(4151),
    [anon_sym_PIPE_PIPE] = ACTIONS(4151),
    [anon_sym_QMARK_QMARK] = ACTIONS(4151),
    [anon_sym_into] = ACTIONS(4151),
    [anon_sym_on] = ACTIONS(4151),
    [anon_sym_equals] = ACTIONS(4151),
    [anon_sym_by] = ACTIONS(4151),
    [anon_sym_as] = ACTIONS(4151),
    [anon_sym_is] = ACTIONS(4151),
    [anon_sym_DASH_GT] = ACTIONS(4151),
    [anon_sym_with] = ACTIONS(4151),
    [aux_sym_preproc_if_token3] = ACTIONS(4151),
    [aux_sym_preproc_else_token1] = ACTIONS(4151),
    [aux_sym_preproc_elif_token1] = ACTIONS(4151),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3906] = {
    [sym_preproc_region] = STATE(3906),
    [sym_preproc_endregion] = STATE(3906),
    [sym_preproc_line] = STATE(3906),
    [sym_preproc_pragma] = STATE(3906),
    [sym_preproc_nullable] = STATE(3906),
    [sym_preproc_error] = STATE(3906),
    [sym_preproc_warning] = STATE(3906),
    [sym_preproc_define] = STATE(3906),
    [sym_preproc_undef] = STATE(3906),
    [anon_sym_EQ] = ACTIONS(4672),
    [anon_sym_LBRACK] = ACTIONS(4670),
    [anon_sym_COLON] = ACTIONS(4670),
    [anon_sym_COMMA] = ACTIONS(4670),
    [anon_sym_LPAREN] = ACTIONS(4670),
    [anon_sym_LT] = ACTIONS(4672),
    [anon_sym_GT] = ACTIONS(4672),
    [anon_sym_QMARK] = ACTIONS(4672),
    [anon_sym_BANG] = ACTIONS(4672),
    [anon_sym_PLUS_PLUS] = ACTIONS(4670),
    [anon_sym_DASH_DASH] = ACTIONS(4670),
    [anon_sym_PLUS] = ACTIONS(4672),
    [anon_sym_DASH] = ACTIONS(4672),
    [anon_sym_STAR] = ACTIONS(4672),
    [anon_sym_SLASH] = ACTIONS(4672),
    [anon_sym_PERCENT] = ACTIONS(4672),
    [anon_sym_CARET] = ACTIONS(4672),
    [anon_sym_PIPE] = ACTIONS(4672),
    [anon_sym_AMP] = ACTIONS(4672),
    [anon_sym_LT_LT] = ACTIONS(4672),
    [anon_sym_GT_GT] = ACTIONS(4672),
    [anon_sym_GT_GT_GT] = ACTIONS(4672),
    [anon_sym_EQ_EQ] = ACTIONS(4670),
    [anon_sym_BANG_EQ] = ACTIONS(4670),
    [anon_sym_GT_EQ] = ACTIONS(4670),
    [anon_sym_LT_EQ] = ACTIONS(4670),
    [anon_sym_DOT] = ACTIONS(4672),
    [anon_sym_switch] = ACTIONS(4670),
    [anon_sym_DOT_DOT] = ACTIONS(4670),
    [anon_sym_and] = ACTIONS(4670),
    [anon_sym_or] = ACTIONS(4670),
    [anon_sym_PLUS_EQ] = ACTIONS(4670),
    [anon_sym_DASH_EQ] = ACTIONS(4670),
    [anon_sym_STAR_EQ] = ACTIONS(4670),
    [anon_sym_SLASH_EQ] = ACTIONS(4670),
    [anon_sym_PERCENT_EQ] = ACTIONS(4670),
    [anon_sym_AMP_EQ] = ACTIONS(4670),
    [anon_sym_CARET_EQ] = ACTIONS(4670),
    [anon_sym_PIPE_EQ] = ACTIONS(4670),
    [anon_sym_LT_LT_EQ] = ACTIONS(4670),
    [anon_sym_GT_GT_EQ] = ACTIONS(4670),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4670),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4670),
    [anon_sym_AMP_AMP] = ACTIONS(4670),
    [anon_sym_PIPE_PIPE] = ACTIONS(4670),
    [anon_sym_QMARK_QMARK] = ACTIONS(4672),
    [anon_sym_into] = ACTIONS(4670),
    [anon_sym_as] = ACTIONS(4670),
    [anon_sym_is] = ACTIONS(4670),
    [anon_sym_DASH_GT] = ACTIONS(4670),
    [anon_sym_with] = ACTIONS(4670),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4670),
  },
  [3907] = {
    [sym_preproc_region] = STATE(3907),
    [sym_preproc_endregion] = STATE(3907),
    [sym_preproc_line] = STATE(3907),
    [sym_preproc_pragma] = STATE(3907),
    [sym_preproc_nullable] = STATE(3907),
    [sym_preproc_error] = STATE(3907),
    [sym_preproc_warning] = STATE(3907),
    [sym_preproc_define] = STATE(3907),
    [sym_preproc_undef] = STATE(3907),
    [anon_sym_SEMI] = ACTIONS(3993),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_COLON] = ACTIONS(3995),
    [anon_sym_COMMA] = ACTIONS(3993),
    [anon_sym_RBRACK] = ACTIONS(3993),
    [anon_sym_LPAREN] = ACTIONS(3993),
    [anon_sym_RPAREN] = ACTIONS(3993),
    [anon_sym_LBRACE] = ACTIONS(3993),
    [anon_sym_RBRACE] = ACTIONS(3993),
    [anon_sym_LT] = ACTIONS(3995),
    [anon_sym_GT] = ACTIONS(3995),
    [anon_sym_in] = ACTIONS(3993),
    [anon_sym_QMARK] = ACTIONS(3995),
    [anon_sym_BANG] = ACTIONS(3995),
    [anon_sym_PLUS_PLUS] = ACTIONS(3993),
    [anon_sym_DASH_DASH] = ACTIONS(3993),
    [anon_sym_PLUS] = ACTIONS(3995),
    [anon_sym_DASH] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3993),
    [anon_sym_SLASH] = ACTIONS(3995),
    [anon_sym_PERCENT] = ACTIONS(3993),
    [anon_sym_CARET] = ACTIONS(3993),
    [anon_sym_PIPE] = ACTIONS(3995),
    [anon_sym_AMP] = ACTIONS(3995),
    [anon_sym_LT_LT] = ACTIONS(3993),
    [anon_sym_GT_GT] = ACTIONS(3995),
    [anon_sym_GT_GT_GT] = ACTIONS(3993),
    [anon_sym_EQ_EQ] = ACTIONS(3993),
    [anon_sym_BANG_EQ] = ACTIONS(3993),
    [anon_sym_GT_EQ] = ACTIONS(3993),
    [anon_sym_LT_EQ] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3995),
    [anon_sym_EQ_GT] = ACTIONS(3993),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_switch] = ACTIONS(3993),
    [anon_sym_when] = ACTIONS(3993),
    [anon_sym_DOT_DOT] = ACTIONS(3993),
    [anon_sym_and] = ACTIONS(3993),
    [anon_sym_or] = ACTIONS(3993),
    [anon_sym_AMP_AMP] = ACTIONS(3993),
    [anon_sym_PIPE_PIPE] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK] = ACTIONS(3993),
    [anon_sym_on] = ACTIONS(3993),
    [anon_sym_equals] = ACTIONS(3993),
    [anon_sym_by] = ACTIONS(3993),
    [anon_sym_as] = ACTIONS(3993),
    [anon_sym_is] = ACTIONS(3993),
    [anon_sym_DASH_GT] = ACTIONS(3993),
    [anon_sym_with] = ACTIONS(3993),
    [aux_sym_preproc_if_token3] = ACTIONS(3993),
    [aux_sym_preproc_else_token1] = ACTIONS(3993),
    [aux_sym_preproc_elif_token1] = ACTIONS(3993),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3908] = {
    [sym_preproc_region] = STATE(3908),
    [sym_preproc_endregion] = STATE(3908),
    [sym_preproc_line] = STATE(3908),
    [sym_preproc_pragma] = STATE(3908),
    [sym_preproc_nullable] = STATE(3908),
    [sym_preproc_error] = STATE(3908),
    [sym_preproc_warning] = STATE(3908),
    [sym_preproc_define] = STATE(3908),
    [sym_preproc_undef] = STATE(3908),
    [anon_sym_SEMI] = ACTIONS(5378),
    [anon_sym_LBRACK] = ACTIONS(5378),
    [anon_sym_COLON] = ACTIONS(5378),
    [anon_sym_COMMA] = ACTIONS(5378),
    [anon_sym_RBRACK] = ACTIONS(5378),
    [anon_sym_LPAREN] = ACTIONS(5378),
    [anon_sym_RPAREN] = ACTIONS(5378),
    [anon_sym_LBRACE] = ACTIONS(5378),
    [anon_sym_RBRACE] = ACTIONS(5378),
    [anon_sym_LT] = ACTIONS(5380),
    [anon_sym_GT] = ACTIONS(5380),
    [anon_sym_in] = ACTIONS(5378),
    [anon_sym_where] = ACTIONS(5378),
    [anon_sym_QMARK] = ACTIONS(5380),
    [anon_sym_BANG] = ACTIONS(5380),
    [anon_sym_PLUS_PLUS] = ACTIONS(5378),
    [anon_sym_DASH_DASH] = ACTIONS(5378),
    [anon_sym_PLUS] = ACTIONS(5380),
    [anon_sym_DASH] = ACTIONS(5380),
    [anon_sym_STAR] = ACTIONS(5378),
    [anon_sym_SLASH] = ACTIONS(5380),
    [anon_sym_PERCENT] = ACTIONS(5378),
    [anon_sym_CARET] = ACTIONS(5378),
    [anon_sym_PIPE] = ACTIONS(5380),
    [anon_sym_AMP] = ACTIONS(5380),
    [anon_sym_LT_LT] = ACTIONS(5378),
    [anon_sym_GT_GT] = ACTIONS(5380),
    [anon_sym_GT_GT_GT] = ACTIONS(5378),
    [anon_sym_EQ_EQ] = ACTIONS(5378),
    [anon_sym_BANG_EQ] = ACTIONS(5378),
    [anon_sym_GT_EQ] = ACTIONS(5378),
    [anon_sym_LT_EQ] = ACTIONS(5378),
    [anon_sym_DOT] = ACTIONS(5380),
    [anon_sym_EQ_GT] = ACTIONS(5378),
    [anon_sym_switch] = ACTIONS(5378),
    [anon_sym_when] = ACTIONS(5378),
    [anon_sym_DOT_DOT] = ACTIONS(5378),
    [anon_sym_and] = ACTIONS(5378),
    [anon_sym_or] = ACTIONS(5378),
    [anon_sym_AMP_AMP] = ACTIONS(5378),
    [anon_sym_PIPE_PIPE] = ACTIONS(5378),
    [anon_sym_QMARK_QMARK] = ACTIONS(5378),
    [anon_sym_on] = ACTIONS(5378),
    [anon_sym_equals] = ACTIONS(5378),
    [anon_sym_by] = ACTIONS(5378),
    [anon_sym_as] = ACTIONS(5378),
    [anon_sym_is] = ACTIONS(5378),
    [anon_sym_DASH_GT] = ACTIONS(5378),
    [anon_sym_with] = ACTIONS(5378),
    [aux_sym_preproc_if_token3] = ACTIONS(5378),
    [aux_sym_preproc_else_token1] = ACTIONS(5378),
    [aux_sym_preproc_elif_token1] = ACTIONS(5378),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3909] = {
    [sym_preproc_region] = STATE(3909),
    [sym_preproc_endregion] = STATE(3909),
    [sym_preproc_line] = STATE(3909),
    [sym_preproc_pragma] = STATE(3909),
    [sym_preproc_nullable] = STATE(3909),
    [sym_preproc_error] = STATE(3909),
    [sym_preproc_warning] = STATE(3909),
    [sym_preproc_define] = STATE(3909),
    [sym_preproc_undef] = STATE(3909),
    [anon_sym_SEMI] = ACTIONS(4128),
    [anon_sym_LBRACK] = ACTIONS(4128),
    [anon_sym_COLON] = ACTIONS(4128),
    [anon_sym_COMMA] = ACTIONS(4128),
    [anon_sym_RBRACK] = ACTIONS(4128),
    [anon_sym_LPAREN] = ACTIONS(4128),
    [anon_sym_RPAREN] = ACTIONS(4128),
    [anon_sym_LBRACE] = ACTIONS(4128),
    [anon_sym_RBRACE] = ACTIONS(4128),
    [anon_sym_LT] = ACTIONS(4126),
    [anon_sym_GT] = ACTIONS(4126),
    [anon_sym_in] = ACTIONS(4126),
    [anon_sym_QMARK] = ACTIONS(4126),
    [anon_sym_BANG] = ACTIONS(4126),
    [anon_sym_PLUS_PLUS] = ACTIONS(4128),
    [anon_sym_DASH_DASH] = ACTIONS(4128),
    [anon_sym_PLUS] = ACTIONS(4126),
    [anon_sym_DASH] = ACTIONS(4126),
    [anon_sym_STAR] = ACTIONS(4128),
    [anon_sym_SLASH] = ACTIONS(4126),
    [anon_sym_PERCENT] = ACTIONS(4128),
    [anon_sym_CARET] = ACTIONS(4128),
    [anon_sym_PIPE] = ACTIONS(4126),
    [anon_sym_AMP] = ACTIONS(4126),
    [anon_sym_LT_LT] = ACTIONS(4128),
    [anon_sym_GT_GT] = ACTIONS(4126),
    [anon_sym_GT_GT_GT] = ACTIONS(4128),
    [anon_sym_EQ_EQ] = ACTIONS(4128),
    [anon_sym_BANG_EQ] = ACTIONS(4128),
    [anon_sym_GT_EQ] = ACTIONS(4128),
    [anon_sym_LT_EQ] = ACTIONS(4128),
    [anon_sym_DOT] = ACTIONS(4126),
    [anon_sym_EQ_GT] = ACTIONS(4128),
    [anon_sym_switch] = ACTIONS(4128),
    [anon_sym_when] = ACTIONS(4128),
    [anon_sym_DOT_DOT] = ACTIONS(4128),
    [anon_sym_and] = ACTIONS(4128),
    [anon_sym_or] = ACTIONS(4128),
    [anon_sym_AMP_AMP] = ACTIONS(4128),
    [anon_sym_PIPE_PIPE] = ACTIONS(4128),
    [anon_sym_QMARK_QMARK] = ACTIONS(4128),
    [anon_sym_into] = ACTIONS(4128),
    [anon_sym_on] = ACTIONS(4128),
    [anon_sym_equals] = ACTIONS(4128),
    [anon_sym_by] = ACTIONS(4128),
    [anon_sym_as] = ACTIONS(4128),
    [anon_sym_is] = ACTIONS(4128),
    [anon_sym_DASH_GT] = ACTIONS(4128),
    [anon_sym_with] = ACTIONS(4128),
    [aux_sym_preproc_if_token3] = ACTIONS(4128),
    [aux_sym_preproc_else_token1] = ACTIONS(4128),
    [aux_sym_preproc_elif_token1] = ACTIONS(4128),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3910] = {
    [sym_preproc_region] = STATE(3910),
    [sym_preproc_endregion] = STATE(3910),
    [sym_preproc_line] = STATE(3910),
    [sym_preproc_pragma] = STATE(3910),
    [sym_preproc_nullable] = STATE(3910),
    [sym_preproc_error] = STATE(3910),
    [sym_preproc_warning] = STATE(3910),
    [sym_preproc_define] = STATE(3910),
    [sym_preproc_undef] = STATE(3910),
    [anon_sym_SEMI] = ACTIONS(4136),
    [anon_sym_LBRACK] = ACTIONS(4136),
    [anon_sym_COLON] = ACTIONS(4136),
    [anon_sym_COMMA] = ACTIONS(4136),
    [anon_sym_RBRACK] = ACTIONS(4136),
    [anon_sym_LPAREN] = ACTIONS(4136),
    [anon_sym_RPAREN] = ACTIONS(4136),
    [anon_sym_LBRACE] = ACTIONS(4136),
    [anon_sym_RBRACE] = ACTIONS(4136),
    [anon_sym_LT] = ACTIONS(4134),
    [anon_sym_GT] = ACTIONS(4134),
    [anon_sym_in] = ACTIONS(4134),
    [anon_sym_QMARK] = ACTIONS(4134),
    [anon_sym_BANG] = ACTIONS(4134),
    [anon_sym_PLUS_PLUS] = ACTIONS(4136),
    [anon_sym_DASH_DASH] = ACTIONS(4136),
    [anon_sym_PLUS] = ACTIONS(4134),
    [anon_sym_DASH] = ACTIONS(4134),
    [anon_sym_STAR] = ACTIONS(4136),
    [anon_sym_SLASH] = ACTIONS(4134),
    [anon_sym_PERCENT] = ACTIONS(4136),
    [anon_sym_CARET] = ACTIONS(4136),
    [anon_sym_PIPE] = ACTIONS(4134),
    [anon_sym_AMP] = ACTIONS(4134),
    [anon_sym_LT_LT] = ACTIONS(4136),
    [anon_sym_GT_GT] = ACTIONS(4134),
    [anon_sym_GT_GT_GT] = ACTIONS(4136),
    [anon_sym_EQ_EQ] = ACTIONS(4136),
    [anon_sym_BANG_EQ] = ACTIONS(4136),
    [anon_sym_GT_EQ] = ACTIONS(4136),
    [anon_sym_LT_EQ] = ACTIONS(4136),
    [anon_sym_DOT] = ACTIONS(4134),
    [anon_sym_EQ_GT] = ACTIONS(4136),
    [anon_sym_switch] = ACTIONS(4136),
    [anon_sym_when] = ACTIONS(4136),
    [anon_sym_DOT_DOT] = ACTIONS(4136),
    [anon_sym_and] = ACTIONS(4136),
    [anon_sym_or] = ACTIONS(4136),
    [anon_sym_AMP_AMP] = ACTIONS(4136),
    [anon_sym_PIPE_PIPE] = ACTIONS(4136),
    [anon_sym_QMARK_QMARK] = ACTIONS(4136),
    [anon_sym_into] = ACTIONS(4136),
    [anon_sym_on] = ACTIONS(4136),
    [anon_sym_equals] = ACTIONS(4136),
    [anon_sym_by] = ACTIONS(4136),
    [anon_sym_as] = ACTIONS(4136),
    [anon_sym_is] = ACTIONS(4136),
    [anon_sym_DASH_GT] = ACTIONS(4136),
    [anon_sym_with] = ACTIONS(4136),
    [aux_sym_preproc_if_token3] = ACTIONS(4136),
    [aux_sym_preproc_else_token1] = ACTIONS(4136),
    [aux_sym_preproc_elif_token1] = ACTIONS(4136),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3911] = {
    [sym_preproc_region] = STATE(3911),
    [sym_preproc_endregion] = STATE(3911),
    [sym_preproc_line] = STATE(3911),
    [sym_preproc_pragma] = STATE(3911),
    [sym_preproc_nullable] = STATE(3911),
    [sym_preproc_error] = STATE(3911),
    [sym_preproc_warning] = STATE(3911),
    [sym_preproc_define] = STATE(3911),
    [sym_preproc_undef] = STATE(3911),
    [anon_sym_SEMI] = ACTIONS(4124),
    [anon_sym_LBRACK] = ACTIONS(4124),
    [anon_sym_COLON] = ACTIONS(4122),
    [anon_sym_COMMA] = ACTIONS(4124),
    [anon_sym_RBRACK] = ACTIONS(4124),
    [anon_sym_LPAREN] = ACTIONS(4124),
    [anon_sym_RPAREN] = ACTIONS(4124),
    [anon_sym_LBRACE] = ACTIONS(4124),
    [anon_sym_RBRACE] = ACTIONS(4124),
    [anon_sym_LT] = ACTIONS(4122),
    [anon_sym_GT] = ACTIONS(4122),
    [anon_sym_in] = ACTIONS(4124),
    [anon_sym_QMARK] = ACTIONS(4122),
    [anon_sym_BANG] = ACTIONS(4122),
    [anon_sym_PLUS_PLUS] = ACTIONS(4124),
    [anon_sym_DASH_DASH] = ACTIONS(4124),
    [anon_sym_PLUS] = ACTIONS(4122),
    [anon_sym_DASH] = ACTIONS(4122),
    [anon_sym_STAR] = ACTIONS(4124),
    [anon_sym_SLASH] = ACTIONS(4122),
    [anon_sym_PERCENT] = ACTIONS(4124),
    [anon_sym_CARET] = ACTIONS(4124),
    [anon_sym_PIPE] = ACTIONS(4122),
    [anon_sym_AMP] = ACTIONS(4122),
    [anon_sym_LT_LT] = ACTIONS(4124),
    [anon_sym_GT_GT] = ACTIONS(4122),
    [anon_sym_GT_GT_GT] = ACTIONS(4124),
    [anon_sym_EQ_EQ] = ACTIONS(4124),
    [anon_sym_BANG_EQ] = ACTIONS(4124),
    [anon_sym_GT_EQ] = ACTIONS(4124),
    [anon_sym_LT_EQ] = ACTIONS(4124),
    [anon_sym_DOT] = ACTIONS(4122),
    [anon_sym_EQ_GT] = ACTIONS(4124),
    [anon_sym_COLON_COLON] = ACTIONS(4124),
    [anon_sym_switch] = ACTIONS(4124),
    [anon_sym_when] = ACTIONS(4124),
    [anon_sym_DOT_DOT] = ACTIONS(4124),
    [anon_sym_and] = ACTIONS(4124),
    [anon_sym_or] = ACTIONS(4124),
    [anon_sym_AMP_AMP] = ACTIONS(4124),
    [anon_sym_PIPE_PIPE] = ACTIONS(4124),
    [anon_sym_QMARK_QMARK] = ACTIONS(4124),
    [anon_sym_on] = ACTIONS(4124),
    [anon_sym_equals] = ACTIONS(4124),
    [anon_sym_by] = ACTIONS(4124),
    [anon_sym_as] = ACTIONS(4124),
    [anon_sym_is] = ACTIONS(4124),
    [anon_sym_DASH_GT] = ACTIONS(4124),
    [anon_sym_with] = ACTIONS(4124),
    [aux_sym_preproc_if_token3] = ACTIONS(4124),
    [aux_sym_preproc_else_token1] = ACTIONS(4124),
    [aux_sym_preproc_elif_token1] = ACTIONS(4124),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3912] = {
    [sym_preproc_region] = STATE(3912),
    [sym_preproc_endregion] = STATE(3912),
    [sym_preproc_line] = STATE(3912),
    [sym_preproc_pragma] = STATE(3912),
    [sym_preproc_nullable] = STATE(3912),
    [sym_preproc_error] = STATE(3912),
    [sym_preproc_warning] = STATE(3912),
    [sym_preproc_define] = STATE(3912),
    [sym_preproc_undef] = STATE(3912),
    [anon_sym_SEMI] = ACTIONS(4455),
    [anon_sym_LBRACK] = ACTIONS(4455),
    [anon_sym_COLON] = ACTIONS(4455),
    [anon_sym_COMMA] = ACTIONS(4455),
    [anon_sym_RBRACK] = ACTIONS(4455),
    [anon_sym_LPAREN] = ACTIONS(4455),
    [anon_sym_RPAREN] = ACTIONS(4455),
    [anon_sym_LBRACE] = ACTIONS(4455),
    [anon_sym_RBRACE] = ACTIONS(4455),
    [anon_sym_LT] = ACTIONS(4453),
    [anon_sym_GT] = ACTIONS(4453),
    [anon_sym_in] = ACTIONS(4453),
    [anon_sym_QMARK] = ACTIONS(4453),
    [anon_sym_BANG] = ACTIONS(4453),
    [anon_sym_PLUS_PLUS] = ACTIONS(4455),
    [anon_sym_DASH_DASH] = ACTIONS(4455),
    [anon_sym_PLUS] = ACTIONS(4453),
    [anon_sym_DASH] = ACTIONS(4453),
    [anon_sym_STAR] = ACTIONS(4455),
    [anon_sym_SLASH] = ACTIONS(4453),
    [anon_sym_PERCENT] = ACTIONS(4455),
    [anon_sym_CARET] = ACTIONS(4455),
    [anon_sym_PIPE] = ACTIONS(4453),
    [anon_sym_AMP] = ACTIONS(4453),
    [anon_sym_LT_LT] = ACTIONS(4455),
    [anon_sym_GT_GT] = ACTIONS(4453),
    [anon_sym_GT_GT_GT] = ACTIONS(4455),
    [anon_sym_EQ_EQ] = ACTIONS(4455),
    [anon_sym_BANG_EQ] = ACTIONS(4455),
    [anon_sym_GT_EQ] = ACTIONS(4455),
    [anon_sym_LT_EQ] = ACTIONS(4455),
    [anon_sym_DOT] = ACTIONS(5826),
    [anon_sym_EQ_GT] = ACTIONS(4455),
    [anon_sym_switch] = ACTIONS(4455),
    [anon_sym_when] = ACTIONS(4455),
    [anon_sym_DOT_DOT] = ACTIONS(4455),
    [anon_sym_and] = ACTIONS(4455),
    [anon_sym_or] = ACTIONS(4455),
    [anon_sym_AMP_AMP] = ACTIONS(4455),
    [anon_sym_PIPE_PIPE] = ACTIONS(4455),
    [anon_sym_QMARK_QMARK] = ACTIONS(4455),
    [anon_sym_into] = ACTIONS(4455),
    [anon_sym_on] = ACTIONS(4455),
    [anon_sym_equals] = ACTIONS(4455),
    [anon_sym_by] = ACTIONS(4455),
    [anon_sym_as] = ACTIONS(4455),
    [anon_sym_is] = ACTIONS(4455),
    [anon_sym_DASH_GT] = ACTIONS(4455),
    [anon_sym_with] = ACTIONS(4455),
    [aux_sym_preproc_if_token3] = ACTIONS(4455),
    [aux_sym_preproc_else_token1] = ACTIONS(4455),
    [aux_sym_preproc_elif_token1] = ACTIONS(4455),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3913] = {
    [sym_preproc_region] = STATE(3913),
    [sym_preproc_endregion] = STATE(3913),
    [sym_preproc_line] = STATE(3913),
    [sym_preproc_pragma] = STATE(3913),
    [sym_preproc_nullable] = STATE(3913),
    [sym_preproc_error] = STATE(3913),
    [sym_preproc_warning] = STATE(3913),
    [sym_preproc_define] = STATE(3913),
    [sym_preproc_undef] = STATE(3913),
    [anon_sym_SEMI] = ACTIONS(5382),
    [anon_sym_LBRACK] = ACTIONS(5382),
    [anon_sym_COLON] = ACTIONS(5382),
    [anon_sym_COMMA] = ACTIONS(5382),
    [anon_sym_RBRACK] = ACTIONS(5382),
    [anon_sym_LPAREN] = ACTIONS(5382),
    [anon_sym_RPAREN] = ACTIONS(5382),
    [anon_sym_RBRACE] = ACTIONS(5382),
    [anon_sym_LT] = ACTIONS(5384),
    [anon_sym_GT] = ACTIONS(5384),
    [anon_sym_in] = ACTIONS(5382),
    [anon_sym_QMARK] = ACTIONS(5384),
    [anon_sym_BANG] = ACTIONS(5384),
    [anon_sym_PLUS_PLUS] = ACTIONS(5382),
    [anon_sym_DASH_DASH] = ACTIONS(5382),
    [anon_sym_PLUS] = ACTIONS(5384),
    [anon_sym_DASH] = ACTIONS(5384),
    [anon_sym_STAR] = ACTIONS(5382),
    [anon_sym_SLASH] = ACTIONS(5384),
    [anon_sym_PERCENT] = ACTIONS(5382),
    [anon_sym_CARET] = ACTIONS(5382),
    [anon_sym_PIPE] = ACTIONS(5384),
    [anon_sym_AMP] = ACTIONS(5384),
    [anon_sym_LT_LT] = ACTIONS(5382),
    [anon_sym_GT_GT] = ACTIONS(5384),
    [anon_sym_GT_GT_GT] = ACTIONS(5382),
    [anon_sym_EQ_EQ] = ACTIONS(5382),
    [anon_sym_BANG_EQ] = ACTIONS(5382),
    [anon_sym_GT_EQ] = ACTIONS(5382),
    [anon_sym_LT_EQ] = ACTIONS(5382),
    [anon_sym_DOT] = ACTIONS(5384),
    [anon_sym_EQ_GT] = ACTIONS(5382),
    [anon_sym_switch] = ACTIONS(5382),
    [anon_sym_when] = ACTIONS(5382),
    [anon_sym_DOT_DOT] = ACTIONS(5382),
    [anon_sym_and] = ACTIONS(5382),
    [anon_sym_or] = ACTIONS(5382),
    [anon_sym_AMP_AMP] = ACTIONS(5382),
    [anon_sym_PIPE_PIPE] = ACTIONS(5382),
    [anon_sym_QMARK_QMARK] = ACTIONS(5382),
    [anon_sym_on] = ACTIONS(5382),
    [anon_sym_equals] = ACTIONS(5382),
    [anon_sym_by] = ACTIONS(5382),
    [anon_sym_as] = ACTIONS(5382),
    [anon_sym_is] = ACTIONS(5382),
    [anon_sym_DASH_GT] = ACTIONS(5382),
    [anon_sym_with] = ACTIONS(5382),
    [anon_sym_DQUOTE] = ACTIONS(5382),
    [sym_string_literal_encoding] = ACTIONS(5828),
    [aux_sym_preproc_if_token3] = ACTIONS(5382),
    [aux_sym_preproc_else_token1] = ACTIONS(5382),
    [aux_sym_preproc_elif_token1] = ACTIONS(5382),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3914] = {
    [sym_preproc_region] = STATE(3914),
    [sym_preproc_endregion] = STATE(3914),
    [sym_preproc_line] = STATE(3914),
    [sym_preproc_pragma] = STATE(3914),
    [sym_preproc_nullable] = STATE(3914),
    [sym_preproc_error] = STATE(3914),
    [sym_preproc_warning] = STATE(3914),
    [sym_preproc_define] = STATE(3914),
    [sym_preproc_undef] = STATE(3914),
    [anon_sym_SEMI] = ACTIONS(5378),
    [anon_sym_LBRACK] = ACTIONS(5378),
    [anon_sym_COLON] = ACTIONS(5378),
    [anon_sym_COMMA] = ACTIONS(5378),
    [anon_sym_RBRACK] = ACTIONS(5378),
    [anon_sym_LPAREN] = ACTIONS(5378),
    [anon_sym_RPAREN] = ACTIONS(5378),
    [anon_sym_LBRACE] = ACTIONS(5378),
    [anon_sym_RBRACE] = ACTIONS(5378),
    [anon_sym_LT] = ACTIONS(5380),
    [anon_sym_GT] = ACTIONS(5380),
    [anon_sym_in] = ACTIONS(5380),
    [anon_sym_QMARK] = ACTIONS(5380),
    [anon_sym_BANG] = ACTIONS(5380),
    [anon_sym_PLUS_PLUS] = ACTIONS(5378),
    [anon_sym_DASH_DASH] = ACTIONS(5378),
    [anon_sym_PLUS] = ACTIONS(5380),
    [anon_sym_DASH] = ACTIONS(5380),
    [anon_sym_STAR] = ACTIONS(5378),
    [anon_sym_SLASH] = ACTIONS(5380),
    [anon_sym_PERCENT] = ACTIONS(5378),
    [anon_sym_CARET] = ACTIONS(5378),
    [anon_sym_PIPE] = ACTIONS(5380),
    [anon_sym_AMP] = ACTIONS(5380),
    [anon_sym_LT_LT] = ACTIONS(5378),
    [anon_sym_GT_GT] = ACTIONS(5380),
    [anon_sym_GT_GT_GT] = ACTIONS(5378),
    [anon_sym_EQ_EQ] = ACTIONS(5378),
    [anon_sym_BANG_EQ] = ACTIONS(5378),
    [anon_sym_GT_EQ] = ACTIONS(5378),
    [anon_sym_LT_EQ] = ACTIONS(5378),
    [anon_sym_DOT] = ACTIONS(5380),
    [anon_sym_EQ_GT] = ACTIONS(5378),
    [anon_sym_switch] = ACTIONS(5378),
    [anon_sym_when] = ACTIONS(5378),
    [anon_sym_DOT_DOT] = ACTIONS(5378),
    [anon_sym_and] = ACTIONS(5378),
    [anon_sym_or] = ACTIONS(5378),
    [anon_sym_AMP_AMP] = ACTIONS(5378),
    [anon_sym_PIPE_PIPE] = ACTIONS(5378),
    [anon_sym_QMARK_QMARK] = ACTIONS(5378),
    [anon_sym_into] = ACTIONS(5378),
    [anon_sym_on] = ACTIONS(5378),
    [anon_sym_equals] = ACTIONS(5378),
    [anon_sym_by] = ACTIONS(5378),
    [anon_sym_as] = ACTIONS(5378),
    [anon_sym_is] = ACTIONS(5378),
    [anon_sym_DASH_GT] = ACTIONS(5378),
    [anon_sym_with] = ACTIONS(5378),
    [aux_sym_preproc_if_token3] = ACTIONS(5378),
    [aux_sym_preproc_else_token1] = ACTIONS(5378),
    [aux_sym_preproc_elif_token1] = ACTIONS(5378),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3915] = {
    [sym_preproc_region] = STATE(3915),
    [sym_preproc_endregion] = STATE(3915),
    [sym_preproc_line] = STATE(3915),
    [sym_preproc_pragma] = STATE(3915),
    [sym_preproc_nullable] = STATE(3915),
    [sym_preproc_error] = STATE(3915),
    [sym_preproc_warning] = STATE(3915),
    [sym_preproc_define] = STATE(3915),
    [sym_preproc_undef] = STATE(3915),
    [sym__identifier_token] = ACTIONS(4039),
    [anon_sym_extern] = ACTIONS(4042),
    [anon_sym_alias] = ACTIONS(4039),
    [anon_sym_global] = ACTIONS(4039),
    [anon_sym_unsafe] = ACTIONS(4042),
    [anon_sym_static] = ACTIONS(4042),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_LPAREN] = ACTIONS(5474),
    [anon_sym_ref] = ACTIONS(4042),
    [anon_sym_delegate] = ACTIONS(4042),
    [anon_sym_abstract] = ACTIONS(4042),
    [anon_sym_async] = ACTIONS(4042),
    [anon_sym_const] = ACTIONS(4042),
    [anon_sym_file] = ACTIONS(4039),
    [anon_sym_fixed] = ACTIONS(4042),
    [anon_sym_internal] = ACTIONS(4042),
    [anon_sym_new] = ACTIONS(4042),
    [anon_sym_override] = ACTIONS(4042),
    [anon_sym_partial] = ACTIONS(4042),
    [anon_sym_private] = ACTIONS(4042),
    [anon_sym_protected] = ACTIONS(4042),
    [anon_sym_public] = ACTIONS(4042),
    [anon_sym_readonly] = ACTIONS(4042),
    [anon_sym_required] = ACTIONS(4042),
    [anon_sym_sealed] = ACTIONS(4042),
    [anon_sym_virtual] = ACTIONS(4042),
    [anon_sym_volatile] = ACTIONS(4042),
    [anon_sym_LT] = ACTIONS(3993),
    [anon_sym_where] = ACTIONS(4039),
    [anon_sym_QMARK] = ACTIONS(3993),
    [anon_sym_notnull] = ACTIONS(4039),
    [anon_sym_unmanaged] = ACTIONS(4039),
    [anon_sym_STAR] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3993),
    [anon_sym_scoped] = ACTIONS(4039),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(4039),
    [sym_predefined_type] = ACTIONS(4042),
    [anon_sym_yield] = ACTIONS(4039),
    [anon_sym_when] = ACTIONS(4039),
    [anon_sym_from] = ACTIONS(4039),
    [anon_sym_into] = ACTIONS(4039),
    [anon_sym_join] = ACTIONS(4039),
    [anon_sym_on] = ACTIONS(4039),
    [anon_sym_equals] = ACTIONS(4039),
    [anon_sym_let] = ACTIONS(4039),
    [anon_sym_orderby] = ACTIONS(4039),
    [anon_sym_ascending] = ACTIONS(4039),
    [anon_sym_descending] = ACTIONS(4039),
    [anon_sym_group] = ACTIONS(4039),
    [anon_sym_by] = ACTIONS(4039),
    [anon_sym_select] = ACTIONS(4039),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3916] = {
    [sym_preproc_region] = STATE(3916),
    [sym_preproc_endregion] = STATE(3916),
    [sym_preproc_line] = STATE(3916),
    [sym_preproc_pragma] = STATE(3916),
    [sym_preproc_nullable] = STATE(3916),
    [sym_preproc_error] = STATE(3916),
    [sym_preproc_warning] = STATE(3916),
    [sym_preproc_define] = STATE(3916),
    [sym_preproc_undef] = STATE(3916),
    [anon_sym_SEMI] = ACTIONS(4468),
    [anon_sym_LBRACK] = ACTIONS(4468),
    [anon_sym_COLON] = ACTIONS(4468),
    [anon_sym_COMMA] = ACTIONS(4468),
    [anon_sym_RBRACK] = ACTIONS(4468),
    [anon_sym_LPAREN] = ACTIONS(4468),
    [anon_sym_RPAREN] = ACTIONS(4468),
    [anon_sym_LBRACE] = ACTIONS(4468),
    [anon_sym_RBRACE] = ACTIONS(4468),
    [anon_sym_LT] = ACTIONS(4466),
    [anon_sym_GT] = ACTIONS(4466),
    [anon_sym_in] = ACTIONS(4466),
    [anon_sym_QMARK] = ACTIONS(4466),
    [anon_sym_BANG] = ACTIONS(4466),
    [anon_sym_PLUS_PLUS] = ACTIONS(4468),
    [anon_sym_DASH_DASH] = ACTIONS(4468),
    [anon_sym_PLUS] = ACTIONS(4466),
    [anon_sym_DASH] = ACTIONS(4466),
    [anon_sym_STAR] = ACTIONS(4468),
    [anon_sym_SLASH] = ACTIONS(4466),
    [anon_sym_PERCENT] = ACTIONS(4468),
    [anon_sym_CARET] = ACTIONS(4468),
    [anon_sym_PIPE] = ACTIONS(4466),
    [anon_sym_AMP] = ACTIONS(4466),
    [anon_sym_LT_LT] = ACTIONS(4468),
    [anon_sym_GT_GT] = ACTIONS(4466),
    [anon_sym_GT_GT_GT] = ACTIONS(4468),
    [anon_sym_EQ_EQ] = ACTIONS(4468),
    [anon_sym_BANG_EQ] = ACTIONS(4468),
    [anon_sym_GT_EQ] = ACTIONS(4468),
    [anon_sym_LT_EQ] = ACTIONS(4468),
    [anon_sym_DOT] = ACTIONS(4466),
    [anon_sym_EQ_GT] = ACTIONS(4468),
    [anon_sym_switch] = ACTIONS(4468),
    [anon_sym_when] = ACTIONS(4468),
    [anon_sym_DOT_DOT] = ACTIONS(4468),
    [anon_sym_and] = ACTIONS(4468),
    [anon_sym_or] = ACTIONS(4468),
    [anon_sym_AMP_AMP] = ACTIONS(4468),
    [anon_sym_PIPE_PIPE] = ACTIONS(4468),
    [anon_sym_QMARK_QMARK] = ACTIONS(4468),
    [anon_sym_into] = ACTIONS(4468),
    [anon_sym_on] = ACTIONS(4468),
    [anon_sym_equals] = ACTIONS(4468),
    [anon_sym_by] = ACTIONS(4468),
    [anon_sym_as] = ACTIONS(4468),
    [anon_sym_is] = ACTIONS(4468),
    [anon_sym_DASH_GT] = ACTIONS(4468),
    [anon_sym_with] = ACTIONS(4468),
    [aux_sym_preproc_if_token3] = ACTIONS(4468),
    [aux_sym_preproc_else_token1] = ACTIONS(4468),
    [aux_sym_preproc_elif_token1] = ACTIONS(4468),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3917] = {
    [sym_argument_list] = STATE(4293),
    [sym_bracketed_argument_list] = STATE(3507),
    [sym_preproc_region] = STATE(3917),
    [sym_preproc_endregion] = STATE(3917),
    [sym_preproc_line] = STATE(3917),
    [sym_preproc_pragma] = STATE(3917),
    [sym_preproc_nullable] = STATE(3917),
    [sym_preproc_error] = STATE(3917),
    [sym_preproc_warning] = STATE(3917),
    [sym_preproc_define] = STATE(3917),
    [sym_preproc_undef] = STATE(3917),
    [anon_sym_SEMI] = ACTIONS(5271),
    [anon_sym_LBRACK] = ACTIONS(5830),
    [anon_sym_COLON] = ACTIONS(5271),
    [anon_sym_COMMA] = ACTIONS(5271),
    [anon_sym_RBRACK] = ACTIONS(5271),
    [anon_sym_LPAREN] = ACTIONS(5776),
    [anon_sym_RPAREN] = ACTIONS(5271),
    [anon_sym_RBRACE] = ACTIONS(5271),
    [anon_sym_LT] = ACTIONS(5275),
    [anon_sym_GT] = ACTIONS(5275),
    [anon_sym_in] = ACTIONS(5271),
    [anon_sym_QMARK] = ACTIONS(5275),
    [anon_sym_BANG] = ACTIONS(5832),
    [anon_sym_PLUS_PLUS] = ACTIONS(5834),
    [anon_sym_DASH_DASH] = ACTIONS(5834),
    [anon_sym_PLUS] = ACTIONS(5275),
    [anon_sym_DASH] = ACTIONS(5275),
    [anon_sym_STAR] = ACTIONS(5271),
    [anon_sym_SLASH] = ACTIONS(5275),
    [anon_sym_PERCENT] = ACTIONS(5271),
    [anon_sym_CARET] = ACTIONS(5271),
    [anon_sym_PIPE] = ACTIONS(5275),
    [anon_sym_AMP] = ACTIONS(5275),
    [anon_sym_LT_LT] = ACTIONS(5271),
    [anon_sym_GT_GT] = ACTIONS(5275),
    [anon_sym_GT_GT_GT] = ACTIONS(5271),
    [anon_sym_EQ_EQ] = ACTIONS(5271),
    [anon_sym_BANG_EQ] = ACTIONS(5271),
    [anon_sym_GT_EQ] = ACTIONS(5271),
    [anon_sym_LT_EQ] = ACTIONS(5271),
    [anon_sym_DOT] = ACTIONS(4602),
    [anon_sym_EQ_GT] = ACTIONS(5271),
    [anon_sym_switch] = ACTIONS(5271),
    [anon_sym_when] = ACTIONS(5271),
    [anon_sym_DOT_DOT] = ACTIONS(5271),
    [anon_sym_and] = ACTIONS(5271),
    [anon_sym_or] = ACTIONS(5271),
    [anon_sym_AMP_AMP] = ACTIONS(5271),
    [anon_sym_PIPE_PIPE] = ACTIONS(5271),
    [anon_sym_QMARK_QMARK] = ACTIONS(5271),
    [anon_sym_on] = ACTIONS(5271),
    [anon_sym_equals] = ACTIONS(5271),
    [anon_sym_by] = ACTIONS(5271),
    [anon_sym_as] = ACTIONS(5271),
    [anon_sym_is] = ACTIONS(5271),
    [anon_sym_DASH_GT] = ACTIONS(4604),
    [anon_sym_with] = ACTIONS(5271),
    [aux_sym_preproc_if_token3] = ACTIONS(5271),
    [aux_sym_preproc_else_token1] = ACTIONS(5271),
    [aux_sym_preproc_elif_token1] = ACTIONS(5271),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3918] = {
    [sym_preproc_region] = STATE(3918),
    [sym_preproc_endregion] = STATE(3918),
    [sym_preproc_line] = STATE(3918),
    [sym_preproc_pragma] = STATE(3918),
    [sym_preproc_nullable] = STATE(3918),
    [sym_preproc_error] = STATE(3918),
    [sym_preproc_warning] = STATE(3918),
    [sym_preproc_define] = STATE(3918),
    [sym_preproc_undef] = STATE(3918),
    [anon_sym_SEMI] = ACTIONS(5353),
    [anon_sym_LBRACK] = ACTIONS(5353),
    [anon_sym_COLON] = ACTIONS(5353),
    [anon_sym_COMMA] = ACTIONS(5353),
    [anon_sym_RBRACK] = ACTIONS(5353),
    [anon_sym_LPAREN] = ACTIONS(5353),
    [anon_sym_RPAREN] = ACTIONS(5353),
    [anon_sym_LBRACE] = ACTIONS(5353),
    [anon_sym_RBRACE] = ACTIONS(5353),
    [anon_sym_LT] = ACTIONS(5355),
    [anon_sym_GT] = ACTIONS(5355),
    [anon_sym_in] = ACTIONS(5353),
    [anon_sym_where] = ACTIONS(5353),
    [anon_sym_QMARK] = ACTIONS(5355),
    [anon_sym_BANG] = ACTIONS(5355),
    [anon_sym_PLUS_PLUS] = ACTIONS(5353),
    [anon_sym_DASH_DASH] = ACTIONS(5353),
    [anon_sym_PLUS] = ACTIONS(5355),
    [anon_sym_DASH] = ACTIONS(5355),
    [anon_sym_STAR] = ACTIONS(5353),
    [anon_sym_SLASH] = ACTIONS(5355),
    [anon_sym_PERCENT] = ACTIONS(5353),
    [anon_sym_CARET] = ACTIONS(5353),
    [anon_sym_PIPE] = ACTIONS(5355),
    [anon_sym_AMP] = ACTIONS(5355),
    [anon_sym_LT_LT] = ACTIONS(5353),
    [anon_sym_GT_GT] = ACTIONS(5355),
    [anon_sym_GT_GT_GT] = ACTIONS(5353),
    [anon_sym_EQ_EQ] = ACTIONS(5353),
    [anon_sym_BANG_EQ] = ACTIONS(5353),
    [anon_sym_GT_EQ] = ACTIONS(5353),
    [anon_sym_LT_EQ] = ACTIONS(5353),
    [anon_sym_DOT] = ACTIONS(5355),
    [anon_sym_EQ_GT] = ACTIONS(5353),
    [anon_sym_switch] = ACTIONS(5353),
    [anon_sym_when] = ACTIONS(5353),
    [anon_sym_DOT_DOT] = ACTIONS(5353),
    [anon_sym_and] = ACTIONS(5353),
    [anon_sym_or] = ACTIONS(5353),
    [anon_sym_AMP_AMP] = ACTIONS(5353),
    [anon_sym_PIPE_PIPE] = ACTIONS(5353),
    [anon_sym_QMARK_QMARK] = ACTIONS(5353),
    [anon_sym_on] = ACTIONS(5353),
    [anon_sym_equals] = ACTIONS(5353),
    [anon_sym_by] = ACTIONS(5353),
    [anon_sym_as] = ACTIONS(5353),
    [anon_sym_is] = ACTIONS(5353),
    [anon_sym_DASH_GT] = ACTIONS(5353),
    [anon_sym_with] = ACTIONS(5353),
    [aux_sym_preproc_if_token3] = ACTIONS(5353),
    [aux_sym_preproc_else_token1] = ACTIONS(5353),
    [aux_sym_preproc_elif_token1] = ACTIONS(5353),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3919] = {
    [sym_preproc_region] = STATE(3919),
    [sym_preproc_endregion] = STATE(3919),
    [sym_preproc_line] = STATE(3919),
    [sym_preproc_pragma] = STATE(3919),
    [sym_preproc_nullable] = STATE(3919),
    [sym_preproc_error] = STATE(3919),
    [sym_preproc_warning] = STATE(3919),
    [sym_preproc_define] = STATE(3919),
    [sym_preproc_undef] = STATE(3919),
    [anon_sym_SEMI] = ACTIONS(4480),
    [anon_sym_LBRACK] = ACTIONS(4480),
    [anon_sym_COLON] = ACTIONS(4480),
    [anon_sym_COMMA] = ACTIONS(4480),
    [anon_sym_RBRACK] = ACTIONS(4480),
    [anon_sym_LPAREN] = ACTIONS(4480),
    [anon_sym_RPAREN] = ACTIONS(4480),
    [anon_sym_LBRACE] = ACTIONS(4480),
    [anon_sym_RBRACE] = ACTIONS(4480),
    [anon_sym_LT] = ACTIONS(4478),
    [anon_sym_GT] = ACTIONS(4478),
    [anon_sym_in] = ACTIONS(4478),
    [anon_sym_QMARK] = ACTIONS(4478),
    [anon_sym_BANG] = ACTIONS(4478),
    [anon_sym_PLUS_PLUS] = ACTIONS(4480),
    [anon_sym_DASH_DASH] = ACTIONS(4480),
    [anon_sym_PLUS] = ACTIONS(4478),
    [anon_sym_DASH] = ACTIONS(4478),
    [anon_sym_STAR] = ACTIONS(4480),
    [anon_sym_SLASH] = ACTIONS(4478),
    [anon_sym_PERCENT] = ACTIONS(4480),
    [anon_sym_CARET] = ACTIONS(4480),
    [anon_sym_PIPE] = ACTIONS(4478),
    [anon_sym_AMP] = ACTIONS(4478),
    [anon_sym_LT_LT] = ACTIONS(4480),
    [anon_sym_GT_GT] = ACTIONS(4478),
    [anon_sym_GT_GT_GT] = ACTIONS(4480),
    [anon_sym_EQ_EQ] = ACTIONS(4480),
    [anon_sym_BANG_EQ] = ACTIONS(4480),
    [anon_sym_GT_EQ] = ACTIONS(4480),
    [anon_sym_LT_EQ] = ACTIONS(4480),
    [anon_sym_DOT] = ACTIONS(4478),
    [anon_sym_EQ_GT] = ACTIONS(4480),
    [anon_sym_switch] = ACTIONS(4480),
    [anon_sym_when] = ACTIONS(4480),
    [anon_sym_DOT_DOT] = ACTIONS(4480),
    [anon_sym_and] = ACTIONS(4480),
    [anon_sym_or] = ACTIONS(4480),
    [anon_sym_AMP_AMP] = ACTIONS(4480),
    [anon_sym_PIPE_PIPE] = ACTIONS(4480),
    [anon_sym_QMARK_QMARK] = ACTIONS(4480),
    [anon_sym_into] = ACTIONS(4480),
    [anon_sym_on] = ACTIONS(4480),
    [anon_sym_equals] = ACTIONS(4480),
    [anon_sym_by] = ACTIONS(4480),
    [anon_sym_as] = ACTIONS(4480),
    [anon_sym_is] = ACTIONS(4480),
    [anon_sym_DASH_GT] = ACTIONS(4480),
    [anon_sym_with] = ACTIONS(4480),
    [aux_sym_preproc_if_token3] = ACTIONS(4480),
    [aux_sym_preproc_else_token1] = ACTIONS(4480),
    [aux_sym_preproc_elif_token1] = ACTIONS(4480),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3920] = {
    [sym_initializer_expression] = STATE(4325),
    [sym_preproc_region] = STATE(3920),
    [sym_preproc_endregion] = STATE(3920),
    [sym_preproc_line] = STATE(3920),
    [sym_preproc_pragma] = STATE(3920),
    [sym_preproc_nullable] = STATE(3920),
    [sym_preproc_error] = STATE(3920),
    [sym_preproc_warning] = STATE(3920),
    [sym_preproc_define] = STATE(3920),
    [sym_preproc_undef] = STATE(3920),
    [anon_sym_SEMI] = ACTIONS(5315),
    [anon_sym_LBRACK] = ACTIONS(5315),
    [anon_sym_COLON] = ACTIONS(5315),
    [anon_sym_COMMA] = ACTIONS(5315),
    [anon_sym_RBRACK] = ACTIONS(5315),
    [anon_sym_LPAREN] = ACTIONS(5315),
    [anon_sym_RPAREN] = ACTIONS(5315),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_RBRACE] = ACTIONS(5315),
    [anon_sym_LT] = ACTIONS(5317),
    [anon_sym_GT] = ACTIONS(5317),
    [anon_sym_in] = ACTIONS(5315),
    [anon_sym_QMARK] = ACTIONS(5317),
    [anon_sym_BANG] = ACTIONS(5317),
    [anon_sym_PLUS_PLUS] = ACTIONS(5315),
    [anon_sym_DASH_DASH] = ACTIONS(5315),
    [anon_sym_PLUS] = ACTIONS(5317),
    [anon_sym_DASH] = ACTIONS(5317),
    [anon_sym_STAR] = ACTIONS(5315),
    [anon_sym_SLASH] = ACTIONS(5317),
    [anon_sym_PERCENT] = ACTIONS(5315),
    [anon_sym_CARET] = ACTIONS(5315),
    [anon_sym_PIPE] = ACTIONS(5317),
    [anon_sym_AMP] = ACTIONS(5317),
    [anon_sym_LT_LT] = ACTIONS(5315),
    [anon_sym_GT_GT] = ACTIONS(5317),
    [anon_sym_GT_GT_GT] = ACTIONS(5315),
    [anon_sym_EQ_EQ] = ACTIONS(5315),
    [anon_sym_BANG_EQ] = ACTIONS(5315),
    [anon_sym_GT_EQ] = ACTIONS(5315),
    [anon_sym_LT_EQ] = ACTIONS(5315),
    [anon_sym_DOT] = ACTIONS(5317),
    [anon_sym_EQ_GT] = ACTIONS(5315),
    [anon_sym_switch] = ACTIONS(5315),
    [anon_sym_when] = ACTIONS(5315),
    [anon_sym_DOT_DOT] = ACTIONS(5315),
    [anon_sym_and] = ACTIONS(5315),
    [anon_sym_or] = ACTIONS(5315),
    [anon_sym_AMP_AMP] = ACTIONS(5315),
    [anon_sym_PIPE_PIPE] = ACTIONS(5315),
    [anon_sym_QMARK_QMARK] = ACTIONS(5315),
    [anon_sym_on] = ACTIONS(5315),
    [anon_sym_equals] = ACTIONS(5315),
    [anon_sym_by] = ACTIONS(5315),
    [anon_sym_as] = ACTIONS(5315),
    [anon_sym_is] = ACTIONS(5315),
    [anon_sym_DASH_GT] = ACTIONS(5315),
    [anon_sym_with] = ACTIONS(5315),
    [aux_sym_preproc_if_token3] = ACTIONS(5315),
    [aux_sym_preproc_else_token1] = ACTIONS(5315),
    [aux_sym_preproc_elif_token1] = ACTIONS(5315),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3921] = {
    [sym_preproc_region] = STATE(3921),
    [sym_preproc_endregion] = STATE(3921),
    [sym_preproc_line] = STATE(3921),
    [sym_preproc_pragma] = STATE(3921),
    [sym_preproc_nullable] = STATE(3921),
    [sym_preproc_error] = STATE(3921),
    [sym_preproc_warning] = STATE(3921),
    [sym_preproc_define] = STATE(3921),
    [sym_preproc_undef] = STATE(3921),
    [anon_sym_SEMI] = ACTIONS(4550),
    [anon_sym_LBRACK] = ACTIONS(4550),
    [anon_sym_COLON] = ACTIONS(4550),
    [anon_sym_COMMA] = ACTIONS(4550),
    [anon_sym_RBRACK] = ACTIONS(4550),
    [anon_sym_LPAREN] = ACTIONS(4550),
    [anon_sym_RPAREN] = ACTIONS(4550),
    [anon_sym_LBRACE] = ACTIONS(4550),
    [anon_sym_RBRACE] = ACTIONS(4550),
    [anon_sym_LT] = ACTIONS(4548),
    [anon_sym_GT] = ACTIONS(4548),
    [anon_sym_in] = ACTIONS(4548),
    [anon_sym_QMARK] = ACTIONS(4548),
    [anon_sym_BANG] = ACTIONS(4548),
    [anon_sym_PLUS_PLUS] = ACTIONS(4550),
    [anon_sym_DASH_DASH] = ACTIONS(4550),
    [anon_sym_PLUS] = ACTIONS(4548),
    [anon_sym_DASH] = ACTIONS(4548),
    [anon_sym_STAR] = ACTIONS(4550),
    [anon_sym_SLASH] = ACTIONS(4548),
    [anon_sym_PERCENT] = ACTIONS(4550),
    [anon_sym_CARET] = ACTIONS(4550),
    [anon_sym_PIPE] = ACTIONS(4548),
    [anon_sym_AMP] = ACTIONS(4548),
    [anon_sym_LT_LT] = ACTIONS(4550),
    [anon_sym_GT_GT] = ACTIONS(4548),
    [anon_sym_GT_GT_GT] = ACTIONS(4550),
    [anon_sym_EQ_EQ] = ACTIONS(4550),
    [anon_sym_BANG_EQ] = ACTIONS(4550),
    [anon_sym_GT_EQ] = ACTIONS(4550),
    [anon_sym_LT_EQ] = ACTIONS(4550),
    [anon_sym_DOT] = ACTIONS(4548),
    [anon_sym_EQ_GT] = ACTIONS(4550),
    [anon_sym_switch] = ACTIONS(4550),
    [anon_sym_when] = ACTIONS(4550),
    [anon_sym_DOT_DOT] = ACTIONS(4550),
    [anon_sym_and] = ACTIONS(4550),
    [anon_sym_or] = ACTIONS(4550),
    [anon_sym_AMP_AMP] = ACTIONS(4550),
    [anon_sym_PIPE_PIPE] = ACTIONS(4550),
    [anon_sym_QMARK_QMARK] = ACTIONS(4550),
    [anon_sym_into] = ACTIONS(4550),
    [anon_sym_on] = ACTIONS(4550),
    [anon_sym_equals] = ACTIONS(4550),
    [anon_sym_by] = ACTIONS(4550),
    [anon_sym_as] = ACTIONS(4550),
    [anon_sym_is] = ACTIONS(4550),
    [anon_sym_DASH_GT] = ACTIONS(4550),
    [anon_sym_with] = ACTIONS(4550),
    [aux_sym_preproc_if_token3] = ACTIONS(4550),
    [aux_sym_preproc_else_token1] = ACTIONS(4550),
    [aux_sym_preproc_elif_token1] = ACTIONS(4550),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3922] = {
    [sym_preproc_region] = STATE(3922),
    [sym_preproc_endregion] = STATE(3922),
    [sym_preproc_line] = STATE(3922),
    [sym_preproc_pragma] = STATE(3922),
    [sym_preproc_nullable] = STATE(3922),
    [sym_preproc_error] = STATE(3922),
    [sym_preproc_warning] = STATE(3922),
    [sym_preproc_define] = STATE(3922),
    [sym_preproc_undef] = STATE(3922),
    [anon_sym_EQ] = ACTIONS(4162),
    [anon_sym_LBRACK] = ACTIONS(4177),
    [anon_sym_COLON] = ACTIONS(4177),
    [anon_sym_COMMA] = ACTIONS(4177),
    [anon_sym_LPAREN] = ACTIONS(4177),
    [anon_sym_LT] = ACTIONS(4162),
    [anon_sym_GT] = ACTIONS(4162),
    [anon_sym_QMARK] = ACTIONS(4162),
    [anon_sym_BANG] = ACTIONS(4162),
    [anon_sym_PLUS_PLUS] = ACTIONS(4177),
    [anon_sym_DASH_DASH] = ACTIONS(4177),
    [anon_sym_PLUS] = ACTIONS(4162),
    [anon_sym_DASH] = ACTIONS(4162),
    [anon_sym_STAR] = ACTIONS(4162),
    [anon_sym_SLASH] = ACTIONS(4162),
    [anon_sym_PERCENT] = ACTIONS(4162),
    [anon_sym_CARET] = ACTIONS(4162),
    [anon_sym_PIPE] = ACTIONS(4162),
    [anon_sym_AMP] = ACTIONS(4162),
    [anon_sym_LT_LT] = ACTIONS(4162),
    [anon_sym_GT_GT] = ACTIONS(4162),
    [anon_sym_GT_GT_GT] = ACTIONS(4162),
    [anon_sym_EQ_EQ] = ACTIONS(4177),
    [anon_sym_BANG_EQ] = ACTIONS(4177),
    [anon_sym_GT_EQ] = ACTIONS(4177),
    [anon_sym_LT_EQ] = ACTIONS(4177),
    [anon_sym_DOT] = ACTIONS(4162),
    [anon_sym_switch] = ACTIONS(4177),
    [anon_sym_DOT_DOT] = ACTIONS(4177),
    [anon_sym_and] = ACTIONS(4177),
    [anon_sym_or] = ACTIONS(4177),
    [anon_sym_PLUS_EQ] = ACTIONS(4177),
    [anon_sym_DASH_EQ] = ACTIONS(4177),
    [anon_sym_STAR_EQ] = ACTIONS(4177),
    [anon_sym_SLASH_EQ] = ACTIONS(4177),
    [anon_sym_PERCENT_EQ] = ACTIONS(4177),
    [anon_sym_AMP_EQ] = ACTIONS(4177),
    [anon_sym_CARET_EQ] = ACTIONS(4177),
    [anon_sym_PIPE_EQ] = ACTIONS(4177),
    [anon_sym_LT_LT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4177),
    [anon_sym_AMP_AMP] = ACTIONS(4177),
    [anon_sym_PIPE_PIPE] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK] = ACTIONS(4162),
    [anon_sym_into] = ACTIONS(4177),
    [anon_sym_as] = ACTIONS(4177),
    [anon_sym_is] = ACTIONS(4177),
    [anon_sym_DASH_GT] = ACTIONS(4177),
    [anon_sym_with] = ACTIONS(4177),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4177),
  },
  [3923] = {
    [sym_preproc_region] = STATE(3923),
    [sym_preproc_endregion] = STATE(3923),
    [sym_preproc_line] = STATE(3923),
    [sym_preproc_pragma] = STATE(3923),
    [sym_preproc_nullable] = STATE(3923),
    [sym_preproc_error] = STATE(3923),
    [sym_preproc_warning] = STATE(3923),
    [sym_preproc_define] = STATE(3923),
    [sym_preproc_undef] = STATE(3923),
    [anon_sym_SEMI] = ACTIONS(4488),
    [anon_sym_LBRACK] = ACTIONS(4488),
    [anon_sym_COLON] = ACTIONS(4488),
    [anon_sym_COMMA] = ACTIONS(4488),
    [anon_sym_RBRACK] = ACTIONS(4488),
    [anon_sym_LPAREN] = ACTIONS(4488),
    [anon_sym_RPAREN] = ACTIONS(4488),
    [anon_sym_LBRACE] = ACTIONS(4488),
    [anon_sym_RBRACE] = ACTIONS(4488),
    [anon_sym_LT] = ACTIONS(4486),
    [anon_sym_GT] = ACTIONS(4486),
    [anon_sym_in] = ACTIONS(4486),
    [anon_sym_QMARK] = ACTIONS(4486),
    [anon_sym_BANG] = ACTIONS(4486),
    [anon_sym_PLUS_PLUS] = ACTIONS(4488),
    [anon_sym_DASH_DASH] = ACTIONS(4488),
    [anon_sym_PLUS] = ACTIONS(4486),
    [anon_sym_DASH] = ACTIONS(4486),
    [anon_sym_STAR] = ACTIONS(4488),
    [anon_sym_SLASH] = ACTIONS(4486),
    [anon_sym_PERCENT] = ACTIONS(4488),
    [anon_sym_CARET] = ACTIONS(4488),
    [anon_sym_PIPE] = ACTIONS(4486),
    [anon_sym_AMP] = ACTIONS(4486),
    [anon_sym_LT_LT] = ACTIONS(4488),
    [anon_sym_GT_GT] = ACTIONS(4486),
    [anon_sym_GT_GT_GT] = ACTIONS(4488),
    [anon_sym_EQ_EQ] = ACTIONS(4488),
    [anon_sym_BANG_EQ] = ACTIONS(4488),
    [anon_sym_GT_EQ] = ACTIONS(4488),
    [anon_sym_LT_EQ] = ACTIONS(4488),
    [anon_sym_DOT] = ACTIONS(4486),
    [anon_sym_EQ_GT] = ACTIONS(4488),
    [anon_sym_switch] = ACTIONS(4488),
    [anon_sym_when] = ACTIONS(4488),
    [anon_sym_DOT_DOT] = ACTIONS(4488),
    [anon_sym_and] = ACTIONS(4488),
    [anon_sym_or] = ACTIONS(4488),
    [anon_sym_AMP_AMP] = ACTIONS(4488),
    [anon_sym_PIPE_PIPE] = ACTIONS(4488),
    [anon_sym_QMARK_QMARK] = ACTIONS(4488),
    [anon_sym_into] = ACTIONS(4488),
    [anon_sym_on] = ACTIONS(4488),
    [anon_sym_equals] = ACTIONS(4488),
    [anon_sym_by] = ACTIONS(4488),
    [anon_sym_as] = ACTIONS(4488),
    [anon_sym_is] = ACTIONS(4488),
    [anon_sym_DASH_GT] = ACTIONS(4488),
    [anon_sym_with] = ACTIONS(4488),
    [aux_sym_preproc_if_token3] = ACTIONS(4488),
    [aux_sym_preproc_else_token1] = ACTIONS(4488),
    [aux_sym_preproc_elif_token1] = ACTIONS(4488),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3924] = {
    [sym_preproc_region] = STATE(3924),
    [sym_preproc_endregion] = STATE(3924),
    [sym_preproc_line] = STATE(3924),
    [sym_preproc_pragma] = STATE(3924),
    [sym_preproc_nullable] = STATE(3924),
    [sym_preproc_error] = STATE(3924),
    [sym_preproc_warning] = STATE(3924),
    [sym_preproc_define] = STATE(3924),
    [sym_preproc_undef] = STATE(3924),
    [anon_sym_SEMI] = ACTIONS(4168),
    [anon_sym_LBRACK] = ACTIONS(4168),
    [anon_sym_COLON] = ACTIONS(4168),
    [anon_sym_COMMA] = ACTIONS(4168),
    [anon_sym_RBRACK] = ACTIONS(4168),
    [anon_sym_LPAREN] = ACTIONS(4168),
    [anon_sym_RPAREN] = ACTIONS(4168),
    [anon_sym_LBRACE] = ACTIONS(4168),
    [anon_sym_RBRACE] = ACTIONS(4168),
    [anon_sym_LT] = ACTIONS(4157),
    [anon_sym_GT] = ACTIONS(4157),
    [anon_sym_in] = ACTIONS(4157),
    [anon_sym_QMARK] = ACTIONS(4157),
    [anon_sym_BANG] = ACTIONS(4157),
    [anon_sym_PLUS_PLUS] = ACTIONS(4168),
    [anon_sym_DASH_DASH] = ACTIONS(4168),
    [anon_sym_PLUS] = ACTIONS(4157),
    [anon_sym_DASH] = ACTIONS(4157),
    [anon_sym_STAR] = ACTIONS(4168),
    [anon_sym_SLASH] = ACTIONS(4157),
    [anon_sym_PERCENT] = ACTIONS(4168),
    [anon_sym_CARET] = ACTIONS(4168),
    [anon_sym_PIPE] = ACTIONS(4157),
    [anon_sym_AMP] = ACTIONS(4157),
    [anon_sym_LT_LT] = ACTIONS(4168),
    [anon_sym_GT_GT] = ACTIONS(4157),
    [anon_sym_GT_GT_GT] = ACTIONS(4168),
    [anon_sym_EQ_EQ] = ACTIONS(4168),
    [anon_sym_BANG_EQ] = ACTIONS(4168),
    [anon_sym_GT_EQ] = ACTIONS(4168),
    [anon_sym_LT_EQ] = ACTIONS(4168),
    [anon_sym_DOT] = ACTIONS(4157),
    [anon_sym_EQ_GT] = ACTIONS(4168),
    [anon_sym_switch] = ACTIONS(4168),
    [anon_sym_when] = ACTIONS(4168),
    [anon_sym_DOT_DOT] = ACTIONS(4168),
    [anon_sym_and] = ACTIONS(4168),
    [anon_sym_or] = ACTIONS(4168),
    [anon_sym_AMP_AMP] = ACTIONS(4168),
    [anon_sym_PIPE_PIPE] = ACTIONS(4168),
    [anon_sym_QMARK_QMARK] = ACTIONS(4168),
    [anon_sym_into] = ACTIONS(4168),
    [anon_sym_on] = ACTIONS(4168),
    [anon_sym_equals] = ACTIONS(4168),
    [anon_sym_by] = ACTIONS(4168),
    [anon_sym_as] = ACTIONS(4168),
    [anon_sym_is] = ACTIONS(4168),
    [anon_sym_DASH_GT] = ACTIONS(4168),
    [anon_sym_with] = ACTIONS(4168),
    [aux_sym_preproc_if_token3] = ACTIONS(4168),
    [aux_sym_preproc_else_token1] = ACTIONS(4168),
    [aux_sym_preproc_elif_token1] = ACTIONS(4168),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3925] = {
    [sym_preproc_region] = STATE(3925),
    [sym_preproc_endregion] = STATE(3925),
    [sym_preproc_line] = STATE(3925),
    [sym_preproc_pragma] = STATE(3925),
    [sym_preproc_nullable] = STATE(3925),
    [sym_preproc_error] = STATE(3925),
    [sym_preproc_warning] = STATE(3925),
    [sym_preproc_define] = STATE(3925),
    [sym_preproc_undef] = STATE(3925),
    [anon_sym_EQ] = ACTIONS(4130),
    [anon_sym_LBRACK] = ACTIONS(4132),
    [anon_sym_COLON] = ACTIONS(4132),
    [anon_sym_COMMA] = ACTIONS(4132),
    [anon_sym_LPAREN] = ACTIONS(4132),
    [anon_sym_LT] = ACTIONS(4130),
    [anon_sym_GT] = ACTIONS(4130),
    [anon_sym_QMARK] = ACTIONS(4130),
    [anon_sym_BANG] = ACTIONS(4130),
    [anon_sym_PLUS_PLUS] = ACTIONS(4132),
    [anon_sym_DASH_DASH] = ACTIONS(4132),
    [anon_sym_PLUS] = ACTIONS(4130),
    [anon_sym_DASH] = ACTIONS(4130),
    [anon_sym_STAR] = ACTIONS(4130),
    [anon_sym_SLASH] = ACTIONS(4130),
    [anon_sym_PERCENT] = ACTIONS(4130),
    [anon_sym_CARET] = ACTIONS(4130),
    [anon_sym_PIPE] = ACTIONS(4130),
    [anon_sym_AMP] = ACTIONS(4130),
    [anon_sym_LT_LT] = ACTIONS(4130),
    [anon_sym_GT_GT] = ACTIONS(4130),
    [anon_sym_GT_GT_GT] = ACTIONS(4130),
    [anon_sym_EQ_EQ] = ACTIONS(4132),
    [anon_sym_BANG_EQ] = ACTIONS(4132),
    [anon_sym_GT_EQ] = ACTIONS(4132),
    [anon_sym_LT_EQ] = ACTIONS(4132),
    [anon_sym_DOT] = ACTIONS(4130),
    [anon_sym_switch] = ACTIONS(4132),
    [anon_sym_DOT_DOT] = ACTIONS(4132),
    [anon_sym_and] = ACTIONS(4132),
    [anon_sym_or] = ACTIONS(4132),
    [anon_sym_PLUS_EQ] = ACTIONS(4132),
    [anon_sym_DASH_EQ] = ACTIONS(4132),
    [anon_sym_STAR_EQ] = ACTIONS(4132),
    [anon_sym_SLASH_EQ] = ACTIONS(4132),
    [anon_sym_PERCENT_EQ] = ACTIONS(4132),
    [anon_sym_AMP_EQ] = ACTIONS(4132),
    [anon_sym_CARET_EQ] = ACTIONS(4132),
    [anon_sym_PIPE_EQ] = ACTIONS(4132),
    [anon_sym_LT_LT_EQ] = ACTIONS(4132),
    [anon_sym_GT_GT_EQ] = ACTIONS(4132),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4132),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4132),
    [anon_sym_AMP_AMP] = ACTIONS(4132),
    [anon_sym_PIPE_PIPE] = ACTIONS(4132),
    [anon_sym_QMARK_QMARK] = ACTIONS(4130),
    [anon_sym_into] = ACTIONS(4132),
    [anon_sym_as] = ACTIONS(4132),
    [anon_sym_is] = ACTIONS(4132),
    [anon_sym_DASH_GT] = ACTIONS(4132),
    [anon_sym_with] = ACTIONS(4132),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4132),
  },
  [3926] = {
    [sym_argument_list] = STATE(4293),
    [sym_bracketed_argument_list] = STATE(3507),
    [sym_preproc_region] = STATE(3926),
    [sym_preproc_endregion] = STATE(3926),
    [sym_preproc_line] = STATE(3926),
    [sym_preproc_pragma] = STATE(3926),
    [sym_preproc_nullable] = STATE(3926),
    [sym_preproc_error] = STATE(3926),
    [sym_preproc_warning] = STATE(3926),
    [sym_preproc_define] = STATE(3926),
    [sym_preproc_undef] = STATE(3926),
    [anon_sym_SEMI] = ACTIONS(5292),
    [anon_sym_LBRACK] = ACTIONS(5830),
    [anon_sym_COLON] = ACTIONS(5292),
    [anon_sym_COMMA] = ACTIONS(5292),
    [anon_sym_RBRACK] = ACTIONS(5292),
    [anon_sym_LPAREN] = ACTIONS(5776),
    [anon_sym_RPAREN] = ACTIONS(5292),
    [anon_sym_RBRACE] = ACTIONS(5292),
    [anon_sym_LT] = ACTIONS(5294),
    [anon_sym_GT] = ACTIONS(5294),
    [anon_sym_in] = ACTIONS(5292),
    [anon_sym_QMARK] = ACTIONS(5294),
    [anon_sym_BANG] = ACTIONS(5832),
    [anon_sym_PLUS_PLUS] = ACTIONS(5834),
    [anon_sym_DASH_DASH] = ACTIONS(5834),
    [anon_sym_PLUS] = ACTIONS(5294),
    [anon_sym_DASH] = ACTIONS(5294),
    [anon_sym_STAR] = ACTIONS(5292),
    [anon_sym_SLASH] = ACTIONS(5294),
    [anon_sym_PERCENT] = ACTIONS(5292),
    [anon_sym_CARET] = ACTIONS(5292),
    [anon_sym_PIPE] = ACTIONS(5294),
    [anon_sym_AMP] = ACTIONS(5294),
    [anon_sym_LT_LT] = ACTIONS(5292),
    [anon_sym_GT_GT] = ACTIONS(5294),
    [anon_sym_GT_GT_GT] = ACTIONS(5292),
    [anon_sym_EQ_EQ] = ACTIONS(5292),
    [anon_sym_BANG_EQ] = ACTIONS(5292),
    [anon_sym_GT_EQ] = ACTIONS(5292),
    [anon_sym_LT_EQ] = ACTIONS(5292),
    [anon_sym_DOT] = ACTIONS(4602),
    [anon_sym_EQ_GT] = ACTIONS(5292),
    [anon_sym_switch] = ACTIONS(5292),
    [anon_sym_when] = ACTIONS(5292),
    [anon_sym_DOT_DOT] = ACTIONS(5292),
    [anon_sym_and] = ACTIONS(5292),
    [anon_sym_or] = ACTIONS(5292),
    [anon_sym_AMP_AMP] = ACTIONS(5292),
    [anon_sym_PIPE_PIPE] = ACTIONS(5292),
    [anon_sym_QMARK_QMARK] = ACTIONS(5292),
    [anon_sym_on] = ACTIONS(5292),
    [anon_sym_equals] = ACTIONS(5292),
    [anon_sym_by] = ACTIONS(5292),
    [anon_sym_as] = ACTIONS(5292),
    [anon_sym_is] = ACTIONS(5292),
    [anon_sym_DASH_GT] = ACTIONS(4604),
    [anon_sym_with] = ACTIONS(5292),
    [aux_sym_preproc_if_token3] = ACTIONS(5292),
    [aux_sym_preproc_else_token1] = ACTIONS(5292),
    [aux_sym_preproc_elif_token1] = ACTIONS(5292),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3927] = {
    [sym_initializer_expression] = STATE(4329),
    [sym_preproc_region] = STATE(3927),
    [sym_preproc_endregion] = STATE(3927),
    [sym_preproc_line] = STATE(3927),
    [sym_preproc_pragma] = STATE(3927),
    [sym_preproc_nullable] = STATE(3927),
    [sym_preproc_error] = STATE(3927),
    [sym_preproc_warning] = STATE(3927),
    [sym_preproc_define] = STATE(3927),
    [sym_preproc_undef] = STATE(3927),
    [anon_sym_SEMI] = ACTIONS(5296),
    [anon_sym_LBRACK] = ACTIONS(5298),
    [anon_sym_COLON] = ACTIONS(5296),
    [anon_sym_COMMA] = ACTIONS(5296),
    [anon_sym_RBRACK] = ACTIONS(5296),
    [anon_sym_LPAREN] = ACTIONS(5296),
    [anon_sym_RPAREN] = ACTIONS(5296),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_RBRACE] = ACTIONS(5296),
    [anon_sym_LT] = ACTIONS(5301),
    [anon_sym_GT] = ACTIONS(5301),
    [anon_sym_in] = ACTIONS(5296),
    [anon_sym_QMARK] = ACTIONS(5301),
    [anon_sym_BANG] = ACTIONS(5301),
    [anon_sym_PLUS_PLUS] = ACTIONS(5296),
    [anon_sym_DASH_DASH] = ACTIONS(5296),
    [anon_sym_PLUS] = ACTIONS(5301),
    [anon_sym_DASH] = ACTIONS(5301),
    [anon_sym_STAR] = ACTIONS(5296),
    [anon_sym_SLASH] = ACTIONS(5301),
    [anon_sym_PERCENT] = ACTIONS(5296),
    [anon_sym_CARET] = ACTIONS(5296),
    [anon_sym_PIPE] = ACTIONS(5301),
    [anon_sym_AMP] = ACTIONS(5301),
    [anon_sym_LT_LT] = ACTIONS(5296),
    [anon_sym_GT_GT] = ACTIONS(5301),
    [anon_sym_GT_GT_GT] = ACTIONS(5296),
    [anon_sym_EQ_EQ] = ACTIONS(5296),
    [anon_sym_BANG_EQ] = ACTIONS(5296),
    [anon_sym_GT_EQ] = ACTIONS(5296),
    [anon_sym_LT_EQ] = ACTIONS(5296),
    [anon_sym_DOT] = ACTIONS(5301),
    [anon_sym_EQ_GT] = ACTIONS(5296),
    [anon_sym_switch] = ACTIONS(5296),
    [anon_sym_when] = ACTIONS(5296),
    [anon_sym_DOT_DOT] = ACTIONS(5296),
    [anon_sym_and] = ACTIONS(5296),
    [anon_sym_or] = ACTIONS(5296),
    [anon_sym_AMP_AMP] = ACTIONS(5296),
    [anon_sym_PIPE_PIPE] = ACTIONS(5296),
    [anon_sym_QMARK_QMARK] = ACTIONS(5296),
    [anon_sym_on] = ACTIONS(5296),
    [anon_sym_equals] = ACTIONS(5296),
    [anon_sym_by] = ACTIONS(5296),
    [anon_sym_as] = ACTIONS(5296),
    [anon_sym_is] = ACTIONS(5296),
    [anon_sym_DASH_GT] = ACTIONS(5296),
    [anon_sym_with] = ACTIONS(5296),
    [aux_sym_preproc_if_token3] = ACTIONS(5296),
    [aux_sym_preproc_else_token1] = ACTIONS(5296),
    [aux_sym_preproc_elif_token1] = ACTIONS(5296),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3928] = {
    [sym_preproc_region] = STATE(3928),
    [sym_preproc_endregion] = STATE(3928),
    [sym_preproc_line] = STATE(3928),
    [sym_preproc_pragma] = STATE(3928),
    [sym_preproc_nullable] = STATE(3928),
    [sym_preproc_error] = STATE(3928),
    [sym_preproc_warning] = STATE(3928),
    [sym_preproc_define] = STATE(3928),
    [sym_preproc_undef] = STATE(3928),
    [anon_sym_SEMI] = ACTIONS(5363),
    [anon_sym_LBRACK] = ACTIONS(5363),
    [anon_sym_COLON] = ACTIONS(5363),
    [anon_sym_COMMA] = ACTIONS(5363),
    [anon_sym_RBRACK] = ACTIONS(5363),
    [anon_sym_LPAREN] = ACTIONS(5363),
    [anon_sym_RPAREN] = ACTIONS(5363),
    [anon_sym_RBRACE] = ACTIONS(5363),
    [anon_sym_LT] = ACTIONS(5365),
    [anon_sym_GT] = ACTIONS(5365),
    [anon_sym_in] = ACTIONS(5365),
    [anon_sym_QMARK] = ACTIONS(5365),
    [anon_sym_BANG] = ACTIONS(5365),
    [anon_sym_PLUS_PLUS] = ACTIONS(5363),
    [anon_sym_DASH_DASH] = ACTIONS(5363),
    [anon_sym_PLUS] = ACTIONS(5365),
    [anon_sym_DASH] = ACTIONS(5365),
    [anon_sym_STAR] = ACTIONS(5363),
    [anon_sym_SLASH] = ACTIONS(5365),
    [anon_sym_PERCENT] = ACTIONS(5363),
    [anon_sym_CARET] = ACTIONS(5363),
    [anon_sym_PIPE] = ACTIONS(5365),
    [anon_sym_AMP] = ACTIONS(5365),
    [anon_sym_LT_LT] = ACTIONS(5363),
    [anon_sym_GT_GT] = ACTIONS(5365),
    [anon_sym_GT_GT_GT] = ACTIONS(5363),
    [anon_sym_EQ_EQ] = ACTIONS(5363),
    [anon_sym_BANG_EQ] = ACTIONS(5363),
    [anon_sym_GT_EQ] = ACTIONS(5363),
    [anon_sym_LT_EQ] = ACTIONS(5363),
    [anon_sym_DOT] = ACTIONS(5365),
    [anon_sym_EQ_GT] = ACTIONS(5363),
    [anon_sym_switch] = ACTIONS(5363),
    [anon_sym_when] = ACTIONS(5363),
    [anon_sym_DOT_DOT] = ACTIONS(5363),
    [anon_sym_and] = ACTIONS(5363),
    [anon_sym_or] = ACTIONS(5363),
    [anon_sym_AMP_AMP] = ACTIONS(5363),
    [anon_sym_PIPE_PIPE] = ACTIONS(5363),
    [anon_sym_QMARK_QMARK] = ACTIONS(5363),
    [anon_sym_into] = ACTIONS(5363),
    [anon_sym_on] = ACTIONS(5363),
    [anon_sym_equals] = ACTIONS(5363),
    [anon_sym_by] = ACTIONS(5363),
    [anon_sym_as] = ACTIONS(5363),
    [anon_sym_is] = ACTIONS(5363),
    [anon_sym_DASH_GT] = ACTIONS(5363),
    [anon_sym_with] = ACTIONS(5363),
    [sym_string_literal_encoding] = ACTIONS(5836),
    [aux_sym_preproc_if_token3] = ACTIONS(5363),
    [aux_sym_preproc_else_token1] = ACTIONS(5363),
    [aux_sym_preproc_elif_token1] = ACTIONS(5363),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3929] = {
    [sym_preproc_region] = STATE(3929),
    [sym_preproc_endregion] = STATE(3929),
    [sym_preproc_line] = STATE(3929),
    [sym_preproc_pragma] = STATE(3929),
    [sym_preproc_nullable] = STATE(3929),
    [sym_preproc_error] = STATE(3929),
    [sym_preproc_warning] = STATE(3929),
    [sym_preproc_define] = STATE(3929),
    [sym_preproc_undef] = STATE(3929),
    [anon_sym_SEMI] = ACTIONS(4433),
    [anon_sym_LBRACK] = ACTIONS(4433),
    [anon_sym_COLON] = ACTIONS(4433),
    [anon_sym_COMMA] = ACTIONS(4433),
    [anon_sym_RBRACK] = ACTIONS(4433),
    [anon_sym_LPAREN] = ACTIONS(4433),
    [anon_sym_RPAREN] = ACTIONS(4433),
    [anon_sym_LBRACE] = ACTIONS(4433),
    [anon_sym_RBRACE] = ACTIONS(4433),
    [anon_sym_LT] = ACTIONS(4431),
    [anon_sym_GT] = ACTIONS(4431),
    [anon_sym_in] = ACTIONS(4431),
    [anon_sym_QMARK] = ACTIONS(4431),
    [anon_sym_BANG] = ACTIONS(4431),
    [anon_sym_PLUS_PLUS] = ACTIONS(4433),
    [anon_sym_DASH_DASH] = ACTIONS(4433),
    [anon_sym_PLUS] = ACTIONS(4431),
    [anon_sym_DASH] = ACTIONS(4431),
    [anon_sym_STAR] = ACTIONS(4433),
    [anon_sym_SLASH] = ACTIONS(4431),
    [anon_sym_PERCENT] = ACTIONS(4433),
    [anon_sym_CARET] = ACTIONS(4433),
    [anon_sym_PIPE] = ACTIONS(4431),
    [anon_sym_AMP] = ACTIONS(4431),
    [anon_sym_LT_LT] = ACTIONS(4433),
    [anon_sym_GT_GT] = ACTIONS(4431),
    [anon_sym_GT_GT_GT] = ACTIONS(4433),
    [anon_sym_EQ_EQ] = ACTIONS(4433),
    [anon_sym_BANG_EQ] = ACTIONS(4433),
    [anon_sym_GT_EQ] = ACTIONS(4433),
    [anon_sym_LT_EQ] = ACTIONS(4433),
    [anon_sym_DOT] = ACTIONS(4431),
    [anon_sym_EQ_GT] = ACTIONS(4433),
    [anon_sym_switch] = ACTIONS(4433),
    [anon_sym_when] = ACTIONS(4433),
    [anon_sym_DOT_DOT] = ACTIONS(4433),
    [anon_sym_and] = ACTIONS(4433),
    [anon_sym_or] = ACTIONS(4433),
    [anon_sym_AMP_AMP] = ACTIONS(4433),
    [anon_sym_PIPE_PIPE] = ACTIONS(4433),
    [anon_sym_QMARK_QMARK] = ACTIONS(4433),
    [anon_sym_into] = ACTIONS(4433),
    [anon_sym_on] = ACTIONS(4433),
    [anon_sym_equals] = ACTIONS(4433),
    [anon_sym_by] = ACTIONS(4433),
    [anon_sym_as] = ACTIONS(4433),
    [anon_sym_is] = ACTIONS(4433),
    [anon_sym_DASH_GT] = ACTIONS(4433),
    [anon_sym_with] = ACTIONS(4433),
    [aux_sym_preproc_if_token3] = ACTIONS(4433),
    [aux_sym_preproc_else_token1] = ACTIONS(4433),
    [aux_sym_preproc_elif_token1] = ACTIONS(4433),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3930] = {
    [sym_preproc_region] = STATE(3930),
    [sym_preproc_endregion] = STATE(3930),
    [sym_preproc_line] = STATE(3930),
    [sym_preproc_pragma] = STATE(3930),
    [sym_preproc_nullable] = STATE(3930),
    [sym_preproc_error] = STATE(3930),
    [sym_preproc_warning] = STATE(3930),
    [sym_preproc_define] = STATE(3930),
    [sym_preproc_undef] = STATE(3930),
    [anon_sym_SEMI] = ACTIONS(4472),
    [anon_sym_LBRACK] = ACTIONS(4472),
    [anon_sym_COLON] = ACTIONS(4472),
    [anon_sym_COMMA] = ACTIONS(4472),
    [anon_sym_RBRACK] = ACTIONS(4472),
    [anon_sym_LPAREN] = ACTIONS(4472),
    [anon_sym_RPAREN] = ACTIONS(4472),
    [anon_sym_LBRACE] = ACTIONS(4472),
    [anon_sym_RBRACE] = ACTIONS(4472),
    [anon_sym_LT] = ACTIONS(4470),
    [anon_sym_GT] = ACTIONS(4470),
    [anon_sym_in] = ACTIONS(4470),
    [anon_sym_QMARK] = ACTIONS(4470),
    [anon_sym_BANG] = ACTIONS(4470),
    [anon_sym_PLUS_PLUS] = ACTIONS(4472),
    [anon_sym_DASH_DASH] = ACTIONS(4472),
    [anon_sym_PLUS] = ACTIONS(4470),
    [anon_sym_DASH] = ACTIONS(4470),
    [anon_sym_STAR] = ACTIONS(4472),
    [anon_sym_SLASH] = ACTIONS(4470),
    [anon_sym_PERCENT] = ACTIONS(4472),
    [anon_sym_CARET] = ACTIONS(4472),
    [anon_sym_PIPE] = ACTIONS(4470),
    [anon_sym_AMP] = ACTIONS(4470),
    [anon_sym_LT_LT] = ACTIONS(4472),
    [anon_sym_GT_GT] = ACTIONS(4470),
    [anon_sym_GT_GT_GT] = ACTIONS(4472),
    [anon_sym_EQ_EQ] = ACTIONS(4472),
    [anon_sym_BANG_EQ] = ACTIONS(4472),
    [anon_sym_GT_EQ] = ACTIONS(4472),
    [anon_sym_LT_EQ] = ACTIONS(4472),
    [anon_sym_DOT] = ACTIONS(4470),
    [anon_sym_EQ_GT] = ACTIONS(4472),
    [anon_sym_switch] = ACTIONS(4472),
    [anon_sym_when] = ACTIONS(4472),
    [anon_sym_DOT_DOT] = ACTIONS(4472),
    [anon_sym_and] = ACTIONS(4472),
    [anon_sym_or] = ACTIONS(4472),
    [anon_sym_AMP_AMP] = ACTIONS(4472),
    [anon_sym_PIPE_PIPE] = ACTIONS(4472),
    [anon_sym_QMARK_QMARK] = ACTIONS(4472),
    [anon_sym_into] = ACTIONS(4472),
    [anon_sym_on] = ACTIONS(4472),
    [anon_sym_equals] = ACTIONS(4472),
    [anon_sym_by] = ACTIONS(4472),
    [anon_sym_as] = ACTIONS(4472),
    [anon_sym_is] = ACTIONS(4472),
    [anon_sym_DASH_GT] = ACTIONS(4472),
    [anon_sym_with] = ACTIONS(4472),
    [aux_sym_preproc_if_token3] = ACTIONS(4472),
    [aux_sym_preproc_else_token1] = ACTIONS(4472),
    [aux_sym_preproc_elif_token1] = ACTIONS(4472),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3931] = {
    [sym_preproc_region] = STATE(3931),
    [sym_preproc_endregion] = STATE(3931),
    [sym_preproc_line] = STATE(3931),
    [sym_preproc_pragma] = STATE(3931),
    [sym_preproc_nullable] = STATE(3931),
    [sym_preproc_error] = STATE(3931),
    [sym_preproc_warning] = STATE(3931),
    [sym_preproc_define] = STATE(3931),
    [sym_preproc_undef] = STATE(3931),
    [anon_sym_SEMI] = ACTIONS(5286),
    [anon_sym_EQ] = ACTIONS(5838),
    [anon_sym_LBRACK] = ACTIONS(5286),
    [anon_sym_LPAREN] = ACTIONS(5286),
    [anon_sym_LT] = ACTIONS(5288),
    [anon_sym_GT] = ACTIONS(5288),
    [anon_sym_QMARK] = ACTIONS(5288),
    [anon_sym_BANG] = ACTIONS(5288),
    [anon_sym_PLUS_PLUS] = ACTIONS(5286),
    [anon_sym_DASH_DASH] = ACTIONS(5286),
    [anon_sym_PLUS] = ACTIONS(5288),
    [anon_sym_DASH] = ACTIONS(5288),
    [anon_sym_STAR] = ACTIONS(5288),
    [anon_sym_SLASH] = ACTIONS(5288),
    [anon_sym_PERCENT] = ACTIONS(5288),
    [anon_sym_CARET] = ACTIONS(5288),
    [anon_sym_PIPE] = ACTIONS(5288),
    [anon_sym_AMP] = ACTIONS(5288),
    [anon_sym_LT_LT] = ACTIONS(5288),
    [anon_sym_GT_GT] = ACTIONS(5288),
    [anon_sym_GT_GT_GT] = ACTIONS(5288),
    [anon_sym_EQ_EQ] = ACTIONS(5286),
    [anon_sym_BANG_EQ] = ACTIONS(5286),
    [anon_sym_GT_EQ] = ACTIONS(5286),
    [anon_sym_LT_EQ] = ACTIONS(5286),
    [anon_sym_DOT] = ACTIONS(5288),
    [anon_sym_switch] = ACTIONS(5286),
    [anon_sym_DOT_DOT] = ACTIONS(5286),
    [anon_sym_and] = ACTIONS(5286),
    [anon_sym_or] = ACTIONS(5286),
    [anon_sym_PLUS_EQ] = ACTIONS(5840),
    [anon_sym_DASH_EQ] = ACTIONS(5840),
    [anon_sym_STAR_EQ] = ACTIONS(5840),
    [anon_sym_SLASH_EQ] = ACTIONS(5840),
    [anon_sym_PERCENT_EQ] = ACTIONS(5840),
    [anon_sym_AMP_EQ] = ACTIONS(5840),
    [anon_sym_CARET_EQ] = ACTIONS(5840),
    [anon_sym_PIPE_EQ] = ACTIONS(5840),
    [anon_sym_LT_LT_EQ] = ACTIONS(5840),
    [anon_sym_GT_GT_EQ] = ACTIONS(5840),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(5840),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(5840),
    [anon_sym_AMP_AMP] = ACTIONS(5286),
    [anon_sym_PIPE_PIPE] = ACTIONS(5286),
    [anon_sym_QMARK_QMARK] = ACTIONS(5288),
    [anon_sym_as] = ACTIONS(5286),
    [anon_sym_is] = ACTIONS(5286),
    [anon_sym_DASH_GT] = ACTIONS(5286),
    [anon_sym_with] = ACTIONS(5286),
    [aux_sym_preproc_if_token3] = ACTIONS(5286),
    [aux_sym_preproc_else_token1] = ACTIONS(5286),
    [aux_sym_preproc_elif_token1] = ACTIONS(5286),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3932] = {
    [sym_argument_list] = STATE(4293),
    [sym_bracketed_argument_list] = STATE(3507),
    [sym_preproc_region] = STATE(3932),
    [sym_preproc_endregion] = STATE(3932),
    [sym_preproc_line] = STATE(3932),
    [sym_preproc_pragma] = STATE(3932),
    [sym_preproc_nullable] = STATE(3932),
    [sym_preproc_error] = STATE(3932),
    [sym_preproc_warning] = STATE(3932),
    [sym_preproc_define] = STATE(3932),
    [sym_preproc_undef] = STATE(3932),
    [anon_sym_SEMI] = ACTIONS(5325),
    [anon_sym_LBRACK] = ACTIONS(5830),
    [anon_sym_COLON] = ACTIONS(5325),
    [anon_sym_COMMA] = ACTIONS(5325),
    [anon_sym_RBRACK] = ACTIONS(5325),
    [anon_sym_LPAREN] = ACTIONS(5776),
    [anon_sym_RPAREN] = ACTIONS(5325),
    [anon_sym_RBRACE] = ACTIONS(5325),
    [anon_sym_LT] = ACTIONS(5327),
    [anon_sym_GT] = ACTIONS(5327),
    [anon_sym_in] = ACTIONS(5325),
    [anon_sym_QMARK] = ACTIONS(5327),
    [anon_sym_BANG] = ACTIONS(5832),
    [anon_sym_PLUS_PLUS] = ACTIONS(5834),
    [anon_sym_DASH_DASH] = ACTIONS(5834),
    [anon_sym_PLUS] = ACTIONS(5327),
    [anon_sym_DASH] = ACTIONS(5327),
    [anon_sym_STAR] = ACTIONS(5325),
    [anon_sym_SLASH] = ACTIONS(5327),
    [anon_sym_PERCENT] = ACTIONS(5325),
    [anon_sym_CARET] = ACTIONS(5325),
    [anon_sym_PIPE] = ACTIONS(5327),
    [anon_sym_AMP] = ACTIONS(5327),
    [anon_sym_LT_LT] = ACTIONS(5325),
    [anon_sym_GT_GT] = ACTIONS(5327),
    [anon_sym_GT_GT_GT] = ACTIONS(5325),
    [anon_sym_EQ_EQ] = ACTIONS(5325),
    [anon_sym_BANG_EQ] = ACTIONS(5325),
    [anon_sym_GT_EQ] = ACTIONS(5325),
    [anon_sym_LT_EQ] = ACTIONS(5325),
    [anon_sym_DOT] = ACTIONS(4602),
    [anon_sym_EQ_GT] = ACTIONS(5325),
    [anon_sym_switch] = ACTIONS(5325),
    [anon_sym_when] = ACTIONS(5325),
    [anon_sym_DOT_DOT] = ACTIONS(5325),
    [anon_sym_and] = ACTIONS(5325),
    [anon_sym_or] = ACTIONS(5325),
    [anon_sym_AMP_AMP] = ACTIONS(5325),
    [anon_sym_PIPE_PIPE] = ACTIONS(5325),
    [anon_sym_QMARK_QMARK] = ACTIONS(5325),
    [anon_sym_on] = ACTIONS(5325),
    [anon_sym_equals] = ACTIONS(5325),
    [anon_sym_by] = ACTIONS(5325),
    [anon_sym_as] = ACTIONS(5325),
    [anon_sym_is] = ACTIONS(5325),
    [anon_sym_DASH_GT] = ACTIONS(4604),
    [anon_sym_with] = ACTIONS(5325),
    [aux_sym_preproc_if_token3] = ACTIONS(5325),
    [aux_sym_preproc_else_token1] = ACTIONS(5325),
    [aux_sym_preproc_elif_token1] = ACTIONS(5325),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3933] = {
    [sym_preproc_region] = STATE(3933),
    [sym_preproc_endregion] = STATE(3933),
    [sym_preproc_line] = STATE(3933),
    [sym_preproc_pragma] = STATE(3933),
    [sym_preproc_nullable] = STATE(3933),
    [sym_preproc_error] = STATE(3933),
    [sym_preproc_warning] = STATE(3933),
    [sym_preproc_define] = STATE(3933),
    [sym_preproc_undef] = STATE(3933),
    [anon_sym_SEMI] = ACTIONS(4554),
    [anon_sym_LBRACK] = ACTIONS(4554),
    [anon_sym_COLON] = ACTIONS(4554),
    [anon_sym_COMMA] = ACTIONS(4554),
    [anon_sym_RBRACK] = ACTIONS(4554),
    [anon_sym_LPAREN] = ACTIONS(4554),
    [anon_sym_RPAREN] = ACTIONS(4554),
    [anon_sym_LBRACE] = ACTIONS(4554),
    [anon_sym_RBRACE] = ACTIONS(4554),
    [anon_sym_LT] = ACTIONS(4552),
    [anon_sym_GT] = ACTIONS(4552),
    [anon_sym_in] = ACTIONS(4552),
    [anon_sym_QMARK] = ACTIONS(4552),
    [anon_sym_BANG] = ACTIONS(4552),
    [anon_sym_PLUS_PLUS] = ACTIONS(4554),
    [anon_sym_DASH_DASH] = ACTIONS(4554),
    [anon_sym_PLUS] = ACTIONS(4552),
    [anon_sym_DASH] = ACTIONS(4552),
    [anon_sym_STAR] = ACTIONS(4554),
    [anon_sym_SLASH] = ACTIONS(4552),
    [anon_sym_PERCENT] = ACTIONS(4554),
    [anon_sym_CARET] = ACTIONS(4554),
    [anon_sym_PIPE] = ACTIONS(4552),
    [anon_sym_AMP] = ACTIONS(4552),
    [anon_sym_LT_LT] = ACTIONS(4554),
    [anon_sym_GT_GT] = ACTIONS(4552),
    [anon_sym_GT_GT_GT] = ACTIONS(4554),
    [anon_sym_EQ_EQ] = ACTIONS(4554),
    [anon_sym_BANG_EQ] = ACTIONS(4554),
    [anon_sym_GT_EQ] = ACTIONS(4554),
    [anon_sym_LT_EQ] = ACTIONS(4554),
    [anon_sym_DOT] = ACTIONS(4552),
    [anon_sym_EQ_GT] = ACTIONS(4554),
    [anon_sym_switch] = ACTIONS(4554),
    [anon_sym_when] = ACTIONS(4554),
    [anon_sym_DOT_DOT] = ACTIONS(4554),
    [anon_sym_and] = ACTIONS(4554),
    [anon_sym_or] = ACTIONS(4554),
    [anon_sym_AMP_AMP] = ACTIONS(4554),
    [anon_sym_PIPE_PIPE] = ACTIONS(4554),
    [anon_sym_QMARK_QMARK] = ACTIONS(4554),
    [anon_sym_into] = ACTIONS(4554),
    [anon_sym_on] = ACTIONS(4554),
    [anon_sym_equals] = ACTIONS(4554),
    [anon_sym_by] = ACTIONS(4554),
    [anon_sym_as] = ACTIONS(4554),
    [anon_sym_is] = ACTIONS(4554),
    [anon_sym_DASH_GT] = ACTIONS(4554),
    [anon_sym_with] = ACTIONS(4554),
    [aux_sym_preproc_if_token3] = ACTIONS(4554),
    [aux_sym_preproc_else_token1] = ACTIONS(4554),
    [aux_sym_preproc_elif_token1] = ACTIONS(4554),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3934] = {
    [sym_preproc_region] = STATE(3934),
    [sym_preproc_endregion] = STATE(3934),
    [sym_preproc_line] = STATE(3934),
    [sym_preproc_pragma] = STATE(3934),
    [sym_preproc_nullable] = STATE(3934),
    [sym_preproc_error] = STATE(3934),
    [sym_preproc_warning] = STATE(3934),
    [sym_preproc_define] = STATE(3934),
    [sym_preproc_undef] = STATE(3934),
    [anon_sym_EQ] = ACTIONS(4138),
    [anon_sym_LBRACK] = ACTIONS(4140),
    [anon_sym_COLON] = ACTIONS(4140),
    [anon_sym_COMMA] = ACTIONS(4140),
    [anon_sym_LPAREN] = ACTIONS(4140),
    [anon_sym_LT] = ACTIONS(4138),
    [anon_sym_GT] = ACTIONS(4138),
    [anon_sym_QMARK] = ACTIONS(4138),
    [anon_sym_BANG] = ACTIONS(4138),
    [anon_sym_PLUS_PLUS] = ACTIONS(4140),
    [anon_sym_DASH_DASH] = ACTIONS(4140),
    [anon_sym_PLUS] = ACTIONS(4138),
    [anon_sym_DASH] = ACTIONS(4138),
    [anon_sym_STAR] = ACTIONS(4138),
    [anon_sym_SLASH] = ACTIONS(4138),
    [anon_sym_PERCENT] = ACTIONS(4138),
    [anon_sym_CARET] = ACTIONS(4138),
    [anon_sym_PIPE] = ACTIONS(4138),
    [anon_sym_AMP] = ACTIONS(4138),
    [anon_sym_LT_LT] = ACTIONS(4138),
    [anon_sym_GT_GT] = ACTIONS(4138),
    [anon_sym_GT_GT_GT] = ACTIONS(4138),
    [anon_sym_EQ_EQ] = ACTIONS(4140),
    [anon_sym_BANG_EQ] = ACTIONS(4140),
    [anon_sym_GT_EQ] = ACTIONS(4140),
    [anon_sym_LT_EQ] = ACTIONS(4140),
    [anon_sym_DOT] = ACTIONS(4138),
    [anon_sym_switch] = ACTIONS(4140),
    [anon_sym_DOT_DOT] = ACTIONS(4140),
    [anon_sym_and] = ACTIONS(4140),
    [anon_sym_or] = ACTIONS(4140),
    [anon_sym_PLUS_EQ] = ACTIONS(4140),
    [anon_sym_DASH_EQ] = ACTIONS(4140),
    [anon_sym_STAR_EQ] = ACTIONS(4140),
    [anon_sym_SLASH_EQ] = ACTIONS(4140),
    [anon_sym_PERCENT_EQ] = ACTIONS(4140),
    [anon_sym_AMP_EQ] = ACTIONS(4140),
    [anon_sym_CARET_EQ] = ACTIONS(4140),
    [anon_sym_PIPE_EQ] = ACTIONS(4140),
    [anon_sym_LT_LT_EQ] = ACTIONS(4140),
    [anon_sym_GT_GT_EQ] = ACTIONS(4140),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4140),
    [anon_sym_AMP_AMP] = ACTIONS(4140),
    [anon_sym_PIPE_PIPE] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK] = ACTIONS(4138),
    [anon_sym_into] = ACTIONS(4140),
    [anon_sym_as] = ACTIONS(4140),
    [anon_sym_is] = ACTIONS(4140),
    [anon_sym_DASH_GT] = ACTIONS(4140),
    [anon_sym_with] = ACTIONS(4140),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4140),
  },
  [3935] = {
    [sym_preproc_region] = STATE(3935),
    [sym_preproc_endregion] = STATE(3935),
    [sym_preproc_line] = STATE(3935),
    [sym_preproc_pragma] = STATE(3935),
    [sym_preproc_nullable] = STATE(3935),
    [sym_preproc_error] = STATE(3935),
    [sym_preproc_warning] = STATE(3935),
    [sym_preproc_define] = STATE(3935),
    [sym_preproc_undef] = STATE(3935),
    [anon_sym_SEMI] = ACTIONS(5363),
    [anon_sym_LBRACK] = ACTIONS(5363),
    [anon_sym_COLON] = ACTIONS(5363),
    [anon_sym_COMMA] = ACTIONS(5363),
    [anon_sym_RBRACK] = ACTIONS(5363),
    [anon_sym_LPAREN] = ACTIONS(5363),
    [anon_sym_RPAREN] = ACTIONS(5363),
    [anon_sym_RBRACE] = ACTIONS(5363),
    [anon_sym_LT] = ACTIONS(5365),
    [anon_sym_GT] = ACTIONS(5365),
    [anon_sym_in] = ACTIONS(5363),
    [anon_sym_QMARK] = ACTIONS(5365),
    [anon_sym_BANG] = ACTIONS(5365),
    [anon_sym_PLUS_PLUS] = ACTIONS(5363),
    [anon_sym_DASH_DASH] = ACTIONS(5363),
    [anon_sym_PLUS] = ACTIONS(5365),
    [anon_sym_DASH] = ACTIONS(5365),
    [anon_sym_STAR] = ACTIONS(5363),
    [anon_sym_SLASH] = ACTIONS(5365),
    [anon_sym_PERCENT] = ACTIONS(5363),
    [anon_sym_CARET] = ACTIONS(5363),
    [anon_sym_PIPE] = ACTIONS(5365),
    [anon_sym_AMP] = ACTIONS(5365),
    [anon_sym_LT_LT] = ACTIONS(5363),
    [anon_sym_GT_GT] = ACTIONS(5365),
    [anon_sym_GT_GT_GT] = ACTIONS(5363),
    [anon_sym_EQ_EQ] = ACTIONS(5363),
    [anon_sym_BANG_EQ] = ACTIONS(5363),
    [anon_sym_GT_EQ] = ACTIONS(5363),
    [anon_sym_LT_EQ] = ACTIONS(5363),
    [anon_sym_DOT] = ACTIONS(5365),
    [anon_sym_EQ_GT] = ACTIONS(5363),
    [anon_sym_switch] = ACTIONS(5363),
    [anon_sym_when] = ACTIONS(5363),
    [anon_sym_DOT_DOT] = ACTIONS(5363),
    [anon_sym_and] = ACTIONS(5363),
    [anon_sym_or] = ACTIONS(5363),
    [anon_sym_AMP_AMP] = ACTIONS(5363),
    [anon_sym_PIPE_PIPE] = ACTIONS(5363),
    [anon_sym_QMARK_QMARK] = ACTIONS(5363),
    [anon_sym_on] = ACTIONS(5363),
    [anon_sym_equals] = ACTIONS(5363),
    [anon_sym_by] = ACTIONS(5363),
    [anon_sym_as] = ACTIONS(5363),
    [anon_sym_is] = ACTIONS(5363),
    [anon_sym_DASH_GT] = ACTIONS(5363),
    [anon_sym_with] = ACTIONS(5363),
    [anon_sym_DQUOTE] = ACTIONS(5363),
    [sym_string_literal_encoding] = ACTIONS(5842),
    [aux_sym_preproc_if_token3] = ACTIONS(5363),
    [aux_sym_preproc_else_token1] = ACTIONS(5363),
    [aux_sym_preproc_elif_token1] = ACTIONS(5363),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3936] = {
    [sym_preproc_region] = STATE(3936),
    [sym_preproc_endregion] = STATE(3936),
    [sym_preproc_line] = STATE(3936),
    [sym_preproc_pragma] = STATE(3936),
    [sym_preproc_nullable] = STATE(3936),
    [sym_preproc_error] = STATE(3936),
    [sym_preproc_warning] = STATE(3936),
    [sym_preproc_define] = STATE(3936),
    [sym_preproc_undef] = STATE(3936),
    [anon_sym_SEMI] = ACTIONS(3993),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_COLON] = ACTIONS(3993),
    [anon_sym_COMMA] = ACTIONS(3993),
    [anon_sym_RBRACK] = ACTIONS(3993),
    [anon_sym_LPAREN] = ACTIONS(3993),
    [anon_sym_RPAREN] = ACTIONS(3993),
    [anon_sym_LBRACE] = ACTIONS(3993),
    [anon_sym_RBRACE] = ACTIONS(3993),
    [anon_sym_LT] = ACTIONS(3995),
    [anon_sym_GT] = ACTIONS(3995),
    [anon_sym_in] = ACTIONS(3995),
    [anon_sym_QMARK] = ACTIONS(3995),
    [anon_sym_BANG] = ACTIONS(3995),
    [anon_sym_PLUS_PLUS] = ACTIONS(3993),
    [anon_sym_DASH_DASH] = ACTIONS(3993),
    [anon_sym_PLUS] = ACTIONS(3995),
    [anon_sym_DASH] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3993),
    [anon_sym_SLASH] = ACTIONS(3995),
    [anon_sym_PERCENT] = ACTIONS(3993),
    [anon_sym_CARET] = ACTIONS(3993),
    [anon_sym_PIPE] = ACTIONS(3995),
    [anon_sym_AMP] = ACTIONS(3995),
    [anon_sym_LT_LT] = ACTIONS(3993),
    [anon_sym_GT_GT] = ACTIONS(3995),
    [anon_sym_GT_GT_GT] = ACTIONS(3993),
    [anon_sym_EQ_EQ] = ACTIONS(3993),
    [anon_sym_BANG_EQ] = ACTIONS(3993),
    [anon_sym_GT_EQ] = ACTIONS(3993),
    [anon_sym_LT_EQ] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3995),
    [anon_sym_EQ_GT] = ACTIONS(3993),
    [anon_sym_switch] = ACTIONS(3993),
    [anon_sym_when] = ACTIONS(3993),
    [anon_sym_DOT_DOT] = ACTIONS(3993),
    [anon_sym_and] = ACTIONS(3993),
    [anon_sym_or] = ACTIONS(3993),
    [anon_sym_AMP_AMP] = ACTIONS(3993),
    [anon_sym_PIPE_PIPE] = ACTIONS(3993),
    [anon_sym_QMARK_QMARK] = ACTIONS(3993),
    [anon_sym_into] = ACTIONS(3993),
    [anon_sym_on] = ACTIONS(3993),
    [anon_sym_equals] = ACTIONS(3993),
    [anon_sym_by] = ACTIONS(3993),
    [anon_sym_as] = ACTIONS(3993),
    [anon_sym_is] = ACTIONS(3993),
    [anon_sym_DASH_GT] = ACTIONS(3993),
    [anon_sym_with] = ACTIONS(3993),
    [aux_sym_preproc_if_token3] = ACTIONS(3993),
    [aux_sym_preproc_else_token1] = ACTIONS(3993),
    [aux_sym_preproc_elif_token1] = ACTIONS(3993),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3937] = {
    [sym_preproc_region] = STATE(3937),
    [sym_preproc_endregion] = STATE(3937),
    [sym_preproc_line] = STATE(3937),
    [sym_preproc_pragma] = STATE(3937),
    [sym_preproc_nullable] = STATE(3937),
    [sym_preproc_error] = STATE(3937),
    [sym_preproc_warning] = STATE(3937),
    [sym_preproc_define] = STATE(3937),
    [sym_preproc_undef] = STATE(3937),
    [anon_sym_SEMI] = ACTIONS(5388),
    [anon_sym_LBRACK] = ACTIONS(5388),
    [anon_sym_COLON] = ACTIONS(5388),
    [anon_sym_COMMA] = ACTIONS(5388),
    [anon_sym_RBRACK] = ACTIONS(5388),
    [anon_sym_LPAREN] = ACTIONS(5388),
    [anon_sym_RPAREN] = ACTIONS(5388),
    [anon_sym_RBRACE] = ACTIONS(5388),
    [anon_sym_LT] = ACTIONS(5390),
    [anon_sym_GT] = ACTIONS(5390),
    [anon_sym_in] = ACTIONS(5390),
    [anon_sym_QMARK] = ACTIONS(5390),
    [anon_sym_BANG] = ACTIONS(5390),
    [anon_sym_PLUS_PLUS] = ACTIONS(5388),
    [anon_sym_DASH_DASH] = ACTIONS(5388),
    [anon_sym_PLUS] = ACTIONS(5390),
    [anon_sym_DASH] = ACTIONS(5390),
    [anon_sym_STAR] = ACTIONS(5388),
    [anon_sym_SLASH] = ACTIONS(5390),
    [anon_sym_PERCENT] = ACTIONS(5388),
    [anon_sym_CARET] = ACTIONS(5388),
    [anon_sym_PIPE] = ACTIONS(5390),
    [anon_sym_AMP] = ACTIONS(5390),
    [anon_sym_LT_LT] = ACTIONS(5388),
    [anon_sym_GT_GT] = ACTIONS(5390),
    [anon_sym_GT_GT_GT] = ACTIONS(5388),
    [anon_sym_EQ_EQ] = ACTIONS(5388),
    [anon_sym_BANG_EQ] = ACTIONS(5388),
    [anon_sym_GT_EQ] = ACTIONS(5388),
    [anon_sym_LT_EQ] = ACTIONS(5388),
    [anon_sym_DOT] = ACTIONS(5390),
    [anon_sym_EQ_GT] = ACTIONS(5388),
    [anon_sym_switch] = ACTIONS(5388),
    [anon_sym_when] = ACTIONS(5388),
    [anon_sym_DOT_DOT] = ACTIONS(5388),
    [anon_sym_and] = ACTIONS(5388),
    [anon_sym_or] = ACTIONS(5388),
    [anon_sym_AMP_AMP] = ACTIONS(5388),
    [anon_sym_PIPE_PIPE] = ACTIONS(5388),
    [anon_sym_QMARK_QMARK] = ACTIONS(5388),
    [anon_sym_into] = ACTIONS(5388),
    [anon_sym_on] = ACTIONS(5388),
    [anon_sym_equals] = ACTIONS(5388),
    [anon_sym_by] = ACTIONS(5388),
    [anon_sym_as] = ACTIONS(5388),
    [anon_sym_is] = ACTIONS(5388),
    [anon_sym_DASH_GT] = ACTIONS(5388),
    [anon_sym_with] = ACTIONS(5388),
    [aux_sym_raw_string_literal_token1] = ACTIONS(5844),
    [aux_sym_preproc_if_token3] = ACTIONS(5388),
    [aux_sym_preproc_else_token1] = ACTIONS(5388),
    [aux_sym_preproc_elif_token1] = ACTIONS(5388),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3938] = {
    [sym_preproc_region] = STATE(3938),
    [sym_preproc_endregion] = STATE(3938),
    [sym_preproc_line] = STATE(3938),
    [sym_preproc_pragma] = STATE(3938),
    [sym_preproc_nullable] = STATE(3938),
    [sym_preproc_error] = STATE(3938),
    [sym_preproc_warning] = STATE(3938),
    [sym_preproc_define] = STATE(3938),
    [sym_preproc_undef] = STATE(3938),
    [anon_sym_EQ] = ACTIONS(4701),
    [anon_sym_LBRACK] = ACTIONS(4699),
    [anon_sym_COLON] = ACTIONS(4699),
    [anon_sym_COMMA] = ACTIONS(4699),
    [anon_sym_LPAREN] = ACTIONS(4699),
    [anon_sym_LT] = ACTIONS(4701),
    [anon_sym_GT] = ACTIONS(4701),
    [anon_sym_QMARK] = ACTIONS(4701),
    [anon_sym_BANG] = ACTIONS(4701),
    [anon_sym_PLUS_PLUS] = ACTIONS(4699),
    [anon_sym_DASH_DASH] = ACTIONS(4699),
    [anon_sym_PLUS] = ACTIONS(4701),
    [anon_sym_DASH] = ACTIONS(4701),
    [anon_sym_STAR] = ACTIONS(4701),
    [anon_sym_SLASH] = ACTIONS(4701),
    [anon_sym_PERCENT] = ACTIONS(4701),
    [anon_sym_CARET] = ACTIONS(4701),
    [anon_sym_PIPE] = ACTIONS(4701),
    [anon_sym_AMP] = ACTIONS(4701),
    [anon_sym_LT_LT] = ACTIONS(4701),
    [anon_sym_GT_GT] = ACTIONS(4701),
    [anon_sym_GT_GT_GT] = ACTIONS(4701),
    [anon_sym_EQ_EQ] = ACTIONS(4699),
    [anon_sym_BANG_EQ] = ACTIONS(4699),
    [anon_sym_GT_EQ] = ACTIONS(4699),
    [anon_sym_LT_EQ] = ACTIONS(4699),
    [anon_sym_DOT] = ACTIONS(4701),
    [anon_sym_switch] = ACTIONS(4699),
    [anon_sym_DOT_DOT] = ACTIONS(4699),
    [anon_sym_and] = ACTIONS(4699),
    [anon_sym_or] = ACTIONS(4699),
    [anon_sym_PLUS_EQ] = ACTIONS(4699),
    [anon_sym_DASH_EQ] = ACTIONS(4699),
    [anon_sym_STAR_EQ] = ACTIONS(4699),
    [anon_sym_SLASH_EQ] = ACTIONS(4699),
    [anon_sym_PERCENT_EQ] = ACTIONS(4699),
    [anon_sym_AMP_EQ] = ACTIONS(4699),
    [anon_sym_CARET_EQ] = ACTIONS(4699),
    [anon_sym_PIPE_EQ] = ACTIONS(4699),
    [anon_sym_LT_LT_EQ] = ACTIONS(4699),
    [anon_sym_GT_GT_EQ] = ACTIONS(4699),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4699),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4699),
    [anon_sym_AMP_AMP] = ACTIONS(4699),
    [anon_sym_PIPE_PIPE] = ACTIONS(4699),
    [anon_sym_QMARK_QMARK] = ACTIONS(4701),
    [anon_sym_into] = ACTIONS(4699),
    [anon_sym_as] = ACTIONS(4699),
    [anon_sym_is] = ACTIONS(4699),
    [anon_sym_DASH_GT] = ACTIONS(4699),
    [anon_sym_with] = ACTIONS(4699),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4699),
  },
  [3939] = {
    [sym_preproc_region] = STATE(3939),
    [sym_preproc_endregion] = STATE(3939),
    [sym_preproc_line] = STATE(3939),
    [sym_preproc_pragma] = STATE(3939),
    [sym_preproc_nullable] = STATE(3939),
    [sym_preproc_error] = STATE(3939),
    [sym_preproc_warning] = STATE(3939),
    [sym_preproc_define] = STATE(3939),
    [sym_preproc_undef] = STATE(3939),
    [anon_sym_SEMI] = ACTIONS(4124),
    [anon_sym_LBRACK] = ACTIONS(4124),
    [anon_sym_COLON] = ACTIONS(4124),
    [anon_sym_COMMA] = ACTIONS(4124),
    [anon_sym_RBRACK] = ACTIONS(4124),
    [anon_sym_LPAREN] = ACTIONS(4124),
    [anon_sym_RPAREN] = ACTIONS(4124),
    [anon_sym_LBRACE] = ACTIONS(4124),
    [anon_sym_RBRACE] = ACTIONS(4124),
    [anon_sym_LT] = ACTIONS(4122),
    [anon_sym_GT] = ACTIONS(4122),
    [anon_sym_in] = ACTIONS(4122),
    [anon_sym_QMARK] = ACTIONS(4122),
    [anon_sym_BANG] = ACTIONS(4122),
    [anon_sym_PLUS_PLUS] = ACTIONS(4124),
    [anon_sym_DASH_DASH] = ACTIONS(4124),
    [anon_sym_PLUS] = ACTIONS(4122),
    [anon_sym_DASH] = ACTIONS(4122),
    [anon_sym_STAR] = ACTIONS(4124),
    [anon_sym_SLASH] = ACTIONS(4122),
    [anon_sym_PERCENT] = ACTIONS(4124),
    [anon_sym_CARET] = ACTIONS(4124),
    [anon_sym_PIPE] = ACTIONS(4122),
    [anon_sym_AMP] = ACTIONS(4122),
    [anon_sym_LT_LT] = ACTIONS(4124),
    [anon_sym_GT_GT] = ACTIONS(4122),
    [anon_sym_GT_GT_GT] = ACTIONS(4124),
    [anon_sym_EQ_EQ] = ACTIONS(4124),
    [anon_sym_BANG_EQ] = ACTIONS(4124),
    [anon_sym_GT_EQ] = ACTIONS(4124),
    [anon_sym_LT_EQ] = ACTIONS(4124),
    [anon_sym_DOT] = ACTIONS(4122),
    [anon_sym_EQ_GT] = ACTIONS(4124),
    [anon_sym_switch] = ACTIONS(4124),
    [anon_sym_when] = ACTIONS(4124),
    [anon_sym_DOT_DOT] = ACTIONS(4124),
    [anon_sym_and] = ACTIONS(4124),
    [anon_sym_or] = ACTIONS(4124),
    [anon_sym_AMP_AMP] = ACTIONS(4124),
    [anon_sym_PIPE_PIPE] = ACTIONS(4124),
    [anon_sym_QMARK_QMARK] = ACTIONS(4124),
    [anon_sym_into] = ACTIONS(4124),
    [anon_sym_on] = ACTIONS(4124),
    [anon_sym_equals] = ACTIONS(4124),
    [anon_sym_by] = ACTIONS(4124),
    [anon_sym_as] = ACTIONS(4124),
    [anon_sym_is] = ACTIONS(4124),
    [anon_sym_DASH_GT] = ACTIONS(4124),
    [anon_sym_with] = ACTIONS(4124),
    [aux_sym_preproc_if_token3] = ACTIONS(4124),
    [aux_sym_preproc_else_token1] = ACTIONS(4124),
    [aux_sym_preproc_elif_token1] = ACTIONS(4124),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3940] = {
    [sym_preproc_region] = STATE(3940),
    [sym_preproc_endregion] = STATE(3940),
    [sym_preproc_line] = STATE(3940),
    [sym_preproc_pragma] = STATE(3940),
    [sym_preproc_nullable] = STATE(3940),
    [sym_preproc_error] = STATE(3940),
    [sym_preproc_warning] = STATE(3940),
    [sym_preproc_define] = STATE(3940),
    [sym_preproc_undef] = STATE(3940),
    [anon_sym_EQ] = ACTIONS(4162),
    [anon_sym_LBRACK] = ACTIONS(4808),
    [anon_sym_COLON] = ACTIONS(4806),
    [anon_sym_COMMA] = ACTIONS(4806),
    [anon_sym_LPAREN] = ACTIONS(4808),
    [anon_sym_LT] = ACTIONS(4811),
    [anon_sym_GT] = ACTIONS(4811),
    [anon_sym_QMARK] = ACTIONS(4811),
    [anon_sym_BANG] = ACTIONS(4811),
    [anon_sym_PLUS_PLUS] = ACTIONS(4808),
    [anon_sym_DASH_DASH] = ACTIONS(4808),
    [anon_sym_PLUS] = ACTIONS(4811),
    [anon_sym_DASH] = ACTIONS(4811),
    [anon_sym_STAR] = ACTIONS(4811),
    [anon_sym_SLASH] = ACTIONS(4811),
    [anon_sym_PERCENT] = ACTIONS(4811),
    [anon_sym_CARET] = ACTIONS(4811),
    [anon_sym_PIPE] = ACTIONS(4811),
    [anon_sym_AMP] = ACTIONS(4811),
    [anon_sym_LT_LT] = ACTIONS(4811),
    [anon_sym_GT_GT] = ACTIONS(4811),
    [anon_sym_GT_GT_GT] = ACTIONS(4811),
    [anon_sym_EQ_EQ] = ACTIONS(4808),
    [anon_sym_BANG_EQ] = ACTIONS(4808),
    [anon_sym_GT_EQ] = ACTIONS(4808),
    [anon_sym_LT_EQ] = ACTIONS(4808),
    [anon_sym_DOT] = ACTIONS(4811),
    [anon_sym_switch] = ACTIONS(4808),
    [anon_sym_DOT_DOT] = ACTIONS(4808),
    [anon_sym_and] = ACTIONS(4806),
    [anon_sym_or] = ACTIONS(4806),
    [anon_sym_PLUS_EQ] = ACTIONS(4177),
    [anon_sym_DASH_EQ] = ACTIONS(4177),
    [anon_sym_STAR_EQ] = ACTIONS(4177),
    [anon_sym_SLASH_EQ] = ACTIONS(4177),
    [anon_sym_PERCENT_EQ] = ACTIONS(4177),
    [anon_sym_AMP_EQ] = ACTIONS(4177),
    [anon_sym_CARET_EQ] = ACTIONS(4177),
    [anon_sym_PIPE_EQ] = ACTIONS(4177),
    [anon_sym_LT_LT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4177),
    [anon_sym_AMP_AMP] = ACTIONS(4808),
    [anon_sym_PIPE_PIPE] = ACTIONS(4808),
    [anon_sym_QMARK_QMARK] = ACTIONS(4811),
    [anon_sym_into] = ACTIONS(4806),
    [anon_sym_as] = ACTIONS(4808),
    [anon_sym_is] = ACTIONS(4808),
    [anon_sym_DASH_GT] = ACTIONS(4808),
    [anon_sym_with] = ACTIONS(4808),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4806),
  },
  [3941] = {
    [sym_preproc_region] = STATE(3941),
    [sym_preproc_endregion] = STATE(3941),
    [sym_preproc_line] = STATE(3941),
    [sym_preproc_pragma] = STATE(3941),
    [sym_preproc_nullable] = STATE(3941),
    [sym_preproc_error] = STATE(3941),
    [sym_preproc_warning] = STATE(3941),
    [sym_preproc_define] = STATE(3941),
    [sym_preproc_undef] = STATE(3941),
    [anon_sym_SEMI] = ACTIONS(5353),
    [anon_sym_LBRACK] = ACTIONS(5353),
    [anon_sym_COLON] = ACTIONS(5353),
    [anon_sym_COMMA] = ACTIONS(5353),
    [anon_sym_RBRACK] = ACTIONS(5353),
    [anon_sym_LPAREN] = ACTIONS(5353),
    [anon_sym_RPAREN] = ACTIONS(5353),
    [anon_sym_LBRACE] = ACTIONS(5353),
    [anon_sym_RBRACE] = ACTIONS(5353),
    [anon_sym_LT] = ACTIONS(5355),
    [anon_sym_GT] = ACTIONS(5355),
    [anon_sym_in] = ACTIONS(5355),
    [anon_sym_QMARK] = ACTIONS(5355),
    [anon_sym_BANG] = ACTIONS(5355),
    [anon_sym_PLUS_PLUS] = ACTIONS(5353),
    [anon_sym_DASH_DASH] = ACTIONS(5353),
    [anon_sym_PLUS] = ACTIONS(5355),
    [anon_sym_DASH] = ACTIONS(5355),
    [anon_sym_STAR] = ACTIONS(5353),
    [anon_sym_SLASH] = ACTIONS(5355),
    [anon_sym_PERCENT] = ACTIONS(5353),
    [anon_sym_CARET] = ACTIONS(5353),
    [anon_sym_PIPE] = ACTIONS(5355),
    [anon_sym_AMP] = ACTIONS(5355),
    [anon_sym_LT_LT] = ACTIONS(5353),
    [anon_sym_GT_GT] = ACTIONS(5355),
    [anon_sym_GT_GT_GT] = ACTIONS(5353),
    [anon_sym_EQ_EQ] = ACTIONS(5353),
    [anon_sym_BANG_EQ] = ACTIONS(5353),
    [anon_sym_GT_EQ] = ACTIONS(5353),
    [anon_sym_LT_EQ] = ACTIONS(5353),
    [anon_sym_DOT] = ACTIONS(5355),
    [anon_sym_EQ_GT] = ACTIONS(5353),
    [anon_sym_switch] = ACTIONS(5353),
    [anon_sym_when] = ACTIONS(5353),
    [anon_sym_DOT_DOT] = ACTIONS(5353),
    [anon_sym_and] = ACTIONS(5353),
    [anon_sym_or] = ACTIONS(5353),
    [anon_sym_AMP_AMP] = ACTIONS(5353),
    [anon_sym_PIPE_PIPE] = ACTIONS(5353),
    [anon_sym_QMARK_QMARK] = ACTIONS(5353),
    [anon_sym_into] = ACTIONS(5353),
    [anon_sym_on] = ACTIONS(5353),
    [anon_sym_equals] = ACTIONS(5353),
    [anon_sym_by] = ACTIONS(5353),
    [anon_sym_as] = ACTIONS(5353),
    [anon_sym_is] = ACTIONS(5353),
    [anon_sym_DASH_GT] = ACTIONS(5353),
    [anon_sym_with] = ACTIONS(5353),
    [aux_sym_preproc_if_token3] = ACTIONS(5353),
    [aux_sym_preproc_else_token1] = ACTIONS(5353),
    [aux_sym_preproc_elif_token1] = ACTIONS(5353),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3942] = {
    [sym_preproc_region] = STATE(3942),
    [sym_preproc_endregion] = STATE(3942),
    [sym_preproc_line] = STATE(3942),
    [sym_preproc_pragma] = STATE(3942),
    [sym_preproc_nullable] = STATE(3942),
    [sym_preproc_error] = STATE(3942),
    [sym_preproc_warning] = STATE(3942),
    [sym_preproc_define] = STATE(3942),
    [sym_preproc_undef] = STATE(3942),
    [anon_sym_SEMI] = ACTIONS(5359),
    [anon_sym_LBRACK] = ACTIONS(5359),
    [anon_sym_COLON] = ACTIONS(5359),
    [anon_sym_COMMA] = ACTIONS(5359),
    [anon_sym_RBRACK] = ACTIONS(5359),
    [anon_sym_LPAREN] = ACTIONS(5359),
    [anon_sym_RPAREN] = ACTIONS(5359),
    [anon_sym_LBRACE] = ACTIONS(5359),
    [anon_sym_RBRACE] = ACTIONS(5359),
    [anon_sym_LT] = ACTIONS(5361),
    [anon_sym_GT] = ACTIONS(5361),
    [anon_sym_in] = ACTIONS(5359),
    [anon_sym_where] = ACTIONS(5359),
    [anon_sym_QMARK] = ACTIONS(5361),
    [anon_sym_BANG] = ACTIONS(5361),
    [anon_sym_PLUS_PLUS] = ACTIONS(5359),
    [anon_sym_DASH_DASH] = ACTIONS(5359),
    [anon_sym_PLUS] = ACTIONS(5361),
    [anon_sym_DASH] = ACTIONS(5361),
    [anon_sym_STAR] = ACTIONS(5359),
    [anon_sym_SLASH] = ACTIONS(5361),
    [anon_sym_PERCENT] = ACTIONS(5359),
    [anon_sym_CARET] = ACTIONS(5359),
    [anon_sym_PIPE] = ACTIONS(5361),
    [anon_sym_AMP] = ACTIONS(5361),
    [anon_sym_LT_LT] = ACTIONS(5359),
    [anon_sym_GT_GT] = ACTIONS(5361),
    [anon_sym_GT_GT_GT] = ACTIONS(5359),
    [anon_sym_EQ_EQ] = ACTIONS(5359),
    [anon_sym_BANG_EQ] = ACTIONS(5359),
    [anon_sym_GT_EQ] = ACTIONS(5359),
    [anon_sym_LT_EQ] = ACTIONS(5359),
    [anon_sym_DOT] = ACTIONS(5361),
    [anon_sym_EQ_GT] = ACTIONS(5359),
    [anon_sym_switch] = ACTIONS(5359),
    [anon_sym_when] = ACTIONS(5359),
    [anon_sym_DOT_DOT] = ACTIONS(5359),
    [anon_sym_and] = ACTIONS(5359),
    [anon_sym_or] = ACTIONS(5359),
    [anon_sym_AMP_AMP] = ACTIONS(5359),
    [anon_sym_PIPE_PIPE] = ACTIONS(5359),
    [anon_sym_QMARK_QMARK] = ACTIONS(5359),
    [anon_sym_on] = ACTIONS(5359),
    [anon_sym_equals] = ACTIONS(5359),
    [anon_sym_by] = ACTIONS(5359),
    [anon_sym_as] = ACTIONS(5359),
    [anon_sym_is] = ACTIONS(5359),
    [anon_sym_DASH_GT] = ACTIONS(5359),
    [anon_sym_with] = ACTIONS(5359),
    [aux_sym_preproc_if_token3] = ACTIONS(5359),
    [aux_sym_preproc_else_token1] = ACTIONS(5359),
    [aux_sym_preproc_elif_token1] = ACTIONS(5359),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3943] = {
    [sym_preproc_region] = STATE(3943),
    [sym_preproc_endregion] = STATE(3943),
    [sym_preproc_line] = STATE(3943),
    [sym_preproc_pragma] = STATE(3943),
    [sym_preproc_nullable] = STATE(3943),
    [sym_preproc_error] = STATE(3943),
    [sym_preproc_warning] = STATE(3943),
    [sym_preproc_define] = STATE(3943),
    [sym_preproc_undef] = STATE(3943),
    [anon_sym_SEMI] = ACTIONS(4494),
    [anon_sym_LBRACK] = ACTIONS(4494),
    [anon_sym_COLON] = ACTIONS(4494),
    [anon_sym_COMMA] = ACTIONS(4494),
    [anon_sym_RBRACK] = ACTIONS(4494),
    [anon_sym_LPAREN] = ACTIONS(4494),
    [anon_sym_RPAREN] = ACTIONS(4494),
    [anon_sym_LBRACE] = ACTIONS(4494),
    [anon_sym_RBRACE] = ACTIONS(4494),
    [anon_sym_LT] = ACTIONS(4492),
    [anon_sym_GT] = ACTIONS(4492),
    [anon_sym_in] = ACTIONS(4492),
    [anon_sym_QMARK] = ACTIONS(4492),
    [anon_sym_BANG] = ACTIONS(4492),
    [anon_sym_PLUS_PLUS] = ACTIONS(4494),
    [anon_sym_DASH_DASH] = ACTIONS(4494),
    [anon_sym_PLUS] = ACTIONS(4492),
    [anon_sym_DASH] = ACTIONS(4492),
    [anon_sym_STAR] = ACTIONS(4494),
    [anon_sym_SLASH] = ACTIONS(4492),
    [anon_sym_PERCENT] = ACTIONS(4494),
    [anon_sym_CARET] = ACTIONS(4494),
    [anon_sym_PIPE] = ACTIONS(4492),
    [anon_sym_AMP] = ACTIONS(4492),
    [anon_sym_LT_LT] = ACTIONS(4494),
    [anon_sym_GT_GT] = ACTIONS(4492),
    [anon_sym_GT_GT_GT] = ACTIONS(4494),
    [anon_sym_EQ_EQ] = ACTIONS(4494),
    [anon_sym_BANG_EQ] = ACTIONS(4494),
    [anon_sym_GT_EQ] = ACTIONS(4494),
    [anon_sym_LT_EQ] = ACTIONS(4494),
    [anon_sym_DOT] = ACTIONS(4492),
    [anon_sym_EQ_GT] = ACTIONS(4494),
    [anon_sym_switch] = ACTIONS(4494),
    [anon_sym_when] = ACTIONS(4494),
    [anon_sym_DOT_DOT] = ACTIONS(4494),
    [anon_sym_and] = ACTIONS(4494),
    [anon_sym_or] = ACTIONS(4494),
    [anon_sym_AMP_AMP] = ACTIONS(4494),
    [anon_sym_PIPE_PIPE] = ACTIONS(4494),
    [anon_sym_QMARK_QMARK] = ACTIONS(4494),
    [anon_sym_into] = ACTIONS(4494),
    [anon_sym_on] = ACTIONS(4494),
    [anon_sym_equals] = ACTIONS(4494),
    [anon_sym_by] = ACTIONS(4494),
    [anon_sym_as] = ACTIONS(4494),
    [anon_sym_is] = ACTIONS(4494),
    [anon_sym_DASH_GT] = ACTIONS(4494),
    [anon_sym_with] = ACTIONS(4494),
    [aux_sym_preproc_if_token3] = ACTIONS(4494),
    [aux_sym_preproc_else_token1] = ACTIONS(4494),
    [aux_sym_preproc_elif_token1] = ACTIONS(4494),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3944] = {
    [sym_preproc_region] = STATE(3944),
    [sym_preproc_endregion] = STATE(3944),
    [sym_preproc_line] = STATE(3944),
    [sym_preproc_pragma] = STATE(3944),
    [sym_preproc_nullable] = STATE(3944),
    [sym_preproc_error] = STATE(3944),
    [sym_preproc_warning] = STATE(3944),
    [sym_preproc_define] = STATE(3944),
    [sym_preproc_undef] = STATE(3944),
    [anon_sym_EQ] = ACTIONS(4672),
    [anon_sym_LBRACK] = ACTIONS(4703),
    [anon_sym_COLON] = ACTIONS(4703),
    [anon_sym_COMMA] = ACTIONS(4703),
    [anon_sym_LPAREN] = ACTIONS(4703),
    [anon_sym_LT] = ACTIONS(4705),
    [anon_sym_GT] = ACTIONS(4705),
    [anon_sym_QMARK] = ACTIONS(4705),
    [anon_sym_BANG] = ACTIONS(4705),
    [anon_sym_PLUS_PLUS] = ACTIONS(4703),
    [anon_sym_DASH_DASH] = ACTIONS(4703),
    [anon_sym_PLUS] = ACTIONS(4705),
    [anon_sym_DASH] = ACTIONS(4705),
    [anon_sym_STAR] = ACTIONS(4705),
    [anon_sym_SLASH] = ACTIONS(4705),
    [anon_sym_PERCENT] = ACTIONS(4705),
    [anon_sym_CARET] = ACTIONS(4705),
    [anon_sym_PIPE] = ACTIONS(4705),
    [anon_sym_AMP] = ACTIONS(4705),
    [anon_sym_LT_LT] = ACTIONS(4705),
    [anon_sym_GT_GT] = ACTIONS(4705),
    [anon_sym_GT_GT_GT] = ACTIONS(4705),
    [anon_sym_EQ_EQ] = ACTIONS(4703),
    [anon_sym_BANG_EQ] = ACTIONS(4703),
    [anon_sym_GT_EQ] = ACTIONS(4703),
    [anon_sym_LT_EQ] = ACTIONS(4703),
    [anon_sym_DOT] = ACTIONS(4705),
    [anon_sym_switch] = ACTIONS(4703),
    [anon_sym_DOT_DOT] = ACTIONS(4703),
    [anon_sym_and] = ACTIONS(4703),
    [anon_sym_or] = ACTIONS(4703),
    [anon_sym_PLUS_EQ] = ACTIONS(4670),
    [anon_sym_DASH_EQ] = ACTIONS(4670),
    [anon_sym_STAR_EQ] = ACTIONS(4670),
    [anon_sym_SLASH_EQ] = ACTIONS(4670),
    [anon_sym_PERCENT_EQ] = ACTIONS(4670),
    [anon_sym_AMP_EQ] = ACTIONS(4670),
    [anon_sym_CARET_EQ] = ACTIONS(4670),
    [anon_sym_PIPE_EQ] = ACTIONS(4670),
    [anon_sym_LT_LT_EQ] = ACTIONS(4670),
    [anon_sym_GT_GT_EQ] = ACTIONS(4670),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4670),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4670),
    [anon_sym_AMP_AMP] = ACTIONS(4703),
    [anon_sym_PIPE_PIPE] = ACTIONS(4703),
    [anon_sym_QMARK_QMARK] = ACTIONS(4705),
    [anon_sym_into] = ACTIONS(4703),
    [anon_sym_as] = ACTIONS(4703),
    [anon_sym_is] = ACTIONS(4703),
    [anon_sym_DASH_GT] = ACTIONS(4703),
    [anon_sym_with] = ACTIONS(4703),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4703),
  },
  [3945] = {
    [sym_preproc_region] = STATE(3945),
    [sym_preproc_endregion] = STATE(3945),
    [sym_preproc_line] = STATE(3945),
    [sym_preproc_pragma] = STATE(3945),
    [sym_preproc_nullable] = STATE(3945),
    [sym_preproc_error] = STATE(3945),
    [sym_preproc_warning] = STATE(3945),
    [sym_preproc_define] = STATE(3945),
    [sym_preproc_undef] = STATE(3945),
    [anon_sym_SEMI] = ACTIONS(4494),
    [anon_sym_LBRACK] = ACTIONS(4593),
    [anon_sym_COLON] = ACTIONS(4494),
    [anon_sym_COMMA] = ACTIONS(4494),
    [anon_sym_RBRACK] = ACTIONS(4494),
    [anon_sym_LPAREN] = ACTIONS(4494),
    [anon_sym_RPAREN] = ACTIONS(4494),
    [anon_sym_LBRACE] = ACTIONS(4494),
    [anon_sym_RBRACE] = ACTIONS(4494),
    [anon_sym_LT] = ACTIONS(4492),
    [anon_sym_GT] = ACTIONS(4492),
    [anon_sym_in] = ACTIONS(4492),
    [anon_sym_QMARK] = ACTIONS(5808),
    [anon_sym_BANG] = ACTIONS(4492),
    [anon_sym_PLUS_PLUS] = ACTIONS(4494),
    [anon_sym_DASH_DASH] = ACTIONS(4494),
    [anon_sym_PLUS] = ACTIONS(4492),
    [anon_sym_DASH] = ACTIONS(4492),
    [anon_sym_STAR] = ACTIONS(4494),
    [anon_sym_SLASH] = ACTIONS(4492),
    [anon_sym_PERCENT] = ACTIONS(4494),
    [anon_sym_CARET] = ACTIONS(4494),
    [anon_sym_PIPE] = ACTIONS(4492),
    [anon_sym_AMP] = ACTIONS(4492),
    [anon_sym_LT_LT] = ACTIONS(4494),
    [anon_sym_GT_GT] = ACTIONS(4492),
    [anon_sym_GT_GT_GT] = ACTIONS(4494),
    [anon_sym_EQ_EQ] = ACTIONS(4494),
    [anon_sym_BANG_EQ] = ACTIONS(4494),
    [anon_sym_GT_EQ] = ACTIONS(4494),
    [anon_sym_LT_EQ] = ACTIONS(4494),
    [anon_sym_DOT] = ACTIONS(4492),
    [anon_sym_EQ_GT] = ACTIONS(4494),
    [anon_sym_switch] = ACTIONS(4494),
    [anon_sym_when] = ACTIONS(4494),
    [anon_sym_DOT_DOT] = ACTIONS(4494),
    [anon_sym_and] = ACTIONS(4494),
    [anon_sym_or] = ACTIONS(4494),
    [anon_sym_AMP_AMP] = ACTIONS(4494),
    [anon_sym_PIPE_PIPE] = ACTIONS(4494),
    [anon_sym_QMARK_QMARK] = ACTIONS(4494),
    [anon_sym_into] = ACTIONS(4494),
    [anon_sym_on] = ACTIONS(4494),
    [anon_sym_equals] = ACTIONS(4494),
    [anon_sym_by] = ACTIONS(4494),
    [anon_sym_as] = ACTIONS(4494),
    [anon_sym_is] = ACTIONS(4494),
    [anon_sym_DASH_GT] = ACTIONS(4494),
    [anon_sym_with] = ACTIONS(4494),
    [aux_sym_preproc_if_token3] = ACTIONS(4494),
    [aux_sym_preproc_else_token1] = ACTIONS(4494),
    [aux_sym_preproc_elif_token1] = ACTIONS(4494),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3946] = {
    [sym_preproc_region] = STATE(3946),
    [sym_preproc_endregion] = STATE(3946),
    [sym_preproc_line] = STATE(3946),
    [sym_preproc_pragma] = STATE(3946),
    [sym_preproc_nullable] = STATE(3946),
    [sym_preproc_error] = STATE(3946),
    [sym_preproc_warning] = STATE(3946),
    [sym_preproc_define] = STATE(3946),
    [sym_preproc_undef] = STATE(3946),
    [anon_sym_SEMI] = ACTIONS(4088),
    [anon_sym_LBRACK] = ACTIONS(4088),
    [anon_sym_COLON] = ACTIONS(4091),
    [anon_sym_COMMA] = ACTIONS(4088),
    [anon_sym_RBRACK] = ACTIONS(4088),
    [anon_sym_LPAREN] = ACTIONS(4088),
    [anon_sym_RPAREN] = ACTIONS(4088),
    [anon_sym_LBRACE] = ACTIONS(4088),
    [anon_sym_RBRACE] = ACTIONS(4088),
    [anon_sym_LT] = ACTIONS(4091),
    [anon_sym_GT] = ACTIONS(4091),
    [anon_sym_in] = ACTIONS(4088),
    [anon_sym_QMARK] = ACTIONS(4091),
    [anon_sym_BANG] = ACTIONS(4091),
    [anon_sym_PLUS_PLUS] = ACTIONS(4088),
    [anon_sym_DASH_DASH] = ACTIONS(4088),
    [anon_sym_PLUS] = ACTIONS(4091),
    [anon_sym_DASH] = ACTIONS(4091),
    [anon_sym_STAR] = ACTIONS(4088),
    [anon_sym_SLASH] = ACTIONS(4091),
    [anon_sym_PERCENT] = ACTIONS(4088),
    [anon_sym_CARET] = ACTIONS(4088),
    [anon_sym_PIPE] = ACTIONS(4091),
    [anon_sym_AMP] = ACTIONS(4091),
    [anon_sym_LT_LT] = ACTIONS(4088),
    [anon_sym_GT_GT] = ACTIONS(4091),
    [anon_sym_GT_GT_GT] = ACTIONS(4088),
    [anon_sym_EQ_EQ] = ACTIONS(4088),
    [anon_sym_BANG_EQ] = ACTIONS(4088),
    [anon_sym_GT_EQ] = ACTIONS(4088),
    [anon_sym_LT_EQ] = ACTIONS(4088),
    [anon_sym_DOT] = ACTIONS(4091),
    [anon_sym_EQ_GT] = ACTIONS(4088),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_switch] = ACTIONS(4088),
    [anon_sym_when] = ACTIONS(4088),
    [anon_sym_DOT_DOT] = ACTIONS(4088),
    [anon_sym_and] = ACTIONS(4088),
    [anon_sym_or] = ACTIONS(4088),
    [anon_sym_AMP_AMP] = ACTIONS(4088),
    [anon_sym_PIPE_PIPE] = ACTIONS(4088),
    [anon_sym_QMARK_QMARK] = ACTIONS(4088),
    [anon_sym_on] = ACTIONS(4088),
    [anon_sym_equals] = ACTIONS(4088),
    [anon_sym_by] = ACTIONS(4088),
    [anon_sym_as] = ACTIONS(4088),
    [anon_sym_is] = ACTIONS(4088),
    [anon_sym_DASH_GT] = ACTIONS(4088),
    [anon_sym_with] = ACTIONS(4088),
    [aux_sym_preproc_if_token3] = ACTIONS(4088),
    [aux_sym_preproc_else_token1] = ACTIONS(4088),
    [aux_sym_preproc_elif_token1] = ACTIONS(4088),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3947] = {
    [sym_preproc_region] = STATE(3947),
    [sym_preproc_endregion] = STATE(3947),
    [sym_preproc_line] = STATE(3947),
    [sym_preproc_pragma] = STATE(3947),
    [sym_preproc_nullable] = STATE(3947),
    [sym_preproc_error] = STATE(3947),
    [sym_preproc_warning] = STATE(3947),
    [sym_preproc_define] = STATE(3947),
    [sym_preproc_undef] = STATE(3947),
    [anon_sym_EQ] = ACTIONS(4149),
    [anon_sym_LBRACK] = ACTIONS(4151),
    [anon_sym_COLON] = ACTIONS(4151),
    [anon_sym_COMMA] = ACTIONS(4151),
    [anon_sym_LPAREN] = ACTIONS(4151),
    [anon_sym_LT] = ACTIONS(4149),
    [anon_sym_GT] = ACTIONS(4149),
    [anon_sym_QMARK] = ACTIONS(4149),
    [anon_sym_BANG] = ACTIONS(4149),
    [anon_sym_PLUS_PLUS] = ACTIONS(4151),
    [anon_sym_DASH_DASH] = ACTIONS(4151),
    [anon_sym_PLUS] = ACTIONS(4149),
    [anon_sym_DASH] = ACTIONS(4149),
    [anon_sym_STAR] = ACTIONS(4149),
    [anon_sym_SLASH] = ACTIONS(4149),
    [anon_sym_PERCENT] = ACTIONS(4149),
    [anon_sym_CARET] = ACTIONS(4149),
    [anon_sym_PIPE] = ACTIONS(4149),
    [anon_sym_AMP] = ACTIONS(4149),
    [anon_sym_LT_LT] = ACTIONS(4149),
    [anon_sym_GT_GT] = ACTIONS(4149),
    [anon_sym_GT_GT_GT] = ACTIONS(4149),
    [anon_sym_EQ_EQ] = ACTIONS(4151),
    [anon_sym_BANG_EQ] = ACTIONS(4151),
    [anon_sym_GT_EQ] = ACTIONS(4151),
    [anon_sym_LT_EQ] = ACTIONS(4151),
    [anon_sym_DOT] = ACTIONS(4149),
    [anon_sym_switch] = ACTIONS(4151),
    [anon_sym_DOT_DOT] = ACTIONS(4151),
    [anon_sym_and] = ACTIONS(4151),
    [anon_sym_or] = ACTIONS(4151),
    [anon_sym_PLUS_EQ] = ACTIONS(4151),
    [anon_sym_DASH_EQ] = ACTIONS(4151),
    [anon_sym_STAR_EQ] = ACTIONS(4151),
    [anon_sym_SLASH_EQ] = ACTIONS(4151),
    [anon_sym_PERCENT_EQ] = ACTIONS(4151),
    [anon_sym_AMP_EQ] = ACTIONS(4151),
    [anon_sym_CARET_EQ] = ACTIONS(4151),
    [anon_sym_PIPE_EQ] = ACTIONS(4151),
    [anon_sym_LT_LT_EQ] = ACTIONS(4151),
    [anon_sym_GT_GT_EQ] = ACTIONS(4151),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4151),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4151),
    [anon_sym_AMP_AMP] = ACTIONS(4151),
    [anon_sym_PIPE_PIPE] = ACTIONS(4151),
    [anon_sym_QMARK_QMARK] = ACTIONS(4149),
    [anon_sym_into] = ACTIONS(4151),
    [anon_sym_as] = ACTIONS(4151),
    [anon_sym_is] = ACTIONS(4151),
    [anon_sym_DASH_GT] = ACTIONS(4151),
    [anon_sym_with] = ACTIONS(4151),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4151),
  },
  [3948] = {
    [sym_preproc_region] = STATE(3948),
    [sym_preproc_endregion] = STATE(3948),
    [sym_preproc_line] = STATE(3948),
    [sym_preproc_pragma] = STATE(3948),
    [sym_preproc_nullable] = STATE(3948),
    [sym_preproc_error] = STATE(3948),
    [sym_preproc_warning] = STATE(3948),
    [sym_preproc_define] = STATE(3948),
    [sym_preproc_undef] = STATE(3948),
    [anon_sym_EQ] = ACTIONS(4709),
    [anon_sym_LBRACK] = ACTIONS(4707),
    [anon_sym_COLON] = ACTIONS(4707),
    [anon_sym_COMMA] = ACTIONS(4707),
    [anon_sym_LPAREN] = ACTIONS(4707),
    [anon_sym_LT] = ACTIONS(4709),
    [anon_sym_GT] = ACTIONS(4709),
    [anon_sym_QMARK] = ACTIONS(4709),
    [anon_sym_BANG] = ACTIONS(4709),
    [anon_sym_PLUS_PLUS] = ACTIONS(4707),
    [anon_sym_DASH_DASH] = ACTIONS(4707),
    [anon_sym_PLUS] = ACTIONS(4709),
    [anon_sym_DASH] = ACTIONS(4709),
    [anon_sym_STAR] = ACTIONS(4709),
    [anon_sym_SLASH] = ACTIONS(4709),
    [anon_sym_PERCENT] = ACTIONS(4709),
    [anon_sym_CARET] = ACTIONS(4709),
    [anon_sym_PIPE] = ACTIONS(4709),
    [anon_sym_AMP] = ACTIONS(4709),
    [anon_sym_LT_LT] = ACTIONS(4709),
    [anon_sym_GT_GT] = ACTIONS(4709),
    [anon_sym_GT_GT_GT] = ACTIONS(4709),
    [anon_sym_EQ_EQ] = ACTIONS(4707),
    [anon_sym_BANG_EQ] = ACTIONS(4707),
    [anon_sym_GT_EQ] = ACTIONS(4707),
    [anon_sym_LT_EQ] = ACTIONS(4707),
    [anon_sym_DOT] = ACTIONS(4709),
    [anon_sym_switch] = ACTIONS(4707),
    [anon_sym_DOT_DOT] = ACTIONS(4707),
    [anon_sym_and] = ACTIONS(4707),
    [anon_sym_or] = ACTIONS(4707),
    [anon_sym_PLUS_EQ] = ACTIONS(4707),
    [anon_sym_DASH_EQ] = ACTIONS(4707),
    [anon_sym_STAR_EQ] = ACTIONS(4707),
    [anon_sym_SLASH_EQ] = ACTIONS(4707),
    [anon_sym_PERCENT_EQ] = ACTIONS(4707),
    [anon_sym_AMP_EQ] = ACTIONS(4707),
    [anon_sym_CARET_EQ] = ACTIONS(4707),
    [anon_sym_PIPE_EQ] = ACTIONS(4707),
    [anon_sym_LT_LT_EQ] = ACTIONS(4707),
    [anon_sym_GT_GT_EQ] = ACTIONS(4707),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4707),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4707),
    [anon_sym_AMP_AMP] = ACTIONS(4707),
    [anon_sym_PIPE_PIPE] = ACTIONS(4707),
    [anon_sym_QMARK_QMARK] = ACTIONS(4709),
    [anon_sym_into] = ACTIONS(4707),
    [anon_sym_as] = ACTIONS(4707),
    [anon_sym_is] = ACTIONS(4707),
    [anon_sym_DASH_GT] = ACTIONS(4707),
    [anon_sym_with] = ACTIONS(4707),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(4707),
  },
  [3949] = {
    [sym_preproc_region] = STATE(3949),
    [sym_preproc_endregion] = STATE(3949),
    [sym_preproc_line] = STATE(3949),
    [sym_preproc_pragma] = STATE(3949),
    [sym_preproc_nullable] = STATE(3949),
    [sym_preproc_error] = STATE(3949),
    [sym_preproc_warning] = STATE(3949),
    [sym_preproc_define] = STATE(3949),
    [sym_preproc_undef] = STATE(3949),
    [anon_sym_SEMI] = ACTIONS(4626),
    [anon_sym_LBRACK] = ACTIONS(4626),
    [anon_sym_COLON] = ACTIONS(4626),
    [anon_sym_COMMA] = ACTIONS(4626),
    [anon_sym_RBRACK] = ACTIONS(4626),
    [anon_sym_LPAREN] = ACTIONS(4626),
    [anon_sym_RPAREN] = ACTIONS(4626),
    [anon_sym_LBRACE] = ACTIONS(4626),
    [anon_sym_RBRACE] = ACTIONS(4626),
    [anon_sym_LT] = ACTIONS(4624),
    [anon_sym_GT] = ACTIONS(4624),
    [anon_sym_in] = ACTIONS(4624),
    [anon_sym_QMARK] = ACTIONS(4624),
    [anon_sym_BANG] = ACTIONS(4624),
    [anon_sym_PLUS_PLUS] = ACTIONS(4626),
    [anon_sym_DASH_DASH] = ACTIONS(4626),
    [anon_sym_PLUS] = ACTIONS(4624),
    [anon_sym_DASH] = ACTIONS(4624),
    [anon_sym_STAR] = ACTIONS(4626),
    [anon_sym_SLASH] = ACTIONS(4624),
    [anon_sym_PERCENT] = ACTIONS(4626),
    [anon_sym_CARET] = ACTIONS(4626),
    [anon_sym_PIPE] = ACTIONS(4624),
    [anon_sym_AMP] = ACTIONS(4624),
    [anon_sym_LT_LT] = ACTIONS(4626),
    [anon_sym_GT_GT] = ACTIONS(4624),
    [anon_sym_GT_GT_GT] = ACTIONS(4626),
    [anon_sym_EQ_EQ] = ACTIONS(4626),
    [anon_sym_BANG_EQ] = ACTIONS(4626),
    [anon_sym_GT_EQ] = ACTIONS(4626),
    [anon_sym_LT_EQ] = ACTIONS(4626),
    [anon_sym_DOT] = ACTIONS(4624),
    [anon_sym_EQ_GT] = ACTIONS(4626),
    [anon_sym_switch] = ACTIONS(4626),
    [anon_sym_when] = ACTIONS(4626),
    [anon_sym_DOT_DOT] = ACTIONS(4626),
    [anon_sym_and] = ACTIONS(4626),
    [anon_sym_or] = ACTIONS(4626),
    [anon_sym_AMP_AMP] = ACTIONS(4626),
    [anon_sym_PIPE_PIPE] = ACTIONS(4626),
    [anon_sym_QMARK_QMARK] = ACTIONS(4626),
    [anon_sym_into] = ACTIONS(4626),
    [anon_sym_on] = ACTIONS(4626),
    [anon_sym_equals] = ACTIONS(4626),
    [anon_sym_by] = ACTIONS(4626),
    [anon_sym_as] = ACTIONS(4626),
    [anon_sym_is] = ACTIONS(4626),
    [anon_sym_DASH_GT] = ACTIONS(4626),
    [anon_sym_with] = ACTIONS(4626),
    [aux_sym_preproc_if_token3] = ACTIONS(4626),
    [aux_sym_preproc_else_token1] = ACTIONS(4626),
    [aux_sym_preproc_elif_token1] = ACTIONS(4626),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3950] = {
    [sym_preproc_region] = STATE(3950),
    [sym_preproc_endregion] = STATE(3950),
    [sym_preproc_line] = STATE(3950),
    [sym_preproc_pragma] = STATE(3950),
    [sym_preproc_nullable] = STATE(3950),
    [sym_preproc_error] = STATE(3950),
    [sym_preproc_warning] = STATE(3950),
    [sym_preproc_define] = STATE(3950),
    [sym_preproc_undef] = STATE(3950),
    [anon_sym_SEMI] = ACTIONS(4181),
    [anon_sym_LBRACK] = ACTIONS(4181),
    [anon_sym_COLON] = ACTIONS(4181),
    [anon_sym_COMMA] = ACTIONS(4181),
    [anon_sym_RBRACK] = ACTIONS(4181),
    [anon_sym_LPAREN] = ACTIONS(4181),
    [anon_sym_RPAREN] = ACTIONS(4181),
    [anon_sym_LBRACE] = ACTIONS(4181),
    [anon_sym_RBRACE] = ACTIONS(4181),
    [anon_sym_LT] = ACTIONS(4179),
    [anon_sym_GT] = ACTIONS(4179),
    [anon_sym_in] = ACTIONS(4179),
    [anon_sym_QMARK] = ACTIONS(4179),
    [anon_sym_BANG] = ACTIONS(4179),
    [anon_sym_PLUS_PLUS] = ACTIONS(4181),
    [anon_sym_DASH_DASH] = ACTIONS(4181),
    [anon_sym_PLUS] = ACTIONS(4179),
    [anon_sym_DASH] = ACTIONS(4179),
    [anon_sym_STAR] = ACTIONS(4181),
    [anon_sym_SLASH] = ACTIONS(4179),
    [anon_sym_PERCENT] = ACTIONS(4181),
    [anon_sym_CARET] = ACTIONS(4181),
    [anon_sym_PIPE] = ACTIONS(4179),
    [anon_sym_AMP] = ACTIONS(4179),
    [anon_sym_LT_LT] = ACTIONS(4181),
    [anon_sym_GT_GT] = ACTIONS(4179),
    [anon_sym_GT_GT_GT] = ACTIONS(4181),
    [anon_sym_EQ_EQ] = ACTIONS(4181),
    [anon_sym_BANG_EQ] = ACTIONS(4181),
    [anon_sym_GT_EQ] = ACTIONS(4181),
    [anon_sym_LT_EQ] = ACTIONS(4181),
    [anon_sym_DOT] = ACTIONS(4179),
    [anon_sym_EQ_GT] = ACTIONS(4181),
    [anon_sym_switch] = ACTIONS(4181),
    [anon_sym_when] = ACTIONS(4181),
    [anon_sym_DOT_DOT] = ACTIONS(4181),
    [anon_sym_and] = ACTIONS(4181),
    [anon_sym_or] = ACTIONS(4181),
    [anon_sym_AMP_AMP] = ACTIONS(4181),
    [anon_sym_PIPE_PIPE] = ACTIONS(4181),
    [anon_sym_QMARK_QMARK] = ACTIONS(4181),
    [anon_sym_into] = ACTIONS(4181),
    [anon_sym_on] = ACTIONS(4181),
    [anon_sym_equals] = ACTIONS(4181),
    [anon_sym_by] = ACTIONS(4181),
    [anon_sym_as] = ACTIONS(4181),
    [anon_sym_is] = ACTIONS(4181),
    [anon_sym_DASH_GT] = ACTIONS(4181),
    [anon_sym_with] = ACTIONS(4181),
    [aux_sym_preproc_if_token3] = ACTIONS(4181),
    [aux_sym_preproc_else_token1] = ACTIONS(4181),
    [aux_sym_preproc_elif_token1] = ACTIONS(4181),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3951] = {
    [sym_preproc_region] = STATE(3951),
    [sym_preproc_endregion] = STATE(3951),
    [sym_preproc_line] = STATE(3951),
    [sym_preproc_pragma] = STATE(3951),
    [sym_preproc_nullable] = STATE(3951),
    [sym_preproc_error] = STATE(3951),
    [sym_preproc_warning] = STATE(3951),
    [sym_preproc_define] = STATE(3951),
    [sym_preproc_undef] = STATE(3951),
    [anon_sym_SEMI] = ACTIONS(5359),
    [anon_sym_LBRACK] = ACTIONS(5359),
    [anon_sym_COLON] = ACTIONS(5359),
    [anon_sym_COMMA] = ACTIONS(5359),
    [anon_sym_RBRACK] = ACTIONS(5359),
    [anon_sym_LPAREN] = ACTIONS(5359),
    [anon_sym_RPAREN] = ACTIONS(5359),
    [anon_sym_LBRACE] = ACTIONS(5359),
    [anon_sym_RBRACE] = ACTIONS(5359),
    [anon_sym_LT] = ACTIONS(5361),
    [anon_sym_GT] = ACTIONS(5361),
    [anon_sym_in] = ACTIONS(5361),
    [anon_sym_QMARK] = ACTIONS(5361),
    [anon_sym_BANG] = ACTIONS(5361),
    [anon_sym_PLUS_PLUS] = ACTIONS(5359),
    [anon_sym_DASH_DASH] = ACTIONS(5359),
    [anon_sym_PLUS] = ACTIONS(5361),
    [anon_sym_DASH] = ACTIONS(5361),
    [anon_sym_STAR] = ACTIONS(5359),
    [anon_sym_SLASH] = ACTIONS(5361),
    [anon_sym_PERCENT] = ACTIONS(5359),
    [anon_sym_CARET] = ACTIONS(5359),
    [anon_sym_PIPE] = ACTIONS(5361),
    [anon_sym_AMP] = ACTIONS(5361),
    [anon_sym_LT_LT] = ACTIONS(5359),
    [anon_sym_GT_GT] = ACTIONS(5361),
    [anon_sym_GT_GT_GT] = ACTIONS(5359),
    [anon_sym_EQ_EQ] = ACTIONS(5359),
    [anon_sym_BANG_EQ] = ACTIONS(5359),
    [anon_sym_GT_EQ] = ACTIONS(5359),
    [anon_sym_LT_EQ] = ACTIONS(5359),
    [anon_sym_DOT] = ACTIONS(5361),
    [anon_sym_EQ_GT] = ACTIONS(5359),
    [anon_sym_switch] = ACTIONS(5359),
    [anon_sym_when] = ACTIONS(5359),
    [anon_sym_DOT_DOT] = ACTIONS(5359),
    [anon_sym_and] = ACTIONS(5359),
    [anon_sym_or] = ACTIONS(5359),
    [anon_sym_AMP_AMP] = ACTIONS(5359),
    [anon_sym_PIPE_PIPE] = ACTIONS(5359),
    [anon_sym_QMARK_QMARK] = ACTIONS(5359),
    [anon_sym_into] = ACTIONS(5359),
    [anon_sym_on] = ACTIONS(5359),
    [anon_sym_equals] = ACTIONS(5359),
    [anon_sym_by] = ACTIONS(5359),
    [anon_sym_as] = ACTIONS(5359),
    [anon_sym_is] = ACTIONS(5359),
    [anon_sym_DASH_GT] = ACTIONS(5359),
    [anon_sym_with] = ACTIONS(5359),
    [aux_sym_preproc_if_token3] = ACTIONS(5359),
    [aux_sym_preproc_else_token1] = ACTIONS(5359),
    [aux_sym_preproc_elif_token1] = ACTIONS(5359),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3952] = {
    [sym_initializer_expression] = STATE(4107),
    [sym_preproc_region] = STATE(3952),
    [sym_preproc_endregion] = STATE(3952),
    [sym_preproc_line] = STATE(3952),
    [sym_preproc_pragma] = STATE(3952),
    [sym_preproc_nullable] = STATE(3952),
    [sym_preproc_error] = STATE(3952),
    [sym_preproc_warning] = STATE(3952),
    [sym_preproc_define] = STATE(3952),
    [sym_preproc_undef] = STATE(3952),
    [anon_sym_SEMI] = ACTIONS(5303),
    [anon_sym_LBRACK] = ACTIONS(5303),
    [anon_sym_COLON] = ACTIONS(5303),
    [anon_sym_COMMA] = ACTIONS(5303),
    [anon_sym_RBRACK] = ACTIONS(5303),
    [anon_sym_LPAREN] = ACTIONS(5303),
    [anon_sym_RPAREN] = ACTIONS(5303),
    [anon_sym_LBRACE] = ACTIONS(1327),
    [anon_sym_RBRACE] = ACTIONS(5303),
    [anon_sym_LT] = ACTIONS(5305),
    [anon_sym_GT] = ACTIONS(5305),
    [anon_sym_in] = ACTIONS(5303),
    [anon_sym_QMARK] = ACTIONS(5305),
    [anon_sym_BANG] = ACTIONS(5305),
    [anon_sym_PLUS_PLUS] = ACTIONS(5303),
    [anon_sym_DASH_DASH] = ACTIONS(5303),
    [anon_sym_PLUS] = ACTIONS(5305),
    [anon_sym_DASH] = ACTIONS(5305),
    [anon_sym_STAR] = ACTIONS(5303),
    [anon_sym_SLASH] = ACTIONS(5305),
    [anon_sym_PERCENT] = ACTIONS(5303),
    [anon_sym_CARET] = ACTIONS(5303),
    [anon_sym_PIPE] = ACTIONS(5305),
    [anon_sym_AMP] = ACTIONS(5305),
    [anon_sym_LT_LT] = ACTIONS(5303),
    [anon_sym_GT_GT] = ACTIONS(5305),
    [anon_sym_GT_GT_GT] = ACTIONS(5303),
    [anon_sym_EQ_EQ] = ACTIONS(5303),
    [anon_sym_BANG_EQ] = ACTIONS(5303),
    [anon_sym_GT_EQ] = ACTIONS(5303),
    [anon_sym_LT_EQ] = ACTIONS(5303),
    [anon_sym_DOT] = ACTIONS(5305),
    [anon_sym_EQ_GT] = ACTIONS(5303),
    [anon_sym_switch] = ACTIONS(5303),
    [anon_sym_when] = ACTIONS(5303),
    [anon_sym_DOT_DOT] = ACTIONS(5303),
    [anon_sym_and] = ACTIONS(5303),
    [anon_sym_or] = ACTIONS(5303),
    [anon_sym_AMP_AMP] = ACTIONS(5303),
    [anon_sym_PIPE_PIPE] = ACTIONS(5303),
    [anon_sym_QMARK_QMARK] = ACTIONS(5303),
    [anon_sym_on] = ACTIONS(5303),
    [anon_sym_equals] = ACTIONS(5303),
    [anon_sym_by] = ACTIONS(5303),
    [anon_sym_as] = ACTIONS(5303),
    [anon_sym_is] = ACTIONS(5303),
    [anon_sym_DASH_GT] = ACTIONS(5303),
    [anon_sym_with] = ACTIONS(5303),
    [aux_sym_preproc_if_token3] = ACTIONS(5303),
    [aux_sym_preproc_else_token1] = ACTIONS(5303),
    [aux_sym_preproc_elif_token1] = ACTIONS(5303),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3953] = {
    [sym_preproc_region] = STATE(3953),
    [sym_preproc_endregion] = STATE(3953),
    [sym_preproc_line] = STATE(3953),
    [sym_preproc_pragma] = STATE(3953),
    [sym_preproc_nullable] = STATE(3953),
    [sym_preproc_error] = STATE(3953),
    [sym_preproc_warning] = STATE(3953),
    [sym_preproc_define] = STATE(3953),
    [sym_preproc_undef] = STATE(3953),
    [anon_sym_SEMI] = ACTIONS(4630),
    [anon_sym_LBRACK] = ACTIONS(4630),
    [anon_sym_COLON] = ACTIONS(4630),
    [anon_sym_COMMA] = ACTIONS(4630),
    [anon_sym_RBRACK] = ACTIONS(4630),
    [anon_sym_LPAREN] = ACTIONS(4630),
    [anon_sym_RPAREN] = ACTIONS(4630),
    [anon_sym_LBRACE] = ACTIONS(4630),
    [anon_sym_RBRACE] = ACTIONS(4630),
    [anon_sym_LT] = ACTIONS(4628),
    [anon_sym_GT] = ACTIONS(4628),
    [anon_sym_in] = ACTIONS(4628),
    [anon_sym_QMARK] = ACTIONS(4628),
    [anon_sym_BANG] = ACTIONS(4628),
    [anon_sym_PLUS_PLUS] = ACTIONS(4630),
    [anon_sym_DASH_DASH] = ACTIONS(4630),
    [anon_sym_PLUS] = ACTIONS(4628),
    [anon_sym_DASH] = ACTIONS(4628),
    [anon_sym_STAR] = ACTIONS(4630),
    [anon_sym_SLASH] = ACTIONS(4628),
    [anon_sym_PERCENT] = ACTIONS(4630),
    [anon_sym_CARET] = ACTIONS(4630),
    [anon_sym_PIPE] = ACTIONS(4628),
    [anon_sym_AMP] = ACTIONS(4628),
    [anon_sym_LT_LT] = ACTIONS(4630),
    [anon_sym_GT_GT] = ACTIONS(4628),
    [anon_sym_GT_GT_GT] = ACTIONS(4630),
    [anon_sym_EQ_EQ] = ACTIONS(4630),
    [anon_sym_BANG_EQ] = ACTIONS(4630),
    [anon_sym_GT_EQ] = ACTIONS(4630),
    [anon_sym_LT_EQ] = ACTIONS(4630),
    [anon_sym_DOT] = ACTIONS(4628),
    [anon_sym_EQ_GT] = ACTIONS(4630),
    [anon_sym_switch] = ACTIONS(4630),
    [anon_sym_when] = ACTIONS(4630),
    [anon_sym_DOT_DOT] = ACTIONS(4630),
    [anon_sym_and] = ACTIONS(4630),
    [anon_sym_or] = ACTIONS(4630),
    [anon_sym_AMP_AMP] = ACTIONS(4630),
    [anon_sym_PIPE_PIPE] = ACTIONS(4630),
    [anon_sym_QMARK_QMARK] = ACTIONS(4630),
    [anon_sym_into] = ACTIONS(4630),
    [anon_sym_on] = ACTIONS(4630),
    [anon_sym_equals] = ACTIONS(4630),
    [anon_sym_by] = ACTIONS(4630),
    [anon_sym_as] = ACTIONS(4630),
    [anon_sym_is] = ACTIONS(4630),
    [anon_sym_DASH_GT] = ACTIONS(4630),
    [anon_sym_with] = ACTIONS(4630),
    [aux_sym_preproc_if_token3] = ACTIONS(4630),
    [aux_sym_preproc_else_token1] = ACTIONS(4630),
    [aux_sym_preproc_elif_token1] = ACTIONS(4630),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3954] = {
    [sym_preproc_region] = STATE(3954),
    [sym_preproc_endregion] = STATE(3954),
    [sym_preproc_line] = STATE(3954),
    [sym_preproc_pragma] = STATE(3954),
    [sym_preproc_nullable] = STATE(3954),
    [sym_preproc_error] = STATE(3954),
    [sym_preproc_warning] = STATE(3954),
    [sym_preproc_define] = STATE(3954),
    [sym_preproc_undef] = STATE(3954),
    [anon_sym_SEMI] = ACTIONS(4455),
    [anon_sym_LBRACK] = ACTIONS(4455),
    [anon_sym_COLON] = ACTIONS(4455),
    [anon_sym_COMMA] = ACTIONS(4455),
    [anon_sym_RBRACK] = ACTIONS(4455),
    [anon_sym_LPAREN] = ACTIONS(4455),
    [anon_sym_RPAREN] = ACTIONS(4455),
    [anon_sym_LBRACE] = ACTIONS(4455),
    [anon_sym_RBRACE] = ACTIONS(4455),
    [anon_sym_LT] = ACTIONS(4453),
    [anon_sym_GT] = ACTIONS(4453),
    [anon_sym_in] = ACTIONS(4453),
    [anon_sym_QMARK] = ACTIONS(4453),
    [anon_sym_BANG] = ACTIONS(4453),
    [anon_sym_PLUS_PLUS] = ACTIONS(4455),
    [anon_sym_DASH_DASH] = ACTIONS(4455),
    [anon_sym_PLUS] = ACTIONS(4453),
    [anon_sym_DASH] = ACTIONS(4453),
    [anon_sym_STAR] = ACTIONS(4455),
    [anon_sym_SLASH] = ACTIONS(4453),
    [anon_sym_PERCENT] = ACTIONS(4455),
    [anon_sym_CARET] = ACTIONS(4455),
    [anon_sym_PIPE] = ACTIONS(4453),
    [anon_sym_AMP] = ACTIONS(4453),
    [anon_sym_LT_LT] = ACTIONS(4455),
    [anon_sym_GT_GT] = ACTIONS(4453),
    [anon_sym_GT_GT_GT] = ACTIONS(4455),
    [anon_sym_EQ_EQ] = ACTIONS(4455),
    [anon_sym_BANG_EQ] = ACTIONS(4455),
    [anon_sym_GT_EQ] = ACTIONS(4455),
    [anon_sym_LT_EQ] = ACTIONS(4455),
    [anon_sym_DOT] = ACTIONS(4453),
    [anon_sym_EQ_GT] = ACTIONS(4455),
    [anon_sym_switch] = ACTIONS(4455),
    [anon_sym_when] = ACTIONS(4455),
    [anon_sym_DOT_DOT] = ACTIONS(4455),
    [anon_sym_and] = ACTIONS(4455),
    [anon_sym_or] = ACTIONS(4455),
    [anon_sym_AMP_AMP] = ACTIONS(4455),
    [anon_sym_PIPE_PIPE] = ACTIONS(4455),
    [anon_sym_QMARK_QMARK] = ACTIONS(4455),
    [anon_sym_into] = ACTIONS(4455),
    [anon_sym_on] = ACTIONS(4455),
    [anon_sym_equals] = ACTIONS(4455),
    [anon_sym_by] = ACTIONS(4455),
    [anon_sym_as] = ACTIONS(4455),
    [anon_sym_is] = ACTIONS(4455),
    [anon_sym_DASH_GT] = ACTIONS(4455),
    [anon_sym_with] = ACTIONS(4455),
    [aux_sym_preproc_if_token3] = ACTIONS(4455),
    [aux_sym_preproc_else_token1] = ACTIONS(4455),
    [aux_sym_preproc_elif_token1] = ACTIONS(4455),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3955] = {
    [sym_preproc_region] = STATE(3955),
    [sym_preproc_endregion] = STATE(3955),
    [sym_preproc_line] = STATE(3955),
    [sym_preproc_pragma] = STATE(3955),
    [sym_preproc_nullable] = STATE(3955),
    [sym_preproc_error] = STATE(3955),
    [sym_preproc_warning] = STATE(3955),
    [sym_preproc_define] = STATE(3955),
    [sym_preproc_undef] = STATE(3955),
    [anon_sym_SEMI] = ACTIONS(5514),
    [anon_sym_LBRACK] = ACTIONS(5514),
    [anon_sym_COLON] = ACTIONS(5514),
    [anon_sym_COMMA] = ACTIONS(5514),
    [anon_sym_RBRACK] = ACTIONS(5514),
    [anon_sym_LPAREN] = ACTIONS(5514),
    [anon_sym_RPAREN] = ACTIONS(5514),
    [anon_sym_RBRACE] = ACTIONS(5514),
    [anon_sym_LT] = ACTIONS(5516),
    [anon_sym_GT] = ACTIONS(5516),
    [anon_sym_in] = ACTIONS(5516),
    [anon_sym_QMARK] = ACTIONS(5516),
    [anon_sym_BANG] = ACTIONS(5516),
    [anon_sym_PLUS_PLUS] = ACTIONS(5514),
    [anon_sym_DASH_DASH] = ACTIONS(5514),
    [anon_sym_PLUS] = ACTIONS(5516),
    [anon_sym_DASH] = ACTIONS(5516),
    [anon_sym_STAR] = ACTIONS(5514),
    [anon_sym_SLASH] = ACTIONS(5516),
    [anon_sym_PERCENT] = ACTIONS(5514),
    [anon_sym_CARET] = ACTIONS(5514),
    [anon_sym_PIPE] = ACTIONS(5516),
    [anon_sym_AMP] = ACTIONS(5516),
    [anon_sym_LT_LT] = ACTIONS(5514),
    [anon_sym_GT_GT] = ACTIONS(5516),
    [anon_sym_GT_GT_GT] = ACTIONS(5514),
    [anon_sym_EQ_EQ] = ACTIONS(5514),
    [anon_sym_BANG_EQ] = ACTIONS(5514),
    [anon_sym_GT_EQ] = ACTIONS(5514),
    [anon_sym_LT_EQ] = ACTIONS(5514),
    [anon_sym_DOT] = ACTIONS(5516),
    [anon_sym_EQ_GT] = ACTIONS(5514),
    [anon_sym_switch] = ACTIONS(5514),
    [anon_sym_when] = ACTIONS(5514),
    [anon_sym_DOT_DOT] = ACTIONS(5514),
    [anon_sym_and] = ACTIONS(5514),
    [anon_sym_or] = ACTIONS(5514),
    [anon_sym_AMP_AMP] = ACTIONS(5514),
    [anon_sym_PIPE_PIPE] = ACTIONS(5514),
    [anon_sym_QMARK_QMARK] = ACTIONS(5514),
    [anon_sym_into] = ACTIONS(5514),
    [anon_sym_on] = ACTIONS(5514),
    [anon_sym_equals] = ACTIONS(5514),
    [anon_sym_by] = ACTIONS(5514),
    [anon_sym_as] = ACTIONS(5514),
    [anon_sym_is] = ACTIONS(5514),
    [anon_sym_DASH_GT] = ACTIONS(5514),
    [anon_sym_with] = ACTIONS(5514),
    [aux_sym_preproc_if_token3] = ACTIONS(5514),
    [aux_sym_preproc_else_token1] = ACTIONS(5514),
    [aux_sym_preproc_elif_token1] = ACTIONS(5514),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3956] = {
    [sym_preproc_region] = STATE(3956),
    [sym_preproc_endregion] = STATE(3956),
    [sym_preproc_line] = STATE(3956),
    [sym_preproc_pragma] = STATE(3956),
    [sym_preproc_nullable] = STATE(3956),
    [sym_preproc_error] = STATE(3956),
    [sym_preproc_warning] = STATE(3956),
    [sym_preproc_define] = STATE(3956),
    [sym_preproc_undef] = STATE(3956),
    [anon_sym_SEMI] = ACTIONS(5490),
    [anon_sym_LBRACK] = ACTIONS(5490),
    [anon_sym_COLON] = ACTIONS(5490),
    [anon_sym_COMMA] = ACTIONS(5490),
    [anon_sym_RBRACK] = ACTIONS(5490),
    [anon_sym_LPAREN] = ACTIONS(5490),
    [anon_sym_RPAREN] = ACTIONS(5490),
    [anon_sym_RBRACE] = ACTIONS(5490),
    [anon_sym_LT] = ACTIONS(5492),
    [anon_sym_GT] = ACTIONS(5492),
    [anon_sym_in] = ACTIONS(5492),
    [anon_sym_QMARK] = ACTIONS(5492),
    [anon_sym_BANG] = ACTIONS(5492),
    [anon_sym_PLUS_PLUS] = ACTIONS(5490),
    [anon_sym_DASH_DASH] = ACTIONS(5490),
    [anon_sym_PLUS] = ACTIONS(5492),
    [anon_sym_DASH] = ACTIONS(5492),
    [anon_sym_STAR] = ACTIONS(5490),
    [anon_sym_SLASH] = ACTIONS(5492),
    [anon_sym_PERCENT] = ACTIONS(5490),
    [anon_sym_CARET] = ACTIONS(5490),
    [anon_sym_PIPE] = ACTIONS(5492),
    [anon_sym_AMP] = ACTIONS(5492),
    [anon_sym_LT_LT] = ACTIONS(5490),
    [anon_sym_GT_GT] = ACTIONS(5492),
    [anon_sym_GT_GT_GT] = ACTIONS(5490),
    [anon_sym_EQ_EQ] = ACTIONS(5490),
    [anon_sym_BANG_EQ] = ACTIONS(5490),
    [anon_sym_GT_EQ] = ACTIONS(5490),
    [anon_sym_LT_EQ] = ACTIONS(5490),
    [anon_sym_DOT] = ACTIONS(5492),
    [anon_sym_EQ_GT] = ACTIONS(5490),
    [anon_sym_switch] = ACTIONS(5490),
    [anon_sym_when] = ACTIONS(5490),
    [anon_sym_DOT_DOT] = ACTIONS(5490),
    [anon_sym_and] = ACTIONS(5490),
    [anon_sym_or] = ACTIONS(5490),
    [anon_sym_AMP_AMP] = ACTIONS(5490),
    [anon_sym_PIPE_PIPE] = ACTIONS(5490),
    [anon_sym_QMARK_QMARK] = ACTIONS(5490),
    [anon_sym_into] = ACTIONS(5490),
    [anon_sym_on] = ACTIONS(5490),
    [anon_sym_equals] = ACTIONS(5490),
    [anon_sym_by] = ACTIONS(5490),
    [anon_sym_as] = ACTIONS(5490),
    [anon_sym_is] = ACTIONS(5490),
    [anon_sym_DASH_GT] = ACTIONS(5490),
    [anon_sym_with] = ACTIONS(5490),
    [aux_sym_preproc_if_token3] = ACTIONS(5490),
    [aux_sym_preproc_else_token1] = ACTIONS(5490),
    [aux_sym_preproc_elif_token1] = ACTIONS(5490),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3957] = {
    [sym_preproc_region] = STATE(3957),
    [sym_preproc_endregion] = STATE(3957),
    [sym_preproc_line] = STATE(3957),
    [sym_preproc_pragma] = STATE(3957),
    [sym_preproc_nullable] = STATE(3957),
    [sym_preproc_error] = STATE(3957),
    [sym_preproc_warning] = STATE(3957),
    [sym_preproc_define] = STATE(3957),
    [sym_preproc_undef] = STATE(3957),
    [anon_sym_SEMI] = ACTIONS(5846),
    [anon_sym_LBRACK] = ACTIONS(5846),
    [anon_sym_COLON] = ACTIONS(5846),
    [anon_sym_COMMA] = ACTIONS(5846),
    [anon_sym_RBRACK] = ACTIONS(5846),
    [anon_sym_LPAREN] = ACTIONS(5846),
    [anon_sym_RPAREN] = ACTIONS(5846),
    [anon_sym_RBRACE] = ACTIONS(5846),
    [anon_sym_LT] = ACTIONS(5848),
    [anon_sym_GT] = ACTIONS(5848),
    [anon_sym_in] = ACTIONS(5848),
    [anon_sym_QMARK] = ACTIONS(5848),
    [anon_sym_BANG] = ACTIONS(5848),
    [anon_sym_PLUS_PLUS] = ACTIONS(5846),
    [anon_sym_DASH_DASH] = ACTIONS(5846),
    [anon_sym_PLUS] = ACTIONS(5848),
    [anon_sym_DASH] = ACTIONS(5848),
    [anon_sym_STAR] = ACTIONS(5846),
    [anon_sym_SLASH] = ACTIONS(5848),
    [anon_sym_PERCENT] = ACTIONS(5846),
    [anon_sym_CARET] = ACTIONS(5846),
    [anon_sym_PIPE] = ACTIONS(5848),
    [anon_sym_AMP] = ACTIONS(5848),
    [anon_sym_LT_LT] = ACTIONS(5846),
    [anon_sym_GT_GT] = ACTIONS(5848),
    [anon_sym_GT_GT_GT] = ACTIONS(5846),
    [anon_sym_EQ_EQ] = ACTIONS(5846),
    [anon_sym_BANG_EQ] = ACTIONS(5846),
    [anon_sym_GT_EQ] = ACTIONS(5846),
    [anon_sym_LT_EQ] = ACTIONS(5846),
    [anon_sym_DOT] = ACTIONS(5848),
    [anon_sym_EQ_GT] = ACTIONS(5846),
    [anon_sym_switch] = ACTIONS(5846),
    [anon_sym_when] = ACTIONS(5846),
    [anon_sym_DOT_DOT] = ACTIONS(5846),
    [anon_sym_and] = ACTIONS(5846),
    [anon_sym_or] = ACTIONS(5846),
    [anon_sym_AMP_AMP] = ACTIONS(5846),
    [anon_sym_PIPE_PIPE] = ACTIONS(5846),
    [anon_sym_QMARK_QMARK] = ACTIONS(5846),
    [anon_sym_into] = ACTIONS(5846),
    [anon_sym_on] = ACTIONS(5846),
    [anon_sym_equals] = ACTIONS(5846),
    [anon_sym_by] = ACTIONS(5846),
    [anon_sym_as] = ACTIONS(5846),
    [anon_sym_is] = ACTIONS(5846),
    [anon_sym_DASH_GT] = ACTIONS(5846),
    [anon_sym_with] = ACTIONS(5846),
    [aux_sym_preproc_if_token3] = ACTIONS(5846),
    [aux_sym_preproc_else_token1] = ACTIONS(5846),
    [aux_sym_preproc_elif_token1] = ACTIONS(5846),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3958] = {
    [sym_preproc_region] = STATE(3958),
    [sym_preproc_endregion] = STATE(3958),
    [sym_preproc_line] = STATE(3958),
    [sym_preproc_pragma] = STATE(3958),
    [sym_preproc_nullable] = STATE(3958),
    [sym_preproc_error] = STATE(3958),
    [sym_preproc_warning] = STATE(3958),
    [sym_preproc_define] = STATE(3958),
    [sym_preproc_undef] = STATE(3958),
    [anon_sym_SEMI] = ACTIONS(4494),
    [anon_sym_LBRACK] = ACTIONS(4593),
    [anon_sym_COLON] = ACTIONS(4494),
    [anon_sym_COMMA] = ACTIONS(4494),
    [anon_sym_RBRACK] = ACTIONS(4494),
    [anon_sym_LPAREN] = ACTIONS(4494),
    [anon_sym_RPAREN] = ACTIONS(4494),
    [anon_sym_LBRACE] = ACTIONS(4494),
    [anon_sym_RBRACE] = ACTIONS(4494),
    [anon_sym_LT] = ACTIONS(4492),
    [anon_sym_GT] = ACTIONS(4492),
    [anon_sym_in] = ACTIONS(4494),
    [anon_sym_QMARK] = ACTIONS(5850),
    [anon_sym_BANG] = ACTIONS(4492),
    [anon_sym_PLUS_PLUS] = ACTIONS(4494),
    [anon_sym_DASH_DASH] = ACTIONS(4494),
    [anon_sym_PLUS] = ACTIONS(4492),
    [anon_sym_DASH] = ACTIONS(4492),
    [anon_sym_STAR] = ACTIONS(4494),
    [anon_sym_SLASH] = ACTIONS(4492),
    [anon_sym_PERCENT] = ACTIONS(4494),
    [anon_sym_CARET] = ACTIONS(4494),
    [anon_sym_PIPE] = ACTIONS(4492),
    [anon_sym_AMP] = ACTIONS(4492),
    [anon_sym_LT_LT] = ACTIONS(4494),
    [anon_sym_GT_GT] = ACTIONS(4492),
    [anon_sym_GT_GT_GT] = ACTIONS(4494),
    [anon_sym_EQ_EQ] = ACTIONS(4494),
    [anon_sym_BANG_EQ] = ACTIONS(4494),
    [anon_sym_GT_EQ] = ACTIONS(4494),
    [anon_sym_LT_EQ] = ACTIONS(4494),
    [anon_sym_DOT] = ACTIONS(4492),
    [anon_sym_EQ_GT] = ACTIONS(4494),
    [anon_sym_switch] = ACTIONS(4494),
    [anon_sym_when] = ACTIONS(4494),
    [anon_sym_DOT_DOT] = ACTIONS(4494),
    [anon_sym_and] = ACTIONS(4494),
    [anon_sym_or] = ACTIONS(4494),
    [anon_sym_AMP_AMP] = ACTIONS(4494),
    [anon_sym_PIPE_PIPE] = ACTIONS(4494),
    [anon_sym_QMARK_QMARK] = ACTIONS(4494),
    [anon_sym_on] = ACTIONS(4494),
    [anon_sym_equals] = ACTIONS(4494),
    [anon_sym_by] = ACTIONS(4494),
    [anon_sym_as] = ACTIONS(4494),
    [anon_sym_is] = ACTIONS(4494),
    [anon_sym_DASH_GT] = ACTIONS(4494),
    [anon_sym_with] = ACTIONS(4494),
    [aux_sym_preproc_if_token3] = ACTIONS(4494),
    [aux_sym_preproc_else_token1] = ACTIONS(4494),
    [aux_sym_preproc_elif_token1] = ACTIONS(4494),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3959] = {
    [sym_preproc_region] = STATE(3959),
    [sym_preproc_endregion] = STATE(3959),
    [sym_preproc_line] = STATE(3959),
    [sym_preproc_pragma] = STATE(3959),
    [sym_preproc_nullable] = STATE(3959),
    [sym_preproc_error] = STATE(3959),
    [sym_preproc_warning] = STATE(3959),
    [sym_preproc_define] = STATE(3959),
    [sym_preproc_undef] = STATE(3959),
    [anon_sym_SEMI] = ACTIONS(4140),
    [anon_sym_LBRACK] = ACTIONS(4140),
    [anon_sym_COLON] = ACTIONS(4140),
    [anon_sym_COMMA] = ACTIONS(4140),
    [anon_sym_RBRACK] = ACTIONS(4140),
    [anon_sym_LPAREN] = ACTIONS(4140),
    [anon_sym_RPAREN] = ACTIONS(4140),
    [anon_sym_LBRACE] = ACTIONS(4140),
    [anon_sym_RBRACE] = ACTIONS(4140),
    [anon_sym_LT] = ACTIONS(4138),
    [anon_sym_GT] = ACTIONS(4138),
    [anon_sym_in] = ACTIONS(4140),
    [anon_sym_QMARK] = ACTIONS(4138),
    [anon_sym_BANG] = ACTIONS(4138),
    [anon_sym_PLUS_PLUS] = ACTIONS(4140),
    [anon_sym_DASH_DASH] = ACTIONS(4140),
    [anon_sym_PLUS] = ACTIONS(4138),
    [anon_sym_DASH] = ACTIONS(4138),
    [anon_sym_STAR] = ACTIONS(4140),
    [anon_sym_SLASH] = ACTIONS(4138),
    [anon_sym_PERCENT] = ACTIONS(4140),
    [anon_sym_CARET] = ACTIONS(4140),
    [anon_sym_PIPE] = ACTIONS(4138),
    [anon_sym_AMP] = ACTIONS(4138),
    [anon_sym_LT_LT] = ACTIONS(4140),
    [anon_sym_GT_GT] = ACTIONS(4138),
    [anon_sym_GT_GT_GT] = ACTIONS(4140),
    [anon_sym_EQ_EQ] = ACTIONS(4140),
    [anon_sym_BANG_EQ] = ACTIONS(4140),
    [anon_sym_GT_EQ] = ACTIONS(4140),
    [anon_sym_LT_EQ] = ACTIONS(4140),
    [anon_sym_DOT] = ACTIONS(4138),
    [anon_sym_EQ_GT] = ACTIONS(4140),
    [anon_sym_switch] = ACTIONS(4140),
    [anon_sym_when] = ACTIONS(4140),
    [anon_sym_DOT_DOT] = ACTIONS(4140),
    [anon_sym_and] = ACTIONS(4140),
    [anon_sym_or] = ACTIONS(4140),
    [anon_sym_AMP_AMP] = ACTIONS(4140),
    [anon_sym_PIPE_PIPE] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK] = ACTIONS(4140),
    [anon_sym_on] = ACTIONS(4140),
    [anon_sym_equals] = ACTIONS(4140),
    [anon_sym_by] = ACTIONS(4140),
    [anon_sym_as] = ACTIONS(4140),
    [anon_sym_is] = ACTIONS(4140),
    [anon_sym_DASH_GT] = ACTIONS(4140),
    [anon_sym_with] = ACTIONS(4140),
    [aux_sym_preproc_if_token3] = ACTIONS(4140),
    [aux_sym_preproc_else_token1] = ACTIONS(4140),
    [aux_sym_preproc_elif_token1] = ACTIONS(4140),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3960] = {
    [sym_preproc_region] = STATE(3960),
    [sym_preproc_endregion] = STATE(3960),
    [sym_preproc_line] = STATE(3960),
    [sym_preproc_pragma] = STATE(3960),
    [sym_preproc_nullable] = STATE(3960),
    [sym_preproc_error] = STATE(3960),
    [sym_preproc_warning] = STATE(3960),
    [sym_preproc_define] = STATE(3960),
    [sym_preproc_undef] = STATE(3960),
    [anon_sym_EQ] = ACTIONS(5853),
    [anon_sym_LBRACK] = ACTIONS(5286),
    [anon_sym_COLON] = ACTIONS(5286),
    [anon_sym_LPAREN] = ACTIONS(5286),
    [anon_sym_LT] = ACTIONS(5288),
    [anon_sym_GT] = ACTIONS(5288),
    [anon_sym_QMARK] = ACTIONS(5288),
    [anon_sym_BANG] = ACTIONS(5288),
    [anon_sym_PLUS_PLUS] = ACTIONS(5286),
    [anon_sym_DASH_DASH] = ACTIONS(5286),
    [anon_sym_PLUS] = ACTIONS(5288),
    [anon_sym_DASH] = ACTIONS(5288),
    [anon_sym_STAR] = ACTIONS(5288),
    [anon_sym_SLASH] = ACTIONS(5288),
    [anon_sym_PERCENT] = ACTIONS(5288),
    [anon_sym_CARET] = ACTIONS(5288),
    [anon_sym_PIPE] = ACTIONS(5288),
    [anon_sym_AMP] = ACTIONS(5288),
    [anon_sym_LT_LT] = ACTIONS(5288),
    [anon_sym_GT_GT] = ACTIONS(5288),
    [anon_sym_GT_GT_GT] = ACTIONS(5288),
    [anon_sym_EQ_EQ] = ACTIONS(5286),
    [anon_sym_BANG_EQ] = ACTIONS(5286),
    [anon_sym_GT_EQ] = ACTIONS(5286),
    [anon_sym_LT_EQ] = ACTIONS(5286),
    [anon_sym_DOT] = ACTIONS(5288),
    [anon_sym_switch] = ACTIONS(5286),
    [anon_sym_when] = ACTIONS(5286),
    [anon_sym_DOT_DOT] = ACTIONS(5286),
    [anon_sym_and] = ACTIONS(5286),
    [anon_sym_or] = ACTIONS(5286),
    [anon_sym_PLUS_EQ] = ACTIONS(5855),
    [anon_sym_DASH_EQ] = ACTIONS(5855),
    [anon_sym_STAR_EQ] = ACTIONS(5855),
    [anon_sym_SLASH_EQ] = ACTIONS(5855),
    [anon_sym_PERCENT_EQ] = ACTIONS(5855),
    [anon_sym_AMP_EQ] = ACTIONS(5855),
    [anon_sym_CARET_EQ] = ACTIONS(5855),
    [anon_sym_PIPE_EQ] = ACTIONS(5855),
    [anon_sym_LT_LT_EQ] = ACTIONS(5855),
    [anon_sym_GT_GT_EQ] = ACTIONS(5855),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(5855),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(5855),
    [anon_sym_AMP_AMP] = ACTIONS(5286),
    [anon_sym_PIPE_PIPE] = ACTIONS(5286),
    [anon_sym_QMARK_QMARK] = ACTIONS(5288),
    [anon_sym_into] = ACTIONS(5286),
    [anon_sym_as] = ACTIONS(5286),
    [anon_sym_is] = ACTIONS(5286),
    [anon_sym_DASH_GT] = ACTIONS(5286),
    [anon_sym_with] = ACTIONS(5286),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3961] = {
    [sym_preproc_region] = STATE(3961),
    [sym_preproc_endregion] = STATE(3961),
    [sym_preproc_line] = STATE(3961),
    [sym_preproc_pragma] = STATE(3961),
    [sym_preproc_nullable] = STATE(3961),
    [sym_preproc_error] = STATE(3961),
    [sym_preproc_warning] = STATE(3961),
    [sym_preproc_define] = STATE(3961),
    [sym_preproc_undef] = STATE(3961),
    [anon_sym_SEMI] = ACTIONS(4494),
    [anon_sym_LBRACK] = ACTIONS(4593),
    [anon_sym_COLON] = ACTIONS(4494),
    [anon_sym_COMMA] = ACTIONS(4494),
    [anon_sym_RBRACK] = ACTIONS(4494),
    [anon_sym_LPAREN] = ACTIONS(4494),
    [anon_sym_RPAREN] = ACTIONS(4494),
    [anon_sym_LBRACE] = ACTIONS(4494),
    [anon_sym_RBRACE] = ACTIONS(4494),
    [anon_sym_LT] = ACTIONS(4492),
    [anon_sym_GT] = ACTIONS(4492),
    [anon_sym_in] = ACTIONS(4494),
    [anon_sym_QMARK] = ACTIONS(4492),
    [anon_sym_BANG] = ACTIONS(4492),
    [anon_sym_PLUS_PLUS] = ACTIONS(4494),
    [anon_sym_DASH_DASH] = ACTIONS(4494),
    [anon_sym_PLUS] = ACTIONS(4492),
    [anon_sym_DASH] = ACTIONS(4492),
    [anon_sym_STAR] = ACTIONS(4599),
    [anon_sym_SLASH] = ACTIONS(4492),
    [anon_sym_PERCENT] = ACTIONS(4494),
    [anon_sym_CARET] = ACTIONS(4494),
    [anon_sym_PIPE] = ACTIONS(4492),
    [anon_sym_AMP] = ACTIONS(4492),
    [anon_sym_LT_LT] = ACTIONS(4494),
    [anon_sym_GT_GT] = ACTIONS(4492),
    [anon_sym_GT_GT_GT] = ACTIONS(4494),
    [anon_sym_EQ_EQ] = ACTIONS(4494),
    [anon_sym_BANG_EQ] = ACTIONS(4494),
    [anon_sym_GT_EQ] = ACTIONS(4494),
    [anon_sym_LT_EQ] = ACTIONS(4494),
    [anon_sym_DOT] = ACTIONS(4492),
    [anon_sym_EQ_GT] = ACTIONS(4494),
    [anon_sym_switch] = ACTIONS(4494),
    [anon_sym_when] = ACTIONS(4494),
    [anon_sym_DOT_DOT] = ACTIONS(4494),
    [anon_sym_and] = ACTIONS(4494),
    [anon_sym_or] = ACTIONS(4494),
    [anon_sym_AMP_AMP] = ACTIONS(4494),
    [anon_sym_PIPE_PIPE] = ACTIONS(4494),
    [anon_sym_QMARK_QMARK] = ACTIONS(4494),
    [anon_sym_on] = ACTIONS(4494),
    [anon_sym_equals] = ACTIONS(4494),
    [anon_sym_by] = ACTIONS(4494),
    [anon_sym_as] = ACTIONS(4494),
    [anon_sym_is] = ACTIONS(4494),
    [anon_sym_DASH_GT] = ACTIONS(4494),
    [anon_sym_with] = ACTIONS(4494),
    [aux_sym_preproc_if_token3] = ACTIONS(4494),
    [aux_sym_preproc_else_token1] = ACTIONS(4494),
    [aux_sym_preproc_elif_token1] = ACTIONS(4494),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3962] = {
    [sym_preproc_region] = STATE(3962),
    [sym_preproc_endregion] = STATE(3962),
    [sym_preproc_line] = STATE(3962),
    [sym_preproc_pragma] = STATE(3962),
    [sym_preproc_nullable] = STATE(3962),
    [sym_preproc_error] = STATE(3962),
    [sym_preproc_warning] = STATE(3962),
    [sym_preproc_define] = STATE(3962),
    [sym_preproc_undef] = STATE(3962),
    [anon_sym_SEMI] = ACTIONS(4494),
    [anon_sym_LBRACK] = ACTIONS(4593),
    [anon_sym_COLON] = ACTIONS(4494),
    [anon_sym_COMMA] = ACTIONS(4494),
    [anon_sym_RBRACK] = ACTIONS(4494),
    [anon_sym_LPAREN] = ACTIONS(4494),
    [anon_sym_RPAREN] = ACTIONS(4494),
    [anon_sym_LBRACE] = ACTIONS(4494),
    [anon_sym_RBRACE] = ACTIONS(4494),
    [anon_sym_LT] = ACTIONS(4492),
    [anon_sym_GT] = ACTIONS(4492),
    [anon_sym_in] = ACTIONS(4494),
    [anon_sym_QMARK] = ACTIONS(5850),
    [anon_sym_BANG] = ACTIONS(4492),
    [anon_sym_PLUS_PLUS] = ACTIONS(4494),
    [anon_sym_DASH_DASH] = ACTIONS(4494),
    [anon_sym_PLUS] = ACTIONS(4492),
    [anon_sym_DASH] = ACTIONS(4492),
    [anon_sym_STAR] = ACTIONS(4599),
    [anon_sym_SLASH] = ACTIONS(4492),
    [anon_sym_PERCENT] = ACTIONS(4494),
    [anon_sym_CARET] = ACTIONS(4494),
    [anon_sym_PIPE] = ACTIONS(4492),
    [anon_sym_AMP] = ACTIONS(4492),
    [anon_sym_LT_LT] = ACTIONS(4494),
    [anon_sym_GT_GT] = ACTIONS(4492),
    [anon_sym_GT_GT_GT] = ACTIONS(4494),
    [anon_sym_EQ_EQ] = ACTIONS(4494),
    [anon_sym_BANG_EQ] = ACTIONS(4494),
    [anon_sym_GT_EQ] = ACTIONS(4494),
    [anon_sym_LT_EQ] = ACTIONS(4494),
    [anon_sym_DOT] = ACTIONS(4492),
    [anon_sym_EQ_GT] = ACTIONS(4494),
    [anon_sym_switch] = ACTIONS(4494),
    [anon_sym_when] = ACTIONS(4494),
    [anon_sym_DOT_DOT] = ACTIONS(4494),
    [anon_sym_and] = ACTIONS(4494),
    [anon_sym_or] = ACTIONS(4494),
    [anon_sym_AMP_AMP] = ACTIONS(4494),
    [anon_sym_PIPE_PIPE] = ACTIONS(4494),
    [anon_sym_QMARK_QMARK] = ACTIONS(4494),
    [anon_sym_on] = ACTIONS(4494),
    [anon_sym_equals] = ACTIONS(4494),
    [anon_sym_by] = ACTIONS(4494),
    [anon_sym_as] = ACTIONS(4494),
    [anon_sym_is] = ACTIONS(4494),
    [anon_sym_DASH_GT] = ACTIONS(4494),
    [anon_sym_with] = ACTIONS(4494),
    [aux_sym_preproc_if_token3] = ACTIONS(4494),
    [aux_sym_preproc_else_token1] = ACTIONS(4494),
    [aux_sym_preproc_elif_token1] = ACTIONS(4494),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3963] = {
    [sym_preproc_region] = STATE(3963),
    [sym_preproc_endregion] = STATE(3963),
    [sym_preproc_line] = STATE(3963),
    [sym_preproc_pragma] = STATE(3963),
    [sym_preproc_nullable] = STATE(3963),
    [sym_preproc_error] = STATE(3963),
    [sym_preproc_warning] = STATE(3963),
    [sym_preproc_define] = STATE(3963),
    [sym_preproc_undef] = STATE(3963),
    [anon_sym_EQ] = ACTIONS(5857),
    [anon_sym_LBRACK] = ACTIONS(5286),
    [anon_sym_LPAREN] = ACTIONS(5286),
    [anon_sym_LT] = ACTIONS(5288),
    [anon_sym_GT] = ACTIONS(5288),
    [anon_sym_QMARK] = ACTIONS(5288),
    [anon_sym_BANG] = ACTIONS(5288),
    [anon_sym_PLUS_PLUS] = ACTIONS(5286),
    [anon_sym_DASH_DASH] = ACTIONS(5286),
    [anon_sym_PLUS] = ACTIONS(5288),
    [anon_sym_DASH] = ACTIONS(5288),
    [anon_sym_STAR] = ACTIONS(5288),
    [anon_sym_SLASH] = ACTIONS(5288),
    [anon_sym_PERCENT] = ACTIONS(5288),
    [anon_sym_CARET] = ACTIONS(5288),
    [anon_sym_PIPE] = ACTIONS(5288),
    [anon_sym_AMP] = ACTIONS(5288),
    [anon_sym_LT_LT] = ACTIONS(5288),
    [anon_sym_GT_GT] = ACTIONS(5288),
    [anon_sym_GT_GT_GT] = ACTIONS(5288),
    [anon_sym_EQ_EQ] = ACTIONS(5286),
    [anon_sym_BANG_EQ] = ACTIONS(5286),
    [anon_sym_GT_EQ] = ACTIONS(5286),
    [anon_sym_LT_EQ] = ACTIONS(5286),
    [anon_sym_DOT] = ACTIONS(5288),
    [anon_sym_EQ_GT] = ACTIONS(5286),
    [anon_sym_switch] = ACTIONS(5286),
    [anon_sym_when] = ACTIONS(5286),
    [anon_sym_DOT_DOT] = ACTIONS(5286),
    [anon_sym_and] = ACTIONS(5286),
    [anon_sym_or] = ACTIONS(5286),
    [anon_sym_PLUS_EQ] = ACTIONS(5859),
    [anon_sym_DASH_EQ] = ACTIONS(5859),
    [anon_sym_STAR_EQ] = ACTIONS(5859),
    [anon_sym_SLASH_EQ] = ACTIONS(5859),
    [anon_sym_PERCENT_EQ] = ACTIONS(5859),
    [anon_sym_AMP_EQ] = ACTIONS(5859),
    [anon_sym_CARET_EQ] = ACTIONS(5859),
    [anon_sym_PIPE_EQ] = ACTIONS(5859),
    [anon_sym_LT_LT_EQ] = ACTIONS(5859),
    [anon_sym_GT_GT_EQ] = ACTIONS(5859),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(5859),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(5859),
    [anon_sym_AMP_AMP] = ACTIONS(5286),
    [anon_sym_PIPE_PIPE] = ACTIONS(5286),
    [anon_sym_QMARK_QMARK] = ACTIONS(5288),
    [anon_sym_into] = ACTIONS(5286),
    [anon_sym_as] = ACTIONS(5286),
    [anon_sym_is] = ACTIONS(5286),
    [anon_sym_DASH_GT] = ACTIONS(5286),
    [anon_sym_with] = ACTIONS(5286),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3964] = {
    [sym_preproc_region] = STATE(3964),
    [sym_preproc_endregion] = STATE(3964),
    [sym_preproc_line] = STATE(3964),
    [sym_preproc_pragma] = STATE(3964),
    [sym_preproc_nullable] = STATE(3964),
    [sym_preproc_error] = STATE(3964),
    [sym_preproc_warning] = STATE(3964),
    [sym_preproc_define] = STATE(3964),
    [sym_preproc_undef] = STATE(3964),
    [anon_sym_SEMI] = ACTIONS(4132),
    [anon_sym_LBRACK] = ACTIONS(4132),
    [anon_sym_COLON] = ACTIONS(4132),
    [anon_sym_COMMA] = ACTIONS(4132),
    [anon_sym_RBRACK] = ACTIONS(4132),
    [anon_sym_LPAREN] = ACTIONS(4132),
    [anon_sym_RPAREN] = ACTIONS(4132),
    [anon_sym_LBRACE] = ACTIONS(4132),
    [anon_sym_RBRACE] = ACTIONS(4132),
    [anon_sym_LT] = ACTIONS(4130),
    [anon_sym_GT] = ACTIONS(4130),
    [anon_sym_in] = ACTIONS(4132),
    [anon_sym_QMARK] = ACTIONS(4130),
    [anon_sym_BANG] = ACTIONS(4130),
    [anon_sym_PLUS_PLUS] = ACTIONS(4132),
    [anon_sym_DASH_DASH] = ACTIONS(4132),
    [anon_sym_PLUS] = ACTIONS(4130),
    [anon_sym_DASH] = ACTIONS(4130),
    [anon_sym_STAR] = ACTIONS(4132),
    [anon_sym_SLASH] = ACTIONS(4130),
    [anon_sym_PERCENT] = ACTIONS(4132),
    [anon_sym_CARET] = ACTIONS(4132),
    [anon_sym_PIPE] = ACTIONS(4130),
    [anon_sym_AMP] = ACTIONS(4130),
    [anon_sym_LT_LT] = ACTIONS(4132),
    [anon_sym_GT_GT] = ACTIONS(4130),
    [anon_sym_GT_GT_GT] = ACTIONS(4132),
    [anon_sym_EQ_EQ] = ACTIONS(4132),
    [anon_sym_BANG_EQ] = ACTIONS(4132),
    [anon_sym_GT_EQ] = ACTIONS(4132),
    [anon_sym_LT_EQ] = ACTIONS(4132),
    [anon_sym_DOT] = ACTIONS(4130),
    [anon_sym_EQ_GT] = ACTIONS(4132),
    [anon_sym_switch] = ACTIONS(4132),
    [anon_sym_when] = ACTIONS(4132),
    [anon_sym_DOT_DOT] = ACTIONS(4132),
    [anon_sym_and] = ACTIONS(4132),
    [anon_sym_or] = ACTIONS(4132),
    [anon_sym_AMP_AMP] = ACTIONS(4132),
    [anon_sym_PIPE_PIPE] = ACTIONS(4132),
    [anon_sym_QMARK_QMARK] = ACTIONS(4132),
    [anon_sym_on] = ACTIONS(4132),
    [anon_sym_equals] = ACTIONS(4132),
    [anon_sym_by] = ACTIONS(4132),
    [anon_sym_as] = ACTIONS(4132),
    [anon_sym_is] = ACTIONS(4132),
    [anon_sym_DASH_GT] = ACTIONS(4132),
    [anon_sym_with] = ACTIONS(4132),
    [aux_sym_preproc_if_token3] = ACTIONS(4132),
    [aux_sym_preproc_else_token1] = ACTIONS(4132),
    [aux_sym_preproc_elif_token1] = ACTIONS(4132),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3965] = {
    [sym_preproc_region] = STATE(3965),
    [sym_preproc_endregion] = STATE(3965),
    [sym_preproc_line] = STATE(3965),
    [sym_preproc_pragma] = STATE(3965),
    [sym_preproc_nullable] = STATE(3965),
    [sym_preproc_error] = STATE(3965),
    [sym_preproc_warning] = STATE(3965),
    [sym_preproc_define] = STATE(3965),
    [sym_preproc_undef] = STATE(3965),
    [anon_sym_SEMI] = ACTIONS(2997),
    [anon_sym_LBRACK] = ACTIONS(2997),
    [anon_sym_COLON] = ACTIONS(2997),
    [anon_sym_COMMA] = ACTIONS(2997),
    [anon_sym_RBRACK] = ACTIONS(2997),
    [anon_sym_LPAREN] = ACTIONS(2997),
    [anon_sym_RPAREN] = ACTIONS(2997),
    [anon_sym_RBRACE] = ACTIONS(2997),
    [anon_sym_LT] = ACTIONS(2995),
    [anon_sym_GT] = ACTIONS(2995),
    [anon_sym_in] = ACTIONS(2995),
    [anon_sym_QMARK] = ACTIONS(2995),
    [anon_sym_BANG] = ACTIONS(2995),
    [anon_sym_PLUS_PLUS] = ACTIONS(2997),
    [anon_sym_DASH_DASH] = ACTIONS(2997),
    [anon_sym_PLUS] = ACTIONS(2995),
    [anon_sym_DASH] = ACTIONS(2995),
    [anon_sym_STAR] = ACTIONS(2997),
    [anon_sym_SLASH] = ACTIONS(2995),
    [anon_sym_PERCENT] = ACTIONS(2997),
    [anon_sym_CARET] = ACTIONS(2997),
    [anon_sym_PIPE] = ACTIONS(2995),
    [anon_sym_AMP] = ACTIONS(2995),
    [anon_sym_LT_LT] = ACTIONS(2997),
    [anon_sym_GT_GT] = ACTIONS(2995),
    [anon_sym_GT_GT_GT] = ACTIONS(2997),
    [anon_sym_EQ_EQ] = ACTIONS(2997),
    [anon_sym_BANG_EQ] = ACTIONS(2997),
    [anon_sym_GT_EQ] = ACTIONS(2997),
    [anon_sym_LT_EQ] = ACTIONS(2997),
    [anon_sym_DOT] = ACTIONS(2995),
    [anon_sym_EQ_GT] = ACTIONS(2997),
    [anon_sym_switch] = ACTIONS(2997),
    [anon_sym_when] = ACTIONS(2997),
    [anon_sym_DOT_DOT] = ACTIONS(2997),
    [anon_sym_and] = ACTIONS(2997),
    [anon_sym_or] = ACTIONS(2997),
    [anon_sym_AMP_AMP] = ACTIONS(2997),
    [anon_sym_PIPE_PIPE] = ACTIONS(2997),
    [anon_sym_QMARK_QMARK] = ACTIONS(2997),
    [anon_sym_into] = ACTIONS(2997),
    [anon_sym_on] = ACTIONS(2997),
    [anon_sym_equals] = ACTIONS(2997),
    [anon_sym_by] = ACTIONS(2997),
    [anon_sym_as] = ACTIONS(2997),
    [anon_sym_is] = ACTIONS(2997),
    [anon_sym_DASH_GT] = ACTIONS(2997),
    [anon_sym_with] = ACTIONS(2997),
    [aux_sym_preproc_if_token3] = ACTIONS(2997),
    [aux_sym_preproc_else_token1] = ACTIONS(2997),
    [aux_sym_preproc_elif_token1] = ACTIONS(2997),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3966] = {
    [sym_preproc_region] = STATE(3966),
    [sym_preproc_endregion] = STATE(3966),
    [sym_preproc_line] = STATE(3966),
    [sym_preproc_pragma] = STATE(3966),
    [sym_preproc_nullable] = STATE(3966),
    [sym_preproc_error] = STATE(3966),
    [sym_preproc_warning] = STATE(3966),
    [sym_preproc_define] = STATE(3966),
    [sym_preproc_undef] = STATE(3966),
    [anon_sym_SEMI] = ACTIONS(5861),
    [anon_sym_LBRACK] = ACTIONS(5861),
    [anon_sym_COLON] = ACTIONS(5861),
    [anon_sym_COMMA] = ACTIONS(5861),
    [anon_sym_RBRACK] = ACTIONS(5861),
    [anon_sym_LPAREN] = ACTIONS(5861),
    [anon_sym_RPAREN] = ACTIONS(5861),
    [anon_sym_RBRACE] = ACTIONS(5861),
    [anon_sym_LT] = ACTIONS(5863),
    [anon_sym_GT] = ACTIONS(5863),
    [anon_sym_in] = ACTIONS(5863),
    [anon_sym_QMARK] = ACTIONS(5863),
    [anon_sym_BANG] = ACTIONS(5863),
    [anon_sym_PLUS_PLUS] = ACTIONS(5861),
    [anon_sym_DASH_DASH] = ACTIONS(5861),
    [anon_sym_PLUS] = ACTIONS(5863),
    [anon_sym_DASH] = ACTIONS(5863),
    [anon_sym_STAR] = ACTIONS(5861),
    [anon_sym_SLASH] = ACTIONS(5863),
    [anon_sym_PERCENT] = ACTIONS(5861),
    [anon_sym_CARET] = ACTIONS(5861),
    [anon_sym_PIPE] = ACTIONS(5863),
    [anon_sym_AMP] = ACTIONS(5863),
    [anon_sym_LT_LT] = ACTIONS(5861),
    [anon_sym_GT_GT] = ACTIONS(5863),
    [anon_sym_GT_GT_GT] = ACTIONS(5861),
    [anon_sym_EQ_EQ] = ACTIONS(5861),
    [anon_sym_BANG_EQ] = ACTIONS(5861),
    [anon_sym_GT_EQ] = ACTIONS(5861),
    [anon_sym_LT_EQ] = ACTIONS(5861),
    [anon_sym_DOT] = ACTIONS(5863),
    [anon_sym_EQ_GT] = ACTIONS(5861),
    [anon_sym_switch] = ACTIONS(5861),
    [anon_sym_when] = ACTIONS(5861),
    [anon_sym_DOT_DOT] = ACTIONS(5861),
    [anon_sym_and] = ACTIONS(5861),
    [anon_sym_or] = ACTIONS(5861),
    [anon_sym_AMP_AMP] = ACTIONS(5861),
    [anon_sym_PIPE_PIPE] = ACTIONS(5861),
    [anon_sym_QMARK_QMARK] = ACTIONS(5861),
    [anon_sym_into] = ACTIONS(5861),
    [anon_sym_on] = ACTIONS(5861),
    [anon_sym_equals] = ACTIONS(5861),
    [anon_sym_by] = ACTIONS(5861),
    [anon_sym_as] = ACTIONS(5861),
    [anon_sym_is] = ACTIONS(5861),
    [anon_sym_DASH_GT] = ACTIONS(5861),
    [anon_sym_with] = ACTIONS(5861),
    [aux_sym_preproc_if_token3] = ACTIONS(5861),
    [aux_sym_preproc_else_token1] = ACTIONS(5861),
    [aux_sym_preproc_elif_token1] = ACTIONS(5861),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3967] = {
    [sym_preproc_region] = STATE(3967),
    [sym_preproc_endregion] = STATE(3967),
    [sym_preproc_line] = STATE(3967),
    [sym_preproc_pragma] = STATE(3967),
    [sym_preproc_nullable] = STATE(3967),
    [sym_preproc_error] = STATE(3967),
    [sym_preproc_warning] = STATE(3967),
    [sym_preproc_define] = STATE(3967),
    [sym_preproc_undef] = STATE(3967),
    [anon_sym_SEMI] = ACTIONS(5506),
    [anon_sym_LBRACK] = ACTIONS(5506),
    [anon_sym_COLON] = ACTIONS(5506),
    [anon_sym_COMMA] = ACTIONS(5506),
    [anon_sym_RBRACK] = ACTIONS(5506),
    [anon_sym_LPAREN] = ACTIONS(5506),
    [anon_sym_RPAREN] = ACTIONS(5506),
    [anon_sym_RBRACE] = ACTIONS(5506),
    [anon_sym_LT] = ACTIONS(5508),
    [anon_sym_GT] = ACTIONS(5508),
    [anon_sym_in] = ACTIONS(5508),
    [anon_sym_QMARK] = ACTIONS(5508),
    [anon_sym_BANG] = ACTIONS(5508),
    [anon_sym_PLUS_PLUS] = ACTIONS(5506),
    [anon_sym_DASH_DASH] = ACTIONS(5506),
    [anon_sym_PLUS] = ACTIONS(5508),
    [anon_sym_DASH] = ACTIONS(5508),
    [anon_sym_STAR] = ACTIONS(5506),
    [anon_sym_SLASH] = ACTIONS(5508),
    [anon_sym_PERCENT] = ACTIONS(5506),
    [anon_sym_CARET] = ACTIONS(5506),
    [anon_sym_PIPE] = ACTIONS(5508),
    [anon_sym_AMP] = ACTIONS(5508),
    [anon_sym_LT_LT] = ACTIONS(5506),
    [anon_sym_GT_GT] = ACTIONS(5508),
    [anon_sym_GT_GT_GT] = ACTIONS(5506),
    [anon_sym_EQ_EQ] = ACTIONS(5506),
    [anon_sym_BANG_EQ] = ACTIONS(5506),
    [anon_sym_GT_EQ] = ACTIONS(5506),
    [anon_sym_LT_EQ] = ACTIONS(5506),
    [anon_sym_DOT] = ACTIONS(5508),
    [anon_sym_EQ_GT] = ACTIONS(5506),
    [anon_sym_switch] = ACTIONS(5506),
    [anon_sym_when] = ACTIONS(5506),
    [anon_sym_DOT_DOT] = ACTIONS(5506),
    [anon_sym_and] = ACTIONS(5506),
    [anon_sym_or] = ACTIONS(5506),
    [anon_sym_AMP_AMP] = ACTIONS(5506),
    [anon_sym_PIPE_PIPE] = ACTIONS(5506),
    [anon_sym_QMARK_QMARK] = ACTIONS(5506),
    [anon_sym_into] = ACTIONS(5506),
    [anon_sym_on] = ACTIONS(5506),
    [anon_sym_equals] = ACTIONS(5506),
    [anon_sym_by] = ACTIONS(5506),
    [anon_sym_as] = ACTIONS(5506),
    [anon_sym_is] = ACTIONS(5506),
    [anon_sym_DASH_GT] = ACTIONS(5506),
    [anon_sym_with] = ACTIONS(5506),
    [aux_sym_preproc_if_token3] = ACTIONS(5506),
    [aux_sym_preproc_else_token1] = ACTIONS(5506),
    [aux_sym_preproc_elif_token1] = ACTIONS(5506),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3968] = {
    [sym_preproc_region] = STATE(3968),
    [sym_preproc_endregion] = STATE(3968),
    [sym_preproc_line] = STATE(3968),
    [sym_preproc_pragma] = STATE(3968),
    [sym_preproc_nullable] = STATE(3968),
    [sym_preproc_error] = STATE(3968),
    [sym_preproc_warning] = STATE(3968),
    [sym_preproc_define] = STATE(3968),
    [sym_preproc_undef] = STATE(3968),
    [anon_sym_SEMI] = ACTIONS(5382),
    [anon_sym_LBRACK] = ACTIONS(5382),
    [anon_sym_COLON] = ACTIONS(5382),
    [anon_sym_COMMA] = ACTIONS(5382),
    [anon_sym_RBRACK] = ACTIONS(5382),
    [anon_sym_LPAREN] = ACTIONS(5382),
    [anon_sym_RPAREN] = ACTIONS(5382),
    [anon_sym_RBRACE] = ACTIONS(5382),
    [anon_sym_LT] = ACTIONS(5384),
    [anon_sym_GT] = ACTIONS(5384),
    [anon_sym_in] = ACTIONS(5382),
    [anon_sym_QMARK] = ACTIONS(5384),
    [anon_sym_BANG] = ACTIONS(5384),
    [anon_sym_PLUS_PLUS] = ACTIONS(5382),
    [anon_sym_DASH_DASH] = ACTIONS(5382),
    [anon_sym_PLUS] = ACTIONS(5384),
    [anon_sym_DASH] = ACTIONS(5384),
    [anon_sym_STAR] = ACTIONS(5382),
    [anon_sym_SLASH] = ACTIONS(5384),
    [anon_sym_PERCENT] = ACTIONS(5382),
    [anon_sym_CARET] = ACTIONS(5382),
    [anon_sym_PIPE] = ACTIONS(5384),
    [anon_sym_AMP] = ACTIONS(5384),
    [anon_sym_LT_LT] = ACTIONS(5382),
    [anon_sym_GT_GT] = ACTIONS(5384),
    [anon_sym_GT_GT_GT] = ACTIONS(5382),
    [anon_sym_EQ_EQ] = ACTIONS(5382),
    [anon_sym_BANG_EQ] = ACTIONS(5382),
    [anon_sym_GT_EQ] = ACTIONS(5382),
    [anon_sym_LT_EQ] = ACTIONS(5382),
    [anon_sym_DOT] = ACTIONS(5384),
    [anon_sym_EQ_GT] = ACTIONS(5382),
    [anon_sym_switch] = ACTIONS(5382),
    [anon_sym_when] = ACTIONS(5382),
    [anon_sym_DOT_DOT] = ACTIONS(5382),
    [anon_sym_and] = ACTIONS(5382),
    [anon_sym_or] = ACTIONS(5382),
    [anon_sym_AMP_AMP] = ACTIONS(5382),
    [anon_sym_PIPE_PIPE] = ACTIONS(5382),
    [anon_sym_QMARK_QMARK] = ACTIONS(5382),
    [anon_sym_on] = ACTIONS(5382),
    [anon_sym_equals] = ACTIONS(5382),
    [anon_sym_by] = ACTIONS(5382),
    [anon_sym_as] = ACTIONS(5382),
    [anon_sym_is] = ACTIONS(5382),
    [anon_sym_DASH_GT] = ACTIONS(5382),
    [anon_sym_with] = ACTIONS(5382),
    [anon_sym_DQUOTE] = ACTIONS(5382),
    [aux_sym_preproc_if_token3] = ACTIONS(5382),
    [aux_sym_preproc_else_token1] = ACTIONS(5382),
    [aux_sym_preproc_elif_token1] = ACTIONS(5382),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3969] = {
    [sym_preproc_region] = STATE(3969),
    [sym_preproc_endregion] = STATE(3969),
    [sym_preproc_line] = STATE(3969),
    [sym_preproc_pragma] = STATE(3969),
    [sym_preproc_nullable] = STATE(3969),
    [sym_preproc_error] = STATE(3969),
    [sym_preproc_warning] = STATE(3969),
    [sym_preproc_define] = STATE(3969),
    [sym_preproc_undef] = STATE(3969),
    [anon_sym_SEMI] = ACTIONS(3039),
    [anon_sym_LBRACK] = ACTIONS(3039),
    [anon_sym_COLON] = ACTIONS(3039),
    [anon_sym_COMMA] = ACTIONS(3039),
    [anon_sym_RBRACK] = ACTIONS(3039),
    [anon_sym_LPAREN] = ACTIONS(3039),
    [anon_sym_RPAREN] = ACTIONS(3039),
    [anon_sym_RBRACE] = ACTIONS(3039),
    [anon_sym_LT] = ACTIONS(3037),
    [anon_sym_GT] = ACTIONS(3037),
    [anon_sym_in] = ACTIONS(3037),
    [anon_sym_QMARK] = ACTIONS(3037),
    [anon_sym_BANG] = ACTIONS(3037),
    [anon_sym_PLUS_PLUS] = ACTIONS(3039),
    [anon_sym_DASH_DASH] = ACTIONS(3039),
    [anon_sym_PLUS] = ACTIONS(3037),
    [anon_sym_DASH] = ACTIONS(3037),
    [anon_sym_STAR] = ACTIONS(3039),
    [anon_sym_SLASH] = ACTIONS(3037),
    [anon_sym_PERCENT] = ACTIONS(3039),
    [anon_sym_CARET] = ACTIONS(3039),
    [anon_sym_PIPE] = ACTIONS(3037),
    [anon_sym_AMP] = ACTIONS(3037),
    [anon_sym_LT_LT] = ACTIONS(3039),
    [anon_sym_GT_GT] = ACTIONS(3037),
    [anon_sym_GT_GT_GT] = ACTIONS(3039),
    [anon_sym_EQ_EQ] = ACTIONS(3039),
    [anon_sym_BANG_EQ] = ACTIONS(3039),
    [anon_sym_GT_EQ] = ACTIONS(3039),
    [anon_sym_LT_EQ] = ACTIONS(3039),
    [anon_sym_DOT] = ACTIONS(3037),
    [anon_sym_EQ_GT] = ACTIONS(3039),
    [anon_sym_switch] = ACTIONS(3039),
    [anon_sym_when] = ACTIONS(3039),
    [anon_sym_DOT_DOT] = ACTIONS(3039),
    [anon_sym_and] = ACTIONS(3039),
    [anon_sym_or] = ACTIONS(3039),
    [anon_sym_AMP_AMP] = ACTIONS(3039),
    [anon_sym_PIPE_PIPE] = ACTIONS(3039),
    [anon_sym_QMARK_QMARK] = ACTIONS(3039),
    [anon_sym_into] = ACTIONS(3039),
    [anon_sym_on] = ACTIONS(3039),
    [anon_sym_equals] = ACTIONS(3039),
    [anon_sym_by] = ACTIONS(3039),
    [anon_sym_as] = ACTIONS(3039),
    [anon_sym_is] = ACTIONS(3039),
    [anon_sym_DASH_GT] = ACTIONS(3039),
    [anon_sym_with] = ACTIONS(3039),
    [aux_sym_preproc_if_token3] = ACTIONS(3039),
    [aux_sym_preproc_else_token1] = ACTIONS(3039),
    [aux_sym_preproc_elif_token1] = ACTIONS(3039),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3970] = {
    [sym_preproc_region] = STATE(3970),
    [sym_preproc_endregion] = STATE(3970),
    [sym_preproc_line] = STATE(3970),
    [sym_preproc_pragma] = STATE(3970),
    [sym_preproc_nullable] = STATE(3970),
    [sym_preproc_error] = STATE(3970),
    [sym_preproc_warning] = STATE(3970),
    [sym_preproc_define] = STATE(3970),
    [sym_preproc_undef] = STATE(3970),
    [anon_sym_SEMI] = ACTIONS(5498),
    [anon_sym_LBRACK] = ACTIONS(5498),
    [anon_sym_COLON] = ACTIONS(5498),
    [anon_sym_COMMA] = ACTIONS(5498),
    [anon_sym_RBRACK] = ACTIONS(5498),
    [anon_sym_LPAREN] = ACTIONS(5498),
    [anon_sym_RPAREN] = ACTIONS(5498),
    [anon_sym_RBRACE] = ACTIONS(5498),
    [anon_sym_LT] = ACTIONS(5500),
    [anon_sym_GT] = ACTIONS(5500),
    [anon_sym_in] = ACTIONS(5500),
    [anon_sym_QMARK] = ACTIONS(5500),
    [anon_sym_BANG] = ACTIONS(5500),
    [anon_sym_PLUS_PLUS] = ACTIONS(5498),
    [anon_sym_DASH_DASH] = ACTIONS(5498),
    [anon_sym_PLUS] = ACTIONS(5500),
    [anon_sym_DASH] = ACTIONS(5500),
    [anon_sym_STAR] = ACTIONS(5498),
    [anon_sym_SLASH] = ACTIONS(5500),
    [anon_sym_PERCENT] = ACTIONS(5498),
    [anon_sym_CARET] = ACTIONS(5498),
    [anon_sym_PIPE] = ACTIONS(5500),
    [anon_sym_AMP] = ACTIONS(5500),
    [anon_sym_LT_LT] = ACTIONS(5498),
    [anon_sym_GT_GT] = ACTIONS(5500),
    [anon_sym_GT_GT_GT] = ACTIONS(5498),
    [anon_sym_EQ_EQ] = ACTIONS(5498),
    [anon_sym_BANG_EQ] = ACTIONS(5498),
    [anon_sym_GT_EQ] = ACTIONS(5498),
    [anon_sym_LT_EQ] = ACTIONS(5498),
    [anon_sym_DOT] = ACTIONS(5500),
    [anon_sym_EQ_GT] = ACTIONS(5498),
    [anon_sym_switch] = ACTIONS(5498),
    [anon_sym_when] = ACTIONS(5498),
    [anon_sym_DOT_DOT] = ACTIONS(5498),
    [anon_sym_and] = ACTIONS(5498),
    [anon_sym_or] = ACTIONS(5498),
    [anon_sym_AMP_AMP] = ACTIONS(5498),
    [anon_sym_PIPE_PIPE] = ACTIONS(5498),
    [anon_sym_QMARK_QMARK] = ACTIONS(5498),
    [anon_sym_into] = ACTIONS(5498),
    [anon_sym_on] = ACTIONS(5498),
    [anon_sym_equals] = ACTIONS(5498),
    [anon_sym_by] = ACTIONS(5498),
    [anon_sym_as] = ACTIONS(5498),
    [anon_sym_is] = ACTIONS(5498),
    [anon_sym_DASH_GT] = ACTIONS(5498),
    [anon_sym_with] = ACTIONS(5498),
    [aux_sym_preproc_if_token3] = ACTIONS(5498),
    [aux_sym_preproc_else_token1] = ACTIONS(5498),
    [aux_sym_preproc_elif_token1] = ACTIONS(5498),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3971] = {
    [sym_preproc_region] = STATE(3971),
    [sym_preproc_endregion] = STATE(3971),
    [sym_preproc_line] = STATE(3971),
    [sym_preproc_pragma] = STATE(3971),
    [sym_preproc_nullable] = STATE(3971),
    [sym_preproc_error] = STATE(3971),
    [sym_preproc_warning] = STATE(3971),
    [sym_preproc_define] = STATE(3971),
    [sym_preproc_undef] = STATE(3971),
    [anon_sym_SEMI] = ACTIONS(4455),
    [anon_sym_LBRACK] = ACTIONS(4455),
    [anon_sym_COLON] = ACTIONS(4455),
    [anon_sym_COMMA] = ACTIONS(4455),
    [anon_sym_RBRACK] = ACTIONS(4455),
    [anon_sym_LPAREN] = ACTIONS(4455),
    [anon_sym_RPAREN] = ACTIONS(4455),
    [anon_sym_LBRACE] = ACTIONS(4455),
    [anon_sym_RBRACE] = ACTIONS(4455),
    [anon_sym_LT] = ACTIONS(4453),
    [anon_sym_GT] = ACTIONS(4453),
    [anon_sym_in] = ACTIONS(4455),
    [anon_sym_QMARK] = ACTIONS(4453),
    [anon_sym_BANG] = ACTIONS(4453),
    [anon_sym_PLUS_PLUS] = ACTIONS(4455),
    [anon_sym_DASH_DASH] = ACTIONS(4455),
    [anon_sym_PLUS] = ACTIONS(4453),
    [anon_sym_DASH] = ACTIONS(4453),
    [anon_sym_STAR] = ACTIONS(4455),
    [anon_sym_SLASH] = ACTIONS(4453),
    [anon_sym_PERCENT] = ACTIONS(4455),
    [anon_sym_CARET] = ACTIONS(4455),
    [anon_sym_PIPE] = ACTIONS(4453),
    [anon_sym_AMP] = ACTIONS(4453),
    [anon_sym_LT_LT] = ACTIONS(4455),
    [anon_sym_GT_GT] = ACTIONS(4453),
    [anon_sym_GT_GT_GT] = ACTIONS(4455),
    [anon_sym_EQ_EQ] = ACTIONS(4455),
    [anon_sym_BANG_EQ] = ACTIONS(4455),
    [anon_sym_GT_EQ] = ACTIONS(4455),
    [anon_sym_LT_EQ] = ACTIONS(4455),
    [anon_sym_DOT] = ACTIONS(4453),
    [anon_sym_EQ_GT] = ACTIONS(4455),
    [anon_sym_switch] = ACTIONS(4455),
    [anon_sym_when] = ACTIONS(4455),
    [anon_sym_DOT_DOT] = ACTIONS(4455),
    [anon_sym_and] = ACTIONS(4455),
    [anon_sym_or] = ACTIONS(4455),
    [anon_sym_AMP_AMP] = ACTIONS(4455),
    [anon_sym_PIPE_PIPE] = ACTIONS(4455),
    [anon_sym_QMARK_QMARK] = ACTIONS(4455),
    [anon_sym_on] = ACTIONS(4455),
    [anon_sym_equals] = ACTIONS(4455),
    [anon_sym_by] = ACTIONS(4455),
    [anon_sym_as] = ACTIONS(4455),
    [anon_sym_is] = ACTIONS(4455),
    [anon_sym_DASH_GT] = ACTIONS(4455),
    [anon_sym_with] = ACTIONS(4455),
    [aux_sym_preproc_if_token3] = ACTIONS(4455),
    [aux_sym_preproc_else_token1] = ACTIONS(4455),
    [aux_sym_preproc_elif_token1] = ACTIONS(4455),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3972] = {
    [sym_preproc_region] = STATE(3972),
    [sym_preproc_endregion] = STATE(3972),
    [sym_preproc_line] = STATE(3972),
    [sym_preproc_pragma] = STATE(3972),
    [sym_preproc_nullable] = STATE(3972),
    [sym_preproc_error] = STATE(3972),
    [sym_preproc_warning] = STATE(3972),
    [sym_preproc_define] = STATE(3972),
    [sym_preproc_undef] = STATE(3972),
    [anon_sym_SEMI] = ACTIONS(5522),
    [anon_sym_LBRACK] = ACTIONS(5522),
    [anon_sym_COLON] = ACTIONS(5522),
    [anon_sym_COMMA] = ACTIONS(5522),
    [anon_sym_RBRACK] = ACTIONS(5522),
    [anon_sym_LPAREN] = ACTIONS(5522),
    [anon_sym_RPAREN] = ACTIONS(5522),
    [anon_sym_RBRACE] = ACTIONS(5522),
    [anon_sym_LT] = ACTIONS(5524),
    [anon_sym_GT] = ACTIONS(5524),
    [anon_sym_in] = ACTIONS(5524),
    [anon_sym_QMARK] = ACTIONS(5524),
    [anon_sym_BANG] = ACTIONS(5524),
    [anon_sym_PLUS_PLUS] = ACTIONS(5522),
    [anon_sym_DASH_DASH] = ACTIONS(5522),
    [anon_sym_PLUS] = ACTIONS(5524),
    [anon_sym_DASH] = ACTIONS(5524),
    [anon_sym_STAR] = ACTIONS(5522),
    [anon_sym_SLASH] = ACTIONS(5524),
    [anon_sym_PERCENT] = ACTIONS(5522),
    [anon_sym_CARET] = ACTIONS(5522),
    [anon_sym_PIPE] = ACTIONS(5524),
    [anon_sym_AMP] = ACTIONS(5524),
    [anon_sym_LT_LT] = ACTIONS(5522),
    [anon_sym_GT_GT] = ACTIONS(5524),
    [anon_sym_GT_GT_GT] = ACTIONS(5522),
    [anon_sym_EQ_EQ] = ACTIONS(5522),
    [anon_sym_BANG_EQ] = ACTIONS(5522),
    [anon_sym_GT_EQ] = ACTIONS(5522),
    [anon_sym_LT_EQ] = ACTIONS(5522),
    [anon_sym_DOT] = ACTIONS(5524),
    [anon_sym_EQ_GT] = ACTIONS(5522),
    [anon_sym_switch] = ACTIONS(5522),
    [anon_sym_when] = ACTIONS(5522),
    [anon_sym_DOT_DOT] = ACTIONS(5522),
    [anon_sym_and] = ACTIONS(5522),
    [anon_sym_or] = ACTIONS(5522),
    [anon_sym_AMP_AMP] = ACTIONS(5522),
    [anon_sym_PIPE_PIPE] = ACTIONS(5522),
    [anon_sym_QMARK_QMARK] = ACTIONS(5522),
    [anon_sym_into] = ACTIONS(5522),
    [anon_sym_on] = ACTIONS(5522),
    [anon_sym_equals] = ACTIONS(5522),
    [anon_sym_by] = ACTIONS(5522),
    [anon_sym_as] = ACTIONS(5522),
    [anon_sym_is] = ACTIONS(5522),
    [anon_sym_DASH_GT] = ACTIONS(5522),
    [anon_sym_with] = ACTIONS(5522),
    [aux_sym_preproc_if_token3] = ACTIONS(5522),
    [aux_sym_preproc_else_token1] = ACTIONS(5522),
    [aux_sym_preproc_elif_token1] = ACTIONS(5522),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3973] = {
    [sym_preproc_region] = STATE(3973),
    [sym_preproc_endregion] = STATE(3973),
    [sym_preproc_line] = STATE(3973),
    [sym_preproc_pragma] = STATE(3973),
    [sym_preproc_nullable] = STATE(3973),
    [sym_preproc_error] = STATE(3973),
    [sym_preproc_warning] = STATE(3973),
    [sym_preproc_define] = STATE(3973),
    [sym_preproc_undef] = STATE(3973),
    [anon_sym_SEMI] = ACTIONS(4468),
    [anon_sym_LBRACK] = ACTIONS(4468),
    [anon_sym_COLON] = ACTIONS(4468),
    [anon_sym_COMMA] = ACTIONS(4468),
    [anon_sym_RBRACK] = ACTIONS(4468),
    [anon_sym_LPAREN] = ACTIONS(4468),
    [anon_sym_RPAREN] = ACTIONS(4468),
    [anon_sym_LBRACE] = ACTIONS(4468),
    [anon_sym_RBRACE] = ACTIONS(4468),
    [anon_sym_LT] = ACTIONS(4466),
    [anon_sym_GT] = ACTIONS(4466),
    [anon_sym_in] = ACTIONS(4468),
    [anon_sym_QMARK] = ACTIONS(4466),
    [anon_sym_BANG] = ACTIONS(4466),
    [anon_sym_PLUS_PLUS] = ACTIONS(4468),
    [anon_sym_DASH_DASH] = ACTIONS(4468),
    [anon_sym_PLUS] = ACTIONS(4466),
    [anon_sym_DASH] = ACTIONS(4466),
    [anon_sym_STAR] = ACTIONS(4468),
    [anon_sym_SLASH] = ACTIONS(4466),
    [anon_sym_PERCENT] = ACTIONS(4468),
    [anon_sym_CARET] = ACTIONS(4468),
    [anon_sym_PIPE] = ACTIONS(4466),
    [anon_sym_AMP] = ACTIONS(4466),
    [anon_sym_LT_LT] = ACTIONS(4468),
    [anon_sym_GT_GT] = ACTIONS(4466),
    [anon_sym_GT_GT_GT] = ACTIONS(4468),
    [anon_sym_EQ_EQ] = ACTIONS(4468),
    [anon_sym_BANG_EQ] = ACTIONS(4468),
    [anon_sym_GT_EQ] = ACTIONS(4468),
    [anon_sym_LT_EQ] = ACTIONS(4468),
    [anon_sym_DOT] = ACTIONS(4466),
    [anon_sym_EQ_GT] = ACTIONS(4468),
    [anon_sym_switch] = ACTIONS(4468),
    [anon_sym_when] = ACTIONS(4468),
    [anon_sym_DOT_DOT] = ACTIONS(4468),
    [anon_sym_and] = ACTIONS(4468),
    [anon_sym_or] = ACTIONS(4468),
    [anon_sym_AMP_AMP] = ACTIONS(4468),
    [anon_sym_PIPE_PIPE] = ACTIONS(4468),
    [anon_sym_QMARK_QMARK] = ACTIONS(4468),
    [anon_sym_on] = ACTIONS(4468),
    [anon_sym_equals] = ACTIONS(4468),
    [anon_sym_by] = ACTIONS(4468),
    [anon_sym_as] = ACTIONS(4468),
    [anon_sym_is] = ACTIONS(4468),
    [anon_sym_DASH_GT] = ACTIONS(4468),
    [anon_sym_with] = ACTIONS(4468),
    [aux_sym_preproc_if_token3] = ACTIONS(4468),
    [aux_sym_preproc_else_token1] = ACTIONS(4468),
    [aux_sym_preproc_elif_token1] = ACTIONS(4468),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3974] = {
    [sym_preproc_region] = STATE(3974),
    [sym_preproc_endregion] = STATE(3974),
    [sym_preproc_line] = STATE(3974),
    [sym_preproc_pragma] = STATE(3974),
    [sym_preproc_nullable] = STATE(3974),
    [sym_preproc_error] = STATE(3974),
    [sym_preproc_warning] = STATE(3974),
    [sym_preproc_define] = STATE(3974),
    [sym_preproc_undef] = STATE(3974),
    [anon_sym_SEMI] = ACTIONS(5576),
    [anon_sym_LBRACK] = ACTIONS(5576),
    [anon_sym_COLON] = ACTIONS(5576),
    [anon_sym_COMMA] = ACTIONS(5576),
    [anon_sym_RBRACK] = ACTIONS(5576),
    [anon_sym_LPAREN] = ACTIONS(5576),
    [anon_sym_RPAREN] = ACTIONS(5576),
    [anon_sym_RBRACE] = ACTIONS(5576),
    [anon_sym_LT] = ACTIONS(5578),
    [anon_sym_GT] = ACTIONS(5578),
    [anon_sym_in] = ACTIONS(5578),
    [anon_sym_QMARK] = ACTIONS(5578),
    [anon_sym_BANG] = ACTIONS(5578),
    [anon_sym_PLUS_PLUS] = ACTIONS(5576),
    [anon_sym_DASH_DASH] = ACTIONS(5576),
    [anon_sym_PLUS] = ACTIONS(5578),
    [anon_sym_DASH] = ACTIONS(5578),
    [anon_sym_STAR] = ACTIONS(5576),
    [anon_sym_SLASH] = ACTIONS(5578),
    [anon_sym_PERCENT] = ACTIONS(5576),
    [anon_sym_CARET] = ACTIONS(5576),
    [anon_sym_PIPE] = ACTIONS(5578),
    [anon_sym_AMP] = ACTIONS(5578),
    [anon_sym_LT_LT] = ACTIONS(5576),
    [anon_sym_GT_GT] = ACTIONS(5578),
    [anon_sym_GT_GT_GT] = ACTIONS(5576),
    [anon_sym_EQ_EQ] = ACTIONS(5576),
    [anon_sym_BANG_EQ] = ACTIONS(5576),
    [anon_sym_GT_EQ] = ACTIONS(5576),
    [anon_sym_LT_EQ] = ACTIONS(5576),
    [anon_sym_DOT] = ACTIONS(5578),
    [anon_sym_EQ_GT] = ACTIONS(5576),
    [anon_sym_switch] = ACTIONS(5576),
    [anon_sym_when] = ACTIONS(5576),
    [anon_sym_DOT_DOT] = ACTIONS(5576),
    [anon_sym_and] = ACTIONS(5576),
    [anon_sym_or] = ACTIONS(5576),
    [anon_sym_AMP_AMP] = ACTIONS(5576),
    [anon_sym_PIPE_PIPE] = ACTIONS(5576),
    [anon_sym_QMARK_QMARK] = ACTIONS(5576),
    [anon_sym_into] = ACTIONS(5576),
    [anon_sym_on] = ACTIONS(5576),
    [anon_sym_equals] = ACTIONS(5576),
    [anon_sym_by] = ACTIONS(5576),
    [anon_sym_as] = ACTIONS(5576),
    [anon_sym_is] = ACTIONS(5576),
    [anon_sym_DASH_GT] = ACTIONS(5576),
    [anon_sym_with] = ACTIONS(5576),
    [aux_sym_preproc_if_token3] = ACTIONS(5576),
    [aux_sym_preproc_else_token1] = ACTIONS(5576),
    [aux_sym_preproc_elif_token1] = ACTIONS(5576),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3975] = {
    [sym_modifier] = STATE(4497),
    [sym_identifier] = STATE(7872),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_region] = STATE(3975),
    [sym_preproc_endregion] = STATE(3975),
    [sym_preproc_line] = STATE(3975),
    [sym_preproc_pragma] = STATE(3975),
    [sym_preproc_nullable] = STATE(3975),
    [sym_preproc_error] = STATE(3975),
    [sym_preproc_warning] = STATE(3975),
    [sym_preproc_define] = STATE(3975),
    [sym_preproc_undef] = STATE(3975),
    [aux_sym_class_declaration_repeat2] = STATE(4351),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(5456),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_unsafe] = ACTIONS(5456),
    [anon_sym_static] = ACTIONS(5456),
    [anon_sym_abstract] = ACTIONS(5456),
    [anon_sym_async] = ACTIONS(5456),
    [anon_sym_const] = ACTIONS(5456),
    [anon_sym_file] = ACTIONS(5462),
    [anon_sym_fixed] = ACTIONS(5456),
    [anon_sym_internal] = ACTIONS(5456),
    [anon_sym_new] = ACTIONS(5456),
    [anon_sym_override] = ACTIONS(5456),
    [anon_sym_partial] = ACTIONS(5456),
    [anon_sym_private] = ACTIONS(5456),
    [anon_sym_protected] = ACTIONS(5456),
    [anon_sym_public] = ACTIONS(5456),
    [anon_sym_readonly] = ACTIONS(5456),
    [anon_sym_required] = ACTIONS(5456),
    [anon_sym_sealed] = ACTIONS(5456),
    [anon_sym_virtual] = ACTIONS(5456),
    [anon_sym_volatile] = ACTIONS(5456),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_get] = ACTIONS(5757),
    [anon_sym_set] = ACTIONS(5757),
    [anon_sym_add] = ACTIONS(5757),
    [anon_sym_remove] = ACTIONS(5757),
    [anon_sym_init] = ACTIONS(5757),
    [anon_sym_scoped] = ACTIONS(29),
    [anon_sym_var] = ACTIONS(29),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_from] = ACTIONS(29),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3976] = {
    [sym_preproc_region] = STATE(3976),
    [sym_preproc_endregion] = STATE(3976),
    [sym_preproc_line] = STATE(3976),
    [sym_preproc_pragma] = STATE(3976),
    [sym_preproc_nullable] = STATE(3976),
    [sym_preproc_error] = STATE(3976),
    [sym_preproc_warning] = STATE(3976),
    [sym_preproc_define] = STATE(3976),
    [sym_preproc_undef] = STATE(3976),
    [anon_sym_SEMI] = ACTIONS(4480),
    [anon_sym_LBRACK] = ACTIONS(4480),
    [anon_sym_COLON] = ACTIONS(4480),
    [anon_sym_COMMA] = ACTIONS(4480),
    [anon_sym_RBRACK] = ACTIONS(4480),
    [anon_sym_LPAREN] = ACTIONS(4480),
    [anon_sym_RPAREN] = ACTIONS(4480),
    [anon_sym_LBRACE] = ACTIONS(4480),
    [anon_sym_RBRACE] = ACTIONS(4480),
    [anon_sym_LT] = ACTIONS(4478),
    [anon_sym_GT] = ACTIONS(4478),
    [anon_sym_in] = ACTIONS(4480),
    [anon_sym_QMARK] = ACTIONS(4478),
    [anon_sym_BANG] = ACTIONS(4478),
    [anon_sym_PLUS_PLUS] = ACTIONS(4480),
    [anon_sym_DASH_DASH] = ACTIONS(4480),
    [anon_sym_PLUS] = ACTIONS(4478),
    [anon_sym_DASH] = ACTIONS(4478),
    [anon_sym_STAR] = ACTIONS(4480),
    [anon_sym_SLASH] = ACTIONS(4478),
    [anon_sym_PERCENT] = ACTIONS(4480),
    [anon_sym_CARET] = ACTIONS(4480),
    [anon_sym_PIPE] = ACTIONS(4478),
    [anon_sym_AMP] = ACTIONS(4478),
    [anon_sym_LT_LT] = ACTIONS(4480),
    [anon_sym_GT_GT] = ACTIONS(4478),
    [anon_sym_GT_GT_GT] = ACTIONS(4480),
    [anon_sym_EQ_EQ] = ACTIONS(4480),
    [anon_sym_BANG_EQ] = ACTIONS(4480),
    [anon_sym_GT_EQ] = ACTIONS(4480),
    [anon_sym_LT_EQ] = ACTIONS(4480),
    [anon_sym_DOT] = ACTIONS(4478),
    [anon_sym_EQ_GT] = ACTIONS(4480),
    [anon_sym_switch] = ACTIONS(4480),
    [anon_sym_when] = ACTIONS(4480),
    [anon_sym_DOT_DOT] = ACTIONS(4480),
    [anon_sym_and] = ACTIONS(4480),
    [anon_sym_or] = ACTIONS(4480),
    [anon_sym_AMP_AMP] = ACTIONS(4480),
    [anon_sym_PIPE_PIPE] = ACTIONS(4480),
    [anon_sym_QMARK_QMARK] = ACTIONS(4480),
    [anon_sym_on] = ACTIONS(4480),
    [anon_sym_equals] = ACTIONS(4480),
    [anon_sym_by] = ACTIONS(4480),
    [anon_sym_as] = ACTIONS(4480),
    [anon_sym_is] = ACTIONS(4480),
    [anon_sym_DASH_GT] = ACTIONS(4480),
    [anon_sym_with] = ACTIONS(4480),
    [aux_sym_preproc_if_token3] = ACTIONS(4480),
    [aux_sym_preproc_else_token1] = ACTIONS(4480),
    [aux_sym_preproc_elif_token1] = ACTIONS(4480),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3977] = {
    [sym_preproc_region] = STATE(3977),
    [sym_preproc_endregion] = STATE(3977),
    [sym_preproc_line] = STATE(3977),
    [sym_preproc_pragma] = STATE(3977),
    [sym_preproc_nullable] = STATE(3977),
    [sym_preproc_error] = STATE(3977),
    [sym_preproc_warning] = STATE(3977),
    [sym_preproc_define] = STATE(3977),
    [sym_preproc_undef] = STATE(3977),
    [anon_sym_SEMI] = ACTIONS(4550),
    [anon_sym_LBRACK] = ACTIONS(4550),
    [anon_sym_COLON] = ACTIONS(4550),
    [anon_sym_COMMA] = ACTIONS(4550),
    [anon_sym_RBRACK] = ACTIONS(4550),
    [anon_sym_LPAREN] = ACTIONS(4550),
    [anon_sym_RPAREN] = ACTIONS(4550),
    [anon_sym_LBRACE] = ACTIONS(4550),
    [anon_sym_RBRACE] = ACTIONS(4550),
    [anon_sym_LT] = ACTIONS(4548),
    [anon_sym_GT] = ACTIONS(4548),
    [anon_sym_in] = ACTIONS(4550),
    [anon_sym_QMARK] = ACTIONS(4548),
    [anon_sym_BANG] = ACTIONS(4548),
    [anon_sym_PLUS_PLUS] = ACTIONS(4550),
    [anon_sym_DASH_DASH] = ACTIONS(4550),
    [anon_sym_PLUS] = ACTIONS(4548),
    [anon_sym_DASH] = ACTIONS(4548),
    [anon_sym_STAR] = ACTIONS(4550),
    [anon_sym_SLASH] = ACTIONS(4548),
    [anon_sym_PERCENT] = ACTIONS(4550),
    [anon_sym_CARET] = ACTIONS(4550),
    [anon_sym_PIPE] = ACTIONS(4548),
    [anon_sym_AMP] = ACTIONS(4548),
    [anon_sym_LT_LT] = ACTIONS(4550),
    [anon_sym_GT_GT] = ACTIONS(4548),
    [anon_sym_GT_GT_GT] = ACTIONS(4550),
    [anon_sym_EQ_EQ] = ACTIONS(4550),
    [anon_sym_BANG_EQ] = ACTIONS(4550),
    [anon_sym_GT_EQ] = ACTIONS(4550),
    [anon_sym_LT_EQ] = ACTIONS(4550),
    [anon_sym_DOT] = ACTIONS(4548),
    [anon_sym_EQ_GT] = ACTIONS(4550),
    [anon_sym_switch] = ACTIONS(4550),
    [anon_sym_when] = ACTIONS(4550),
    [anon_sym_DOT_DOT] = ACTIONS(4550),
    [anon_sym_and] = ACTIONS(4550),
    [anon_sym_or] = ACTIONS(4550),
    [anon_sym_AMP_AMP] = ACTIONS(4550),
    [anon_sym_PIPE_PIPE] = ACTIONS(4550),
    [anon_sym_QMARK_QMARK] = ACTIONS(4550),
    [anon_sym_on] = ACTIONS(4550),
    [anon_sym_equals] = ACTIONS(4550),
    [anon_sym_by] = ACTIONS(4550),
    [anon_sym_as] = ACTIONS(4550),
    [anon_sym_is] = ACTIONS(4550),
    [anon_sym_DASH_GT] = ACTIONS(4550),
    [anon_sym_with] = ACTIONS(4550),
    [aux_sym_preproc_if_token3] = ACTIONS(4550),
    [aux_sym_preproc_else_token1] = ACTIONS(4550),
    [aux_sym_preproc_elif_token1] = ACTIONS(4550),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3978] = {
    [sym_preproc_region] = STATE(3978),
    [sym_preproc_endregion] = STATE(3978),
    [sym_preproc_line] = STATE(3978),
    [sym_preproc_pragma] = STATE(3978),
    [sym_preproc_nullable] = STATE(3978),
    [sym_preproc_error] = STATE(3978),
    [sym_preproc_warning] = STATE(3978),
    [sym_preproc_define] = STATE(3978),
    [sym_preproc_undef] = STATE(3978),
    [anon_sym_SEMI] = ACTIONS(5530),
    [anon_sym_LBRACK] = ACTIONS(5530),
    [anon_sym_COLON] = ACTIONS(5530),
    [anon_sym_COMMA] = ACTIONS(5530),
    [anon_sym_RBRACK] = ACTIONS(5530),
    [anon_sym_LPAREN] = ACTIONS(5530),
    [anon_sym_RPAREN] = ACTIONS(5530),
    [anon_sym_RBRACE] = ACTIONS(5530),
    [anon_sym_LT] = ACTIONS(5532),
    [anon_sym_GT] = ACTIONS(5532),
    [anon_sym_in] = ACTIONS(5532),
    [anon_sym_QMARK] = ACTIONS(5532),
    [anon_sym_BANG] = ACTIONS(5532),
    [anon_sym_PLUS_PLUS] = ACTIONS(5530),
    [anon_sym_DASH_DASH] = ACTIONS(5530),
    [anon_sym_PLUS] = ACTIONS(5532),
    [anon_sym_DASH] = ACTIONS(5532),
    [anon_sym_STAR] = ACTIONS(5530),
    [anon_sym_SLASH] = ACTIONS(5532),
    [anon_sym_PERCENT] = ACTIONS(5530),
    [anon_sym_CARET] = ACTIONS(5530),
    [anon_sym_PIPE] = ACTIONS(5532),
    [anon_sym_AMP] = ACTIONS(5532),
    [anon_sym_LT_LT] = ACTIONS(5530),
    [anon_sym_GT_GT] = ACTIONS(5532),
    [anon_sym_GT_GT_GT] = ACTIONS(5530),
    [anon_sym_EQ_EQ] = ACTIONS(5530),
    [anon_sym_BANG_EQ] = ACTIONS(5530),
    [anon_sym_GT_EQ] = ACTIONS(5530),
    [anon_sym_LT_EQ] = ACTIONS(5530),
    [anon_sym_DOT] = ACTIONS(5532),
    [anon_sym_EQ_GT] = ACTIONS(5530),
    [anon_sym_switch] = ACTIONS(5530),
    [anon_sym_when] = ACTIONS(5530),
    [anon_sym_DOT_DOT] = ACTIONS(5530),
    [anon_sym_and] = ACTIONS(5530),
    [anon_sym_or] = ACTIONS(5530),
    [anon_sym_AMP_AMP] = ACTIONS(5530),
    [anon_sym_PIPE_PIPE] = ACTIONS(5530),
    [anon_sym_QMARK_QMARK] = ACTIONS(5530),
    [anon_sym_into] = ACTIONS(5530),
    [anon_sym_on] = ACTIONS(5530),
    [anon_sym_equals] = ACTIONS(5530),
    [anon_sym_by] = ACTIONS(5530),
    [anon_sym_as] = ACTIONS(5530),
    [anon_sym_is] = ACTIONS(5530),
    [anon_sym_DASH_GT] = ACTIONS(5530),
    [anon_sym_with] = ACTIONS(5530),
    [aux_sym_preproc_if_token3] = ACTIONS(5530),
    [aux_sym_preproc_else_token1] = ACTIONS(5530),
    [aux_sym_preproc_elif_token1] = ACTIONS(5530),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3979] = {
    [sym_preproc_region] = STATE(3979),
    [sym_preproc_endregion] = STATE(3979),
    [sym_preproc_line] = STATE(3979),
    [sym_preproc_pragma] = STATE(3979),
    [sym_preproc_nullable] = STATE(3979),
    [sym_preproc_error] = STATE(3979),
    [sym_preproc_warning] = STATE(3979),
    [sym_preproc_define] = STATE(3979),
    [sym_preproc_undef] = STATE(3979),
    [anon_sym_SEMI] = ACTIONS(4488),
    [anon_sym_LBRACK] = ACTIONS(4488),
    [anon_sym_COLON] = ACTIONS(4488),
    [anon_sym_COMMA] = ACTIONS(4488),
    [anon_sym_RBRACK] = ACTIONS(4488),
    [anon_sym_LPAREN] = ACTIONS(4488),
    [anon_sym_RPAREN] = ACTIONS(4488),
    [anon_sym_LBRACE] = ACTIONS(4488),
    [anon_sym_RBRACE] = ACTIONS(4488),
    [anon_sym_LT] = ACTIONS(4486),
    [anon_sym_GT] = ACTIONS(4486),
    [anon_sym_in] = ACTIONS(4488),
    [anon_sym_QMARK] = ACTIONS(4486),
    [anon_sym_BANG] = ACTIONS(4486),
    [anon_sym_PLUS_PLUS] = ACTIONS(4488),
    [anon_sym_DASH_DASH] = ACTIONS(4488),
    [anon_sym_PLUS] = ACTIONS(4486),
    [anon_sym_DASH] = ACTIONS(4486),
    [anon_sym_STAR] = ACTIONS(4488),
    [anon_sym_SLASH] = ACTIONS(4486),
    [anon_sym_PERCENT] = ACTIONS(4488),
    [anon_sym_CARET] = ACTIONS(4488),
    [anon_sym_PIPE] = ACTIONS(4486),
    [anon_sym_AMP] = ACTIONS(4486),
    [anon_sym_LT_LT] = ACTIONS(4488),
    [anon_sym_GT_GT] = ACTIONS(4486),
    [anon_sym_GT_GT_GT] = ACTIONS(4488),
    [anon_sym_EQ_EQ] = ACTIONS(4488),
    [anon_sym_BANG_EQ] = ACTIONS(4488),
    [anon_sym_GT_EQ] = ACTIONS(4488),
    [anon_sym_LT_EQ] = ACTIONS(4488),
    [anon_sym_DOT] = ACTIONS(4486),
    [anon_sym_EQ_GT] = ACTIONS(4488),
    [anon_sym_switch] = ACTIONS(4488),
    [anon_sym_when] = ACTIONS(4488),
    [anon_sym_DOT_DOT] = ACTIONS(4488),
    [anon_sym_and] = ACTIONS(4488),
    [anon_sym_or] = ACTIONS(4488),
    [anon_sym_AMP_AMP] = ACTIONS(4488),
    [anon_sym_PIPE_PIPE] = ACTIONS(4488),
    [anon_sym_QMARK_QMARK] = ACTIONS(4488),
    [anon_sym_on] = ACTIONS(4488),
    [anon_sym_equals] = ACTIONS(4488),
    [anon_sym_by] = ACTIONS(4488),
    [anon_sym_as] = ACTIONS(4488),
    [anon_sym_is] = ACTIONS(4488),
    [anon_sym_DASH_GT] = ACTIONS(4488),
    [anon_sym_with] = ACTIONS(4488),
    [aux_sym_preproc_if_token3] = ACTIONS(4488),
    [aux_sym_preproc_else_token1] = ACTIONS(4488),
    [aux_sym_preproc_elif_token1] = ACTIONS(4488),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3980] = {
    [sym_preproc_region] = STATE(3980),
    [sym_preproc_endregion] = STATE(3980),
    [sym_preproc_line] = STATE(3980),
    [sym_preproc_pragma] = STATE(3980),
    [sym_preproc_nullable] = STATE(3980),
    [sym_preproc_error] = STATE(3980),
    [sym_preproc_warning] = STATE(3980),
    [sym_preproc_define] = STATE(3980),
    [sym_preproc_undef] = STATE(3980),
    [anon_sym_SEMI] = ACTIONS(5401),
    [anon_sym_LBRACK] = ACTIONS(5401),
    [anon_sym_COLON] = ACTIONS(5401),
    [anon_sym_COMMA] = ACTIONS(5401),
    [anon_sym_RBRACK] = ACTIONS(5401),
    [anon_sym_LPAREN] = ACTIONS(5401),
    [anon_sym_RPAREN] = ACTIONS(5401),
    [anon_sym_RBRACE] = ACTIONS(5401),
    [anon_sym_LT] = ACTIONS(5403),
    [anon_sym_GT] = ACTIONS(5403),
    [anon_sym_in] = ACTIONS(5403),
    [anon_sym_QMARK] = ACTIONS(5403),
    [anon_sym_BANG] = ACTIONS(5403),
    [anon_sym_PLUS_PLUS] = ACTIONS(5401),
    [anon_sym_DASH_DASH] = ACTIONS(5401),
    [anon_sym_PLUS] = ACTIONS(5403),
    [anon_sym_DASH] = ACTIONS(5403),
    [anon_sym_STAR] = ACTIONS(5401),
    [anon_sym_SLASH] = ACTIONS(5403),
    [anon_sym_PERCENT] = ACTIONS(5401),
    [anon_sym_CARET] = ACTIONS(5401),
    [anon_sym_PIPE] = ACTIONS(5403),
    [anon_sym_AMP] = ACTIONS(5403),
    [anon_sym_LT_LT] = ACTIONS(5401),
    [anon_sym_GT_GT] = ACTIONS(5403),
    [anon_sym_GT_GT_GT] = ACTIONS(5401),
    [anon_sym_EQ_EQ] = ACTIONS(5401),
    [anon_sym_BANG_EQ] = ACTIONS(5401),
    [anon_sym_GT_EQ] = ACTIONS(5401),
    [anon_sym_LT_EQ] = ACTIONS(5401),
    [anon_sym_DOT] = ACTIONS(5403),
    [anon_sym_EQ_GT] = ACTIONS(5401),
    [anon_sym_switch] = ACTIONS(5401),
    [anon_sym_when] = ACTIONS(5401),
    [anon_sym_DOT_DOT] = ACTIONS(5401),
    [anon_sym_and] = ACTIONS(5401),
    [anon_sym_or] = ACTIONS(5401),
    [anon_sym_AMP_AMP] = ACTIONS(5401),
    [anon_sym_PIPE_PIPE] = ACTIONS(5401),
    [anon_sym_QMARK_QMARK] = ACTIONS(5401),
    [anon_sym_into] = ACTIONS(5401),
    [anon_sym_on] = ACTIONS(5401),
    [anon_sym_equals] = ACTIONS(5401),
    [anon_sym_by] = ACTIONS(5401),
    [anon_sym_as] = ACTIONS(5401),
    [anon_sym_is] = ACTIONS(5401),
    [anon_sym_DASH_GT] = ACTIONS(5401),
    [anon_sym_with] = ACTIONS(5401),
    [aux_sym_preproc_if_token3] = ACTIONS(5401),
    [aux_sym_preproc_else_token1] = ACTIONS(5401),
    [aux_sym_preproc_elif_token1] = ACTIONS(5401),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3981] = {
    [sym_preproc_region] = STATE(3981),
    [sym_preproc_endregion] = STATE(3981),
    [sym_preproc_line] = STATE(3981),
    [sym_preproc_pragma] = STATE(3981),
    [sym_preproc_nullable] = STATE(3981),
    [sym_preproc_error] = STATE(3981),
    [sym_preproc_warning] = STATE(3981),
    [sym_preproc_define] = STATE(3981),
    [sym_preproc_undef] = STATE(3981),
    [anon_sym_SEMI] = ACTIONS(5865),
    [anon_sym_LBRACK] = ACTIONS(5865),
    [anon_sym_COLON] = ACTIONS(5865),
    [anon_sym_COMMA] = ACTIONS(5865),
    [anon_sym_RBRACK] = ACTIONS(5865),
    [anon_sym_LPAREN] = ACTIONS(5865),
    [anon_sym_RPAREN] = ACTIONS(5865),
    [anon_sym_RBRACE] = ACTIONS(5865),
    [anon_sym_LT] = ACTIONS(5867),
    [anon_sym_GT] = ACTIONS(5867),
    [anon_sym_in] = ACTIONS(5867),
    [anon_sym_QMARK] = ACTIONS(5867),
    [anon_sym_BANG] = ACTIONS(5867),
    [anon_sym_PLUS_PLUS] = ACTIONS(5865),
    [anon_sym_DASH_DASH] = ACTIONS(5865),
    [anon_sym_PLUS] = ACTIONS(5867),
    [anon_sym_DASH] = ACTIONS(5867),
    [anon_sym_STAR] = ACTIONS(5865),
    [anon_sym_SLASH] = ACTIONS(5867),
    [anon_sym_PERCENT] = ACTIONS(5865),
    [anon_sym_CARET] = ACTIONS(5865),
    [anon_sym_PIPE] = ACTIONS(5867),
    [anon_sym_AMP] = ACTIONS(5867),
    [anon_sym_LT_LT] = ACTIONS(5865),
    [anon_sym_GT_GT] = ACTIONS(5867),
    [anon_sym_GT_GT_GT] = ACTIONS(5865),
    [anon_sym_EQ_EQ] = ACTIONS(5865),
    [anon_sym_BANG_EQ] = ACTIONS(5865),
    [anon_sym_GT_EQ] = ACTIONS(5865),
    [anon_sym_LT_EQ] = ACTIONS(5865),
    [anon_sym_DOT] = ACTIONS(5867),
    [anon_sym_EQ_GT] = ACTIONS(5865),
    [anon_sym_switch] = ACTIONS(5865),
    [anon_sym_when] = ACTIONS(5865),
    [anon_sym_DOT_DOT] = ACTIONS(5865),
    [anon_sym_and] = ACTIONS(5865),
    [anon_sym_or] = ACTIONS(5865),
    [anon_sym_AMP_AMP] = ACTIONS(5865),
    [anon_sym_PIPE_PIPE] = ACTIONS(5865),
    [anon_sym_QMARK_QMARK] = ACTIONS(5865),
    [anon_sym_into] = ACTIONS(5865),
    [anon_sym_on] = ACTIONS(5865),
    [anon_sym_equals] = ACTIONS(5865),
    [anon_sym_by] = ACTIONS(5865),
    [anon_sym_as] = ACTIONS(5865),
    [anon_sym_is] = ACTIONS(5865),
    [anon_sym_DASH_GT] = ACTIONS(5865),
    [anon_sym_with] = ACTIONS(5865),
    [aux_sym_preproc_if_token3] = ACTIONS(5865),
    [aux_sym_preproc_else_token1] = ACTIONS(5865),
    [aux_sym_preproc_elif_token1] = ACTIONS(5865),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3982] = {
    [sym_preproc_region] = STATE(3982),
    [sym_preproc_endregion] = STATE(3982),
    [sym_preproc_line] = STATE(3982),
    [sym_preproc_pragma] = STATE(3982),
    [sym_preproc_nullable] = STATE(3982),
    [sym_preproc_error] = STATE(3982),
    [sym_preproc_warning] = STATE(3982),
    [sym_preproc_define] = STATE(3982),
    [sym_preproc_undef] = STATE(3982),
    [anon_sym_SEMI] = ACTIONS(5869),
    [anon_sym_LBRACK] = ACTIONS(5869),
    [anon_sym_COLON] = ACTIONS(5869),
    [anon_sym_COMMA] = ACTIONS(5869),
    [anon_sym_RBRACK] = ACTIONS(5869),
    [anon_sym_LPAREN] = ACTIONS(5869),
    [anon_sym_RPAREN] = ACTIONS(5869),
    [anon_sym_RBRACE] = ACTIONS(5869),
    [anon_sym_LT] = ACTIONS(5871),
    [anon_sym_GT] = ACTIONS(5871),
    [anon_sym_in] = ACTIONS(5871),
    [anon_sym_QMARK] = ACTIONS(5871),
    [anon_sym_BANG] = ACTIONS(5871),
    [anon_sym_PLUS_PLUS] = ACTIONS(5869),
    [anon_sym_DASH_DASH] = ACTIONS(5869),
    [anon_sym_PLUS] = ACTIONS(5871),
    [anon_sym_DASH] = ACTIONS(5871),
    [anon_sym_STAR] = ACTIONS(5869),
    [anon_sym_SLASH] = ACTIONS(5871),
    [anon_sym_PERCENT] = ACTIONS(5869),
    [anon_sym_CARET] = ACTIONS(5869),
    [anon_sym_PIPE] = ACTIONS(5871),
    [anon_sym_AMP] = ACTIONS(5871),
    [anon_sym_LT_LT] = ACTIONS(5869),
    [anon_sym_GT_GT] = ACTIONS(5871),
    [anon_sym_GT_GT_GT] = ACTIONS(5869),
    [anon_sym_EQ_EQ] = ACTIONS(5869),
    [anon_sym_BANG_EQ] = ACTIONS(5869),
    [anon_sym_GT_EQ] = ACTIONS(5869),
    [anon_sym_LT_EQ] = ACTIONS(5869),
    [anon_sym_DOT] = ACTIONS(5871),
    [anon_sym_EQ_GT] = ACTIONS(5869),
    [anon_sym_switch] = ACTIONS(5869),
    [anon_sym_when] = ACTIONS(5869),
    [anon_sym_DOT_DOT] = ACTIONS(5869),
    [anon_sym_and] = ACTIONS(5869),
    [anon_sym_or] = ACTIONS(5869),
    [anon_sym_AMP_AMP] = ACTIONS(5869),
    [anon_sym_PIPE_PIPE] = ACTIONS(5869),
    [anon_sym_QMARK_QMARK] = ACTIONS(5869),
    [anon_sym_into] = ACTIONS(5869),
    [anon_sym_on] = ACTIONS(5869),
    [anon_sym_equals] = ACTIONS(5869),
    [anon_sym_by] = ACTIONS(5869),
    [anon_sym_as] = ACTIONS(5869),
    [anon_sym_is] = ACTIONS(5869),
    [anon_sym_DASH_GT] = ACTIONS(5869),
    [anon_sym_with] = ACTIONS(5869),
    [aux_sym_preproc_if_token3] = ACTIONS(5869),
    [aux_sym_preproc_else_token1] = ACTIONS(5869),
    [aux_sym_preproc_elif_token1] = ACTIONS(5869),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3983] = {
    [sym_preproc_region] = STATE(3983),
    [sym_preproc_endregion] = STATE(3983),
    [sym_preproc_line] = STATE(3983),
    [sym_preproc_pragma] = STATE(3983),
    [sym_preproc_nullable] = STATE(3983),
    [sym_preproc_error] = STATE(3983),
    [sym_preproc_warning] = STATE(3983),
    [sym_preproc_define] = STATE(3983),
    [sym_preproc_undef] = STATE(3983),
    [anon_sym_SEMI] = ACTIONS(4310),
    [anon_sym_LBRACK] = ACTIONS(4310),
    [anon_sym_COLON] = ACTIONS(4310),
    [anon_sym_COMMA] = ACTIONS(4310),
    [anon_sym_RBRACK] = ACTIONS(4310),
    [anon_sym_LPAREN] = ACTIONS(4310),
    [anon_sym_RPAREN] = ACTIONS(4310),
    [anon_sym_RBRACE] = ACTIONS(4310),
    [anon_sym_LT] = ACTIONS(5873),
    [anon_sym_GT] = ACTIONS(5873),
    [anon_sym_in] = ACTIONS(5873),
    [anon_sym_QMARK] = ACTIONS(5873),
    [anon_sym_BANG] = ACTIONS(5873),
    [anon_sym_PLUS_PLUS] = ACTIONS(4310),
    [anon_sym_DASH_DASH] = ACTIONS(4310),
    [anon_sym_PLUS] = ACTIONS(5873),
    [anon_sym_DASH] = ACTIONS(5873),
    [anon_sym_STAR] = ACTIONS(4310),
    [anon_sym_SLASH] = ACTIONS(5873),
    [anon_sym_PERCENT] = ACTIONS(4310),
    [anon_sym_CARET] = ACTIONS(4310),
    [anon_sym_PIPE] = ACTIONS(5873),
    [anon_sym_AMP] = ACTIONS(5873),
    [anon_sym_LT_LT] = ACTIONS(4310),
    [anon_sym_GT_GT] = ACTIONS(5873),
    [anon_sym_GT_GT_GT] = ACTIONS(4310),
    [anon_sym_EQ_EQ] = ACTIONS(4310),
    [anon_sym_BANG_EQ] = ACTIONS(4310),
    [anon_sym_GT_EQ] = ACTIONS(4310),
    [anon_sym_LT_EQ] = ACTIONS(4310),
    [anon_sym_DOT] = ACTIONS(5873),
    [anon_sym_EQ_GT] = ACTIONS(4310),
    [anon_sym_switch] = ACTIONS(4310),
    [anon_sym_when] = ACTIONS(4310),
    [anon_sym_DOT_DOT] = ACTIONS(4310),
    [anon_sym_and] = ACTIONS(4310),
    [anon_sym_or] = ACTIONS(4310),
    [anon_sym_AMP_AMP] = ACTIONS(4310),
    [anon_sym_PIPE_PIPE] = ACTIONS(4310),
    [anon_sym_QMARK_QMARK] = ACTIONS(4310),
    [anon_sym_into] = ACTIONS(4310),
    [anon_sym_on] = ACTIONS(4310),
    [anon_sym_equals] = ACTIONS(4310),
    [anon_sym_by] = ACTIONS(4310),
    [anon_sym_as] = ACTIONS(4310),
    [anon_sym_is] = ACTIONS(4310),
    [anon_sym_DASH_GT] = ACTIONS(4310),
    [anon_sym_with] = ACTIONS(4310),
    [aux_sym_preproc_if_token3] = ACTIONS(4310),
    [aux_sym_preproc_else_token1] = ACTIONS(4310),
    [aux_sym_preproc_elif_token1] = ACTIONS(4310),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3984] = {
    [sym_preproc_region] = STATE(3984),
    [sym_preproc_endregion] = STATE(3984),
    [sym_preproc_line] = STATE(3984),
    [sym_preproc_pragma] = STATE(3984),
    [sym_preproc_nullable] = STATE(3984),
    [sym_preproc_error] = STATE(3984),
    [sym_preproc_warning] = STATE(3984),
    [sym_preproc_define] = STATE(3984),
    [sym_preproc_undef] = STATE(3984),
    [anon_sym_SEMI] = ACTIONS(4585),
    [anon_sym_LBRACK] = ACTIONS(4585),
    [anon_sym_COLON] = ACTIONS(4585),
    [anon_sym_COMMA] = ACTIONS(4585),
    [anon_sym_RBRACK] = ACTIONS(4585),
    [anon_sym_LPAREN] = ACTIONS(4585),
    [anon_sym_RPAREN] = ACTIONS(4585),
    [anon_sym_LBRACE] = ACTIONS(4585),
    [anon_sym_RBRACE] = ACTIONS(4585),
    [anon_sym_LT] = ACTIONS(4583),
    [anon_sym_GT] = ACTIONS(4583),
    [anon_sym_in] = ACTIONS(4585),
    [anon_sym_QMARK] = ACTIONS(4583),
    [anon_sym_BANG] = ACTIONS(4583),
    [anon_sym_PLUS_PLUS] = ACTIONS(4585),
    [anon_sym_DASH_DASH] = ACTIONS(4585),
    [anon_sym_PLUS] = ACTIONS(4583),
    [anon_sym_DASH] = ACTIONS(4583),
    [anon_sym_STAR] = ACTIONS(4585),
    [anon_sym_SLASH] = ACTIONS(4583),
    [anon_sym_PERCENT] = ACTIONS(4585),
    [anon_sym_CARET] = ACTIONS(4585),
    [anon_sym_PIPE] = ACTIONS(4583),
    [anon_sym_AMP] = ACTIONS(4583),
    [anon_sym_LT_LT] = ACTIONS(4585),
    [anon_sym_GT_GT] = ACTIONS(4583),
    [anon_sym_GT_GT_GT] = ACTIONS(4585),
    [anon_sym_EQ_EQ] = ACTIONS(4585),
    [anon_sym_BANG_EQ] = ACTIONS(4585),
    [anon_sym_GT_EQ] = ACTIONS(4585),
    [anon_sym_LT_EQ] = ACTIONS(4585),
    [anon_sym_DOT] = ACTIONS(4583),
    [anon_sym_EQ_GT] = ACTIONS(4585),
    [anon_sym_switch] = ACTIONS(4585),
    [anon_sym_when] = ACTIONS(4585),
    [anon_sym_DOT_DOT] = ACTIONS(4585),
    [anon_sym_and] = ACTIONS(4585),
    [anon_sym_or] = ACTIONS(4585),
    [anon_sym_AMP_AMP] = ACTIONS(4585),
    [anon_sym_PIPE_PIPE] = ACTIONS(4585),
    [anon_sym_QMARK_QMARK] = ACTIONS(4585),
    [anon_sym_on] = ACTIONS(4585),
    [anon_sym_equals] = ACTIONS(4585),
    [anon_sym_by] = ACTIONS(4585),
    [anon_sym_as] = ACTIONS(4585),
    [anon_sym_is] = ACTIONS(4585),
    [anon_sym_DASH_GT] = ACTIONS(4585),
    [anon_sym_with] = ACTIONS(4585),
    [aux_sym_preproc_if_token3] = ACTIONS(4585),
    [aux_sym_preproc_else_token1] = ACTIONS(4585),
    [aux_sym_preproc_elif_token1] = ACTIONS(4585),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3985] = {
    [sym_preproc_region] = STATE(3985),
    [sym_preproc_endregion] = STATE(3985),
    [sym_preproc_line] = STATE(3985),
    [sym_preproc_pragma] = STATE(3985),
    [sym_preproc_nullable] = STATE(3985),
    [sym_preproc_error] = STATE(3985),
    [sym_preproc_warning] = STATE(3985),
    [sym_preproc_define] = STATE(3985),
    [sym_preproc_undef] = STATE(3985),
    [anon_sym_SEMI] = ACTIONS(5408),
    [anon_sym_LBRACK] = ACTIONS(5408),
    [anon_sym_COLON] = ACTIONS(5408),
    [anon_sym_COMMA] = ACTIONS(5408),
    [anon_sym_RBRACK] = ACTIONS(5408),
    [anon_sym_LPAREN] = ACTIONS(5408),
    [anon_sym_RPAREN] = ACTIONS(5408),
    [anon_sym_RBRACE] = ACTIONS(5408),
    [anon_sym_LT] = ACTIONS(5410),
    [anon_sym_GT] = ACTIONS(5410),
    [anon_sym_in] = ACTIONS(5410),
    [anon_sym_QMARK] = ACTIONS(5410),
    [anon_sym_BANG] = ACTIONS(5410),
    [anon_sym_PLUS_PLUS] = ACTIONS(5408),
    [anon_sym_DASH_DASH] = ACTIONS(5408),
    [anon_sym_PLUS] = ACTIONS(5410),
    [anon_sym_DASH] = ACTIONS(5410),
    [anon_sym_STAR] = ACTIONS(5408),
    [anon_sym_SLASH] = ACTIONS(5410),
    [anon_sym_PERCENT] = ACTIONS(5408),
    [anon_sym_CARET] = ACTIONS(5408),
    [anon_sym_PIPE] = ACTIONS(5410),
    [anon_sym_AMP] = ACTIONS(5410),
    [anon_sym_LT_LT] = ACTIONS(5408),
    [anon_sym_GT_GT] = ACTIONS(5410),
    [anon_sym_GT_GT_GT] = ACTIONS(5408),
    [anon_sym_EQ_EQ] = ACTIONS(5408),
    [anon_sym_BANG_EQ] = ACTIONS(5408),
    [anon_sym_GT_EQ] = ACTIONS(5408),
    [anon_sym_LT_EQ] = ACTIONS(5408),
    [anon_sym_DOT] = ACTIONS(5410),
    [anon_sym_EQ_GT] = ACTIONS(5408),
    [anon_sym_switch] = ACTIONS(5408),
    [anon_sym_when] = ACTIONS(5408),
    [anon_sym_DOT_DOT] = ACTIONS(5408),
    [anon_sym_and] = ACTIONS(5408),
    [anon_sym_or] = ACTIONS(5408),
    [anon_sym_AMP_AMP] = ACTIONS(5408),
    [anon_sym_PIPE_PIPE] = ACTIONS(5408),
    [anon_sym_QMARK_QMARK] = ACTIONS(5408),
    [anon_sym_into] = ACTIONS(5408),
    [anon_sym_on] = ACTIONS(5408),
    [anon_sym_equals] = ACTIONS(5408),
    [anon_sym_by] = ACTIONS(5408),
    [anon_sym_as] = ACTIONS(5408),
    [anon_sym_is] = ACTIONS(5408),
    [anon_sym_DASH_GT] = ACTIONS(5408),
    [anon_sym_with] = ACTIONS(5408),
    [aux_sym_preproc_if_token3] = ACTIONS(5408),
    [aux_sym_preproc_else_token1] = ACTIONS(5408),
    [aux_sym_preproc_elif_token1] = ACTIONS(5408),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3986] = {
    [sym_preproc_region] = STATE(3986),
    [sym_preproc_endregion] = STATE(3986),
    [sym_preproc_line] = STATE(3986),
    [sym_preproc_pragma] = STATE(3986),
    [sym_preproc_nullable] = STATE(3986),
    [sym_preproc_error] = STATE(3986),
    [sym_preproc_warning] = STATE(3986),
    [sym_preproc_define] = STATE(3986),
    [sym_preproc_undef] = STATE(3986),
    [anon_sym_SEMI] = ACTIONS(5875),
    [anon_sym_LBRACK] = ACTIONS(5875),
    [anon_sym_COLON] = ACTIONS(5875),
    [anon_sym_COMMA] = ACTIONS(5875),
    [anon_sym_RBRACK] = ACTIONS(5875),
    [anon_sym_LPAREN] = ACTIONS(5875),
    [anon_sym_RPAREN] = ACTIONS(5875),
    [anon_sym_RBRACE] = ACTIONS(5875),
    [anon_sym_LT] = ACTIONS(5877),
    [anon_sym_GT] = ACTIONS(5877),
    [anon_sym_in] = ACTIONS(5877),
    [anon_sym_QMARK] = ACTIONS(5877),
    [anon_sym_BANG] = ACTIONS(5877),
    [anon_sym_PLUS_PLUS] = ACTIONS(5875),
    [anon_sym_DASH_DASH] = ACTIONS(5875),
    [anon_sym_PLUS] = ACTIONS(5877),
    [anon_sym_DASH] = ACTIONS(5877),
    [anon_sym_STAR] = ACTIONS(5875),
    [anon_sym_SLASH] = ACTIONS(5877),
    [anon_sym_PERCENT] = ACTIONS(5875),
    [anon_sym_CARET] = ACTIONS(5875),
    [anon_sym_PIPE] = ACTIONS(5877),
    [anon_sym_AMP] = ACTIONS(5877),
    [anon_sym_LT_LT] = ACTIONS(5875),
    [anon_sym_GT_GT] = ACTIONS(5877),
    [anon_sym_GT_GT_GT] = ACTIONS(5875),
    [anon_sym_EQ_EQ] = ACTIONS(5875),
    [anon_sym_BANG_EQ] = ACTIONS(5875),
    [anon_sym_GT_EQ] = ACTIONS(5875),
    [anon_sym_LT_EQ] = ACTIONS(5875),
    [anon_sym_DOT] = ACTIONS(5877),
    [anon_sym_EQ_GT] = ACTIONS(5875),
    [anon_sym_switch] = ACTIONS(5875),
    [anon_sym_when] = ACTIONS(5875),
    [anon_sym_DOT_DOT] = ACTIONS(5875),
    [anon_sym_and] = ACTIONS(5875),
    [anon_sym_or] = ACTIONS(5875),
    [anon_sym_AMP_AMP] = ACTIONS(5875),
    [anon_sym_PIPE_PIPE] = ACTIONS(5875),
    [anon_sym_QMARK_QMARK] = ACTIONS(5875),
    [anon_sym_into] = ACTIONS(5875),
    [anon_sym_on] = ACTIONS(5875),
    [anon_sym_equals] = ACTIONS(5875),
    [anon_sym_by] = ACTIONS(5875),
    [anon_sym_as] = ACTIONS(5875),
    [anon_sym_is] = ACTIONS(5875),
    [anon_sym_DASH_GT] = ACTIONS(5875),
    [anon_sym_with] = ACTIONS(5875),
    [aux_sym_preproc_if_token3] = ACTIONS(5875),
    [aux_sym_preproc_else_token1] = ACTIONS(5875),
    [aux_sym_preproc_elif_token1] = ACTIONS(5875),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3987] = {
    [sym_preproc_region] = STATE(3987),
    [sym_preproc_endregion] = STATE(3987),
    [sym_preproc_line] = STATE(3987),
    [sym_preproc_pragma] = STATE(3987),
    [sym_preproc_nullable] = STATE(3987),
    [sym_preproc_error] = STATE(3987),
    [sym_preproc_warning] = STATE(3987),
    [sym_preproc_define] = STATE(3987),
    [sym_preproc_undef] = STATE(3987),
    [anon_sym_SEMI] = ACTIONS(5879),
    [anon_sym_LBRACK] = ACTIONS(5879),
    [anon_sym_COLON] = ACTIONS(5879),
    [anon_sym_COMMA] = ACTIONS(5879),
    [anon_sym_RBRACK] = ACTIONS(5879),
    [anon_sym_LPAREN] = ACTIONS(5879),
    [anon_sym_RPAREN] = ACTIONS(5879),
    [anon_sym_RBRACE] = ACTIONS(5879),
    [anon_sym_LT] = ACTIONS(5881),
    [anon_sym_GT] = ACTIONS(5881),
    [anon_sym_in] = ACTIONS(5881),
    [anon_sym_QMARK] = ACTIONS(5881),
    [anon_sym_BANG] = ACTIONS(5881),
    [anon_sym_PLUS_PLUS] = ACTIONS(5879),
    [anon_sym_DASH_DASH] = ACTIONS(5879),
    [anon_sym_PLUS] = ACTIONS(5881),
    [anon_sym_DASH] = ACTIONS(5881),
    [anon_sym_STAR] = ACTIONS(5879),
    [anon_sym_SLASH] = ACTIONS(5881),
    [anon_sym_PERCENT] = ACTIONS(5879),
    [anon_sym_CARET] = ACTIONS(5879),
    [anon_sym_PIPE] = ACTIONS(5881),
    [anon_sym_AMP] = ACTIONS(5881),
    [anon_sym_LT_LT] = ACTIONS(5879),
    [anon_sym_GT_GT] = ACTIONS(5881),
    [anon_sym_GT_GT_GT] = ACTIONS(5879),
    [anon_sym_EQ_EQ] = ACTIONS(5879),
    [anon_sym_BANG_EQ] = ACTIONS(5879),
    [anon_sym_GT_EQ] = ACTIONS(5879),
    [anon_sym_LT_EQ] = ACTIONS(5879),
    [anon_sym_DOT] = ACTIONS(5881),
    [anon_sym_EQ_GT] = ACTIONS(5879),
    [anon_sym_switch] = ACTIONS(5879),
    [anon_sym_when] = ACTIONS(5879),
    [anon_sym_DOT_DOT] = ACTIONS(5879),
    [anon_sym_and] = ACTIONS(5879),
    [anon_sym_or] = ACTIONS(5879),
    [anon_sym_AMP_AMP] = ACTIONS(5879),
    [anon_sym_PIPE_PIPE] = ACTIONS(5879),
    [anon_sym_QMARK_QMARK] = ACTIONS(5879),
    [anon_sym_into] = ACTIONS(5879),
    [anon_sym_on] = ACTIONS(5879),
    [anon_sym_equals] = ACTIONS(5879),
    [anon_sym_by] = ACTIONS(5879),
    [anon_sym_as] = ACTIONS(5879),
    [anon_sym_is] = ACTIONS(5879),
    [anon_sym_DASH_GT] = ACTIONS(5879),
    [anon_sym_with] = ACTIONS(5879),
    [aux_sym_preproc_if_token3] = ACTIONS(5879),
    [aux_sym_preproc_else_token1] = ACTIONS(5879),
    [aux_sym_preproc_elif_token1] = ACTIONS(5879),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3988] = {
    [sym_preproc_region] = STATE(3988),
    [sym_preproc_endregion] = STATE(3988),
    [sym_preproc_line] = STATE(3988),
    [sym_preproc_pragma] = STATE(3988),
    [sym_preproc_nullable] = STATE(3988),
    [sym_preproc_error] = STATE(3988),
    [sym_preproc_warning] = STATE(3988),
    [sym_preproc_define] = STATE(3988),
    [sym_preproc_undef] = STATE(3988),
    [sym__identifier_token] = ACTIONS(4042),
    [anon_sym_extern] = ACTIONS(4042),
    [anon_sym_alias] = ACTIONS(4042),
    [anon_sym_global] = ACTIONS(4042),
    [anon_sym_unsafe] = ACTIONS(4042),
    [anon_sym_static] = ACTIONS(4042),
    [anon_sym_LPAREN] = ACTIONS(5474),
    [anon_sym_class] = ACTIONS(4042),
    [anon_sym_ref] = ACTIONS(4042),
    [anon_sym_struct] = ACTIONS(4042),
    [anon_sym_enum] = ACTIONS(4042),
    [anon_sym_interface] = ACTIONS(4042),
    [anon_sym_delegate] = ACTIONS(4042),
    [anon_sym_record] = ACTIONS(4042),
    [anon_sym_abstract] = ACTIONS(4042),
    [anon_sym_async] = ACTIONS(4042),
    [anon_sym_const] = ACTIONS(4042),
    [anon_sym_file] = ACTIONS(4042),
    [anon_sym_fixed] = ACTIONS(4042),
    [anon_sym_internal] = ACTIONS(4042),
    [anon_sym_new] = ACTIONS(4042),
    [anon_sym_override] = ACTIONS(4042),
    [anon_sym_partial] = ACTIONS(4042),
    [anon_sym_private] = ACTIONS(4042),
    [anon_sym_protected] = ACTIONS(4042),
    [anon_sym_public] = ACTIONS(4042),
    [anon_sym_readonly] = ACTIONS(4042),
    [anon_sym_required] = ACTIONS(4042),
    [anon_sym_sealed] = ACTIONS(4042),
    [anon_sym_virtual] = ACTIONS(4042),
    [anon_sym_volatile] = ACTIONS(4042),
    [anon_sym_where] = ACTIONS(4042),
    [anon_sym_notnull] = ACTIONS(4042),
    [anon_sym_unmanaged] = ACTIONS(4042),
    [anon_sym_scoped] = ACTIONS(4042),
    [anon_sym_var] = ACTIONS(4042),
    [sym_predefined_type] = ACTIONS(4042),
    [anon_sym_yield] = ACTIONS(4042),
    [anon_sym_when] = ACTIONS(4042),
    [anon_sym_from] = ACTIONS(4042),
    [anon_sym_into] = ACTIONS(4042),
    [anon_sym_join] = ACTIONS(4042),
    [anon_sym_on] = ACTIONS(4042),
    [anon_sym_equals] = ACTIONS(4042),
    [anon_sym_let] = ACTIONS(4042),
    [anon_sym_orderby] = ACTIONS(4042),
    [anon_sym_ascending] = ACTIONS(4042),
    [anon_sym_descending] = ACTIONS(4042),
    [anon_sym_group] = ACTIONS(4042),
    [anon_sym_by] = ACTIONS(4042),
    [anon_sym_select] = ACTIONS(4042),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3989] = {
    [sym_preproc_region] = STATE(3989),
    [sym_preproc_endregion] = STATE(3989),
    [sym_preproc_line] = STATE(3989),
    [sym_preproc_pragma] = STATE(3989),
    [sym_preproc_nullable] = STATE(3989),
    [sym_preproc_error] = STATE(3989),
    [sym_preproc_warning] = STATE(3989),
    [sym_preproc_define] = STATE(3989),
    [sym_preproc_undef] = STATE(3989),
    [anon_sym_SEMI] = ACTIONS(4806),
    [anon_sym_LBRACK] = ACTIONS(5883),
    [anon_sym_COLON] = ACTIONS(4806),
    [anon_sym_COMMA] = ACTIONS(4806),
    [anon_sym_RBRACK] = ACTIONS(4806),
    [anon_sym_LPAREN] = ACTIONS(5883),
    [anon_sym_RPAREN] = ACTIONS(4806),
    [anon_sym_RBRACE] = ACTIONS(4806),
    [anon_sym_LT] = ACTIONS(5886),
    [anon_sym_GT] = ACTIONS(5886),
    [anon_sym_in] = ACTIONS(4814),
    [anon_sym_QMARK] = ACTIONS(5886),
    [anon_sym_BANG] = ACTIONS(5886),
    [anon_sym_PLUS_PLUS] = ACTIONS(5883),
    [anon_sym_DASH_DASH] = ACTIONS(5883),
    [anon_sym_PLUS] = ACTIONS(5886),
    [anon_sym_DASH] = ACTIONS(5886),
    [anon_sym_STAR] = ACTIONS(5883),
    [anon_sym_SLASH] = ACTIONS(5886),
    [anon_sym_PERCENT] = ACTIONS(5883),
    [anon_sym_CARET] = ACTIONS(5883),
    [anon_sym_PIPE] = ACTIONS(5886),
    [anon_sym_AMP] = ACTIONS(5886),
    [anon_sym_LT_LT] = ACTIONS(5883),
    [anon_sym_GT_GT] = ACTIONS(5886),
    [anon_sym_GT_GT_GT] = ACTIONS(5883),
    [anon_sym_EQ_EQ] = ACTIONS(5883),
    [anon_sym_BANG_EQ] = ACTIONS(5883),
    [anon_sym_GT_EQ] = ACTIONS(5883),
    [anon_sym_LT_EQ] = ACTIONS(5883),
    [anon_sym_DOT] = ACTIONS(5886),
    [anon_sym_EQ_GT] = ACTIONS(4806),
    [anon_sym_switch] = ACTIONS(5883),
    [anon_sym_when] = ACTIONS(4806),
    [anon_sym_DOT_DOT] = ACTIONS(5883),
    [anon_sym_and] = ACTIONS(4806),
    [anon_sym_or] = ACTIONS(4806),
    [anon_sym_AMP_AMP] = ACTIONS(5883),
    [anon_sym_PIPE_PIPE] = ACTIONS(5883),
    [anon_sym_QMARK_QMARK] = ACTIONS(5883),
    [anon_sym_into] = ACTIONS(4806),
    [anon_sym_on] = ACTIONS(4806),
    [anon_sym_equals] = ACTIONS(4806),
    [anon_sym_by] = ACTIONS(4806),
    [anon_sym_as] = ACTIONS(5883),
    [anon_sym_is] = ACTIONS(5883),
    [anon_sym_DASH_GT] = ACTIONS(5883),
    [anon_sym_with] = ACTIONS(5883),
    [aux_sym_preproc_if_token3] = ACTIONS(4806),
    [aux_sym_preproc_else_token1] = ACTIONS(4806),
    [aux_sym_preproc_elif_token1] = ACTIONS(4806),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3990] = {
    [sym_preproc_region] = STATE(3990),
    [sym_preproc_endregion] = STATE(3990),
    [sym_preproc_line] = STATE(3990),
    [sym_preproc_pragma] = STATE(3990),
    [sym_preproc_nullable] = STATE(3990),
    [sym_preproc_error] = STATE(3990),
    [sym_preproc_warning] = STATE(3990),
    [sym_preproc_define] = STATE(3990),
    [sym_preproc_undef] = STATE(3990),
    [anon_sym_SEMI] = ACTIONS(4806),
    [anon_sym_LBRACK] = ACTIONS(5889),
    [anon_sym_COLON] = ACTIONS(4806),
    [anon_sym_COMMA] = ACTIONS(4806),
    [anon_sym_RBRACK] = ACTIONS(4806),
    [anon_sym_LPAREN] = ACTIONS(5889),
    [anon_sym_RPAREN] = ACTIONS(4806),
    [anon_sym_RBRACE] = ACTIONS(4806),
    [anon_sym_LT] = ACTIONS(5892),
    [anon_sym_GT] = ACTIONS(5892),
    [anon_sym_in] = ACTIONS(4814),
    [anon_sym_QMARK] = ACTIONS(5892),
    [anon_sym_BANG] = ACTIONS(5892),
    [anon_sym_PLUS_PLUS] = ACTIONS(5889),
    [anon_sym_DASH_DASH] = ACTIONS(5889),
    [anon_sym_PLUS] = ACTIONS(5892),
    [anon_sym_DASH] = ACTIONS(5892),
    [anon_sym_STAR] = ACTIONS(5889),
    [anon_sym_SLASH] = ACTIONS(5892),
    [anon_sym_PERCENT] = ACTIONS(5889),
    [anon_sym_CARET] = ACTIONS(5889),
    [anon_sym_PIPE] = ACTIONS(5892),
    [anon_sym_AMP] = ACTIONS(5892),
    [anon_sym_LT_LT] = ACTIONS(5889),
    [anon_sym_GT_GT] = ACTIONS(5892),
    [anon_sym_GT_GT_GT] = ACTIONS(5889),
    [anon_sym_EQ_EQ] = ACTIONS(5889),
    [anon_sym_BANG_EQ] = ACTIONS(5889),
    [anon_sym_GT_EQ] = ACTIONS(5889),
    [anon_sym_LT_EQ] = ACTIONS(5889),
    [anon_sym_DOT] = ACTIONS(5892),
    [anon_sym_EQ_GT] = ACTIONS(4806),
    [anon_sym_switch] = ACTIONS(5889),
    [anon_sym_when] = ACTIONS(4806),
    [anon_sym_DOT_DOT] = ACTIONS(5889),
    [anon_sym_and] = ACTIONS(4806),
    [anon_sym_or] = ACTIONS(4806),
    [anon_sym_AMP_AMP] = ACTIONS(5889),
    [anon_sym_PIPE_PIPE] = ACTIONS(5889),
    [anon_sym_QMARK_QMARK] = ACTIONS(5889),
    [anon_sym_into] = ACTIONS(4806),
    [anon_sym_on] = ACTIONS(4806),
    [anon_sym_equals] = ACTIONS(4806),
    [anon_sym_by] = ACTIONS(4806),
    [anon_sym_as] = ACTIONS(5889),
    [anon_sym_is] = ACTIONS(5889),
    [anon_sym_DASH_GT] = ACTIONS(5889),
    [anon_sym_with] = ACTIONS(5889),
    [aux_sym_preproc_if_token3] = ACTIONS(4806),
    [aux_sym_preproc_else_token1] = ACTIONS(4806),
    [aux_sym_preproc_elif_token1] = ACTIONS(4806),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3991] = {
    [sym_preproc_region] = STATE(3991),
    [sym_preproc_endregion] = STATE(3991),
    [sym_preproc_line] = STATE(3991),
    [sym_preproc_pragma] = STATE(3991),
    [sym_preproc_nullable] = STATE(3991),
    [sym_preproc_error] = STATE(3991),
    [sym_preproc_warning] = STATE(3991),
    [sym_preproc_define] = STATE(3991),
    [sym_preproc_undef] = STATE(3991),
    [anon_sym_SEMI] = ACTIONS(5416),
    [anon_sym_LBRACK] = ACTIONS(5416),
    [anon_sym_COLON] = ACTIONS(5416),
    [anon_sym_COMMA] = ACTIONS(5416),
    [anon_sym_RBRACK] = ACTIONS(5416),
    [anon_sym_LPAREN] = ACTIONS(5416),
    [anon_sym_RPAREN] = ACTIONS(5416),
    [anon_sym_RBRACE] = ACTIONS(5416),
    [anon_sym_LT] = ACTIONS(5418),
    [anon_sym_GT] = ACTIONS(5418),
    [anon_sym_in] = ACTIONS(5418),
    [anon_sym_QMARK] = ACTIONS(5418),
    [anon_sym_BANG] = ACTIONS(5418),
    [anon_sym_PLUS_PLUS] = ACTIONS(5416),
    [anon_sym_DASH_DASH] = ACTIONS(5416),
    [anon_sym_PLUS] = ACTIONS(5418),
    [anon_sym_DASH] = ACTIONS(5418),
    [anon_sym_STAR] = ACTIONS(5416),
    [anon_sym_SLASH] = ACTIONS(5418),
    [anon_sym_PERCENT] = ACTIONS(5416),
    [anon_sym_CARET] = ACTIONS(5416),
    [anon_sym_PIPE] = ACTIONS(5418),
    [anon_sym_AMP] = ACTIONS(5418),
    [anon_sym_LT_LT] = ACTIONS(5416),
    [anon_sym_GT_GT] = ACTIONS(5418),
    [anon_sym_GT_GT_GT] = ACTIONS(5416),
    [anon_sym_EQ_EQ] = ACTIONS(5416),
    [anon_sym_BANG_EQ] = ACTIONS(5416),
    [anon_sym_GT_EQ] = ACTIONS(5416),
    [anon_sym_LT_EQ] = ACTIONS(5416),
    [anon_sym_DOT] = ACTIONS(5418),
    [anon_sym_EQ_GT] = ACTIONS(5416),
    [anon_sym_switch] = ACTIONS(5416),
    [anon_sym_when] = ACTIONS(5416),
    [anon_sym_DOT_DOT] = ACTIONS(5416),
    [anon_sym_and] = ACTIONS(5416),
    [anon_sym_or] = ACTIONS(5416),
    [anon_sym_AMP_AMP] = ACTIONS(5416),
    [anon_sym_PIPE_PIPE] = ACTIONS(5416),
    [anon_sym_QMARK_QMARK] = ACTIONS(5416),
    [anon_sym_into] = ACTIONS(5416),
    [anon_sym_on] = ACTIONS(5416),
    [anon_sym_equals] = ACTIONS(5416),
    [anon_sym_by] = ACTIONS(5416),
    [anon_sym_as] = ACTIONS(5416),
    [anon_sym_is] = ACTIONS(5416),
    [anon_sym_DASH_GT] = ACTIONS(5416),
    [anon_sym_with] = ACTIONS(5416),
    [aux_sym_preproc_if_token3] = ACTIONS(5416),
    [aux_sym_preproc_else_token1] = ACTIONS(5416),
    [aux_sym_preproc_elif_token1] = ACTIONS(5416),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3992] = {
    [sym_preproc_region] = STATE(3992),
    [sym_preproc_endregion] = STATE(3992),
    [sym_preproc_line] = STATE(3992),
    [sym_preproc_pragma] = STATE(3992),
    [sym_preproc_nullable] = STATE(3992),
    [sym_preproc_error] = STATE(3992),
    [sym_preproc_warning] = STATE(3992),
    [sym_preproc_define] = STATE(3992),
    [sym_preproc_undef] = STATE(3992),
    [anon_sym_SEMI] = ACTIONS(4500),
    [anon_sym_LBRACK] = ACTIONS(4500),
    [anon_sym_COLON] = ACTIONS(4500),
    [anon_sym_COMMA] = ACTIONS(4500),
    [anon_sym_RBRACK] = ACTIONS(4500),
    [anon_sym_LPAREN] = ACTIONS(4500),
    [anon_sym_RPAREN] = ACTIONS(4500),
    [anon_sym_LBRACE] = ACTIONS(4500),
    [anon_sym_RBRACE] = ACTIONS(4500),
    [anon_sym_LT] = ACTIONS(4498),
    [anon_sym_GT] = ACTIONS(4498),
    [anon_sym_in] = ACTIONS(4500),
    [anon_sym_QMARK] = ACTIONS(4498),
    [anon_sym_BANG] = ACTIONS(4498),
    [anon_sym_PLUS_PLUS] = ACTIONS(4500),
    [anon_sym_DASH_DASH] = ACTIONS(4500),
    [anon_sym_PLUS] = ACTIONS(4498),
    [anon_sym_DASH] = ACTIONS(4498),
    [anon_sym_STAR] = ACTIONS(4500),
    [anon_sym_SLASH] = ACTIONS(4498),
    [anon_sym_PERCENT] = ACTIONS(4500),
    [anon_sym_CARET] = ACTIONS(4500),
    [anon_sym_PIPE] = ACTIONS(4498),
    [anon_sym_AMP] = ACTIONS(4498),
    [anon_sym_LT_LT] = ACTIONS(4500),
    [anon_sym_GT_GT] = ACTIONS(4498),
    [anon_sym_GT_GT_GT] = ACTIONS(4500),
    [anon_sym_EQ_EQ] = ACTIONS(4500),
    [anon_sym_BANG_EQ] = ACTIONS(4500),
    [anon_sym_GT_EQ] = ACTIONS(4500),
    [anon_sym_LT_EQ] = ACTIONS(4500),
    [anon_sym_DOT] = ACTIONS(4498),
    [anon_sym_EQ_GT] = ACTIONS(4500),
    [anon_sym_switch] = ACTIONS(4500),
    [anon_sym_when] = ACTIONS(4500),
    [anon_sym_DOT_DOT] = ACTIONS(4500),
    [anon_sym_and] = ACTIONS(4500),
    [anon_sym_or] = ACTIONS(4500),
    [anon_sym_AMP_AMP] = ACTIONS(4500),
    [anon_sym_PIPE_PIPE] = ACTIONS(4500),
    [anon_sym_QMARK_QMARK] = ACTIONS(4500),
    [anon_sym_on] = ACTIONS(4500),
    [anon_sym_equals] = ACTIONS(4500),
    [anon_sym_by] = ACTIONS(4500),
    [anon_sym_as] = ACTIONS(4500),
    [anon_sym_is] = ACTIONS(4500),
    [anon_sym_DASH_GT] = ACTIONS(4500),
    [anon_sym_with] = ACTIONS(4500),
    [aux_sym_preproc_if_token3] = ACTIONS(4500),
    [aux_sym_preproc_else_token1] = ACTIONS(4500),
    [aux_sym_preproc_elif_token1] = ACTIONS(4500),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3993] = {
    [sym_preproc_region] = STATE(3993),
    [sym_preproc_endregion] = STATE(3993),
    [sym_preproc_line] = STATE(3993),
    [sym_preproc_pragma] = STATE(3993),
    [sym_preproc_nullable] = STATE(3993),
    [sym_preproc_error] = STATE(3993),
    [sym_preproc_warning] = STATE(3993),
    [sym_preproc_define] = STATE(3993),
    [sym_preproc_undef] = STATE(3993),
    [anon_sym_SEMI] = ACTIONS(5895),
    [anon_sym_LBRACK] = ACTIONS(5895),
    [anon_sym_COLON] = ACTIONS(5895),
    [anon_sym_COMMA] = ACTIONS(5895),
    [anon_sym_RBRACK] = ACTIONS(5895),
    [anon_sym_LPAREN] = ACTIONS(5895),
    [anon_sym_RPAREN] = ACTIONS(5895),
    [anon_sym_RBRACE] = ACTIONS(5895),
    [anon_sym_LT] = ACTIONS(5897),
    [anon_sym_GT] = ACTIONS(5897),
    [anon_sym_in] = ACTIONS(5897),
    [anon_sym_QMARK] = ACTIONS(5897),
    [anon_sym_BANG] = ACTIONS(5897),
    [anon_sym_PLUS_PLUS] = ACTIONS(5895),
    [anon_sym_DASH_DASH] = ACTIONS(5895),
    [anon_sym_PLUS] = ACTIONS(5897),
    [anon_sym_DASH] = ACTIONS(5897),
    [anon_sym_STAR] = ACTIONS(5895),
    [anon_sym_SLASH] = ACTIONS(5897),
    [anon_sym_PERCENT] = ACTIONS(5895),
    [anon_sym_CARET] = ACTIONS(5895),
    [anon_sym_PIPE] = ACTIONS(5897),
    [anon_sym_AMP] = ACTIONS(5897),
    [anon_sym_LT_LT] = ACTIONS(5895),
    [anon_sym_GT_GT] = ACTIONS(5897),
    [anon_sym_GT_GT_GT] = ACTIONS(5895),
    [anon_sym_EQ_EQ] = ACTIONS(5895),
    [anon_sym_BANG_EQ] = ACTIONS(5895),
    [anon_sym_GT_EQ] = ACTIONS(5895),
    [anon_sym_LT_EQ] = ACTIONS(5895),
    [anon_sym_DOT] = ACTIONS(5897),
    [anon_sym_EQ_GT] = ACTIONS(5895),
    [anon_sym_switch] = ACTIONS(5895),
    [anon_sym_when] = ACTIONS(5895),
    [anon_sym_DOT_DOT] = ACTIONS(5895),
    [anon_sym_and] = ACTIONS(5895),
    [anon_sym_or] = ACTIONS(5895),
    [anon_sym_AMP_AMP] = ACTIONS(5895),
    [anon_sym_PIPE_PIPE] = ACTIONS(5895),
    [anon_sym_QMARK_QMARK] = ACTIONS(5895),
    [anon_sym_into] = ACTIONS(5895),
    [anon_sym_on] = ACTIONS(5895),
    [anon_sym_equals] = ACTIONS(5895),
    [anon_sym_by] = ACTIONS(5895),
    [anon_sym_as] = ACTIONS(5895),
    [anon_sym_is] = ACTIONS(5895),
    [anon_sym_DASH_GT] = ACTIONS(5895),
    [anon_sym_with] = ACTIONS(5895),
    [aux_sym_preproc_if_token3] = ACTIONS(5895),
    [aux_sym_preproc_else_token1] = ACTIONS(5895),
    [aux_sym_preproc_elif_token1] = ACTIONS(5895),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3994] = {
    [sym_preproc_region] = STATE(3994),
    [sym_preproc_endregion] = STATE(3994),
    [sym_preproc_line] = STATE(3994),
    [sym_preproc_pragma] = STATE(3994),
    [sym_preproc_nullable] = STATE(3994),
    [sym_preproc_error] = STATE(3994),
    [sym_preproc_warning] = STATE(3994),
    [sym_preproc_define] = STATE(3994),
    [sym_preproc_undef] = STATE(3994),
    [anon_sym_SEMI] = ACTIONS(5544),
    [anon_sym_LBRACK] = ACTIONS(5544),
    [anon_sym_COLON] = ACTIONS(5544),
    [anon_sym_COMMA] = ACTIONS(5544),
    [anon_sym_RBRACK] = ACTIONS(5544),
    [anon_sym_LPAREN] = ACTIONS(5544),
    [anon_sym_RPAREN] = ACTIONS(5544),
    [anon_sym_RBRACE] = ACTIONS(5544),
    [anon_sym_LT] = ACTIONS(5546),
    [anon_sym_GT] = ACTIONS(5546),
    [anon_sym_in] = ACTIONS(5546),
    [anon_sym_QMARK] = ACTIONS(5546),
    [anon_sym_BANG] = ACTIONS(5546),
    [anon_sym_PLUS_PLUS] = ACTIONS(5544),
    [anon_sym_DASH_DASH] = ACTIONS(5544),
    [anon_sym_PLUS] = ACTIONS(5546),
    [anon_sym_DASH] = ACTIONS(5546),
    [anon_sym_STAR] = ACTIONS(5544),
    [anon_sym_SLASH] = ACTIONS(5546),
    [anon_sym_PERCENT] = ACTIONS(5544),
    [anon_sym_CARET] = ACTIONS(5544),
    [anon_sym_PIPE] = ACTIONS(5546),
    [anon_sym_AMP] = ACTIONS(5546),
    [anon_sym_LT_LT] = ACTIONS(5544),
    [anon_sym_GT_GT] = ACTIONS(5546),
    [anon_sym_GT_GT_GT] = ACTIONS(5544),
    [anon_sym_EQ_EQ] = ACTIONS(5544),
    [anon_sym_BANG_EQ] = ACTIONS(5544),
    [anon_sym_GT_EQ] = ACTIONS(5544),
    [anon_sym_LT_EQ] = ACTIONS(5544),
    [anon_sym_DOT] = ACTIONS(5546),
    [anon_sym_EQ_GT] = ACTIONS(5544),
    [anon_sym_switch] = ACTIONS(5544),
    [anon_sym_when] = ACTIONS(5544),
    [anon_sym_DOT_DOT] = ACTIONS(5544),
    [anon_sym_and] = ACTIONS(5544),
    [anon_sym_or] = ACTIONS(5544),
    [anon_sym_AMP_AMP] = ACTIONS(5544),
    [anon_sym_PIPE_PIPE] = ACTIONS(5544),
    [anon_sym_QMARK_QMARK] = ACTIONS(5544),
    [anon_sym_into] = ACTIONS(5544),
    [anon_sym_on] = ACTIONS(5544),
    [anon_sym_equals] = ACTIONS(5544),
    [anon_sym_by] = ACTIONS(5544),
    [anon_sym_as] = ACTIONS(5544),
    [anon_sym_is] = ACTIONS(5544),
    [anon_sym_DASH_GT] = ACTIONS(5544),
    [anon_sym_with] = ACTIONS(5544),
    [aux_sym_preproc_if_token3] = ACTIONS(5544),
    [aux_sym_preproc_else_token1] = ACTIONS(5544),
    [aux_sym_preproc_elif_token1] = ACTIONS(5544),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3995] = {
    [sym_preproc_region] = STATE(3995),
    [sym_preproc_endregion] = STATE(3995),
    [sym_preproc_line] = STATE(3995),
    [sym_preproc_pragma] = STATE(3995),
    [sym_preproc_nullable] = STATE(3995),
    [sym_preproc_error] = STATE(3995),
    [sym_preproc_warning] = STATE(3995),
    [sym_preproc_define] = STATE(3995),
    [sym_preproc_undef] = STATE(3995),
    [sym__identifier_token] = ACTIONS(4042),
    [anon_sym_extern] = ACTIONS(4042),
    [anon_sym_alias] = ACTIONS(5899),
    [anon_sym_global] = ACTIONS(4042),
    [anon_sym_unsafe] = ACTIONS(4042),
    [anon_sym_static] = ACTIONS(4042),
    [anon_sym_LPAREN] = ACTIONS(5474),
    [anon_sym_class] = ACTIONS(4042),
    [anon_sym_ref] = ACTIONS(4042),
    [anon_sym_struct] = ACTIONS(4042),
    [anon_sym_enum] = ACTIONS(4042),
    [anon_sym_interface] = ACTIONS(4042),
    [anon_sym_delegate] = ACTIONS(4042),
    [anon_sym_record] = ACTIONS(4042),
    [anon_sym_abstract] = ACTIONS(4042),
    [anon_sym_async] = ACTIONS(4042),
    [anon_sym_const] = ACTIONS(4042),
    [anon_sym_file] = ACTIONS(4042),
    [anon_sym_fixed] = ACTIONS(4042),
    [anon_sym_internal] = ACTIONS(4042),
    [anon_sym_new] = ACTIONS(4042),
    [anon_sym_override] = ACTIONS(4042),
    [anon_sym_partial] = ACTIONS(4042),
    [anon_sym_private] = ACTIONS(4042),
    [anon_sym_protected] = ACTIONS(4042),
    [anon_sym_public] = ACTIONS(4042),
    [anon_sym_readonly] = ACTIONS(4042),
    [anon_sym_required] = ACTIONS(4042),
    [anon_sym_sealed] = ACTIONS(4042),
    [anon_sym_virtual] = ACTIONS(4042),
    [anon_sym_volatile] = ACTIONS(4042),
    [anon_sym_where] = ACTIONS(4042),
    [anon_sym_notnull] = ACTIONS(4042),
    [anon_sym_unmanaged] = ACTIONS(4042),
    [anon_sym_scoped] = ACTIONS(4042),
    [anon_sym_var] = ACTIONS(4042),
    [sym_predefined_type] = ACTIONS(4042),
    [anon_sym_yield] = ACTIONS(4042),
    [anon_sym_when] = ACTIONS(4042),
    [anon_sym_from] = ACTIONS(4042),
    [anon_sym_into] = ACTIONS(4042),
    [anon_sym_join] = ACTIONS(4042),
    [anon_sym_on] = ACTIONS(4042),
    [anon_sym_equals] = ACTIONS(4042),
    [anon_sym_let] = ACTIONS(4042),
    [anon_sym_orderby] = ACTIONS(4042),
    [anon_sym_ascending] = ACTIONS(4042),
    [anon_sym_descending] = ACTIONS(4042),
    [anon_sym_group] = ACTIONS(4042),
    [anon_sym_by] = ACTIONS(4042),
    [anon_sym_select] = ACTIONS(4042),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3996] = {
    [sym_preproc_region] = STATE(3996),
    [sym_preproc_endregion] = STATE(3996),
    [sym_preproc_line] = STATE(3996),
    [sym_preproc_pragma] = STATE(3996),
    [sym_preproc_nullable] = STATE(3996),
    [sym_preproc_error] = STATE(3996),
    [sym_preproc_warning] = STATE(3996),
    [sym_preproc_define] = STATE(3996),
    [sym_preproc_undef] = STATE(3996),
    [anon_sym_SEMI] = ACTIONS(5476),
    [anon_sym_LBRACK] = ACTIONS(5476),
    [anon_sym_COLON] = ACTIONS(5476),
    [anon_sym_COMMA] = ACTIONS(5476),
    [anon_sym_RBRACK] = ACTIONS(5476),
    [anon_sym_LPAREN] = ACTIONS(5476),
    [anon_sym_RPAREN] = ACTIONS(5476),
    [anon_sym_RBRACE] = ACTIONS(5476),
    [anon_sym_LT] = ACTIONS(5478),
    [anon_sym_GT] = ACTIONS(5478),
    [anon_sym_in] = ACTIONS(5478),
    [anon_sym_QMARK] = ACTIONS(5478),
    [anon_sym_BANG] = ACTIONS(5478),
    [anon_sym_PLUS_PLUS] = ACTIONS(5476),
    [anon_sym_DASH_DASH] = ACTIONS(5476),
    [anon_sym_PLUS] = ACTIONS(5478),
    [anon_sym_DASH] = ACTIONS(5478),
    [anon_sym_STAR] = ACTIONS(5476),
    [anon_sym_SLASH] = ACTIONS(5478),
    [anon_sym_PERCENT] = ACTIONS(5476),
    [anon_sym_CARET] = ACTIONS(5476),
    [anon_sym_PIPE] = ACTIONS(5478),
    [anon_sym_AMP] = ACTIONS(5478),
    [anon_sym_LT_LT] = ACTIONS(5476),
    [anon_sym_GT_GT] = ACTIONS(5478),
    [anon_sym_GT_GT_GT] = ACTIONS(5476),
    [anon_sym_EQ_EQ] = ACTIONS(5476),
    [anon_sym_BANG_EQ] = ACTIONS(5476),
    [anon_sym_GT_EQ] = ACTIONS(5476),
    [anon_sym_LT_EQ] = ACTIONS(5476),
    [anon_sym_DOT] = ACTIONS(5478),
    [anon_sym_EQ_GT] = ACTIONS(5476),
    [anon_sym_switch] = ACTIONS(5476),
    [anon_sym_when] = ACTIONS(5476),
    [anon_sym_DOT_DOT] = ACTIONS(5476),
    [anon_sym_and] = ACTIONS(5476),
    [anon_sym_or] = ACTIONS(5476),
    [anon_sym_AMP_AMP] = ACTIONS(5476),
    [anon_sym_PIPE_PIPE] = ACTIONS(5476),
    [anon_sym_QMARK_QMARK] = ACTIONS(5476),
    [anon_sym_into] = ACTIONS(5476),
    [anon_sym_on] = ACTIONS(5476),
    [anon_sym_equals] = ACTIONS(5476),
    [anon_sym_by] = ACTIONS(5476),
    [anon_sym_as] = ACTIONS(5476),
    [anon_sym_is] = ACTIONS(5476),
    [anon_sym_DASH_GT] = ACTIONS(5476),
    [anon_sym_with] = ACTIONS(5476),
    [aux_sym_preproc_if_token3] = ACTIONS(5476),
    [aux_sym_preproc_else_token1] = ACTIONS(5476),
    [aux_sym_preproc_elif_token1] = ACTIONS(5476),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3997] = {
    [sym_preproc_region] = STATE(3997),
    [sym_preproc_endregion] = STATE(3997),
    [sym_preproc_line] = STATE(3997),
    [sym_preproc_pragma] = STATE(3997),
    [sym_preproc_nullable] = STATE(3997),
    [sym_preproc_error] = STATE(3997),
    [sym_preproc_warning] = STATE(3997),
    [sym_preproc_define] = STATE(3997),
    [sym_preproc_undef] = STATE(3997),
    [sym__identifier_token] = ACTIONS(4042),
    [anon_sym_extern] = ACTIONS(4042),
    [anon_sym_alias] = ACTIONS(4042),
    [anon_sym_global] = ACTIONS(4042),
    [anon_sym_unsafe] = ACTIONS(4042),
    [anon_sym_static] = ACTIONS(4042),
    [anon_sym_LPAREN] = ACTIONS(5901),
    [anon_sym_class] = ACTIONS(4042),
    [anon_sym_ref] = ACTIONS(4042),
    [anon_sym_struct] = ACTIONS(4042),
    [anon_sym_enum] = ACTIONS(4042),
    [anon_sym_interface] = ACTIONS(4042),
    [anon_sym_delegate] = ACTIONS(4042),
    [anon_sym_record] = ACTIONS(4042),
    [anon_sym_abstract] = ACTIONS(4042),
    [anon_sym_async] = ACTIONS(4042),
    [anon_sym_const] = ACTIONS(4042),
    [anon_sym_file] = ACTIONS(4042),
    [anon_sym_fixed] = ACTIONS(4042),
    [anon_sym_internal] = ACTIONS(4042),
    [anon_sym_new] = ACTIONS(4042),
    [anon_sym_override] = ACTIONS(4042),
    [anon_sym_partial] = ACTIONS(4042),
    [anon_sym_private] = ACTIONS(4042),
    [anon_sym_protected] = ACTIONS(4042),
    [anon_sym_public] = ACTIONS(4042),
    [anon_sym_readonly] = ACTIONS(4042),
    [anon_sym_required] = ACTIONS(4042),
    [anon_sym_sealed] = ACTIONS(4042),
    [anon_sym_virtual] = ACTIONS(4042),
    [anon_sym_volatile] = ACTIONS(4042),
    [anon_sym_where] = ACTIONS(4042),
    [anon_sym_notnull] = ACTIONS(4042),
    [anon_sym_unmanaged] = ACTIONS(4042),
    [anon_sym_scoped] = ACTIONS(4042),
    [anon_sym_var] = ACTIONS(4042),
    [sym_predefined_type] = ACTIONS(4042),
    [anon_sym_yield] = ACTIONS(4042),
    [anon_sym_when] = ACTIONS(4042),
    [anon_sym_from] = ACTIONS(4042),
    [anon_sym_into] = ACTIONS(4042),
    [anon_sym_join] = ACTIONS(4042),
    [anon_sym_on] = ACTIONS(4042),
    [anon_sym_equals] = ACTIONS(4042),
    [anon_sym_let] = ACTIONS(4042),
    [anon_sym_orderby] = ACTIONS(4042),
    [anon_sym_ascending] = ACTIONS(4042),
    [anon_sym_descending] = ACTIONS(4042),
    [anon_sym_group] = ACTIONS(4042),
    [anon_sym_by] = ACTIONS(4042),
    [anon_sym_select] = ACTIONS(4042),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3998] = {
    [sym_preproc_region] = STATE(3998),
    [sym_preproc_endregion] = STATE(3998),
    [sym_preproc_line] = STATE(3998),
    [sym_preproc_pragma] = STATE(3998),
    [sym_preproc_nullable] = STATE(3998),
    [sym_preproc_error] = STATE(3998),
    [sym_preproc_warning] = STATE(3998),
    [sym_preproc_define] = STATE(3998),
    [sym_preproc_undef] = STATE(3998),
    [anon_sym_SEMI] = ACTIONS(4151),
    [anon_sym_LBRACK] = ACTIONS(4151),
    [anon_sym_COLON] = ACTIONS(4151),
    [anon_sym_COMMA] = ACTIONS(4151),
    [anon_sym_RBRACK] = ACTIONS(4151),
    [anon_sym_LPAREN] = ACTIONS(4151),
    [anon_sym_RPAREN] = ACTIONS(4151),
    [anon_sym_LBRACE] = ACTIONS(4151),
    [anon_sym_RBRACE] = ACTIONS(4151),
    [anon_sym_LT] = ACTIONS(4149),
    [anon_sym_GT] = ACTIONS(4149),
    [anon_sym_in] = ACTIONS(4151),
    [anon_sym_QMARK] = ACTIONS(4149),
    [anon_sym_BANG] = ACTIONS(4149),
    [anon_sym_PLUS_PLUS] = ACTIONS(4151),
    [anon_sym_DASH_DASH] = ACTIONS(4151),
    [anon_sym_PLUS] = ACTIONS(4149),
    [anon_sym_DASH] = ACTIONS(4149),
    [anon_sym_STAR] = ACTIONS(4151),
    [anon_sym_SLASH] = ACTIONS(4149),
    [anon_sym_PERCENT] = ACTIONS(4151),
    [anon_sym_CARET] = ACTIONS(4151),
    [anon_sym_PIPE] = ACTIONS(4149),
    [anon_sym_AMP] = ACTIONS(4149),
    [anon_sym_LT_LT] = ACTIONS(4151),
    [anon_sym_GT_GT] = ACTIONS(4149),
    [anon_sym_GT_GT_GT] = ACTIONS(4151),
    [anon_sym_EQ_EQ] = ACTIONS(4151),
    [anon_sym_BANG_EQ] = ACTIONS(4151),
    [anon_sym_GT_EQ] = ACTIONS(4151),
    [anon_sym_LT_EQ] = ACTIONS(4151),
    [anon_sym_DOT] = ACTIONS(4149),
    [anon_sym_EQ_GT] = ACTIONS(4151),
    [anon_sym_switch] = ACTIONS(4151),
    [anon_sym_when] = ACTIONS(4151),
    [anon_sym_DOT_DOT] = ACTIONS(4151),
    [anon_sym_and] = ACTIONS(4151),
    [anon_sym_or] = ACTIONS(4151),
    [anon_sym_AMP_AMP] = ACTIONS(4151),
    [anon_sym_PIPE_PIPE] = ACTIONS(4151),
    [anon_sym_QMARK_QMARK] = ACTIONS(4151),
    [anon_sym_on] = ACTIONS(4151),
    [anon_sym_equals] = ACTIONS(4151),
    [anon_sym_by] = ACTIONS(4151),
    [anon_sym_as] = ACTIONS(4151),
    [anon_sym_is] = ACTIONS(4151),
    [anon_sym_DASH_GT] = ACTIONS(4151),
    [anon_sym_with] = ACTIONS(4151),
    [aux_sym_preproc_if_token3] = ACTIONS(4151),
    [aux_sym_preproc_else_token1] = ACTIONS(4151),
    [aux_sym_preproc_elif_token1] = ACTIONS(4151),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [3999] = {
    [sym_preproc_region] = STATE(3999),
    [sym_preproc_endregion] = STATE(3999),
    [sym_preproc_line] = STATE(3999),
    [sym_preproc_pragma] = STATE(3999),
    [sym_preproc_nullable] = STATE(3999),
    [sym_preproc_error] = STATE(3999),
    [sym_preproc_warning] = STATE(3999),
    [sym_preproc_define] = STATE(3999),
    [sym_preproc_undef] = STATE(3999),
    [anon_sym_SEMI] = ACTIONS(5682),
    [anon_sym_LBRACK] = ACTIONS(5682),
    [anon_sym_COLON] = ACTIONS(5682),
    [anon_sym_COMMA] = ACTIONS(5682),
    [anon_sym_RBRACK] = ACTIONS(5682),
    [anon_sym_LPAREN] = ACTIONS(5682),
    [anon_sym_RPAREN] = ACTIONS(5682),
    [anon_sym_RBRACE] = ACTIONS(5682),
    [anon_sym_LT] = ACTIONS(5684),
    [anon_sym_GT] = ACTIONS(5684),
    [anon_sym_in] = ACTIONS(5684),
    [anon_sym_QMARK] = ACTIONS(5684),
    [anon_sym_BANG] = ACTIONS(5684),
    [anon_sym_PLUS_PLUS] = ACTIONS(5682),
    [anon_sym_DASH_DASH] = ACTIONS(5682),
    [anon_sym_PLUS] = ACTIONS(5684),
    [anon_sym_DASH] = ACTIONS(5684),
    [anon_sym_STAR] = ACTIONS(5682),
    [anon_sym_SLASH] = ACTIONS(5684),
    [anon_sym_PERCENT] = ACTIONS(5682),
    [anon_sym_CARET] = ACTIONS(5682),
    [anon_sym_PIPE] = ACTIONS(5684),
    [anon_sym_AMP] = ACTIONS(5684),
    [anon_sym_LT_LT] = ACTIONS(5682),
    [anon_sym_GT_GT] = ACTIONS(5684),
    [anon_sym_GT_GT_GT] = ACTIONS(5682),
    [anon_sym_EQ_EQ] = ACTIONS(5682),
    [anon_sym_BANG_EQ] = ACTIONS(5682),
    [anon_sym_GT_EQ] = ACTIONS(5682),
    [anon_sym_LT_EQ] = ACTIONS(5682),
    [anon_sym_DOT] = ACTIONS(5684),
    [anon_sym_EQ_GT] = ACTIONS(5682),
    [anon_sym_switch] = ACTIONS(5682),
    [anon_sym_when] = ACTIONS(5682),
    [anon_sym_DOT_DOT] = ACTIONS(5682),
    [anon_sym_and] = ACTIONS(5682),
    [anon_sym_or] = ACTIONS(5682),
    [anon_sym_AMP_AMP] = ACTIONS(5682),
    [anon_sym_PIPE_PIPE] = ACTIONS(5682),
    [anon_sym_QMARK_QMARK] = ACTIONS(5682),
    [anon_sym_into] = ACTIONS(5682),
    [anon_sym_on] = ACTIONS(5682),
    [anon_sym_equals] = ACTIONS(5682),
    [anon_sym_by] = ACTIONS(5682),
    [anon_sym_as] = ACTIONS(5682),
    [anon_sym_is] = ACTIONS(5682),
    [anon_sym_DASH_GT] = ACTIONS(5682),
    [anon_sym_with] = ACTIONS(5682),
    [aux_sym_preproc_if_token3] = ACTIONS(5682),
    [aux_sym_preproc_else_token1] = ACTIONS(5682),
    [aux_sym_preproc_elif_token1] = ACTIONS(5682),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4000] = {
    [sym_preproc_region] = STATE(4000),
    [sym_preproc_endregion] = STATE(4000),
    [sym_preproc_line] = STATE(4000),
    [sym_preproc_pragma] = STATE(4000),
    [sym_preproc_nullable] = STATE(4000),
    [sym_preproc_error] = STATE(4000),
    [sym_preproc_warning] = STATE(4000),
    [sym_preproc_define] = STATE(4000),
    [sym_preproc_undef] = STATE(4000),
    [anon_sym_SEMI] = ACTIONS(5526),
    [anon_sym_LBRACK] = ACTIONS(5526),
    [anon_sym_COLON] = ACTIONS(5526),
    [anon_sym_COMMA] = ACTIONS(5526),
    [anon_sym_RBRACK] = ACTIONS(5526),
    [anon_sym_LPAREN] = ACTIONS(5526),
    [anon_sym_RPAREN] = ACTIONS(5526),
    [anon_sym_RBRACE] = ACTIONS(5526),
    [anon_sym_LT] = ACTIONS(5528),
    [anon_sym_GT] = ACTIONS(5528),
    [anon_sym_in] = ACTIONS(5528),
    [anon_sym_QMARK] = ACTIONS(5528),
    [anon_sym_BANG] = ACTIONS(5528),
    [anon_sym_PLUS_PLUS] = ACTIONS(5526),
    [anon_sym_DASH_DASH] = ACTIONS(5526),
    [anon_sym_PLUS] = ACTIONS(5528),
    [anon_sym_DASH] = ACTIONS(5528),
    [anon_sym_STAR] = ACTIONS(5526),
    [anon_sym_SLASH] = ACTIONS(5528),
    [anon_sym_PERCENT] = ACTIONS(5526),
    [anon_sym_CARET] = ACTIONS(5526),
    [anon_sym_PIPE] = ACTIONS(5528),
    [anon_sym_AMP] = ACTIONS(5528),
    [anon_sym_LT_LT] = ACTIONS(5526),
    [anon_sym_GT_GT] = ACTIONS(5528),
    [anon_sym_GT_GT_GT] = ACTIONS(5526),
    [anon_sym_EQ_EQ] = ACTIONS(5526),
    [anon_sym_BANG_EQ] = ACTIONS(5526),
    [anon_sym_GT_EQ] = ACTIONS(5526),
    [anon_sym_LT_EQ] = ACTIONS(5526),
    [anon_sym_DOT] = ACTIONS(5528),
    [anon_sym_EQ_GT] = ACTIONS(5526),
    [anon_sym_switch] = ACTIONS(5526),
    [anon_sym_when] = ACTIONS(5526),
    [anon_sym_DOT_DOT] = ACTIONS(5526),
    [anon_sym_and] = ACTIONS(5526),
    [anon_sym_or] = ACTIONS(5526),
    [anon_sym_AMP_AMP] = ACTIONS(5526),
    [anon_sym_PIPE_PIPE] = ACTIONS(5526),
    [anon_sym_QMARK_QMARK] = ACTIONS(5526),
    [anon_sym_into] = ACTIONS(5526),
    [anon_sym_on] = ACTIONS(5526),
    [anon_sym_equals] = ACTIONS(5526),
    [anon_sym_by] = ACTIONS(5526),
    [anon_sym_as] = ACTIONS(5526),
    [anon_sym_is] = ACTIONS(5526),
    [anon_sym_DASH_GT] = ACTIONS(5526),
    [anon_sym_with] = ACTIONS(5526),
    [aux_sym_preproc_if_token3] = ACTIONS(5526),
    [aux_sym_preproc_else_token1] = ACTIONS(5526),
    [aux_sym_preproc_elif_token1] = ACTIONS(5526),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4001] = {
    [sym_preproc_region] = STATE(4001),
    [sym_preproc_endregion] = STATE(4001),
    [sym_preproc_line] = STATE(4001),
    [sym_preproc_pragma] = STATE(4001),
    [sym_preproc_nullable] = STATE(4001),
    [sym_preproc_error] = STATE(4001),
    [sym_preproc_warning] = STATE(4001),
    [sym_preproc_define] = STATE(4001),
    [sym_preproc_undef] = STATE(4001),
    [anon_sym_SEMI] = ACTIONS(5286),
    [anon_sym_LBRACK] = ACTIONS(5286),
    [anon_sym_COLON] = ACTIONS(5286),
    [anon_sym_COMMA] = ACTIONS(5286),
    [anon_sym_RBRACK] = ACTIONS(5286),
    [anon_sym_LPAREN] = ACTIONS(5286),
    [anon_sym_RPAREN] = ACTIONS(5286),
    [anon_sym_RBRACE] = ACTIONS(5286),
    [anon_sym_LT] = ACTIONS(5288),
    [anon_sym_GT] = ACTIONS(5288),
    [anon_sym_in] = ACTIONS(5288),
    [anon_sym_QMARK] = ACTIONS(5288),
    [anon_sym_BANG] = ACTIONS(5288),
    [anon_sym_PLUS_PLUS] = ACTIONS(5286),
    [anon_sym_DASH_DASH] = ACTIONS(5286),
    [anon_sym_PLUS] = ACTIONS(5288),
    [anon_sym_DASH] = ACTIONS(5288),
    [anon_sym_STAR] = ACTIONS(5286),
    [anon_sym_SLASH] = ACTIONS(5288),
    [anon_sym_PERCENT] = ACTIONS(5286),
    [anon_sym_CARET] = ACTIONS(5286),
    [anon_sym_PIPE] = ACTIONS(5288),
    [anon_sym_AMP] = ACTIONS(5288),
    [anon_sym_LT_LT] = ACTIONS(5286),
    [anon_sym_GT_GT] = ACTIONS(5288),
    [anon_sym_GT_GT_GT] = ACTIONS(5286),
    [anon_sym_EQ_EQ] = ACTIONS(5286),
    [anon_sym_BANG_EQ] = ACTIONS(5286),
    [anon_sym_GT_EQ] = ACTIONS(5286),
    [anon_sym_LT_EQ] = ACTIONS(5286),
    [anon_sym_DOT] = ACTIONS(5288),
    [anon_sym_EQ_GT] = ACTIONS(5286),
    [anon_sym_switch] = ACTIONS(5286),
    [anon_sym_when] = ACTIONS(5286),
    [anon_sym_DOT_DOT] = ACTIONS(5286),
    [anon_sym_and] = ACTIONS(5286),
    [anon_sym_or] = ACTIONS(5286),
    [anon_sym_AMP_AMP] = ACTIONS(5286),
    [anon_sym_PIPE_PIPE] = ACTIONS(5286),
    [anon_sym_QMARK_QMARK] = ACTIONS(5286),
    [anon_sym_into] = ACTIONS(5286),
    [anon_sym_on] = ACTIONS(5286),
    [anon_sym_equals] = ACTIONS(5286),
    [anon_sym_by] = ACTIONS(5286),
    [anon_sym_as] = ACTIONS(5286),
    [anon_sym_is] = ACTIONS(5286),
    [anon_sym_DASH_GT] = ACTIONS(5286),
    [anon_sym_with] = ACTIONS(5286),
    [aux_sym_preproc_if_token3] = ACTIONS(5286),
    [aux_sym_preproc_else_token1] = ACTIONS(5286),
    [aux_sym_preproc_elif_token1] = ACTIONS(5286),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4002] = {
    [sym_preproc_region] = STATE(4002),
    [sym_preproc_endregion] = STATE(4002),
    [sym_preproc_line] = STATE(4002),
    [sym_preproc_pragma] = STATE(4002),
    [sym_preproc_nullable] = STATE(4002),
    [sym_preproc_error] = STATE(4002),
    [sym_preproc_warning] = STATE(4002),
    [sym_preproc_define] = STATE(4002),
    [sym_preproc_undef] = STATE(4002),
    [anon_sym_SEMI] = ACTIONS(2035),
    [anon_sym_LBRACK] = ACTIONS(2035),
    [anon_sym_COLON] = ACTIONS(2035),
    [anon_sym_COMMA] = ACTIONS(2035),
    [anon_sym_RBRACK] = ACTIONS(2035),
    [anon_sym_LPAREN] = ACTIONS(2035),
    [anon_sym_RPAREN] = ACTIONS(2035),
    [anon_sym_RBRACE] = ACTIONS(2035),
    [anon_sym_LT] = ACTIONS(2037),
    [anon_sym_GT] = ACTIONS(2037),
    [anon_sym_in] = ACTIONS(2037),
    [anon_sym_QMARK] = ACTIONS(2037),
    [anon_sym_BANG] = ACTIONS(2037),
    [anon_sym_PLUS_PLUS] = ACTIONS(2035),
    [anon_sym_DASH_DASH] = ACTIONS(2035),
    [anon_sym_PLUS] = ACTIONS(2037),
    [anon_sym_DASH] = ACTIONS(2037),
    [anon_sym_STAR] = ACTIONS(2035),
    [anon_sym_SLASH] = ACTIONS(2037),
    [anon_sym_PERCENT] = ACTIONS(2035),
    [anon_sym_CARET] = ACTIONS(2035),
    [anon_sym_PIPE] = ACTIONS(2037),
    [anon_sym_AMP] = ACTIONS(2037),
    [anon_sym_LT_LT] = ACTIONS(2035),
    [anon_sym_GT_GT] = ACTIONS(2037),
    [anon_sym_GT_GT_GT] = ACTIONS(2035),
    [anon_sym_EQ_EQ] = ACTIONS(2035),
    [anon_sym_BANG_EQ] = ACTIONS(2035),
    [anon_sym_GT_EQ] = ACTIONS(2035),
    [anon_sym_LT_EQ] = ACTIONS(2035),
    [anon_sym_DOT] = ACTIONS(2037),
    [anon_sym_EQ_GT] = ACTIONS(2035),
    [anon_sym_switch] = ACTIONS(2035),
    [anon_sym_when] = ACTIONS(2035),
    [anon_sym_DOT_DOT] = ACTIONS(2035),
    [anon_sym_and] = ACTIONS(2035),
    [anon_sym_or] = ACTIONS(2035),
    [anon_sym_AMP_AMP] = ACTIONS(2035),
    [anon_sym_PIPE_PIPE] = ACTIONS(2035),
    [anon_sym_QMARK_QMARK] = ACTIONS(2035),
    [anon_sym_into] = ACTIONS(2035),
    [anon_sym_on] = ACTIONS(2035),
    [anon_sym_equals] = ACTIONS(2035),
    [anon_sym_by] = ACTIONS(2035),
    [anon_sym_as] = ACTIONS(2035),
    [anon_sym_is] = ACTIONS(2035),
    [anon_sym_DASH_GT] = ACTIONS(2035),
    [anon_sym_with] = ACTIONS(2035),
    [aux_sym_preproc_if_token3] = ACTIONS(2035),
    [aux_sym_preproc_else_token1] = ACTIONS(2035),
    [aux_sym_preproc_elif_token1] = ACTIONS(2035),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4003] = {
    [sym_preproc_region] = STATE(4003),
    [sym_preproc_endregion] = STATE(4003),
    [sym_preproc_line] = STATE(4003),
    [sym_preproc_pragma] = STATE(4003),
    [sym_preproc_nullable] = STATE(4003),
    [sym_preproc_error] = STATE(4003),
    [sym_preproc_warning] = STATE(4003),
    [sym_preproc_define] = STATE(4003),
    [sym_preproc_undef] = STATE(4003),
    [anon_sym_SEMI] = ACTIONS(5560),
    [anon_sym_LBRACK] = ACTIONS(5560),
    [anon_sym_COLON] = ACTIONS(5560),
    [anon_sym_COMMA] = ACTIONS(5560),
    [anon_sym_RBRACK] = ACTIONS(5560),
    [anon_sym_LPAREN] = ACTIONS(5560),
    [anon_sym_RPAREN] = ACTIONS(5560),
    [anon_sym_RBRACE] = ACTIONS(5560),
    [anon_sym_LT] = ACTIONS(5562),
    [anon_sym_GT] = ACTIONS(5562),
    [anon_sym_in] = ACTIONS(5562),
    [anon_sym_QMARK] = ACTIONS(5562),
    [anon_sym_BANG] = ACTIONS(5562),
    [anon_sym_PLUS_PLUS] = ACTIONS(5560),
    [anon_sym_DASH_DASH] = ACTIONS(5560),
    [anon_sym_PLUS] = ACTIONS(5562),
    [anon_sym_DASH] = ACTIONS(5562),
    [anon_sym_STAR] = ACTIONS(5560),
    [anon_sym_SLASH] = ACTIONS(5562),
    [anon_sym_PERCENT] = ACTIONS(5560),
    [anon_sym_CARET] = ACTIONS(5560),
    [anon_sym_PIPE] = ACTIONS(5562),
    [anon_sym_AMP] = ACTIONS(5562),
    [anon_sym_LT_LT] = ACTIONS(5560),
    [anon_sym_GT_GT] = ACTIONS(5562),
    [anon_sym_GT_GT_GT] = ACTIONS(5560),
    [anon_sym_EQ_EQ] = ACTIONS(5560),
    [anon_sym_BANG_EQ] = ACTIONS(5560),
    [anon_sym_GT_EQ] = ACTIONS(5560),
    [anon_sym_LT_EQ] = ACTIONS(5560),
    [anon_sym_DOT] = ACTIONS(5562),
    [anon_sym_EQ_GT] = ACTIONS(5560),
    [anon_sym_switch] = ACTIONS(5560),
    [anon_sym_when] = ACTIONS(5560),
    [anon_sym_DOT_DOT] = ACTIONS(5560),
    [anon_sym_and] = ACTIONS(5560),
    [anon_sym_or] = ACTIONS(5560),
    [anon_sym_AMP_AMP] = ACTIONS(5560),
    [anon_sym_PIPE_PIPE] = ACTIONS(5560),
    [anon_sym_QMARK_QMARK] = ACTIONS(5560),
    [anon_sym_into] = ACTIONS(5560),
    [anon_sym_on] = ACTIONS(5560),
    [anon_sym_equals] = ACTIONS(5560),
    [anon_sym_by] = ACTIONS(5560),
    [anon_sym_as] = ACTIONS(5560),
    [anon_sym_is] = ACTIONS(5560),
    [anon_sym_DASH_GT] = ACTIONS(5560),
    [anon_sym_with] = ACTIONS(5560),
    [aux_sym_preproc_if_token3] = ACTIONS(5560),
    [aux_sym_preproc_else_token1] = ACTIONS(5560),
    [aux_sym_preproc_elif_token1] = ACTIONS(5560),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4004] = {
    [sym_type_argument_list] = STATE(3607),
    [sym_preproc_region] = STATE(4004),
    [sym_preproc_endregion] = STATE(4004),
    [sym_preproc_line] = STATE(4004),
    [sym_preproc_pragma] = STATE(4004),
    [sym_preproc_nullable] = STATE(4004),
    [sym_preproc_error] = STATE(4004),
    [sym_preproc_warning] = STATE(4004),
    [sym_preproc_define] = STATE(4004),
    [sym_preproc_undef] = STATE(4004),
    [anon_sym_SEMI] = ACTIONS(4140),
    [anon_sym_LBRACK] = ACTIONS(4140),
    [anon_sym_COLON] = ACTIONS(4138),
    [anon_sym_COMMA] = ACTIONS(4140),
    [anon_sym_RBRACK] = ACTIONS(4140),
    [anon_sym_LPAREN] = ACTIONS(4140),
    [anon_sym_RPAREN] = ACTIONS(4140),
    [anon_sym_LBRACE] = ACTIONS(4140),
    [anon_sym_RBRACE] = ACTIONS(4140),
    [anon_sym_LT] = ACTIONS(5281),
    [anon_sym_GT] = ACTIONS(4138),
    [anon_sym_in] = ACTIONS(4138),
    [anon_sym_QMARK] = ACTIONS(4138),
    [anon_sym_BANG] = ACTIONS(4138),
    [anon_sym_PLUS_PLUS] = ACTIONS(4140),
    [anon_sym_DASH_DASH] = ACTIONS(4140),
    [anon_sym_PLUS] = ACTIONS(4138),
    [anon_sym_DASH] = ACTIONS(4138),
    [anon_sym_STAR] = ACTIONS(4140),
    [anon_sym_SLASH] = ACTIONS(4138),
    [anon_sym_PERCENT] = ACTIONS(4140),
    [anon_sym_CARET] = ACTIONS(4140),
    [anon_sym_PIPE] = ACTIONS(4138),
    [anon_sym_AMP] = ACTIONS(4138),
    [anon_sym_LT_LT] = ACTIONS(4140),
    [anon_sym_GT_GT] = ACTIONS(4138),
    [anon_sym_GT_GT_GT] = ACTIONS(4140),
    [anon_sym_EQ_EQ] = ACTIONS(4140),
    [anon_sym_BANG_EQ] = ACTIONS(4140),
    [anon_sym_GT_EQ] = ACTIONS(4140),
    [anon_sym_LT_EQ] = ACTIONS(4140),
    [anon_sym_DOT] = ACTIONS(4138),
    [anon_sym_EQ_GT] = ACTIONS(4140),
    [anon_sym_COLON_COLON] = ACTIONS(5903),
    [anon_sym_switch] = ACTIONS(4140),
    [anon_sym_DOT_DOT] = ACTIONS(4140),
    [anon_sym_AMP_AMP] = ACTIONS(4140),
    [anon_sym_PIPE_PIPE] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK] = ACTIONS(4140),
    [anon_sym_into] = ACTIONS(4140),
    [anon_sym_on] = ACTIONS(4140),
    [anon_sym_equals] = ACTIONS(4140),
    [anon_sym_by] = ACTIONS(4140),
    [anon_sym_as] = ACTIONS(4140),
    [anon_sym_is] = ACTIONS(4140),
    [anon_sym_DASH_GT] = ACTIONS(4140),
    [anon_sym_with] = ACTIONS(4140),
    [aux_sym_preproc_if_token3] = ACTIONS(4140),
    [aux_sym_preproc_else_token1] = ACTIONS(4140),
    [aux_sym_preproc_elif_token1] = ACTIONS(4140),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4005] = {
    [sym_preproc_region] = STATE(4005),
    [sym_preproc_endregion] = STATE(4005),
    [sym_preproc_line] = STATE(4005),
    [sym_preproc_pragma] = STATE(4005),
    [sym_preproc_nullable] = STATE(4005),
    [sym_preproc_error] = STATE(4005),
    [sym_preproc_warning] = STATE(4005),
    [sym_preproc_define] = STATE(4005),
    [sym_preproc_undef] = STATE(4005),
    [anon_sym_SEMI] = ACTIONS(5572),
    [anon_sym_LBRACK] = ACTIONS(5572),
    [anon_sym_COLON] = ACTIONS(5572),
    [anon_sym_COMMA] = ACTIONS(5572),
    [anon_sym_RBRACK] = ACTIONS(5572),
    [anon_sym_LPAREN] = ACTIONS(5572),
    [anon_sym_RPAREN] = ACTIONS(5572),
    [anon_sym_RBRACE] = ACTIONS(5572),
    [anon_sym_LT] = ACTIONS(5574),
    [anon_sym_GT] = ACTIONS(5574),
    [anon_sym_in] = ACTIONS(5574),
    [anon_sym_QMARK] = ACTIONS(5574),
    [anon_sym_BANG] = ACTIONS(5574),
    [anon_sym_PLUS_PLUS] = ACTIONS(5572),
    [anon_sym_DASH_DASH] = ACTIONS(5572),
    [anon_sym_PLUS] = ACTIONS(5574),
    [anon_sym_DASH] = ACTIONS(5574),
    [anon_sym_STAR] = ACTIONS(5572),
    [anon_sym_SLASH] = ACTIONS(5574),
    [anon_sym_PERCENT] = ACTIONS(5572),
    [anon_sym_CARET] = ACTIONS(5572),
    [anon_sym_PIPE] = ACTIONS(5574),
    [anon_sym_AMP] = ACTIONS(5574),
    [anon_sym_LT_LT] = ACTIONS(5572),
    [anon_sym_GT_GT] = ACTIONS(5574),
    [anon_sym_GT_GT_GT] = ACTIONS(5572),
    [anon_sym_EQ_EQ] = ACTIONS(5572),
    [anon_sym_BANG_EQ] = ACTIONS(5572),
    [anon_sym_GT_EQ] = ACTIONS(5572),
    [anon_sym_LT_EQ] = ACTIONS(5572),
    [anon_sym_DOT] = ACTIONS(5574),
    [anon_sym_EQ_GT] = ACTIONS(5572),
    [anon_sym_switch] = ACTIONS(5572),
    [anon_sym_when] = ACTIONS(5572),
    [anon_sym_DOT_DOT] = ACTIONS(5572),
    [anon_sym_and] = ACTIONS(5572),
    [anon_sym_or] = ACTIONS(5572),
    [anon_sym_AMP_AMP] = ACTIONS(5572),
    [anon_sym_PIPE_PIPE] = ACTIONS(5572),
    [anon_sym_QMARK_QMARK] = ACTIONS(5572),
    [anon_sym_into] = ACTIONS(5572),
    [anon_sym_on] = ACTIONS(5572),
    [anon_sym_equals] = ACTIONS(5572),
    [anon_sym_by] = ACTIONS(5572),
    [anon_sym_as] = ACTIONS(5572),
    [anon_sym_is] = ACTIONS(5572),
    [anon_sym_DASH_GT] = ACTIONS(5572),
    [anon_sym_with] = ACTIONS(5572),
    [aux_sym_preproc_if_token3] = ACTIONS(5572),
    [aux_sym_preproc_else_token1] = ACTIONS(5572),
    [aux_sym_preproc_elif_token1] = ACTIONS(5572),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4006] = {
    [sym_preproc_region] = STATE(4006),
    [sym_preproc_endregion] = STATE(4006),
    [sym_preproc_line] = STATE(4006),
    [sym_preproc_pragma] = STATE(4006),
    [sym_preproc_nullable] = STATE(4006),
    [sym_preproc_error] = STATE(4006),
    [sym_preproc_warning] = STATE(4006),
    [sym_preproc_define] = STATE(4006),
    [sym_preproc_undef] = STATE(4006),
    [anon_sym_SEMI] = ACTIONS(5428),
    [anon_sym_LBRACK] = ACTIONS(5428),
    [anon_sym_COLON] = ACTIONS(5428),
    [anon_sym_COMMA] = ACTIONS(5428),
    [anon_sym_RBRACK] = ACTIONS(5428),
    [anon_sym_LPAREN] = ACTIONS(5428),
    [anon_sym_RPAREN] = ACTIONS(5428),
    [anon_sym_RBRACE] = ACTIONS(5428),
    [anon_sym_LT] = ACTIONS(5430),
    [anon_sym_GT] = ACTIONS(5430),
    [anon_sym_in] = ACTIONS(5430),
    [anon_sym_QMARK] = ACTIONS(5430),
    [anon_sym_BANG] = ACTIONS(5430),
    [anon_sym_PLUS_PLUS] = ACTIONS(5428),
    [anon_sym_DASH_DASH] = ACTIONS(5428),
    [anon_sym_PLUS] = ACTIONS(5430),
    [anon_sym_DASH] = ACTIONS(5430),
    [anon_sym_STAR] = ACTIONS(5428),
    [anon_sym_SLASH] = ACTIONS(5430),
    [anon_sym_PERCENT] = ACTIONS(5428),
    [anon_sym_CARET] = ACTIONS(5428),
    [anon_sym_PIPE] = ACTIONS(5430),
    [anon_sym_AMP] = ACTIONS(5430),
    [anon_sym_LT_LT] = ACTIONS(5428),
    [anon_sym_GT_GT] = ACTIONS(5430),
    [anon_sym_GT_GT_GT] = ACTIONS(5428),
    [anon_sym_EQ_EQ] = ACTIONS(5428),
    [anon_sym_BANG_EQ] = ACTIONS(5428),
    [anon_sym_GT_EQ] = ACTIONS(5428),
    [anon_sym_LT_EQ] = ACTIONS(5428),
    [anon_sym_DOT] = ACTIONS(5430),
    [anon_sym_EQ_GT] = ACTIONS(5428),
    [anon_sym_switch] = ACTIONS(5428),
    [anon_sym_when] = ACTIONS(5428),
    [anon_sym_DOT_DOT] = ACTIONS(5428),
    [anon_sym_and] = ACTIONS(5428),
    [anon_sym_or] = ACTIONS(5428),
    [anon_sym_AMP_AMP] = ACTIONS(5428),
    [anon_sym_PIPE_PIPE] = ACTIONS(5428),
    [anon_sym_QMARK_QMARK] = ACTIONS(5428),
    [anon_sym_into] = ACTIONS(5428),
    [anon_sym_on] = ACTIONS(5428),
    [anon_sym_equals] = ACTIONS(5428),
    [anon_sym_by] = ACTIONS(5428),
    [anon_sym_as] = ACTIONS(5428),
    [anon_sym_is] = ACTIONS(5428),
    [anon_sym_DASH_GT] = ACTIONS(5428),
    [anon_sym_with] = ACTIONS(5428),
    [aux_sym_preproc_if_token3] = ACTIONS(5428),
    [aux_sym_preproc_else_token1] = ACTIONS(5428),
    [aux_sym_preproc_elif_token1] = ACTIONS(5428),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4007] = {
    [sym_preproc_region] = STATE(4007),
    [sym_preproc_endregion] = STATE(4007),
    [sym_preproc_line] = STATE(4007),
    [sym_preproc_pragma] = STATE(4007),
    [sym_preproc_nullable] = STATE(4007),
    [sym_preproc_error] = STATE(4007),
    [sym_preproc_warning] = STATE(4007),
    [sym_preproc_define] = STATE(4007),
    [sym_preproc_undef] = STATE(4007),
    [anon_sym_SEMI] = ACTIONS(4128),
    [anon_sym_LBRACK] = ACTIONS(4128),
    [anon_sym_COLON] = ACTIONS(4128),
    [anon_sym_COMMA] = ACTIONS(4128),
    [anon_sym_RBRACK] = ACTIONS(4128),
    [anon_sym_LPAREN] = ACTIONS(4128),
    [anon_sym_RPAREN] = ACTIONS(4128),
    [anon_sym_LBRACE] = ACTIONS(4128),
    [anon_sym_RBRACE] = ACTIONS(4128),
    [anon_sym_LT] = ACTIONS(4126),
    [anon_sym_GT] = ACTIONS(4126),
    [anon_sym_in] = ACTIONS(4128),
    [anon_sym_QMARK] = ACTIONS(4126),
    [anon_sym_BANG] = ACTIONS(4126),
    [anon_sym_PLUS_PLUS] = ACTIONS(4128),
    [anon_sym_DASH_DASH] = ACTIONS(4128),
    [anon_sym_PLUS] = ACTIONS(4126),
    [anon_sym_DASH] = ACTIONS(4126),
    [anon_sym_STAR] = ACTIONS(4128),
    [anon_sym_SLASH] = ACTIONS(4126),
    [anon_sym_PERCENT] = ACTIONS(4128),
    [anon_sym_CARET] = ACTIONS(4128),
    [anon_sym_PIPE] = ACTIONS(4126),
    [anon_sym_AMP] = ACTIONS(4126),
    [anon_sym_LT_LT] = ACTIONS(4128),
    [anon_sym_GT_GT] = ACTIONS(4126),
    [anon_sym_GT_GT_GT] = ACTIONS(4128),
    [anon_sym_EQ_EQ] = ACTIONS(4128),
    [anon_sym_BANG_EQ] = ACTIONS(4128),
    [anon_sym_GT_EQ] = ACTIONS(4128),
    [anon_sym_LT_EQ] = ACTIONS(4128),
    [anon_sym_DOT] = ACTIONS(4126),
    [anon_sym_EQ_GT] = ACTIONS(4128),
    [anon_sym_switch] = ACTIONS(4128),
    [anon_sym_when] = ACTIONS(4128),
    [anon_sym_DOT_DOT] = ACTIONS(4128),
    [anon_sym_and] = ACTIONS(4128),
    [anon_sym_or] = ACTIONS(4128),
    [anon_sym_AMP_AMP] = ACTIONS(4128),
    [anon_sym_PIPE_PIPE] = ACTIONS(4128),
    [anon_sym_QMARK_QMARK] = ACTIONS(4128),
    [anon_sym_on] = ACTIONS(4128),
    [anon_sym_equals] = ACTIONS(4128),
    [anon_sym_by] = ACTIONS(4128),
    [anon_sym_as] = ACTIONS(4128),
    [anon_sym_is] = ACTIONS(4128),
    [anon_sym_DASH_GT] = ACTIONS(4128),
    [anon_sym_with] = ACTIONS(4128),
    [aux_sym_preproc_if_token3] = ACTIONS(4128),
    [aux_sym_preproc_else_token1] = ACTIONS(4128),
    [aux_sym_preproc_elif_token1] = ACTIONS(4128),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4008] = {
    [sym_preproc_region] = STATE(4008),
    [sym_preproc_endregion] = STATE(4008),
    [sym_preproc_line] = STATE(4008),
    [sym_preproc_pragma] = STATE(4008),
    [sym_preproc_nullable] = STATE(4008),
    [sym_preproc_error] = STATE(4008),
    [sym_preproc_warning] = STATE(4008),
    [sym_preproc_define] = STATE(4008),
    [sym_preproc_undef] = STATE(4008),
    [anon_sym_SEMI] = ACTIONS(5452),
    [anon_sym_LBRACK] = ACTIONS(5452),
    [anon_sym_COLON] = ACTIONS(5452),
    [anon_sym_COMMA] = ACTIONS(5452),
    [anon_sym_RBRACK] = ACTIONS(5452),
    [anon_sym_LPAREN] = ACTIONS(5452),
    [anon_sym_RPAREN] = ACTIONS(5452),
    [anon_sym_RBRACE] = ACTIONS(5452),
    [anon_sym_LT] = ACTIONS(5454),
    [anon_sym_GT] = ACTIONS(5454),
    [anon_sym_in] = ACTIONS(5454),
    [anon_sym_QMARK] = ACTIONS(5454),
    [anon_sym_BANG] = ACTIONS(5454),
    [anon_sym_PLUS_PLUS] = ACTIONS(5452),
    [anon_sym_DASH_DASH] = ACTIONS(5452),
    [anon_sym_PLUS] = ACTIONS(5454),
    [anon_sym_DASH] = ACTIONS(5454),
    [anon_sym_STAR] = ACTIONS(5452),
    [anon_sym_SLASH] = ACTIONS(5454),
    [anon_sym_PERCENT] = ACTIONS(5452),
    [anon_sym_CARET] = ACTIONS(5452),
    [anon_sym_PIPE] = ACTIONS(5454),
    [anon_sym_AMP] = ACTIONS(5454),
    [anon_sym_LT_LT] = ACTIONS(5452),
    [anon_sym_GT_GT] = ACTIONS(5454),
    [anon_sym_GT_GT_GT] = ACTIONS(5452),
    [anon_sym_EQ_EQ] = ACTIONS(5452),
    [anon_sym_BANG_EQ] = ACTIONS(5452),
    [anon_sym_GT_EQ] = ACTIONS(5452),
    [anon_sym_LT_EQ] = ACTIONS(5452),
    [anon_sym_DOT] = ACTIONS(5454),
    [anon_sym_EQ_GT] = ACTIONS(5452),
    [anon_sym_switch] = ACTIONS(5452),
    [anon_sym_when] = ACTIONS(5452),
    [anon_sym_DOT_DOT] = ACTIONS(5452),
    [anon_sym_and] = ACTIONS(5452),
    [anon_sym_or] = ACTIONS(5452),
    [anon_sym_AMP_AMP] = ACTIONS(5452),
    [anon_sym_PIPE_PIPE] = ACTIONS(5452),
    [anon_sym_QMARK_QMARK] = ACTIONS(5452),
    [anon_sym_into] = ACTIONS(5452),
    [anon_sym_on] = ACTIONS(5452),
    [anon_sym_equals] = ACTIONS(5452),
    [anon_sym_by] = ACTIONS(5452),
    [anon_sym_as] = ACTIONS(5452),
    [anon_sym_is] = ACTIONS(5452),
    [anon_sym_DASH_GT] = ACTIONS(5452),
    [anon_sym_with] = ACTIONS(5452),
    [aux_sym_preproc_if_token3] = ACTIONS(5452),
    [aux_sym_preproc_else_token1] = ACTIONS(5452),
    [aux_sym_preproc_elif_token1] = ACTIONS(5452),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4009] = {
    [sym_preproc_region] = STATE(4009),
    [sym_preproc_endregion] = STATE(4009),
    [sym_preproc_line] = STATE(4009),
    [sym_preproc_pragma] = STATE(4009),
    [sym_preproc_nullable] = STATE(4009),
    [sym_preproc_error] = STATE(4009),
    [sym_preproc_warning] = STATE(4009),
    [sym_preproc_define] = STATE(4009),
    [sym_preproc_undef] = STATE(4009),
    [anon_sym_SEMI] = ACTIONS(5466),
    [anon_sym_LBRACK] = ACTIONS(5466),
    [anon_sym_COLON] = ACTIONS(5466),
    [anon_sym_COMMA] = ACTIONS(5466),
    [anon_sym_RBRACK] = ACTIONS(5466),
    [anon_sym_LPAREN] = ACTIONS(5466),
    [anon_sym_RPAREN] = ACTIONS(5466),
    [anon_sym_RBRACE] = ACTIONS(5466),
    [anon_sym_LT] = ACTIONS(5468),
    [anon_sym_GT] = ACTIONS(5468),
    [anon_sym_in] = ACTIONS(5468),
    [anon_sym_QMARK] = ACTIONS(5468),
    [anon_sym_BANG] = ACTIONS(5468),
    [anon_sym_PLUS_PLUS] = ACTIONS(5466),
    [anon_sym_DASH_DASH] = ACTIONS(5466),
    [anon_sym_PLUS] = ACTIONS(5468),
    [anon_sym_DASH] = ACTIONS(5468),
    [anon_sym_STAR] = ACTIONS(5466),
    [anon_sym_SLASH] = ACTIONS(5468),
    [anon_sym_PERCENT] = ACTIONS(5466),
    [anon_sym_CARET] = ACTIONS(5466),
    [anon_sym_PIPE] = ACTIONS(5468),
    [anon_sym_AMP] = ACTIONS(5468),
    [anon_sym_LT_LT] = ACTIONS(5466),
    [anon_sym_GT_GT] = ACTIONS(5468),
    [anon_sym_GT_GT_GT] = ACTIONS(5466),
    [anon_sym_EQ_EQ] = ACTIONS(5466),
    [anon_sym_BANG_EQ] = ACTIONS(5466),
    [anon_sym_GT_EQ] = ACTIONS(5466),
    [anon_sym_LT_EQ] = ACTIONS(5466),
    [anon_sym_DOT] = ACTIONS(5468),
    [anon_sym_EQ_GT] = ACTIONS(5466),
    [anon_sym_switch] = ACTIONS(5466),
    [anon_sym_when] = ACTIONS(5466),
    [anon_sym_DOT_DOT] = ACTIONS(5466),
    [anon_sym_and] = ACTIONS(5466),
    [anon_sym_or] = ACTIONS(5466),
    [anon_sym_AMP_AMP] = ACTIONS(5466),
    [anon_sym_PIPE_PIPE] = ACTIONS(5466),
    [anon_sym_QMARK_QMARK] = ACTIONS(5466),
    [anon_sym_into] = ACTIONS(5466),
    [anon_sym_on] = ACTIONS(5466),
    [anon_sym_equals] = ACTIONS(5466),
    [anon_sym_by] = ACTIONS(5466),
    [anon_sym_as] = ACTIONS(5466),
    [anon_sym_is] = ACTIONS(5466),
    [anon_sym_DASH_GT] = ACTIONS(5466),
    [anon_sym_with] = ACTIONS(5466),
    [aux_sym_preproc_if_token3] = ACTIONS(5466),
    [aux_sym_preproc_else_token1] = ACTIONS(5466),
    [aux_sym_preproc_elif_token1] = ACTIONS(5466),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4010] = {
    [sym_preproc_region] = STATE(4010),
    [sym_preproc_endregion] = STATE(4010),
    [sym_preproc_line] = STATE(4010),
    [sym_preproc_pragma] = STATE(4010),
    [sym_preproc_nullable] = STATE(4010),
    [sym_preproc_error] = STATE(4010),
    [sym_preproc_warning] = STATE(4010),
    [sym_preproc_define] = STATE(4010),
    [sym_preproc_undef] = STATE(4010),
    [anon_sym_SEMI] = ACTIONS(4136),
    [anon_sym_LBRACK] = ACTIONS(4136),
    [anon_sym_COLON] = ACTIONS(4136),
    [anon_sym_COMMA] = ACTIONS(4136),
    [anon_sym_RBRACK] = ACTIONS(4136),
    [anon_sym_LPAREN] = ACTIONS(4136),
    [anon_sym_RPAREN] = ACTIONS(4136),
    [anon_sym_LBRACE] = ACTIONS(4136),
    [anon_sym_RBRACE] = ACTIONS(4136),
    [anon_sym_LT] = ACTIONS(4134),
    [anon_sym_GT] = ACTIONS(4134),
    [anon_sym_in] = ACTIONS(4136),
    [anon_sym_QMARK] = ACTIONS(4134),
    [anon_sym_BANG] = ACTIONS(4134),
    [anon_sym_PLUS_PLUS] = ACTIONS(4136),
    [anon_sym_DASH_DASH] = ACTIONS(4136),
    [anon_sym_PLUS] = ACTIONS(4134),
    [anon_sym_DASH] = ACTIONS(4134),
    [anon_sym_STAR] = ACTIONS(4136),
    [anon_sym_SLASH] = ACTIONS(4134),
    [anon_sym_PERCENT] = ACTIONS(4136),
    [anon_sym_CARET] = ACTIONS(4136),
    [anon_sym_PIPE] = ACTIONS(4134),
    [anon_sym_AMP] = ACTIONS(4134),
    [anon_sym_LT_LT] = ACTIONS(4136),
    [anon_sym_GT_GT] = ACTIONS(4134),
    [anon_sym_GT_GT_GT] = ACTIONS(4136),
    [anon_sym_EQ_EQ] = ACTIONS(4136),
    [anon_sym_BANG_EQ] = ACTIONS(4136),
    [anon_sym_GT_EQ] = ACTIONS(4136),
    [anon_sym_LT_EQ] = ACTIONS(4136),
    [anon_sym_DOT] = ACTIONS(4134),
    [anon_sym_EQ_GT] = ACTIONS(4136),
    [anon_sym_switch] = ACTIONS(4136),
    [anon_sym_when] = ACTIONS(4136),
    [anon_sym_DOT_DOT] = ACTIONS(4136),
    [anon_sym_and] = ACTIONS(4136),
    [anon_sym_or] = ACTIONS(4136),
    [anon_sym_AMP_AMP] = ACTIONS(4136),
    [anon_sym_PIPE_PIPE] = ACTIONS(4136),
    [anon_sym_QMARK_QMARK] = ACTIONS(4136),
    [anon_sym_on] = ACTIONS(4136),
    [anon_sym_equals] = ACTIONS(4136),
    [anon_sym_by] = ACTIONS(4136),
    [anon_sym_as] = ACTIONS(4136),
    [anon_sym_is] = ACTIONS(4136),
    [anon_sym_DASH_GT] = ACTIONS(4136),
    [anon_sym_with] = ACTIONS(4136),
    [aux_sym_preproc_if_token3] = ACTIONS(4136),
    [aux_sym_preproc_else_token1] = ACTIONS(4136),
    [aux_sym_preproc_elif_token1] = ACTIONS(4136),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4011] = {
    [sym_preproc_region] = STATE(4011),
    [sym_preproc_endregion] = STATE(4011),
    [sym_preproc_line] = STATE(4011),
    [sym_preproc_pragma] = STATE(4011),
    [sym_preproc_nullable] = STATE(4011),
    [sym_preproc_error] = STATE(4011),
    [sym_preproc_warning] = STATE(4011),
    [sym_preproc_define] = STATE(4011),
    [sym_preproc_undef] = STATE(4011),
    [anon_sym_SEMI] = ACTIONS(5486),
    [anon_sym_LBRACK] = ACTIONS(5486),
    [anon_sym_COLON] = ACTIONS(5486),
    [anon_sym_COMMA] = ACTIONS(5486),
    [anon_sym_RBRACK] = ACTIONS(5486),
    [anon_sym_LPAREN] = ACTIONS(5486),
    [anon_sym_RPAREN] = ACTIONS(5486),
    [anon_sym_RBRACE] = ACTIONS(5486),
    [anon_sym_LT] = ACTIONS(5488),
    [anon_sym_GT] = ACTIONS(5488),
    [anon_sym_in] = ACTIONS(5488),
    [anon_sym_QMARK] = ACTIONS(5488),
    [anon_sym_BANG] = ACTIONS(5488),
    [anon_sym_PLUS_PLUS] = ACTIONS(5486),
    [anon_sym_DASH_DASH] = ACTIONS(5486),
    [anon_sym_PLUS] = ACTIONS(5488),
    [anon_sym_DASH] = ACTIONS(5488),
    [anon_sym_STAR] = ACTIONS(5486),
    [anon_sym_SLASH] = ACTIONS(5488),
    [anon_sym_PERCENT] = ACTIONS(5486),
    [anon_sym_CARET] = ACTIONS(5486),
    [anon_sym_PIPE] = ACTIONS(5488),
    [anon_sym_AMP] = ACTIONS(5488),
    [anon_sym_LT_LT] = ACTIONS(5486),
    [anon_sym_GT_GT] = ACTIONS(5488),
    [anon_sym_GT_GT_GT] = ACTIONS(5486),
    [anon_sym_EQ_EQ] = ACTIONS(5486),
    [anon_sym_BANG_EQ] = ACTIONS(5486),
    [anon_sym_GT_EQ] = ACTIONS(5486),
    [anon_sym_LT_EQ] = ACTIONS(5486),
    [anon_sym_DOT] = ACTIONS(5488),
    [anon_sym_EQ_GT] = ACTIONS(5486),
    [anon_sym_switch] = ACTIONS(5486),
    [anon_sym_when] = ACTIONS(5486),
    [anon_sym_DOT_DOT] = ACTIONS(5486),
    [anon_sym_and] = ACTIONS(5486),
    [anon_sym_or] = ACTIONS(5486),
    [anon_sym_AMP_AMP] = ACTIONS(5486),
    [anon_sym_PIPE_PIPE] = ACTIONS(5486),
    [anon_sym_QMARK_QMARK] = ACTIONS(5486),
    [anon_sym_into] = ACTIONS(5486),
    [anon_sym_on] = ACTIONS(5486),
    [anon_sym_equals] = ACTIONS(5486),
    [anon_sym_by] = ACTIONS(5486),
    [anon_sym_as] = ACTIONS(5486),
    [anon_sym_is] = ACTIONS(5486),
    [anon_sym_DASH_GT] = ACTIONS(5486),
    [anon_sym_with] = ACTIONS(5486),
    [aux_sym_preproc_if_token3] = ACTIONS(5486),
    [aux_sym_preproc_else_token1] = ACTIONS(5486),
    [aux_sym_preproc_elif_token1] = ACTIONS(5486),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4012] = {
    [sym_preproc_region] = STATE(4012),
    [sym_preproc_endregion] = STATE(4012),
    [sym_preproc_line] = STATE(4012),
    [sym_preproc_pragma] = STATE(4012),
    [sym_preproc_nullable] = STATE(4012),
    [sym_preproc_error] = STATE(4012),
    [sym_preproc_warning] = STATE(4012),
    [sym_preproc_define] = STATE(4012),
    [sym_preproc_undef] = STATE(4012),
    [anon_sym_SEMI] = ACTIONS(5494),
    [anon_sym_LBRACK] = ACTIONS(5494),
    [anon_sym_COLON] = ACTIONS(5494),
    [anon_sym_COMMA] = ACTIONS(5494),
    [anon_sym_RBRACK] = ACTIONS(5494),
    [anon_sym_LPAREN] = ACTIONS(5494),
    [anon_sym_RPAREN] = ACTIONS(5494),
    [anon_sym_RBRACE] = ACTIONS(5494),
    [anon_sym_LT] = ACTIONS(5496),
    [anon_sym_GT] = ACTIONS(5496),
    [anon_sym_in] = ACTIONS(5496),
    [anon_sym_QMARK] = ACTIONS(5496),
    [anon_sym_BANG] = ACTIONS(5496),
    [anon_sym_PLUS_PLUS] = ACTIONS(5494),
    [anon_sym_DASH_DASH] = ACTIONS(5494),
    [anon_sym_PLUS] = ACTIONS(5496),
    [anon_sym_DASH] = ACTIONS(5496),
    [anon_sym_STAR] = ACTIONS(5494),
    [anon_sym_SLASH] = ACTIONS(5496),
    [anon_sym_PERCENT] = ACTIONS(5494),
    [anon_sym_CARET] = ACTIONS(5494),
    [anon_sym_PIPE] = ACTIONS(5496),
    [anon_sym_AMP] = ACTIONS(5496),
    [anon_sym_LT_LT] = ACTIONS(5494),
    [anon_sym_GT_GT] = ACTIONS(5496),
    [anon_sym_GT_GT_GT] = ACTIONS(5494),
    [anon_sym_EQ_EQ] = ACTIONS(5494),
    [anon_sym_BANG_EQ] = ACTIONS(5494),
    [anon_sym_GT_EQ] = ACTIONS(5494),
    [anon_sym_LT_EQ] = ACTIONS(5494),
    [anon_sym_DOT] = ACTIONS(5496),
    [anon_sym_EQ_GT] = ACTIONS(5494),
    [anon_sym_switch] = ACTIONS(5494),
    [anon_sym_when] = ACTIONS(5494),
    [anon_sym_DOT_DOT] = ACTIONS(5494),
    [anon_sym_and] = ACTIONS(5494),
    [anon_sym_or] = ACTIONS(5494),
    [anon_sym_AMP_AMP] = ACTIONS(5494),
    [anon_sym_PIPE_PIPE] = ACTIONS(5494),
    [anon_sym_QMARK_QMARK] = ACTIONS(5494),
    [anon_sym_into] = ACTIONS(5494),
    [anon_sym_on] = ACTIONS(5494),
    [anon_sym_equals] = ACTIONS(5494),
    [anon_sym_by] = ACTIONS(5494),
    [anon_sym_as] = ACTIONS(5494),
    [anon_sym_is] = ACTIONS(5494),
    [anon_sym_DASH_GT] = ACTIONS(5494),
    [anon_sym_with] = ACTIONS(5494),
    [aux_sym_preproc_if_token3] = ACTIONS(5494),
    [aux_sym_preproc_else_token1] = ACTIONS(5494),
    [aux_sym_preproc_elif_token1] = ACTIONS(5494),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4013] = {
    [sym_preproc_region] = STATE(4013),
    [sym_preproc_endregion] = STATE(4013),
    [sym_preproc_line] = STATE(4013),
    [sym_preproc_pragma] = STATE(4013),
    [sym_preproc_nullable] = STATE(4013),
    [sym_preproc_error] = STATE(4013),
    [sym_preproc_warning] = STATE(4013),
    [sym_preproc_define] = STATE(4013),
    [sym_preproc_undef] = STATE(4013),
    [anon_sym_SEMI] = ACTIONS(5502),
    [anon_sym_LBRACK] = ACTIONS(5502),
    [anon_sym_COLON] = ACTIONS(5502),
    [anon_sym_COMMA] = ACTIONS(5502),
    [anon_sym_RBRACK] = ACTIONS(5502),
    [anon_sym_LPAREN] = ACTIONS(5502),
    [anon_sym_RPAREN] = ACTIONS(5502),
    [anon_sym_RBRACE] = ACTIONS(5502),
    [anon_sym_LT] = ACTIONS(5504),
    [anon_sym_GT] = ACTIONS(5504),
    [anon_sym_in] = ACTIONS(5504),
    [anon_sym_QMARK] = ACTIONS(5504),
    [anon_sym_BANG] = ACTIONS(5504),
    [anon_sym_PLUS_PLUS] = ACTIONS(5502),
    [anon_sym_DASH_DASH] = ACTIONS(5502),
    [anon_sym_PLUS] = ACTIONS(5504),
    [anon_sym_DASH] = ACTIONS(5504),
    [anon_sym_STAR] = ACTIONS(5502),
    [anon_sym_SLASH] = ACTIONS(5504),
    [anon_sym_PERCENT] = ACTIONS(5502),
    [anon_sym_CARET] = ACTIONS(5502),
    [anon_sym_PIPE] = ACTIONS(5504),
    [anon_sym_AMP] = ACTIONS(5504),
    [anon_sym_LT_LT] = ACTIONS(5502),
    [anon_sym_GT_GT] = ACTIONS(5504),
    [anon_sym_GT_GT_GT] = ACTIONS(5502),
    [anon_sym_EQ_EQ] = ACTIONS(5502),
    [anon_sym_BANG_EQ] = ACTIONS(5502),
    [anon_sym_GT_EQ] = ACTIONS(5502),
    [anon_sym_LT_EQ] = ACTIONS(5502),
    [anon_sym_DOT] = ACTIONS(5504),
    [anon_sym_EQ_GT] = ACTIONS(5502),
    [anon_sym_switch] = ACTIONS(5502),
    [anon_sym_when] = ACTIONS(5502),
    [anon_sym_DOT_DOT] = ACTIONS(5502),
    [anon_sym_and] = ACTIONS(5502),
    [anon_sym_or] = ACTIONS(5502),
    [anon_sym_AMP_AMP] = ACTIONS(5502),
    [anon_sym_PIPE_PIPE] = ACTIONS(5502),
    [anon_sym_QMARK_QMARK] = ACTIONS(5502),
    [anon_sym_into] = ACTIONS(5502),
    [anon_sym_on] = ACTIONS(5502),
    [anon_sym_equals] = ACTIONS(5502),
    [anon_sym_by] = ACTIONS(5502),
    [anon_sym_as] = ACTIONS(5502),
    [anon_sym_is] = ACTIONS(5502),
    [anon_sym_DASH_GT] = ACTIONS(5502),
    [anon_sym_with] = ACTIONS(5502),
    [aux_sym_preproc_if_token3] = ACTIONS(5502),
    [aux_sym_preproc_else_token1] = ACTIONS(5502),
    [aux_sym_preproc_elif_token1] = ACTIONS(5502),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4014] = {
    [sym_preproc_region] = STATE(4014),
    [sym_preproc_endregion] = STATE(4014),
    [sym_preproc_line] = STATE(4014),
    [sym_preproc_pragma] = STATE(4014),
    [sym_preproc_nullable] = STATE(4014),
    [sym_preproc_error] = STATE(4014),
    [sym_preproc_warning] = STATE(4014),
    [sym_preproc_define] = STATE(4014),
    [sym_preproc_undef] = STATE(4014),
    [anon_sym_SEMI] = ACTIONS(5534),
    [anon_sym_LBRACK] = ACTIONS(5534),
    [anon_sym_COLON] = ACTIONS(5534),
    [anon_sym_COMMA] = ACTIONS(5534),
    [anon_sym_RBRACK] = ACTIONS(5534),
    [anon_sym_LPAREN] = ACTIONS(5534),
    [anon_sym_RPAREN] = ACTIONS(5534),
    [anon_sym_RBRACE] = ACTIONS(5534),
    [anon_sym_LT] = ACTIONS(5536),
    [anon_sym_GT] = ACTIONS(5536),
    [anon_sym_in] = ACTIONS(5536),
    [anon_sym_QMARK] = ACTIONS(5536),
    [anon_sym_BANG] = ACTIONS(5536),
    [anon_sym_PLUS_PLUS] = ACTIONS(5534),
    [anon_sym_DASH_DASH] = ACTIONS(5534),
    [anon_sym_PLUS] = ACTIONS(5536),
    [anon_sym_DASH] = ACTIONS(5536),
    [anon_sym_STAR] = ACTIONS(5534),
    [anon_sym_SLASH] = ACTIONS(5536),
    [anon_sym_PERCENT] = ACTIONS(5534),
    [anon_sym_CARET] = ACTIONS(5534),
    [anon_sym_PIPE] = ACTIONS(5536),
    [anon_sym_AMP] = ACTIONS(5536),
    [anon_sym_LT_LT] = ACTIONS(5534),
    [anon_sym_GT_GT] = ACTIONS(5536),
    [anon_sym_GT_GT_GT] = ACTIONS(5534),
    [anon_sym_EQ_EQ] = ACTIONS(5534),
    [anon_sym_BANG_EQ] = ACTIONS(5534),
    [anon_sym_GT_EQ] = ACTIONS(5534),
    [anon_sym_LT_EQ] = ACTIONS(5534),
    [anon_sym_DOT] = ACTIONS(5536),
    [anon_sym_EQ_GT] = ACTIONS(5534),
    [anon_sym_switch] = ACTIONS(5534),
    [anon_sym_when] = ACTIONS(5534),
    [anon_sym_DOT_DOT] = ACTIONS(5534),
    [anon_sym_and] = ACTIONS(5534),
    [anon_sym_or] = ACTIONS(5534),
    [anon_sym_AMP_AMP] = ACTIONS(5534),
    [anon_sym_PIPE_PIPE] = ACTIONS(5534),
    [anon_sym_QMARK_QMARK] = ACTIONS(5534),
    [anon_sym_into] = ACTIONS(5534),
    [anon_sym_on] = ACTIONS(5534),
    [anon_sym_equals] = ACTIONS(5534),
    [anon_sym_by] = ACTIONS(5534),
    [anon_sym_as] = ACTIONS(5534),
    [anon_sym_is] = ACTIONS(5534),
    [anon_sym_DASH_GT] = ACTIONS(5534),
    [anon_sym_with] = ACTIONS(5534),
    [aux_sym_preproc_if_token3] = ACTIONS(5534),
    [aux_sym_preproc_else_token1] = ACTIONS(5534),
    [aux_sym_preproc_elif_token1] = ACTIONS(5534),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4015] = {
    [sym_preproc_region] = STATE(4015),
    [sym_preproc_endregion] = STATE(4015),
    [sym_preproc_line] = STATE(4015),
    [sym_preproc_pragma] = STATE(4015),
    [sym_preproc_nullable] = STATE(4015),
    [sym_preproc_error] = STATE(4015),
    [sym_preproc_warning] = STATE(4015),
    [sym_preproc_define] = STATE(4015),
    [sym_preproc_undef] = STATE(4015),
    [anon_sym_SEMI] = ACTIONS(5538),
    [anon_sym_LBRACK] = ACTIONS(5538),
    [anon_sym_COLON] = ACTIONS(5538),
    [anon_sym_COMMA] = ACTIONS(5538),
    [anon_sym_RBRACK] = ACTIONS(5538),
    [anon_sym_LPAREN] = ACTIONS(5538),
    [anon_sym_RPAREN] = ACTIONS(5538),
    [anon_sym_RBRACE] = ACTIONS(5538),
    [anon_sym_LT] = ACTIONS(5540),
    [anon_sym_GT] = ACTIONS(5540),
    [anon_sym_in] = ACTIONS(5540),
    [anon_sym_QMARK] = ACTIONS(5540),
    [anon_sym_BANG] = ACTIONS(5540),
    [anon_sym_PLUS_PLUS] = ACTIONS(5538),
    [anon_sym_DASH_DASH] = ACTIONS(5538),
    [anon_sym_PLUS] = ACTIONS(5540),
    [anon_sym_DASH] = ACTIONS(5540),
    [anon_sym_STAR] = ACTIONS(5538),
    [anon_sym_SLASH] = ACTIONS(5540),
    [anon_sym_PERCENT] = ACTIONS(5538),
    [anon_sym_CARET] = ACTIONS(5538),
    [anon_sym_PIPE] = ACTIONS(5540),
    [anon_sym_AMP] = ACTIONS(5540),
    [anon_sym_LT_LT] = ACTIONS(5538),
    [anon_sym_GT_GT] = ACTIONS(5540),
    [anon_sym_GT_GT_GT] = ACTIONS(5538),
    [anon_sym_EQ_EQ] = ACTIONS(5538),
    [anon_sym_BANG_EQ] = ACTIONS(5538),
    [anon_sym_GT_EQ] = ACTIONS(5538),
    [anon_sym_LT_EQ] = ACTIONS(5538),
    [anon_sym_DOT] = ACTIONS(5540),
    [anon_sym_EQ_GT] = ACTIONS(5538),
    [anon_sym_switch] = ACTIONS(5538),
    [anon_sym_when] = ACTIONS(5538),
    [anon_sym_DOT_DOT] = ACTIONS(5538),
    [anon_sym_and] = ACTIONS(5538),
    [anon_sym_or] = ACTIONS(5538),
    [anon_sym_AMP_AMP] = ACTIONS(5538),
    [anon_sym_PIPE_PIPE] = ACTIONS(5538),
    [anon_sym_QMARK_QMARK] = ACTIONS(5538),
    [anon_sym_into] = ACTIONS(5538),
    [anon_sym_on] = ACTIONS(5538),
    [anon_sym_equals] = ACTIONS(5538),
    [anon_sym_by] = ACTIONS(5538),
    [anon_sym_as] = ACTIONS(5538),
    [anon_sym_is] = ACTIONS(5538),
    [anon_sym_DASH_GT] = ACTIONS(5538),
    [anon_sym_with] = ACTIONS(5538),
    [aux_sym_preproc_if_token3] = ACTIONS(5538),
    [aux_sym_preproc_else_token1] = ACTIONS(5538),
    [aux_sym_preproc_elif_token1] = ACTIONS(5538),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4016] = {
    [sym_preproc_region] = STATE(4016),
    [sym_preproc_endregion] = STATE(4016),
    [sym_preproc_line] = STATE(4016),
    [sym_preproc_pragma] = STATE(4016),
    [sym_preproc_nullable] = STATE(4016),
    [sym_preproc_error] = STATE(4016),
    [sym_preproc_warning] = STATE(4016),
    [sym_preproc_define] = STATE(4016),
    [sym_preproc_undef] = STATE(4016),
    [anon_sym_SEMI] = ACTIONS(5580),
    [anon_sym_LBRACK] = ACTIONS(5580),
    [anon_sym_COLON] = ACTIONS(5580),
    [anon_sym_COMMA] = ACTIONS(5580),
    [anon_sym_RBRACK] = ACTIONS(5580),
    [anon_sym_LPAREN] = ACTIONS(5580),
    [anon_sym_RPAREN] = ACTIONS(5580),
    [anon_sym_RBRACE] = ACTIONS(5580),
    [anon_sym_LT] = ACTIONS(5582),
    [anon_sym_GT] = ACTIONS(5582),
    [anon_sym_in] = ACTIONS(5582),
    [anon_sym_QMARK] = ACTIONS(5582),
    [anon_sym_BANG] = ACTIONS(5582),
    [anon_sym_PLUS_PLUS] = ACTIONS(5580),
    [anon_sym_DASH_DASH] = ACTIONS(5580),
    [anon_sym_PLUS] = ACTIONS(5582),
    [anon_sym_DASH] = ACTIONS(5582),
    [anon_sym_STAR] = ACTIONS(5580),
    [anon_sym_SLASH] = ACTIONS(5582),
    [anon_sym_PERCENT] = ACTIONS(5580),
    [anon_sym_CARET] = ACTIONS(5580),
    [anon_sym_PIPE] = ACTIONS(5582),
    [anon_sym_AMP] = ACTIONS(5582),
    [anon_sym_LT_LT] = ACTIONS(5580),
    [anon_sym_GT_GT] = ACTIONS(5582),
    [anon_sym_GT_GT_GT] = ACTIONS(5580),
    [anon_sym_EQ_EQ] = ACTIONS(5580),
    [anon_sym_BANG_EQ] = ACTIONS(5580),
    [anon_sym_GT_EQ] = ACTIONS(5580),
    [anon_sym_LT_EQ] = ACTIONS(5580),
    [anon_sym_DOT] = ACTIONS(5582),
    [anon_sym_EQ_GT] = ACTIONS(5580),
    [anon_sym_switch] = ACTIONS(5580),
    [anon_sym_when] = ACTIONS(5580),
    [anon_sym_DOT_DOT] = ACTIONS(5580),
    [anon_sym_and] = ACTIONS(5580),
    [anon_sym_or] = ACTIONS(5580),
    [anon_sym_AMP_AMP] = ACTIONS(5580),
    [anon_sym_PIPE_PIPE] = ACTIONS(5580),
    [anon_sym_QMARK_QMARK] = ACTIONS(5580),
    [anon_sym_into] = ACTIONS(5580),
    [anon_sym_on] = ACTIONS(5580),
    [anon_sym_equals] = ACTIONS(5580),
    [anon_sym_by] = ACTIONS(5580),
    [anon_sym_as] = ACTIONS(5580),
    [anon_sym_is] = ACTIONS(5580),
    [anon_sym_DASH_GT] = ACTIONS(5580),
    [anon_sym_with] = ACTIONS(5580),
    [aux_sym_preproc_if_token3] = ACTIONS(5580),
    [aux_sym_preproc_else_token1] = ACTIONS(5580),
    [aux_sym_preproc_elif_token1] = ACTIONS(5580),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4017] = {
    [sym_preproc_region] = STATE(4017),
    [sym_preproc_endregion] = STATE(4017),
    [sym_preproc_line] = STATE(4017),
    [sym_preproc_pragma] = STATE(4017),
    [sym_preproc_nullable] = STATE(4017),
    [sym_preproc_error] = STATE(4017),
    [sym_preproc_warning] = STATE(4017),
    [sym_preproc_define] = STATE(4017),
    [sym_preproc_undef] = STATE(4017),
    [anon_sym_SEMI] = ACTIONS(5632),
    [anon_sym_LBRACK] = ACTIONS(5632),
    [anon_sym_COLON] = ACTIONS(5632),
    [anon_sym_COMMA] = ACTIONS(5632),
    [anon_sym_RBRACK] = ACTIONS(5632),
    [anon_sym_LPAREN] = ACTIONS(5632),
    [anon_sym_RPAREN] = ACTIONS(5632),
    [anon_sym_RBRACE] = ACTIONS(5632),
    [anon_sym_LT] = ACTIONS(5634),
    [anon_sym_GT] = ACTIONS(5634),
    [anon_sym_in] = ACTIONS(5634),
    [anon_sym_QMARK] = ACTIONS(5634),
    [anon_sym_BANG] = ACTIONS(5634),
    [anon_sym_PLUS_PLUS] = ACTIONS(5632),
    [anon_sym_DASH_DASH] = ACTIONS(5632),
    [anon_sym_PLUS] = ACTIONS(5634),
    [anon_sym_DASH] = ACTIONS(5634),
    [anon_sym_STAR] = ACTIONS(5632),
    [anon_sym_SLASH] = ACTIONS(5634),
    [anon_sym_PERCENT] = ACTIONS(5632),
    [anon_sym_CARET] = ACTIONS(5632),
    [anon_sym_PIPE] = ACTIONS(5634),
    [anon_sym_AMP] = ACTIONS(5634),
    [anon_sym_LT_LT] = ACTIONS(5632),
    [anon_sym_GT_GT] = ACTIONS(5634),
    [anon_sym_GT_GT_GT] = ACTIONS(5632),
    [anon_sym_EQ_EQ] = ACTIONS(5632),
    [anon_sym_BANG_EQ] = ACTIONS(5632),
    [anon_sym_GT_EQ] = ACTIONS(5632),
    [anon_sym_LT_EQ] = ACTIONS(5632),
    [anon_sym_DOT] = ACTIONS(5634),
    [anon_sym_EQ_GT] = ACTIONS(5632),
    [anon_sym_switch] = ACTIONS(5632),
    [anon_sym_when] = ACTIONS(5632),
    [anon_sym_DOT_DOT] = ACTIONS(5632),
    [anon_sym_and] = ACTIONS(5632),
    [anon_sym_or] = ACTIONS(5632),
    [anon_sym_AMP_AMP] = ACTIONS(5632),
    [anon_sym_PIPE_PIPE] = ACTIONS(5632),
    [anon_sym_QMARK_QMARK] = ACTIONS(5632),
    [anon_sym_into] = ACTIONS(5632),
    [anon_sym_on] = ACTIONS(5632),
    [anon_sym_equals] = ACTIONS(5632),
    [anon_sym_by] = ACTIONS(5632),
    [anon_sym_as] = ACTIONS(5632),
    [anon_sym_is] = ACTIONS(5632),
    [anon_sym_DASH_GT] = ACTIONS(5632),
    [anon_sym_with] = ACTIONS(5632),
    [aux_sym_preproc_if_token3] = ACTIONS(5632),
    [aux_sym_preproc_else_token1] = ACTIONS(5632),
    [aux_sym_preproc_elif_token1] = ACTIONS(5632),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4018] = {
    [sym_preproc_region] = STATE(4018),
    [sym_preproc_endregion] = STATE(4018),
    [sym_preproc_line] = STATE(4018),
    [sym_preproc_pragma] = STATE(4018),
    [sym_preproc_nullable] = STATE(4018),
    [sym_preproc_error] = STATE(4018),
    [sym_preproc_warning] = STATE(4018),
    [sym_preproc_define] = STATE(4018),
    [sym_preproc_undef] = STATE(4018),
    [anon_sym_SEMI] = ACTIONS(5652),
    [anon_sym_LBRACK] = ACTIONS(5652),
    [anon_sym_COLON] = ACTIONS(5652),
    [anon_sym_COMMA] = ACTIONS(5652),
    [anon_sym_RBRACK] = ACTIONS(5652),
    [anon_sym_LPAREN] = ACTIONS(5652),
    [anon_sym_RPAREN] = ACTIONS(5652),
    [anon_sym_RBRACE] = ACTIONS(5652),
    [anon_sym_LT] = ACTIONS(5654),
    [anon_sym_GT] = ACTIONS(5654),
    [anon_sym_in] = ACTIONS(5654),
    [anon_sym_QMARK] = ACTIONS(5654),
    [anon_sym_BANG] = ACTIONS(5654),
    [anon_sym_PLUS_PLUS] = ACTIONS(5652),
    [anon_sym_DASH_DASH] = ACTIONS(5652),
    [anon_sym_PLUS] = ACTIONS(5654),
    [anon_sym_DASH] = ACTIONS(5654),
    [anon_sym_STAR] = ACTIONS(5652),
    [anon_sym_SLASH] = ACTIONS(5654),
    [anon_sym_PERCENT] = ACTIONS(5652),
    [anon_sym_CARET] = ACTIONS(5652),
    [anon_sym_PIPE] = ACTIONS(5654),
    [anon_sym_AMP] = ACTIONS(5654),
    [anon_sym_LT_LT] = ACTIONS(5652),
    [anon_sym_GT_GT] = ACTIONS(5654),
    [anon_sym_GT_GT_GT] = ACTIONS(5652),
    [anon_sym_EQ_EQ] = ACTIONS(5652),
    [anon_sym_BANG_EQ] = ACTIONS(5652),
    [anon_sym_GT_EQ] = ACTIONS(5652),
    [anon_sym_LT_EQ] = ACTIONS(5652),
    [anon_sym_DOT] = ACTIONS(5654),
    [anon_sym_EQ_GT] = ACTIONS(5652),
    [anon_sym_switch] = ACTIONS(5652),
    [anon_sym_when] = ACTIONS(5652),
    [anon_sym_DOT_DOT] = ACTIONS(5652),
    [anon_sym_and] = ACTIONS(5652),
    [anon_sym_or] = ACTIONS(5652),
    [anon_sym_AMP_AMP] = ACTIONS(5652),
    [anon_sym_PIPE_PIPE] = ACTIONS(5652),
    [anon_sym_QMARK_QMARK] = ACTIONS(5652),
    [anon_sym_into] = ACTIONS(5652),
    [anon_sym_on] = ACTIONS(5652),
    [anon_sym_equals] = ACTIONS(5652),
    [anon_sym_by] = ACTIONS(5652),
    [anon_sym_as] = ACTIONS(5652),
    [anon_sym_is] = ACTIONS(5652),
    [anon_sym_DASH_GT] = ACTIONS(5652),
    [anon_sym_with] = ACTIONS(5652),
    [aux_sym_preproc_if_token3] = ACTIONS(5652),
    [aux_sym_preproc_else_token1] = ACTIONS(5652),
    [aux_sym_preproc_elif_token1] = ACTIONS(5652),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4019] = {
    [sym_preproc_region] = STATE(4019),
    [sym_preproc_endregion] = STATE(4019),
    [sym_preproc_line] = STATE(4019),
    [sym_preproc_pragma] = STATE(4019),
    [sym_preproc_nullable] = STATE(4019),
    [sym_preproc_error] = STATE(4019),
    [sym_preproc_warning] = STATE(4019),
    [sym_preproc_define] = STATE(4019),
    [sym_preproc_undef] = STATE(4019),
    [anon_sym_SEMI] = ACTIONS(4765),
    [anon_sym_LBRACK] = ACTIONS(4765),
    [anon_sym_COLON] = ACTIONS(4765),
    [anon_sym_COMMA] = ACTIONS(4765),
    [anon_sym_RBRACK] = ACTIONS(4765),
    [anon_sym_LPAREN] = ACTIONS(4765),
    [anon_sym_RPAREN] = ACTIONS(4765),
    [anon_sym_RBRACE] = ACTIONS(4765),
    [anon_sym_LT] = ACTIONS(4767),
    [anon_sym_GT] = ACTIONS(4767),
    [anon_sym_in] = ACTIONS(4767),
    [anon_sym_QMARK] = ACTIONS(4767),
    [anon_sym_BANG] = ACTIONS(4767),
    [anon_sym_PLUS_PLUS] = ACTIONS(4765),
    [anon_sym_DASH_DASH] = ACTIONS(4765),
    [anon_sym_PLUS] = ACTIONS(4767),
    [anon_sym_DASH] = ACTIONS(4767),
    [anon_sym_STAR] = ACTIONS(4765),
    [anon_sym_SLASH] = ACTIONS(4767),
    [anon_sym_PERCENT] = ACTIONS(4765),
    [anon_sym_CARET] = ACTIONS(4765),
    [anon_sym_PIPE] = ACTIONS(4767),
    [anon_sym_AMP] = ACTIONS(4767),
    [anon_sym_LT_LT] = ACTIONS(4765),
    [anon_sym_GT_GT] = ACTIONS(4767),
    [anon_sym_GT_GT_GT] = ACTIONS(4765),
    [anon_sym_EQ_EQ] = ACTIONS(4765),
    [anon_sym_BANG_EQ] = ACTIONS(4765),
    [anon_sym_GT_EQ] = ACTIONS(4765),
    [anon_sym_LT_EQ] = ACTIONS(4765),
    [anon_sym_DOT] = ACTIONS(4767),
    [anon_sym_EQ_GT] = ACTIONS(4765),
    [anon_sym_switch] = ACTIONS(4765),
    [anon_sym_when] = ACTIONS(4765),
    [anon_sym_DOT_DOT] = ACTIONS(4765),
    [anon_sym_and] = ACTIONS(4765),
    [anon_sym_or] = ACTIONS(4765),
    [anon_sym_AMP_AMP] = ACTIONS(4765),
    [anon_sym_PIPE_PIPE] = ACTIONS(4765),
    [anon_sym_QMARK_QMARK] = ACTIONS(4765),
    [anon_sym_into] = ACTIONS(4765),
    [anon_sym_on] = ACTIONS(4765),
    [anon_sym_equals] = ACTIONS(4765),
    [anon_sym_by] = ACTIONS(4765),
    [anon_sym_as] = ACTIONS(4765),
    [anon_sym_is] = ACTIONS(4765),
    [anon_sym_DASH_GT] = ACTIONS(4765),
    [anon_sym_with] = ACTIONS(4765),
    [aux_sym_preproc_if_token3] = ACTIONS(4765),
    [aux_sym_preproc_else_token1] = ACTIONS(4765),
    [aux_sym_preproc_elif_token1] = ACTIONS(4765),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4020] = {
    [sym_preproc_region] = STATE(4020),
    [sym_preproc_endregion] = STATE(4020),
    [sym_preproc_line] = STATE(4020),
    [sym_preproc_pragma] = STATE(4020),
    [sym_preproc_nullable] = STATE(4020),
    [sym_preproc_error] = STATE(4020),
    [sym_preproc_warning] = STATE(4020),
    [sym_preproc_define] = STATE(4020),
    [sym_preproc_undef] = STATE(4020),
    [anon_sym_SEMI] = ACTIONS(5640),
    [anon_sym_LBRACK] = ACTIONS(5640),
    [anon_sym_COLON] = ACTIONS(5640),
    [anon_sym_COMMA] = ACTIONS(5640),
    [anon_sym_RBRACK] = ACTIONS(5640),
    [anon_sym_LPAREN] = ACTIONS(5640),
    [anon_sym_RPAREN] = ACTIONS(5640),
    [anon_sym_RBRACE] = ACTIONS(5640),
    [anon_sym_LT] = ACTIONS(5642),
    [anon_sym_GT] = ACTIONS(5642),
    [anon_sym_in] = ACTIONS(5642),
    [anon_sym_QMARK] = ACTIONS(5642),
    [anon_sym_BANG] = ACTIONS(5642),
    [anon_sym_PLUS_PLUS] = ACTIONS(5640),
    [anon_sym_DASH_DASH] = ACTIONS(5640),
    [anon_sym_PLUS] = ACTIONS(5642),
    [anon_sym_DASH] = ACTIONS(5642),
    [anon_sym_STAR] = ACTIONS(5640),
    [anon_sym_SLASH] = ACTIONS(5642),
    [anon_sym_PERCENT] = ACTIONS(5640),
    [anon_sym_CARET] = ACTIONS(5640),
    [anon_sym_PIPE] = ACTIONS(5642),
    [anon_sym_AMP] = ACTIONS(5642),
    [anon_sym_LT_LT] = ACTIONS(5640),
    [anon_sym_GT_GT] = ACTIONS(5642),
    [anon_sym_GT_GT_GT] = ACTIONS(5640),
    [anon_sym_EQ_EQ] = ACTIONS(5640),
    [anon_sym_BANG_EQ] = ACTIONS(5640),
    [anon_sym_GT_EQ] = ACTIONS(5640),
    [anon_sym_LT_EQ] = ACTIONS(5640),
    [anon_sym_DOT] = ACTIONS(5642),
    [anon_sym_EQ_GT] = ACTIONS(5640),
    [anon_sym_switch] = ACTIONS(5640),
    [anon_sym_when] = ACTIONS(5640),
    [anon_sym_DOT_DOT] = ACTIONS(5640),
    [anon_sym_and] = ACTIONS(5640),
    [anon_sym_or] = ACTIONS(5640),
    [anon_sym_AMP_AMP] = ACTIONS(5640),
    [anon_sym_PIPE_PIPE] = ACTIONS(5640),
    [anon_sym_QMARK_QMARK] = ACTIONS(5640),
    [anon_sym_into] = ACTIONS(5640),
    [anon_sym_on] = ACTIONS(5640),
    [anon_sym_equals] = ACTIONS(5640),
    [anon_sym_by] = ACTIONS(5640),
    [anon_sym_as] = ACTIONS(5640),
    [anon_sym_is] = ACTIONS(5640),
    [anon_sym_DASH_GT] = ACTIONS(5640),
    [anon_sym_with] = ACTIONS(5640),
    [aux_sym_preproc_if_token3] = ACTIONS(5640),
    [aux_sym_preproc_else_token1] = ACTIONS(5640),
    [aux_sym_preproc_elif_token1] = ACTIONS(5640),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4021] = {
    [sym_preproc_region] = STATE(4021),
    [sym_preproc_endregion] = STATE(4021),
    [sym_preproc_line] = STATE(4021),
    [sym_preproc_pragma] = STATE(4021),
    [sym_preproc_nullable] = STATE(4021),
    [sym_preproc_error] = STATE(4021),
    [sym_preproc_warning] = STATE(4021),
    [sym_preproc_define] = STATE(4021),
    [sym_preproc_undef] = STATE(4021),
    [anon_sym_SEMI] = ACTIONS(5584),
    [anon_sym_LBRACK] = ACTIONS(5584),
    [anon_sym_COLON] = ACTIONS(5584),
    [anon_sym_COMMA] = ACTIONS(5584),
    [anon_sym_RBRACK] = ACTIONS(5584),
    [anon_sym_LPAREN] = ACTIONS(5584),
    [anon_sym_RPAREN] = ACTIONS(5584),
    [anon_sym_RBRACE] = ACTIONS(5584),
    [anon_sym_LT] = ACTIONS(5586),
    [anon_sym_GT] = ACTIONS(5586),
    [anon_sym_in] = ACTIONS(5586),
    [anon_sym_QMARK] = ACTIONS(5586),
    [anon_sym_BANG] = ACTIONS(5586),
    [anon_sym_PLUS_PLUS] = ACTIONS(5584),
    [anon_sym_DASH_DASH] = ACTIONS(5584),
    [anon_sym_PLUS] = ACTIONS(5586),
    [anon_sym_DASH] = ACTIONS(5586),
    [anon_sym_STAR] = ACTIONS(5584),
    [anon_sym_SLASH] = ACTIONS(5586),
    [anon_sym_PERCENT] = ACTIONS(5584),
    [anon_sym_CARET] = ACTIONS(5584),
    [anon_sym_PIPE] = ACTIONS(5586),
    [anon_sym_AMP] = ACTIONS(5586),
    [anon_sym_LT_LT] = ACTIONS(5584),
    [anon_sym_GT_GT] = ACTIONS(5586),
    [anon_sym_GT_GT_GT] = ACTIONS(5584),
    [anon_sym_EQ_EQ] = ACTIONS(5584),
    [anon_sym_BANG_EQ] = ACTIONS(5584),
    [anon_sym_GT_EQ] = ACTIONS(5584),
    [anon_sym_LT_EQ] = ACTIONS(5584),
    [anon_sym_DOT] = ACTIONS(5586),
    [anon_sym_EQ_GT] = ACTIONS(5584),
    [anon_sym_switch] = ACTIONS(5584),
    [anon_sym_when] = ACTIONS(5584),
    [anon_sym_DOT_DOT] = ACTIONS(5584),
    [anon_sym_and] = ACTIONS(5584),
    [anon_sym_or] = ACTIONS(5584),
    [anon_sym_AMP_AMP] = ACTIONS(5584),
    [anon_sym_PIPE_PIPE] = ACTIONS(5584),
    [anon_sym_QMARK_QMARK] = ACTIONS(5584),
    [anon_sym_into] = ACTIONS(5584),
    [anon_sym_on] = ACTIONS(5584),
    [anon_sym_equals] = ACTIONS(5584),
    [anon_sym_by] = ACTIONS(5584),
    [anon_sym_as] = ACTIONS(5584),
    [anon_sym_is] = ACTIONS(5584),
    [anon_sym_DASH_GT] = ACTIONS(5584),
    [anon_sym_with] = ACTIONS(5584),
    [aux_sym_preproc_if_token3] = ACTIONS(5584),
    [aux_sym_preproc_else_token1] = ACTIONS(5584),
    [aux_sym_preproc_elif_token1] = ACTIONS(5584),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4022] = {
    [sym_preproc_region] = STATE(4022),
    [sym_preproc_endregion] = STATE(4022),
    [sym_preproc_line] = STATE(4022),
    [sym_preproc_pragma] = STATE(4022),
    [sym_preproc_nullable] = STATE(4022),
    [sym_preproc_error] = STATE(4022),
    [sym_preproc_warning] = STATE(4022),
    [sym_preproc_define] = STATE(4022),
    [sym_preproc_undef] = STATE(4022),
    [anon_sym_SEMI] = ACTIONS(5608),
    [anon_sym_LBRACK] = ACTIONS(5608),
    [anon_sym_COLON] = ACTIONS(5608),
    [anon_sym_COMMA] = ACTIONS(5608),
    [anon_sym_RBRACK] = ACTIONS(5608),
    [anon_sym_LPAREN] = ACTIONS(5608),
    [anon_sym_RPAREN] = ACTIONS(5608),
    [anon_sym_RBRACE] = ACTIONS(5608),
    [anon_sym_LT] = ACTIONS(5610),
    [anon_sym_GT] = ACTIONS(5610),
    [anon_sym_in] = ACTIONS(5610),
    [anon_sym_QMARK] = ACTIONS(5610),
    [anon_sym_BANG] = ACTIONS(5610),
    [anon_sym_PLUS_PLUS] = ACTIONS(5608),
    [anon_sym_DASH_DASH] = ACTIONS(5608),
    [anon_sym_PLUS] = ACTIONS(5610),
    [anon_sym_DASH] = ACTIONS(5610),
    [anon_sym_STAR] = ACTIONS(5608),
    [anon_sym_SLASH] = ACTIONS(5610),
    [anon_sym_PERCENT] = ACTIONS(5608),
    [anon_sym_CARET] = ACTIONS(5608),
    [anon_sym_PIPE] = ACTIONS(5610),
    [anon_sym_AMP] = ACTIONS(5610),
    [anon_sym_LT_LT] = ACTIONS(5608),
    [anon_sym_GT_GT] = ACTIONS(5610),
    [anon_sym_GT_GT_GT] = ACTIONS(5608),
    [anon_sym_EQ_EQ] = ACTIONS(5608),
    [anon_sym_BANG_EQ] = ACTIONS(5608),
    [anon_sym_GT_EQ] = ACTIONS(5608),
    [anon_sym_LT_EQ] = ACTIONS(5608),
    [anon_sym_DOT] = ACTIONS(5610),
    [anon_sym_EQ_GT] = ACTIONS(5608),
    [anon_sym_switch] = ACTIONS(5608),
    [anon_sym_when] = ACTIONS(5608),
    [anon_sym_DOT_DOT] = ACTIONS(5608),
    [anon_sym_and] = ACTIONS(5608),
    [anon_sym_or] = ACTIONS(5608),
    [anon_sym_AMP_AMP] = ACTIONS(5608),
    [anon_sym_PIPE_PIPE] = ACTIONS(5608),
    [anon_sym_QMARK_QMARK] = ACTIONS(5608),
    [anon_sym_into] = ACTIONS(5608),
    [anon_sym_on] = ACTIONS(5608),
    [anon_sym_equals] = ACTIONS(5608),
    [anon_sym_by] = ACTIONS(5608),
    [anon_sym_as] = ACTIONS(5608),
    [anon_sym_is] = ACTIONS(5608),
    [anon_sym_DASH_GT] = ACTIONS(5608),
    [anon_sym_with] = ACTIONS(5608),
    [aux_sym_preproc_if_token3] = ACTIONS(5608),
    [aux_sym_preproc_else_token1] = ACTIONS(5608),
    [aux_sym_preproc_elif_token1] = ACTIONS(5608),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4023] = {
    [sym_preproc_region] = STATE(4023),
    [sym_preproc_endregion] = STATE(4023),
    [sym_preproc_line] = STATE(4023),
    [sym_preproc_pragma] = STATE(4023),
    [sym_preproc_nullable] = STATE(4023),
    [sym_preproc_error] = STATE(4023),
    [sym_preproc_warning] = STATE(4023),
    [sym_preproc_define] = STATE(4023),
    [sym_preproc_undef] = STATE(4023),
    [anon_sym_SEMI] = ACTIONS(5660),
    [anon_sym_LBRACK] = ACTIONS(5660),
    [anon_sym_COLON] = ACTIONS(5660),
    [anon_sym_COMMA] = ACTIONS(5660),
    [anon_sym_RBRACK] = ACTIONS(5660),
    [anon_sym_LPAREN] = ACTIONS(5660),
    [anon_sym_RPAREN] = ACTIONS(5660),
    [anon_sym_RBRACE] = ACTIONS(5660),
    [anon_sym_LT] = ACTIONS(5662),
    [anon_sym_GT] = ACTIONS(5662),
    [anon_sym_in] = ACTIONS(5662),
    [anon_sym_QMARK] = ACTIONS(5662),
    [anon_sym_BANG] = ACTIONS(5662),
    [anon_sym_PLUS_PLUS] = ACTIONS(5660),
    [anon_sym_DASH_DASH] = ACTIONS(5660),
    [anon_sym_PLUS] = ACTIONS(5662),
    [anon_sym_DASH] = ACTIONS(5662),
    [anon_sym_STAR] = ACTIONS(5660),
    [anon_sym_SLASH] = ACTIONS(5662),
    [anon_sym_PERCENT] = ACTIONS(5660),
    [anon_sym_CARET] = ACTIONS(5660),
    [anon_sym_PIPE] = ACTIONS(5662),
    [anon_sym_AMP] = ACTIONS(5662),
    [anon_sym_LT_LT] = ACTIONS(5660),
    [anon_sym_GT_GT] = ACTIONS(5662),
    [anon_sym_GT_GT_GT] = ACTIONS(5660),
    [anon_sym_EQ_EQ] = ACTIONS(5660),
    [anon_sym_BANG_EQ] = ACTIONS(5660),
    [anon_sym_GT_EQ] = ACTIONS(5660),
    [anon_sym_LT_EQ] = ACTIONS(5660),
    [anon_sym_DOT] = ACTIONS(5662),
    [anon_sym_EQ_GT] = ACTIONS(5660),
    [anon_sym_switch] = ACTIONS(5660),
    [anon_sym_when] = ACTIONS(5660),
    [anon_sym_DOT_DOT] = ACTIONS(5660),
    [anon_sym_and] = ACTIONS(5660),
    [anon_sym_or] = ACTIONS(5660),
    [anon_sym_AMP_AMP] = ACTIONS(5660),
    [anon_sym_PIPE_PIPE] = ACTIONS(5660),
    [anon_sym_QMARK_QMARK] = ACTIONS(5660),
    [anon_sym_into] = ACTIONS(5660),
    [anon_sym_on] = ACTIONS(5660),
    [anon_sym_equals] = ACTIONS(5660),
    [anon_sym_by] = ACTIONS(5660),
    [anon_sym_as] = ACTIONS(5660),
    [anon_sym_is] = ACTIONS(5660),
    [anon_sym_DASH_GT] = ACTIONS(5660),
    [anon_sym_with] = ACTIONS(5660),
    [aux_sym_preproc_if_token3] = ACTIONS(5660),
    [aux_sym_preproc_else_token1] = ACTIONS(5660),
    [aux_sym_preproc_elif_token1] = ACTIONS(5660),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4024] = {
    [sym_preproc_region] = STATE(4024),
    [sym_preproc_endregion] = STATE(4024),
    [sym_preproc_line] = STATE(4024),
    [sym_preproc_pragma] = STATE(4024),
    [sym_preproc_nullable] = STATE(4024),
    [sym_preproc_error] = STATE(4024),
    [sym_preproc_warning] = STATE(4024),
    [sym_preproc_define] = STATE(4024),
    [sym_preproc_undef] = STATE(4024),
    [anon_sym_SEMI] = ACTIONS(2997),
    [anon_sym_LBRACK] = ACTIONS(2997),
    [anon_sym_COLON] = ACTIONS(2997),
    [anon_sym_COMMA] = ACTIONS(2997),
    [anon_sym_RBRACK] = ACTIONS(2997),
    [anon_sym_LPAREN] = ACTIONS(2997),
    [anon_sym_RPAREN] = ACTIONS(2997),
    [anon_sym_RBRACE] = ACTIONS(2997),
    [anon_sym_LT] = ACTIONS(2995),
    [anon_sym_GT] = ACTIONS(2995),
    [anon_sym_in] = ACTIONS(2995),
    [anon_sym_QMARK] = ACTIONS(2995),
    [anon_sym_BANG] = ACTIONS(2995),
    [anon_sym_PLUS_PLUS] = ACTIONS(2997),
    [anon_sym_DASH_DASH] = ACTIONS(2997),
    [anon_sym_PLUS] = ACTIONS(2995),
    [anon_sym_DASH] = ACTIONS(2995),
    [anon_sym_STAR] = ACTIONS(2997),
    [anon_sym_SLASH] = ACTIONS(2995),
    [anon_sym_PERCENT] = ACTIONS(2997),
    [anon_sym_CARET] = ACTIONS(2997),
    [anon_sym_PIPE] = ACTIONS(2995),
    [anon_sym_AMP] = ACTIONS(2995),
    [anon_sym_LT_LT] = ACTIONS(2997),
    [anon_sym_GT_GT] = ACTIONS(2995),
    [anon_sym_GT_GT_GT] = ACTIONS(2997),
    [anon_sym_EQ_EQ] = ACTIONS(2997),
    [anon_sym_BANG_EQ] = ACTIONS(2997),
    [anon_sym_GT_EQ] = ACTIONS(2997),
    [anon_sym_LT_EQ] = ACTIONS(2997),
    [anon_sym_DOT] = ACTIONS(2995),
    [anon_sym_EQ_GT] = ACTIONS(2997),
    [anon_sym_switch] = ACTIONS(2997),
    [anon_sym_when] = ACTIONS(2997),
    [anon_sym_DOT_DOT] = ACTIONS(2997),
    [anon_sym_and] = ACTIONS(2997),
    [anon_sym_or] = ACTIONS(2997),
    [anon_sym_AMP_AMP] = ACTIONS(2997),
    [anon_sym_PIPE_PIPE] = ACTIONS(2997),
    [anon_sym_QMARK_QMARK] = ACTIONS(2997),
    [anon_sym_into] = ACTIONS(2997),
    [anon_sym_on] = ACTIONS(2997),
    [anon_sym_equals] = ACTIONS(2997),
    [anon_sym_by] = ACTIONS(2997),
    [anon_sym_as] = ACTIONS(2997),
    [anon_sym_is] = ACTIONS(2997),
    [anon_sym_DASH_GT] = ACTIONS(2997),
    [anon_sym_with] = ACTIONS(2997),
    [aux_sym_preproc_if_token3] = ACTIONS(2997),
    [aux_sym_preproc_else_token1] = ACTIONS(2997),
    [aux_sym_preproc_elif_token1] = ACTIONS(2997),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4025] = {
    [sym_preproc_region] = STATE(4025),
    [sym_preproc_endregion] = STATE(4025),
    [sym_preproc_line] = STATE(4025),
    [sym_preproc_pragma] = STATE(4025),
    [sym_preproc_nullable] = STATE(4025),
    [sym_preproc_error] = STATE(4025),
    [sym_preproc_warning] = STATE(4025),
    [sym_preproc_define] = STATE(4025),
    [sym_preproc_undef] = STATE(4025),
    [sym__identifier_token] = ACTIONS(4042),
    [anon_sym_extern] = ACTIONS(4042),
    [anon_sym_alias] = ACTIONS(5905),
    [anon_sym_global] = ACTIONS(4042),
    [anon_sym_unsafe] = ACTIONS(4042),
    [anon_sym_static] = ACTIONS(4042),
    [anon_sym_LPAREN] = ACTIONS(5474),
    [anon_sym_class] = ACTIONS(4042),
    [anon_sym_ref] = ACTIONS(4042),
    [anon_sym_struct] = ACTIONS(4042),
    [anon_sym_enum] = ACTIONS(4042),
    [anon_sym_interface] = ACTIONS(4042),
    [anon_sym_delegate] = ACTIONS(4042),
    [anon_sym_record] = ACTIONS(4042),
    [anon_sym_abstract] = ACTIONS(4042),
    [anon_sym_async] = ACTIONS(4042),
    [anon_sym_const] = ACTIONS(4042),
    [anon_sym_file] = ACTIONS(4042),
    [anon_sym_fixed] = ACTIONS(4042),
    [anon_sym_internal] = ACTIONS(4042),
    [anon_sym_new] = ACTIONS(4042),
    [anon_sym_override] = ACTIONS(4042),
    [anon_sym_partial] = ACTIONS(4042),
    [anon_sym_private] = ACTIONS(4042),
    [anon_sym_protected] = ACTIONS(4042),
    [anon_sym_public] = ACTIONS(4042),
    [anon_sym_readonly] = ACTIONS(4042),
    [anon_sym_required] = ACTIONS(4042),
    [anon_sym_sealed] = ACTIONS(4042),
    [anon_sym_virtual] = ACTIONS(4042),
    [anon_sym_volatile] = ACTIONS(4042),
    [anon_sym_where] = ACTIONS(4042),
    [anon_sym_notnull] = ACTIONS(4042),
    [anon_sym_unmanaged] = ACTIONS(4042),
    [anon_sym_scoped] = ACTIONS(4042),
    [anon_sym_var] = ACTIONS(4042),
    [sym_predefined_type] = ACTIONS(4042),
    [anon_sym_yield] = ACTIONS(4042),
    [anon_sym_when] = ACTIONS(4042),
    [anon_sym_from] = ACTIONS(4042),
    [anon_sym_into] = ACTIONS(4042),
    [anon_sym_join] = ACTIONS(4042),
    [anon_sym_on] = ACTIONS(4042),
    [anon_sym_equals] = ACTIONS(4042),
    [anon_sym_let] = ACTIONS(4042),
    [anon_sym_orderby] = ACTIONS(4042),
    [anon_sym_ascending] = ACTIONS(4042),
    [anon_sym_descending] = ACTIONS(4042),
    [anon_sym_group] = ACTIONS(4042),
    [anon_sym_by] = ACTIONS(4042),
    [anon_sym_select] = ACTIONS(4042),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4026] = {
    [sym_preproc_region] = STATE(4026),
    [sym_preproc_endregion] = STATE(4026),
    [sym_preproc_line] = STATE(4026),
    [sym_preproc_pragma] = STATE(4026),
    [sym_preproc_nullable] = STATE(4026),
    [sym_preproc_error] = STATE(4026),
    [sym_preproc_warning] = STATE(4026),
    [sym_preproc_define] = STATE(4026),
    [sym_preproc_undef] = STATE(4026),
    [anon_sym_SEMI] = ACTIONS(5420),
    [anon_sym_LBRACK] = ACTIONS(5420),
    [anon_sym_COLON] = ACTIONS(5420),
    [anon_sym_COMMA] = ACTIONS(5420),
    [anon_sym_RBRACK] = ACTIONS(5420),
    [anon_sym_LPAREN] = ACTIONS(5420),
    [anon_sym_RPAREN] = ACTIONS(5420),
    [anon_sym_RBRACE] = ACTIONS(5420),
    [anon_sym_LT] = ACTIONS(5422),
    [anon_sym_GT] = ACTIONS(5422),
    [anon_sym_in] = ACTIONS(5422),
    [anon_sym_QMARK] = ACTIONS(5422),
    [anon_sym_BANG] = ACTIONS(5422),
    [anon_sym_PLUS_PLUS] = ACTIONS(5420),
    [anon_sym_DASH_DASH] = ACTIONS(5420),
    [anon_sym_PLUS] = ACTIONS(5422),
    [anon_sym_DASH] = ACTIONS(5422),
    [anon_sym_STAR] = ACTIONS(5420),
    [anon_sym_SLASH] = ACTIONS(5422),
    [anon_sym_PERCENT] = ACTIONS(5420),
    [anon_sym_CARET] = ACTIONS(5420),
    [anon_sym_PIPE] = ACTIONS(5422),
    [anon_sym_AMP] = ACTIONS(5422),
    [anon_sym_LT_LT] = ACTIONS(5420),
    [anon_sym_GT_GT] = ACTIONS(5422),
    [anon_sym_GT_GT_GT] = ACTIONS(5420),
    [anon_sym_EQ_EQ] = ACTIONS(5420),
    [anon_sym_BANG_EQ] = ACTIONS(5420),
    [anon_sym_GT_EQ] = ACTIONS(5420),
    [anon_sym_LT_EQ] = ACTIONS(5420),
    [anon_sym_DOT] = ACTIONS(5422),
    [anon_sym_EQ_GT] = ACTIONS(5420),
    [anon_sym_switch] = ACTIONS(5420),
    [anon_sym_when] = ACTIONS(5420),
    [anon_sym_DOT_DOT] = ACTIONS(5420),
    [anon_sym_and] = ACTIONS(5420),
    [anon_sym_or] = ACTIONS(5420),
    [anon_sym_AMP_AMP] = ACTIONS(5420),
    [anon_sym_PIPE_PIPE] = ACTIONS(5420),
    [anon_sym_QMARK_QMARK] = ACTIONS(5420),
    [anon_sym_into] = ACTIONS(5420),
    [anon_sym_on] = ACTIONS(5420),
    [anon_sym_equals] = ACTIONS(5420),
    [anon_sym_by] = ACTIONS(5420),
    [anon_sym_as] = ACTIONS(5420),
    [anon_sym_is] = ACTIONS(5420),
    [anon_sym_DASH_GT] = ACTIONS(5420),
    [anon_sym_with] = ACTIONS(5420),
    [aux_sym_preproc_if_token3] = ACTIONS(5420),
    [aux_sym_preproc_else_token1] = ACTIONS(5420),
    [aux_sym_preproc_elif_token1] = ACTIONS(5420),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4027] = {
    [sym_preproc_region] = STATE(4027),
    [sym_preproc_endregion] = STATE(4027),
    [sym_preproc_line] = STATE(4027),
    [sym_preproc_pragma] = STATE(4027),
    [sym_preproc_nullable] = STATE(4027),
    [sym_preproc_error] = STATE(4027),
    [sym_preproc_warning] = STATE(4027),
    [sym_preproc_define] = STATE(4027),
    [sym_preproc_undef] = STATE(4027),
    [sym__identifier_token] = ACTIONS(4042),
    [anon_sym_extern] = ACTIONS(4042),
    [anon_sym_alias] = ACTIONS(4042),
    [anon_sym_global] = ACTIONS(4042),
    [anon_sym_unsafe] = ACTIONS(4042),
    [anon_sym_static] = ACTIONS(4042),
    [anon_sym_LPAREN] = ACTIONS(5907),
    [anon_sym_class] = ACTIONS(4042),
    [anon_sym_ref] = ACTIONS(4042),
    [anon_sym_struct] = ACTIONS(4042),
    [anon_sym_enum] = ACTIONS(4042),
    [anon_sym_interface] = ACTIONS(4042),
    [anon_sym_delegate] = ACTIONS(4042),
    [anon_sym_record] = ACTIONS(4042),
    [anon_sym_abstract] = ACTIONS(4042),
    [anon_sym_async] = ACTIONS(4042),
    [anon_sym_const] = ACTIONS(4042),
    [anon_sym_file] = ACTIONS(4042),
    [anon_sym_fixed] = ACTIONS(4042),
    [anon_sym_internal] = ACTIONS(4042),
    [anon_sym_new] = ACTIONS(4042),
    [anon_sym_override] = ACTIONS(4042),
    [anon_sym_partial] = ACTIONS(4042),
    [anon_sym_private] = ACTIONS(4042),
    [anon_sym_protected] = ACTIONS(4042),
    [anon_sym_public] = ACTIONS(4042),
    [anon_sym_readonly] = ACTIONS(4042),
    [anon_sym_required] = ACTIONS(4042),
    [anon_sym_sealed] = ACTIONS(4042),
    [anon_sym_virtual] = ACTIONS(4042),
    [anon_sym_volatile] = ACTIONS(4042),
    [anon_sym_where] = ACTIONS(4042),
    [anon_sym_notnull] = ACTIONS(4042),
    [anon_sym_unmanaged] = ACTIONS(4042),
    [anon_sym_scoped] = ACTIONS(4042),
    [anon_sym_var] = ACTIONS(4042),
    [sym_predefined_type] = ACTIONS(4042),
    [anon_sym_yield] = ACTIONS(4042),
    [anon_sym_when] = ACTIONS(4042),
    [anon_sym_from] = ACTIONS(4042),
    [anon_sym_into] = ACTIONS(4042),
    [anon_sym_join] = ACTIONS(4042),
    [anon_sym_on] = ACTIONS(4042),
    [anon_sym_equals] = ACTIONS(4042),
    [anon_sym_let] = ACTIONS(4042),
    [anon_sym_orderby] = ACTIONS(4042),
    [anon_sym_ascending] = ACTIONS(4042),
    [anon_sym_descending] = ACTIONS(4042),
    [anon_sym_group] = ACTIONS(4042),
    [anon_sym_by] = ACTIONS(4042),
    [anon_sym_select] = ACTIONS(4042),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4028] = {
    [sym_preproc_region] = STATE(4028),
    [sym_preproc_endregion] = STATE(4028),
    [sym_preproc_line] = STATE(4028),
    [sym_preproc_pragma] = STATE(4028),
    [sym_preproc_nullable] = STATE(4028),
    [sym_preproc_error] = STATE(4028),
    [sym_preproc_warning] = STATE(4028),
    [sym_preproc_define] = STATE(4028),
    [sym_preproc_undef] = STATE(4028),
    [anon_sym_SEMI] = ACTIONS(5644),
    [anon_sym_LBRACK] = ACTIONS(5644),
    [anon_sym_COLON] = ACTIONS(5644),
    [anon_sym_COMMA] = ACTIONS(5644),
    [anon_sym_RBRACK] = ACTIONS(5644),
    [anon_sym_LPAREN] = ACTIONS(5644),
    [anon_sym_RPAREN] = ACTIONS(5644),
    [anon_sym_RBRACE] = ACTIONS(5644),
    [anon_sym_LT] = ACTIONS(5646),
    [anon_sym_GT] = ACTIONS(5646),
    [anon_sym_in] = ACTIONS(5646),
    [anon_sym_QMARK] = ACTIONS(5646),
    [anon_sym_BANG] = ACTIONS(5646),
    [anon_sym_PLUS_PLUS] = ACTIONS(5644),
    [anon_sym_DASH_DASH] = ACTIONS(5644),
    [anon_sym_PLUS] = ACTIONS(5646),
    [anon_sym_DASH] = ACTIONS(5646),
    [anon_sym_STAR] = ACTIONS(5644),
    [anon_sym_SLASH] = ACTIONS(5646),
    [anon_sym_PERCENT] = ACTIONS(5644),
    [anon_sym_CARET] = ACTIONS(5644),
    [anon_sym_PIPE] = ACTIONS(5646),
    [anon_sym_AMP] = ACTIONS(5646),
    [anon_sym_LT_LT] = ACTIONS(5644),
    [anon_sym_GT_GT] = ACTIONS(5646),
    [anon_sym_GT_GT_GT] = ACTIONS(5644),
    [anon_sym_EQ_EQ] = ACTIONS(5644),
    [anon_sym_BANG_EQ] = ACTIONS(5644),
    [anon_sym_GT_EQ] = ACTIONS(5644),
    [anon_sym_LT_EQ] = ACTIONS(5644),
    [anon_sym_DOT] = ACTIONS(5646),
    [anon_sym_EQ_GT] = ACTIONS(5644),
    [anon_sym_switch] = ACTIONS(5644),
    [anon_sym_when] = ACTIONS(5644),
    [anon_sym_DOT_DOT] = ACTIONS(5644),
    [anon_sym_and] = ACTIONS(5644),
    [anon_sym_or] = ACTIONS(5644),
    [anon_sym_AMP_AMP] = ACTIONS(5644),
    [anon_sym_PIPE_PIPE] = ACTIONS(5644),
    [anon_sym_QMARK_QMARK] = ACTIONS(5644),
    [anon_sym_into] = ACTIONS(5644),
    [anon_sym_on] = ACTIONS(5644),
    [anon_sym_equals] = ACTIONS(5644),
    [anon_sym_by] = ACTIONS(5644),
    [anon_sym_as] = ACTIONS(5644),
    [anon_sym_is] = ACTIONS(5644),
    [anon_sym_DASH_GT] = ACTIONS(5644),
    [anon_sym_with] = ACTIONS(5644),
    [aux_sym_preproc_if_token3] = ACTIONS(5644),
    [aux_sym_preproc_else_token1] = ACTIONS(5644),
    [aux_sym_preproc_elif_token1] = ACTIONS(5644),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4029] = {
    [sym_preproc_region] = STATE(4029),
    [sym_preproc_endregion] = STATE(4029),
    [sym_preproc_line] = STATE(4029),
    [sym_preproc_pragma] = STATE(4029),
    [sym_preproc_nullable] = STATE(4029),
    [sym_preproc_error] = STATE(4029),
    [sym_preproc_warning] = STATE(4029),
    [sym_preproc_define] = STATE(4029),
    [sym_preproc_undef] = STATE(4029),
    [anon_sym_SEMI] = ACTIONS(5909),
    [anon_sym_LBRACK] = ACTIONS(5909),
    [anon_sym_COLON] = ACTIONS(5909),
    [anon_sym_COMMA] = ACTIONS(5909),
    [anon_sym_RBRACK] = ACTIONS(5909),
    [anon_sym_LPAREN] = ACTIONS(5909),
    [anon_sym_RPAREN] = ACTIONS(5909),
    [anon_sym_RBRACE] = ACTIONS(5909),
    [anon_sym_LT] = ACTIONS(5911),
    [anon_sym_GT] = ACTIONS(5911),
    [anon_sym_in] = ACTIONS(5911),
    [anon_sym_QMARK] = ACTIONS(5911),
    [anon_sym_BANG] = ACTIONS(5911),
    [anon_sym_PLUS_PLUS] = ACTIONS(5909),
    [anon_sym_DASH_DASH] = ACTIONS(5909),
    [anon_sym_PLUS] = ACTIONS(5911),
    [anon_sym_DASH] = ACTIONS(5911),
    [anon_sym_STAR] = ACTIONS(5909),
    [anon_sym_SLASH] = ACTIONS(5911),
    [anon_sym_PERCENT] = ACTIONS(5909),
    [anon_sym_CARET] = ACTIONS(5909),
    [anon_sym_PIPE] = ACTIONS(5911),
    [anon_sym_AMP] = ACTIONS(5911),
    [anon_sym_LT_LT] = ACTIONS(5909),
    [anon_sym_GT_GT] = ACTIONS(5911),
    [anon_sym_GT_GT_GT] = ACTIONS(5909),
    [anon_sym_EQ_EQ] = ACTIONS(5909),
    [anon_sym_BANG_EQ] = ACTIONS(5909),
    [anon_sym_GT_EQ] = ACTIONS(5909),
    [anon_sym_LT_EQ] = ACTIONS(5909),
    [anon_sym_DOT] = ACTIONS(5911),
    [anon_sym_EQ_GT] = ACTIONS(5909),
    [anon_sym_switch] = ACTIONS(5909),
    [anon_sym_when] = ACTIONS(5909),
    [anon_sym_DOT_DOT] = ACTIONS(5909),
    [anon_sym_and] = ACTIONS(5909),
    [anon_sym_or] = ACTIONS(5909),
    [anon_sym_AMP_AMP] = ACTIONS(5909),
    [anon_sym_PIPE_PIPE] = ACTIONS(5909),
    [anon_sym_QMARK_QMARK] = ACTIONS(5909),
    [anon_sym_into] = ACTIONS(5909),
    [anon_sym_on] = ACTIONS(5909),
    [anon_sym_equals] = ACTIONS(5909),
    [anon_sym_by] = ACTIONS(5909),
    [anon_sym_as] = ACTIONS(5909),
    [anon_sym_is] = ACTIONS(5909),
    [anon_sym_DASH_GT] = ACTIONS(5909),
    [anon_sym_with] = ACTIONS(5909),
    [aux_sym_preproc_if_token3] = ACTIONS(5909),
    [aux_sym_preproc_else_token1] = ACTIONS(5909),
    [aux_sym_preproc_elif_token1] = ACTIONS(5909),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4030] = {
    [sym_preproc_region] = STATE(4030),
    [sym_preproc_endregion] = STATE(4030),
    [sym_preproc_line] = STATE(4030),
    [sym_preproc_pragma] = STATE(4030),
    [sym_preproc_nullable] = STATE(4030),
    [sym_preproc_error] = STATE(4030),
    [sym_preproc_warning] = STATE(4030),
    [sym_preproc_define] = STATE(4030),
    [sym_preproc_undef] = STATE(4030),
    [anon_sym_SEMI] = ACTIONS(5424),
    [anon_sym_LBRACK] = ACTIONS(5424),
    [anon_sym_COLON] = ACTIONS(5424),
    [anon_sym_COMMA] = ACTIONS(5424),
    [anon_sym_RBRACK] = ACTIONS(5424),
    [anon_sym_LPAREN] = ACTIONS(5424),
    [anon_sym_RPAREN] = ACTIONS(5424),
    [anon_sym_RBRACE] = ACTIONS(5424),
    [anon_sym_LT] = ACTIONS(5426),
    [anon_sym_GT] = ACTIONS(5426),
    [anon_sym_in] = ACTIONS(5426),
    [anon_sym_QMARK] = ACTIONS(5426),
    [anon_sym_BANG] = ACTIONS(5426),
    [anon_sym_PLUS_PLUS] = ACTIONS(5424),
    [anon_sym_DASH_DASH] = ACTIONS(5424),
    [anon_sym_PLUS] = ACTIONS(5426),
    [anon_sym_DASH] = ACTIONS(5426),
    [anon_sym_STAR] = ACTIONS(5424),
    [anon_sym_SLASH] = ACTIONS(5426),
    [anon_sym_PERCENT] = ACTIONS(5424),
    [anon_sym_CARET] = ACTIONS(5424),
    [anon_sym_PIPE] = ACTIONS(5426),
    [anon_sym_AMP] = ACTIONS(5426),
    [anon_sym_LT_LT] = ACTIONS(5424),
    [anon_sym_GT_GT] = ACTIONS(5426),
    [anon_sym_GT_GT_GT] = ACTIONS(5424),
    [anon_sym_EQ_EQ] = ACTIONS(5424),
    [anon_sym_BANG_EQ] = ACTIONS(5424),
    [anon_sym_GT_EQ] = ACTIONS(5424),
    [anon_sym_LT_EQ] = ACTIONS(5424),
    [anon_sym_DOT] = ACTIONS(5426),
    [anon_sym_EQ_GT] = ACTIONS(5424),
    [anon_sym_switch] = ACTIONS(5424),
    [anon_sym_when] = ACTIONS(5424),
    [anon_sym_DOT_DOT] = ACTIONS(5424),
    [anon_sym_and] = ACTIONS(5424),
    [anon_sym_or] = ACTIONS(5424),
    [anon_sym_AMP_AMP] = ACTIONS(5424),
    [anon_sym_PIPE_PIPE] = ACTIONS(5424),
    [anon_sym_QMARK_QMARK] = ACTIONS(5424),
    [anon_sym_into] = ACTIONS(5424),
    [anon_sym_on] = ACTIONS(5424),
    [anon_sym_equals] = ACTIONS(5424),
    [anon_sym_by] = ACTIONS(5424),
    [anon_sym_as] = ACTIONS(5424),
    [anon_sym_is] = ACTIONS(5424),
    [anon_sym_DASH_GT] = ACTIONS(5424),
    [anon_sym_with] = ACTIONS(5424),
    [aux_sym_preproc_if_token3] = ACTIONS(5424),
    [aux_sym_preproc_else_token1] = ACTIONS(5424),
    [aux_sym_preproc_elif_token1] = ACTIONS(5424),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4031] = {
    [sym_preproc_region] = STATE(4031),
    [sym_preproc_endregion] = STATE(4031),
    [sym_preproc_line] = STATE(4031),
    [sym_preproc_pragma] = STATE(4031),
    [sym_preproc_nullable] = STATE(4031),
    [sym_preproc_error] = STATE(4031),
    [sym_preproc_warning] = STATE(4031),
    [sym_preproc_define] = STATE(4031),
    [sym_preproc_undef] = STATE(4031),
    [anon_sym_SEMI] = ACTIONS(4494),
    [anon_sym_LBRACK] = ACTIONS(4494),
    [anon_sym_COLON] = ACTIONS(4494),
    [anon_sym_COMMA] = ACTIONS(4494),
    [anon_sym_RBRACK] = ACTIONS(4494),
    [anon_sym_LPAREN] = ACTIONS(4494),
    [anon_sym_RPAREN] = ACTIONS(4494),
    [anon_sym_LBRACE] = ACTIONS(4494),
    [anon_sym_RBRACE] = ACTIONS(4494),
    [anon_sym_LT] = ACTIONS(4492),
    [anon_sym_GT] = ACTIONS(4492),
    [anon_sym_in] = ACTIONS(4494),
    [anon_sym_QMARK] = ACTIONS(4492),
    [anon_sym_BANG] = ACTIONS(4492),
    [anon_sym_PLUS_PLUS] = ACTIONS(4494),
    [anon_sym_DASH_DASH] = ACTIONS(4494),
    [anon_sym_PLUS] = ACTIONS(4492),
    [anon_sym_DASH] = ACTIONS(4492),
    [anon_sym_STAR] = ACTIONS(4494),
    [anon_sym_SLASH] = ACTIONS(4492),
    [anon_sym_PERCENT] = ACTIONS(4494),
    [anon_sym_CARET] = ACTIONS(4494),
    [anon_sym_PIPE] = ACTIONS(4492),
    [anon_sym_AMP] = ACTIONS(4492),
    [anon_sym_LT_LT] = ACTIONS(4494),
    [anon_sym_GT_GT] = ACTIONS(4492),
    [anon_sym_GT_GT_GT] = ACTIONS(4494),
    [anon_sym_EQ_EQ] = ACTIONS(4494),
    [anon_sym_BANG_EQ] = ACTIONS(4494),
    [anon_sym_GT_EQ] = ACTIONS(4494),
    [anon_sym_LT_EQ] = ACTIONS(4494),
    [anon_sym_DOT] = ACTIONS(4492),
    [anon_sym_EQ_GT] = ACTIONS(4494),
    [anon_sym_switch] = ACTIONS(4494),
    [anon_sym_when] = ACTIONS(4494),
    [anon_sym_DOT_DOT] = ACTIONS(4494),
    [anon_sym_and] = ACTIONS(4494),
    [anon_sym_or] = ACTIONS(4494),
    [anon_sym_AMP_AMP] = ACTIONS(4494),
    [anon_sym_PIPE_PIPE] = ACTIONS(4494),
    [anon_sym_QMARK_QMARK] = ACTIONS(4494),
    [anon_sym_on] = ACTIONS(4494),
    [anon_sym_equals] = ACTIONS(4494),
    [anon_sym_by] = ACTIONS(4494),
    [anon_sym_as] = ACTIONS(4494),
    [anon_sym_is] = ACTIONS(4494),
    [anon_sym_DASH_GT] = ACTIONS(4494),
    [anon_sym_with] = ACTIONS(4494),
    [aux_sym_preproc_if_token3] = ACTIONS(4494),
    [aux_sym_preproc_else_token1] = ACTIONS(4494),
    [aux_sym_preproc_elif_token1] = ACTIONS(4494),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4032] = {
    [sym_preproc_region] = STATE(4032),
    [sym_preproc_endregion] = STATE(4032),
    [sym_preproc_line] = STATE(4032),
    [sym_preproc_pragma] = STATE(4032),
    [sym_preproc_nullable] = STATE(4032),
    [sym_preproc_error] = STATE(4032),
    [sym_preproc_warning] = STATE(4032),
    [sym_preproc_define] = STATE(4032),
    [sym_preproc_undef] = STATE(4032),
    [anon_sym_SEMI] = ACTIONS(4433),
    [anon_sym_LBRACK] = ACTIONS(4433),
    [anon_sym_COLON] = ACTIONS(4433),
    [anon_sym_COMMA] = ACTIONS(4433),
    [anon_sym_RBRACK] = ACTIONS(4433),
    [anon_sym_LPAREN] = ACTIONS(4433),
    [anon_sym_RPAREN] = ACTIONS(4433),
    [anon_sym_LBRACE] = ACTIONS(4433),
    [anon_sym_RBRACE] = ACTIONS(4433),
    [anon_sym_LT] = ACTIONS(4431),
    [anon_sym_GT] = ACTIONS(4431),
    [anon_sym_in] = ACTIONS(4433),
    [anon_sym_QMARK] = ACTIONS(4431),
    [anon_sym_BANG] = ACTIONS(4431),
    [anon_sym_PLUS_PLUS] = ACTIONS(4433),
    [anon_sym_DASH_DASH] = ACTIONS(4433),
    [anon_sym_PLUS] = ACTIONS(4431),
    [anon_sym_DASH] = ACTIONS(4431),
    [anon_sym_STAR] = ACTIONS(4433),
    [anon_sym_SLASH] = ACTIONS(4431),
    [anon_sym_PERCENT] = ACTIONS(4433),
    [anon_sym_CARET] = ACTIONS(4433),
    [anon_sym_PIPE] = ACTIONS(4431),
    [anon_sym_AMP] = ACTIONS(4431),
    [anon_sym_LT_LT] = ACTIONS(4433),
    [anon_sym_GT_GT] = ACTIONS(4431),
    [anon_sym_GT_GT_GT] = ACTIONS(4433),
    [anon_sym_EQ_EQ] = ACTIONS(4433),
    [anon_sym_BANG_EQ] = ACTIONS(4433),
    [anon_sym_GT_EQ] = ACTIONS(4433),
    [anon_sym_LT_EQ] = ACTIONS(4433),
    [anon_sym_DOT] = ACTIONS(4431),
    [anon_sym_EQ_GT] = ACTIONS(4433),
    [anon_sym_switch] = ACTIONS(4433),
    [anon_sym_when] = ACTIONS(4433),
    [anon_sym_DOT_DOT] = ACTIONS(4433),
    [anon_sym_and] = ACTIONS(4433),
    [anon_sym_or] = ACTIONS(4433),
    [anon_sym_AMP_AMP] = ACTIONS(4433),
    [anon_sym_PIPE_PIPE] = ACTIONS(4433),
    [anon_sym_QMARK_QMARK] = ACTIONS(4433),
    [anon_sym_on] = ACTIONS(4433),
    [anon_sym_equals] = ACTIONS(4433),
    [anon_sym_by] = ACTIONS(4433),
    [anon_sym_as] = ACTIONS(4433),
    [anon_sym_is] = ACTIONS(4433),
    [anon_sym_DASH_GT] = ACTIONS(4433),
    [anon_sym_with] = ACTIONS(4433),
    [aux_sym_preproc_if_token3] = ACTIONS(4433),
    [aux_sym_preproc_else_token1] = ACTIONS(4433),
    [aux_sym_preproc_elif_token1] = ACTIONS(4433),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4033] = {
    [sym_preproc_region] = STATE(4033),
    [sym_preproc_endregion] = STATE(4033),
    [sym_preproc_line] = STATE(4033),
    [sym_preproc_pragma] = STATE(4033),
    [sym_preproc_nullable] = STATE(4033),
    [sym_preproc_error] = STATE(4033),
    [sym_preproc_warning] = STATE(4033),
    [sym_preproc_define] = STATE(4033),
    [sym_preproc_undef] = STATE(4033),
    [anon_sym_SEMI] = ACTIONS(5596),
    [anon_sym_LBRACK] = ACTIONS(5596),
    [anon_sym_COLON] = ACTIONS(5596),
    [anon_sym_COMMA] = ACTIONS(5596),
    [anon_sym_RBRACK] = ACTIONS(5596),
    [anon_sym_LPAREN] = ACTIONS(5596),
    [anon_sym_RPAREN] = ACTIONS(5596),
    [anon_sym_RBRACE] = ACTIONS(5596),
    [anon_sym_LT] = ACTIONS(5598),
    [anon_sym_GT] = ACTIONS(5598),
    [anon_sym_in] = ACTIONS(5598),
    [anon_sym_QMARK] = ACTIONS(5598),
    [anon_sym_BANG] = ACTIONS(5598),
    [anon_sym_PLUS_PLUS] = ACTIONS(5596),
    [anon_sym_DASH_DASH] = ACTIONS(5596),
    [anon_sym_PLUS] = ACTIONS(5598),
    [anon_sym_DASH] = ACTIONS(5598),
    [anon_sym_STAR] = ACTIONS(5596),
    [anon_sym_SLASH] = ACTIONS(5598),
    [anon_sym_PERCENT] = ACTIONS(5596),
    [anon_sym_CARET] = ACTIONS(5596),
    [anon_sym_PIPE] = ACTIONS(5598),
    [anon_sym_AMP] = ACTIONS(5598),
    [anon_sym_LT_LT] = ACTIONS(5596),
    [anon_sym_GT_GT] = ACTIONS(5598),
    [anon_sym_GT_GT_GT] = ACTIONS(5596),
    [anon_sym_EQ_EQ] = ACTIONS(5596),
    [anon_sym_BANG_EQ] = ACTIONS(5596),
    [anon_sym_GT_EQ] = ACTIONS(5596),
    [anon_sym_LT_EQ] = ACTIONS(5596),
    [anon_sym_DOT] = ACTIONS(5598),
    [anon_sym_EQ_GT] = ACTIONS(5596),
    [anon_sym_switch] = ACTIONS(5596),
    [anon_sym_when] = ACTIONS(5596),
    [anon_sym_DOT_DOT] = ACTIONS(5596),
    [anon_sym_and] = ACTIONS(5596),
    [anon_sym_or] = ACTIONS(5596),
    [anon_sym_AMP_AMP] = ACTIONS(5596),
    [anon_sym_PIPE_PIPE] = ACTIONS(5596),
    [anon_sym_QMARK_QMARK] = ACTIONS(5596),
    [anon_sym_into] = ACTIONS(5596),
    [anon_sym_on] = ACTIONS(5596),
    [anon_sym_equals] = ACTIONS(5596),
    [anon_sym_by] = ACTIONS(5596),
    [anon_sym_as] = ACTIONS(5596),
    [anon_sym_is] = ACTIONS(5596),
    [anon_sym_DASH_GT] = ACTIONS(5596),
    [anon_sym_with] = ACTIONS(5596),
    [aux_sym_preproc_if_token3] = ACTIONS(5596),
    [aux_sym_preproc_else_token1] = ACTIONS(5596),
    [aux_sym_preproc_elif_token1] = ACTIONS(5596),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4034] = {
    [sym_preproc_region] = STATE(4034),
    [sym_preproc_endregion] = STATE(4034),
    [sym_preproc_line] = STATE(4034),
    [sym_preproc_pragma] = STATE(4034),
    [sym_preproc_nullable] = STATE(4034),
    [sym_preproc_error] = STATE(4034),
    [sym_preproc_warning] = STATE(4034),
    [sym_preproc_define] = STATE(4034),
    [sym_preproc_undef] = STATE(4034),
    [anon_sym_SEMI] = ACTIONS(2993),
    [anon_sym_LBRACK] = ACTIONS(2993),
    [anon_sym_COLON] = ACTIONS(2993),
    [anon_sym_COMMA] = ACTIONS(2993),
    [anon_sym_RBRACK] = ACTIONS(2993),
    [anon_sym_LPAREN] = ACTIONS(2993),
    [anon_sym_RPAREN] = ACTIONS(2993),
    [anon_sym_RBRACE] = ACTIONS(2993),
    [anon_sym_LT] = ACTIONS(2991),
    [anon_sym_GT] = ACTIONS(2991),
    [anon_sym_in] = ACTIONS(2991),
    [anon_sym_QMARK] = ACTIONS(2991),
    [anon_sym_BANG] = ACTIONS(2991),
    [anon_sym_PLUS_PLUS] = ACTIONS(2993),
    [anon_sym_DASH_DASH] = ACTIONS(2993),
    [anon_sym_PLUS] = ACTIONS(2991),
    [anon_sym_DASH] = ACTIONS(2991),
    [anon_sym_STAR] = ACTIONS(2993),
    [anon_sym_SLASH] = ACTIONS(2991),
    [anon_sym_PERCENT] = ACTIONS(2993),
    [anon_sym_CARET] = ACTIONS(2993),
    [anon_sym_PIPE] = ACTIONS(2991),
    [anon_sym_AMP] = ACTIONS(2991),
    [anon_sym_LT_LT] = ACTIONS(2993),
    [anon_sym_GT_GT] = ACTIONS(2991),
    [anon_sym_GT_GT_GT] = ACTIONS(2993),
    [anon_sym_EQ_EQ] = ACTIONS(2993),
    [anon_sym_BANG_EQ] = ACTIONS(2993),
    [anon_sym_GT_EQ] = ACTIONS(2993),
    [anon_sym_LT_EQ] = ACTIONS(2993),
    [anon_sym_DOT] = ACTIONS(2991),
    [anon_sym_EQ_GT] = ACTIONS(2993),
    [anon_sym_switch] = ACTIONS(2993),
    [anon_sym_when] = ACTIONS(2993),
    [anon_sym_DOT_DOT] = ACTIONS(2993),
    [anon_sym_and] = ACTIONS(2993),
    [anon_sym_or] = ACTIONS(2993),
    [anon_sym_AMP_AMP] = ACTIONS(2993),
    [anon_sym_PIPE_PIPE] = ACTIONS(2993),
    [anon_sym_QMARK_QMARK] = ACTIONS(2993),
    [anon_sym_into] = ACTIONS(2993),
    [anon_sym_on] = ACTIONS(2993),
    [anon_sym_equals] = ACTIONS(2993),
    [anon_sym_by] = ACTIONS(2993),
    [anon_sym_as] = ACTIONS(2993),
    [anon_sym_is] = ACTIONS(2993),
    [anon_sym_DASH_GT] = ACTIONS(2993),
    [anon_sym_with] = ACTIONS(2993),
    [aux_sym_preproc_if_token3] = ACTIONS(2993),
    [aux_sym_preproc_else_token1] = ACTIONS(2993),
    [aux_sym_preproc_elif_token1] = ACTIONS(2993),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4035] = {
    [sym_preproc_region] = STATE(4035),
    [sym_preproc_endregion] = STATE(4035),
    [sym_preproc_line] = STATE(4035),
    [sym_preproc_pragma] = STATE(4035),
    [sym_preproc_nullable] = STATE(4035),
    [sym_preproc_error] = STATE(4035),
    [sym_preproc_warning] = STATE(4035),
    [sym_preproc_define] = STATE(4035),
    [sym_preproc_undef] = STATE(4035),
    [anon_sym_SEMI] = ACTIONS(5913),
    [anon_sym_LBRACK] = ACTIONS(5913),
    [anon_sym_COLON] = ACTIONS(5913),
    [anon_sym_COMMA] = ACTIONS(5913),
    [anon_sym_RBRACK] = ACTIONS(5913),
    [anon_sym_LPAREN] = ACTIONS(5913),
    [anon_sym_RPAREN] = ACTIONS(5913),
    [anon_sym_RBRACE] = ACTIONS(5913),
    [anon_sym_LT] = ACTIONS(5915),
    [anon_sym_GT] = ACTIONS(5915),
    [anon_sym_in] = ACTIONS(5915),
    [anon_sym_QMARK] = ACTIONS(5915),
    [anon_sym_BANG] = ACTIONS(5915),
    [anon_sym_PLUS_PLUS] = ACTIONS(5913),
    [anon_sym_DASH_DASH] = ACTIONS(5913),
    [anon_sym_PLUS] = ACTIONS(5915),
    [anon_sym_DASH] = ACTIONS(5915),
    [anon_sym_STAR] = ACTIONS(5913),
    [anon_sym_SLASH] = ACTIONS(5915),
    [anon_sym_PERCENT] = ACTIONS(5913),
    [anon_sym_CARET] = ACTIONS(5913),
    [anon_sym_PIPE] = ACTIONS(5915),
    [anon_sym_AMP] = ACTIONS(5915),
    [anon_sym_LT_LT] = ACTIONS(5913),
    [anon_sym_GT_GT] = ACTIONS(5915),
    [anon_sym_GT_GT_GT] = ACTIONS(5913),
    [anon_sym_EQ_EQ] = ACTIONS(5913),
    [anon_sym_BANG_EQ] = ACTIONS(5913),
    [anon_sym_GT_EQ] = ACTIONS(5913),
    [anon_sym_LT_EQ] = ACTIONS(5913),
    [anon_sym_DOT] = ACTIONS(5915),
    [anon_sym_EQ_GT] = ACTIONS(5913),
    [anon_sym_switch] = ACTIONS(5913),
    [anon_sym_when] = ACTIONS(5913),
    [anon_sym_DOT_DOT] = ACTIONS(5913),
    [anon_sym_and] = ACTIONS(5913),
    [anon_sym_or] = ACTIONS(5913),
    [anon_sym_AMP_AMP] = ACTIONS(5913),
    [anon_sym_PIPE_PIPE] = ACTIONS(5913),
    [anon_sym_QMARK_QMARK] = ACTIONS(5913),
    [anon_sym_into] = ACTIONS(5913),
    [anon_sym_on] = ACTIONS(5913),
    [anon_sym_equals] = ACTIONS(5913),
    [anon_sym_by] = ACTIONS(5913),
    [anon_sym_as] = ACTIONS(5913),
    [anon_sym_is] = ACTIONS(5913),
    [anon_sym_DASH_GT] = ACTIONS(5913),
    [anon_sym_with] = ACTIONS(5913),
    [aux_sym_preproc_if_token3] = ACTIONS(5913),
    [aux_sym_preproc_else_token1] = ACTIONS(5913),
    [aux_sym_preproc_elif_token1] = ACTIONS(5913),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4036] = {
    [sym_preproc_region] = STATE(4036),
    [sym_preproc_endregion] = STATE(4036),
    [sym_preproc_line] = STATE(4036),
    [sym_preproc_pragma] = STATE(4036),
    [sym_preproc_nullable] = STATE(4036),
    [sym_preproc_error] = STATE(4036),
    [sym_preproc_warning] = STATE(4036),
    [sym_preproc_define] = STATE(4036),
    [sym_preproc_undef] = STATE(4036),
    [anon_sym_SEMI] = ACTIONS(4472),
    [anon_sym_LBRACK] = ACTIONS(4472),
    [anon_sym_COLON] = ACTIONS(4472),
    [anon_sym_COMMA] = ACTIONS(4472),
    [anon_sym_RBRACK] = ACTIONS(4472),
    [anon_sym_LPAREN] = ACTIONS(4472),
    [anon_sym_RPAREN] = ACTIONS(4472),
    [anon_sym_LBRACE] = ACTIONS(4472),
    [anon_sym_RBRACE] = ACTIONS(4472),
    [anon_sym_LT] = ACTIONS(4470),
    [anon_sym_GT] = ACTIONS(4470),
    [anon_sym_in] = ACTIONS(4472),
    [anon_sym_QMARK] = ACTIONS(4470),
    [anon_sym_BANG] = ACTIONS(4470),
    [anon_sym_PLUS_PLUS] = ACTIONS(4472),
    [anon_sym_DASH_DASH] = ACTIONS(4472),
    [anon_sym_PLUS] = ACTIONS(4470),
    [anon_sym_DASH] = ACTIONS(4470),
    [anon_sym_STAR] = ACTIONS(4472),
    [anon_sym_SLASH] = ACTIONS(4470),
    [anon_sym_PERCENT] = ACTIONS(4472),
    [anon_sym_CARET] = ACTIONS(4472),
    [anon_sym_PIPE] = ACTIONS(4470),
    [anon_sym_AMP] = ACTIONS(4470),
    [anon_sym_LT_LT] = ACTIONS(4472),
    [anon_sym_GT_GT] = ACTIONS(4470),
    [anon_sym_GT_GT_GT] = ACTIONS(4472),
    [anon_sym_EQ_EQ] = ACTIONS(4472),
    [anon_sym_BANG_EQ] = ACTIONS(4472),
    [anon_sym_GT_EQ] = ACTIONS(4472),
    [anon_sym_LT_EQ] = ACTIONS(4472),
    [anon_sym_DOT] = ACTIONS(4470),
    [anon_sym_EQ_GT] = ACTIONS(4472),
    [anon_sym_switch] = ACTIONS(4472),
    [anon_sym_when] = ACTIONS(4472),
    [anon_sym_DOT_DOT] = ACTIONS(4472),
    [anon_sym_and] = ACTIONS(4472),
    [anon_sym_or] = ACTIONS(4472),
    [anon_sym_AMP_AMP] = ACTIONS(4472),
    [anon_sym_PIPE_PIPE] = ACTIONS(4472),
    [anon_sym_QMARK_QMARK] = ACTIONS(4472),
    [anon_sym_on] = ACTIONS(4472),
    [anon_sym_equals] = ACTIONS(4472),
    [anon_sym_by] = ACTIONS(4472),
    [anon_sym_as] = ACTIONS(4472),
    [anon_sym_is] = ACTIONS(4472),
    [anon_sym_DASH_GT] = ACTIONS(4472),
    [anon_sym_with] = ACTIONS(4472),
    [aux_sym_preproc_if_token3] = ACTIONS(4472),
    [aux_sym_preproc_else_token1] = ACTIONS(4472),
    [aux_sym_preproc_elif_token1] = ACTIONS(4472),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4037] = {
    [sym_preproc_region] = STATE(4037),
    [sym_preproc_endregion] = STATE(4037),
    [sym_preproc_line] = STATE(4037),
    [sym_preproc_pragma] = STATE(4037),
    [sym_preproc_nullable] = STATE(4037),
    [sym_preproc_error] = STATE(4037),
    [sym_preproc_warning] = STATE(4037),
    [sym_preproc_define] = STATE(4037),
    [sym_preproc_undef] = STATE(4037),
    [anon_sym_SEMI] = ACTIONS(5556),
    [anon_sym_LBRACK] = ACTIONS(5556),
    [anon_sym_COLON] = ACTIONS(5556),
    [anon_sym_COMMA] = ACTIONS(5556),
    [anon_sym_RBRACK] = ACTIONS(5556),
    [anon_sym_LPAREN] = ACTIONS(5556),
    [anon_sym_RPAREN] = ACTIONS(5556),
    [anon_sym_RBRACE] = ACTIONS(5556),
    [anon_sym_LT] = ACTIONS(5558),
    [anon_sym_GT] = ACTIONS(5558),
    [anon_sym_in] = ACTIONS(5558),
    [anon_sym_QMARK] = ACTIONS(5558),
    [anon_sym_BANG] = ACTIONS(5558),
    [anon_sym_PLUS_PLUS] = ACTIONS(5556),
    [anon_sym_DASH_DASH] = ACTIONS(5556),
    [anon_sym_PLUS] = ACTIONS(5558),
    [anon_sym_DASH] = ACTIONS(5558),
    [anon_sym_STAR] = ACTIONS(5556),
    [anon_sym_SLASH] = ACTIONS(5558),
    [anon_sym_PERCENT] = ACTIONS(5556),
    [anon_sym_CARET] = ACTIONS(5556),
    [anon_sym_PIPE] = ACTIONS(5558),
    [anon_sym_AMP] = ACTIONS(5558),
    [anon_sym_LT_LT] = ACTIONS(5556),
    [anon_sym_GT_GT] = ACTIONS(5558),
    [anon_sym_GT_GT_GT] = ACTIONS(5556),
    [anon_sym_EQ_EQ] = ACTIONS(5556),
    [anon_sym_BANG_EQ] = ACTIONS(5556),
    [anon_sym_GT_EQ] = ACTIONS(5556),
    [anon_sym_LT_EQ] = ACTIONS(5556),
    [anon_sym_DOT] = ACTIONS(5558),
    [anon_sym_EQ_GT] = ACTIONS(5556),
    [anon_sym_switch] = ACTIONS(5556),
    [anon_sym_when] = ACTIONS(5556),
    [anon_sym_DOT_DOT] = ACTIONS(5556),
    [anon_sym_and] = ACTIONS(5556),
    [anon_sym_or] = ACTIONS(5556),
    [anon_sym_AMP_AMP] = ACTIONS(5556),
    [anon_sym_PIPE_PIPE] = ACTIONS(5556),
    [anon_sym_QMARK_QMARK] = ACTIONS(5556),
    [anon_sym_into] = ACTIONS(5556),
    [anon_sym_on] = ACTIONS(5556),
    [anon_sym_equals] = ACTIONS(5556),
    [anon_sym_by] = ACTIONS(5556),
    [anon_sym_as] = ACTIONS(5556),
    [anon_sym_is] = ACTIONS(5556),
    [anon_sym_DASH_GT] = ACTIONS(5556),
    [anon_sym_with] = ACTIONS(5556),
    [aux_sym_preproc_if_token3] = ACTIONS(5556),
    [aux_sym_preproc_else_token1] = ACTIONS(5556),
    [aux_sym_preproc_elif_token1] = ACTIONS(5556),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4038] = {
    [sym_preproc_region] = STATE(4038),
    [sym_preproc_endregion] = STATE(4038),
    [sym_preproc_line] = STATE(4038),
    [sym_preproc_pragma] = STATE(4038),
    [sym_preproc_nullable] = STATE(4038),
    [sym_preproc_error] = STATE(4038),
    [sym_preproc_warning] = STATE(4038),
    [sym_preproc_define] = STATE(4038),
    [sym_preproc_undef] = STATE(4038),
    [anon_sym_EQ] = ACTIONS(5917),
    [anon_sym_LBRACK] = ACTIONS(5286),
    [anon_sym_COLON] = ACTIONS(5286),
    [anon_sym_COMMA] = ACTIONS(5286),
    [anon_sym_LPAREN] = ACTIONS(5286),
    [anon_sym_LT] = ACTIONS(5288),
    [anon_sym_GT] = ACTIONS(5288),
    [anon_sym_QMARK] = ACTIONS(5288),
    [anon_sym_BANG] = ACTIONS(5288),
    [anon_sym_PLUS_PLUS] = ACTIONS(5286),
    [anon_sym_DASH_DASH] = ACTIONS(5286),
    [anon_sym_PLUS] = ACTIONS(5288),
    [anon_sym_DASH] = ACTIONS(5288),
    [anon_sym_STAR] = ACTIONS(5288),
    [anon_sym_SLASH] = ACTIONS(5288),
    [anon_sym_PERCENT] = ACTIONS(5288),
    [anon_sym_CARET] = ACTIONS(5288),
    [anon_sym_PIPE] = ACTIONS(5288),
    [anon_sym_AMP] = ACTIONS(5288),
    [anon_sym_LT_LT] = ACTIONS(5288),
    [anon_sym_GT_GT] = ACTIONS(5288),
    [anon_sym_GT_GT_GT] = ACTIONS(5288),
    [anon_sym_EQ_EQ] = ACTIONS(5286),
    [anon_sym_BANG_EQ] = ACTIONS(5286),
    [anon_sym_GT_EQ] = ACTIONS(5286),
    [anon_sym_LT_EQ] = ACTIONS(5286),
    [anon_sym_DOT] = ACTIONS(5288),
    [anon_sym_switch] = ACTIONS(5286),
    [anon_sym_DOT_DOT] = ACTIONS(5286),
    [anon_sym_and] = ACTIONS(5286),
    [anon_sym_or] = ACTIONS(5286),
    [anon_sym_PLUS_EQ] = ACTIONS(5919),
    [anon_sym_DASH_EQ] = ACTIONS(5919),
    [anon_sym_STAR_EQ] = ACTIONS(5919),
    [anon_sym_SLASH_EQ] = ACTIONS(5919),
    [anon_sym_PERCENT_EQ] = ACTIONS(5919),
    [anon_sym_AMP_EQ] = ACTIONS(5919),
    [anon_sym_CARET_EQ] = ACTIONS(5919),
    [anon_sym_PIPE_EQ] = ACTIONS(5919),
    [anon_sym_LT_LT_EQ] = ACTIONS(5919),
    [anon_sym_GT_GT_EQ] = ACTIONS(5919),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(5919),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(5919),
    [anon_sym_AMP_AMP] = ACTIONS(5286),
    [anon_sym_PIPE_PIPE] = ACTIONS(5286),
    [anon_sym_QMARK_QMARK] = ACTIONS(5288),
    [anon_sym_as] = ACTIONS(5286),
    [anon_sym_is] = ACTIONS(5286),
    [anon_sym_DASH_GT] = ACTIONS(5286),
    [anon_sym_with] = ACTIONS(5286),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(5286),
  },
  [4039] = {
    [sym_initializer_expression] = STATE(4328),
    [sym_preproc_region] = STATE(4039),
    [sym_preproc_endregion] = STATE(4039),
    [sym_preproc_line] = STATE(4039),
    [sym_preproc_pragma] = STATE(4039),
    [sym_preproc_nullable] = STATE(4039),
    [sym_preproc_error] = STATE(4039),
    [sym_preproc_warning] = STATE(4039),
    [sym_preproc_define] = STATE(4039),
    [sym_preproc_undef] = STATE(4039),
    [anon_sym_SEMI] = ACTIONS(5340),
    [anon_sym_LBRACK] = ACTIONS(5336),
    [anon_sym_COLON] = ACTIONS(5340),
    [anon_sym_COMMA] = ACTIONS(5340),
    [anon_sym_RBRACK] = ACTIONS(5340),
    [anon_sym_LPAREN] = ACTIONS(5340),
    [anon_sym_RPAREN] = ACTIONS(5340),
    [anon_sym_LBRACE] = ACTIONS(5921),
    [anon_sym_RBRACE] = ACTIONS(5340),
    [anon_sym_LT] = ACTIONS(5346),
    [anon_sym_GT] = ACTIONS(5346),
    [anon_sym_QMARK] = ACTIONS(5924),
    [anon_sym_BANG] = ACTIONS(5346),
    [anon_sym_PLUS_PLUS] = ACTIONS(5340),
    [anon_sym_DASH_DASH] = ACTIONS(5340),
    [anon_sym_PLUS] = ACTIONS(5346),
    [anon_sym_DASH] = ACTIONS(5346),
    [anon_sym_STAR] = ACTIONS(5340),
    [anon_sym_SLASH] = ACTIONS(5346),
    [anon_sym_PERCENT] = ACTIONS(5340),
    [anon_sym_CARET] = ACTIONS(5340),
    [anon_sym_PIPE] = ACTIONS(5346),
    [anon_sym_AMP] = ACTIONS(5346),
    [anon_sym_LT_LT] = ACTIONS(5340),
    [anon_sym_GT_GT] = ACTIONS(5346),
    [anon_sym_GT_GT_GT] = ACTIONS(5340),
    [anon_sym_EQ_EQ] = ACTIONS(5340),
    [anon_sym_BANG_EQ] = ACTIONS(5340),
    [anon_sym_GT_EQ] = ACTIONS(5340),
    [anon_sym_LT_EQ] = ACTIONS(5340),
    [anon_sym_DOT] = ACTIONS(5346),
    [anon_sym_EQ_GT] = ACTIONS(5340),
    [anon_sym_switch] = ACTIONS(5340),
    [anon_sym_when] = ACTIONS(5340),
    [anon_sym_DOT_DOT] = ACTIONS(5340),
    [anon_sym_and] = ACTIONS(5340),
    [anon_sym_or] = ACTIONS(5340),
    [anon_sym_AMP_AMP] = ACTIONS(5340),
    [anon_sym_PIPE_PIPE] = ACTIONS(5340),
    [anon_sym_QMARK_QMARK] = ACTIONS(5340),
    [anon_sym_on] = ACTIONS(5340),
    [anon_sym_equals] = ACTIONS(5340),
    [anon_sym_by] = ACTIONS(5340),
    [anon_sym_as] = ACTIONS(5340),
    [anon_sym_is] = ACTIONS(5340),
    [anon_sym_DASH_GT] = ACTIONS(5340),
    [anon_sym_with] = ACTIONS(5340),
    [aux_sym_preproc_if_token3] = ACTIONS(5340),
    [aux_sym_preproc_else_token1] = ACTIONS(5340),
    [aux_sym_preproc_elif_token1] = ACTIONS(5340),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4040] = {
    [sym_preproc_region] = STATE(4040),
    [sym_preproc_endregion] = STATE(4040),
    [sym_preproc_line] = STATE(4040),
    [sym_preproc_pragma] = STATE(4040),
    [sym_preproc_nullable] = STATE(4040),
    [sym_preproc_error] = STATE(4040),
    [sym_preproc_warning] = STATE(4040),
    [sym_preproc_define] = STATE(4040),
    [sym_preproc_undef] = STATE(4040),
    [anon_sym_SEMI] = ACTIONS(5913),
    [anon_sym_LBRACK] = ACTIONS(5913),
    [anon_sym_COLON] = ACTIONS(5913),
    [anon_sym_COMMA] = ACTIONS(5913),
    [anon_sym_RBRACK] = ACTIONS(5913),
    [anon_sym_LPAREN] = ACTIONS(5913),
    [anon_sym_RPAREN] = ACTIONS(5913),
    [anon_sym_RBRACE] = ACTIONS(5913),
    [anon_sym_LT] = ACTIONS(5915),
    [anon_sym_GT] = ACTIONS(5915),
    [anon_sym_in] = ACTIONS(5915),
    [anon_sym_QMARK] = ACTIONS(5915),
    [anon_sym_BANG] = ACTIONS(5915),
    [anon_sym_PLUS_PLUS] = ACTIONS(5913),
    [anon_sym_DASH_DASH] = ACTIONS(5913),
    [anon_sym_PLUS] = ACTIONS(5915),
    [anon_sym_DASH] = ACTIONS(5915),
    [anon_sym_STAR] = ACTIONS(5913),
    [anon_sym_SLASH] = ACTIONS(5915),
    [anon_sym_PERCENT] = ACTIONS(5913),
    [anon_sym_CARET] = ACTIONS(5913),
    [anon_sym_PIPE] = ACTIONS(5915),
    [anon_sym_AMP] = ACTIONS(5915),
    [anon_sym_LT_LT] = ACTIONS(5913),
    [anon_sym_GT_GT] = ACTIONS(5915),
    [anon_sym_GT_GT_GT] = ACTIONS(5913),
    [anon_sym_EQ_EQ] = ACTIONS(5913),
    [anon_sym_BANG_EQ] = ACTIONS(5913),
    [anon_sym_GT_EQ] = ACTIONS(5913),
    [anon_sym_LT_EQ] = ACTIONS(5913),
    [anon_sym_DOT] = ACTIONS(5915),
    [anon_sym_EQ_GT] = ACTIONS(5913),
    [anon_sym_switch] = ACTIONS(5913),
    [anon_sym_when] = ACTIONS(5913),
    [anon_sym_DOT_DOT] = ACTIONS(5913),
    [anon_sym_and] = ACTIONS(5913),
    [anon_sym_or] = ACTIONS(5913),
    [anon_sym_AMP_AMP] = ACTIONS(5913),
    [anon_sym_PIPE_PIPE] = ACTIONS(5913),
    [anon_sym_QMARK_QMARK] = ACTIONS(5913),
    [anon_sym_into] = ACTIONS(5913),
    [anon_sym_on] = ACTIONS(5913),
    [anon_sym_equals] = ACTIONS(5913),
    [anon_sym_by] = ACTIONS(5913),
    [anon_sym_as] = ACTIONS(5913),
    [anon_sym_is] = ACTIONS(5913),
    [anon_sym_DASH_GT] = ACTIONS(5913),
    [anon_sym_with] = ACTIONS(5913),
    [aux_sym_preproc_if_token3] = ACTIONS(5913),
    [aux_sym_preproc_else_token1] = ACTIONS(5913),
    [aux_sym_preproc_elif_token1] = ACTIONS(5913),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4041] = {
    [sym_preproc_region] = STATE(4041),
    [sym_preproc_endregion] = STATE(4041),
    [sym_preproc_line] = STATE(4041),
    [sym_preproc_pragma] = STATE(4041),
    [sym_preproc_nullable] = STATE(4041),
    [sym_preproc_error] = STATE(4041),
    [sym_preproc_warning] = STATE(4041),
    [sym_preproc_define] = STATE(4041),
    [sym_preproc_undef] = STATE(4041),
    [anon_sym_SEMI] = ACTIONS(5600),
    [anon_sym_LBRACK] = ACTIONS(5600),
    [anon_sym_COLON] = ACTIONS(5600),
    [anon_sym_COMMA] = ACTIONS(5600),
    [anon_sym_RBRACK] = ACTIONS(5600),
    [anon_sym_LPAREN] = ACTIONS(5600),
    [anon_sym_RPAREN] = ACTIONS(5600),
    [anon_sym_RBRACE] = ACTIONS(5600),
    [anon_sym_LT] = ACTIONS(5602),
    [anon_sym_GT] = ACTIONS(5602),
    [anon_sym_in] = ACTIONS(5602),
    [anon_sym_QMARK] = ACTIONS(5602),
    [anon_sym_BANG] = ACTIONS(5602),
    [anon_sym_PLUS_PLUS] = ACTIONS(5600),
    [anon_sym_DASH_DASH] = ACTIONS(5600),
    [anon_sym_PLUS] = ACTIONS(5602),
    [anon_sym_DASH] = ACTIONS(5602),
    [anon_sym_STAR] = ACTIONS(5600),
    [anon_sym_SLASH] = ACTIONS(5602),
    [anon_sym_PERCENT] = ACTIONS(5600),
    [anon_sym_CARET] = ACTIONS(5600),
    [anon_sym_PIPE] = ACTIONS(5602),
    [anon_sym_AMP] = ACTIONS(5602),
    [anon_sym_LT_LT] = ACTIONS(5600),
    [anon_sym_GT_GT] = ACTIONS(5602),
    [anon_sym_GT_GT_GT] = ACTIONS(5600),
    [anon_sym_EQ_EQ] = ACTIONS(5600),
    [anon_sym_BANG_EQ] = ACTIONS(5600),
    [anon_sym_GT_EQ] = ACTIONS(5600),
    [anon_sym_LT_EQ] = ACTIONS(5600),
    [anon_sym_DOT] = ACTIONS(5602),
    [anon_sym_EQ_GT] = ACTIONS(5600),
    [anon_sym_switch] = ACTIONS(5600),
    [anon_sym_when] = ACTIONS(5600),
    [anon_sym_DOT_DOT] = ACTIONS(5600),
    [anon_sym_and] = ACTIONS(5600),
    [anon_sym_or] = ACTIONS(5600),
    [anon_sym_AMP_AMP] = ACTIONS(5600),
    [anon_sym_PIPE_PIPE] = ACTIONS(5600),
    [anon_sym_QMARK_QMARK] = ACTIONS(5600),
    [anon_sym_into] = ACTIONS(5600),
    [anon_sym_on] = ACTIONS(5600),
    [anon_sym_equals] = ACTIONS(5600),
    [anon_sym_by] = ACTIONS(5600),
    [anon_sym_as] = ACTIONS(5600),
    [anon_sym_is] = ACTIONS(5600),
    [anon_sym_DASH_GT] = ACTIONS(5600),
    [anon_sym_with] = ACTIONS(5600),
    [aux_sym_preproc_if_token3] = ACTIONS(5600),
    [aux_sym_preproc_else_token1] = ACTIONS(5600),
    [aux_sym_preproc_elif_token1] = ACTIONS(5600),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4042] = {
    [sym_preproc_region] = STATE(4042),
    [sym_preproc_endregion] = STATE(4042),
    [sym_preproc_line] = STATE(4042),
    [sym_preproc_pragma] = STATE(4042),
    [sym_preproc_nullable] = STATE(4042),
    [sym_preproc_error] = STATE(4042),
    [sym_preproc_warning] = STATE(4042),
    [sym_preproc_define] = STATE(4042),
    [sym_preproc_undef] = STATE(4042),
    [anon_sym_SEMI] = ACTIONS(5604),
    [anon_sym_LBRACK] = ACTIONS(5604),
    [anon_sym_COLON] = ACTIONS(5604),
    [anon_sym_COMMA] = ACTIONS(5604),
    [anon_sym_RBRACK] = ACTIONS(5604),
    [anon_sym_LPAREN] = ACTIONS(5604),
    [anon_sym_RPAREN] = ACTIONS(5604),
    [anon_sym_RBRACE] = ACTIONS(5604),
    [anon_sym_LT] = ACTIONS(5606),
    [anon_sym_GT] = ACTIONS(5606),
    [anon_sym_in] = ACTIONS(5606),
    [anon_sym_QMARK] = ACTIONS(5606),
    [anon_sym_BANG] = ACTIONS(5606),
    [anon_sym_PLUS_PLUS] = ACTIONS(5604),
    [anon_sym_DASH_DASH] = ACTIONS(5604),
    [anon_sym_PLUS] = ACTIONS(5606),
    [anon_sym_DASH] = ACTIONS(5606),
    [anon_sym_STAR] = ACTIONS(5604),
    [anon_sym_SLASH] = ACTIONS(5606),
    [anon_sym_PERCENT] = ACTIONS(5604),
    [anon_sym_CARET] = ACTIONS(5604),
    [anon_sym_PIPE] = ACTIONS(5606),
    [anon_sym_AMP] = ACTIONS(5606),
    [anon_sym_LT_LT] = ACTIONS(5604),
    [anon_sym_GT_GT] = ACTIONS(5606),
    [anon_sym_GT_GT_GT] = ACTIONS(5604),
    [anon_sym_EQ_EQ] = ACTIONS(5604),
    [anon_sym_BANG_EQ] = ACTIONS(5604),
    [anon_sym_GT_EQ] = ACTIONS(5604),
    [anon_sym_LT_EQ] = ACTIONS(5604),
    [anon_sym_DOT] = ACTIONS(5606),
    [anon_sym_EQ_GT] = ACTIONS(5604),
    [anon_sym_switch] = ACTIONS(5604),
    [anon_sym_when] = ACTIONS(5604),
    [anon_sym_DOT_DOT] = ACTIONS(5604),
    [anon_sym_and] = ACTIONS(5604),
    [anon_sym_or] = ACTIONS(5604),
    [anon_sym_AMP_AMP] = ACTIONS(5604),
    [anon_sym_PIPE_PIPE] = ACTIONS(5604),
    [anon_sym_QMARK_QMARK] = ACTIONS(5604),
    [anon_sym_into] = ACTIONS(5604),
    [anon_sym_on] = ACTIONS(5604),
    [anon_sym_equals] = ACTIONS(5604),
    [anon_sym_by] = ACTIONS(5604),
    [anon_sym_as] = ACTIONS(5604),
    [anon_sym_is] = ACTIONS(5604),
    [anon_sym_DASH_GT] = ACTIONS(5604),
    [anon_sym_with] = ACTIONS(5604),
    [aux_sym_preproc_if_token3] = ACTIONS(5604),
    [aux_sym_preproc_else_token1] = ACTIONS(5604),
    [aux_sym_preproc_elif_token1] = ACTIONS(5604),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4043] = {
    [sym_preproc_region] = STATE(4043),
    [sym_preproc_endregion] = STATE(4043),
    [sym_preproc_line] = STATE(4043),
    [sym_preproc_pragma] = STATE(4043),
    [sym_preproc_nullable] = STATE(4043),
    [sym_preproc_error] = STATE(4043),
    [sym_preproc_warning] = STATE(4043),
    [sym_preproc_define] = STATE(4043),
    [sym_preproc_undef] = STATE(4043),
    [anon_sym_SEMI] = ACTIONS(5928),
    [anon_sym_LBRACK] = ACTIONS(5928),
    [anon_sym_COLON] = ACTIONS(5928),
    [anon_sym_COMMA] = ACTIONS(5928),
    [anon_sym_RBRACK] = ACTIONS(5928),
    [anon_sym_LPAREN] = ACTIONS(5928),
    [anon_sym_RPAREN] = ACTIONS(5928),
    [anon_sym_RBRACE] = ACTIONS(5928),
    [anon_sym_LT] = ACTIONS(5930),
    [anon_sym_GT] = ACTIONS(5930),
    [anon_sym_in] = ACTIONS(5930),
    [anon_sym_QMARK] = ACTIONS(5930),
    [anon_sym_BANG] = ACTIONS(5930),
    [anon_sym_PLUS_PLUS] = ACTIONS(5928),
    [anon_sym_DASH_DASH] = ACTIONS(5928),
    [anon_sym_PLUS] = ACTIONS(5930),
    [anon_sym_DASH] = ACTIONS(5930),
    [anon_sym_STAR] = ACTIONS(5928),
    [anon_sym_SLASH] = ACTIONS(5930),
    [anon_sym_PERCENT] = ACTIONS(5928),
    [anon_sym_CARET] = ACTIONS(5928),
    [anon_sym_PIPE] = ACTIONS(5930),
    [anon_sym_AMP] = ACTIONS(5930),
    [anon_sym_LT_LT] = ACTIONS(5928),
    [anon_sym_GT_GT] = ACTIONS(5930),
    [anon_sym_GT_GT_GT] = ACTIONS(5928),
    [anon_sym_EQ_EQ] = ACTIONS(5928),
    [anon_sym_BANG_EQ] = ACTIONS(5928),
    [anon_sym_GT_EQ] = ACTIONS(5928),
    [anon_sym_LT_EQ] = ACTIONS(5928),
    [anon_sym_DOT] = ACTIONS(5930),
    [anon_sym_EQ_GT] = ACTIONS(5928),
    [anon_sym_switch] = ACTIONS(5928),
    [anon_sym_when] = ACTIONS(5928),
    [anon_sym_DOT_DOT] = ACTIONS(5928),
    [anon_sym_and] = ACTIONS(5928),
    [anon_sym_or] = ACTIONS(5928),
    [anon_sym_AMP_AMP] = ACTIONS(5928),
    [anon_sym_PIPE_PIPE] = ACTIONS(5928),
    [anon_sym_QMARK_QMARK] = ACTIONS(5928),
    [anon_sym_into] = ACTIONS(5928),
    [anon_sym_on] = ACTIONS(5928),
    [anon_sym_equals] = ACTIONS(5928),
    [anon_sym_by] = ACTIONS(5928),
    [anon_sym_as] = ACTIONS(5928),
    [anon_sym_is] = ACTIONS(5928),
    [anon_sym_DASH_GT] = ACTIONS(5928),
    [anon_sym_with] = ACTIONS(5928),
    [aux_sym_preproc_if_token3] = ACTIONS(5928),
    [aux_sym_preproc_else_token1] = ACTIONS(5928),
    [aux_sym_preproc_elif_token1] = ACTIONS(5928),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4044] = {
    [sym_preproc_region] = STATE(4044),
    [sym_preproc_endregion] = STATE(4044),
    [sym_preproc_line] = STATE(4044),
    [sym_preproc_pragma] = STATE(4044),
    [sym_preproc_nullable] = STATE(4044),
    [sym_preproc_error] = STATE(4044),
    [sym_preproc_warning] = STATE(4044),
    [sym_preproc_define] = STATE(4044),
    [sym_preproc_undef] = STATE(4044),
    [anon_sym_SEMI] = ACTIONS(5548),
    [anon_sym_LBRACK] = ACTIONS(5548),
    [anon_sym_COLON] = ACTIONS(5548),
    [anon_sym_COMMA] = ACTIONS(5548),
    [anon_sym_RBRACK] = ACTIONS(5548),
    [anon_sym_LPAREN] = ACTIONS(5548),
    [anon_sym_RPAREN] = ACTIONS(5548),
    [anon_sym_RBRACE] = ACTIONS(5548),
    [anon_sym_LT] = ACTIONS(5550),
    [anon_sym_GT] = ACTIONS(5550),
    [anon_sym_in] = ACTIONS(5550),
    [anon_sym_QMARK] = ACTIONS(5550),
    [anon_sym_BANG] = ACTIONS(5550),
    [anon_sym_PLUS_PLUS] = ACTIONS(5548),
    [anon_sym_DASH_DASH] = ACTIONS(5548),
    [anon_sym_PLUS] = ACTIONS(5550),
    [anon_sym_DASH] = ACTIONS(5550),
    [anon_sym_STAR] = ACTIONS(5548),
    [anon_sym_SLASH] = ACTIONS(5550),
    [anon_sym_PERCENT] = ACTIONS(5548),
    [anon_sym_CARET] = ACTIONS(5548),
    [anon_sym_PIPE] = ACTIONS(5550),
    [anon_sym_AMP] = ACTIONS(5550),
    [anon_sym_LT_LT] = ACTIONS(5548),
    [anon_sym_GT_GT] = ACTIONS(5550),
    [anon_sym_GT_GT_GT] = ACTIONS(5548),
    [anon_sym_EQ_EQ] = ACTIONS(5548),
    [anon_sym_BANG_EQ] = ACTIONS(5548),
    [anon_sym_GT_EQ] = ACTIONS(5548),
    [anon_sym_LT_EQ] = ACTIONS(5548),
    [anon_sym_DOT] = ACTIONS(5550),
    [anon_sym_EQ_GT] = ACTIONS(5548),
    [anon_sym_switch] = ACTIONS(5548),
    [anon_sym_when] = ACTIONS(5548),
    [anon_sym_DOT_DOT] = ACTIONS(5548),
    [anon_sym_and] = ACTIONS(5548),
    [anon_sym_or] = ACTIONS(5548),
    [anon_sym_AMP_AMP] = ACTIONS(5548),
    [anon_sym_PIPE_PIPE] = ACTIONS(5548),
    [anon_sym_QMARK_QMARK] = ACTIONS(5548),
    [anon_sym_into] = ACTIONS(5548),
    [anon_sym_on] = ACTIONS(5548),
    [anon_sym_equals] = ACTIONS(5548),
    [anon_sym_by] = ACTIONS(5548),
    [anon_sym_as] = ACTIONS(5548),
    [anon_sym_is] = ACTIONS(5548),
    [anon_sym_DASH_GT] = ACTIONS(5548),
    [anon_sym_with] = ACTIONS(5548),
    [aux_sym_preproc_if_token3] = ACTIONS(5548),
    [aux_sym_preproc_else_token1] = ACTIONS(5548),
    [aux_sym_preproc_elif_token1] = ACTIONS(5548),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4045] = {
    [sym_preproc_region] = STATE(4045),
    [sym_preproc_endregion] = STATE(4045),
    [sym_preproc_line] = STATE(4045),
    [sym_preproc_pragma] = STATE(4045),
    [sym_preproc_nullable] = STATE(4045),
    [sym_preproc_error] = STATE(4045),
    [sym_preproc_warning] = STATE(4045),
    [sym_preproc_define] = STATE(4045),
    [sym_preproc_undef] = STATE(4045),
    [anon_sym_SEMI] = ACTIONS(4554),
    [anon_sym_LBRACK] = ACTIONS(4554),
    [anon_sym_COLON] = ACTIONS(4554),
    [anon_sym_COMMA] = ACTIONS(4554),
    [anon_sym_RBRACK] = ACTIONS(4554),
    [anon_sym_LPAREN] = ACTIONS(4554),
    [anon_sym_RPAREN] = ACTIONS(4554),
    [anon_sym_LBRACE] = ACTIONS(4554),
    [anon_sym_RBRACE] = ACTIONS(4554),
    [anon_sym_LT] = ACTIONS(4552),
    [anon_sym_GT] = ACTIONS(4552),
    [anon_sym_in] = ACTIONS(4554),
    [anon_sym_QMARK] = ACTIONS(4552),
    [anon_sym_BANG] = ACTIONS(4552),
    [anon_sym_PLUS_PLUS] = ACTIONS(4554),
    [anon_sym_DASH_DASH] = ACTIONS(4554),
    [anon_sym_PLUS] = ACTIONS(4552),
    [anon_sym_DASH] = ACTIONS(4552),
    [anon_sym_STAR] = ACTIONS(4554),
    [anon_sym_SLASH] = ACTIONS(4552),
    [anon_sym_PERCENT] = ACTIONS(4554),
    [anon_sym_CARET] = ACTIONS(4554),
    [anon_sym_PIPE] = ACTIONS(4552),
    [anon_sym_AMP] = ACTIONS(4552),
    [anon_sym_LT_LT] = ACTIONS(4554),
    [anon_sym_GT_GT] = ACTIONS(4552),
    [anon_sym_GT_GT_GT] = ACTIONS(4554),
    [anon_sym_EQ_EQ] = ACTIONS(4554),
    [anon_sym_BANG_EQ] = ACTIONS(4554),
    [anon_sym_GT_EQ] = ACTIONS(4554),
    [anon_sym_LT_EQ] = ACTIONS(4554),
    [anon_sym_DOT] = ACTIONS(4552),
    [anon_sym_EQ_GT] = ACTIONS(4554),
    [anon_sym_switch] = ACTIONS(4554),
    [anon_sym_when] = ACTIONS(4554),
    [anon_sym_DOT_DOT] = ACTIONS(4554),
    [anon_sym_and] = ACTIONS(4554),
    [anon_sym_or] = ACTIONS(4554),
    [anon_sym_AMP_AMP] = ACTIONS(4554),
    [anon_sym_PIPE_PIPE] = ACTIONS(4554),
    [anon_sym_QMARK_QMARK] = ACTIONS(4554),
    [anon_sym_on] = ACTIONS(4554),
    [anon_sym_equals] = ACTIONS(4554),
    [anon_sym_by] = ACTIONS(4554),
    [anon_sym_as] = ACTIONS(4554),
    [anon_sym_is] = ACTIONS(4554),
    [anon_sym_DASH_GT] = ACTIONS(4554),
    [anon_sym_with] = ACTIONS(4554),
    [aux_sym_preproc_if_token3] = ACTIONS(4554),
    [aux_sym_preproc_else_token1] = ACTIONS(4554),
    [aux_sym_preproc_elif_token1] = ACTIONS(4554),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4046] = {
    [sym_preproc_region] = STATE(4046),
    [sym_preproc_endregion] = STATE(4046),
    [sym_preproc_line] = STATE(4046),
    [sym_preproc_pragma] = STATE(4046),
    [sym_preproc_nullable] = STATE(4046),
    [sym_preproc_error] = STATE(4046),
    [sym_preproc_warning] = STATE(4046),
    [sym_preproc_define] = STATE(4046),
    [sym_preproc_undef] = STATE(4046),
    [anon_sym_SEMI] = ACTIONS(5616),
    [anon_sym_LBRACK] = ACTIONS(5616),
    [anon_sym_COLON] = ACTIONS(5616),
    [anon_sym_COMMA] = ACTIONS(5616),
    [anon_sym_RBRACK] = ACTIONS(5616),
    [anon_sym_LPAREN] = ACTIONS(5616),
    [anon_sym_RPAREN] = ACTIONS(5616),
    [anon_sym_RBRACE] = ACTIONS(5616),
    [anon_sym_LT] = ACTIONS(5618),
    [anon_sym_GT] = ACTIONS(5618),
    [anon_sym_in] = ACTIONS(5618),
    [anon_sym_QMARK] = ACTIONS(5618),
    [anon_sym_BANG] = ACTIONS(5618),
    [anon_sym_PLUS_PLUS] = ACTIONS(5616),
    [anon_sym_DASH_DASH] = ACTIONS(5616),
    [anon_sym_PLUS] = ACTIONS(5618),
    [anon_sym_DASH] = ACTIONS(5618),
    [anon_sym_STAR] = ACTIONS(5616),
    [anon_sym_SLASH] = ACTIONS(5618),
    [anon_sym_PERCENT] = ACTIONS(5616),
    [anon_sym_CARET] = ACTIONS(5616),
    [anon_sym_PIPE] = ACTIONS(5618),
    [anon_sym_AMP] = ACTIONS(5618),
    [anon_sym_LT_LT] = ACTIONS(5616),
    [anon_sym_GT_GT] = ACTIONS(5618),
    [anon_sym_GT_GT_GT] = ACTIONS(5616),
    [anon_sym_EQ_EQ] = ACTIONS(5616),
    [anon_sym_BANG_EQ] = ACTIONS(5616),
    [anon_sym_GT_EQ] = ACTIONS(5616),
    [anon_sym_LT_EQ] = ACTIONS(5616),
    [anon_sym_DOT] = ACTIONS(5618),
    [anon_sym_EQ_GT] = ACTIONS(5616),
    [anon_sym_switch] = ACTIONS(5616),
    [anon_sym_when] = ACTIONS(5616),
    [anon_sym_DOT_DOT] = ACTIONS(5616),
    [anon_sym_and] = ACTIONS(5616),
    [anon_sym_or] = ACTIONS(5616),
    [anon_sym_AMP_AMP] = ACTIONS(5616),
    [anon_sym_PIPE_PIPE] = ACTIONS(5616),
    [anon_sym_QMARK_QMARK] = ACTIONS(5616),
    [anon_sym_into] = ACTIONS(5616),
    [anon_sym_on] = ACTIONS(5616),
    [anon_sym_equals] = ACTIONS(5616),
    [anon_sym_by] = ACTIONS(5616),
    [anon_sym_as] = ACTIONS(5616),
    [anon_sym_is] = ACTIONS(5616),
    [anon_sym_DASH_GT] = ACTIONS(5616),
    [anon_sym_with] = ACTIONS(5616),
    [aux_sym_preproc_if_token3] = ACTIONS(5616),
    [aux_sym_preproc_else_token1] = ACTIONS(5616),
    [aux_sym_preproc_elif_token1] = ACTIONS(5616),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4047] = {
    [sym_preproc_region] = STATE(4047),
    [sym_preproc_endregion] = STATE(4047),
    [sym_preproc_line] = STATE(4047),
    [sym_preproc_pragma] = STATE(4047),
    [sym_preproc_nullable] = STATE(4047),
    [sym_preproc_error] = STATE(4047),
    [sym_preproc_warning] = STATE(4047),
    [sym_preproc_define] = STATE(4047),
    [sym_preproc_undef] = STATE(4047),
    [anon_sym_SEMI] = ACTIONS(5670),
    [anon_sym_LBRACK] = ACTIONS(5670),
    [anon_sym_COLON] = ACTIONS(5670),
    [anon_sym_COMMA] = ACTIONS(5670),
    [anon_sym_RBRACK] = ACTIONS(5670),
    [anon_sym_LPAREN] = ACTIONS(5670),
    [anon_sym_RPAREN] = ACTIONS(5670),
    [anon_sym_RBRACE] = ACTIONS(5670),
    [anon_sym_LT] = ACTIONS(5672),
    [anon_sym_GT] = ACTIONS(5672),
    [anon_sym_in] = ACTIONS(5672),
    [anon_sym_QMARK] = ACTIONS(5672),
    [anon_sym_BANG] = ACTIONS(5672),
    [anon_sym_PLUS_PLUS] = ACTIONS(5670),
    [anon_sym_DASH_DASH] = ACTIONS(5670),
    [anon_sym_PLUS] = ACTIONS(5672),
    [anon_sym_DASH] = ACTIONS(5672),
    [anon_sym_STAR] = ACTIONS(5670),
    [anon_sym_SLASH] = ACTIONS(5672),
    [anon_sym_PERCENT] = ACTIONS(5670),
    [anon_sym_CARET] = ACTIONS(5670),
    [anon_sym_PIPE] = ACTIONS(5672),
    [anon_sym_AMP] = ACTIONS(5672),
    [anon_sym_LT_LT] = ACTIONS(5670),
    [anon_sym_GT_GT] = ACTIONS(5672),
    [anon_sym_GT_GT_GT] = ACTIONS(5670),
    [anon_sym_EQ_EQ] = ACTIONS(5670),
    [anon_sym_BANG_EQ] = ACTIONS(5670),
    [anon_sym_GT_EQ] = ACTIONS(5670),
    [anon_sym_LT_EQ] = ACTIONS(5670),
    [anon_sym_DOT] = ACTIONS(5672),
    [anon_sym_EQ_GT] = ACTIONS(5670),
    [anon_sym_switch] = ACTIONS(5670),
    [anon_sym_when] = ACTIONS(5670),
    [anon_sym_DOT_DOT] = ACTIONS(5670),
    [anon_sym_and] = ACTIONS(5670),
    [anon_sym_or] = ACTIONS(5670),
    [anon_sym_AMP_AMP] = ACTIONS(5670),
    [anon_sym_PIPE_PIPE] = ACTIONS(5670),
    [anon_sym_QMARK_QMARK] = ACTIONS(5670),
    [anon_sym_into] = ACTIONS(5670),
    [anon_sym_on] = ACTIONS(5670),
    [anon_sym_equals] = ACTIONS(5670),
    [anon_sym_by] = ACTIONS(5670),
    [anon_sym_as] = ACTIONS(5670),
    [anon_sym_is] = ACTIONS(5670),
    [anon_sym_DASH_GT] = ACTIONS(5670),
    [anon_sym_with] = ACTIONS(5670),
    [aux_sym_preproc_if_token3] = ACTIONS(5670),
    [aux_sym_preproc_else_token1] = ACTIONS(5670),
    [aux_sym_preproc_elif_token1] = ACTIONS(5670),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4048] = {
    [sym_preproc_region] = STATE(4048),
    [sym_preproc_endregion] = STATE(4048),
    [sym_preproc_line] = STATE(4048),
    [sym_preproc_pragma] = STATE(4048),
    [sym_preproc_nullable] = STATE(4048),
    [sym_preproc_error] = STATE(4048),
    [sym_preproc_warning] = STATE(4048),
    [sym_preproc_define] = STATE(4048),
    [sym_preproc_undef] = STATE(4048),
    [anon_sym_SEMI] = ACTIONS(5664),
    [anon_sym_LBRACK] = ACTIONS(5664),
    [anon_sym_COLON] = ACTIONS(5664),
    [anon_sym_COMMA] = ACTIONS(5664),
    [anon_sym_RBRACK] = ACTIONS(5664),
    [anon_sym_LPAREN] = ACTIONS(5664),
    [anon_sym_RPAREN] = ACTIONS(5664),
    [anon_sym_RBRACE] = ACTIONS(5664),
    [anon_sym_LT] = ACTIONS(5666),
    [anon_sym_GT] = ACTIONS(5666),
    [anon_sym_in] = ACTIONS(5666),
    [anon_sym_QMARK] = ACTIONS(5666),
    [anon_sym_BANG] = ACTIONS(5666),
    [anon_sym_PLUS_PLUS] = ACTIONS(5664),
    [anon_sym_DASH_DASH] = ACTIONS(5664),
    [anon_sym_PLUS] = ACTIONS(5666),
    [anon_sym_DASH] = ACTIONS(5666),
    [anon_sym_STAR] = ACTIONS(5664),
    [anon_sym_SLASH] = ACTIONS(5666),
    [anon_sym_PERCENT] = ACTIONS(5664),
    [anon_sym_CARET] = ACTIONS(5664),
    [anon_sym_PIPE] = ACTIONS(5666),
    [anon_sym_AMP] = ACTIONS(5666),
    [anon_sym_LT_LT] = ACTIONS(5664),
    [anon_sym_GT_GT] = ACTIONS(5666),
    [anon_sym_GT_GT_GT] = ACTIONS(5664),
    [anon_sym_EQ_EQ] = ACTIONS(5664),
    [anon_sym_BANG_EQ] = ACTIONS(5664),
    [anon_sym_GT_EQ] = ACTIONS(5664),
    [anon_sym_LT_EQ] = ACTIONS(5664),
    [anon_sym_DOT] = ACTIONS(5666),
    [anon_sym_EQ_GT] = ACTIONS(5664),
    [anon_sym_switch] = ACTIONS(5664),
    [anon_sym_when] = ACTIONS(5664),
    [anon_sym_DOT_DOT] = ACTIONS(5664),
    [anon_sym_and] = ACTIONS(5664),
    [anon_sym_or] = ACTIONS(5664),
    [anon_sym_AMP_AMP] = ACTIONS(5664),
    [anon_sym_PIPE_PIPE] = ACTIONS(5664),
    [anon_sym_QMARK_QMARK] = ACTIONS(5664),
    [anon_sym_into] = ACTIONS(5664),
    [anon_sym_on] = ACTIONS(5664),
    [anon_sym_equals] = ACTIONS(5664),
    [anon_sym_by] = ACTIONS(5664),
    [anon_sym_as] = ACTIONS(5664),
    [anon_sym_is] = ACTIONS(5664),
    [anon_sym_DASH_GT] = ACTIONS(5664),
    [anon_sym_with] = ACTIONS(5664),
    [aux_sym_preproc_if_token3] = ACTIONS(5664),
    [aux_sym_preproc_else_token1] = ACTIONS(5664),
    [aux_sym_preproc_elif_token1] = ACTIONS(5664),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4049] = {
    [sym_preproc_region] = STATE(4049),
    [sym_preproc_endregion] = STATE(4049),
    [sym_preproc_line] = STATE(4049),
    [sym_preproc_pragma] = STATE(4049),
    [sym_preproc_nullable] = STATE(4049),
    [sym_preproc_error] = STATE(4049),
    [sym_preproc_warning] = STATE(4049),
    [sym_preproc_define] = STATE(4049),
    [sym_preproc_undef] = STATE(4049),
    [anon_sym_SEMI] = ACTIONS(5678),
    [anon_sym_LBRACK] = ACTIONS(5678),
    [anon_sym_COLON] = ACTIONS(5678),
    [anon_sym_COMMA] = ACTIONS(5678),
    [anon_sym_RBRACK] = ACTIONS(5678),
    [anon_sym_LPAREN] = ACTIONS(5678),
    [anon_sym_RPAREN] = ACTIONS(5678),
    [anon_sym_RBRACE] = ACTIONS(5678),
    [anon_sym_LT] = ACTIONS(5680),
    [anon_sym_GT] = ACTIONS(5680),
    [anon_sym_in] = ACTIONS(5680),
    [anon_sym_QMARK] = ACTIONS(5680),
    [anon_sym_BANG] = ACTIONS(5680),
    [anon_sym_PLUS_PLUS] = ACTIONS(5678),
    [anon_sym_DASH_DASH] = ACTIONS(5678),
    [anon_sym_PLUS] = ACTIONS(5680),
    [anon_sym_DASH] = ACTIONS(5680),
    [anon_sym_STAR] = ACTIONS(5678),
    [anon_sym_SLASH] = ACTIONS(5680),
    [anon_sym_PERCENT] = ACTIONS(5678),
    [anon_sym_CARET] = ACTIONS(5678),
    [anon_sym_PIPE] = ACTIONS(5680),
    [anon_sym_AMP] = ACTIONS(5680),
    [anon_sym_LT_LT] = ACTIONS(5678),
    [anon_sym_GT_GT] = ACTIONS(5680),
    [anon_sym_GT_GT_GT] = ACTIONS(5678),
    [anon_sym_EQ_EQ] = ACTIONS(5678),
    [anon_sym_BANG_EQ] = ACTIONS(5678),
    [anon_sym_GT_EQ] = ACTIONS(5678),
    [anon_sym_LT_EQ] = ACTIONS(5678),
    [anon_sym_DOT] = ACTIONS(5680),
    [anon_sym_EQ_GT] = ACTIONS(5678),
    [anon_sym_switch] = ACTIONS(5678),
    [anon_sym_when] = ACTIONS(5678),
    [anon_sym_DOT_DOT] = ACTIONS(5678),
    [anon_sym_and] = ACTIONS(5678),
    [anon_sym_or] = ACTIONS(5678),
    [anon_sym_AMP_AMP] = ACTIONS(5678),
    [anon_sym_PIPE_PIPE] = ACTIONS(5678),
    [anon_sym_QMARK_QMARK] = ACTIONS(5678),
    [anon_sym_into] = ACTIONS(5678),
    [anon_sym_on] = ACTIONS(5678),
    [anon_sym_equals] = ACTIONS(5678),
    [anon_sym_by] = ACTIONS(5678),
    [anon_sym_as] = ACTIONS(5678),
    [anon_sym_is] = ACTIONS(5678),
    [anon_sym_DASH_GT] = ACTIONS(5678),
    [anon_sym_with] = ACTIONS(5678),
    [aux_sym_preproc_if_token3] = ACTIONS(5678),
    [aux_sym_preproc_else_token1] = ACTIONS(5678),
    [aux_sym_preproc_elif_token1] = ACTIONS(5678),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4050] = {
    [sym_preproc_region] = STATE(4050),
    [sym_preproc_endregion] = STATE(4050),
    [sym_preproc_line] = STATE(4050),
    [sym_preproc_pragma] = STATE(4050),
    [sym_preproc_nullable] = STATE(4050),
    [sym_preproc_error] = STATE(4050),
    [sym_preproc_warning] = STATE(4050),
    [sym_preproc_define] = STATE(4050),
    [sym_preproc_undef] = STATE(4050),
    [anon_sym_SEMI] = ACTIONS(4626),
    [anon_sym_LBRACK] = ACTIONS(4626),
    [anon_sym_COLON] = ACTIONS(4626),
    [anon_sym_COMMA] = ACTIONS(4626),
    [anon_sym_RBRACK] = ACTIONS(4626),
    [anon_sym_LPAREN] = ACTIONS(4626),
    [anon_sym_RPAREN] = ACTIONS(4626),
    [anon_sym_LBRACE] = ACTIONS(4626),
    [anon_sym_RBRACE] = ACTIONS(4626),
    [anon_sym_LT] = ACTIONS(4624),
    [anon_sym_GT] = ACTIONS(4624),
    [anon_sym_in] = ACTIONS(4626),
    [anon_sym_QMARK] = ACTIONS(4624),
    [anon_sym_BANG] = ACTIONS(4624),
    [anon_sym_PLUS_PLUS] = ACTIONS(4626),
    [anon_sym_DASH_DASH] = ACTIONS(4626),
    [anon_sym_PLUS] = ACTIONS(4624),
    [anon_sym_DASH] = ACTIONS(4624),
    [anon_sym_STAR] = ACTIONS(4626),
    [anon_sym_SLASH] = ACTIONS(4624),
    [anon_sym_PERCENT] = ACTIONS(4626),
    [anon_sym_CARET] = ACTIONS(4626),
    [anon_sym_PIPE] = ACTIONS(4624),
    [anon_sym_AMP] = ACTIONS(4624),
    [anon_sym_LT_LT] = ACTIONS(4626),
    [anon_sym_GT_GT] = ACTIONS(4624),
    [anon_sym_GT_GT_GT] = ACTIONS(4626),
    [anon_sym_EQ_EQ] = ACTIONS(4626),
    [anon_sym_BANG_EQ] = ACTIONS(4626),
    [anon_sym_GT_EQ] = ACTIONS(4626),
    [anon_sym_LT_EQ] = ACTIONS(4626),
    [anon_sym_DOT] = ACTIONS(4624),
    [anon_sym_EQ_GT] = ACTIONS(4626),
    [anon_sym_switch] = ACTIONS(4626),
    [anon_sym_when] = ACTIONS(4626),
    [anon_sym_DOT_DOT] = ACTIONS(4626),
    [anon_sym_and] = ACTIONS(4626),
    [anon_sym_or] = ACTIONS(4626),
    [anon_sym_AMP_AMP] = ACTIONS(4626),
    [anon_sym_PIPE_PIPE] = ACTIONS(4626),
    [anon_sym_QMARK_QMARK] = ACTIONS(4626),
    [anon_sym_on] = ACTIONS(4626),
    [anon_sym_equals] = ACTIONS(4626),
    [anon_sym_by] = ACTIONS(4626),
    [anon_sym_as] = ACTIONS(4626),
    [anon_sym_is] = ACTIONS(4626),
    [anon_sym_DASH_GT] = ACTIONS(4626),
    [anon_sym_with] = ACTIONS(4626),
    [aux_sym_preproc_if_token3] = ACTIONS(4626),
    [aux_sym_preproc_else_token1] = ACTIONS(4626),
    [aux_sym_preproc_elif_token1] = ACTIONS(4626),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4051] = {
    [sym_preproc_region] = STATE(4051),
    [sym_preproc_endregion] = STATE(4051),
    [sym_preproc_line] = STATE(4051),
    [sym_preproc_pragma] = STATE(4051),
    [sym_preproc_nullable] = STATE(4051),
    [sym_preproc_error] = STATE(4051),
    [sym_preproc_warning] = STATE(4051),
    [sym_preproc_define] = STATE(4051),
    [sym_preproc_undef] = STATE(4051),
    [anon_sym_SEMI] = ACTIONS(4181),
    [anon_sym_LBRACK] = ACTIONS(4181),
    [anon_sym_COLON] = ACTIONS(4181),
    [anon_sym_COMMA] = ACTIONS(4181),
    [anon_sym_RBRACK] = ACTIONS(4181),
    [anon_sym_LPAREN] = ACTIONS(4181),
    [anon_sym_RPAREN] = ACTIONS(4181),
    [anon_sym_LBRACE] = ACTIONS(4181),
    [anon_sym_RBRACE] = ACTIONS(4181),
    [anon_sym_LT] = ACTIONS(4179),
    [anon_sym_GT] = ACTIONS(4179),
    [anon_sym_in] = ACTIONS(4181),
    [anon_sym_QMARK] = ACTIONS(4179),
    [anon_sym_BANG] = ACTIONS(4179),
    [anon_sym_PLUS_PLUS] = ACTIONS(4181),
    [anon_sym_DASH_DASH] = ACTIONS(4181),
    [anon_sym_PLUS] = ACTIONS(4179),
    [anon_sym_DASH] = ACTIONS(4179),
    [anon_sym_STAR] = ACTIONS(4181),
    [anon_sym_SLASH] = ACTIONS(4179),
    [anon_sym_PERCENT] = ACTIONS(4181),
    [anon_sym_CARET] = ACTIONS(4181),
    [anon_sym_PIPE] = ACTIONS(4179),
    [anon_sym_AMP] = ACTIONS(4179),
    [anon_sym_LT_LT] = ACTIONS(4181),
    [anon_sym_GT_GT] = ACTIONS(4179),
    [anon_sym_GT_GT_GT] = ACTIONS(4181),
    [anon_sym_EQ_EQ] = ACTIONS(4181),
    [anon_sym_BANG_EQ] = ACTIONS(4181),
    [anon_sym_GT_EQ] = ACTIONS(4181),
    [anon_sym_LT_EQ] = ACTIONS(4181),
    [anon_sym_DOT] = ACTIONS(4179),
    [anon_sym_EQ_GT] = ACTIONS(4181),
    [anon_sym_switch] = ACTIONS(4181),
    [anon_sym_when] = ACTIONS(4181),
    [anon_sym_DOT_DOT] = ACTIONS(4181),
    [anon_sym_and] = ACTIONS(4181),
    [anon_sym_or] = ACTIONS(4181),
    [anon_sym_AMP_AMP] = ACTIONS(4181),
    [anon_sym_PIPE_PIPE] = ACTIONS(4181),
    [anon_sym_QMARK_QMARK] = ACTIONS(4181),
    [anon_sym_on] = ACTIONS(4181),
    [anon_sym_equals] = ACTIONS(4181),
    [anon_sym_by] = ACTIONS(4181),
    [anon_sym_as] = ACTIONS(4181),
    [anon_sym_is] = ACTIONS(4181),
    [anon_sym_DASH_GT] = ACTIONS(4181),
    [anon_sym_with] = ACTIONS(4181),
    [aux_sym_preproc_if_token3] = ACTIONS(4181),
    [aux_sym_preproc_else_token1] = ACTIONS(4181),
    [aux_sym_preproc_elif_token1] = ACTIONS(4181),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4052] = {
    [sym_preproc_region] = STATE(4052),
    [sym_preproc_endregion] = STATE(4052),
    [sym_preproc_line] = STATE(4052),
    [sym_preproc_pragma] = STATE(4052),
    [sym_preproc_nullable] = STATE(4052),
    [sym_preproc_error] = STATE(4052),
    [sym_preproc_warning] = STATE(4052),
    [sym_preproc_define] = STATE(4052),
    [sym_preproc_undef] = STATE(4052),
    [anon_sym_SEMI] = ACTIONS(5932),
    [anon_sym_LBRACK] = ACTIONS(5932),
    [anon_sym_COLON] = ACTIONS(5932),
    [anon_sym_COMMA] = ACTIONS(5932),
    [anon_sym_RBRACK] = ACTIONS(5932),
    [anon_sym_LPAREN] = ACTIONS(5932),
    [anon_sym_RPAREN] = ACTIONS(5932),
    [anon_sym_RBRACE] = ACTIONS(5932),
    [anon_sym_LT] = ACTIONS(5934),
    [anon_sym_GT] = ACTIONS(5934),
    [anon_sym_in] = ACTIONS(5934),
    [anon_sym_QMARK] = ACTIONS(5934),
    [anon_sym_BANG] = ACTIONS(5934),
    [anon_sym_PLUS_PLUS] = ACTIONS(5932),
    [anon_sym_DASH_DASH] = ACTIONS(5932),
    [anon_sym_PLUS] = ACTIONS(5934),
    [anon_sym_DASH] = ACTIONS(5934),
    [anon_sym_STAR] = ACTIONS(5932),
    [anon_sym_SLASH] = ACTIONS(5934),
    [anon_sym_PERCENT] = ACTIONS(5932),
    [anon_sym_CARET] = ACTIONS(5932),
    [anon_sym_PIPE] = ACTIONS(5934),
    [anon_sym_AMP] = ACTIONS(5934),
    [anon_sym_LT_LT] = ACTIONS(5932),
    [anon_sym_GT_GT] = ACTIONS(5934),
    [anon_sym_GT_GT_GT] = ACTIONS(5932),
    [anon_sym_EQ_EQ] = ACTIONS(5932),
    [anon_sym_BANG_EQ] = ACTIONS(5932),
    [anon_sym_GT_EQ] = ACTIONS(5932),
    [anon_sym_LT_EQ] = ACTIONS(5932),
    [anon_sym_DOT] = ACTIONS(5934),
    [anon_sym_EQ_GT] = ACTIONS(5932),
    [anon_sym_switch] = ACTIONS(5932),
    [anon_sym_when] = ACTIONS(5932),
    [anon_sym_DOT_DOT] = ACTIONS(5932),
    [anon_sym_and] = ACTIONS(5932),
    [anon_sym_or] = ACTIONS(5932),
    [anon_sym_AMP_AMP] = ACTIONS(5932),
    [anon_sym_PIPE_PIPE] = ACTIONS(5932),
    [anon_sym_QMARK_QMARK] = ACTIONS(5932),
    [anon_sym_into] = ACTIONS(5932),
    [anon_sym_on] = ACTIONS(5932),
    [anon_sym_equals] = ACTIONS(5932),
    [anon_sym_by] = ACTIONS(5932),
    [anon_sym_as] = ACTIONS(5932),
    [anon_sym_is] = ACTIONS(5932),
    [anon_sym_DASH_GT] = ACTIONS(5932),
    [anon_sym_with] = ACTIONS(5932),
    [aux_sym_preproc_if_token3] = ACTIONS(5932),
    [aux_sym_preproc_else_token1] = ACTIONS(5932),
    [aux_sym_preproc_elif_token1] = ACTIONS(5932),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4053] = {
    [sym_preproc_region] = STATE(4053),
    [sym_preproc_endregion] = STATE(4053),
    [sym_preproc_line] = STATE(4053),
    [sym_preproc_pragma] = STATE(4053),
    [sym_preproc_nullable] = STATE(4053),
    [sym_preproc_error] = STATE(4053),
    [sym_preproc_warning] = STATE(4053),
    [sym_preproc_define] = STATE(4053),
    [sym_preproc_undef] = STATE(4053),
    [anon_sym_SEMI] = ACTIONS(5628),
    [anon_sym_LBRACK] = ACTIONS(5628),
    [anon_sym_COLON] = ACTIONS(5628),
    [anon_sym_COMMA] = ACTIONS(5628),
    [anon_sym_RBRACK] = ACTIONS(5628),
    [anon_sym_LPAREN] = ACTIONS(5628),
    [anon_sym_RPAREN] = ACTIONS(5628),
    [anon_sym_RBRACE] = ACTIONS(5628),
    [anon_sym_LT] = ACTIONS(5630),
    [anon_sym_GT] = ACTIONS(5630),
    [anon_sym_in] = ACTIONS(5630),
    [anon_sym_QMARK] = ACTIONS(5630),
    [anon_sym_BANG] = ACTIONS(5630),
    [anon_sym_PLUS_PLUS] = ACTIONS(5628),
    [anon_sym_DASH_DASH] = ACTIONS(5628),
    [anon_sym_PLUS] = ACTIONS(5630),
    [anon_sym_DASH] = ACTIONS(5630),
    [anon_sym_STAR] = ACTIONS(5628),
    [anon_sym_SLASH] = ACTIONS(5630),
    [anon_sym_PERCENT] = ACTIONS(5628),
    [anon_sym_CARET] = ACTIONS(5628),
    [anon_sym_PIPE] = ACTIONS(5630),
    [anon_sym_AMP] = ACTIONS(5630),
    [anon_sym_LT_LT] = ACTIONS(5628),
    [anon_sym_GT_GT] = ACTIONS(5630),
    [anon_sym_GT_GT_GT] = ACTIONS(5628),
    [anon_sym_EQ_EQ] = ACTIONS(5628),
    [anon_sym_BANG_EQ] = ACTIONS(5628),
    [anon_sym_GT_EQ] = ACTIONS(5628),
    [anon_sym_LT_EQ] = ACTIONS(5628),
    [anon_sym_DOT] = ACTIONS(5630),
    [anon_sym_EQ_GT] = ACTIONS(5628),
    [anon_sym_switch] = ACTIONS(5628),
    [anon_sym_when] = ACTIONS(5628),
    [anon_sym_DOT_DOT] = ACTIONS(5628),
    [anon_sym_and] = ACTIONS(5628),
    [anon_sym_or] = ACTIONS(5628),
    [anon_sym_AMP_AMP] = ACTIONS(5628),
    [anon_sym_PIPE_PIPE] = ACTIONS(5628),
    [anon_sym_QMARK_QMARK] = ACTIONS(5628),
    [anon_sym_into] = ACTIONS(5628),
    [anon_sym_on] = ACTIONS(5628),
    [anon_sym_equals] = ACTIONS(5628),
    [anon_sym_by] = ACTIONS(5628),
    [anon_sym_as] = ACTIONS(5628),
    [anon_sym_is] = ACTIONS(5628),
    [anon_sym_DASH_GT] = ACTIONS(5628),
    [anon_sym_with] = ACTIONS(5628),
    [aux_sym_preproc_if_token3] = ACTIONS(5628),
    [aux_sym_preproc_else_token1] = ACTIONS(5628),
    [aux_sym_preproc_elif_token1] = ACTIONS(5628),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4054] = {
    [sym_preproc_region] = STATE(4054),
    [sym_preproc_endregion] = STATE(4054),
    [sym_preproc_line] = STATE(4054),
    [sym_preproc_pragma] = STATE(4054),
    [sym_preproc_nullable] = STATE(4054),
    [sym_preproc_error] = STATE(4054),
    [sym_preproc_warning] = STATE(4054),
    [sym_preproc_define] = STATE(4054),
    [sym_preproc_undef] = STATE(4054),
    [anon_sym_SEMI] = ACTIONS(4630),
    [anon_sym_LBRACK] = ACTIONS(4630),
    [anon_sym_COLON] = ACTIONS(4630),
    [anon_sym_COMMA] = ACTIONS(4630),
    [anon_sym_RBRACK] = ACTIONS(4630),
    [anon_sym_LPAREN] = ACTIONS(4630),
    [anon_sym_RPAREN] = ACTIONS(4630),
    [anon_sym_LBRACE] = ACTIONS(4630),
    [anon_sym_RBRACE] = ACTIONS(4630),
    [anon_sym_LT] = ACTIONS(4628),
    [anon_sym_GT] = ACTIONS(4628),
    [anon_sym_in] = ACTIONS(4630),
    [anon_sym_QMARK] = ACTIONS(4628),
    [anon_sym_BANG] = ACTIONS(4628),
    [anon_sym_PLUS_PLUS] = ACTIONS(4630),
    [anon_sym_DASH_DASH] = ACTIONS(4630),
    [anon_sym_PLUS] = ACTIONS(4628),
    [anon_sym_DASH] = ACTIONS(4628),
    [anon_sym_STAR] = ACTIONS(4630),
    [anon_sym_SLASH] = ACTIONS(4628),
    [anon_sym_PERCENT] = ACTIONS(4630),
    [anon_sym_CARET] = ACTIONS(4630),
    [anon_sym_PIPE] = ACTIONS(4628),
    [anon_sym_AMP] = ACTIONS(4628),
    [anon_sym_LT_LT] = ACTIONS(4630),
    [anon_sym_GT_GT] = ACTIONS(4628),
    [anon_sym_GT_GT_GT] = ACTIONS(4630),
    [anon_sym_EQ_EQ] = ACTIONS(4630),
    [anon_sym_BANG_EQ] = ACTIONS(4630),
    [anon_sym_GT_EQ] = ACTIONS(4630),
    [anon_sym_LT_EQ] = ACTIONS(4630),
    [anon_sym_DOT] = ACTIONS(4628),
    [anon_sym_EQ_GT] = ACTIONS(4630),
    [anon_sym_switch] = ACTIONS(4630),
    [anon_sym_when] = ACTIONS(4630),
    [anon_sym_DOT_DOT] = ACTIONS(4630),
    [anon_sym_and] = ACTIONS(4630),
    [anon_sym_or] = ACTIONS(4630),
    [anon_sym_AMP_AMP] = ACTIONS(4630),
    [anon_sym_PIPE_PIPE] = ACTIONS(4630),
    [anon_sym_QMARK_QMARK] = ACTIONS(4630),
    [anon_sym_on] = ACTIONS(4630),
    [anon_sym_equals] = ACTIONS(4630),
    [anon_sym_by] = ACTIONS(4630),
    [anon_sym_as] = ACTIONS(4630),
    [anon_sym_is] = ACTIONS(4630),
    [anon_sym_DASH_GT] = ACTIONS(4630),
    [anon_sym_with] = ACTIONS(4630),
    [aux_sym_preproc_if_token3] = ACTIONS(4630),
    [aux_sym_preproc_else_token1] = ACTIONS(4630),
    [aux_sym_preproc_elif_token1] = ACTIONS(4630),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4055] = {
    [sym_preproc_region] = STATE(4055),
    [sym_preproc_endregion] = STATE(4055),
    [sym_preproc_line] = STATE(4055),
    [sym_preproc_pragma] = STATE(4055),
    [sym_preproc_nullable] = STATE(4055),
    [sym_preproc_error] = STATE(4055),
    [sym_preproc_warning] = STATE(4055),
    [sym_preproc_define] = STATE(4055),
    [sym_preproc_undef] = STATE(4055),
    [anon_sym_SEMI] = ACTIONS(4546),
    [anon_sym_LBRACK] = ACTIONS(4546),
    [anon_sym_COLON] = ACTIONS(4546),
    [anon_sym_COMMA] = ACTIONS(4546),
    [anon_sym_RBRACK] = ACTIONS(4546),
    [anon_sym_LPAREN] = ACTIONS(4546),
    [anon_sym_RPAREN] = ACTIONS(4546),
    [anon_sym_LBRACE] = ACTIONS(4546),
    [anon_sym_RBRACE] = ACTIONS(4546),
    [anon_sym_LT] = ACTIONS(4544),
    [anon_sym_GT] = ACTIONS(4544),
    [anon_sym_in] = ACTIONS(4546),
    [anon_sym_QMARK] = ACTIONS(4544),
    [anon_sym_BANG] = ACTIONS(4544),
    [anon_sym_PLUS_PLUS] = ACTIONS(4546),
    [anon_sym_DASH_DASH] = ACTIONS(4546),
    [anon_sym_PLUS] = ACTIONS(4544),
    [anon_sym_DASH] = ACTIONS(4544),
    [anon_sym_STAR] = ACTIONS(4546),
    [anon_sym_SLASH] = ACTIONS(4544),
    [anon_sym_PERCENT] = ACTIONS(4546),
    [anon_sym_CARET] = ACTIONS(4546),
    [anon_sym_PIPE] = ACTIONS(4544),
    [anon_sym_AMP] = ACTIONS(4544),
    [anon_sym_LT_LT] = ACTIONS(4546),
    [anon_sym_GT_GT] = ACTIONS(4544),
    [anon_sym_GT_GT_GT] = ACTIONS(4546),
    [anon_sym_EQ_EQ] = ACTIONS(4546),
    [anon_sym_BANG_EQ] = ACTIONS(4546),
    [anon_sym_GT_EQ] = ACTIONS(4546),
    [anon_sym_LT_EQ] = ACTIONS(4546),
    [anon_sym_DOT] = ACTIONS(4544),
    [anon_sym_EQ_GT] = ACTIONS(4546),
    [anon_sym_switch] = ACTIONS(4546),
    [anon_sym_when] = ACTIONS(4546),
    [anon_sym_DOT_DOT] = ACTIONS(4546),
    [anon_sym_and] = ACTIONS(4546),
    [anon_sym_or] = ACTIONS(4546),
    [anon_sym_AMP_AMP] = ACTIONS(4546),
    [anon_sym_PIPE_PIPE] = ACTIONS(4546),
    [anon_sym_QMARK_QMARK] = ACTIONS(4546),
    [anon_sym_on] = ACTIONS(4546),
    [anon_sym_equals] = ACTIONS(4546),
    [anon_sym_by] = ACTIONS(4546),
    [anon_sym_as] = ACTIONS(4546),
    [anon_sym_is] = ACTIONS(4546),
    [anon_sym_DASH_GT] = ACTIONS(4546),
    [anon_sym_with] = ACTIONS(4546),
    [aux_sym_preproc_if_token3] = ACTIONS(4546),
    [aux_sym_preproc_else_token1] = ACTIONS(4546),
    [aux_sym_preproc_elif_token1] = ACTIONS(4546),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4056] = {
    [sym_preproc_region] = STATE(4056),
    [sym_preproc_endregion] = STATE(4056),
    [sym_preproc_line] = STATE(4056),
    [sym_preproc_pragma] = STATE(4056),
    [sym_preproc_nullable] = STATE(4056),
    [sym_preproc_error] = STATE(4056),
    [sym_preproc_warning] = STATE(4056),
    [sym_preproc_define] = STATE(4056),
    [sym_preproc_undef] = STATE(4056),
    [anon_sym_SEMI] = ACTIONS(2031),
    [anon_sym_LBRACK] = ACTIONS(2031),
    [anon_sym_COLON] = ACTIONS(2031),
    [anon_sym_COMMA] = ACTIONS(2031),
    [anon_sym_RBRACK] = ACTIONS(2031),
    [anon_sym_LPAREN] = ACTIONS(5936),
    [anon_sym_RPAREN] = ACTIONS(2031),
    [anon_sym_RBRACE] = ACTIONS(2031),
    [anon_sym_LT] = ACTIONS(2029),
    [anon_sym_GT] = ACTIONS(2029),
    [anon_sym_in] = ACTIONS(2029),
    [anon_sym_QMARK] = ACTIONS(2029),
    [anon_sym_BANG] = ACTIONS(2029),
    [anon_sym_PLUS_PLUS] = ACTIONS(2031),
    [anon_sym_DASH_DASH] = ACTIONS(2031),
    [anon_sym_PLUS] = ACTIONS(2029),
    [anon_sym_DASH] = ACTIONS(2029),
    [anon_sym_STAR] = ACTIONS(2031),
    [anon_sym_SLASH] = ACTIONS(2029),
    [anon_sym_PERCENT] = ACTIONS(2031),
    [anon_sym_CARET] = ACTIONS(2031),
    [anon_sym_PIPE] = ACTIONS(2029),
    [anon_sym_AMP] = ACTIONS(2029),
    [anon_sym_LT_LT] = ACTIONS(2031),
    [anon_sym_GT_GT] = ACTIONS(2029),
    [anon_sym_GT_GT_GT] = ACTIONS(2031),
    [anon_sym_EQ_EQ] = ACTIONS(2031),
    [anon_sym_BANG_EQ] = ACTIONS(2031),
    [anon_sym_GT_EQ] = ACTIONS(2031),
    [anon_sym_LT_EQ] = ACTIONS(2031),
    [anon_sym_DOT] = ACTIONS(2029),
    [anon_sym_EQ_GT] = ACTIONS(2031),
    [anon_sym_switch] = ACTIONS(2031),
    [anon_sym_when] = ACTIONS(2031),
    [anon_sym_DOT_DOT] = ACTIONS(2031),
    [anon_sym_and] = ACTIONS(2031),
    [anon_sym_or] = ACTIONS(2031),
    [anon_sym_AMP_AMP] = ACTIONS(2031),
    [anon_sym_PIPE_PIPE] = ACTIONS(2031),
    [anon_sym_QMARK_QMARK] = ACTIONS(2031),
    [anon_sym_into] = ACTIONS(2031),
    [anon_sym_on] = ACTIONS(2031),
    [anon_sym_equals] = ACTIONS(2031),
    [anon_sym_by] = ACTIONS(2031),
    [anon_sym_as] = ACTIONS(2031),
    [anon_sym_is] = ACTIONS(2031),
    [anon_sym_DASH_GT] = ACTIONS(2031),
    [anon_sym_with] = ACTIONS(2031),
    [aux_sym_preproc_if_token3] = ACTIONS(2031),
    [aux_sym_preproc_else_token1] = ACTIONS(2031),
    [aux_sym_preproc_elif_token1] = ACTIONS(2031),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4057] = {
    [sym_preproc_region] = STATE(4057),
    [sym_preproc_endregion] = STATE(4057),
    [sym_preproc_line] = STATE(4057),
    [sym_preproc_pragma] = STATE(4057),
    [sym_preproc_nullable] = STATE(4057),
    [sym_preproc_error] = STATE(4057),
    [sym_preproc_warning] = STATE(4057),
    [sym_preproc_define] = STATE(4057),
    [sym_preproc_undef] = STATE(4057),
    [anon_sym_SEMI] = ACTIONS(5620),
    [anon_sym_LBRACK] = ACTIONS(5620),
    [anon_sym_COLON] = ACTIONS(5620),
    [anon_sym_COMMA] = ACTIONS(5620),
    [anon_sym_RBRACK] = ACTIONS(5620),
    [anon_sym_LPAREN] = ACTIONS(5620),
    [anon_sym_RPAREN] = ACTIONS(5620),
    [anon_sym_RBRACE] = ACTIONS(5620),
    [anon_sym_LT] = ACTIONS(5622),
    [anon_sym_GT] = ACTIONS(5622),
    [anon_sym_in] = ACTIONS(5622),
    [anon_sym_QMARK] = ACTIONS(5622),
    [anon_sym_BANG] = ACTIONS(5622),
    [anon_sym_PLUS_PLUS] = ACTIONS(5620),
    [anon_sym_DASH_DASH] = ACTIONS(5620),
    [anon_sym_PLUS] = ACTIONS(5622),
    [anon_sym_DASH] = ACTIONS(5622),
    [anon_sym_STAR] = ACTIONS(5620),
    [anon_sym_SLASH] = ACTIONS(5622),
    [anon_sym_PERCENT] = ACTIONS(5620),
    [anon_sym_CARET] = ACTIONS(5620),
    [anon_sym_PIPE] = ACTIONS(5622),
    [anon_sym_AMP] = ACTIONS(5622),
    [anon_sym_LT_LT] = ACTIONS(5620),
    [anon_sym_GT_GT] = ACTIONS(5622),
    [anon_sym_GT_GT_GT] = ACTIONS(5620),
    [anon_sym_EQ_EQ] = ACTIONS(5620),
    [anon_sym_BANG_EQ] = ACTIONS(5620),
    [anon_sym_GT_EQ] = ACTIONS(5620),
    [anon_sym_LT_EQ] = ACTIONS(5620),
    [anon_sym_DOT] = ACTIONS(5622),
    [anon_sym_EQ_GT] = ACTIONS(5620),
    [anon_sym_switch] = ACTIONS(5620),
    [anon_sym_when] = ACTIONS(5620),
    [anon_sym_DOT_DOT] = ACTIONS(5620),
    [anon_sym_and] = ACTIONS(5620),
    [anon_sym_or] = ACTIONS(5620),
    [anon_sym_AMP_AMP] = ACTIONS(5620),
    [anon_sym_PIPE_PIPE] = ACTIONS(5620),
    [anon_sym_QMARK_QMARK] = ACTIONS(5620),
    [anon_sym_into] = ACTIONS(5620),
    [anon_sym_on] = ACTIONS(5620),
    [anon_sym_equals] = ACTIONS(5620),
    [anon_sym_by] = ACTIONS(5620),
    [anon_sym_as] = ACTIONS(5620),
    [anon_sym_is] = ACTIONS(5620),
    [anon_sym_DASH_GT] = ACTIONS(5620),
    [anon_sym_with] = ACTIONS(5620),
    [aux_sym_preproc_if_token3] = ACTIONS(5620),
    [aux_sym_preproc_else_token1] = ACTIONS(5620),
    [aux_sym_preproc_elif_token1] = ACTIONS(5620),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4058] = {
    [sym_preproc_region] = STATE(4058),
    [sym_preproc_endregion] = STATE(4058),
    [sym_preproc_line] = STATE(4058),
    [sym_preproc_pragma] = STATE(4058),
    [sym_preproc_nullable] = STATE(4058),
    [sym_preproc_error] = STATE(4058),
    [sym_preproc_warning] = STATE(4058),
    [sym_preproc_define] = STATE(4058),
    [sym_preproc_undef] = STATE(4058),
    [anon_sym_SEMI] = ACTIONS(5686),
    [anon_sym_LBRACK] = ACTIONS(5686),
    [anon_sym_COLON] = ACTIONS(5686),
    [anon_sym_COMMA] = ACTIONS(5686),
    [anon_sym_RBRACK] = ACTIONS(5686),
    [anon_sym_LPAREN] = ACTIONS(5686),
    [anon_sym_RPAREN] = ACTIONS(5686),
    [anon_sym_RBRACE] = ACTIONS(5686),
    [anon_sym_LT] = ACTIONS(5688),
    [anon_sym_GT] = ACTIONS(5688),
    [anon_sym_in] = ACTIONS(5688),
    [anon_sym_QMARK] = ACTIONS(5688),
    [anon_sym_BANG] = ACTIONS(5688),
    [anon_sym_PLUS_PLUS] = ACTIONS(5686),
    [anon_sym_DASH_DASH] = ACTIONS(5686),
    [anon_sym_PLUS] = ACTIONS(5688),
    [anon_sym_DASH] = ACTIONS(5688),
    [anon_sym_STAR] = ACTIONS(5686),
    [anon_sym_SLASH] = ACTIONS(5688),
    [anon_sym_PERCENT] = ACTIONS(5686),
    [anon_sym_CARET] = ACTIONS(5686),
    [anon_sym_PIPE] = ACTIONS(5688),
    [anon_sym_AMP] = ACTIONS(5688),
    [anon_sym_LT_LT] = ACTIONS(5686),
    [anon_sym_GT_GT] = ACTIONS(5688),
    [anon_sym_GT_GT_GT] = ACTIONS(5686),
    [anon_sym_EQ_EQ] = ACTIONS(5686),
    [anon_sym_BANG_EQ] = ACTIONS(5686),
    [anon_sym_GT_EQ] = ACTIONS(5686),
    [anon_sym_LT_EQ] = ACTIONS(5686),
    [anon_sym_DOT] = ACTIONS(5688),
    [anon_sym_EQ_GT] = ACTIONS(5686),
    [anon_sym_switch] = ACTIONS(5686),
    [anon_sym_when] = ACTIONS(5686),
    [anon_sym_DOT_DOT] = ACTIONS(5686),
    [anon_sym_and] = ACTIONS(5686),
    [anon_sym_or] = ACTIONS(5686),
    [anon_sym_AMP_AMP] = ACTIONS(5686),
    [anon_sym_PIPE_PIPE] = ACTIONS(5686),
    [anon_sym_QMARK_QMARK] = ACTIONS(5686),
    [anon_sym_into] = ACTIONS(5686),
    [anon_sym_on] = ACTIONS(5686),
    [anon_sym_equals] = ACTIONS(5686),
    [anon_sym_by] = ACTIONS(5686),
    [anon_sym_as] = ACTIONS(5686),
    [anon_sym_is] = ACTIONS(5686),
    [anon_sym_DASH_GT] = ACTIONS(5686),
    [anon_sym_with] = ACTIONS(5686),
    [aux_sym_preproc_if_token3] = ACTIONS(5686),
    [aux_sym_preproc_else_token1] = ACTIONS(5686),
    [aux_sym_preproc_elif_token1] = ACTIONS(5686),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4059] = {
    [sym_preproc_region] = STATE(4059),
    [sym_preproc_endregion] = STATE(4059),
    [sym_preproc_line] = STATE(4059),
    [sym_preproc_pragma] = STATE(4059),
    [sym_preproc_nullable] = STATE(4059),
    [sym_preproc_error] = STATE(4059),
    [sym_preproc_warning] = STATE(4059),
    [sym_preproc_define] = STATE(4059),
    [sym_preproc_undef] = STATE(4059),
    [anon_sym_SEMI] = ACTIONS(5660),
    [anon_sym_LBRACK] = ACTIONS(5660),
    [anon_sym_COLON] = ACTIONS(5660),
    [anon_sym_COMMA] = ACTIONS(5660),
    [anon_sym_RBRACK] = ACTIONS(5660),
    [anon_sym_LPAREN] = ACTIONS(5660),
    [anon_sym_RPAREN] = ACTIONS(5660),
    [anon_sym_RBRACE] = ACTIONS(5660),
    [anon_sym_LT] = ACTIONS(5662),
    [anon_sym_GT] = ACTIONS(5662),
    [anon_sym_in] = ACTIONS(5660),
    [anon_sym_QMARK] = ACTIONS(5662),
    [anon_sym_BANG] = ACTIONS(5662),
    [anon_sym_PLUS_PLUS] = ACTIONS(5660),
    [anon_sym_DASH_DASH] = ACTIONS(5660),
    [anon_sym_PLUS] = ACTIONS(5662),
    [anon_sym_DASH] = ACTIONS(5662),
    [anon_sym_STAR] = ACTIONS(5660),
    [anon_sym_SLASH] = ACTIONS(5662),
    [anon_sym_PERCENT] = ACTIONS(5660),
    [anon_sym_CARET] = ACTIONS(5660),
    [anon_sym_PIPE] = ACTIONS(5662),
    [anon_sym_AMP] = ACTIONS(5662),
    [anon_sym_LT_LT] = ACTIONS(5660),
    [anon_sym_GT_GT] = ACTIONS(5662),
    [anon_sym_GT_GT_GT] = ACTIONS(5660),
    [anon_sym_EQ_EQ] = ACTIONS(5660),
    [anon_sym_BANG_EQ] = ACTIONS(5660),
    [anon_sym_GT_EQ] = ACTIONS(5660),
    [anon_sym_LT_EQ] = ACTIONS(5660),
    [anon_sym_DOT] = ACTIONS(5662),
    [anon_sym_EQ_GT] = ACTIONS(5660),
    [anon_sym_switch] = ACTIONS(5660),
    [anon_sym_when] = ACTIONS(5660),
    [anon_sym_DOT_DOT] = ACTIONS(5660),
    [anon_sym_and] = ACTIONS(5660),
    [anon_sym_or] = ACTIONS(5660),
    [anon_sym_AMP_AMP] = ACTIONS(5660),
    [anon_sym_PIPE_PIPE] = ACTIONS(5660),
    [anon_sym_QMARK_QMARK] = ACTIONS(5660),
    [anon_sym_on] = ACTIONS(5660),
    [anon_sym_equals] = ACTIONS(5660),
    [anon_sym_by] = ACTIONS(5660),
    [anon_sym_as] = ACTIONS(5660),
    [anon_sym_is] = ACTIONS(5660),
    [anon_sym_DASH_GT] = ACTIONS(5660),
    [anon_sym_with] = ACTIONS(5660),
    [anon_sym_DQUOTE] = ACTIONS(5660),
    [aux_sym_preproc_if_token3] = ACTIONS(5660),
    [aux_sym_preproc_else_token1] = ACTIONS(5660),
    [aux_sym_preproc_elif_token1] = ACTIONS(5660),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4060] = {
    [sym_preproc_region] = STATE(4060),
    [sym_preproc_endregion] = STATE(4060),
    [sym_preproc_line] = STATE(4060),
    [sym_preproc_pragma] = STATE(4060),
    [sym_preproc_nullable] = STATE(4060),
    [sym_preproc_error] = STATE(4060),
    [sym_preproc_warning] = STATE(4060),
    [sym_preproc_define] = STATE(4060),
    [sym_preproc_undef] = STATE(4060),
    [anon_sym_SEMI] = ACTIONS(5624),
    [anon_sym_LBRACK] = ACTIONS(5624),
    [anon_sym_COLON] = ACTIONS(5624),
    [anon_sym_COMMA] = ACTIONS(5624),
    [anon_sym_RBRACK] = ACTIONS(5624),
    [anon_sym_LPAREN] = ACTIONS(5624),
    [anon_sym_RPAREN] = ACTIONS(5624),
    [anon_sym_RBRACE] = ACTIONS(5624),
    [anon_sym_LT] = ACTIONS(5626),
    [anon_sym_GT] = ACTIONS(5626),
    [anon_sym_in] = ACTIONS(5626),
    [anon_sym_QMARK] = ACTIONS(5626),
    [anon_sym_BANG] = ACTIONS(5626),
    [anon_sym_PLUS_PLUS] = ACTIONS(5624),
    [anon_sym_DASH_DASH] = ACTIONS(5624),
    [anon_sym_PLUS] = ACTIONS(5626),
    [anon_sym_DASH] = ACTIONS(5626),
    [anon_sym_STAR] = ACTIONS(5624),
    [anon_sym_SLASH] = ACTIONS(5626),
    [anon_sym_PERCENT] = ACTIONS(5624),
    [anon_sym_CARET] = ACTIONS(5624),
    [anon_sym_PIPE] = ACTIONS(5626),
    [anon_sym_AMP] = ACTIONS(5626),
    [anon_sym_LT_LT] = ACTIONS(5624),
    [anon_sym_GT_GT] = ACTIONS(5626),
    [anon_sym_GT_GT_GT] = ACTIONS(5624),
    [anon_sym_EQ_EQ] = ACTIONS(5624),
    [anon_sym_BANG_EQ] = ACTIONS(5624),
    [anon_sym_GT_EQ] = ACTIONS(5624),
    [anon_sym_LT_EQ] = ACTIONS(5624),
    [anon_sym_DOT] = ACTIONS(5626),
    [anon_sym_EQ_GT] = ACTIONS(5624),
    [anon_sym_switch] = ACTIONS(5624),
    [anon_sym_when] = ACTIONS(5624),
    [anon_sym_DOT_DOT] = ACTIONS(5624),
    [anon_sym_and] = ACTIONS(5624),
    [anon_sym_or] = ACTIONS(5624),
    [anon_sym_AMP_AMP] = ACTIONS(5624),
    [anon_sym_PIPE_PIPE] = ACTIONS(5624),
    [anon_sym_QMARK_QMARK] = ACTIONS(5624),
    [anon_sym_into] = ACTIONS(5624),
    [anon_sym_on] = ACTIONS(5624),
    [anon_sym_equals] = ACTIONS(5624),
    [anon_sym_by] = ACTIONS(5624),
    [anon_sym_as] = ACTIONS(5624),
    [anon_sym_is] = ACTIONS(5624),
    [anon_sym_DASH_GT] = ACTIONS(5624),
    [anon_sym_with] = ACTIONS(5624),
    [aux_sym_preproc_if_token3] = ACTIONS(5624),
    [aux_sym_preproc_else_token1] = ACTIONS(5624),
    [aux_sym_preproc_elif_token1] = ACTIONS(5624),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4061] = {
    [sym_preproc_region] = STATE(4061),
    [sym_preproc_endregion] = STATE(4061),
    [sym_preproc_line] = STATE(4061),
    [sym_preproc_pragma] = STATE(4061),
    [sym_preproc_nullable] = STATE(4061),
    [sym_preproc_error] = STATE(4061),
    [sym_preproc_warning] = STATE(4061),
    [sym_preproc_define] = STATE(4061),
    [sym_preproc_undef] = STATE(4061),
    [anon_sym_SEMI] = ACTIONS(5564),
    [anon_sym_LBRACK] = ACTIONS(5564),
    [anon_sym_COLON] = ACTIONS(5564),
    [anon_sym_COMMA] = ACTIONS(5564),
    [anon_sym_RBRACK] = ACTIONS(5564),
    [anon_sym_LPAREN] = ACTIONS(5564),
    [anon_sym_RPAREN] = ACTIONS(5564),
    [anon_sym_RBRACE] = ACTIONS(5564),
    [anon_sym_LT] = ACTIONS(5566),
    [anon_sym_GT] = ACTIONS(5566),
    [anon_sym_in] = ACTIONS(5566),
    [anon_sym_QMARK] = ACTIONS(5566),
    [anon_sym_BANG] = ACTIONS(5566),
    [anon_sym_PLUS_PLUS] = ACTIONS(5564),
    [anon_sym_DASH_DASH] = ACTIONS(5564),
    [anon_sym_PLUS] = ACTIONS(5566),
    [anon_sym_DASH] = ACTIONS(5566),
    [anon_sym_STAR] = ACTIONS(5564),
    [anon_sym_SLASH] = ACTIONS(5566),
    [anon_sym_PERCENT] = ACTIONS(5564),
    [anon_sym_CARET] = ACTIONS(5564),
    [anon_sym_PIPE] = ACTIONS(5566),
    [anon_sym_AMP] = ACTIONS(5566),
    [anon_sym_LT_LT] = ACTIONS(5564),
    [anon_sym_GT_GT] = ACTIONS(5566),
    [anon_sym_GT_GT_GT] = ACTIONS(5564),
    [anon_sym_EQ_EQ] = ACTIONS(5564),
    [anon_sym_BANG_EQ] = ACTIONS(5564),
    [anon_sym_GT_EQ] = ACTIONS(5564),
    [anon_sym_LT_EQ] = ACTIONS(5564),
    [anon_sym_DOT] = ACTIONS(5566),
    [anon_sym_EQ_GT] = ACTIONS(5564),
    [anon_sym_switch] = ACTIONS(5564),
    [anon_sym_when] = ACTIONS(5564),
    [anon_sym_DOT_DOT] = ACTIONS(5564),
    [anon_sym_and] = ACTIONS(5564),
    [anon_sym_or] = ACTIONS(5564),
    [anon_sym_AMP_AMP] = ACTIONS(5564),
    [anon_sym_PIPE_PIPE] = ACTIONS(5564),
    [anon_sym_QMARK_QMARK] = ACTIONS(5564),
    [anon_sym_into] = ACTIONS(5564),
    [anon_sym_on] = ACTIONS(5564),
    [anon_sym_equals] = ACTIONS(5564),
    [anon_sym_by] = ACTIONS(5564),
    [anon_sym_as] = ACTIONS(5564),
    [anon_sym_is] = ACTIONS(5564),
    [anon_sym_DASH_GT] = ACTIONS(5564),
    [anon_sym_with] = ACTIONS(5564),
    [aux_sym_preproc_if_token3] = ACTIONS(5564),
    [aux_sym_preproc_else_token1] = ACTIONS(5564),
    [aux_sym_preproc_elif_token1] = ACTIONS(5564),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4062] = {
    [sym_preproc_region] = STATE(4062),
    [sym_preproc_endregion] = STATE(4062),
    [sym_preproc_line] = STATE(4062),
    [sym_preproc_pragma] = STATE(4062),
    [sym_preproc_nullable] = STATE(4062),
    [sym_preproc_error] = STATE(4062),
    [sym_preproc_warning] = STATE(4062),
    [sym_preproc_define] = STATE(4062),
    [sym_preproc_undef] = STATE(4062),
    [anon_sym_SEMI] = ACTIONS(5674),
    [anon_sym_LBRACK] = ACTIONS(5674),
    [anon_sym_COLON] = ACTIONS(5674),
    [anon_sym_COMMA] = ACTIONS(5674),
    [anon_sym_RBRACK] = ACTIONS(5674),
    [anon_sym_LPAREN] = ACTIONS(5674),
    [anon_sym_RPAREN] = ACTIONS(5674),
    [anon_sym_RBRACE] = ACTIONS(5674),
    [anon_sym_LT] = ACTIONS(5676),
    [anon_sym_GT] = ACTIONS(5676),
    [anon_sym_in] = ACTIONS(5676),
    [anon_sym_QMARK] = ACTIONS(5676),
    [anon_sym_BANG] = ACTIONS(5676),
    [anon_sym_PLUS_PLUS] = ACTIONS(5674),
    [anon_sym_DASH_DASH] = ACTIONS(5674),
    [anon_sym_PLUS] = ACTIONS(5676),
    [anon_sym_DASH] = ACTIONS(5676),
    [anon_sym_STAR] = ACTIONS(5674),
    [anon_sym_SLASH] = ACTIONS(5676),
    [anon_sym_PERCENT] = ACTIONS(5674),
    [anon_sym_CARET] = ACTIONS(5674),
    [anon_sym_PIPE] = ACTIONS(5676),
    [anon_sym_AMP] = ACTIONS(5676),
    [anon_sym_LT_LT] = ACTIONS(5674),
    [anon_sym_GT_GT] = ACTIONS(5676),
    [anon_sym_GT_GT_GT] = ACTIONS(5674),
    [anon_sym_EQ_EQ] = ACTIONS(5674),
    [anon_sym_BANG_EQ] = ACTIONS(5674),
    [anon_sym_GT_EQ] = ACTIONS(5674),
    [anon_sym_LT_EQ] = ACTIONS(5674),
    [anon_sym_DOT] = ACTIONS(5676),
    [anon_sym_EQ_GT] = ACTIONS(5674),
    [anon_sym_switch] = ACTIONS(5674),
    [anon_sym_when] = ACTIONS(5674),
    [anon_sym_DOT_DOT] = ACTIONS(5674),
    [anon_sym_and] = ACTIONS(5674),
    [anon_sym_or] = ACTIONS(5674),
    [anon_sym_AMP_AMP] = ACTIONS(5674),
    [anon_sym_PIPE_PIPE] = ACTIONS(5674),
    [anon_sym_QMARK_QMARK] = ACTIONS(5674),
    [anon_sym_into] = ACTIONS(5674),
    [anon_sym_on] = ACTIONS(5674),
    [anon_sym_equals] = ACTIONS(5674),
    [anon_sym_by] = ACTIONS(5674),
    [anon_sym_as] = ACTIONS(5674),
    [anon_sym_is] = ACTIONS(5674),
    [anon_sym_DASH_GT] = ACTIONS(5674),
    [anon_sym_with] = ACTIONS(5674),
    [aux_sym_preproc_if_token3] = ACTIONS(5674),
    [aux_sym_preproc_else_token1] = ACTIONS(5674),
    [aux_sym_preproc_elif_token1] = ACTIONS(5674),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4063] = {
    [sym_preproc_region] = STATE(4063),
    [sym_preproc_endregion] = STATE(4063),
    [sym_preproc_line] = STATE(4063),
    [sym_preproc_pragma] = STATE(4063),
    [sym_preproc_nullable] = STATE(4063),
    [sym_preproc_error] = STATE(4063),
    [sym_preproc_warning] = STATE(4063),
    [sym_preproc_define] = STATE(4063),
    [sym_preproc_undef] = STATE(4063),
    [anon_sym_SEMI] = ACTIONS(5568),
    [anon_sym_LBRACK] = ACTIONS(5568),
    [anon_sym_COLON] = ACTIONS(5568),
    [anon_sym_COMMA] = ACTIONS(5568),
    [anon_sym_RBRACK] = ACTIONS(5568),
    [anon_sym_LPAREN] = ACTIONS(5568),
    [anon_sym_RPAREN] = ACTIONS(5568),
    [anon_sym_RBRACE] = ACTIONS(5568),
    [anon_sym_LT] = ACTIONS(5570),
    [anon_sym_GT] = ACTIONS(5570),
    [anon_sym_in] = ACTIONS(5570),
    [anon_sym_QMARK] = ACTIONS(5570),
    [anon_sym_BANG] = ACTIONS(5570),
    [anon_sym_PLUS_PLUS] = ACTIONS(5568),
    [anon_sym_DASH_DASH] = ACTIONS(5568),
    [anon_sym_PLUS] = ACTIONS(5570),
    [anon_sym_DASH] = ACTIONS(5570),
    [anon_sym_STAR] = ACTIONS(5568),
    [anon_sym_SLASH] = ACTIONS(5570),
    [anon_sym_PERCENT] = ACTIONS(5568),
    [anon_sym_CARET] = ACTIONS(5568),
    [anon_sym_PIPE] = ACTIONS(5570),
    [anon_sym_AMP] = ACTIONS(5570),
    [anon_sym_LT_LT] = ACTIONS(5568),
    [anon_sym_GT_GT] = ACTIONS(5570),
    [anon_sym_GT_GT_GT] = ACTIONS(5568),
    [anon_sym_EQ_EQ] = ACTIONS(5568),
    [anon_sym_BANG_EQ] = ACTIONS(5568),
    [anon_sym_GT_EQ] = ACTIONS(5568),
    [anon_sym_LT_EQ] = ACTIONS(5568),
    [anon_sym_DOT] = ACTIONS(5570),
    [anon_sym_EQ_GT] = ACTIONS(5568),
    [anon_sym_switch] = ACTIONS(5568),
    [anon_sym_when] = ACTIONS(5568),
    [anon_sym_DOT_DOT] = ACTIONS(5568),
    [anon_sym_and] = ACTIONS(5568),
    [anon_sym_or] = ACTIONS(5568),
    [anon_sym_AMP_AMP] = ACTIONS(5568),
    [anon_sym_PIPE_PIPE] = ACTIONS(5568),
    [anon_sym_QMARK_QMARK] = ACTIONS(5568),
    [anon_sym_into] = ACTIONS(5568),
    [anon_sym_on] = ACTIONS(5568),
    [anon_sym_equals] = ACTIONS(5568),
    [anon_sym_by] = ACTIONS(5568),
    [anon_sym_as] = ACTIONS(5568),
    [anon_sym_is] = ACTIONS(5568),
    [anon_sym_DASH_GT] = ACTIONS(5568),
    [anon_sym_with] = ACTIONS(5568),
    [aux_sym_preproc_if_token3] = ACTIONS(5568),
    [aux_sym_preproc_else_token1] = ACTIONS(5568),
    [aux_sym_preproc_elif_token1] = ACTIONS(5568),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4064] = {
    [sym_preproc_region] = STATE(4064),
    [sym_preproc_endregion] = STATE(4064),
    [sym_preproc_line] = STATE(4064),
    [sym_preproc_pragma] = STATE(4064),
    [sym_preproc_nullable] = STATE(4064),
    [sym_preproc_error] = STATE(4064),
    [sym_preproc_warning] = STATE(4064),
    [sym_preproc_define] = STATE(4064),
    [sym_preproc_undef] = STATE(4064),
    [anon_sym_SEMI] = ACTIONS(5518),
    [anon_sym_LBRACK] = ACTIONS(5518),
    [anon_sym_COLON] = ACTIONS(5518),
    [anon_sym_COMMA] = ACTIONS(5518),
    [anon_sym_RBRACK] = ACTIONS(5518),
    [anon_sym_LPAREN] = ACTIONS(5518),
    [anon_sym_RPAREN] = ACTIONS(5518),
    [anon_sym_RBRACE] = ACTIONS(5518),
    [anon_sym_LT] = ACTIONS(5520),
    [anon_sym_GT] = ACTIONS(5520),
    [anon_sym_in] = ACTIONS(5520),
    [anon_sym_QMARK] = ACTIONS(5520),
    [anon_sym_BANG] = ACTIONS(5520),
    [anon_sym_PLUS_PLUS] = ACTIONS(5518),
    [anon_sym_DASH_DASH] = ACTIONS(5518),
    [anon_sym_PLUS] = ACTIONS(5520),
    [anon_sym_DASH] = ACTIONS(5520),
    [anon_sym_STAR] = ACTIONS(5518),
    [anon_sym_SLASH] = ACTIONS(5520),
    [anon_sym_PERCENT] = ACTIONS(5518),
    [anon_sym_CARET] = ACTIONS(5518),
    [anon_sym_PIPE] = ACTIONS(5520),
    [anon_sym_AMP] = ACTIONS(5520),
    [anon_sym_LT_LT] = ACTIONS(5518),
    [anon_sym_GT_GT] = ACTIONS(5520),
    [anon_sym_GT_GT_GT] = ACTIONS(5518),
    [anon_sym_EQ_EQ] = ACTIONS(5518),
    [anon_sym_BANG_EQ] = ACTIONS(5518),
    [anon_sym_GT_EQ] = ACTIONS(5518),
    [anon_sym_LT_EQ] = ACTIONS(5518),
    [anon_sym_DOT] = ACTIONS(5520),
    [anon_sym_EQ_GT] = ACTIONS(5518),
    [anon_sym_switch] = ACTIONS(5518),
    [anon_sym_when] = ACTIONS(5518),
    [anon_sym_DOT_DOT] = ACTIONS(5518),
    [anon_sym_and] = ACTIONS(5518),
    [anon_sym_or] = ACTIONS(5518),
    [anon_sym_AMP_AMP] = ACTIONS(5518),
    [anon_sym_PIPE_PIPE] = ACTIONS(5518),
    [anon_sym_QMARK_QMARK] = ACTIONS(5518),
    [anon_sym_into] = ACTIONS(5518),
    [anon_sym_on] = ACTIONS(5518),
    [anon_sym_equals] = ACTIONS(5518),
    [anon_sym_by] = ACTIONS(5518),
    [anon_sym_as] = ACTIONS(5518),
    [anon_sym_is] = ACTIONS(5518),
    [anon_sym_DASH_GT] = ACTIONS(5518),
    [anon_sym_with] = ACTIONS(5518),
    [aux_sym_preproc_if_token3] = ACTIONS(5518),
    [aux_sym_preproc_else_token1] = ACTIONS(5518),
    [aux_sym_preproc_elif_token1] = ACTIONS(5518),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4065] = {
    [sym_preproc_region] = STATE(4065),
    [sym_preproc_endregion] = STATE(4065),
    [sym_preproc_line] = STATE(4065),
    [sym_preproc_pragma] = STATE(4065),
    [sym_preproc_nullable] = STATE(4065),
    [sym_preproc_error] = STATE(4065),
    [sym_preproc_warning] = STATE(4065),
    [sym_preproc_define] = STATE(4065),
    [sym_preproc_undef] = STATE(4065),
    [anon_sym_SEMI] = ACTIONS(5938),
    [anon_sym_LBRACK] = ACTIONS(5938),
    [anon_sym_COLON] = ACTIONS(5938),
    [anon_sym_COMMA] = ACTIONS(5938),
    [anon_sym_RBRACK] = ACTIONS(5938),
    [anon_sym_LPAREN] = ACTIONS(5938),
    [anon_sym_RPAREN] = ACTIONS(5938),
    [anon_sym_RBRACE] = ACTIONS(5938),
    [anon_sym_LT] = ACTIONS(5940),
    [anon_sym_GT] = ACTIONS(5940),
    [anon_sym_in] = ACTIONS(5940),
    [anon_sym_QMARK] = ACTIONS(5940),
    [anon_sym_BANG] = ACTIONS(5940),
    [anon_sym_PLUS_PLUS] = ACTIONS(5938),
    [anon_sym_DASH_DASH] = ACTIONS(5938),
    [anon_sym_PLUS] = ACTIONS(5940),
    [anon_sym_DASH] = ACTIONS(5940),
    [anon_sym_STAR] = ACTIONS(5938),
    [anon_sym_SLASH] = ACTIONS(5940),
    [anon_sym_PERCENT] = ACTIONS(5938),
    [anon_sym_CARET] = ACTIONS(5938),
    [anon_sym_PIPE] = ACTIONS(5940),
    [anon_sym_AMP] = ACTIONS(5940),
    [anon_sym_LT_LT] = ACTIONS(5938),
    [anon_sym_GT_GT] = ACTIONS(5940),
    [anon_sym_GT_GT_GT] = ACTIONS(5938),
    [anon_sym_EQ_EQ] = ACTIONS(5938),
    [anon_sym_BANG_EQ] = ACTIONS(5938),
    [anon_sym_GT_EQ] = ACTIONS(5938),
    [anon_sym_LT_EQ] = ACTIONS(5938),
    [anon_sym_DOT] = ACTIONS(5940),
    [anon_sym_EQ_GT] = ACTIONS(5938),
    [anon_sym_switch] = ACTIONS(5938),
    [anon_sym_when] = ACTIONS(5938),
    [anon_sym_DOT_DOT] = ACTIONS(5938),
    [anon_sym_and] = ACTIONS(5938),
    [anon_sym_or] = ACTIONS(5938),
    [anon_sym_AMP_AMP] = ACTIONS(5938),
    [anon_sym_PIPE_PIPE] = ACTIONS(5938),
    [anon_sym_QMARK_QMARK] = ACTIONS(5938),
    [anon_sym_into] = ACTIONS(5938),
    [anon_sym_on] = ACTIONS(5938),
    [anon_sym_equals] = ACTIONS(5938),
    [anon_sym_by] = ACTIONS(5938),
    [anon_sym_as] = ACTIONS(5938),
    [anon_sym_is] = ACTIONS(5938),
    [anon_sym_DASH_GT] = ACTIONS(5938),
    [anon_sym_with] = ACTIONS(5938),
    [aux_sym_preproc_if_token3] = ACTIONS(5938),
    [aux_sym_preproc_else_token1] = ACTIONS(5938),
    [aux_sym_preproc_elif_token1] = ACTIONS(5938),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4066] = {
    [sym_preproc_region] = STATE(4066),
    [sym_preproc_endregion] = STATE(4066),
    [sym_preproc_line] = STATE(4066),
    [sym_preproc_pragma] = STATE(4066),
    [sym_preproc_nullable] = STATE(4066),
    [sym_preproc_error] = STATE(4066),
    [sym_preproc_warning] = STATE(4066),
    [sym_preproc_define] = STATE(4066),
    [sym_preproc_undef] = STATE(4066),
    [anon_sym_SEMI] = ACTIONS(5656),
    [anon_sym_LBRACK] = ACTIONS(5656),
    [anon_sym_COLON] = ACTIONS(5656),
    [anon_sym_COMMA] = ACTIONS(5656),
    [anon_sym_RBRACK] = ACTIONS(5656),
    [anon_sym_LPAREN] = ACTIONS(5656),
    [anon_sym_RPAREN] = ACTIONS(5656),
    [anon_sym_RBRACE] = ACTIONS(5656),
    [anon_sym_LT] = ACTIONS(5658),
    [anon_sym_GT] = ACTIONS(5658),
    [anon_sym_in] = ACTIONS(5658),
    [anon_sym_QMARK] = ACTIONS(5658),
    [anon_sym_BANG] = ACTIONS(5658),
    [anon_sym_PLUS_PLUS] = ACTIONS(5656),
    [anon_sym_DASH_DASH] = ACTIONS(5656),
    [anon_sym_PLUS] = ACTIONS(5658),
    [anon_sym_DASH] = ACTIONS(5658),
    [anon_sym_STAR] = ACTIONS(5656),
    [anon_sym_SLASH] = ACTIONS(5658),
    [anon_sym_PERCENT] = ACTIONS(5656),
    [anon_sym_CARET] = ACTIONS(5656),
    [anon_sym_PIPE] = ACTIONS(5658),
    [anon_sym_AMP] = ACTIONS(5658),
    [anon_sym_LT_LT] = ACTIONS(5656),
    [anon_sym_GT_GT] = ACTIONS(5658),
    [anon_sym_GT_GT_GT] = ACTIONS(5656),
    [anon_sym_EQ_EQ] = ACTIONS(5656),
    [anon_sym_BANG_EQ] = ACTIONS(5656),
    [anon_sym_GT_EQ] = ACTIONS(5656),
    [anon_sym_LT_EQ] = ACTIONS(5656),
    [anon_sym_DOT] = ACTIONS(5658),
    [anon_sym_EQ_GT] = ACTIONS(5656),
    [anon_sym_switch] = ACTIONS(5656),
    [anon_sym_when] = ACTIONS(5656),
    [anon_sym_DOT_DOT] = ACTIONS(5656),
    [anon_sym_and] = ACTIONS(5656),
    [anon_sym_or] = ACTIONS(5656),
    [anon_sym_AMP_AMP] = ACTIONS(5656),
    [anon_sym_PIPE_PIPE] = ACTIONS(5656),
    [anon_sym_QMARK_QMARK] = ACTIONS(5656),
    [anon_sym_into] = ACTIONS(5656),
    [anon_sym_on] = ACTIONS(5656),
    [anon_sym_equals] = ACTIONS(5656),
    [anon_sym_by] = ACTIONS(5656),
    [anon_sym_as] = ACTIONS(5656),
    [anon_sym_is] = ACTIONS(5656),
    [anon_sym_DASH_GT] = ACTIONS(5656),
    [anon_sym_with] = ACTIONS(5656),
    [aux_sym_preproc_if_token3] = ACTIONS(5656),
    [aux_sym_preproc_else_token1] = ACTIONS(5656),
    [aux_sym_preproc_elif_token1] = ACTIONS(5656),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4067] = {
    [sym_preproc_region] = STATE(4067),
    [sym_preproc_endregion] = STATE(4067),
    [sym_preproc_line] = STATE(4067),
    [sym_preproc_pragma] = STATE(4067),
    [sym_preproc_nullable] = STATE(4067),
    [sym_preproc_error] = STATE(4067),
    [sym_preproc_warning] = STATE(4067),
    [sym_preproc_define] = STATE(4067),
    [sym_preproc_undef] = STATE(4067),
    [anon_sym_SEMI] = ACTIONS(5942),
    [anon_sym_LBRACK] = ACTIONS(5942),
    [anon_sym_COLON] = ACTIONS(5942),
    [anon_sym_COMMA] = ACTIONS(5942),
    [anon_sym_RBRACK] = ACTIONS(5942),
    [anon_sym_LPAREN] = ACTIONS(5942),
    [anon_sym_RPAREN] = ACTIONS(5942),
    [anon_sym_RBRACE] = ACTIONS(5942),
    [anon_sym_LT] = ACTIONS(5944),
    [anon_sym_GT] = ACTIONS(5944),
    [anon_sym_in] = ACTIONS(5944),
    [anon_sym_QMARK] = ACTIONS(5944),
    [anon_sym_BANG] = ACTIONS(5944),
    [anon_sym_PLUS_PLUS] = ACTIONS(5942),
    [anon_sym_DASH_DASH] = ACTIONS(5942),
    [anon_sym_PLUS] = ACTIONS(5944),
    [anon_sym_DASH] = ACTIONS(5944),
    [anon_sym_STAR] = ACTIONS(5942),
    [anon_sym_SLASH] = ACTIONS(5944),
    [anon_sym_PERCENT] = ACTIONS(5942),
    [anon_sym_CARET] = ACTIONS(5942),
    [anon_sym_PIPE] = ACTIONS(5944),
    [anon_sym_AMP] = ACTIONS(5944),
    [anon_sym_LT_LT] = ACTIONS(5942),
    [anon_sym_GT_GT] = ACTIONS(5944),
    [anon_sym_GT_GT_GT] = ACTIONS(5942),
    [anon_sym_EQ_EQ] = ACTIONS(5942),
    [anon_sym_BANG_EQ] = ACTIONS(5942),
    [anon_sym_GT_EQ] = ACTIONS(5942),
    [anon_sym_LT_EQ] = ACTIONS(5942),
    [anon_sym_DOT] = ACTIONS(5944),
    [anon_sym_EQ_GT] = ACTIONS(5942),
    [anon_sym_switch] = ACTIONS(5942),
    [anon_sym_when] = ACTIONS(5942),
    [anon_sym_DOT_DOT] = ACTIONS(5942),
    [anon_sym_and] = ACTIONS(5942),
    [anon_sym_or] = ACTIONS(5942),
    [anon_sym_AMP_AMP] = ACTIONS(5942),
    [anon_sym_PIPE_PIPE] = ACTIONS(5942),
    [anon_sym_QMARK_QMARK] = ACTIONS(5942),
    [anon_sym_into] = ACTIONS(5942),
    [anon_sym_on] = ACTIONS(5942),
    [anon_sym_equals] = ACTIONS(5942),
    [anon_sym_by] = ACTIONS(5942),
    [anon_sym_as] = ACTIONS(5942),
    [anon_sym_is] = ACTIONS(5942),
    [anon_sym_DASH_GT] = ACTIONS(5942),
    [anon_sym_with] = ACTIONS(5942),
    [aux_sym_preproc_if_token3] = ACTIONS(5942),
    [aux_sym_preproc_else_token1] = ACTIONS(5942),
    [aux_sym_preproc_elif_token1] = ACTIONS(5942),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4068] = {
    [sym_preproc_region] = STATE(4068),
    [sym_preproc_endregion] = STATE(4068),
    [sym_preproc_line] = STATE(4068),
    [sym_preproc_pragma] = STATE(4068),
    [sym_preproc_nullable] = STATE(4068),
    [sym_preproc_error] = STATE(4068),
    [sym_preproc_warning] = STATE(4068),
    [sym_preproc_define] = STATE(4068),
    [sym_preproc_undef] = STATE(4068),
    [anon_sym_SEMI] = ACTIONS(5946),
    [anon_sym_LBRACK] = ACTIONS(5946),
    [anon_sym_COLON] = ACTIONS(5946),
    [anon_sym_COMMA] = ACTIONS(5946),
    [anon_sym_RBRACK] = ACTIONS(5946),
    [anon_sym_LPAREN] = ACTIONS(5946),
    [anon_sym_RPAREN] = ACTIONS(5946),
    [anon_sym_RBRACE] = ACTIONS(5946),
    [anon_sym_LT] = ACTIONS(5948),
    [anon_sym_GT] = ACTIONS(5948),
    [anon_sym_in] = ACTIONS(5948),
    [anon_sym_QMARK] = ACTIONS(5948),
    [anon_sym_BANG] = ACTIONS(5948),
    [anon_sym_PLUS_PLUS] = ACTIONS(5946),
    [anon_sym_DASH_DASH] = ACTIONS(5946),
    [anon_sym_PLUS] = ACTIONS(5948),
    [anon_sym_DASH] = ACTIONS(5948),
    [anon_sym_STAR] = ACTIONS(5946),
    [anon_sym_SLASH] = ACTIONS(5948),
    [anon_sym_PERCENT] = ACTIONS(5946),
    [anon_sym_CARET] = ACTIONS(5946),
    [anon_sym_PIPE] = ACTIONS(5948),
    [anon_sym_AMP] = ACTIONS(5948),
    [anon_sym_LT_LT] = ACTIONS(5946),
    [anon_sym_GT_GT] = ACTIONS(5948),
    [anon_sym_GT_GT_GT] = ACTIONS(5946),
    [anon_sym_EQ_EQ] = ACTIONS(5946),
    [anon_sym_BANG_EQ] = ACTIONS(5946),
    [anon_sym_GT_EQ] = ACTIONS(5946),
    [anon_sym_LT_EQ] = ACTIONS(5946),
    [anon_sym_DOT] = ACTIONS(5948),
    [anon_sym_EQ_GT] = ACTIONS(5946),
    [anon_sym_switch] = ACTIONS(5946),
    [anon_sym_when] = ACTIONS(5946),
    [anon_sym_DOT_DOT] = ACTIONS(5946),
    [anon_sym_and] = ACTIONS(5946),
    [anon_sym_or] = ACTIONS(5946),
    [anon_sym_AMP_AMP] = ACTIONS(5946),
    [anon_sym_PIPE_PIPE] = ACTIONS(5946),
    [anon_sym_QMARK_QMARK] = ACTIONS(5946),
    [anon_sym_into] = ACTIONS(5946),
    [anon_sym_on] = ACTIONS(5946),
    [anon_sym_equals] = ACTIONS(5946),
    [anon_sym_by] = ACTIONS(5946),
    [anon_sym_as] = ACTIONS(5946),
    [anon_sym_is] = ACTIONS(5946),
    [anon_sym_DASH_GT] = ACTIONS(5946),
    [anon_sym_with] = ACTIONS(5946),
    [aux_sym_preproc_if_token3] = ACTIONS(5946),
    [aux_sym_preproc_else_token1] = ACTIONS(5946),
    [aux_sym_preproc_elif_token1] = ACTIONS(5946),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4069] = {
    [sym_preproc_region] = STATE(4069),
    [sym_preproc_endregion] = STATE(4069),
    [sym_preproc_line] = STATE(4069),
    [sym_preproc_pragma] = STATE(4069),
    [sym_preproc_nullable] = STATE(4069),
    [sym_preproc_error] = STATE(4069),
    [sym_preproc_warning] = STATE(4069),
    [sym_preproc_define] = STATE(4069),
    [sym_preproc_undef] = STATE(4069),
    [anon_sym_EQ] = ACTIONS(5950),
    [anon_sym_LBRACK] = ACTIONS(5286),
    [anon_sym_COLON] = ACTIONS(5286),
    [anon_sym_COMMA] = ACTIONS(5286),
    [anon_sym_LPAREN] = ACTIONS(5286),
    [anon_sym_RPAREN] = ACTIONS(5286),
    [anon_sym_RBRACE] = ACTIONS(5286),
    [anon_sym_LT] = ACTIONS(5288),
    [anon_sym_GT] = ACTIONS(5288),
    [anon_sym_QMARK] = ACTIONS(5288),
    [anon_sym_BANG] = ACTIONS(5288),
    [anon_sym_PLUS_PLUS] = ACTIONS(5286),
    [anon_sym_DASH_DASH] = ACTIONS(5286),
    [anon_sym_PLUS] = ACTIONS(5288),
    [anon_sym_DASH] = ACTIONS(5288),
    [anon_sym_STAR] = ACTIONS(5288),
    [anon_sym_SLASH] = ACTIONS(5288),
    [anon_sym_PERCENT] = ACTIONS(5288),
    [anon_sym_CARET] = ACTIONS(5288),
    [anon_sym_PIPE] = ACTIONS(5288),
    [anon_sym_AMP] = ACTIONS(5288),
    [anon_sym_LT_LT] = ACTIONS(5288),
    [anon_sym_GT_GT] = ACTIONS(5288),
    [anon_sym_GT_GT_GT] = ACTIONS(5288),
    [anon_sym_EQ_EQ] = ACTIONS(5286),
    [anon_sym_BANG_EQ] = ACTIONS(5286),
    [anon_sym_GT_EQ] = ACTIONS(5286),
    [anon_sym_LT_EQ] = ACTIONS(5286),
    [anon_sym_DOT] = ACTIONS(5288),
    [anon_sym_switch] = ACTIONS(5286),
    [anon_sym_DOT_DOT] = ACTIONS(5286),
    [anon_sym_PLUS_EQ] = ACTIONS(5952),
    [anon_sym_DASH_EQ] = ACTIONS(5952),
    [anon_sym_STAR_EQ] = ACTIONS(5952),
    [anon_sym_SLASH_EQ] = ACTIONS(5952),
    [anon_sym_PERCENT_EQ] = ACTIONS(5952),
    [anon_sym_AMP_EQ] = ACTIONS(5952),
    [anon_sym_CARET_EQ] = ACTIONS(5952),
    [anon_sym_PIPE_EQ] = ACTIONS(5952),
    [anon_sym_LT_LT_EQ] = ACTIONS(5952),
    [anon_sym_GT_GT_EQ] = ACTIONS(5952),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(5952),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(5952),
    [anon_sym_AMP_AMP] = ACTIONS(5286),
    [anon_sym_PIPE_PIPE] = ACTIONS(5286),
    [anon_sym_QMARK_QMARK] = ACTIONS(5288),
    [anon_sym_into] = ACTIONS(5286),
    [anon_sym_as] = ACTIONS(5286),
    [anon_sym_is] = ACTIONS(5286),
    [anon_sym_DASH_GT] = ACTIONS(5286),
    [anon_sym_with] = ACTIONS(5286),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4070] = {
    [sym_preproc_region] = STATE(4070),
    [sym_preproc_endregion] = STATE(4070),
    [sym_preproc_line] = STATE(4070),
    [sym_preproc_pragma] = STATE(4070),
    [sym_preproc_nullable] = STATE(4070),
    [sym_preproc_error] = STATE(4070),
    [sym_preproc_warning] = STATE(4070),
    [sym_preproc_define] = STATE(4070),
    [sym_preproc_undef] = STATE(4070),
    [anon_sym_SEMI] = ACTIONS(4310),
    [anon_sym_LBRACK] = ACTIONS(4310),
    [anon_sym_COLON] = ACTIONS(4310),
    [anon_sym_COMMA] = ACTIONS(4310),
    [anon_sym_RBRACK] = ACTIONS(4310),
    [anon_sym_LPAREN] = ACTIONS(4310),
    [anon_sym_RPAREN] = ACTIONS(4310),
    [anon_sym_RBRACE] = ACTIONS(4310),
    [anon_sym_LT] = ACTIONS(5873),
    [anon_sym_GT] = ACTIONS(5873),
    [anon_sym_in] = ACTIONS(5873),
    [anon_sym_QMARK] = ACTIONS(5873),
    [anon_sym_BANG] = ACTIONS(5873),
    [anon_sym_PLUS_PLUS] = ACTIONS(4310),
    [anon_sym_DASH_DASH] = ACTIONS(4310),
    [anon_sym_PLUS] = ACTIONS(5873),
    [anon_sym_DASH] = ACTIONS(5873),
    [anon_sym_STAR] = ACTIONS(4310),
    [anon_sym_SLASH] = ACTIONS(5873),
    [anon_sym_PERCENT] = ACTIONS(4310),
    [anon_sym_CARET] = ACTIONS(4310),
    [anon_sym_PIPE] = ACTIONS(5873),
    [anon_sym_AMP] = ACTIONS(5873),
    [anon_sym_LT_LT] = ACTIONS(4310),
    [anon_sym_GT_GT] = ACTIONS(5873),
    [anon_sym_GT_GT_GT] = ACTIONS(4310),
    [anon_sym_EQ_EQ] = ACTIONS(4310),
    [anon_sym_BANG_EQ] = ACTIONS(4310),
    [anon_sym_GT_EQ] = ACTIONS(4310),
    [anon_sym_LT_EQ] = ACTIONS(4310),
    [anon_sym_DOT] = ACTIONS(5873),
    [anon_sym_EQ_GT] = ACTIONS(4145),
    [anon_sym_switch] = ACTIONS(4310),
    [anon_sym_when] = ACTIONS(4310),
    [anon_sym_DOT_DOT] = ACTIONS(4310),
    [anon_sym_and] = ACTIONS(4310),
    [anon_sym_or] = ACTIONS(4310),
    [anon_sym_AMP_AMP] = ACTIONS(4310),
    [anon_sym_PIPE_PIPE] = ACTIONS(4310),
    [anon_sym_QMARK_QMARK] = ACTIONS(4310),
    [anon_sym_into] = ACTIONS(4310),
    [anon_sym_on] = ACTIONS(4310),
    [anon_sym_equals] = ACTIONS(4310),
    [anon_sym_by] = ACTIONS(4310),
    [anon_sym_as] = ACTIONS(4310),
    [anon_sym_is] = ACTIONS(4310),
    [anon_sym_DASH_GT] = ACTIONS(4310),
    [anon_sym_with] = ACTIONS(4310),
    [aux_sym_preproc_if_token3] = ACTIONS(4310),
    [aux_sym_preproc_else_token1] = ACTIONS(4310),
    [aux_sym_preproc_elif_token1] = ACTIONS(4310),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4071] = {
    [sym_preproc_region] = STATE(4071),
    [sym_preproc_endregion] = STATE(4071),
    [sym_preproc_line] = STATE(4071),
    [sym_preproc_pragma] = STATE(4071),
    [sym_preproc_nullable] = STATE(4071),
    [sym_preproc_error] = STATE(4071),
    [sym_preproc_warning] = STATE(4071),
    [sym_preproc_define] = STATE(4071),
    [sym_preproc_undef] = STATE(4071),
    [anon_sym_SEMI] = ACTIONS(5382),
    [anon_sym_LBRACK] = ACTIONS(5382),
    [anon_sym_COLON] = ACTIONS(5382),
    [anon_sym_COMMA] = ACTIONS(5382),
    [anon_sym_RBRACK] = ACTIONS(5382),
    [anon_sym_LPAREN] = ACTIONS(5382),
    [anon_sym_RPAREN] = ACTIONS(5382),
    [anon_sym_RBRACE] = ACTIONS(5382),
    [anon_sym_LT] = ACTIONS(5384),
    [anon_sym_GT] = ACTIONS(5384),
    [anon_sym_in] = ACTIONS(5384),
    [anon_sym_QMARK] = ACTIONS(5384),
    [anon_sym_BANG] = ACTIONS(5384),
    [anon_sym_PLUS_PLUS] = ACTIONS(5382),
    [anon_sym_DASH_DASH] = ACTIONS(5382),
    [anon_sym_PLUS] = ACTIONS(5384),
    [anon_sym_DASH] = ACTIONS(5384),
    [anon_sym_STAR] = ACTIONS(5382),
    [anon_sym_SLASH] = ACTIONS(5384),
    [anon_sym_PERCENT] = ACTIONS(5382),
    [anon_sym_CARET] = ACTIONS(5382),
    [anon_sym_PIPE] = ACTIONS(5384),
    [anon_sym_AMP] = ACTIONS(5384),
    [anon_sym_LT_LT] = ACTIONS(5382),
    [anon_sym_GT_GT] = ACTIONS(5384),
    [anon_sym_GT_GT_GT] = ACTIONS(5382),
    [anon_sym_EQ_EQ] = ACTIONS(5382),
    [anon_sym_BANG_EQ] = ACTIONS(5382),
    [anon_sym_GT_EQ] = ACTIONS(5382),
    [anon_sym_LT_EQ] = ACTIONS(5382),
    [anon_sym_DOT] = ACTIONS(5384),
    [anon_sym_EQ_GT] = ACTIONS(5382),
    [anon_sym_switch] = ACTIONS(5382),
    [anon_sym_when] = ACTIONS(5382),
    [anon_sym_DOT_DOT] = ACTIONS(5382),
    [anon_sym_and] = ACTIONS(5382),
    [anon_sym_or] = ACTIONS(5382),
    [anon_sym_AMP_AMP] = ACTIONS(5382),
    [anon_sym_PIPE_PIPE] = ACTIONS(5382),
    [anon_sym_QMARK_QMARK] = ACTIONS(5382),
    [anon_sym_into] = ACTIONS(5382),
    [anon_sym_on] = ACTIONS(5382),
    [anon_sym_equals] = ACTIONS(5382),
    [anon_sym_by] = ACTIONS(5382),
    [anon_sym_as] = ACTIONS(5382),
    [anon_sym_is] = ACTIONS(5382),
    [anon_sym_DASH_GT] = ACTIONS(5382),
    [anon_sym_with] = ACTIONS(5382),
    [aux_sym_preproc_if_token3] = ACTIONS(5382),
    [aux_sym_preproc_else_token1] = ACTIONS(5382),
    [aux_sym_preproc_elif_token1] = ACTIONS(5382),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4072] = {
    [sym_preproc_region] = STATE(4072),
    [sym_preproc_endregion] = STATE(4072),
    [sym_preproc_line] = STATE(4072),
    [sym_preproc_pragma] = STATE(4072),
    [sym_preproc_nullable] = STATE(4072),
    [sym_preproc_error] = STATE(4072),
    [sym_preproc_warning] = STATE(4072),
    [sym_preproc_define] = STATE(4072),
    [sym_preproc_undef] = STATE(4072),
    [anon_sym_SEMI] = ACTIONS(4504),
    [anon_sym_LBRACK] = ACTIONS(4504),
    [anon_sym_COLON] = ACTIONS(4504),
    [anon_sym_COMMA] = ACTIONS(4504),
    [anon_sym_RBRACK] = ACTIONS(4504),
    [anon_sym_LPAREN] = ACTIONS(4504),
    [anon_sym_RPAREN] = ACTIONS(4504),
    [anon_sym_LBRACE] = ACTIONS(4504),
    [anon_sym_RBRACE] = ACTIONS(4504),
    [anon_sym_LT] = ACTIONS(4502),
    [anon_sym_GT] = ACTIONS(4502),
    [anon_sym_in] = ACTIONS(4504),
    [anon_sym_QMARK] = ACTIONS(4502),
    [anon_sym_BANG] = ACTIONS(4502),
    [anon_sym_PLUS_PLUS] = ACTIONS(4504),
    [anon_sym_DASH_DASH] = ACTIONS(4504),
    [anon_sym_PLUS] = ACTIONS(4502),
    [anon_sym_DASH] = ACTIONS(4502),
    [anon_sym_STAR] = ACTIONS(4504),
    [anon_sym_SLASH] = ACTIONS(4502),
    [anon_sym_PERCENT] = ACTIONS(4504),
    [anon_sym_CARET] = ACTIONS(4504),
    [anon_sym_PIPE] = ACTIONS(4502),
    [anon_sym_AMP] = ACTIONS(4502),
    [anon_sym_LT_LT] = ACTIONS(4504),
    [anon_sym_GT_GT] = ACTIONS(4502),
    [anon_sym_GT_GT_GT] = ACTIONS(4504),
    [anon_sym_EQ_EQ] = ACTIONS(4504),
    [anon_sym_BANG_EQ] = ACTIONS(4504),
    [anon_sym_GT_EQ] = ACTIONS(4504),
    [anon_sym_LT_EQ] = ACTIONS(4504),
    [anon_sym_DOT] = ACTIONS(4502),
    [anon_sym_EQ_GT] = ACTIONS(4504),
    [anon_sym_switch] = ACTIONS(4504),
    [anon_sym_when] = ACTIONS(4504),
    [anon_sym_DOT_DOT] = ACTIONS(4504),
    [anon_sym_and] = ACTIONS(4504),
    [anon_sym_or] = ACTIONS(4504),
    [anon_sym_AMP_AMP] = ACTIONS(4504),
    [anon_sym_PIPE_PIPE] = ACTIONS(4504),
    [anon_sym_QMARK_QMARK] = ACTIONS(4504),
    [anon_sym_on] = ACTIONS(4504),
    [anon_sym_equals] = ACTIONS(4504),
    [anon_sym_by] = ACTIONS(4504),
    [anon_sym_as] = ACTIONS(4504),
    [anon_sym_is] = ACTIONS(4504),
    [anon_sym_DASH_GT] = ACTIONS(4504),
    [anon_sym_with] = ACTIONS(4504),
    [aux_sym_preproc_if_token3] = ACTIONS(4504),
    [aux_sym_preproc_else_token1] = ACTIONS(4504),
    [aux_sym_preproc_elif_token1] = ACTIONS(4504),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4073] = {
    [sym_preproc_region] = STATE(4073),
    [sym_preproc_endregion] = STATE(4073),
    [sym_preproc_line] = STATE(4073),
    [sym_preproc_pragma] = STATE(4073),
    [sym_preproc_nullable] = STATE(4073),
    [sym_preproc_error] = STATE(4073),
    [sym_preproc_warning] = STATE(4073),
    [sym_preproc_define] = STATE(4073),
    [sym_preproc_undef] = STATE(4073),
    [anon_sym_SEMI] = ACTIONS(5480),
    [anon_sym_LBRACK] = ACTIONS(5480),
    [anon_sym_COLON] = ACTIONS(5480),
    [anon_sym_COMMA] = ACTIONS(5480),
    [anon_sym_RBRACK] = ACTIONS(5480),
    [anon_sym_LPAREN] = ACTIONS(5480),
    [anon_sym_RPAREN] = ACTIONS(5480),
    [anon_sym_RBRACE] = ACTIONS(5480),
    [anon_sym_LT] = ACTIONS(5482),
    [anon_sym_GT] = ACTIONS(5482),
    [anon_sym_in] = ACTIONS(5482),
    [anon_sym_QMARK] = ACTIONS(5482),
    [anon_sym_BANG] = ACTIONS(5482),
    [anon_sym_PLUS_PLUS] = ACTIONS(5480),
    [anon_sym_DASH_DASH] = ACTIONS(5480),
    [anon_sym_PLUS] = ACTIONS(5482),
    [anon_sym_DASH] = ACTIONS(5482),
    [anon_sym_STAR] = ACTIONS(5480),
    [anon_sym_SLASH] = ACTIONS(5482),
    [anon_sym_PERCENT] = ACTIONS(5480),
    [anon_sym_CARET] = ACTIONS(5480),
    [anon_sym_PIPE] = ACTIONS(5482),
    [anon_sym_AMP] = ACTIONS(5482),
    [anon_sym_LT_LT] = ACTIONS(5480),
    [anon_sym_GT_GT] = ACTIONS(5482),
    [anon_sym_GT_GT_GT] = ACTIONS(5480),
    [anon_sym_EQ_EQ] = ACTIONS(5480),
    [anon_sym_BANG_EQ] = ACTIONS(5480),
    [anon_sym_GT_EQ] = ACTIONS(5480),
    [anon_sym_LT_EQ] = ACTIONS(5480),
    [anon_sym_DOT] = ACTIONS(5482),
    [anon_sym_EQ_GT] = ACTIONS(5480),
    [anon_sym_switch] = ACTIONS(5480),
    [anon_sym_when] = ACTIONS(5480),
    [anon_sym_DOT_DOT] = ACTIONS(5480),
    [anon_sym_and] = ACTIONS(5480),
    [anon_sym_or] = ACTIONS(5480),
    [anon_sym_AMP_AMP] = ACTIONS(5480),
    [anon_sym_PIPE_PIPE] = ACTIONS(5480),
    [anon_sym_QMARK_QMARK] = ACTIONS(5480),
    [anon_sym_into] = ACTIONS(5480),
    [anon_sym_on] = ACTIONS(5480),
    [anon_sym_equals] = ACTIONS(5480),
    [anon_sym_by] = ACTIONS(5480),
    [anon_sym_as] = ACTIONS(5480),
    [anon_sym_is] = ACTIONS(5480),
    [anon_sym_DASH_GT] = ACTIONS(5480),
    [anon_sym_with] = ACTIONS(5480),
    [aux_sym_preproc_if_token3] = ACTIONS(5480),
    [aux_sym_preproc_else_token1] = ACTIONS(5480),
    [aux_sym_preproc_elif_token1] = ACTIONS(5480),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4074] = {
    [sym_preproc_region] = STATE(4074),
    [sym_preproc_endregion] = STATE(4074),
    [sym_preproc_line] = STATE(4074),
    [sym_preproc_pragma] = STATE(4074),
    [sym_preproc_nullable] = STATE(4074),
    [sym_preproc_error] = STATE(4074),
    [sym_preproc_warning] = STATE(4074),
    [sym_preproc_define] = STATE(4074),
    [sym_preproc_undef] = STATE(4074),
    [anon_sym_SEMI] = ACTIONS(5588),
    [anon_sym_LBRACK] = ACTIONS(5588),
    [anon_sym_COLON] = ACTIONS(5588),
    [anon_sym_COMMA] = ACTIONS(5588),
    [anon_sym_RBRACK] = ACTIONS(5588),
    [anon_sym_LPAREN] = ACTIONS(5588),
    [anon_sym_RPAREN] = ACTIONS(5588),
    [anon_sym_RBRACE] = ACTIONS(5588),
    [anon_sym_LT] = ACTIONS(5590),
    [anon_sym_GT] = ACTIONS(5590),
    [anon_sym_in] = ACTIONS(5590),
    [anon_sym_QMARK] = ACTIONS(5590),
    [anon_sym_BANG] = ACTIONS(5590),
    [anon_sym_PLUS_PLUS] = ACTIONS(5588),
    [anon_sym_DASH_DASH] = ACTIONS(5588),
    [anon_sym_PLUS] = ACTIONS(5590),
    [anon_sym_DASH] = ACTIONS(5590),
    [anon_sym_STAR] = ACTIONS(5588),
    [anon_sym_SLASH] = ACTIONS(5590),
    [anon_sym_PERCENT] = ACTIONS(5588),
    [anon_sym_CARET] = ACTIONS(5588),
    [anon_sym_PIPE] = ACTIONS(5590),
    [anon_sym_AMP] = ACTIONS(5590),
    [anon_sym_LT_LT] = ACTIONS(5588),
    [anon_sym_GT_GT] = ACTIONS(5590),
    [anon_sym_GT_GT_GT] = ACTIONS(5588),
    [anon_sym_EQ_EQ] = ACTIONS(5588),
    [anon_sym_BANG_EQ] = ACTIONS(5588),
    [anon_sym_GT_EQ] = ACTIONS(5588),
    [anon_sym_LT_EQ] = ACTIONS(5588),
    [anon_sym_DOT] = ACTIONS(5590),
    [anon_sym_EQ_GT] = ACTIONS(5588),
    [anon_sym_switch] = ACTIONS(5588),
    [anon_sym_when] = ACTIONS(5588),
    [anon_sym_DOT_DOT] = ACTIONS(5588),
    [anon_sym_and] = ACTIONS(5588),
    [anon_sym_or] = ACTIONS(5588),
    [anon_sym_AMP_AMP] = ACTIONS(5588),
    [anon_sym_PIPE_PIPE] = ACTIONS(5588),
    [anon_sym_QMARK_QMARK] = ACTIONS(5588),
    [anon_sym_into] = ACTIONS(5588),
    [anon_sym_on] = ACTIONS(5588),
    [anon_sym_equals] = ACTIONS(5588),
    [anon_sym_by] = ACTIONS(5588),
    [anon_sym_as] = ACTIONS(5588),
    [anon_sym_is] = ACTIONS(5588),
    [anon_sym_DASH_GT] = ACTIONS(5588),
    [anon_sym_with] = ACTIONS(5588),
    [aux_sym_preproc_if_token3] = ACTIONS(5588),
    [aux_sym_preproc_else_token1] = ACTIONS(5588),
    [aux_sym_preproc_elif_token1] = ACTIONS(5588),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4075] = {
    [sym_preproc_region] = STATE(4075),
    [sym_preproc_endregion] = STATE(4075),
    [sym_preproc_line] = STATE(4075),
    [sym_preproc_pragma] = STATE(4075),
    [sym_preproc_nullable] = STATE(4075),
    [sym_preproc_error] = STATE(4075),
    [sym_preproc_warning] = STATE(4075),
    [sym_preproc_define] = STATE(4075),
    [sym_preproc_undef] = STATE(4075),
    [anon_sym_SEMI] = ACTIONS(5510),
    [anon_sym_LBRACK] = ACTIONS(5510),
    [anon_sym_COLON] = ACTIONS(5510),
    [anon_sym_COMMA] = ACTIONS(5510),
    [anon_sym_RBRACK] = ACTIONS(5510),
    [anon_sym_LPAREN] = ACTIONS(5510),
    [anon_sym_RPAREN] = ACTIONS(5510),
    [anon_sym_RBRACE] = ACTIONS(5510),
    [anon_sym_LT] = ACTIONS(5512),
    [anon_sym_GT] = ACTIONS(5512),
    [anon_sym_in] = ACTIONS(5512),
    [anon_sym_QMARK] = ACTIONS(5512),
    [anon_sym_BANG] = ACTIONS(5512),
    [anon_sym_PLUS_PLUS] = ACTIONS(5510),
    [anon_sym_DASH_DASH] = ACTIONS(5510),
    [anon_sym_PLUS] = ACTIONS(5512),
    [anon_sym_DASH] = ACTIONS(5512),
    [anon_sym_STAR] = ACTIONS(5510),
    [anon_sym_SLASH] = ACTIONS(5512),
    [anon_sym_PERCENT] = ACTIONS(5510),
    [anon_sym_CARET] = ACTIONS(5510),
    [anon_sym_PIPE] = ACTIONS(5512),
    [anon_sym_AMP] = ACTIONS(5512),
    [anon_sym_LT_LT] = ACTIONS(5510),
    [anon_sym_GT_GT] = ACTIONS(5512),
    [anon_sym_GT_GT_GT] = ACTIONS(5510),
    [anon_sym_EQ_EQ] = ACTIONS(5510),
    [anon_sym_BANG_EQ] = ACTIONS(5510),
    [anon_sym_GT_EQ] = ACTIONS(5510),
    [anon_sym_LT_EQ] = ACTIONS(5510),
    [anon_sym_DOT] = ACTIONS(5512),
    [anon_sym_EQ_GT] = ACTIONS(5510),
    [anon_sym_switch] = ACTIONS(5510),
    [anon_sym_when] = ACTIONS(5510),
    [anon_sym_DOT_DOT] = ACTIONS(5510),
    [anon_sym_and] = ACTIONS(5510),
    [anon_sym_or] = ACTIONS(5510),
    [anon_sym_AMP_AMP] = ACTIONS(5510),
    [anon_sym_PIPE_PIPE] = ACTIONS(5510),
    [anon_sym_QMARK_QMARK] = ACTIONS(5510),
    [anon_sym_into] = ACTIONS(5510),
    [anon_sym_on] = ACTIONS(5510),
    [anon_sym_equals] = ACTIONS(5510),
    [anon_sym_by] = ACTIONS(5510),
    [anon_sym_as] = ACTIONS(5510),
    [anon_sym_is] = ACTIONS(5510),
    [anon_sym_DASH_GT] = ACTIONS(5510),
    [anon_sym_with] = ACTIONS(5510),
    [aux_sym_preproc_if_token3] = ACTIONS(5510),
    [aux_sym_preproc_else_token1] = ACTIONS(5510),
    [aux_sym_preproc_elif_token1] = ACTIONS(5510),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4076] = {
    [sym_preproc_region] = STATE(4076),
    [sym_preproc_endregion] = STATE(4076),
    [sym_preproc_line] = STATE(4076),
    [sym_preproc_pragma] = STATE(4076),
    [sym_preproc_nullable] = STATE(4076),
    [sym_preproc_error] = STATE(4076),
    [sym_preproc_warning] = STATE(4076),
    [sym_preproc_define] = STATE(4076),
    [sym_preproc_undef] = STATE(4076),
    [anon_sym_SEMI] = ACTIONS(5470),
    [anon_sym_LBRACK] = ACTIONS(5470),
    [anon_sym_COLON] = ACTIONS(5470),
    [anon_sym_COMMA] = ACTIONS(5470),
    [anon_sym_RBRACK] = ACTIONS(5470),
    [anon_sym_LPAREN] = ACTIONS(5470),
    [anon_sym_RPAREN] = ACTIONS(5470),
    [anon_sym_RBRACE] = ACTIONS(5470),
    [anon_sym_LT] = ACTIONS(5472),
    [anon_sym_GT] = ACTIONS(5472),
    [anon_sym_in] = ACTIONS(5472),
    [anon_sym_QMARK] = ACTIONS(5472),
    [anon_sym_BANG] = ACTIONS(5472),
    [anon_sym_PLUS_PLUS] = ACTIONS(5470),
    [anon_sym_DASH_DASH] = ACTIONS(5470),
    [anon_sym_PLUS] = ACTIONS(5472),
    [anon_sym_DASH] = ACTIONS(5472),
    [anon_sym_STAR] = ACTIONS(5470),
    [anon_sym_SLASH] = ACTIONS(5472),
    [anon_sym_PERCENT] = ACTIONS(5470),
    [anon_sym_CARET] = ACTIONS(5470),
    [anon_sym_PIPE] = ACTIONS(5472),
    [anon_sym_AMP] = ACTIONS(5472),
    [anon_sym_LT_LT] = ACTIONS(5470),
    [anon_sym_GT_GT] = ACTIONS(5472),
    [anon_sym_GT_GT_GT] = ACTIONS(5470),
    [anon_sym_EQ_EQ] = ACTIONS(5470),
    [anon_sym_BANG_EQ] = ACTIONS(5470),
    [anon_sym_GT_EQ] = ACTIONS(5470),
    [anon_sym_LT_EQ] = ACTIONS(5470),
    [anon_sym_DOT] = ACTIONS(5472),
    [anon_sym_EQ_GT] = ACTIONS(5470),
    [anon_sym_switch] = ACTIONS(5470),
    [anon_sym_when] = ACTIONS(5470),
    [anon_sym_DOT_DOT] = ACTIONS(5470),
    [anon_sym_and] = ACTIONS(5470),
    [anon_sym_or] = ACTIONS(5470),
    [anon_sym_AMP_AMP] = ACTIONS(5470),
    [anon_sym_PIPE_PIPE] = ACTIONS(5470),
    [anon_sym_QMARK_QMARK] = ACTIONS(5470),
    [anon_sym_into] = ACTIONS(5470),
    [anon_sym_on] = ACTIONS(5470),
    [anon_sym_equals] = ACTIONS(5470),
    [anon_sym_by] = ACTIONS(5470),
    [anon_sym_as] = ACTIONS(5470),
    [anon_sym_is] = ACTIONS(5470),
    [anon_sym_DASH_GT] = ACTIONS(5470),
    [anon_sym_with] = ACTIONS(5470),
    [aux_sym_preproc_if_token3] = ACTIONS(5470),
    [aux_sym_preproc_else_token1] = ACTIONS(5470),
    [aux_sym_preproc_elif_token1] = ACTIONS(5470),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4077] = {
    [sym_preproc_region] = STATE(4077),
    [sym_preproc_endregion] = STATE(4077),
    [sym_preproc_line] = STATE(4077),
    [sym_preproc_pragma] = STATE(4077),
    [sym_preproc_nullable] = STATE(4077),
    [sym_preproc_error] = STATE(4077),
    [sym_preproc_warning] = STATE(4077),
    [sym_preproc_define] = STATE(4077),
    [sym_preproc_undef] = STATE(4077),
    [anon_sym_SEMI] = ACTIONS(5412),
    [anon_sym_LBRACK] = ACTIONS(5412),
    [anon_sym_COLON] = ACTIONS(5412),
    [anon_sym_COMMA] = ACTIONS(5412),
    [anon_sym_RBRACK] = ACTIONS(5412),
    [anon_sym_LPAREN] = ACTIONS(5412),
    [anon_sym_RPAREN] = ACTIONS(5412),
    [anon_sym_RBRACE] = ACTIONS(5412),
    [anon_sym_LT] = ACTIONS(5414),
    [anon_sym_GT] = ACTIONS(5414),
    [anon_sym_in] = ACTIONS(5414),
    [anon_sym_QMARK] = ACTIONS(5414),
    [anon_sym_BANG] = ACTIONS(5414),
    [anon_sym_PLUS_PLUS] = ACTIONS(5412),
    [anon_sym_DASH_DASH] = ACTIONS(5412),
    [anon_sym_PLUS] = ACTIONS(5414),
    [anon_sym_DASH] = ACTIONS(5414),
    [anon_sym_STAR] = ACTIONS(5412),
    [anon_sym_SLASH] = ACTIONS(5414),
    [anon_sym_PERCENT] = ACTIONS(5412),
    [anon_sym_CARET] = ACTIONS(5412),
    [anon_sym_PIPE] = ACTIONS(5414),
    [anon_sym_AMP] = ACTIONS(5414),
    [anon_sym_LT_LT] = ACTIONS(5412),
    [anon_sym_GT_GT] = ACTIONS(5414),
    [anon_sym_GT_GT_GT] = ACTIONS(5412),
    [anon_sym_EQ_EQ] = ACTIONS(5412),
    [anon_sym_BANG_EQ] = ACTIONS(5412),
    [anon_sym_GT_EQ] = ACTIONS(5412),
    [anon_sym_LT_EQ] = ACTIONS(5412),
    [anon_sym_DOT] = ACTIONS(5414),
    [anon_sym_EQ_GT] = ACTIONS(5412),
    [anon_sym_switch] = ACTIONS(5412),
    [anon_sym_when] = ACTIONS(5412),
    [anon_sym_DOT_DOT] = ACTIONS(5412),
    [anon_sym_and] = ACTIONS(5412),
    [anon_sym_or] = ACTIONS(5412),
    [anon_sym_AMP_AMP] = ACTIONS(5412),
    [anon_sym_PIPE_PIPE] = ACTIONS(5412),
    [anon_sym_QMARK_QMARK] = ACTIONS(5412),
    [anon_sym_into] = ACTIONS(5412),
    [anon_sym_on] = ACTIONS(5412),
    [anon_sym_equals] = ACTIONS(5412),
    [anon_sym_by] = ACTIONS(5412),
    [anon_sym_as] = ACTIONS(5412),
    [anon_sym_is] = ACTIONS(5412),
    [anon_sym_DASH_GT] = ACTIONS(5412),
    [anon_sym_with] = ACTIONS(5412),
    [aux_sym_preproc_if_token3] = ACTIONS(5412),
    [aux_sym_preproc_else_token1] = ACTIONS(5412),
    [aux_sym_preproc_elif_token1] = ACTIONS(5412),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4078] = {
    [sym_preproc_region] = STATE(4078),
    [sym_preproc_endregion] = STATE(4078),
    [sym_preproc_line] = STATE(4078),
    [sym_preproc_pragma] = STATE(4078),
    [sym_preproc_nullable] = STATE(4078),
    [sym_preproc_error] = STATE(4078),
    [sym_preproc_warning] = STATE(4078),
    [sym_preproc_define] = STATE(4078),
    [sym_preproc_undef] = STATE(4078),
    [anon_sym_SEMI] = ACTIONS(5592),
    [anon_sym_LBRACK] = ACTIONS(5592),
    [anon_sym_COLON] = ACTIONS(5592),
    [anon_sym_COMMA] = ACTIONS(5592),
    [anon_sym_RBRACK] = ACTIONS(5592),
    [anon_sym_LPAREN] = ACTIONS(5592),
    [anon_sym_RPAREN] = ACTIONS(5592),
    [anon_sym_RBRACE] = ACTIONS(5592),
    [anon_sym_LT] = ACTIONS(5594),
    [anon_sym_GT] = ACTIONS(5594),
    [anon_sym_in] = ACTIONS(5594),
    [anon_sym_QMARK] = ACTIONS(5594),
    [anon_sym_BANG] = ACTIONS(5594),
    [anon_sym_PLUS_PLUS] = ACTIONS(5592),
    [anon_sym_DASH_DASH] = ACTIONS(5592),
    [anon_sym_PLUS] = ACTIONS(5594),
    [anon_sym_DASH] = ACTIONS(5594),
    [anon_sym_STAR] = ACTIONS(5592),
    [anon_sym_SLASH] = ACTIONS(5594),
    [anon_sym_PERCENT] = ACTIONS(5592),
    [anon_sym_CARET] = ACTIONS(5592),
    [anon_sym_PIPE] = ACTIONS(5594),
    [anon_sym_AMP] = ACTIONS(5594),
    [anon_sym_LT_LT] = ACTIONS(5592),
    [anon_sym_GT_GT] = ACTIONS(5594),
    [anon_sym_GT_GT_GT] = ACTIONS(5592),
    [anon_sym_EQ_EQ] = ACTIONS(5592),
    [anon_sym_BANG_EQ] = ACTIONS(5592),
    [anon_sym_GT_EQ] = ACTIONS(5592),
    [anon_sym_LT_EQ] = ACTIONS(5592),
    [anon_sym_DOT] = ACTIONS(5594),
    [anon_sym_EQ_GT] = ACTIONS(5592),
    [anon_sym_switch] = ACTIONS(5592),
    [anon_sym_when] = ACTIONS(5592),
    [anon_sym_DOT_DOT] = ACTIONS(5592),
    [anon_sym_and] = ACTIONS(5592),
    [anon_sym_or] = ACTIONS(5592),
    [anon_sym_AMP_AMP] = ACTIONS(5592),
    [anon_sym_PIPE_PIPE] = ACTIONS(5592),
    [anon_sym_QMARK_QMARK] = ACTIONS(5592),
    [anon_sym_into] = ACTIONS(5592),
    [anon_sym_on] = ACTIONS(5592),
    [anon_sym_equals] = ACTIONS(5592),
    [anon_sym_by] = ACTIONS(5592),
    [anon_sym_as] = ACTIONS(5592),
    [anon_sym_is] = ACTIONS(5592),
    [anon_sym_DASH_GT] = ACTIONS(5592),
    [anon_sym_with] = ACTIONS(5592),
    [aux_sym_preproc_if_token3] = ACTIONS(5592),
    [aux_sym_preproc_else_token1] = ACTIONS(5592),
    [aux_sym_preproc_elif_token1] = ACTIONS(5592),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4079] = {
    [sym_preproc_region] = STATE(4079),
    [sym_preproc_endregion] = STATE(4079),
    [sym_preproc_line] = STATE(4079),
    [sym_preproc_pragma] = STATE(4079),
    [sym_preproc_nullable] = STATE(4079),
    [sym_preproc_error] = STATE(4079),
    [sym_preproc_warning] = STATE(4079),
    [sym_preproc_define] = STATE(4079),
    [sym_preproc_undef] = STATE(4079),
    [anon_sym_SEMI] = ACTIONS(5388),
    [anon_sym_LBRACK] = ACTIONS(5388),
    [anon_sym_COLON] = ACTIONS(5388),
    [anon_sym_COMMA] = ACTIONS(5388),
    [anon_sym_RBRACK] = ACTIONS(5388),
    [anon_sym_LPAREN] = ACTIONS(5388),
    [anon_sym_RPAREN] = ACTIONS(5388),
    [anon_sym_RBRACE] = ACTIONS(5388),
    [anon_sym_LT] = ACTIONS(5390),
    [anon_sym_GT] = ACTIONS(5390),
    [anon_sym_in] = ACTIONS(5388),
    [anon_sym_QMARK] = ACTIONS(5390),
    [anon_sym_BANG] = ACTIONS(5390),
    [anon_sym_PLUS_PLUS] = ACTIONS(5388),
    [anon_sym_DASH_DASH] = ACTIONS(5388),
    [anon_sym_PLUS] = ACTIONS(5390),
    [anon_sym_DASH] = ACTIONS(5390),
    [anon_sym_STAR] = ACTIONS(5388),
    [anon_sym_SLASH] = ACTIONS(5390),
    [anon_sym_PERCENT] = ACTIONS(5388),
    [anon_sym_CARET] = ACTIONS(5388),
    [anon_sym_PIPE] = ACTIONS(5390),
    [anon_sym_AMP] = ACTIONS(5390),
    [anon_sym_LT_LT] = ACTIONS(5388),
    [anon_sym_GT_GT] = ACTIONS(5390),
    [anon_sym_GT_GT_GT] = ACTIONS(5388),
    [anon_sym_EQ_EQ] = ACTIONS(5388),
    [anon_sym_BANG_EQ] = ACTIONS(5388),
    [anon_sym_GT_EQ] = ACTIONS(5388),
    [anon_sym_LT_EQ] = ACTIONS(5388),
    [anon_sym_DOT] = ACTIONS(5390),
    [anon_sym_EQ_GT] = ACTIONS(5388),
    [anon_sym_switch] = ACTIONS(5388),
    [anon_sym_when] = ACTIONS(5388),
    [anon_sym_DOT_DOT] = ACTIONS(5388),
    [anon_sym_and] = ACTIONS(5388),
    [anon_sym_or] = ACTIONS(5388),
    [anon_sym_AMP_AMP] = ACTIONS(5388),
    [anon_sym_PIPE_PIPE] = ACTIONS(5388),
    [anon_sym_QMARK_QMARK] = ACTIONS(5388),
    [anon_sym_on] = ACTIONS(5388),
    [anon_sym_equals] = ACTIONS(5388),
    [anon_sym_by] = ACTIONS(5388),
    [anon_sym_as] = ACTIONS(5388),
    [anon_sym_is] = ACTIONS(5388),
    [anon_sym_DASH_GT] = ACTIONS(5388),
    [anon_sym_with] = ACTIONS(5388),
    [aux_sym_raw_string_literal_token1] = ACTIONS(5954),
    [aux_sym_preproc_if_token3] = ACTIONS(5388),
    [aux_sym_preproc_else_token1] = ACTIONS(5388),
    [aux_sym_preproc_elif_token1] = ACTIONS(5388),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4080] = {
    [sym_preproc_region] = STATE(4080),
    [sym_preproc_endregion] = STATE(4080),
    [sym_preproc_line] = STATE(4080),
    [sym_preproc_pragma] = STATE(4080),
    [sym_preproc_nullable] = STATE(4080),
    [sym_preproc_error] = STATE(4080),
    [sym_preproc_warning] = STATE(4080),
    [sym_preproc_define] = STATE(4080),
    [sym_preproc_undef] = STATE(4080),
    [anon_sym_SEMI] = ACTIONS(5636),
    [anon_sym_LBRACK] = ACTIONS(5636),
    [anon_sym_COLON] = ACTIONS(5636),
    [anon_sym_COMMA] = ACTIONS(5636),
    [anon_sym_RBRACK] = ACTIONS(5636),
    [anon_sym_LPAREN] = ACTIONS(5636),
    [anon_sym_RPAREN] = ACTIONS(5636),
    [anon_sym_RBRACE] = ACTIONS(5636),
    [anon_sym_LT] = ACTIONS(5638),
    [anon_sym_GT] = ACTIONS(5638),
    [anon_sym_in] = ACTIONS(5638),
    [anon_sym_QMARK] = ACTIONS(5638),
    [anon_sym_BANG] = ACTIONS(5638),
    [anon_sym_PLUS_PLUS] = ACTIONS(5636),
    [anon_sym_DASH_DASH] = ACTIONS(5636),
    [anon_sym_PLUS] = ACTIONS(5638),
    [anon_sym_DASH] = ACTIONS(5638),
    [anon_sym_STAR] = ACTIONS(5636),
    [anon_sym_SLASH] = ACTIONS(5638),
    [anon_sym_PERCENT] = ACTIONS(5636),
    [anon_sym_CARET] = ACTIONS(5636),
    [anon_sym_PIPE] = ACTIONS(5638),
    [anon_sym_AMP] = ACTIONS(5638),
    [anon_sym_LT_LT] = ACTIONS(5636),
    [anon_sym_GT_GT] = ACTIONS(5638),
    [anon_sym_GT_GT_GT] = ACTIONS(5636),
    [anon_sym_EQ_EQ] = ACTIONS(5636),
    [anon_sym_BANG_EQ] = ACTIONS(5636),
    [anon_sym_GT_EQ] = ACTIONS(5636),
    [anon_sym_LT_EQ] = ACTIONS(5636),
    [anon_sym_DOT] = ACTIONS(5638),
    [anon_sym_EQ_GT] = ACTIONS(5636),
    [anon_sym_switch] = ACTIONS(5636),
    [anon_sym_when] = ACTIONS(5636),
    [anon_sym_DOT_DOT] = ACTIONS(5636),
    [anon_sym_and] = ACTIONS(5636),
    [anon_sym_or] = ACTIONS(5636),
    [anon_sym_AMP_AMP] = ACTIONS(5636),
    [anon_sym_PIPE_PIPE] = ACTIONS(5636),
    [anon_sym_QMARK_QMARK] = ACTIONS(5636),
    [anon_sym_into] = ACTIONS(5636),
    [anon_sym_on] = ACTIONS(5636),
    [anon_sym_equals] = ACTIONS(5636),
    [anon_sym_by] = ACTIONS(5636),
    [anon_sym_as] = ACTIONS(5636),
    [anon_sym_is] = ACTIONS(5636),
    [anon_sym_DASH_GT] = ACTIONS(5636),
    [anon_sym_with] = ACTIONS(5636),
    [aux_sym_preproc_if_token3] = ACTIONS(5636),
    [aux_sym_preproc_else_token1] = ACTIONS(5636),
    [aux_sym_preproc_elif_token1] = ACTIONS(5636),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4081] = {
    [sym_preproc_region] = STATE(4081),
    [sym_preproc_endregion] = STATE(4081),
    [sym_preproc_line] = STATE(4081),
    [sym_preproc_pragma] = STATE(4081),
    [sym_preproc_nullable] = STATE(4081),
    [sym_preproc_error] = STATE(4081),
    [sym_preproc_warning] = STATE(4081),
    [sym_preproc_define] = STATE(4081),
    [sym_preproc_undef] = STATE(4081),
    [anon_sym_SEMI] = ACTIONS(5648),
    [anon_sym_LBRACK] = ACTIONS(5648),
    [anon_sym_COLON] = ACTIONS(5648),
    [anon_sym_COMMA] = ACTIONS(5648),
    [anon_sym_RBRACK] = ACTIONS(5648),
    [anon_sym_LPAREN] = ACTIONS(5648),
    [anon_sym_RPAREN] = ACTIONS(5648),
    [anon_sym_RBRACE] = ACTIONS(5648),
    [anon_sym_LT] = ACTIONS(5650),
    [anon_sym_GT] = ACTIONS(5650),
    [anon_sym_in] = ACTIONS(5650),
    [anon_sym_QMARK] = ACTIONS(5650),
    [anon_sym_BANG] = ACTIONS(5650),
    [anon_sym_PLUS_PLUS] = ACTIONS(5648),
    [anon_sym_DASH_DASH] = ACTIONS(5648),
    [anon_sym_PLUS] = ACTIONS(5650),
    [anon_sym_DASH] = ACTIONS(5650),
    [anon_sym_STAR] = ACTIONS(5648),
    [anon_sym_SLASH] = ACTIONS(5650),
    [anon_sym_PERCENT] = ACTIONS(5648),
    [anon_sym_CARET] = ACTIONS(5648),
    [anon_sym_PIPE] = ACTIONS(5650),
    [anon_sym_AMP] = ACTIONS(5650),
    [anon_sym_LT_LT] = ACTIONS(5648),
    [anon_sym_GT_GT] = ACTIONS(5650),
    [anon_sym_GT_GT_GT] = ACTIONS(5648),
    [anon_sym_EQ_EQ] = ACTIONS(5648),
    [anon_sym_BANG_EQ] = ACTIONS(5648),
    [anon_sym_GT_EQ] = ACTIONS(5648),
    [anon_sym_LT_EQ] = ACTIONS(5648),
    [anon_sym_DOT] = ACTIONS(5650),
    [anon_sym_EQ_GT] = ACTIONS(5648),
    [anon_sym_switch] = ACTIONS(5648),
    [anon_sym_when] = ACTIONS(5648),
    [anon_sym_DOT_DOT] = ACTIONS(5648),
    [anon_sym_and] = ACTIONS(5648),
    [anon_sym_or] = ACTIONS(5648),
    [anon_sym_AMP_AMP] = ACTIONS(5648),
    [anon_sym_PIPE_PIPE] = ACTIONS(5648),
    [anon_sym_QMARK_QMARK] = ACTIONS(5648),
    [anon_sym_into] = ACTIONS(5648),
    [anon_sym_on] = ACTIONS(5648),
    [anon_sym_equals] = ACTIONS(5648),
    [anon_sym_by] = ACTIONS(5648),
    [anon_sym_as] = ACTIONS(5648),
    [anon_sym_is] = ACTIONS(5648),
    [anon_sym_DASH_GT] = ACTIONS(5648),
    [anon_sym_with] = ACTIONS(5648),
    [aux_sym_preproc_if_token3] = ACTIONS(5648),
    [aux_sym_preproc_else_token1] = ACTIONS(5648),
    [aux_sym_preproc_elif_token1] = ACTIONS(5648),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4082] = {
    [sym_preproc_region] = STATE(4082),
    [sym_preproc_endregion] = STATE(4082),
    [sym_preproc_line] = STATE(4082),
    [sym_preproc_pragma] = STATE(4082),
    [sym_preproc_nullable] = STATE(4082),
    [sym_preproc_error] = STATE(4082),
    [sym_preproc_warning] = STATE(4082),
    [sym_preproc_define] = STATE(4082),
    [sym_preproc_undef] = STATE(4082),
    [anon_sym_SEMI] = ACTIONS(5956),
    [anon_sym_LBRACK] = ACTIONS(5956),
    [anon_sym_COLON] = ACTIONS(5956),
    [anon_sym_COMMA] = ACTIONS(5956),
    [anon_sym_RBRACK] = ACTIONS(5956),
    [anon_sym_LPAREN] = ACTIONS(5956),
    [anon_sym_RPAREN] = ACTIONS(5956),
    [anon_sym_RBRACE] = ACTIONS(5956),
    [anon_sym_LT] = ACTIONS(5958),
    [anon_sym_GT] = ACTIONS(5958),
    [anon_sym_in] = ACTIONS(5958),
    [anon_sym_QMARK] = ACTIONS(5958),
    [anon_sym_BANG] = ACTIONS(5958),
    [anon_sym_PLUS_PLUS] = ACTIONS(5956),
    [anon_sym_DASH_DASH] = ACTIONS(5956),
    [anon_sym_PLUS] = ACTIONS(5958),
    [anon_sym_DASH] = ACTIONS(5958),
    [anon_sym_STAR] = ACTIONS(5956),
    [anon_sym_SLASH] = ACTIONS(5958),
    [anon_sym_PERCENT] = ACTIONS(5956),
    [anon_sym_CARET] = ACTIONS(5956),
    [anon_sym_PIPE] = ACTIONS(5958),
    [anon_sym_AMP] = ACTIONS(5958),
    [anon_sym_LT_LT] = ACTIONS(5956),
    [anon_sym_GT_GT] = ACTIONS(5958),
    [anon_sym_GT_GT_GT] = ACTIONS(5956),
    [anon_sym_EQ_EQ] = ACTIONS(5956),
    [anon_sym_BANG_EQ] = ACTIONS(5956),
    [anon_sym_GT_EQ] = ACTIONS(5956),
    [anon_sym_LT_EQ] = ACTIONS(5956),
    [anon_sym_DOT] = ACTIONS(5958),
    [anon_sym_EQ_GT] = ACTIONS(5956),
    [anon_sym_switch] = ACTIONS(5956),
    [anon_sym_when] = ACTIONS(5956),
    [anon_sym_DOT_DOT] = ACTIONS(5956),
    [anon_sym_and] = ACTIONS(5956),
    [anon_sym_or] = ACTIONS(5956),
    [anon_sym_AMP_AMP] = ACTIONS(5956),
    [anon_sym_PIPE_PIPE] = ACTIONS(5956),
    [anon_sym_QMARK_QMARK] = ACTIONS(5956),
    [anon_sym_into] = ACTIONS(5956),
    [anon_sym_on] = ACTIONS(5956),
    [anon_sym_equals] = ACTIONS(5956),
    [anon_sym_by] = ACTIONS(5956),
    [anon_sym_as] = ACTIONS(5956),
    [anon_sym_is] = ACTIONS(5956),
    [anon_sym_DASH_GT] = ACTIONS(5956),
    [anon_sym_with] = ACTIONS(5956),
    [aux_sym_preproc_if_token3] = ACTIONS(5956),
    [aux_sym_preproc_else_token1] = ACTIONS(5956),
    [aux_sym_preproc_elif_token1] = ACTIONS(5956),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4083] = {
    [sym_preproc_region] = STATE(4083),
    [sym_preproc_endregion] = STATE(4083),
    [sym_preproc_line] = STATE(4083),
    [sym_preproc_pragma] = STATE(4083),
    [sym_preproc_nullable] = STATE(4083),
    [sym_preproc_error] = STATE(4083),
    [sym_preproc_warning] = STATE(4083),
    [sym_preproc_define] = STATE(4083),
    [sym_preproc_undef] = STATE(4083),
    [anon_sym_SEMI] = ACTIONS(5960),
    [anon_sym_LBRACK] = ACTIONS(5960),
    [anon_sym_COLON] = ACTIONS(5960),
    [anon_sym_COMMA] = ACTIONS(5960),
    [anon_sym_RBRACK] = ACTIONS(5960),
    [anon_sym_LPAREN] = ACTIONS(5960),
    [anon_sym_RPAREN] = ACTIONS(5960),
    [anon_sym_RBRACE] = ACTIONS(5960),
    [anon_sym_LT] = ACTIONS(5962),
    [anon_sym_GT] = ACTIONS(5962),
    [anon_sym_in] = ACTIONS(5962),
    [anon_sym_QMARK] = ACTIONS(5962),
    [anon_sym_BANG] = ACTIONS(5962),
    [anon_sym_PLUS_PLUS] = ACTIONS(5960),
    [anon_sym_DASH_DASH] = ACTIONS(5960),
    [anon_sym_PLUS] = ACTIONS(5962),
    [anon_sym_DASH] = ACTIONS(5962),
    [anon_sym_STAR] = ACTIONS(5960),
    [anon_sym_SLASH] = ACTIONS(5962),
    [anon_sym_PERCENT] = ACTIONS(5960),
    [anon_sym_CARET] = ACTIONS(5960),
    [anon_sym_PIPE] = ACTIONS(5962),
    [anon_sym_AMP] = ACTIONS(5962),
    [anon_sym_LT_LT] = ACTIONS(5960),
    [anon_sym_GT_GT] = ACTIONS(5962),
    [anon_sym_GT_GT_GT] = ACTIONS(5960),
    [anon_sym_EQ_EQ] = ACTIONS(5960),
    [anon_sym_BANG_EQ] = ACTIONS(5960),
    [anon_sym_GT_EQ] = ACTIONS(5960),
    [anon_sym_LT_EQ] = ACTIONS(5960),
    [anon_sym_DOT] = ACTIONS(5962),
    [anon_sym_EQ_GT] = ACTIONS(5960),
    [anon_sym_switch] = ACTIONS(5960),
    [anon_sym_when] = ACTIONS(5960),
    [anon_sym_DOT_DOT] = ACTIONS(5960),
    [anon_sym_and] = ACTIONS(5960),
    [anon_sym_or] = ACTIONS(5960),
    [anon_sym_AMP_AMP] = ACTIONS(5960),
    [anon_sym_PIPE_PIPE] = ACTIONS(5960),
    [anon_sym_QMARK_QMARK] = ACTIONS(5960),
    [anon_sym_into] = ACTIONS(5960),
    [anon_sym_on] = ACTIONS(5960),
    [anon_sym_equals] = ACTIONS(5960),
    [anon_sym_by] = ACTIONS(5960),
    [anon_sym_as] = ACTIONS(5960),
    [anon_sym_is] = ACTIONS(5960),
    [anon_sym_DASH_GT] = ACTIONS(5960),
    [anon_sym_with] = ACTIONS(5960),
    [aux_sym_preproc_if_token3] = ACTIONS(5960),
    [aux_sym_preproc_else_token1] = ACTIONS(5960),
    [aux_sym_preproc_elif_token1] = ACTIONS(5960),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4084] = {
    [sym_preproc_region] = STATE(4084),
    [sym_preproc_endregion] = STATE(4084),
    [sym_preproc_line] = STATE(4084),
    [sym_preproc_pragma] = STATE(4084),
    [sym_preproc_nullable] = STATE(4084),
    [sym_preproc_error] = STATE(4084),
    [sym_preproc_warning] = STATE(4084),
    [sym_preproc_define] = STATE(4084),
    [sym_preproc_undef] = STATE(4084),
    [anon_sym_SEMI] = ACTIONS(5552),
    [anon_sym_LBRACK] = ACTIONS(5552),
    [anon_sym_COLON] = ACTIONS(5552),
    [anon_sym_COMMA] = ACTIONS(5552),
    [anon_sym_RBRACK] = ACTIONS(5552),
    [anon_sym_LPAREN] = ACTIONS(5552),
    [anon_sym_RPAREN] = ACTIONS(5552),
    [anon_sym_RBRACE] = ACTIONS(5552),
    [anon_sym_LT] = ACTIONS(5554),
    [anon_sym_GT] = ACTIONS(5554),
    [anon_sym_in] = ACTIONS(5554),
    [anon_sym_QMARK] = ACTIONS(5554),
    [anon_sym_BANG] = ACTIONS(5554),
    [anon_sym_PLUS_PLUS] = ACTIONS(5552),
    [anon_sym_DASH_DASH] = ACTIONS(5552),
    [anon_sym_PLUS] = ACTIONS(5554),
    [anon_sym_DASH] = ACTIONS(5554),
    [anon_sym_STAR] = ACTIONS(5552),
    [anon_sym_SLASH] = ACTIONS(5554),
    [anon_sym_PERCENT] = ACTIONS(5552),
    [anon_sym_CARET] = ACTIONS(5552),
    [anon_sym_PIPE] = ACTIONS(5554),
    [anon_sym_AMP] = ACTIONS(5554),
    [anon_sym_LT_LT] = ACTIONS(5552),
    [anon_sym_GT_GT] = ACTIONS(5554),
    [anon_sym_GT_GT_GT] = ACTIONS(5552),
    [anon_sym_EQ_EQ] = ACTIONS(5552),
    [anon_sym_BANG_EQ] = ACTIONS(5552),
    [anon_sym_GT_EQ] = ACTIONS(5552),
    [anon_sym_LT_EQ] = ACTIONS(5552),
    [anon_sym_DOT] = ACTIONS(5554),
    [anon_sym_EQ_GT] = ACTIONS(5552),
    [anon_sym_switch] = ACTIONS(5552),
    [anon_sym_when] = ACTIONS(5552),
    [anon_sym_DOT_DOT] = ACTIONS(5552),
    [anon_sym_and] = ACTIONS(5552),
    [anon_sym_or] = ACTIONS(5552),
    [anon_sym_AMP_AMP] = ACTIONS(5552),
    [anon_sym_PIPE_PIPE] = ACTIONS(5552),
    [anon_sym_QMARK_QMARK] = ACTIONS(5552),
    [anon_sym_into] = ACTIONS(5552),
    [anon_sym_on] = ACTIONS(5552),
    [anon_sym_equals] = ACTIONS(5552),
    [anon_sym_by] = ACTIONS(5552),
    [anon_sym_as] = ACTIONS(5552),
    [anon_sym_is] = ACTIONS(5552),
    [anon_sym_DASH_GT] = ACTIONS(5552),
    [anon_sym_with] = ACTIONS(5552),
    [aux_sym_preproc_if_token3] = ACTIONS(5552),
    [aux_sym_preproc_else_token1] = ACTIONS(5552),
    [aux_sym_preproc_elif_token1] = ACTIONS(5552),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4085] = {
    [sym_preproc_region] = STATE(4085),
    [sym_preproc_endregion] = STATE(4085),
    [sym_preproc_line] = STATE(4085),
    [sym_preproc_pragma] = STATE(4085),
    [sym_preproc_nullable] = STATE(4085),
    [sym_preproc_error] = STATE(4085),
    [sym_preproc_warning] = STATE(4085),
    [sym_preproc_define] = STATE(4085),
    [sym_preproc_undef] = STATE(4085),
    [anon_sym_SEMI] = ACTIONS(4168),
    [anon_sym_LBRACK] = ACTIONS(4168),
    [anon_sym_COLON] = ACTIONS(4168),
    [anon_sym_COMMA] = ACTIONS(4168),
    [anon_sym_RBRACK] = ACTIONS(4168),
    [anon_sym_LPAREN] = ACTIONS(4168),
    [anon_sym_RPAREN] = ACTIONS(4168),
    [anon_sym_LBRACE] = ACTIONS(4168),
    [anon_sym_RBRACE] = ACTIONS(4168),
    [anon_sym_LT] = ACTIONS(4157),
    [anon_sym_GT] = ACTIONS(4157),
    [anon_sym_in] = ACTIONS(4168),
    [anon_sym_QMARK] = ACTIONS(4157),
    [anon_sym_BANG] = ACTIONS(4157),
    [anon_sym_PLUS_PLUS] = ACTIONS(4168),
    [anon_sym_DASH_DASH] = ACTIONS(4168),
    [anon_sym_PLUS] = ACTIONS(4157),
    [anon_sym_DASH] = ACTIONS(4157),
    [anon_sym_STAR] = ACTIONS(4168),
    [anon_sym_SLASH] = ACTIONS(4157),
    [anon_sym_PERCENT] = ACTIONS(4168),
    [anon_sym_CARET] = ACTIONS(4168),
    [anon_sym_PIPE] = ACTIONS(4157),
    [anon_sym_AMP] = ACTIONS(4157),
    [anon_sym_LT_LT] = ACTIONS(4168),
    [anon_sym_GT_GT] = ACTIONS(4157),
    [anon_sym_GT_GT_GT] = ACTIONS(4168),
    [anon_sym_EQ_EQ] = ACTIONS(4168),
    [anon_sym_BANG_EQ] = ACTIONS(4168),
    [anon_sym_GT_EQ] = ACTIONS(4168),
    [anon_sym_LT_EQ] = ACTIONS(4168),
    [anon_sym_DOT] = ACTIONS(4157),
    [anon_sym_EQ_GT] = ACTIONS(4168),
    [anon_sym_switch] = ACTIONS(4168),
    [anon_sym_when] = ACTIONS(4168),
    [anon_sym_DOT_DOT] = ACTIONS(4168),
    [anon_sym_and] = ACTIONS(4168),
    [anon_sym_or] = ACTIONS(4168),
    [anon_sym_AMP_AMP] = ACTIONS(4168),
    [anon_sym_PIPE_PIPE] = ACTIONS(4168),
    [anon_sym_QMARK_QMARK] = ACTIONS(4168),
    [anon_sym_on] = ACTIONS(4168),
    [anon_sym_equals] = ACTIONS(4168),
    [anon_sym_by] = ACTIONS(4168),
    [anon_sym_as] = ACTIONS(4168),
    [anon_sym_is] = ACTIONS(4168),
    [anon_sym_DASH_GT] = ACTIONS(4168),
    [anon_sym_with] = ACTIONS(4168),
    [aux_sym_preproc_if_token3] = ACTIONS(4168),
    [aux_sym_preproc_else_token1] = ACTIONS(4168),
    [aux_sym_preproc_elif_token1] = ACTIONS(4168),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4086] = {
    [sym_preproc_region] = STATE(4086),
    [sym_preproc_endregion] = STATE(4086),
    [sym_preproc_line] = STATE(4086),
    [sym_preproc_pragma] = STATE(4086),
    [sym_preproc_nullable] = STATE(4086),
    [sym_preproc_error] = STATE(4086),
    [sym_preproc_warning] = STATE(4086),
    [sym_preproc_define] = STATE(4086),
    [sym_preproc_undef] = STATE(4086),
    [anon_sym_SEMI] = ACTIONS(5964),
    [anon_sym_LBRACK] = ACTIONS(5964),
    [anon_sym_COLON] = ACTIONS(5964),
    [anon_sym_COMMA] = ACTIONS(5964),
    [anon_sym_RBRACK] = ACTIONS(5964),
    [anon_sym_LPAREN] = ACTIONS(5964),
    [anon_sym_RPAREN] = ACTIONS(5964),
    [anon_sym_RBRACE] = ACTIONS(5964),
    [anon_sym_LT] = ACTIONS(5966),
    [anon_sym_GT] = ACTIONS(5966),
    [anon_sym_in] = ACTIONS(5966),
    [anon_sym_QMARK] = ACTIONS(5966),
    [anon_sym_BANG] = ACTIONS(5966),
    [anon_sym_PLUS_PLUS] = ACTIONS(5964),
    [anon_sym_DASH_DASH] = ACTIONS(5964),
    [anon_sym_PLUS] = ACTIONS(5966),
    [anon_sym_DASH] = ACTIONS(5966),
    [anon_sym_STAR] = ACTIONS(5964),
    [anon_sym_SLASH] = ACTIONS(5966),
    [anon_sym_PERCENT] = ACTIONS(5964),
    [anon_sym_CARET] = ACTIONS(5964),
    [anon_sym_PIPE] = ACTIONS(5966),
    [anon_sym_AMP] = ACTIONS(5966),
    [anon_sym_LT_LT] = ACTIONS(5964),
    [anon_sym_GT_GT] = ACTIONS(5966),
    [anon_sym_GT_GT_GT] = ACTIONS(5964),
    [anon_sym_EQ_EQ] = ACTIONS(5964),
    [anon_sym_BANG_EQ] = ACTIONS(5964),
    [anon_sym_GT_EQ] = ACTIONS(5964),
    [anon_sym_LT_EQ] = ACTIONS(5964),
    [anon_sym_DOT] = ACTIONS(5966),
    [anon_sym_EQ_GT] = ACTIONS(5964),
    [anon_sym_switch] = ACTIONS(5964),
    [anon_sym_when] = ACTIONS(5964),
    [anon_sym_DOT_DOT] = ACTIONS(5964),
    [anon_sym_and] = ACTIONS(5964),
    [anon_sym_or] = ACTIONS(5964),
    [anon_sym_AMP_AMP] = ACTIONS(5964),
    [anon_sym_PIPE_PIPE] = ACTIONS(5964),
    [anon_sym_QMARK_QMARK] = ACTIONS(5964),
    [anon_sym_into] = ACTIONS(5964),
    [anon_sym_on] = ACTIONS(5964),
    [anon_sym_equals] = ACTIONS(5964),
    [anon_sym_by] = ACTIONS(5964),
    [anon_sym_as] = ACTIONS(5964),
    [anon_sym_is] = ACTIONS(5964),
    [anon_sym_DASH_GT] = ACTIONS(5964),
    [anon_sym_with] = ACTIONS(5964),
    [aux_sym_preproc_if_token3] = ACTIONS(5964),
    [aux_sym_preproc_else_token1] = ACTIONS(5964),
    [aux_sym_preproc_elif_token1] = ACTIONS(5964),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4087] = {
    [sym_modifier] = STATE(4497),
    [sym_identifier] = STATE(7904),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_region] = STATE(4087),
    [sym_preproc_endregion] = STATE(4087),
    [sym_preproc_line] = STATE(4087),
    [sym_preproc_pragma] = STATE(4087),
    [sym_preproc_nullable] = STATE(4087),
    [sym_preproc_error] = STATE(4087),
    [sym_preproc_warning] = STATE(4087),
    [sym_preproc_define] = STATE(4087),
    [sym_preproc_undef] = STATE(4087),
    [aux_sym_class_declaration_repeat2] = STATE(4351),
    [sym__identifier_token] = ACTIONS(25),
    [anon_sym_extern] = ACTIONS(5456),
    [anon_sym_alias] = ACTIONS(29),
    [anon_sym_global] = ACTIONS(29),
    [anon_sym_unsafe] = ACTIONS(5456),
    [anon_sym_static] = ACTIONS(5456),
    [anon_sym_abstract] = ACTIONS(5456),
    [anon_sym_async] = ACTIONS(5456),
    [anon_sym_const] = ACTIONS(5456),
    [anon_sym_file] = ACTIONS(5462),
    [anon_sym_fixed] = ACTIONS(5456),
    [anon_sym_internal] = ACTIONS(5456),
    [anon_sym_new] = ACTIONS(5456),
    [anon_sym_override] = ACTIONS(5456),
    [anon_sym_partial] = ACTIONS(5456),
    [anon_sym_private] = ACTIONS(5456),
    [anon_sym_protected] = ACTIONS(5456),
    [anon_sym_public] = ACTIONS(5456),
    [anon_sym_readonly] = ACTIONS(5456),
    [anon_sym_required] = ACTIONS(5456),
    [anon_sym_sealed] = ACTIONS(5456),
    [anon_sym_virtual] = ACTIONS(5456),
    [anon_sym_volatile] = ACTIONS(5456),
    [anon_sym_where] = ACTIONS(29),
    [anon_sym_notnull] = ACTIONS(29),
    [anon_sym_unmanaged] = ACTIONS(29),
    [anon_sym_get] = ACTIONS(5968),
    [anon_sym_set] = ACTIONS(5968),
    [anon_sym_add] = ACTIONS(5968),
    [anon_sym_remove] = ACTIONS(5968),
    [anon_sym_init] = ACTIONS(5968),
    [anon_sym_scoped] = ACTIONS(29),
    [anon_sym_var] = ACTIONS(29),
    [anon_sym_yield] = ACTIONS(29),
    [anon_sym_when] = ACTIONS(29),
    [anon_sym_from] = ACTIONS(29),
    [anon_sym_into] = ACTIONS(29),
    [anon_sym_join] = ACTIONS(29),
    [anon_sym_on] = ACTIONS(29),
    [anon_sym_equals] = ACTIONS(29),
    [anon_sym_let] = ACTIONS(29),
    [anon_sym_orderby] = ACTIONS(29),
    [anon_sym_ascending] = ACTIONS(29),
    [anon_sym_descending] = ACTIONS(29),
    [anon_sym_group] = ACTIONS(29),
    [anon_sym_by] = ACTIONS(29),
    [anon_sym_select] = ACTIONS(29),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4088] = {
    [sym_preproc_region] = STATE(4088),
    [sym_preproc_endregion] = STATE(4088),
    [sym_preproc_line] = STATE(4088),
    [sym_preproc_pragma] = STATE(4088),
    [sym_preproc_nullable] = STATE(4088),
    [sym_preproc_error] = STATE(4088),
    [sym_preproc_warning] = STATE(4088),
    [sym_preproc_define] = STATE(4088),
    [sym_preproc_undef] = STATE(4088),
    [anon_sym_SEMI] = ACTIONS(5928),
    [anon_sym_LBRACK] = ACTIONS(5928),
    [anon_sym_COLON] = ACTIONS(5928),
    [anon_sym_COMMA] = ACTIONS(5928),
    [anon_sym_RBRACK] = ACTIONS(5928),
    [anon_sym_LPAREN] = ACTIONS(5928),
    [anon_sym_RPAREN] = ACTIONS(5928),
    [anon_sym_RBRACE] = ACTIONS(5928),
    [anon_sym_LT] = ACTIONS(5930),
    [anon_sym_GT] = ACTIONS(5930),
    [anon_sym_in] = ACTIONS(5930),
    [anon_sym_QMARK] = ACTIONS(5930),
    [anon_sym_BANG] = ACTIONS(5930),
    [anon_sym_PLUS_PLUS] = ACTIONS(5928),
    [anon_sym_DASH_DASH] = ACTIONS(5928),
    [anon_sym_PLUS] = ACTIONS(5930),
    [anon_sym_DASH] = ACTIONS(5930),
    [anon_sym_STAR] = ACTIONS(5928),
    [anon_sym_SLASH] = ACTIONS(5930),
    [anon_sym_PERCENT] = ACTIONS(5928),
    [anon_sym_CARET] = ACTIONS(5928),
    [anon_sym_PIPE] = ACTIONS(5930),
    [anon_sym_AMP] = ACTIONS(5930),
    [anon_sym_LT_LT] = ACTIONS(5928),
    [anon_sym_GT_GT] = ACTIONS(5930),
    [anon_sym_GT_GT_GT] = ACTIONS(5928),
    [anon_sym_EQ_EQ] = ACTIONS(5928),
    [anon_sym_BANG_EQ] = ACTIONS(5928),
    [anon_sym_GT_EQ] = ACTIONS(5928),
    [anon_sym_LT_EQ] = ACTIONS(5928),
    [anon_sym_DOT] = ACTIONS(5930),
    [anon_sym_EQ_GT] = ACTIONS(5928),
    [anon_sym_switch] = ACTIONS(5928),
    [anon_sym_when] = ACTIONS(5928),
    [anon_sym_DOT_DOT] = ACTIONS(5928),
    [anon_sym_and] = ACTIONS(5928),
    [anon_sym_or] = ACTIONS(5928),
    [anon_sym_AMP_AMP] = ACTIONS(5928),
    [anon_sym_PIPE_PIPE] = ACTIONS(5928),
    [anon_sym_QMARK_QMARK] = ACTIONS(5928),
    [anon_sym_into] = ACTIONS(5928),
    [anon_sym_on] = ACTIONS(5928),
    [anon_sym_equals] = ACTIONS(5928),
    [anon_sym_by] = ACTIONS(5928),
    [anon_sym_as] = ACTIONS(5928),
    [anon_sym_is] = ACTIONS(5928),
    [anon_sym_DASH_GT] = ACTIONS(5928),
    [anon_sym_with] = ACTIONS(5928),
    [aux_sym_preproc_if_token3] = ACTIONS(5928),
    [aux_sym_preproc_else_token1] = ACTIONS(5928),
    [aux_sym_preproc_elif_token1] = ACTIONS(5928),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4089] = {
    [sym_preproc_region] = STATE(4089),
    [sym_preproc_endregion] = STATE(4089),
    [sym_preproc_line] = STATE(4089),
    [sym_preproc_pragma] = STATE(4089),
    [sym_preproc_nullable] = STATE(4089),
    [sym_preproc_error] = STATE(4089),
    [sym_preproc_warning] = STATE(4089),
    [sym_preproc_define] = STATE(4089),
    [sym_preproc_undef] = STATE(4089),
    [anon_sym_SEMI] = ACTIONS(3001),
    [anon_sym_LBRACK] = ACTIONS(3001),
    [anon_sym_COLON] = ACTIONS(3001),
    [anon_sym_COMMA] = ACTIONS(3001),
    [anon_sym_RBRACK] = ACTIONS(3001),
    [anon_sym_LPAREN] = ACTIONS(3001),
    [anon_sym_RPAREN] = ACTIONS(3001),
    [anon_sym_RBRACE] = ACTIONS(3001),
    [anon_sym_LT] = ACTIONS(2999),
    [anon_sym_GT] = ACTIONS(2999),
    [anon_sym_in] = ACTIONS(2999),
    [anon_sym_QMARK] = ACTIONS(2999),
    [anon_sym_BANG] = ACTIONS(2999),
    [anon_sym_PLUS_PLUS] = ACTIONS(3001),
    [anon_sym_DASH_DASH] = ACTIONS(3001),
    [anon_sym_PLUS] = ACTIONS(2999),
    [anon_sym_DASH] = ACTIONS(2999),
    [anon_sym_STAR] = ACTIONS(3001),
    [anon_sym_SLASH] = ACTIONS(2999),
    [anon_sym_PERCENT] = ACTIONS(3001),
    [anon_sym_CARET] = ACTIONS(3001),
    [anon_sym_PIPE] = ACTIONS(2999),
    [anon_sym_AMP] = ACTIONS(2999),
    [anon_sym_LT_LT] = ACTIONS(3001),
    [anon_sym_GT_GT] = ACTIONS(2999),
    [anon_sym_GT_GT_GT] = ACTIONS(3001),
    [anon_sym_EQ_EQ] = ACTIONS(3001),
    [anon_sym_BANG_EQ] = ACTIONS(3001),
    [anon_sym_GT_EQ] = ACTIONS(3001),
    [anon_sym_LT_EQ] = ACTIONS(3001),
    [anon_sym_DOT] = ACTIONS(2999),
    [anon_sym_EQ_GT] = ACTIONS(3001),
    [anon_sym_switch] = ACTIONS(3001),
    [anon_sym_when] = ACTIONS(3001),
    [anon_sym_DOT_DOT] = ACTIONS(3001),
    [anon_sym_and] = ACTIONS(3001),
    [anon_sym_or] = ACTIONS(3001),
    [anon_sym_AMP_AMP] = ACTIONS(3001),
    [anon_sym_PIPE_PIPE] = ACTIONS(3001),
    [anon_sym_QMARK_QMARK] = ACTIONS(3001),
    [anon_sym_into] = ACTIONS(3001),
    [anon_sym_on] = ACTIONS(3001),
    [anon_sym_equals] = ACTIONS(3001),
    [anon_sym_by] = ACTIONS(3001),
    [anon_sym_as] = ACTIONS(3001),
    [anon_sym_is] = ACTIONS(3001),
    [anon_sym_DASH_GT] = ACTIONS(3001),
    [anon_sym_with] = ACTIONS(3001),
    [aux_sym_preproc_if_token3] = ACTIONS(3001),
    [aux_sym_preproc_else_token1] = ACTIONS(3001),
    [aux_sym_preproc_elif_token1] = ACTIONS(3001),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4090] = {
    [sym_preproc_region] = STATE(4090),
    [sym_preproc_endregion] = STATE(4090),
    [sym_preproc_line] = STATE(4090),
    [sym_preproc_pragma] = STATE(4090),
    [sym_preproc_nullable] = STATE(4090),
    [sym_preproc_error] = STATE(4090),
    [sym_preproc_warning] = STATE(4090),
    [sym_preproc_define] = STATE(4090),
    [sym_preproc_undef] = STATE(4090),
    [anon_sym_SEMI] = ACTIONS(4484),
    [anon_sym_LBRACK] = ACTIONS(4484),
    [anon_sym_COLON] = ACTIONS(4484),
    [anon_sym_COMMA] = ACTIONS(4484),
    [anon_sym_RBRACK] = ACTIONS(4484),
    [anon_sym_LPAREN] = ACTIONS(4484),
    [anon_sym_RPAREN] = ACTIONS(4484),
    [anon_sym_LBRACE] = ACTIONS(4484),
    [anon_sym_RBRACE] = ACTIONS(4484),
    [anon_sym_LT] = ACTIONS(4482),
    [anon_sym_GT] = ACTIONS(4482),
    [anon_sym_in] = ACTIONS(4484),
    [anon_sym_QMARK] = ACTIONS(4482),
    [anon_sym_BANG] = ACTIONS(4482),
    [anon_sym_PLUS_PLUS] = ACTIONS(4484),
    [anon_sym_DASH_DASH] = ACTIONS(4484),
    [anon_sym_PLUS] = ACTIONS(4482),
    [anon_sym_DASH] = ACTIONS(4482),
    [anon_sym_STAR] = ACTIONS(4484),
    [anon_sym_SLASH] = ACTIONS(4482),
    [anon_sym_PERCENT] = ACTIONS(4484),
    [anon_sym_CARET] = ACTIONS(4484),
    [anon_sym_PIPE] = ACTIONS(4482),
    [anon_sym_AMP] = ACTIONS(4482),
    [anon_sym_LT_LT] = ACTIONS(4484),
    [anon_sym_GT_GT] = ACTIONS(4482),
    [anon_sym_GT_GT_GT] = ACTIONS(4484),
    [anon_sym_EQ_EQ] = ACTIONS(4484),
    [anon_sym_BANG_EQ] = ACTIONS(4484),
    [anon_sym_GT_EQ] = ACTIONS(4484),
    [anon_sym_LT_EQ] = ACTIONS(4484),
    [anon_sym_DOT] = ACTIONS(4482),
    [anon_sym_EQ_GT] = ACTIONS(4484),
    [anon_sym_switch] = ACTIONS(4484),
    [anon_sym_when] = ACTIONS(4484),
    [anon_sym_DOT_DOT] = ACTIONS(4484),
    [anon_sym_and] = ACTIONS(4484),
    [anon_sym_or] = ACTIONS(4484),
    [anon_sym_AMP_AMP] = ACTIONS(4484),
    [anon_sym_PIPE_PIPE] = ACTIONS(4484),
    [anon_sym_QMARK_QMARK] = ACTIONS(4484),
    [anon_sym_on] = ACTIONS(4484),
    [anon_sym_equals] = ACTIONS(4484),
    [anon_sym_by] = ACTIONS(4484),
    [anon_sym_as] = ACTIONS(4484),
    [anon_sym_is] = ACTIONS(4484),
    [anon_sym_DASH_GT] = ACTIONS(4484),
    [anon_sym_with] = ACTIONS(4484),
    [aux_sym_preproc_if_token3] = ACTIONS(4484),
    [aux_sym_preproc_else_token1] = ACTIONS(4484),
    [aux_sym_preproc_elif_token1] = ACTIONS(4484),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4091] = {
    [sym_preproc_region] = STATE(4091),
    [sym_preproc_endregion] = STATE(4091),
    [sym_preproc_line] = STATE(4091),
    [sym_preproc_pragma] = STATE(4091),
    [sym_preproc_nullable] = STATE(4091),
    [sym_preproc_error] = STATE(4091),
    [sym_preproc_warning] = STATE(4091),
    [sym_preproc_define] = STATE(4091),
    [sym_preproc_undef] = STATE(4091),
    [anon_sym_SEMI] = ACTIONS(5970),
    [anon_sym_LBRACK] = ACTIONS(5970),
    [anon_sym_COLON] = ACTIONS(5970),
    [anon_sym_COMMA] = ACTIONS(5970),
    [anon_sym_RBRACK] = ACTIONS(5970),
    [anon_sym_LPAREN] = ACTIONS(5970),
    [anon_sym_RPAREN] = ACTIONS(5970),
    [anon_sym_RBRACE] = ACTIONS(5970),
    [anon_sym_LT] = ACTIONS(5972),
    [anon_sym_GT] = ACTIONS(5972),
    [anon_sym_in] = ACTIONS(5972),
    [anon_sym_QMARK] = ACTIONS(5972),
    [anon_sym_BANG] = ACTIONS(5972),
    [anon_sym_PLUS_PLUS] = ACTIONS(5970),
    [anon_sym_DASH_DASH] = ACTIONS(5970),
    [anon_sym_PLUS] = ACTIONS(5972),
    [anon_sym_DASH] = ACTIONS(5972),
    [anon_sym_STAR] = ACTIONS(5970),
    [anon_sym_SLASH] = ACTIONS(5972),
    [anon_sym_PERCENT] = ACTIONS(5970),
    [anon_sym_CARET] = ACTIONS(5970),
    [anon_sym_PIPE] = ACTIONS(5972),
    [anon_sym_AMP] = ACTIONS(5972),
    [anon_sym_LT_LT] = ACTIONS(5970),
    [anon_sym_GT_GT] = ACTIONS(5972),
    [anon_sym_GT_GT_GT] = ACTIONS(5970),
    [anon_sym_EQ_EQ] = ACTIONS(5970),
    [anon_sym_BANG_EQ] = ACTIONS(5970),
    [anon_sym_GT_EQ] = ACTIONS(5970),
    [anon_sym_LT_EQ] = ACTIONS(5970),
    [anon_sym_DOT] = ACTIONS(5972),
    [anon_sym_EQ_GT] = ACTIONS(5970),
    [anon_sym_switch] = ACTIONS(5970),
    [anon_sym_when] = ACTIONS(5970),
    [anon_sym_DOT_DOT] = ACTIONS(5970),
    [anon_sym_and] = ACTIONS(5970),
    [anon_sym_or] = ACTIONS(5970),
    [anon_sym_AMP_AMP] = ACTIONS(5970),
    [anon_sym_PIPE_PIPE] = ACTIONS(5970),
    [anon_sym_QMARK_QMARK] = ACTIONS(5970),
    [anon_sym_into] = ACTIONS(5970),
    [anon_sym_on] = ACTIONS(5970),
    [anon_sym_equals] = ACTIONS(5970),
    [anon_sym_by] = ACTIONS(5970),
    [anon_sym_as] = ACTIONS(5970),
    [anon_sym_is] = ACTIONS(5970),
    [anon_sym_DASH_GT] = ACTIONS(5970),
    [anon_sym_with] = ACTIONS(5970),
    [aux_sym_preproc_if_token3] = ACTIONS(5970),
    [aux_sym_preproc_else_token1] = ACTIONS(5970),
    [aux_sym_preproc_elif_token1] = ACTIONS(5970),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4092] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7083),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9364),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4092),
    [sym_preproc_endregion] = STATE(4092),
    [sym_preproc_line] = STATE(4092),
    [sym_preproc_pragma] = STATE(4092),
    [sym_preproc_nullable] = STATE(4092),
    [sym_preproc_error] = STATE(4092),
    [sym_preproc_warning] = STATE(4092),
    [sym_preproc_define] = STATE(4092),
    [sym_preproc_undef] = STATE(4092),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(5974),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4093] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(6976),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9923),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4093),
    [sym_preproc_endregion] = STATE(4093),
    [sym_preproc_line] = STATE(4093),
    [sym_preproc_pragma] = STATE(4093),
    [sym_preproc_nullable] = STATE(4093),
    [sym_preproc_error] = STATE(4093),
    [sym_preproc_warning] = STATE(4093),
    [sym_preproc_define] = STATE(4093),
    [sym_preproc_undef] = STATE(4093),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4094] = {
    [sym__name] = STATE(7882),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(9347),
    [sym_implicit_type] = STATE(8747),
    [sym_array_type] = STATE(8331),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(8345),
    [sym_pointer_type] = STATE(8345),
    [sym__pointer_base_type] = STATE(9367),
    [sym_function_pointer_type] = STATE(8345),
    [sym_function_pointer_parameter] = STATE(9589),
    [sym_ref_type] = STATE(8787),
    [sym__ref_base_type] = STATE(9629),
    [sym_scoped_type] = STATE(8787),
    [sym_tuple_type] = STATE(8056),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4094),
    [sym_preproc_endregion] = STATE(4094),
    [sym_preproc_line] = STATE(4094),
    [sym_preproc_pragma] = STATE(4094),
    [sym_preproc_nullable] = STATE(4094),
    [sym_preproc_error] = STATE(4094),
    [sym_preproc_warning] = STATE(4094),
    [sym_preproc_define] = STATE(4094),
    [sym_preproc_undef] = STATE(4094),
    [aux_sym_function_pointer_type_repeat1] = STATE(4128),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(5976),
    [anon_sym_delegate] = ACTIONS(5747),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_in] = ACTIONS(5978),
    [anon_sym_out] = ACTIONS(5978),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(5980),
    [anon_sym_var] = ACTIONS(5369),
    [sym_predefined_type] = ACTIONS(5982),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4095] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7116),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9876),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4095),
    [sym_preproc_endregion] = STATE(4095),
    [sym_preproc_line] = STATE(4095),
    [sym_preproc_pragma] = STATE(4095),
    [sym_preproc_nullable] = STATE(4095),
    [sym_preproc_error] = STATE(4095),
    [sym_preproc_warning] = STATE(4095),
    [sym_preproc_define] = STATE(4095),
    [sym_preproc_undef] = STATE(4095),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(5984),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4096] = {
    [sym_preproc_region] = STATE(4096),
    [sym_preproc_endregion] = STATE(4096),
    [sym_preproc_line] = STATE(4096),
    [sym_preproc_pragma] = STATE(4096),
    [sym_preproc_nullable] = STATE(4096),
    [sym_preproc_error] = STATE(4096),
    [sym_preproc_warning] = STATE(4096),
    [sym_preproc_define] = STATE(4096),
    [sym_preproc_undef] = STATE(4096),
    [anon_sym_SEMI] = ACTIONS(5428),
    [anon_sym_LBRACK] = ACTIONS(5428),
    [anon_sym_COLON] = ACTIONS(5428),
    [anon_sym_COMMA] = ACTIONS(5428),
    [anon_sym_RBRACK] = ACTIONS(5428),
    [anon_sym_LPAREN] = ACTIONS(5428),
    [anon_sym_RPAREN] = ACTIONS(5428),
    [anon_sym_RBRACE] = ACTIONS(5428),
    [anon_sym_LT] = ACTIONS(5430),
    [anon_sym_GT] = ACTIONS(5430),
    [anon_sym_in] = ACTIONS(5428),
    [anon_sym_QMARK] = ACTIONS(5430),
    [anon_sym_BANG] = ACTIONS(5430),
    [anon_sym_PLUS_PLUS] = ACTIONS(5428),
    [anon_sym_DASH_DASH] = ACTIONS(5428),
    [anon_sym_PLUS] = ACTIONS(5430),
    [anon_sym_DASH] = ACTIONS(5430),
    [anon_sym_STAR] = ACTIONS(5428),
    [anon_sym_SLASH] = ACTIONS(5430),
    [anon_sym_PERCENT] = ACTIONS(5428),
    [anon_sym_CARET] = ACTIONS(5428),
    [anon_sym_PIPE] = ACTIONS(5430),
    [anon_sym_AMP] = ACTIONS(5430),
    [anon_sym_LT_LT] = ACTIONS(5428),
    [anon_sym_GT_GT] = ACTIONS(5430),
    [anon_sym_GT_GT_GT] = ACTIONS(5428),
    [anon_sym_EQ_EQ] = ACTIONS(5428),
    [anon_sym_BANG_EQ] = ACTIONS(5428),
    [anon_sym_GT_EQ] = ACTIONS(5428),
    [anon_sym_LT_EQ] = ACTIONS(5428),
    [anon_sym_DOT] = ACTIONS(5430),
    [anon_sym_EQ_GT] = ACTIONS(5428),
    [anon_sym_switch] = ACTIONS(5428),
    [anon_sym_when] = ACTIONS(5428),
    [anon_sym_DOT_DOT] = ACTIONS(5428),
    [anon_sym_and] = ACTIONS(5428),
    [anon_sym_or] = ACTIONS(5428),
    [anon_sym_AMP_AMP] = ACTIONS(5428),
    [anon_sym_PIPE_PIPE] = ACTIONS(5428),
    [anon_sym_QMARK_QMARK] = ACTIONS(5428),
    [anon_sym_on] = ACTIONS(5428),
    [anon_sym_equals] = ACTIONS(5428),
    [anon_sym_by] = ACTIONS(5428),
    [anon_sym_as] = ACTIONS(5428),
    [anon_sym_is] = ACTIONS(5428),
    [anon_sym_DASH_GT] = ACTIONS(5428),
    [anon_sym_with] = ACTIONS(5428),
    [aux_sym_preproc_if_token3] = ACTIONS(5428),
    [aux_sym_preproc_else_token1] = ACTIONS(5428),
    [aux_sym_preproc_elif_token1] = ACTIONS(5428),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4097] = {
    [sym_preproc_region] = STATE(4097),
    [sym_preproc_endregion] = STATE(4097),
    [sym_preproc_line] = STATE(4097),
    [sym_preproc_pragma] = STATE(4097),
    [sym_preproc_nullable] = STATE(4097),
    [sym_preproc_error] = STATE(4097),
    [sym_preproc_warning] = STATE(4097),
    [sym_preproc_define] = STATE(4097),
    [sym_preproc_undef] = STATE(4097),
    [anon_sym_SEMI] = ACTIONS(5466),
    [anon_sym_LBRACK] = ACTIONS(5466),
    [anon_sym_COLON] = ACTIONS(5466),
    [anon_sym_COMMA] = ACTIONS(5466),
    [anon_sym_RBRACK] = ACTIONS(5466),
    [anon_sym_LPAREN] = ACTIONS(5466),
    [anon_sym_RPAREN] = ACTIONS(5466),
    [anon_sym_RBRACE] = ACTIONS(5466),
    [anon_sym_LT] = ACTIONS(5468),
    [anon_sym_GT] = ACTIONS(5468),
    [anon_sym_in] = ACTIONS(5466),
    [anon_sym_QMARK] = ACTIONS(5468),
    [anon_sym_BANG] = ACTIONS(5468),
    [anon_sym_PLUS_PLUS] = ACTIONS(5466),
    [anon_sym_DASH_DASH] = ACTIONS(5466),
    [anon_sym_PLUS] = ACTIONS(5468),
    [anon_sym_DASH] = ACTIONS(5468),
    [anon_sym_STAR] = ACTIONS(5466),
    [anon_sym_SLASH] = ACTIONS(5468),
    [anon_sym_PERCENT] = ACTIONS(5466),
    [anon_sym_CARET] = ACTIONS(5466),
    [anon_sym_PIPE] = ACTIONS(5468),
    [anon_sym_AMP] = ACTIONS(5468),
    [anon_sym_LT_LT] = ACTIONS(5466),
    [anon_sym_GT_GT] = ACTIONS(5468),
    [anon_sym_GT_GT_GT] = ACTIONS(5466),
    [anon_sym_EQ_EQ] = ACTIONS(5466),
    [anon_sym_BANG_EQ] = ACTIONS(5466),
    [anon_sym_GT_EQ] = ACTIONS(5466),
    [anon_sym_LT_EQ] = ACTIONS(5466),
    [anon_sym_DOT] = ACTIONS(5468),
    [anon_sym_EQ_GT] = ACTIONS(5466),
    [anon_sym_switch] = ACTIONS(5466),
    [anon_sym_when] = ACTIONS(5466),
    [anon_sym_DOT_DOT] = ACTIONS(5466),
    [anon_sym_and] = ACTIONS(5466),
    [anon_sym_or] = ACTIONS(5466),
    [anon_sym_AMP_AMP] = ACTIONS(5466),
    [anon_sym_PIPE_PIPE] = ACTIONS(5466),
    [anon_sym_QMARK_QMARK] = ACTIONS(5466),
    [anon_sym_on] = ACTIONS(5466),
    [anon_sym_equals] = ACTIONS(5466),
    [anon_sym_by] = ACTIONS(5466),
    [anon_sym_as] = ACTIONS(5466),
    [anon_sym_is] = ACTIONS(5466),
    [anon_sym_DASH_GT] = ACTIONS(5466),
    [anon_sym_with] = ACTIONS(5466),
    [aux_sym_preproc_if_token3] = ACTIONS(5466),
    [aux_sym_preproc_else_token1] = ACTIONS(5466),
    [aux_sym_preproc_elif_token1] = ACTIONS(5466),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4098] = {
    [sym_preproc_region] = STATE(4098),
    [sym_preproc_endregion] = STATE(4098),
    [sym_preproc_line] = STATE(4098),
    [sym_preproc_pragma] = STATE(4098),
    [sym_preproc_nullable] = STATE(4098),
    [sym_preproc_error] = STATE(4098),
    [sym_preproc_warning] = STATE(4098),
    [sym_preproc_define] = STATE(4098),
    [sym_preproc_undef] = STATE(4098),
    [anon_sym_SEMI] = ACTIONS(5486),
    [anon_sym_LBRACK] = ACTIONS(5486),
    [anon_sym_COLON] = ACTIONS(5486),
    [anon_sym_COMMA] = ACTIONS(5486),
    [anon_sym_RBRACK] = ACTIONS(5486),
    [anon_sym_LPAREN] = ACTIONS(5486),
    [anon_sym_RPAREN] = ACTIONS(5486),
    [anon_sym_RBRACE] = ACTIONS(5486),
    [anon_sym_LT] = ACTIONS(5488),
    [anon_sym_GT] = ACTIONS(5488),
    [anon_sym_in] = ACTIONS(5486),
    [anon_sym_QMARK] = ACTIONS(5488),
    [anon_sym_BANG] = ACTIONS(5488),
    [anon_sym_PLUS_PLUS] = ACTIONS(5486),
    [anon_sym_DASH_DASH] = ACTIONS(5486),
    [anon_sym_PLUS] = ACTIONS(5488),
    [anon_sym_DASH] = ACTIONS(5488),
    [anon_sym_STAR] = ACTIONS(5486),
    [anon_sym_SLASH] = ACTIONS(5488),
    [anon_sym_PERCENT] = ACTIONS(5486),
    [anon_sym_CARET] = ACTIONS(5486),
    [anon_sym_PIPE] = ACTIONS(5488),
    [anon_sym_AMP] = ACTIONS(5488),
    [anon_sym_LT_LT] = ACTIONS(5486),
    [anon_sym_GT_GT] = ACTIONS(5488),
    [anon_sym_GT_GT_GT] = ACTIONS(5486),
    [anon_sym_EQ_EQ] = ACTIONS(5486),
    [anon_sym_BANG_EQ] = ACTIONS(5486),
    [anon_sym_GT_EQ] = ACTIONS(5486),
    [anon_sym_LT_EQ] = ACTIONS(5486),
    [anon_sym_DOT] = ACTIONS(5488),
    [anon_sym_EQ_GT] = ACTIONS(5486),
    [anon_sym_switch] = ACTIONS(5486),
    [anon_sym_when] = ACTIONS(5486),
    [anon_sym_DOT_DOT] = ACTIONS(5486),
    [anon_sym_and] = ACTIONS(5486),
    [anon_sym_or] = ACTIONS(5486),
    [anon_sym_AMP_AMP] = ACTIONS(5486),
    [anon_sym_PIPE_PIPE] = ACTIONS(5486),
    [anon_sym_QMARK_QMARK] = ACTIONS(5486),
    [anon_sym_on] = ACTIONS(5486),
    [anon_sym_equals] = ACTIONS(5486),
    [anon_sym_by] = ACTIONS(5486),
    [anon_sym_as] = ACTIONS(5486),
    [anon_sym_is] = ACTIONS(5486),
    [anon_sym_DASH_GT] = ACTIONS(5486),
    [anon_sym_with] = ACTIONS(5486),
    [aux_sym_preproc_if_token3] = ACTIONS(5486),
    [aux_sym_preproc_else_token1] = ACTIONS(5486),
    [aux_sym_preproc_elif_token1] = ACTIONS(5486),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4099] = {
    [sym_preproc_region] = STATE(4099),
    [sym_preproc_endregion] = STATE(4099),
    [sym_preproc_line] = STATE(4099),
    [sym_preproc_pragma] = STATE(4099),
    [sym_preproc_nullable] = STATE(4099),
    [sym_preproc_error] = STATE(4099),
    [sym_preproc_warning] = STATE(4099),
    [sym_preproc_define] = STATE(4099),
    [sym_preproc_undef] = STATE(4099),
    [anon_sym_SEMI] = ACTIONS(5560),
    [anon_sym_LBRACK] = ACTIONS(5560),
    [anon_sym_COLON] = ACTIONS(5560),
    [anon_sym_COMMA] = ACTIONS(5560),
    [anon_sym_RBRACK] = ACTIONS(5560),
    [anon_sym_LPAREN] = ACTIONS(5560),
    [anon_sym_RPAREN] = ACTIONS(5560),
    [anon_sym_RBRACE] = ACTIONS(5560),
    [anon_sym_LT] = ACTIONS(5562),
    [anon_sym_GT] = ACTIONS(5562),
    [anon_sym_in] = ACTIONS(5560),
    [anon_sym_QMARK] = ACTIONS(5562),
    [anon_sym_BANG] = ACTIONS(5562),
    [anon_sym_PLUS_PLUS] = ACTIONS(5560),
    [anon_sym_DASH_DASH] = ACTIONS(5560),
    [anon_sym_PLUS] = ACTIONS(5562),
    [anon_sym_DASH] = ACTIONS(5562),
    [anon_sym_STAR] = ACTIONS(5560),
    [anon_sym_SLASH] = ACTIONS(5562),
    [anon_sym_PERCENT] = ACTIONS(5560),
    [anon_sym_CARET] = ACTIONS(5560),
    [anon_sym_PIPE] = ACTIONS(5562),
    [anon_sym_AMP] = ACTIONS(5562),
    [anon_sym_LT_LT] = ACTIONS(5560),
    [anon_sym_GT_GT] = ACTIONS(5562),
    [anon_sym_GT_GT_GT] = ACTIONS(5560),
    [anon_sym_EQ_EQ] = ACTIONS(5560),
    [anon_sym_BANG_EQ] = ACTIONS(5560),
    [anon_sym_GT_EQ] = ACTIONS(5560),
    [anon_sym_LT_EQ] = ACTIONS(5560),
    [anon_sym_DOT] = ACTIONS(5562),
    [anon_sym_EQ_GT] = ACTIONS(5560),
    [anon_sym_switch] = ACTIONS(5560),
    [anon_sym_when] = ACTIONS(5560),
    [anon_sym_DOT_DOT] = ACTIONS(5560),
    [anon_sym_and] = ACTIONS(5560),
    [anon_sym_or] = ACTIONS(5560),
    [anon_sym_AMP_AMP] = ACTIONS(5560),
    [anon_sym_PIPE_PIPE] = ACTIONS(5560),
    [anon_sym_QMARK_QMARK] = ACTIONS(5560),
    [anon_sym_on] = ACTIONS(5560),
    [anon_sym_equals] = ACTIONS(5560),
    [anon_sym_by] = ACTIONS(5560),
    [anon_sym_as] = ACTIONS(5560),
    [anon_sym_is] = ACTIONS(5560),
    [anon_sym_DASH_GT] = ACTIONS(5560),
    [anon_sym_with] = ACTIONS(5560),
    [aux_sym_preproc_if_token3] = ACTIONS(5560),
    [aux_sym_preproc_else_token1] = ACTIONS(5560),
    [aux_sym_preproc_elif_token1] = ACTIONS(5560),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4100] = {
    [sym_type_parameter_constraint] = STATE(8093),
    [sym_constructor_constraint] = STATE(8006),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(8011),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4100),
    [sym_preproc_endregion] = STATE(4100),
    [sym_preproc_line] = STATE(4100),
    [sym_preproc_pragma] = STATE(4100),
    [sym_preproc_nullable] = STATE(4100),
    [sym_preproc_error] = STATE(4100),
    [sym_preproc_warning] = STATE(4100),
    [sym_preproc_define] = STATE(4100),
    [sym_preproc_undef] = STATE(4100),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_class] = ACTIONS(5986),
    [anon_sym_ref] = ACTIONS(5988),
    [anon_sym_struct] = ACTIONS(5990),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_new] = ACTIONS(5992),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(5994),
    [anon_sym_unmanaged] = ACTIONS(5994),
    [anon_sym_scoped] = ACTIONS(5996),
    [anon_sym_var] = ACTIONS(5369),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4101] = {
    [sym_preproc_region] = STATE(4101),
    [sym_preproc_endregion] = STATE(4101),
    [sym_preproc_line] = STATE(4101),
    [sym_preproc_pragma] = STATE(4101),
    [sym_preproc_nullable] = STATE(4101),
    [sym_preproc_error] = STATE(4101),
    [sym_preproc_warning] = STATE(4101),
    [sym_preproc_define] = STATE(4101),
    [sym_preproc_undef] = STATE(4101),
    [anon_sym_SEMI] = ACTIONS(5572),
    [anon_sym_LBRACK] = ACTIONS(5572),
    [anon_sym_COLON] = ACTIONS(5572),
    [anon_sym_COMMA] = ACTIONS(5572),
    [anon_sym_RBRACK] = ACTIONS(5572),
    [anon_sym_LPAREN] = ACTIONS(5572),
    [anon_sym_RPAREN] = ACTIONS(5572),
    [anon_sym_RBRACE] = ACTIONS(5572),
    [anon_sym_LT] = ACTIONS(5574),
    [anon_sym_GT] = ACTIONS(5574),
    [anon_sym_in] = ACTIONS(5572),
    [anon_sym_QMARK] = ACTIONS(5574),
    [anon_sym_BANG] = ACTIONS(5574),
    [anon_sym_PLUS_PLUS] = ACTIONS(5572),
    [anon_sym_DASH_DASH] = ACTIONS(5572),
    [anon_sym_PLUS] = ACTIONS(5574),
    [anon_sym_DASH] = ACTIONS(5574),
    [anon_sym_STAR] = ACTIONS(5572),
    [anon_sym_SLASH] = ACTIONS(5574),
    [anon_sym_PERCENT] = ACTIONS(5572),
    [anon_sym_CARET] = ACTIONS(5572),
    [anon_sym_PIPE] = ACTIONS(5574),
    [anon_sym_AMP] = ACTIONS(5574),
    [anon_sym_LT_LT] = ACTIONS(5572),
    [anon_sym_GT_GT] = ACTIONS(5574),
    [anon_sym_GT_GT_GT] = ACTIONS(5572),
    [anon_sym_EQ_EQ] = ACTIONS(5572),
    [anon_sym_BANG_EQ] = ACTIONS(5572),
    [anon_sym_GT_EQ] = ACTIONS(5572),
    [anon_sym_LT_EQ] = ACTIONS(5572),
    [anon_sym_DOT] = ACTIONS(5574),
    [anon_sym_EQ_GT] = ACTIONS(5572),
    [anon_sym_switch] = ACTIONS(5572),
    [anon_sym_when] = ACTIONS(5572),
    [anon_sym_DOT_DOT] = ACTIONS(5572),
    [anon_sym_and] = ACTIONS(5572),
    [anon_sym_or] = ACTIONS(5572),
    [anon_sym_AMP_AMP] = ACTIONS(5572),
    [anon_sym_PIPE_PIPE] = ACTIONS(5572),
    [anon_sym_QMARK_QMARK] = ACTIONS(5572),
    [anon_sym_on] = ACTIONS(5572),
    [anon_sym_equals] = ACTIONS(5572),
    [anon_sym_by] = ACTIONS(5572),
    [anon_sym_as] = ACTIONS(5572),
    [anon_sym_is] = ACTIONS(5572),
    [anon_sym_DASH_GT] = ACTIONS(5572),
    [anon_sym_with] = ACTIONS(5572),
    [aux_sym_preproc_if_token3] = ACTIONS(5572),
    [aux_sym_preproc_else_token1] = ACTIONS(5572),
    [aux_sym_preproc_elif_token1] = ACTIONS(5572),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4102] = {
    [sym_preproc_region] = STATE(4102),
    [sym_preproc_endregion] = STATE(4102),
    [sym_preproc_line] = STATE(4102),
    [sym_preproc_pragma] = STATE(4102),
    [sym_preproc_nullable] = STATE(4102),
    [sym_preproc_error] = STATE(4102),
    [sym_preproc_warning] = STATE(4102),
    [sym_preproc_define] = STATE(4102),
    [sym_preproc_undef] = STATE(4102),
    [anon_sym_SEMI] = ACTIONS(5584),
    [anon_sym_LBRACK] = ACTIONS(5584),
    [anon_sym_COLON] = ACTIONS(5584),
    [anon_sym_COMMA] = ACTIONS(5584),
    [anon_sym_RBRACK] = ACTIONS(5584),
    [anon_sym_LPAREN] = ACTIONS(5584),
    [anon_sym_RPAREN] = ACTIONS(5584),
    [anon_sym_RBRACE] = ACTIONS(5584),
    [anon_sym_LT] = ACTIONS(5586),
    [anon_sym_GT] = ACTIONS(5586),
    [anon_sym_in] = ACTIONS(5584),
    [anon_sym_QMARK] = ACTIONS(5586),
    [anon_sym_BANG] = ACTIONS(5586),
    [anon_sym_PLUS_PLUS] = ACTIONS(5584),
    [anon_sym_DASH_DASH] = ACTIONS(5584),
    [anon_sym_PLUS] = ACTIONS(5586),
    [anon_sym_DASH] = ACTIONS(5586),
    [anon_sym_STAR] = ACTIONS(5584),
    [anon_sym_SLASH] = ACTIONS(5586),
    [anon_sym_PERCENT] = ACTIONS(5584),
    [anon_sym_CARET] = ACTIONS(5584),
    [anon_sym_PIPE] = ACTIONS(5586),
    [anon_sym_AMP] = ACTIONS(5586),
    [anon_sym_LT_LT] = ACTIONS(5584),
    [anon_sym_GT_GT] = ACTIONS(5586),
    [anon_sym_GT_GT_GT] = ACTIONS(5584),
    [anon_sym_EQ_EQ] = ACTIONS(5584),
    [anon_sym_BANG_EQ] = ACTIONS(5584),
    [anon_sym_GT_EQ] = ACTIONS(5584),
    [anon_sym_LT_EQ] = ACTIONS(5584),
    [anon_sym_DOT] = ACTIONS(5586),
    [anon_sym_EQ_GT] = ACTIONS(5584),
    [anon_sym_switch] = ACTIONS(5584),
    [anon_sym_when] = ACTIONS(5584),
    [anon_sym_DOT_DOT] = ACTIONS(5584),
    [anon_sym_and] = ACTIONS(5584),
    [anon_sym_or] = ACTIONS(5584),
    [anon_sym_AMP_AMP] = ACTIONS(5584),
    [anon_sym_PIPE_PIPE] = ACTIONS(5584),
    [anon_sym_QMARK_QMARK] = ACTIONS(5584),
    [anon_sym_on] = ACTIONS(5584),
    [anon_sym_equals] = ACTIONS(5584),
    [anon_sym_by] = ACTIONS(5584),
    [anon_sym_as] = ACTIONS(5584),
    [anon_sym_is] = ACTIONS(5584),
    [anon_sym_DASH_GT] = ACTIONS(5584),
    [anon_sym_with] = ACTIONS(5584),
    [aux_sym_preproc_if_token3] = ACTIONS(5584),
    [aux_sym_preproc_else_token1] = ACTIONS(5584),
    [aux_sym_preproc_elif_token1] = ACTIONS(5584),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4103] = {
    [sym_preproc_region] = STATE(4103),
    [sym_preproc_endregion] = STATE(4103),
    [sym_preproc_line] = STATE(4103),
    [sym_preproc_pragma] = STATE(4103),
    [sym_preproc_nullable] = STATE(4103),
    [sym_preproc_error] = STATE(4103),
    [sym_preproc_warning] = STATE(4103),
    [sym_preproc_define] = STATE(4103),
    [sym_preproc_undef] = STATE(4103),
    [anon_sym_SEMI] = ACTIONS(5596),
    [anon_sym_LBRACK] = ACTIONS(5596),
    [anon_sym_COLON] = ACTIONS(5596),
    [anon_sym_COMMA] = ACTIONS(5596),
    [anon_sym_RBRACK] = ACTIONS(5596),
    [anon_sym_LPAREN] = ACTIONS(5596),
    [anon_sym_RPAREN] = ACTIONS(5596),
    [anon_sym_RBRACE] = ACTIONS(5596),
    [anon_sym_LT] = ACTIONS(5598),
    [anon_sym_GT] = ACTIONS(5598),
    [anon_sym_in] = ACTIONS(5596),
    [anon_sym_QMARK] = ACTIONS(5598),
    [anon_sym_BANG] = ACTIONS(5598),
    [anon_sym_PLUS_PLUS] = ACTIONS(5596),
    [anon_sym_DASH_DASH] = ACTIONS(5596),
    [anon_sym_PLUS] = ACTIONS(5598),
    [anon_sym_DASH] = ACTIONS(5598),
    [anon_sym_STAR] = ACTIONS(5596),
    [anon_sym_SLASH] = ACTIONS(5598),
    [anon_sym_PERCENT] = ACTIONS(5596),
    [anon_sym_CARET] = ACTIONS(5596),
    [anon_sym_PIPE] = ACTIONS(5598),
    [anon_sym_AMP] = ACTIONS(5598),
    [anon_sym_LT_LT] = ACTIONS(5596),
    [anon_sym_GT_GT] = ACTIONS(5598),
    [anon_sym_GT_GT_GT] = ACTIONS(5596),
    [anon_sym_EQ_EQ] = ACTIONS(5596),
    [anon_sym_BANG_EQ] = ACTIONS(5596),
    [anon_sym_GT_EQ] = ACTIONS(5596),
    [anon_sym_LT_EQ] = ACTIONS(5596),
    [anon_sym_DOT] = ACTIONS(5598),
    [anon_sym_EQ_GT] = ACTIONS(5596),
    [anon_sym_switch] = ACTIONS(5596),
    [anon_sym_when] = ACTIONS(5596),
    [anon_sym_DOT_DOT] = ACTIONS(5596),
    [anon_sym_and] = ACTIONS(5596),
    [anon_sym_or] = ACTIONS(5596),
    [anon_sym_AMP_AMP] = ACTIONS(5596),
    [anon_sym_PIPE_PIPE] = ACTIONS(5596),
    [anon_sym_QMARK_QMARK] = ACTIONS(5596),
    [anon_sym_on] = ACTIONS(5596),
    [anon_sym_equals] = ACTIONS(5596),
    [anon_sym_by] = ACTIONS(5596),
    [anon_sym_as] = ACTIONS(5596),
    [anon_sym_is] = ACTIONS(5596),
    [anon_sym_DASH_GT] = ACTIONS(5596),
    [anon_sym_with] = ACTIONS(5596),
    [aux_sym_preproc_if_token3] = ACTIONS(5596),
    [aux_sym_preproc_else_token1] = ACTIONS(5596),
    [aux_sym_preproc_elif_token1] = ACTIONS(5596),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4104] = {
    [sym_preproc_region] = STATE(4104),
    [sym_preproc_endregion] = STATE(4104),
    [sym_preproc_line] = STATE(4104),
    [sym_preproc_pragma] = STATE(4104),
    [sym_preproc_nullable] = STATE(4104),
    [sym_preproc_error] = STATE(4104),
    [sym_preproc_warning] = STATE(4104),
    [sym_preproc_define] = STATE(4104),
    [sym_preproc_undef] = STATE(4104),
    [anon_sym_SEMI] = ACTIONS(5600),
    [anon_sym_LBRACK] = ACTIONS(5600),
    [anon_sym_COLON] = ACTIONS(5600),
    [anon_sym_COMMA] = ACTIONS(5600),
    [anon_sym_RBRACK] = ACTIONS(5600),
    [anon_sym_LPAREN] = ACTIONS(5600),
    [anon_sym_RPAREN] = ACTIONS(5600),
    [anon_sym_RBRACE] = ACTIONS(5600),
    [anon_sym_LT] = ACTIONS(5602),
    [anon_sym_GT] = ACTIONS(5602),
    [anon_sym_in] = ACTIONS(5600),
    [anon_sym_QMARK] = ACTIONS(5602),
    [anon_sym_BANG] = ACTIONS(5602),
    [anon_sym_PLUS_PLUS] = ACTIONS(5600),
    [anon_sym_DASH_DASH] = ACTIONS(5600),
    [anon_sym_PLUS] = ACTIONS(5602),
    [anon_sym_DASH] = ACTIONS(5602),
    [anon_sym_STAR] = ACTIONS(5600),
    [anon_sym_SLASH] = ACTIONS(5602),
    [anon_sym_PERCENT] = ACTIONS(5600),
    [anon_sym_CARET] = ACTIONS(5600),
    [anon_sym_PIPE] = ACTIONS(5602),
    [anon_sym_AMP] = ACTIONS(5602),
    [anon_sym_LT_LT] = ACTIONS(5600),
    [anon_sym_GT_GT] = ACTIONS(5602),
    [anon_sym_GT_GT_GT] = ACTIONS(5600),
    [anon_sym_EQ_EQ] = ACTIONS(5600),
    [anon_sym_BANG_EQ] = ACTIONS(5600),
    [anon_sym_GT_EQ] = ACTIONS(5600),
    [anon_sym_LT_EQ] = ACTIONS(5600),
    [anon_sym_DOT] = ACTIONS(5602),
    [anon_sym_EQ_GT] = ACTIONS(5600),
    [anon_sym_switch] = ACTIONS(5600),
    [anon_sym_when] = ACTIONS(5600),
    [anon_sym_DOT_DOT] = ACTIONS(5600),
    [anon_sym_and] = ACTIONS(5600),
    [anon_sym_or] = ACTIONS(5600),
    [anon_sym_AMP_AMP] = ACTIONS(5600),
    [anon_sym_PIPE_PIPE] = ACTIONS(5600),
    [anon_sym_QMARK_QMARK] = ACTIONS(5600),
    [anon_sym_on] = ACTIONS(5600),
    [anon_sym_equals] = ACTIONS(5600),
    [anon_sym_by] = ACTIONS(5600),
    [anon_sym_as] = ACTIONS(5600),
    [anon_sym_is] = ACTIONS(5600),
    [anon_sym_DASH_GT] = ACTIONS(5600),
    [anon_sym_with] = ACTIONS(5600),
    [aux_sym_preproc_if_token3] = ACTIONS(5600),
    [aux_sym_preproc_else_token1] = ACTIONS(5600),
    [aux_sym_preproc_elif_token1] = ACTIONS(5600),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4105] = {
    [sym_preproc_region] = STATE(4105),
    [sym_preproc_endregion] = STATE(4105),
    [sym_preproc_line] = STATE(4105),
    [sym_preproc_pragma] = STATE(4105),
    [sym_preproc_nullable] = STATE(4105),
    [sym_preproc_error] = STATE(4105),
    [sym_preproc_warning] = STATE(4105),
    [sym_preproc_define] = STATE(4105),
    [sym_preproc_undef] = STATE(4105),
    [anon_sym_SEMI] = ACTIONS(5604),
    [anon_sym_LBRACK] = ACTIONS(5604),
    [anon_sym_COLON] = ACTIONS(5604),
    [anon_sym_COMMA] = ACTIONS(5604),
    [anon_sym_RBRACK] = ACTIONS(5604),
    [anon_sym_LPAREN] = ACTIONS(5604),
    [anon_sym_RPAREN] = ACTIONS(5604),
    [anon_sym_RBRACE] = ACTIONS(5604),
    [anon_sym_LT] = ACTIONS(5606),
    [anon_sym_GT] = ACTIONS(5606),
    [anon_sym_in] = ACTIONS(5604),
    [anon_sym_QMARK] = ACTIONS(5606),
    [anon_sym_BANG] = ACTIONS(5606),
    [anon_sym_PLUS_PLUS] = ACTIONS(5604),
    [anon_sym_DASH_DASH] = ACTIONS(5604),
    [anon_sym_PLUS] = ACTIONS(5606),
    [anon_sym_DASH] = ACTIONS(5606),
    [anon_sym_STAR] = ACTIONS(5604),
    [anon_sym_SLASH] = ACTIONS(5606),
    [anon_sym_PERCENT] = ACTIONS(5604),
    [anon_sym_CARET] = ACTIONS(5604),
    [anon_sym_PIPE] = ACTIONS(5606),
    [anon_sym_AMP] = ACTIONS(5606),
    [anon_sym_LT_LT] = ACTIONS(5604),
    [anon_sym_GT_GT] = ACTIONS(5606),
    [anon_sym_GT_GT_GT] = ACTIONS(5604),
    [anon_sym_EQ_EQ] = ACTIONS(5604),
    [anon_sym_BANG_EQ] = ACTIONS(5604),
    [anon_sym_GT_EQ] = ACTIONS(5604),
    [anon_sym_LT_EQ] = ACTIONS(5604),
    [anon_sym_DOT] = ACTIONS(5606),
    [anon_sym_EQ_GT] = ACTIONS(5604),
    [anon_sym_switch] = ACTIONS(5604),
    [anon_sym_when] = ACTIONS(5604),
    [anon_sym_DOT_DOT] = ACTIONS(5604),
    [anon_sym_and] = ACTIONS(5604),
    [anon_sym_or] = ACTIONS(5604),
    [anon_sym_AMP_AMP] = ACTIONS(5604),
    [anon_sym_PIPE_PIPE] = ACTIONS(5604),
    [anon_sym_QMARK_QMARK] = ACTIONS(5604),
    [anon_sym_on] = ACTIONS(5604),
    [anon_sym_equals] = ACTIONS(5604),
    [anon_sym_by] = ACTIONS(5604),
    [anon_sym_as] = ACTIONS(5604),
    [anon_sym_is] = ACTIONS(5604),
    [anon_sym_DASH_GT] = ACTIONS(5604),
    [anon_sym_with] = ACTIONS(5604),
    [aux_sym_preproc_if_token3] = ACTIONS(5604),
    [aux_sym_preproc_else_token1] = ACTIONS(5604),
    [aux_sym_preproc_elif_token1] = ACTIONS(5604),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4106] = {
    [sym_preproc_region] = STATE(4106),
    [sym_preproc_endregion] = STATE(4106),
    [sym_preproc_line] = STATE(4106),
    [sym_preproc_pragma] = STATE(4106),
    [sym_preproc_nullable] = STATE(4106),
    [sym_preproc_error] = STATE(4106),
    [sym_preproc_warning] = STATE(4106),
    [sym_preproc_define] = STATE(4106),
    [sym_preproc_undef] = STATE(4106),
    [anon_sym_SEMI] = ACTIONS(5616),
    [anon_sym_LBRACK] = ACTIONS(5616),
    [anon_sym_COLON] = ACTIONS(5616),
    [anon_sym_COMMA] = ACTIONS(5616),
    [anon_sym_RBRACK] = ACTIONS(5616),
    [anon_sym_LPAREN] = ACTIONS(5616),
    [anon_sym_RPAREN] = ACTIONS(5616),
    [anon_sym_RBRACE] = ACTIONS(5616),
    [anon_sym_LT] = ACTIONS(5618),
    [anon_sym_GT] = ACTIONS(5618),
    [anon_sym_in] = ACTIONS(5616),
    [anon_sym_QMARK] = ACTIONS(5618),
    [anon_sym_BANG] = ACTIONS(5618),
    [anon_sym_PLUS_PLUS] = ACTIONS(5616),
    [anon_sym_DASH_DASH] = ACTIONS(5616),
    [anon_sym_PLUS] = ACTIONS(5618),
    [anon_sym_DASH] = ACTIONS(5618),
    [anon_sym_STAR] = ACTIONS(5616),
    [anon_sym_SLASH] = ACTIONS(5618),
    [anon_sym_PERCENT] = ACTIONS(5616),
    [anon_sym_CARET] = ACTIONS(5616),
    [anon_sym_PIPE] = ACTIONS(5618),
    [anon_sym_AMP] = ACTIONS(5618),
    [anon_sym_LT_LT] = ACTIONS(5616),
    [anon_sym_GT_GT] = ACTIONS(5618),
    [anon_sym_GT_GT_GT] = ACTIONS(5616),
    [anon_sym_EQ_EQ] = ACTIONS(5616),
    [anon_sym_BANG_EQ] = ACTIONS(5616),
    [anon_sym_GT_EQ] = ACTIONS(5616),
    [anon_sym_LT_EQ] = ACTIONS(5616),
    [anon_sym_DOT] = ACTIONS(5618),
    [anon_sym_EQ_GT] = ACTIONS(5616),
    [anon_sym_switch] = ACTIONS(5616),
    [anon_sym_when] = ACTIONS(5616),
    [anon_sym_DOT_DOT] = ACTIONS(5616),
    [anon_sym_and] = ACTIONS(5616),
    [anon_sym_or] = ACTIONS(5616),
    [anon_sym_AMP_AMP] = ACTIONS(5616),
    [anon_sym_PIPE_PIPE] = ACTIONS(5616),
    [anon_sym_QMARK_QMARK] = ACTIONS(5616),
    [anon_sym_on] = ACTIONS(5616),
    [anon_sym_equals] = ACTIONS(5616),
    [anon_sym_by] = ACTIONS(5616),
    [anon_sym_as] = ACTIONS(5616),
    [anon_sym_is] = ACTIONS(5616),
    [anon_sym_DASH_GT] = ACTIONS(5616),
    [anon_sym_with] = ACTIONS(5616),
    [aux_sym_preproc_if_token3] = ACTIONS(5616),
    [aux_sym_preproc_else_token1] = ACTIONS(5616),
    [aux_sym_preproc_elif_token1] = ACTIONS(5616),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4107] = {
    [sym_preproc_region] = STATE(4107),
    [sym_preproc_endregion] = STATE(4107),
    [sym_preproc_line] = STATE(4107),
    [sym_preproc_pragma] = STATE(4107),
    [sym_preproc_nullable] = STATE(4107),
    [sym_preproc_error] = STATE(4107),
    [sym_preproc_warning] = STATE(4107),
    [sym_preproc_define] = STATE(4107),
    [sym_preproc_undef] = STATE(4107),
    [anon_sym_SEMI] = ACTIONS(5494),
    [anon_sym_LBRACK] = ACTIONS(5494),
    [anon_sym_COLON] = ACTIONS(5494),
    [anon_sym_COMMA] = ACTIONS(5494),
    [anon_sym_RBRACK] = ACTIONS(5494),
    [anon_sym_LPAREN] = ACTIONS(5494),
    [anon_sym_RPAREN] = ACTIONS(5494),
    [anon_sym_RBRACE] = ACTIONS(5494),
    [anon_sym_LT] = ACTIONS(5496),
    [anon_sym_GT] = ACTIONS(5496),
    [anon_sym_in] = ACTIONS(5494),
    [anon_sym_QMARK] = ACTIONS(5496),
    [anon_sym_BANG] = ACTIONS(5496),
    [anon_sym_PLUS_PLUS] = ACTIONS(5494),
    [anon_sym_DASH_DASH] = ACTIONS(5494),
    [anon_sym_PLUS] = ACTIONS(5496),
    [anon_sym_DASH] = ACTIONS(5496),
    [anon_sym_STAR] = ACTIONS(5494),
    [anon_sym_SLASH] = ACTIONS(5496),
    [anon_sym_PERCENT] = ACTIONS(5494),
    [anon_sym_CARET] = ACTIONS(5494),
    [anon_sym_PIPE] = ACTIONS(5496),
    [anon_sym_AMP] = ACTIONS(5496),
    [anon_sym_LT_LT] = ACTIONS(5494),
    [anon_sym_GT_GT] = ACTIONS(5496),
    [anon_sym_GT_GT_GT] = ACTIONS(5494),
    [anon_sym_EQ_EQ] = ACTIONS(5494),
    [anon_sym_BANG_EQ] = ACTIONS(5494),
    [anon_sym_GT_EQ] = ACTIONS(5494),
    [anon_sym_LT_EQ] = ACTIONS(5494),
    [anon_sym_DOT] = ACTIONS(5496),
    [anon_sym_EQ_GT] = ACTIONS(5494),
    [anon_sym_switch] = ACTIONS(5494),
    [anon_sym_when] = ACTIONS(5494),
    [anon_sym_DOT_DOT] = ACTIONS(5494),
    [anon_sym_and] = ACTIONS(5494),
    [anon_sym_or] = ACTIONS(5494),
    [anon_sym_AMP_AMP] = ACTIONS(5494),
    [anon_sym_PIPE_PIPE] = ACTIONS(5494),
    [anon_sym_QMARK_QMARK] = ACTIONS(5494),
    [anon_sym_on] = ACTIONS(5494),
    [anon_sym_equals] = ACTIONS(5494),
    [anon_sym_by] = ACTIONS(5494),
    [anon_sym_as] = ACTIONS(5494),
    [anon_sym_is] = ACTIONS(5494),
    [anon_sym_DASH_GT] = ACTIONS(5494),
    [anon_sym_with] = ACTIONS(5494),
    [aux_sym_preproc_if_token3] = ACTIONS(5494),
    [aux_sym_preproc_else_token1] = ACTIONS(5494),
    [aux_sym_preproc_elif_token1] = ACTIONS(5494),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4108] = {
    [sym_preproc_region] = STATE(4108),
    [sym_preproc_endregion] = STATE(4108),
    [sym_preproc_line] = STATE(4108),
    [sym_preproc_pragma] = STATE(4108),
    [sym_preproc_nullable] = STATE(4108),
    [sym_preproc_error] = STATE(4108),
    [sym_preproc_warning] = STATE(4108),
    [sym_preproc_define] = STATE(4108),
    [sym_preproc_undef] = STATE(4108),
    [anon_sym_SEMI] = ACTIONS(5502),
    [anon_sym_LBRACK] = ACTIONS(5502),
    [anon_sym_COLON] = ACTIONS(5502),
    [anon_sym_COMMA] = ACTIONS(5502),
    [anon_sym_RBRACK] = ACTIONS(5502),
    [anon_sym_LPAREN] = ACTIONS(5502),
    [anon_sym_RPAREN] = ACTIONS(5502),
    [anon_sym_RBRACE] = ACTIONS(5502),
    [anon_sym_LT] = ACTIONS(5504),
    [anon_sym_GT] = ACTIONS(5504),
    [anon_sym_in] = ACTIONS(5502),
    [anon_sym_QMARK] = ACTIONS(5504),
    [anon_sym_BANG] = ACTIONS(5504),
    [anon_sym_PLUS_PLUS] = ACTIONS(5502),
    [anon_sym_DASH_DASH] = ACTIONS(5502),
    [anon_sym_PLUS] = ACTIONS(5504),
    [anon_sym_DASH] = ACTIONS(5504),
    [anon_sym_STAR] = ACTIONS(5502),
    [anon_sym_SLASH] = ACTIONS(5504),
    [anon_sym_PERCENT] = ACTIONS(5502),
    [anon_sym_CARET] = ACTIONS(5502),
    [anon_sym_PIPE] = ACTIONS(5504),
    [anon_sym_AMP] = ACTIONS(5504),
    [anon_sym_LT_LT] = ACTIONS(5502),
    [anon_sym_GT_GT] = ACTIONS(5504),
    [anon_sym_GT_GT_GT] = ACTIONS(5502),
    [anon_sym_EQ_EQ] = ACTIONS(5502),
    [anon_sym_BANG_EQ] = ACTIONS(5502),
    [anon_sym_GT_EQ] = ACTIONS(5502),
    [anon_sym_LT_EQ] = ACTIONS(5502),
    [anon_sym_DOT] = ACTIONS(5504),
    [anon_sym_EQ_GT] = ACTIONS(5502),
    [anon_sym_switch] = ACTIONS(5502),
    [anon_sym_when] = ACTIONS(5502),
    [anon_sym_DOT_DOT] = ACTIONS(5502),
    [anon_sym_and] = ACTIONS(5502),
    [anon_sym_or] = ACTIONS(5502),
    [anon_sym_AMP_AMP] = ACTIONS(5502),
    [anon_sym_PIPE_PIPE] = ACTIONS(5502),
    [anon_sym_QMARK_QMARK] = ACTIONS(5502),
    [anon_sym_on] = ACTIONS(5502),
    [anon_sym_equals] = ACTIONS(5502),
    [anon_sym_by] = ACTIONS(5502),
    [anon_sym_as] = ACTIONS(5502),
    [anon_sym_is] = ACTIONS(5502),
    [anon_sym_DASH_GT] = ACTIONS(5502),
    [anon_sym_with] = ACTIONS(5502),
    [aux_sym_preproc_if_token3] = ACTIONS(5502),
    [aux_sym_preproc_else_token1] = ACTIONS(5502),
    [aux_sym_preproc_elif_token1] = ACTIONS(5502),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4109] = {
    [sym_preproc_region] = STATE(4109),
    [sym_preproc_endregion] = STATE(4109),
    [sym_preproc_line] = STATE(4109),
    [sym_preproc_pragma] = STATE(4109),
    [sym_preproc_nullable] = STATE(4109),
    [sym_preproc_error] = STATE(4109),
    [sym_preproc_warning] = STATE(4109),
    [sym_preproc_define] = STATE(4109),
    [sym_preproc_undef] = STATE(4109),
    [anon_sym_SEMI] = ACTIONS(5534),
    [anon_sym_LBRACK] = ACTIONS(5534),
    [anon_sym_COLON] = ACTIONS(5534),
    [anon_sym_COMMA] = ACTIONS(5534),
    [anon_sym_RBRACK] = ACTIONS(5534),
    [anon_sym_LPAREN] = ACTIONS(5534),
    [anon_sym_RPAREN] = ACTIONS(5534),
    [anon_sym_RBRACE] = ACTIONS(5534),
    [anon_sym_LT] = ACTIONS(5536),
    [anon_sym_GT] = ACTIONS(5536),
    [anon_sym_in] = ACTIONS(5534),
    [anon_sym_QMARK] = ACTIONS(5536),
    [anon_sym_BANG] = ACTIONS(5536),
    [anon_sym_PLUS_PLUS] = ACTIONS(5534),
    [anon_sym_DASH_DASH] = ACTIONS(5534),
    [anon_sym_PLUS] = ACTIONS(5536),
    [anon_sym_DASH] = ACTIONS(5536),
    [anon_sym_STAR] = ACTIONS(5534),
    [anon_sym_SLASH] = ACTIONS(5536),
    [anon_sym_PERCENT] = ACTIONS(5534),
    [anon_sym_CARET] = ACTIONS(5534),
    [anon_sym_PIPE] = ACTIONS(5536),
    [anon_sym_AMP] = ACTIONS(5536),
    [anon_sym_LT_LT] = ACTIONS(5534),
    [anon_sym_GT_GT] = ACTIONS(5536),
    [anon_sym_GT_GT_GT] = ACTIONS(5534),
    [anon_sym_EQ_EQ] = ACTIONS(5534),
    [anon_sym_BANG_EQ] = ACTIONS(5534),
    [anon_sym_GT_EQ] = ACTIONS(5534),
    [anon_sym_LT_EQ] = ACTIONS(5534),
    [anon_sym_DOT] = ACTIONS(5536),
    [anon_sym_EQ_GT] = ACTIONS(5534),
    [anon_sym_switch] = ACTIONS(5534),
    [anon_sym_when] = ACTIONS(5534),
    [anon_sym_DOT_DOT] = ACTIONS(5534),
    [anon_sym_and] = ACTIONS(5534),
    [anon_sym_or] = ACTIONS(5534),
    [anon_sym_AMP_AMP] = ACTIONS(5534),
    [anon_sym_PIPE_PIPE] = ACTIONS(5534),
    [anon_sym_QMARK_QMARK] = ACTIONS(5534),
    [anon_sym_on] = ACTIONS(5534),
    [anon_sym_equals] = ACTIONS(5534),
    [anon_sym_by] = ACTIONS(5534),
    [anon_sym_as] = ACTIONS(5534),
    [anon_sym_is] = ACTIONS(5534),
    [anon_sym_DASH_GT] = ACTIONS(5534),
    [anon_sym_with] = ACTIONS(5534),
    [aux_sym_preproc_if_token3] = ACTIONS(5534),
    [aux_sym_preproc_else_token1] = ACTIONS(5534),
    [aux_sym_preproc_elif_token1] = ACTIONS(5534),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4110] = {
    [sym_preproc_region] = STATE(4110),
    [sym_preproc_endregion] = STATE(4110),
    [sym_preproc_line] = STATE(4110),
    [sym_preproc_pragma] = STATE(4110),
    [sym_preproc_nullable] = STATE(4110),
    [sym_preproc_error] = STATE(4110),
    [sym_preproc_warning] = STATE(4110),
    [sym_preproc_define] = STATE(4110),
    [sym_preproc_undef] = STATE(4110),
    [anon_sym_SEMI] = ACTIONS(5620),
    [anon_sym_LBRACK] = ACTIONS(5620),
    [anon_sym_COLON] = ACTIONS(5620),
    [anon_sym_COMMA] = ACTIONS(5620),
    [anon_sym_RBRACK] = ACTIONS(5620),
    [anon_sym_LPAREN] = ACTIONS(5620),
    [anon_sym_RPAREN] = ACTIONS(5620),
    [anon_sym_RBRACE] = ACTIONS(5620),
    [anon_sym_LT] = ACTIONS(5622),
    [anon_sym_GT] = ACTIONS(5622),
    [anon_sym_in] = ACTIONS(5620),
    [anon_sym_QMARK] = ACTIONS(5622),
    [anon_sym_BANG] = ACTIONS(5622),
    [anon_sym_PLUS_PLUS] = ACTIONS(5620),
    [anon_sym_DASH_DASH] = ACTIONS(5620),
    [anon_sym_PLUS] = ACTIONS(5622),
    [anon_sym_DASH] = ACTIONS(5622),
    [anon_sym_STAR] = ACTIONS(5620),
    [anon_sym_SLASH] = ACTIONS(5622),
    [anon_sym_PERCENT] = ACTIONS(5620),
    [anon_sym_CARET] = ACTIONS(5620),
    [anon_sym_PIPE] = ACTIONS(5622),
    [anon_sym_AMP] = ACTIONS(5622),
    [anon_sym_LT_LT] = ACTIONS(5620),
    [anon_sym_GT_GT] = ACTIONS(5622),
    [anon_sym_GT_GT_GT] = ACTIONS(5620),
    [anon_sym_EQ_EQ] = ACTIONS(5620),
    [anon_sym_BANG_EQ] = ACTIONS(5620),
    [anon_sym_GT_EQ] = ACTIONS(5620),
    [anon_sym_LT_EQ] = ACTIONS(5620),
    [anon_sym_DOT] = ACTIONS(5622),
    [anon_sym_EQ_GT] = ACTIONS(5620),
    [anon_sym_switch] = ACTIONS(5620),
    [anon_sym_when] = ACTIONS(5620),
    [anon_sym_DOT_DOT] = ACTIONS(5620),
    [anon_sym_and] = ACTIONS(5620),
    [anon_sym_or] = ACTIONS(5620),
    [anon_sym_AMP_AMP] = ACTIONS(5620),
    [anon_sym_PIPE_PIPE] = ACTIONS(5620),
    [anon_sym_QMARK_QMARK] = ACTIONS(5620),
    [anon_sym_on] = ACTIONS(5620),
    [anon_sym_equals] = ACTIONS(5620),
    [anon_sym_by] = ACTIONS(5620),
    [anon_sym_as] = ACTIONS(5620),
    [anon_sym_is] = ACTIONS(5620),
    [anon_sym_DASH_GT] = ACTIONS(5620),
    [anon_sym_with] = ACTIONS(5620),
    [aux_sym_preproc_if_token3] = ACTIONS(5620),
    [aux_sym_preproc_else_token1] = ACTIONS(5620),
    [aux_sym_preproc_elif_token1] = ACTIONS(5620),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4111] = {
    [sym_preproc_region] = STATE(4111),
    [sym_preproc_endregion] = STATE(4111),
    [sym_preproc_line] = STATE(4111),
    [sym_preproc_pragma] = STATE(4111),
    [sym_preproc_nullable] = STATE(4111),
    [sym_preproc_error] = STATE(4111),
    [sym_preproc_warning] = STATE(4111),
    [sym_preproc_define] = STATE(4111),
    [sym_preproc_undef] = STATE(4111),
    [anon_sym_SEMI] = ACTIONS(5624),
    [anon_sym_LBRACK] = ACTIONS(5624),
    [anon_sym_COLON] = ACTIONS(5624),
    [anon_sym_COMMA] = ACTIONS(5624),
    [anon_sym_RBRACK] = ACTIONS(5624),
    [anon_sym_LPAREN] = ACTIONS(5624),
    [anon_sym_RPAREN] = ACTIONS(5624),
    [anon_sym_RBRACE] = ACTIONS(5624),
    [anon_sym_LT] = ACTIONS(5626),
    [anon_sym_GT] = ACTIONS(5626),
    [anon_sym_in] = ACTIONS(5624),
    [anon_sym_QMARK] = ACTIONS(5626),
    [anon_sym_BANG] = ACTIONS(5626),
    [anon_sym_PLUS_PLUS] = ACTIONS(5624),
    [anon_sym_DASH_DASH] = ACTIONS(5624),
    [anon_sym_PLUS] = ACTIONS(5626),
    [anon_sym_DASH] = ACTIONS(5626),
    [anon_sym_STAR] = ACTIONS(5624),
    [anon_sym_SLASH] = ACTIONS(5626),
    [anon_sym_PERCENT] = ACTIONS(5624),
    [anon_sym_CARET] = ACTIONS(5624),
    [anon_sym_PIPE] = ACTIONS(5626),
    [anon_sym_AMP] = ACTIONS(5626),
    [anon_sym_LT_LT] = ACTIONS(5624),
    [anon_sym_GT_GT] = ACTIONS(5626),
    [anon_sym_GT_GT_GT] = ACTIONS(5624),
    [anon_sym_EQ_EQ] = ACTIONS(5624),
    [anon_sym_BANG_EQ] = ACTIONS(5624),
    [anon_sym_GT_EQ] = ACTIONS(5624),
    [anon_sym_LT_EQ] = ACTIONS(5624),
    [anon_sym_DOT] = ACTIONS(5626),
    [anon_sym_EQ_GT] = ACTIONS(5624),
    [anon_sym_switch] = ACTIONS(5624),
    [anon_sym_when] = ACTIONS(5624),
    [anon_sym_DOT_DOT] = ACTIONS(5624),
    [anon_sym_and] = ACTIONS(5624),
    [anon_sym_or] = ACTIONS(5624),
    [anon_sym_AMP_AMP] = ACTIONS(5624),
    [anon_sym_PIPE_PIPE] = ACTIONS(5624),
    [anon_sym_QMARK_QMARK] = ACTIONS(5624),
    [anon_sym_on] = ACTIONS(5624),
    [anon_sym_equals] = ACTIONS(5624),
    [anon_sym_by] = ACTIONS(5624),
    [anon_sym_as] = ACTIONS(5624),
    [anon_sym_is] = ACTIONS(5624),
    [anon_sym_DASH_GT] = ACTIONS(5624),
    [anon_sym_with] = ACTIONS(5624),
    [aux_sym_preproc_if_token3] = ACTIONS(5624),
    [aux_sym_preproc_else_token1] = ACTIONS(5624),
    [aux_sym_preproc_elif_token1] = ACTIONS(5624),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4112] = {
    [sym_preproc_region] = STATE(4112),
    [sym_preproc_endregion] = STATE(4112),
    [sym_preproc_line] = STATE(4112),
    [sym_preproc_pragma] = STATE(4112),
    [sym_preproc_nullable] = STATE(4112),
    [sym_preproc_error] = STATE(4112),
    [sym_preproc_warning] = STATE(4112),
    [sym_preproc_define] = STATE(4112),
    [sym_preproc_undef] = STATE(4112),
    [anon_sym_SEMI] = ACTIONS(5656),
    [anon_sym_LBRACK] = ACTIONS(5656),
    [anon_sym_COLON] = ACTIONS(5656),
    [anon_sym_COMMA] = ACTIONS(5656),
    [anon_sym_RBRACK] = ACTIONS(5656),
    [anon_sym_LPAREN] = ACTIONS(5656),
    [anon_sym_RPAREN] = ACTIONS(5656),
    [anon_sym_RBRACE] = ACTIONS(5656),
    [anon_sym_LT] = ACTIONS(5658),
    [anon_sym_GT] = ACTIONS(5658),
    [anon_sym_in] = ACTIONS(5656),
    [anon_sym_QMARK] = ACTIONS(5658),
    [anon_sym_BANG] = ACTIONS(5658),
    [anon_sym_PLUS_PLUS] = ACTIONS(5656),
    [anon_sym_DASH_DASH] = ACTIONS(5656),
    [anon_sym_PLUS] = ACTIONS(5658),
    [anon_sym_DASH] = ACTIONS(5658),
    [anon_sym_STAR] = ACTIONS(5656),
    [anon_sym_SLASH] = ACTIONS(5658),
    [anon_sym_PERCENT] = ACTIONS(5656),
    [anon_sym_CARET] = ACTIONS(5656),
    [anon_sym_PIPE] = ACTIONS(5658),
    [anon_sym_AMP] = ACTIONS(5658),
    [anon_sym_LT_LT] = ACTIONS(5656),
    [anon_sym_GT_GT] = ACTIONS(5658),
    [anon_sym_GT_GT_GT] = ACTIONS(5656),
    [anon_sym_EQ_EQ] = ACTIONS(5656),
    [anon_sym_BANG_EQ] = ACTIONS(5656),
    [anon_sym_GT_EQ] = ACTIONS(5656),
    [anon_sym_LT_EQ] = ACTIONS(5656),
    [anon_sym_DOT] = ACTIONS(5658),
    [anon_sym_EQ_GT] = ACTIONS(5656),
    [anon_sym_switch] = ACTIONS(5656),
    [anon_sym_when] = ACTIONS(5656),
    [anon_sym_DOT_DOT] = ACTIONS(5656),
    [anon_sym_and] = ACTIONS(5656),
    [anon_sym_or] = ACTIONS(5656),
    [anon_sym_AMP_AMP] = ACTIONS(5656),
    [anon_sym_PIPE_PIPE] = ACTIONS(5656),
    [anon_sym_QMARK_QMARK] = ACTIONS(5656),
    [anon_sym_on] = ACTIONS(5656),
    [anon_sym_equals] = ACTIONS(5656),
    [anon_sym_by] = ACTIONS(5656),
    [anon_sym_as] = ACTIONS(5656),
    [anon_sym_is] = ACTIONS(5656),
    [anon_sym_DASH_GT] = ACTIONS(5656),
    [anon_sym_with] = ACTIONS(5656),
    [aux_sym_preproc_if_token3] = ACTIONS(5656),
    [aux_sym_preproc_else_token1] = ACTIONS(5656),
    [aux_sym_preproc_elif_token1] = ACTIONS(5656),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4113] = {
    [sym_preproc_region] = STATE(4113),
    [sym_preproc_endregion] = STATE(4113),
    [sym_preproc_line] = STATE(4113),
    [sym_preproc_pragma] = STATE(4113),
    [sym_preproc_nullable] = STATE(4113),
    [sym_preproc_error] = STATE(4113),
    [sym_preproc_warning] = STATE(4113),
    [sym_preproc_define] = STATE(4113),
    [sym_preproc_undef] = STATE(4113),
    [anon_sym_SEMI] = ACTIONS(5636),
    [anon_sym_LBRACK] = ACTIONS(5636),
    [anon_sym_COLON] = ACTIONS(5636),
    [anon_sym_COMMA] = ACTIONS(5636),
    [anon_sym_RBRACK] = ACTIONS(5636),
    [anon_sym_LPAREN] = ACTIONS(5636),
    [anon_sym_RPAREN] = ACTIONS(5636),
    [anon_sym_RBRACE] = ACTIONS(5636),
    [anon_sym_LT] = ACTIONS(5638),
    [anon_sym_GT] = ACTIONS(5638),
    [anon_sym_in] = ACTIONS(5636),
    [anon_sym_QMARK] = ACTIONS(5638),
    [anon_sym_BANG] = ACTIONS(5638),
    [anon_sym_PLUS_PLUS] = ACTIONS(5636),
    [anon_sym_DASH_DASH] = ACTIONS(5636),
    [anon_sym_PLUS] = ACTIONS(5638),
    [anon_sym_DASH] = ACTIONS(5638),
    [anon_sym_STAR] = ACTIONS(5636),
    [anon_sym_SLASH] = ACTIONS(5638),
    [anon_sym_PERCENT] = ACTIONS(5636),
    [anon_sym_CARET] = ACTIONS(5636),
    [anon_sym_PIPE] = ACTIONS(5638),
    [anon_sym_AMP] = ACTIONS(5638),
    [anon_sym_LT_LT] = ACTIONS(5636),
    [anon_sym_GT_GT] = ACTIONS(5638),
    [anon_sym_GT_GT_GT] = ACTIONS(5636),
    [anon_sym_EQ_EQ] = ACTIONS(5636),
    [anon_sym_BANG_EQ] = ACTIONS(5636),
    [anon_sym_GT_EQ] = ACTIONS(5636),
    [anon_sym_LT_EQ] = ACTIONS(5636),
    [anon_sym_DOT] = ACTIONS(5638),
    [anon_sym_EQ_GT] = ACTIONS(5636),
    [anon_sym_switch] = ACTIONS(5636),
    [anon_sym_when] = ACTIONS(5636),
    [anon_sym_DOT_DOT] = ACTIONS(5636),
    [anon_sym_and] = ACTIONS(5636),
    [anon_sym_or] = ACTIONS(5636),
    [anon_sym_AMP_AMP] = ACTIONS(5636),
    [anon_sym_PIPE_PIPE] = ACTIONS(5636),
    [anon_sym_QMARK_QMARK] = ACTIONS(5636),
    [anon_sym_on] = ACTIONS(5636),
    [anon_sym_equals] = ACTIONS(5636),
    [anon_sym_by] = ACTIONS(5636),
    [anon_sym_as] = ACTIONS(5636),
    [anon_sym_is] = ACTIONS(5636),
    [anon_sym_DASH_GT] = ACTIONS(5636),
    [anon_sym_with] = ACTIONS(5636),
    [aux_sym_preproc_if_token3] = ACTIONS(5636),
    [aux_sym_preproc_else_token1] = ACTIONS(5636),
    [aux_sym_preproc_elif_token1] = ACTIONS(5636),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4114] = {
    [sym_preproc_region] = STATE(4114),
    [sym_preproc_endregion] = STATE(4114),
    [sym_preproc_line] = STATE(4114),
    [sym_preproc_pragma] = STATE(4114),
    [sym_preproc_nullable] = STATE(4114),
    [sym_preproc_error] = STATE(4114),
    [sym_preproc_warning] = STATE(4114),
    [sym_preproc_define] = STATE(4114),
    [sym_preproc_undef] = STATE(4114),
    [anon_sym_SEMI] = ACTIONS(5664),
    [anon_sym_LBRACK] = ACTIONS(5664),
    [anon_sym_COLON] = ACTIONS(5664),
    [anon_sym_COMMA] = ACTIONS(5664),
    [anon_sym_RBRACK] = ACTIONS(5664),
    [anon_sym_LPAREN] = ACTIONS(5664),
    [anon_sym_RPAREN] = ACTIONS(5664),
    [anon_sym_RBRACE] = ACTIONS(5664),
    [anon_sym_LT] = ACTIONS(5666),
    [anon_sym_GT] = ACTIONS(5666),
    [anon_sym_in] = ACTIONS(5664),
    [anon_sym_QMARK] = ACTIONS(5666),
    [anon_sym_BANG] = ACTIONS(5666),
    [anon_sym_PLUS_PLUS] = ACTIONS(5664),
    [anon_sym_DASH_DASH] = ACTIONS(5664),
    [anon_sym_PLUS] = ACTIONS(5666),
    [anon_sym_DASH] = ACTIONS(5666),
    [anon_sym_STAR] = ACTIONS(5664),
    [anon_sym_SLASH] = ACTIONS(5666),
    [anon_sym_PERCENT] = ACTIONS(5664),
    [anon_sym_CARET] = ACTIONS(5664),
    [anon_sym_PIPE] = ACTIONS(5666),
    [anon_sym_AMP] = ACTIONS(5666),
    [anon_sym_LT_LT] = ACTIONS(5664),
    [anon_sym_GT_GT] = ACTIONS(5666),
    [anon_sym_GT_GT_GT] = ACTIONS(5664),
    [anon_sym_EQ_EQ] = ACTIONS(5664),
    [anon_sym_BANG_EQ] = ACTIONS(5664),
    [anon_sym_GT_EQ] = ACTIONS(5664),
    [anon_sym_LT_EQ] = ACTIONS(5664),
    [anon_sym_DOT] = ACTIONS(5666),
    [anon_sym_EQ_GT] = ACTIONS(5664),
    [anon_sym_switch] = ACTIONS(5664),
    [anon_sym_when] = ACTIONS(5664),
    [anon_sym_DOT_DOT] = ACTIONS(5664),
    [anon_sym_and] = ACTIONS(5664),
    [anon_sym_or] = ACTIONS(5664),
    [anon_sym_AMP_AMP] = ACTIONS(5664),
    [anon_sym_PIPE_PIPE] = ACTIONS(5664),
    [anon_sym_QMARK_QMARK] = ACTIONS(5664),
    [anon_sym_on] = ACTIONS(5664),
    [anon_sym_equals] = ACTIONS(5664),
    [anon_sym_by] = ACTIONS(5664),
    [anon_sym_as] = ACTIONS(5664),
    [anon_sym_is] = ACTIONS(5664),
    [anon_sym_DASH_GT] = ACTIONS(5664),
    [anon_sym_with] = ACTIONS(5664),
    [aux_sym_preproc_if_token3] = ACTIONS(5664),
    [aux_sym_preproc_else_token1] = ACTIONS(5664),
    [aux_sym_preproc_elif_token1] = ACTIONS(5664),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4115] = {
    [sym_preproc_region] = STATE(4115),
    [sym_preproc_endregion] = STATE(4115),
    [sym_preproc_line] = STATE(4115),
    [sym_preproc_pragma] = STATE(4115),
    [sym_preproc_nullable] = STATE(4115),
    [sym_preproc_error] = STATE(4115),
    [sym_preproc_warning] = STATE(4115),
    [sym_preproc_define] = STATE(4115),
    [sym_preproc_undef] = STATE(4115),
    [anon_sym_SEMI] = ACTIONS(5632),
    [anon_sym_LBRACK] = ACTIONS(5632),
    [anon_sym_COLON] = ACTIONS(5632),
    [anon_sym_COMMA] = ACTIONS(5632),
    [anon_sym_RBRACK] = ACTIONS(5632),
    [anon_sym_LPAREN] = ACTIONS(5632),
    [anon_sym_RPAREN] = ACTIONS(5632),
    [anon_sym_RBRACE] = ACTIONS(5632),
    [anon_sym_LT] = ACTIONS(5634),
    [anon_sym_GT] = ACTIONS(5634),
    [anon_sym_in] = ACTIONS(5632),
    [anon_sym_QMARK] = ACTIONS(5634),
    [anon_sym_BANG] = ACTIONS(5634),
    [anon_sym_PLUS_PLUS] = ACTIONS(5632),
    [anon_sym_DASH_DASH] = ACTIONS(5632),
    [anon_sym_PLUS] = ACTIONS(5634),
    [anon_sym_DASH] = ACTIONS(5634),
    [anon_sym_STAR] = ACTIONS(5632),
    [anon_sym_SLASH] = ACTIONS(5634),
    [anon_sym_PERCENT] = ACTIONS(5632),
    [anon_sym_CARET] = ACTIONS(5632),
    [anon_sym_PIPE] = ACTIONS(5634),
    [anon_sym_AMP] = ACTIONS(5634),
    [anon_sym_LT_LT] = ACTIONS(5632),
    [anon_sym_GT_GT] = ACTIONS(5634),
    [anon_sym_GT_GT_GT] = ACTIONS(5632),
    [anon_sym_EQ_EQ] = ACTIONS(5632),
    [anon_sym_BANG_EQ] = ACTIONS(5632),
    [anon_sym_GT_EQ] = ACTIONS(5632),
    [anon_sym_LT_EQ] = ACTIONS(5632),
    [anon_sym_DOT] = ACTIONS(5634),
    [anon_sym_EQ_GT] = ACTIONS(5632),
    [anon_sym_switch] = ACTIONS(5632),
    [anon_sym_when] = ACTIONS(5632),
    [anon_sym_DOT_DOT] = ACTIONS(5632),
    [anon_sym_and] = ACTIONS(5632),
    [anon_sym_or] = ACTIONS(5632),
    [anon_sym_AMP_AMP] = ACTIONS(5632),
    [anon_sym_PIPE_PIPE] = ACTIONS(5632),
    [anon_sym_QMARK_QMARK] = ACTIONS(5632),
    [anon_sym_on] = ACTIONS(5632),
    [anon_sym_equals] = ACTIONS(5632),
    [anon_sym_by] = ACTIONS(5632),
    [anon_sym_as] = ACTIONS(5632),
    [anon_sym_is] = ACTIONS(5632),
    [anon_sym_DASH_GT] = ACTIONS(5632),
    [anon_sym_with] = ACTIONS(5632),
    [aux_sym_preproc_if_token3] = ACTIONS(5632),
    [aux_sym_preproc_else_token1] = ACTIONS(5632),
    [aux_sym_preproc_elif_token1] = ACTIONS(5632),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4116] = {
    [sym_preproc_region] = STATE(4116),
    [sym_preproc_endregion] = STATE(4116),
    [sym_preproc_line] = STATE(4116),
    [sym_preproc_pragma] = STATE(4116),
    [sym_preproc_nullable] = STATE(4116),
    [sym_preproc_error] = STATE(4116),
    [sym_preproc_warning] = STATE(4116),
    [sym_preproc_define] = STATE(4116),
    [sym_preproc_undef] = STATE(4116),
    [sym__identifier_token] = ACTIONS(4042),
    [anon_sym_extern] = ACTIONS(4042),
    [anon_sym_alias] = ACTIONS(4042),
    [anon_sym_SEMI] = ACTIONS(3993),
    [anon_sym_global] = ACTIONS(4042),
    [anon_sym_unsafe] = ACTIONS(4042),
    [anon_sym_static] = ACTIONS(4042),
    [anon_sym_LBRACE] = ACTIONS(3993),
    [anon_sym_abstract] = ACTIONS(4042),
    [anon_sym_async] = ACTIONS(4042),
    [anon_sym_const] = ACTIONS(4042),
    [anon_sym_file] = ACTIONS(4042),
    [anon_sym_fixed] = ACTIONS(4042),
    [anon_sym_internal] = ACTIONS(4042),
    [anon_sym_new] = ACTIONS(4042),
    [anon_sym_override] = ACTIONS(4042),
    [anon_sym_partial] = ACTIONS(4042),
    [anon_sym_private] = ACTIONS(4042),
    [anon_sym_protected] = ACTIONS(4042),
    [anon_sym_public] = ACTIONS(4042),
    [anon_sym_readonly] = ACTIONS(4042),
    [anon_sym_required] = ACTIONS(4042),
    [anon_sym_sealed] = ACTIONS(4042),
    [anon_sym_virtual] = ACTIONS(4042),
    [anon_sym_volatile] = ACTIONS(4042),
    [anon_sym_where] = ACTIONS(4042),
    [anon_sym_notnull] = ACTIONS(4042),
    [anon_sym_unmanaged] = ACTIONS(4042),
    [anon_sym_get] = ACTIONS(4042),
    [anon_sym_set] = ACTIONS(4042),
    [anon_sym_add] = ACTIONS(4042),
    [anon_sym_remove] = ACTIONS(4042),
    [anon_sym_init] = ACTIONS(4042),
    [anon_sym_scoped] = ACTIONS(4042),
    [anon_sym_EQ_GT] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(4042),
    [anon_sym_yield] = ACTIONS(4042),
    [anon_sym_when] = ACTIONS(4042),
    [anon_sym_from] = ACTIONS(4042),
    [anon_sym_into] = ACTIONS(4042),
    [anon_sym_join] = ACTIONS(4042),
    [anon_sym_on] = ACTIONS(4042),
    [anon_sym_equals] = ACTIONS(4042),
    [anon_sym_let] = ACTIONS(4042),
    [anon_sym_orderby] = ACTIONS(4042),
    [anon_sym_ascending] = ACTIONS(4042),
    [anon_sym_descending] = ACTIONS(4042),
    [anon_sym_group] = ACTIONS(4042),
    [anon_sym_by] = ACTIONS(4042),
    [anon_sym_select] = ACTIONS(4042),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4117] = {
    [sym_preproc_region] = STATE(4117),
    [sym_preproc_endregion] = STATE(4117),
    [sym_preproc_line] = STATE(4117),
    [sym_preproc_pragma] = STATE(4117),
    [sym_preproc_nullable] = STATE(4117),
    [sym_preproc_error] = STATE(4117),
    [sym_preproc_warning] = STATE(4117),
    [sym_preproc_define] = STATE(4117),
    [sym_preproc_undef] = STATE(4117),
    [anon_sym_SEMI] = ACTIONS(5869),
    [anon_sym_LBRACK] = ACTIONS(5869),
    [anon_sym_COLON] = ACTIONS(5869),
    [anon_sym_COMMA] = ACTIONS(5869),
    [anon_sym_RBRACK] = ACTIONS(5869),
    [anon_sym_LPAREN] = ACTIONS(5869),
    [anon_sym_RPAREN] = ACTIONS(5869),
    [anon_sym_RBRACE] = ACTIONS(5869),
    [anon_sym_LT] = ACTIONS(5871),
    [anon_sym_GT] = ACTIONS(5871),
    [anon_sym_in] = ACTIONS(5869),
    [anon_sym_QMARK] = ACTIONS(5871),
    [anon_sym_BANG] = ACTIONS(5871),
    [anon_sym_PLUS_PLUS] = ACTIONS(5869),
    [anon_sym_DASH_DASH] = ACTIONS(5869),
    [anon_sym_PLUS] = ACTIONS(5871),
    [anon_sym_DASH] = ACTIONS(5871),
    [anon_sym_STAR] = ACTIONS(5869),
    [anon_sym_SLASH] = ACTIONS(5871),
    [anon_sym_PERCENT] = ACTIONS(5869),
    [anon_sym_CARET] = ACTIONS(5869),
    [anon_sym_PIPE] = ACTIONS(5871),
    [anon_sym_AMP] = ACTIONS(5871),
    [anon_sym_LT_LT] = ACTIONS(5869),
    [anon_sym_GT_GT] = ACTIONS(5871),
    [anon_sym_GT_GT_GT] = ACTIONS(5869),
    [anon_sym_EQ_EQ] = ACTIONS(5869),
    [anon_sym_BANG_EQ] = ACTIONS(5869),
    [anon_sym_GT_EQ] = ACTIONS(5869),
    [anon_sym_LT_EQ] = ACTIONS(5869),
    [anon_sym_DOT] = ACTIONS(5871),
    [anon_sym_EQ_GT] = ACTIONS(5869),
    [anon_sym_switch] = ACTIONS(5869),
    [anon_sym_when] = ACTIONS(5869),
    [anon_sym_DOT_DOT] = ACTIONS(5869),
    [anon_sym_and] = ACTIONS(5869),
    [anon_sym_or] = ACTIONS(5869),
    [anon_sym_AMP_AMP] = ACTIONS(5869),
    [anon_sym_PIPE_PIPE] = ACTIONS(5869),
    [anon_sym_QMARK_QMARK] = ACTIONS(5869),
    [anon_sym_on] = ACTIONS(5869),
    [anon_sym_equals] = ACTIONS(5869),
    [anon_sym_by] = ACTIONS(5869),
    [anon_sym_as] = ACTIONS(5869),
    [anon_sym_is] = ACTIONS(5869),
    [anon_sym_DASH_GT] = ACTIONS(5869),
    [anon_sym_with] = ACTIONS(5869),
    [aux_sym_preproc_if_token3] = ACTIONS(5869),
    [aux_sym_preproc_else_token1] = ACTIONS(5869),
    [aux_sym_preproc_elif_token1] = ACTIONS(5869),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4118] = {
    [sym_preproc_region] = STATE(4118),
    [sym_preproc_endregion] = STATE(4118),
    [sym_preproc_line] = STATE(4118),
    [sym_preproc_pragma] = STATE(4118),
    [sym_preproc_nullable] = STATE(4118),
    [sym_preproc_error] = STATE(4118),
    [sym_preproc_warning] = STATE(4118),
    [sym_preproc_define] = STATE(4118),
    [sym_preproc_undef] = STATE(4118),
    [anon_sym_SEMI] = ACTIONS(5640),
    [anon_sym_LBRACK] = ACTIONS(5640),
    [anon_sym_COLON] = ACTIONS(5640),
    [anon_sym_COMMA] = ACTIONS(5640),
    [anon_sym_RBRACK] = ACTIONS(5640),
    [anon_sym_LPAREN] = ACTIONS(5640),
    [anon_sym_RPAREN] = ACTIONS(5640),
    [anon_sym_RBRACE] = ACTIONS(5640),
    [anon_sym_LT] = ACTIONS(5642),
    [anon_sym_GT] = ACTIONS(5642),
    [anon_sym_in] = ACTIONS(5640),
    [anon_sym_QMARK] = ACTIONS(5642),
    [anon_sym_BANG] = ACTIONS(5642),
    [anon_sym_PLUS_PLUS] = ACTIONS(5640),
    [anon_sym_DASH_DASH] = ACTIONS(5640),
    [anon_sym_PLUS] = ACTIONS(5642),
    [anon_sym_DASH] = ACTIONS(5642),
    [anon_sym_STAR] = ACTIONS(5640),
    [anon_sym_SLASH] = ACTIONS(5642),
    [anon_sym_PERCENT] = ACTIONS(5640),
    [anon_sym_CARET] = ACTIONS(5640),
    [anon_sym_PIPE] = ACTIONS(5642),
    [anon_sym_AMP] = ACTIONS(5642),
    [anon_sym_LT_LT] = ACTIONS(5640),
    [anon_sym_GT_GT] = ACTIONS(5642),
    [anon_sym_GT_GT_GT] = ACTIONS(5640),
    [anon_sym_EQ_EQ] = ACTIONS(5640),
    [anon_sym_BANG_EQ] = ACTIONS(5640),
    [anon_sym_GT_EQ] = ACTIONS(5640),
    [anon_sym_LT_EQ] = ACTIONS(5640),
    [anon_sym_DOT] = ACTIONS(5642),
    [anon_sym_EQ_GT] = ACTIONS(5640),
    [anon_sym_switch] = ACTIONS(5640),
    [anon_sym_when] = ACTIONS(5640),
    [anon_sym_DOT_DOT] = ACTIONS(5640),
    [anon_sym_and] = ACTIONS(5640),
    [anon_sym_or] = ACTIONS(5640),
    [anon_sym_AMP_AMP] = ACTIONS(5640),
    [anon_sym_PIPE_PIPE] = ACTIONS(5640),
    [anon_sym_QMARK_QMARK] = ACTIONS(5640),
    [anon_sym_on] = ACTIONS(5640),
    [anon_sym_equals] = ACTIONS(5640),
    [anon_sym_by] = ACTIONS(5640),
    [anon_sym_as] = ACTIONS(5640),
    [anon_sym_is] = ACTIONS(5640),
    [anon_sym_DASH_GT] = ACTIONS(5640),
    [anon_sym_with] = ACTIONS(5640),
    [aux_sym_preproc_if_token3] = ACTIONS(5640),
    [aux_sym_preproc_else_token1] = ACTIONS(5640),
    [aux_sym_preproc_elif_token1] = ACTIONS(5640),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4119] = {
    [sym_preproc_region] = STATE(4119),
    [sym_preproc_endregion] = STATE(4119),
    [sym_preproc_line] = STATE(4119),
    [sym_preproc_pragma] = STATE(4119),
    [sym_preproc_nullable] = STATE(4119),
    [sym_preproc_error] = STATE(4119),
    [sym_preproc_warning] = STATE(4119),
    [sym_preproc_define] = STATE(4119),
    [sym_preproc_undef] = STATE(4119),
    [anon_sym_SEMI] = ACTIONS(5644),
    [anon_sym_LBRACK] = ACTIONS(5644),
    [anon_sym_COLON] = ACTIONS(5644),
    [anon_sym_COMMA] = ACTIONS(5644),
    [anon_sym_RBRACK] = ACTIONS(5644),
    [anon_sym_LPAREN] = ACTIONS(5644),
    [anon_sym_RPAREN] = ACTIONS(5644),
    [anon_sym_RBRACE] = ACTIONS(5644),
    [anon_sym_LT] = ACTIONS(5646),
    [anon_sym_GT] = ACTIONS(5646),
    [anon_sym_in] = ACTIONS(5644),
    [anon_sym_QMARK] = ACTIONS(5646),
    [anon_sym_BANG] = ACTIONS(5646),
    [anon_sym_PLUS_PLUS] = ACTIONS(5644),
    [anon_sym_DASH_DASH] = ACTIONS(5644),
    [anon_sym_PLUS] = ACTIONS(5646),
    [anon_sym_DASH] = ACTIONS(5646),
    [anon_sym_STAR] = ACTIONS(5644),
    [anon_sym_SLASH] = ACTIONS(5646),
    [anon_sym_PERCENT] = ACTIONS(5644),
    [anon_sym_CARET] = ACTIONS(5644),
    [anon_sym_PIPE] = ACTIONS(5646),
    [anon_sym_AMP] = ACTIONS(5646),
    [anon_sym_LT_LT] = ACTIONS(5644),
    [anon_sym_GT_GT] = ACTIONS(5646),
    [anon_sym_GT_GT_GT] = ACTIONS(5644),
    [anon_sym_EQ_EQ] = ACTIONS(5644),
    [anon_sym_BANG_EQ] = ACTIONS(5644),
    [anon_sym_GT_EQ] = ACTIONS(5644),
    [anon_sym_LT_EQ] = ACTIONS(5644),
    [anon_sym_DOT] = ACTIONS(5646),
    [anon_sym_EQ_GT] = ACTIONS(5644),
    [anon_sym_switch] = ACTIONS(5644),
    [anon_sym_when] = ACTIONS(5644),
    [anon_sym_DOT_DOT] = ACTIONS(5644),
    [anon_sym_and] = ACTIONS(5644),
    [anon_sym_or] = ACTIONS(5644),
    [anon_sym_AMP_AMP] = ACTIONS(5644),
    [anon_sym_PIPE_PIPE] = ACTIONS(5644),
    [anon_sym_QMARK_QMARK] = ACTIONS(5644),
    [anon_sym_on] = ACTIONS(5644),
    [anon_sym_equals] = ACTIONS(5644),
    [anon_sym_by] = ACTIONS(5644),
    [anon_sym_as] = ACTIONS(5644),
    [anon_sym_is] = ACTIONS(5644),
    [anon_sym_DASH_GT] = ACTIONS(5644),
    [anon_sym_with] = ACTIONS(5644),
    [aux_sym_preproc_if_token3] = ACTIONS(5644),
    [aux_sym_preproc_else_token1] = ACTIONS(5644),
    [aux_sym_preproc_elif_token1] = ACTIONS(5644),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4120] = {
    [sym_preproc_region] = STATE(4120),
    [sym_preproc_endregion] = STATE(4120),
    [sym_preproc_line] = STATE(4120),
    [sym_preproc_pragma] = STATE(4120),
    [sym_preproc_nullable] = STATE(4120),
    [sym_preproc_error] = STATE(4120),
    [sym_preproc_warning] = STATE(4120),
    [sym_preproc_define] = STATE(4120),
    [sym_preproc_undef] = STATE(4120),
    [anon_sym_SEMI] = ACTIONS(5875),
    [anon_sym_LBRACK] = ACTIONS(5875),
    [anon_sym_COLON] = ACTIONS(5875),
    [anon_sym_COMMA] = ACTIONS(5875),
    [anon_sym_RBRACK] = ACTIONS(5875),
    [anon_sym_LPAREN] = ACTIONS(5875),
    [anon_sym_RPAREN] = ACTIONS(5875),
    [anon_sym_RBRACE] = ACTIONS(5875),
    [anon_sym_LT] = ACTIONS(5877),
    [anon_sym_GT] = ACTIONS(5877),
    [anon_sym_in] = ACTIONS(5875),
    [anon_sym_QMARK] = ACTIONS(5877),
    [anon_sym_BANG] = ACTIONS(5877),
    [anon_sym_PLUS_PLUS] = ACTIONS(5875),
    [anon_sym_DASH_DASH] = ACTIONS(5875),
    [anon_sym_PLUS] = ACTIONS(5877),
    [anon_sym_DASH] = ACTIONS(5877),
    [anon_sym_STAR] = ACTIONS(5875),
    [anon_sym_SLASH] = ACTIONS(5877),
    [anon_sym_PERCENT] = ACTIONS(5875),
    [anon_sym_CARET] = ACTIONS(5875),
    [anon_sym_PIPE] = ACTIONS(5877),
    [anon_sym_AMP] = ACTIONS(5877),
    [anon_sym_LT_LT] = ACTIONS(5875),
    [anon_sym_GT_GT] = ACTIONS(5877),
    [anon_sym_GT_GT_GT] = ACTIONS(5875),
    [anon_sym_EQ_EQ] = ACTIONS(5875),
    [anon_sym_BANG_EQ] = ACTIONS(5875),
    [anon_sym_GT_EQ] = ACTIONS(5875),
    [anon_sym_LT_EQ] = ACTIONS(5875),
    [anon_sym_DOT] = ACTIONS(5877),
    [anon_sym_EQ_GT] = ACTIONS(5875),
    [anon_sym_switch] = ACTIONS(5875),
    [anon_sym_when] = ACTIONS(5875),
    [anon_sym_DOT_DOT] = ACTIONS(5875),
    [anon_sym_and] = ACTIONS(5875),
    [anon_sym_or] = ACTIONS(5875),
    [anon_sym_AMP_AMP] = ACTIONS(5875),
    [anon_sym_PIPE_PIPE] = ACTIONS(5875),
    [anon_sym_QMARK_QMARK] = ACTIONS(5875),
    [anon_sym_on] = ACTIONS(5875),
    [anon_sym_equals] = ACTIONS(5875),
    [anon_sym_by] = ACTIONS(5875),
    [anon_sym_as] = ACTIONS(5875),
    [anon_sym_is] = ACTIONS(5875),
    [anon_sym_DASH_GT] = ACTIONS(5875),
    [anon_sym_with] = ACTIONS(5875),
    [aux_sym_preproc_if_token3] = ACTIONS(5875),
    [aux_sym_preproc_else_token1] = ACTIONS(5875),
    [aux_sym_preproc_elif_token1] = ACTIONS(5875),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4121] = {
    [sym_preproc_region] = STATE(4121),
    [sym_preproc_endregion] = STATE(4121),
    [sym_preproc_line] = STATE(4121),
    [sym_preproc_pragma] = STATE(4121),
    [sym_preproc_nullable] = STATE(4121),
    [sym_preproc_error] = STATE(4121),
    [sym_preproc_warning] = STATE(4121),
    [sym_preproc_define] = STATE(4121),
    [sym_preproc_undef] = STATE(4121),
    [anon_sym_SEMI] = ACTIONS(5588),
    [anon_sym_LBRACK] = ACTIONS(5588),
    [anon_sym_COLON] = ACTIONS(5588),
    [anon_sym_COMMA] = ACTIONS(5588),
    [anon_sym_RBRACK] = ACTIONS(5588),
    [anon_sym_LPAREN] = ACTIONS(5588),
    [anon_sym_RPAREN] = ACTIONS(5588),
    [anon_sym_RBRACE] = ACTIONS(5588),
    [anon_sym_LT] = ACTIONS(5590),
    [anon_sym_GT] = ACTIONS(5590),
    [anon_sym_in] = ACTIONS(5588),
    [anon_sym_QMARK] = ACTIONS(5590),
    [anon_sym_BANG] = ACTIONS(5590),
    [anon_sym_PLUS_PLUS] = ACTIONS(5588),
    [anon_sym_DASH_DASH] = ACTIONS(5588),
    [anon_sym_PLUS] = ACTIONS(5590),
    [anon_sym_DASH] = ACTIONS(5590),
    [anon_sym_STAR] = ACTIONS(5588),
    [anon_sym_SLASH] = ACTIONS(5590),
    [anon_sym_PERCENT] = ACTIONS(5588),
    [anon_sym_CARET] = ACTIONS(5588),
    [anon_sym_PIPE] = ACTIONS(5590),
    [anon_sym_AMP] = ACTIONS(5590),
    [anon_sym_LT_LT] = ACTIONS(5588),
    [anon_sym_GT_GT] = ACTIONS(5590),
    [anon_sym_GT_GT_GT] = ACTIONS(5588),
    [anon_sym_EQ_EQ] = ACTIONS(5588),
    [anon_sym_BANG_EQ] = ACTIONS(5588),
    [anon_sym_GT_EQ] = ACTIONS(5588),
    [anon_sym_LT_EQ] = ACTIONS(5588),
    [anon_sym_DOT] = ACTIONS(5590),
    [anon_sym_EQ_GT] = ACTIONS(5588),
    [anon_sym_switch] = ACTIONS(5588),
    [anon_sym_when] = ACTIONS(5588),
    [anon_sym_DOT_DOT] = ACTIONS(5588),
    [anon_sym_and] = ACTIONS(5588),
    [anon_sym_or] = ACTIONS(5588),
    [anon_sym_AMP_AMP] = ACTIONS(5588),
    [anon_sym_PIPE_PIPE] = ACTIONS(5588),
    [anon_sym_QMARK_QMARK] = ACTIONS(5588),
    [anon_sym_on] = ACTIONS(5588),
    [anon_sym_equals] = ACTIONS(5588),
    [anon_sym_by] = ACTIONS(5588),
    [anon_sym_as] = ACTIONS(5588),
    [anon_sym_is] = ACTIONS(5588),
    [anon_sym_DASH_GT] = ACTIONS(5588),
    [anon_sym_with] = ACTIONS(5588),
    [aux_sym_preproc_if_token3] = ACTIONS(5588),
    [aux_sym_preproc_else_token1] = ACTIONS(5588),
    [aux_sym_preproc_elif_token1] = ACTIONS(5588),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4122] = {
    [sym_preproc_region] = STATE(4122),
    [sym_preproc_endregion] = STATE(4122),
    [sym_preproc_line] = STATE(4122),
    [sym_preproc_pragma] = STATE(4122),
    [sym_preproc_nullable] = STATE(4122),
    [sym_preproc_error] = STATE(4122),
    [sym_preproc_warning] = STATE(4122),
    [sym_preproc_define] = STATE(4122),
    [sym_preproc_undef] = STATE(4122),
    [anon_sym_SEMI] = ACTIONS(5942),
    [anon_sym_LBRACK] = ACTIONS(5942),
    [anon_sym_COLON] = ACTIONS(5942),
    [anon_sym_COMMA] = ACTIONS(5942),
    [anon_sym_RBRACK] = ACTIONS(5942),
    [anon_sym_LPAREN] = ACTIONS(5942),
    [anon_sym_RPAREN] = ACTIONS(5942),
    [anon_sym_RBRACE] = ACTIONS(5942),
    [anon_sym_LT] = ACTIONS(5944),
    [anon_sym_GT] = ACTIONS(5944),
    [anon_sym_in] = ACTIONS(5942),
    [anon_sym_QMARK] = ACTIONS(5944),
    [anon_sym_BANG] = ACTIONS(5944),
    [anon_sym_PLUS_PLUS] = ACTIONS(5942),
    [anon_sym_DASH_DASH] = ACTIONS(5942),
    [anon_sym_PLUS] = ACTIONS(5944),
    [anon_sym_DASH] = ACTIONS(5944),
    [anon_sym_STAR] = ACTIONS(5942),
    [anon_sym_SLASH] = ACTIONS(5944),
    [anon_sym_PERCENT] = ACTIONS(5942),
    [anon_sym_CARET] = ACTIONS(5942),
    [anon_sym_PIPE] = ACTIONS(5944),
    [anon_sym_AMP] = ACTIONS(5944),
    [anon_sym_LT_LT] = ACTIONS(5942),
    [anon_sym_GT_GT] = ACTIONS(5944),
    [anon_sym_GT_GT_GT] = ACTIONS(5942),
    [anon_sym_EQ_EQ] = ACTIONS(5942),
    [anon_sym_BANG_EQ] = ACTIONS(5942),
    [anon_sym_GT_EQ] = ACTIONS(5942),
    [anon_sym_LT_EQ] = ACTIONS(5942),
    [anon_sym_DOT] = ACTIONS(5944),
    [anon_sym_EQ_GT] = ACTIONS(5942),
    [anon_sym_switch] = ACTIONS(5942),
    [anon_sym_when] = ACTIONS(5942),
    [anon_sym_DOT_DOT] = ACTIONS(5942),
    [anon_sym_and] = ACTIONS(5942),
    [anon_sym_or] = ACTIONS(5942),
    [anon_sym_AMP_AMP] = ACTIONS(5942),
    [anon_sym_PIPE_PIPE] = ACTIONS(5942),
    [anon_sym_QMARK_QMARK] = ACTIONS(5942),
    [anon_sym_on] = ACTIONS(5942),
    [anon_sym_equals] = ACTIONS(5942),
    [anon_sym_by] = ACTIONS(5942),
    [anon_sym_as] = ACTIONS(5942),
    [anon_sym_is] = ACTIONS(5942),
    [anon_sym_DASH_GT] = ACTIONS(5942),
    [anon_sym_with] = ACTIONS(5942),
    [aux_sym_preproc_if_token3] = ACTIONS(5942),
    [aux_sym_preproc_else_token1] = ACTIONS(5942),
    [aux_sym_preproc_elif_token1] = ACTIONS(5942),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4123] = {
    [sym__name] = STATE(6202),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_ref_type] = STATE(2883),
    [sym__scoped_base_type] = STATE(2885),
    [sym_identifier] = STATE(5346),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_region] = STATE(4123),
    [sym_preproc_endregion] = STATE(4123),
    [sym_preproc_line] = STATE(4123),
    [sym_preproc_pragma] = STATE(4123),
    [sym_preproc_nullable] = STATE(4123),
    [sym_preproc_error] = STATE(4123),
    [sym_preproc_warning] = STATE(4123),
    [sym_preproc_define] = STATE(4123),
    [sym_preproc_undef] = STATE(4123),
    [sym__identifier_token] = ACTIONS(4061),
    [anon_sym_alias] = ACTIONS(4065),
    [anon_sym_global] = ACTIONS(4065),
    [anon_sym_EQ] = ACTIONS(3993),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_COMMA] = ACTIONS(3993),
    [anon_sym_RBRACK] = ACTIONS(3993),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_RPAREN] = ACTIONS(3993),
    [anon_sym_ref] = ACTIONS(2669),
    [anon_sym_delegate] = ACTIONS(2669),
    [anon_sym_file] = ACTIONS(4065),
    [anon_sym_readonly] = ACTIONS(2669),
    [anon_sym_LT] = ACTIONS(3993),
    [anon_sym_in] = ACTIONS(2669),
    [anon_sym_out] = ACTIONS(2669),
    [anon_sym_where] = ACTIONS(4065),
    [anon_sym_QMARK] = ACTIONS(3993),
    [anon_sym_notnull] = ACTIONS(4065),
    [anon_sym_unmanaged] = ACTIONS(4065),
    [anon_sym_STAR] = ACTIONS(3993),
    [anon_sym_this] = ACTIONS(2669),
    [anon_sym_DOT] = ACTIONS(3993),
    [anon_sym_scoped] = ACTIONS(4065),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(4065),
    [sym_predefined_type] = ACTIONS(2669),
    [anon_sym_yield] = ACTIONS(4065),
    [anon_sym_when] = ACTIONS(4065),
    [anon_sym_from] = ACTIONS(4065),
    [anon_sym_into] = ACTIONS(4065),
    [anon_sym_join] = ACTIONS(4065),
    [anon_sym_on] = ACTIONS(4065),
    [anon_sym_equals] = ACTIONS(4065),
    [anon_sym_let] = ACTIONS(4065),
    [anon_sym_orderby] = ACTIONS(4065),
    [anon_sym_ascending] = ACTIONS(4065),
    [anon_sym_descending] = ACTIONS(4065),
    [anon_sym_group] = ACTIONS(4065),
    [anon_sym_by] = ACTIONS(4065),
    [anon_sym_select] = ACTIONS(4065),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4124] = {
    [sym_preproc_region] = STATE(4124),
    [sym_preproc_endregion] = STATE(4124),
    [sym_preproc_line] = STATE(4124),
    [sym_preproc_pragma] = STATE(4124),
    [sym_preproc_nullable] = STATE(4124),
    [sym_preproc_error] = STATE(4124),
    [sym_preproc_warning] = STATE(4124),
    [sym_preproc_define] = STATE(4124),
    [sym_preproc_undef] = STATE(4124),
    [anon_sym_SEMI] = ACTIONS(5946),
    [anon_sym_LBRACK] = ACTIONS(5946),
    [anon_sym_COLON] = ACTIONS(5946),
    [anon_sym_COMMA] = ACTIONS(5946),
    [anon_sym_RBRACK] = ACTIONS(5946),
    [anon_sym_LPAREN] = ACTIONS(5946),
    [anon_sym_RPAREN] = ACTIONS(5946),
    [anon_sym_RBRACE] = ACTIONS(5946),
    [anon_sym_LT] = ACTIONS(5948),
    [anon_sym_GT] = ACTIONS(5948),
    [anon_sym_in] = ACTIONS(5946),
    [anon_sym_QMARK] = ACTIONS(5948),
    [anon_sym_BANG] = ACTIONS(5948),
    [anon_sym_PLUS_PLUS] = ACTIONS(5946),
    [anon_sym_DASH_DASH] = ACTIONS(5946),
    [anon_sym_PLUS] = ACTIONS(5948),
    [anon_sym_DASH] = ACTIONS(5948),
    [anon_sym_STAR] = ACTIONS(5946),
    [anon_sym_SLASH] = ACTIONS(5948),
    [anon_sym_PERCENT] = ACTIONS(5946),
    [anon_sym_CARET] = ACTIONS(5946),
    [anon_sym_PIPE] = ACTIONS(5948),
    [anon_sym_AMP] = ACTIONS(5948),
    [anon_sym_LT_LT] = ACTIONS(5946),
    [anon_sym_GT_GT] = ACTIONS(5948),
    [anon_sym_GT_GT_GT] = ACTIONS(5946),
    [anon_sym_EQ_EQ] = ACTIONS(5946),
    [anon_sym_BANG_EQ] = ACTIONS(5946),
    [anon_sym_GT_EQ] = ACTIONS(5946),
    [anon_sym_LT_EQ] = ACTIONS(5946),
    [anon_sym_DOT] = ACTIONS(5948),
    [anon_sym_EQ_GT] = ACTIONS(5946),
    [anon_sym_switch] = ACTIONS(5946),
    [anon_sym_when] = ACTIONS(5946),
    [anon_sym_DOT_DOT] = ACTIONS(5946),
    [anon_sym_and] = ACTIONS(5946),
    [anon_sym_or] = ACTIONS(5946),
    [anon_sym_AMP_AMP] = ACTIONS(5946),
    [anon_sym_PIPE_PIPE] = ACTIONS(5946),
    [anon_sym_QMARK_QMARK] = ACTIONS(5946),
    [anon_sym_on] = ACTIONS(5946),
    [anon_sym_equals] = ACTIONS(5946),
    [anon_sym_by] = ACTIONS(5946),
    [anon_sym_as] = ACTIONS(5946),
    [anon_sym_is] = ACTIONS(5946),
    [anon_sym_DASH_GT] = ACTIONS(5946),
    [anon_sym_with] = ACTIONS(5946),
    [aux_sym_preproc_if_token3] = ACTIONS(5946),
    [aux_sym_preproc_else_token1] = ACTIONS(5946),
    [aux_sym_preproc_elif_token1] = ACTIONS(5946),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4125] = {
    [sym_preproc_region] = STATE(4125),
    [sym_preproc_endregion] = STATE(4125),
    [sym_preproc_line] = STATE(4125),
    [sym_preproc_pragma] = STATE(4125),
    [sym_preproc_nullable] = STATE(4125),
    [sym_preproc_error] = STATE(4125),
    [sym_preproc_warning] = STATE(4125),
    [sym_preproc_define] = STATE(4125),
    [sym_preproc_undef] = STATE(4125),
    [anon_sym_SEMI] = ACTIONS(5682),
    [anon_sym_LBRACK] = ACTIONS(5682),
    [anon_sym_COLON] = ACTIONS(5682),
    [anon_sym_COMMA] = ACTIONS(5682),
    [anon_sym_RBRACK] = ACTIONS(5682),
    [anon_sym_LPAREN] = ACTIONS(5682),
    [anon_sym_RPAREN] = ACTIONS(5682),
    [anon_sym_RBRACE] = ACTIONS(5682),
    [anon_sym_LT] = ACTIONS(5684),
    [anon_sym_GT] = ACTIONS(5684),
    [anon_sym_in] = ACTIONS(5682),
    [anon_sym_QMARK] = ACTIONS(5684),
    [anon_sym_BANG] = ACTIONS(5684),
    [anon_sym_PLUS_PLUS] = ACTIONS(5682),
    [anon_sym_DASH_DASH] = ACTIONS(5682),
    [anon_sym_PLUS] = ACTIONS(5684),
    [anon_sym_DASH] = ACTIONS(5684),
    [anon_sym_STAR] = ACTIONS(5682),
    [anon_sym_SLASH] = ACTIONS(5684),
    [anon_sym_PERCENT] = ACTIONS(5682),
    [anon_sym_CARET] = ACTIONS(5682),
    [anon_sym_PIPE] = ACTIONS(5684),
    [anon_sym_AMP] = ACTIONS(5684),
    [anon_sym_LT_LT] = ACTIONS(5682),
    [anon_sym_GT_GT] = ACTIONS(5684),
    [anon_sym_GT_GT_GT] = ACTIONS(5682),
    [anon_sym_EQ_EQ] = ACTIONS(5682),
    [anon_sym_BANG_EQ] = ACTIONS(5682),
    [anon_sym_GT_EQ] = ACTIONS(5682),
    [anon_sym_LT_EQ] = ACTIONS(5682),
    [anon_sym_DOT] = ACTIONS(5684),
    [anon_sym_EQ_GT] = ACTIONS(5682),
    [anon_sym_switch] = ACTIONS(5682),
    [anon_sym_when] = ACTIONS(5682),
    [anon_sym_DOT_DOT] = ACTIONS(5682),
    [anon_sym_and] = ACTIONS(5682),
    [anon_sym_or] = ACTIONS(5682),
    [anon_sym_AMP_AMP] = ACTIONS(5682),
    [anon_sym_PIPE_PIPE] = ACTIONS(5682),
    [anon_sym_QMARK_QMARK] = ACTIONS(5682),
    [anon_sym_on] = ACTIONS(5682),
    [anon_sym_equals] = ACTIONS(5682),
    [anon_sym_by] = ACTIONS(5682),
    [anon_sym_as] = ACTIONS(5682),
    [anon_sym_is] = ACTIONS(5682),
    [anon_sym_DASH_GT] = ACTIONS(5682),
    [anon_sym_with] = ACTIONS(5682),
    [aux_sym_preproc_if_token3] = ACTIONS(5682),
    [aux_sym_preproc_else_token1] = ACTIONS(5682),
    [aux_sym_preproc_elif_token1] = ACTIONS(5682),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4126] = {
    [sym__name] = STATE(6202),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_ref_type] = STATE(2883),
    [sym__scoped_base_type] = STATE(2885),
    [sym_identifier] = STATE(5346),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_region] = STATE(4126),
    [sym_preproc_endregion] = STATE(4126),
    [sym_preproc_line] = STATE(4126),
    [sym_preproc_pragma] = STATE(4126),
    [sym_preproc_nullable] = STATE(4126),
    [sym_preproc_error] = STATE(4126),
    [sym_preproc_warning] = STATE(4126),
    [sym_preproc_define] = STATE(4126),
    [sym_preproc_undef] = STATE(4126),
    [sym__identifier_token] = ACTIONS(4061),
    [anon_sym_alias] = ACTIONS(4065),
    [anon_sym_global] = ACTIONS(4065),
    [anon_sym_EQ] = ACTIONS(3995),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_COMMA] = ACTIONS(3993),
    [anon_sym_LPAREN] = ACTIONS(4069),
    [anon_sym_RPAREN] = ACTIONS(3993),
    [anon_sym_ref] = ACTIONS(2669),
    [anon_sym_delegate] = ACTIONS(2669),
    [anon_sym_file] = ACTIONS(4065),
    [anon_sym_readonly] = ACTIONS(2669),
    [anon_sym_LT] = ACTIONS(3993),
    [anon_sym_in] = ACTIONS(2669),
    [anon_sym_out] = ACTIONS(2669),
    [anon_sym_where] = ACTIONS(4065),
    [anon_sym_QMARK] = ACTIONS(3993),
    [anon_sym_notnull] = ACTIONS(4065),
    [anon_sym_unmanaged] = ACTIONS(4065),
    [anon_sym_STAR] = ACTIONS(3993),
    [anon_sym_this] = ACTIONS(2669),
    [anon_sym_DOT] = ACTIONS(3993),
    [anon_sym_scoped] = ACTIONS(4065),
    [anon_sym_EQ_GT] = ACTIONS(3993),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(4065),
    [sym_predefined_type] = ACTIONS(2669),
    [anon_sym_yield] = ACTIONS(4065),
    [anon_sym_when] = ACTIONS(4065),
    [anon_sym_from] = ACTIONS(4065),
    [anon_sym_into] = ACTIONS(4065),
    [anon_sym_join] = ACTIONS(4065),
    [anon_sym_on] = ACTIONS(4065),
    [anon_sym_equals] = ACTIONS(4065),
    [anon_sym_let] = ACTIONS(4065),
    [anon_sym_orderby] = ACTIONS(4065),
    [anon_sym_ascending] = ACTIONS(4065),
    [anon_sym_descending] = ACTIONS(4065),
    [anon_sym_group] = ACTIONS(4065),
    [anon_sym_by] = ACTIONS(4065),
    [anon_sym_select] = ACTIONS(4065),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4127] = {
    [sym_preproc_region] = STATE(4127),
    [sym_preproc_endregion] = STATE(4127),
    [sym_preproc_line] = STATE(4127),
    [sym_preproc_pragma] = STATE(4127),
    [sym_preproc_nullable] = STATE(4127),
    [sym_preproc_error] = STATE(4127),
    [sym_preproc_warning] = STATE(4127),
    [sym_preproc_define] = STATE(4127),
    [sym_preproc_undef] = STATE(4127),
    [anon_sym_SEMI] = ACTIONS(5674),
    [anon_sym_LBRACK] = ACTIONS(5674),
    [anon_sym_COLON] = ACTIONS(5674),
    [anon_sym_COMMA] = ACTIONS(5674),
    [anon_sym_RBRACK] = ACTIONS(5674),
    [anon_sym_LPAREN] = ACTIONS(5674),
    [anon_sym_RPAREN] = ACTIONS(5674),
    [anon_sym_RBRACE] = ACTIONS(5674),
    [anon_sym_LT] = ACTIONS(5676),
    [anon_sym_GT] = ACTIONS(5676),
    [anon_sym_in] = ACTIONS(5674),
    [anon_sym_QMARK] = ACTIONS(5676),
    [anon_sym_BANG] = ACTIONS(5676),
    [anon_sym_PLUS_PLUS] = ACTIONS(5674),
    [anon_sym_DASH_DASH] = ACTIONS(5674),
    [anon_sym_PLUS] = ACTIONS(5676),
    [anon_sym_DASH] = ACTIONS(5676),
    [anon_sym_STAR] = ACTIONS(5674),
    [anon_sym_SLASH] = ACTIONS(5676),
    [anon_sym_PERCENT] = ACTIONS(5674),
    [anon_sym_CARET] = ACTIONS(5674),
    [anon_sym_PIPE] = ACTIONS(5676),
    [anon_sym_AMP] = ACTIONS(5676),
    [anon_sym_LT_LT] = ACTIONS(5674),
    [anon_sym_GT_GT] = ACTIONS(5676),
    [anon_sym_GT_GT_GT] = ACTIONS(5674),
    [anon_sym_EQ_EQ] = ACTIONS(5674),
    [anon_sym_BANG_EQ] = ACTIONS(5674),
    [anon_sym_GT_EQ] = ACTIONS(5674),
    [anon_sym_LT_EQ] = ACTIONS(5674),
    [anon_sym_DOT] = ACTIONS(5676),
    [anon_sym_EQ_GT] = ACTIONS(5674),
    [anon_sym_switch] = ACTIONS(5674),
    [anon_sym_when] = ACTIONS(5674),
    [anon_sym_DOT_DOT] = ACTIONS(5674),
    [anon_sym_and] = ACTIONS(5674),
    [anon_sym_or] = ACTIONS(5674),
    [anon_sym_AMP_AMP] = ACTIONS(5674),
    [anon_sym_PIPE_PIPE] = ACTIONS(5674),
    [anon_sym_QMARK_QMARK] = ACTIONS(5674),
    [anon_sym_on] = ACTIONS(5674),
    [anon_sym_equals] = ACTIONS(5674),
    [anon_sym_by] = ACTIONS(5674),
    [anon_sym_as] = ACTIONS(5674),
    [anon_sym_is] = ACTIONS(5674),
    [anon_sym_DASH_GT] = ACTIONS(5674),
    [anon_sym_with] = ACTIONS(5674),
    [aux_sym_preproc_if_token3] = ACTIONS(5674),
    [aux_sym_preproc_else_token1] = ACTIONS(5674),
    [aux_sym_preproc_elif_token1] = ACTIONS(5674),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4128] = {
    [sym__name] = STATE(7882),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(9522),
    [sym_implicit_type] = STATE(8747),
    [sym_array_type] = STATE(8331),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(8345),
    [sym_pointer_type] = STATE(8345),
    [sym__pointer_base_type] = STATE(9367),
    [sym_function_pointer_type] = STATE(8345),
    [sym_function_pointer_parameter] = STATE(9589),
    [sym_ref_type] = STATE(8787),
    [sym__ref_base_type] = STATE(9629),
    [sym_scoped_type] = STATE(8787),
    [sym_tuple_type] = STATE(8056),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4128),
    [sym_preproc_endregion] = STATE(4128),
    [sym_preproc_line] = STATE(4128),
    [sym_preproc_pragma] = STATE(4128),
    [sym_preproc_nullable] = STATE(4128),
    [sym_preproc_error] = STATE(4128),
    [sym_preproc_warning] = STATE(4128),
    [sym_preproc_define] = STATE(4128),
    [sym_preproc_undef] = STATE(4128),
    [aux_sym_function_pointer_type_repeat1] = STATE(4540),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(5976),
    [anon_sym_delegate] = ACTIONS(5747),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_in] = ACTIONS(5978),
    [anon_sym_out] = ACTIONS(5978),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(5980),
    [anon_sym_var] = ACTIONS(5369),
    [sym_predefined_type] = ACTIONS(5982),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4129] = {
    [sym__name] = STATE(7882),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(9522),
    [sym_implicit_type] = STATE(8747),
    [sym_array_type] = STATE(8331),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(8345),
    [sym_pointer_type] = STATE(8345),
    [sym__pointer_base_type] = STATE(9367),
    [sym_function_pointer_type] = STATE(8345),
    [sym_function_pointer_parameter] = STATE(9589),
    [sym_ref_type] = STATE(8787),
    [sym__ref_base_type] = STATE(9629),
    [sym_scoped_type] = STATE(8787),
    [sym_tuple_type] = STATE(8056),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4129),
    [sym_preproc_endregion] = STATE(4129),
    [sym_preproc_line] = STATE(4129),
    [sym_preproc_pragma] = STATE(4129),
    [sym_preproc_nullable] = STATE(4129),
    [sym_preproc_error] = STATE(4129),
    [sym_preproc_warning] = STATE(4129),
    [sym_preproc_define] = STATE(4129),
    [sym_preproc_undef] = STATE(4129),
    [aux_sym_function_pointer_type_repeat1] = STATE(4330),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(5976),
    [anon_sym_delegate] = ACTIONS(5747),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_in] = ACTIONS(5978),
    [anon_sym_out] = ACTIONS(5978),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(5980),
    [anon_sym_var] = ACTIONS(5369),
    [sym_predefined_type] = ACTIONS(5982),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4130] = {
    [sym_preproc_region] = STATE(4130),
    [sym_preproc_endregion] = STATE(4130),
    [sym_preproc_line] = STATE(4130),
    [sym_preproc_pragma] = STATE(4130),
    [sym_preproc_nullable] = STATE(4130),
    [sym_preproc_error] = STATE(4130),
    [sym_preproc_warning] = STATE(4130),
    [sym_preproc_define] = STATE(4130),
    [sym_preproc_undef] = STATE(4130),
    [anon_sym_SEMI] = ACTIONS(5956),
    [anon_sym_LBRACK] = ACTIONS(5956),
    [anon_sym_COLON] = ACTIONS(5956),
    [anon_sym_COMMA] = ACTIONS(5956),
    [anon_sym_RBRACK] = ACTIONS(5956),
    [anon_sym_LPAREN] = ACTIONS(5956),
    [anon_sym_RPAREN] = ACTIONS(5956),
    [anon_sym_RBRACE] = ACTIONS(5956),
    [anon_sym_LT] = ACTIONS(5958),
    [anon_sym_GT] = ACTIONS(5958),
    [anon_sym_in] = ACTIONS(5956),
    [anon_sym_QMARK] = ACTIONS(5958),
    [anon_sym_BANG] = ACTIONS(5958),
    [anon_sym_PLUS_PLUS] = ACTIONS(5956),
    [anon_sym_DASH_DASH] = ACTIONS(5956),
    [anon_sym_PLUS] = ACTIONS(5958),
    [anon_sym_DASH] = ACTIONS(5958),
    [anon_sym_STAR] = ACTIONS(5956),
    [anon_sym_SLASH] = ACTIONS(5958),
    [anon_sym_PERCENT] = ACTIONS(5956),
    [anon_sym_CARET] = ACTIONS(5956),
    [anon_sym_PIPE] = ACTIONS(5958),
    [anon_sym_AMP] = ACTIONS(5958),
    [anon_sym_LT_LT] = ACTIONS(5956),
    [anon_sym_GT_GT] = ACTIONS(5958),
    [anon_sym_GT_GT_GT] = ACTIONS(5956),
    [anon_sym_EQ_EQ] = ACTIONS(5956),
    [anon_sym_BANG_EQ] = ACTIONS(5956),
    [anon_sym_GT_EQ] = ACTIONS(5956),
    [anon_sym_LT_EQ] = ACTIONS(5956),
    [anon_sym_DOT] = ACTIONS(5958),
    [anon_sym_EQ_GT] = ACTIONS(5956),
    [anon_sym_switch] = ACTIONS(5956),
    [anon_sym_when] = ACTIONS(5956),
    [anon_sym_DOT_DOT] = ACTIONS(5956),
    [anon_sym_and] = ACTIONS(5956),
    [anon_sym_or] = ACTIONS(5956),
    [anon_sym_AMP_AMP] = ACTIONS(5956),
    [anon_sym_PIPE_PIPE] = ACTIONS(5956),
    [anon_sym_QMARK_QMARK] = ACTIONS(5956),
    [anon_sym_on] = ACTIONS(5956),
    [anon_sym_equals] = ACTIONS(5956),
    [anon_sym_by] = ACTIONS(5956),
    [anon_sym_as] = ACTIONS(5956),
    [anon_sym_is] = ACTIONS(5956),
    [anon_sym_DASH_GT] = ACTIONS(5956),
    [anon_sym_with] = ACTIONS(5956),
    [aux_sym_preproc_if_token3] = ACTIONS(5956),
    [aux_sym_preproc_else_token1] = ACTIONS(5956),
    [aux_sym_preproc_elif_token1] = ACTIONS(5956),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4131] = {
    [sym_preproc_region] = STATE(4131),
    [sym_preproc_endregion] = STATE(4131),
    [sym_preproc_line] = STATE(4131),
    [sym_preproc_pragma] = STATE(4131),
    [sym_preproc_nullable] = STATE(4131),
    [sym_preproc_error] = STATE(4131),
    [sym_preproc_warning] = STATE(4131),
    [sym_preproc_define] = STATE(4131),
    [sym_preproc_undef] = STATE(4131),
    [anon_sym_SEMI] = ACTIONS(5670),
    [anon_sym_LBRACK] = ACTIONS(5670),
    [anon_sym_COLON] = ACTIONS(5670),
    [anon_sym_COMMA] = ACTIONS(5670),
    [anon_sym_RBRACK] = ACTIONS(5670),
    [anon_sym_LPAREN] = ACTIONS(5670),
    [anon_sym_RPAREN] = ACTIONS(5670),
    [anon_sym_RBRACE] = ACTIONS(5670),
    [anon_sym_LT] = ACTIONS(5672),
    [anon_sym_GT] = ACTIONS(5672),
    [anon_sym_in] = ACTIONS(5670),
    [anon_sym_QMARK] = ACTIONS(5672),
    [anon_sym_BANG] = ACTIONS(5672),
    [anon_sym_PLUS_PLUS] = ACTIONS(5670),
    [anon_sym_DASH_DASH] = ACTIONS(5670),
    [anon_sym_PLUS] = ACTIONS(5672),
    [anon_sym_DASH] = ACTIONS(5672),
    [anon_sym_STAR] = ACTIONS(5670),
    [anon_sym_SLASH] = ACTIONS(5672),
    [anon_sym_PERCENT] = ACTIONS(5670),
    [anon_sym_CARET] = ACTIONS(5670),
    [anon_sym_PIPE] = ACTIONS(5672),
    [anon_sym_AMP] = ACTIONS(5672),
    [anon_sym_LT_LT] = ACTIONS(5670),
    [anon_sym_GT_GT] = ACTIONS(5672),
    [anon_sym_GT_GT_GT] = ACTIONS(5670),
    [anon_sym_EQ_EQ] = ACTIONS(5670),
    [anon_sym_BANG_EQ] = ACTIONS(5670),
    [anon_sym_GT_EQ] = ACTIONS(5670),
    [anon_sym_LT_EQ] = ACTIONS(5670),
    [anon_sym_DOT] = ACTIONS(5672),
    [anon_sym_EQ_GT] = ACTIONS(5670),
    [anon_sym_switch] = ACTIONS(5670),
    [anon_sym_when] = ACTIONS(5670),
    [anon_sym_DOT_DOT] = ACTIONS(5670),
    [anon_sym_and] = ACTIONS(5670),
    [anon_sym_or] = ACTIONS(5670),
    [anon_sym_AMP_AMP] = ACTIONS(5670),
    [anon_sym_PIPE_PIPE] = ACTIONS(5670),
    [anon_sym_QMARK_QMARK] = ACTIONS(5670),
    [anon_sym_on] = ACTIONS(5670),
    [anon_sym_equals] = ACTIONS(5670),
    [anon_sym_by] = ACTIONS(5670),
    [anon_sym_as] = ACTIONS(5670),
    [anon_sym_is] = ACTIONS(5670),
    [anon_sym_DASH_GT] = ACTIONS(5670),
    [anon_sym_with] = ACTIONS(5670),
    [aux_sym_preproc_if_token3] = ACTIONS(5670),
    [aux_sym_preproc_else_token1] = ACTIONS(5670),
    [aux_sym_preproc_elif_token1] = ACTIONS(5670),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4132] = {
    [sym_preproc_region] = STATE(4132),
    [sym_preproc_endregion] = STATE(4132),
    [sym_preproc_line] = STATE(4132),
    [sym_preproc_pragma] = STATE(4132),
    [sym_preproc_nullable] = STATE(4132),
    [sym_preproc_error] = STATE(4132),
    [sym_preproc_warning] = STATE(4132),
    [sym_preproc_define] = STATE(4132),
    [sym_preproc_undef] = STATE(4132),
    [anon_sym_SEMI] = ACTIONS(5476),
    [anon_sym_LBRACK] = ACTIONS(5476),
    [anon_sym_COLON] = ACTIONS(5476),
    [anon_sym_COMMA] = ACTIONS(5476),
    [anon_sym_RBRACK] = ACTIONS(5476),
    [anon_sym_LPAREN] = ACTIONS(5476),
    [anon_sym_RPAREN] = ACTIONS(5476),
    [anon_sym_RBRACE] = ACTIONS(5476),
    [anon_sym_LT] = ACTIONS(5478),
    [anon_sym_GT] = ACTIONS(5478),
    [anon_sym_in] = ACTIONS(5476),
    [anon_sym_QMARK] = ACTIONS(5478),
    [anon_sym_BANG] = ACTIONS(5478),
    [anon_sym_PLUS_PLUS] = ACTIONS(5476),
    [anon_sym_DASH_DASH] = ACTIONS(5476),
    [anon_sym_PLUS] = ACTIONS(5478),
    [anon_sym_DASH] = ACTIONS(5478),
    [anon_sym_STAR] = ACTIONS(5476),
    [anon_sym_SLASH] = ACTIONS(5478),
    [anon_sym_PERCENT] = ACTIONS(5476),
    [anon_sym_CARET] = ACTIONS(5476),
    [anon_sym_PIPE] = ACTIONS(5478),
    [anon_sym_AMP] = ACTIONS(5478),
    [anon_sym_LT_LT] = ACTIONS(5476),
    [anon_sym_GT_GT] = ACTIONS(5478),
    [anon_sym_GT_GT_GT] = ACTIONS(5476),
    [anon_sym_EQ_EQ] = ACTIONS(5476),
    [anon_sym_BANG_EQ] = ACTIONS(5476),
    [anon_sym_GT_EQ] = ACTIONS(5476),
    [anon_sym_LT_EQ] = ACTIONS(5476),
    [anon_sym_DOT] = ACTIONS(5478),
    [anon_sym_EQ_GT] = ACTIONS(5476),
    [anon_sym_switch] = ACTIONS(5476),
    [anon_sym_when] = ACTIONS(5476),
    [anon_sym_DOT_DOT] = ACTIONS(5476),
    [anon_sym_and] = ACTIONS(5476),
    [anon_sym_or] = ACTIONS(5476),
    [anon_sym_AMP_AMP] = ACTIONS(5476),
    [anon_sym_PIPE_PIPE] = ACTIONS(5476),
    [anon_sym_QMARK_QMARK] = ACTIONS(5476),
    [anon_sym_on] = ACTIONS(5476),
    [anon_sym_equals] = ACTIONS(5476),
    [anon_sym_by] = ACTIONS(5476),
    [anon_sym_as] = ACTIONS(5476),
    [anon_sym_is] = ACTIONS(5476),
    [anon_sym_DASH_GT] = ACTIONS(5476),
    [anon_sym_with] = ACTIONS(5476),
    [aux_sym_preproc_if_token3] = ACTIONS(5476),
    [aux_sym_preproc_else_token1] = ACTIONS(5476),
    [aux_sym_preproc_elif_token1] = ACTIONS(5476),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4133] = {
    [sym_preproc_region] = STATE(4133),
    [sym_preproc_endregion] = STATE(4133),
    [sym_preproc_line] = STATE(4133),
    [sym_preproc_pragma] = STATE(4133),
    [sym_preproc_nullable] = STATE(4133),
    [sym_preproc_error] = STATE(4133),
    [sym_preproc_warning] = STATE(4133),
    [sym_preproc_define] = STATE(4133),
    [sym_preproc_undef] = STATE(4133),
    [anon_sym_SEMI] = ACTIONS(2035),
    [anon_sym_LBRACK] = ACTIONS(2035),
    [anon_sym_COLON] = ACTIONS(2035),
    [anon_sym_COMMA] = ACTIONS(2035),
    [anon_sym_RBRACK] = ACTIONS(2035),
    [anon_sym_LPAREN] = ACTIONS(2035),
    [anon_sym_RPAREN] = ACTIONS(2035),
    [anon_sym_RBRACE] = ACTIONS(2035),
    [anon_sym_LT] = ACTIONS(2037),
    [anon_sym_GT] = ACTIONS(2037),
    [anon_sym_in] = ACTIONS(2035),
    [anon_sym_QMARK] = ACTIONS(2037),
    [anon_sym_BANG] = ACTIONS(2037),
    [anon_sym_PLUS_PLUS] = ACTIONS(2035),
    [anon_sym_DASH_DASH] = ACTIONS(2035),
    [anon_sym_PLUS] = ACTIONS(2037),
    [anon_sym_DASH] = ACTIONS(2037),
    [anon_sym_STAR] = ACTIONS(2035),
    [anon_sym_SLASH] = ACTIONS(2037),
    [anon_sym_PERCENT] = ACTIONS(2035),
    [anon_sym_CARET] = ACTIONS(2035),
    [anon_sym_PIPE] = ACTIONS(2037),
    [anon_sym_AMP] = ACTIONS(2037),
    [anon_sym_LT_LT] = ACTIONS(2035),
    [anon_sym_GT_GT] = ACTIONS(2037),
    [anon_sym_GT_GT_GT] = ACTIONS(2035),
    [anon_sym_EQ_EQ] = ACTIONS(2035),
    [anon_sym_BANG_EQ] = ACTIONS(2035),
    [anon_sym_GT_EQ] = ACTIONS(2035),
    [anon_sym_LT_EQ] = ACTIONS(2035),
    [anon_sym_DOT] = ACTIONS(2037),
    [anon_sym_EQ_GT] = ACTIONS(2035),
    [anon_sym_switch] = ACTIONS(2035),
    [anon_sym_when] = ACTIONS(2035),
    [anon_sym_DOT_DOT] = ACTIONS(2035),
    [anon_sym_and] = ACTIONS(2035),
    [anon_sym_or] = ACTIONS(2035),
    [anon_sym_AMP_AMP] = ACTIONS(2035),
    [anon_sym_PIPE_PIPE] = ACTIONS(2035),
    [anon_sym_QMARK_QMARK] = ACTIONS(2035),
    [anon_sym_on] = ACTIONS(2035),
    [anon_sym_equals] = ACTIONS(2035),
    [anon_sym_by] = ACTIONS(2035),
    [anon_sym_as] = ACTIONS(2035),
    [anon_sym_is] = ACTIONS(2035),
    [anon_sym_DASH_GT] = ACTIONS(2035),
    [anon_sym_with] = ACTIONS(2035),
    [aux_sym_preproc_if_token3] = ACTIONS(2035),
    [aux_sym_preproc_else_token1] = ACTIONS(2035),
    [aux_sym_preproc_elif_token1] = ACTIONS(2035),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4134] = {
    [sym_preproc_region] = STATE(4134),
    [sym_preproc_endregion] = STATE(4134),
    [sym_preproc_line] = STATE(4134),
    [sym_preproc_pragma] = STATE(4134),
    [sym_preproc_nullable] = STATE(4134),
    [sym_preproc_error] = STATE(4134),
    [sym_preproc_warning] = STATE(4134),
    [sym_preproc_define] = STATE(4134),
    [sym_preproc_undef] = STATE(4134),
    [anon_sym_SEMI] = ACTIONS(5686),
    [anon_sym_LBRACK] = ACTIONS(5686),
    [anon_sym_COLON] = ACTIONS(5686),
    [anon_sym_COMMA] = ACTIONS(5686),
    [anon_sym_RBRACK] = ACTIONS(5686),
    [anon_sym_LPAREN] = ACTIONS(5686),
    [anon_sym_RPAREN] = ACTIONS(5686),
    [anon_sym_RBRACE] = ACTIONS(5686),
    [anon_sym_LT] = ACTIONS(5688),
    [anon_sym_GT] = ACTIONS(5688),
    [anon_sym_in] = ACTIONS(5686),
    [anon_sym_QMARK] = ACTIONS(5688),
    [anon_sym_BANG] = ACTIONS(5688),
    [anon_sym_PLUS_PLUS] = ACTIONS(5686),
    [anon_sym_DASH_DASH] = ACTIONS(5686),
    [anon_sym_PLUS] = ACTIONS(5688),
    [anon_sym_DASH] = ACTIONS(5688),
    [anon_sym_STAR] = ACTIONS(5686),
    [anon_sym_SLASH] = ACTIONS(5688),
    [anon_sym_PERCENT] = ACTIONS(5686),
    [anon_sym_CARET] = ACTIONS(5686),
    [anon_sym_PIPE] = ACTIONS(5688),
    [anon_sym_AMP] = ACTIONS(5688),
    [anon_sym_LT_LT] = ACTIONS(5686),
    [anon_sym_GT_GT] = ACTIONS(5688),
    [anon_sym_GT_GT_GT] = ACTIONS(5686),
    [anon_sym_EQ_EQ] = ACTIONS(5686),
    [anon_sym_BANG_EQ] = ACTIONS(5686),
    [anon_sym_GT_EQ] = ACTIONS(5686),
    [anon_sym_LT_EQ] = ACTIONS(5686),
    [anon_sym_DOT] = ACTIONS(5688),
    [anon_sym_EQ_GT] = ACTIONS(5686),
    [anon_sym_switch] = ACTIONS(5686),
    [anon_sym_when] = ACTIONS(5686),
    [anon_sym_DOT_DOT] = ACTIONS(5686),
    [anon_sym_and] = ACTIONS(5686),
    [anon_sym_or] = ACTIONS(5686),
    [anon_sym_AMP_AMP] = ACTIONS(5686),
    [anon_sym_PIPE_PIPE] = ACTIONS(5686),
    [anon_sym_QMARK_QMARK] = ACTIONS(5686),
    [anon_sym_on] = ACTIONS(5686),
    [anon_sym_equals] = ACTIONS(5686),
    [anon_sym_by] = ACTIONS(5686),
    [anon_sym_as] = ACTIONS(5686),
    [anon_sym_is] = ACTIONS(5686),
    [anon_sym_DASH_GT] = ACTIONS(5686),
    [anon_sym_with] = ACTIONS(5686),
    [aux_sym_preproc_if_token3] = ACTIONS(5686),
    [aux_sym_preproc_else_token1] = ACTIONS(5686),
    [aux_sym_preproc_elif_token1] = ACTIONS(5686),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4135] = {
    [sym_preproc_region] = STATE(4135),
    [sym_preproc_endregion] = STATE(4135),
    [sym_preproc_line] = STATE(4135),
    [sym_preproc_pragma] = STATE(4135),
    [sym_preproc_nullable] = STATE(4135),
    [sym_preproc_error] = STATE(4135),
    [sym_preproc_warning] = STATE(4135),
    [sym_preproc_define] = STATE(4135),
    [sym_preproc_undef] = STATE(4135),
    [anon_sym_EQ] = ACTIONS(5998),
    [anon_sym_LBRACK] = ACTIONS(5286),
    [anon_sym_COMMA] = ACTIONS(5286),
    [anon_sym_RBRACK] = ACTIONS(5286),
    [anon_sym_LPAREN] = ACTIONS(5286),
    [anon_sym_RPAREN] = ACTIONS(5286),
    [anon_sym_RBRACE] = ACTIONS(5286),
    [anon_sym_LT] = ACTIONS(5288),
    [anon_sym_GT] = ACTIONS(5288),
    [anon_sym_QMARK] = ACTIONS(5288),
    [anon_sym_BANG] = ACTIONS(5288),
    [anon_sym_PLUS_PLUS] = ACTIONS(5286),
    [anon_sym_DASH_DASH] = ACTIONS(5286),
    [anon_sym_PLUS] = ACTIONS(5288),
    [anon_sym_DASH] = ACTIONS(5288),
    [anon_sym_STAR] = ACTIONS(5288),
    [anon_sym_SLASH] = ACTIONS(5288),
    [anon_sym_PERCENT] = ACTIONS(5288),
    [anon_sym_CARET] = ACTIONS(5288),
    [anon_sym_PIPE] = ACTIONS(5288),
    [anon_sym_AMP] = ACTIONS(5288),
    [anon_sym_LT_LT] = ACTIONS(5288),
    [anon_sym_GT_GT] = ACTIONS(5288),
    [anon_sym_GT_GT_GT] = ACTIONS(5288),
    [anon_sym_EQ_EQ] = ACTIONS(5286),
    [anon_sym_BANG_EQ] = ACTIONS(5286),
    [anon_sym_GT_EQ] = ACTIONS(5286),
    [anon_sym_LT_EQ] = ACTIONS(5286),
    [anon_sym_DOT] = ACTIONS(5288),
    [anon_sym_switch] = ACTIONS(5286),
    [anon_sym_DOT_DOT] = ACTIONS(5286),
    [anon_sym_PLUS_EQ] = ACTIONS(6000),
    [anon_sym_DASH_EQ] = ACTIONS(6000),
    [anon_sym_STAR_EQ] = ACTIONS(6000),
    [anon_sym_SLASH_EQ] = ACTIONS(6000),
    [anon_sym_PERCENT_EQ] = ACTIONS(6000),
    [anon_sym_AMP_EQ] = ACTIONS(6000),
    [anon_sym_CARET_EQ] = ACTIONS(6000),
    [anon_sym_PIPE_EQ] = ACTIONS(6000),
    [anon_sym_LT_LT_EQ] = ACTIONS(6000),
    [anon_sym_GT_GT_EQ] = ACTIONS(6000),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(6000),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(6000),
    [anon_sym_AMP_AMP] = ACTIONS(5286),
    [anon_sym_PIPE_PIPE] = ACTIONS(5286),
    [anon_sym_QMARK_QMARK] = ACTIONS(5288),
    [anon_sym_as] = ACTIONS(5286),
    [anon_sym_is] = ACTIONS(5286),
    [anon_sym_DASH_GT] = ACTIONS(5286),
    [anon_sym_with] = ACTIONS(5286),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4136] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7111),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9132),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4136),
    [sym_preproc_endregion] = STATE(4136),
    [sym_preproc_line] = STATE(4136),
    [sym_preproc_pragma] = STATE(4136),
    [sym_preproc_nullable] = STATE(4136),
    [sym_preproc_error] = STATE(4136),
    [sym_preproc_warning] = STATE(4136),
    [sym_preproc_define] = STATE(4136),
    [sym_preproc_undef] = STATE(4136),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(5984),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4137] = {
    [sym_preproc_region] = STATE(4137),
    [sym_preproc_endregion] = STATE(4137),
    [sym_preproc_line] = STATE(4137),
    [sym_preproc_pragma] = STATE(4137),
    [sym_preproc_nullable] = STATE(4137),
    [sym_preproc_error] = STATE(4137),
    [sym_preproc_warning] = STATE(4137),
    [sym_preproc_define] = STATE(4137),
    [sym_preproc_undef] = STATE(4137),
    [anon_sym_SEMI] = ACTIONS(5879),
    [anon_sym_LBRACK] = ACTIONS(5879),
    [anon_sym_COLON] = ACTIONS(5879),
    [anon_sym_COMMA] = ACTIONS(5879),
    [anon_sym_RBRACK] = ACTIONS(5879),
    [anon_sym_LPAREN] = ACTIONS(5879),
    [anon_sym_RPAREN] = ACTIONS(5879),
    [anon_sym_RBRACE] = ACTIONS(5879),
    [anon_sym_LT] = ACTIONS(5881),
    [anon_sym_GT] = ACTIONS(5881),
    [anon_sym_in] = ACTIONS(5879),
    [anon_sym_QMARK] = ACTIONS(5881),
    [anon_sym_BANG] = ACTIONS(5881),
    [anon_sym_PLUS_PLUS] = ACTIONS(5879),
    [anon_sym_DASH_DASH] = ACTIONS(5879),
    [anon_sym_PLUS] = ACTIONS(5881),
    [anon_sym_DASH] = ACTIONS(5881),
    [anon_sym_STAR] = ACTIONS(5879),
    [anon_sym_SLASH] = ACTIONS(5881),
    [anon_sym_PERCENT] = ACTIONS(5879),
    [anon_sym_CARET] = ACTIONS(5879),
    [anon_sym_PIPE] = ACTIONS(5881),
    [anon_sym_AMP] = ACTIONS(5881),
    [anon_sym_LT_LT] = ACTIONS(5879),
    [anon_sym_GT_GT] = ACTIONS(5881),
    [anon_sym_GT_GT_GT] = ACTIONS(5879),
    [anon_sym_EQ_EQ] = ACTIONS(5879),
    [anon_sym_BANG_EQ] = ACTIONS(5879),
    [anon_sym_GT_EQ] = ACTIONS(5879),
    [anon_sym_LT_EQ] = ACTIONS(5879),
    [anon_sym_DOT] = ACTIONS(5881),
    [anon_sym_EQ_GT] = ACTIONS(5879),
    [anon_sym_switch] = ACTIONS(5879),
    [anon_sym_when] = ACTIONS(5879),
    [anon_sym_DOT_DOT] = ACTIONS(5879),
    [anon_sym_and] = ACTIONS(5879),
    [anon_sym_or] = ACTIONS(5879),
    [anon_sym_AMP_AMP] = ACTIONS(5879),
    [anon_sym_PIPE_PIPE] = ACTIONS(5879),
    [anon_sym_QMARK_QMARK] = ACTIONS(5879),
    [anon_sym_on] = ACTIONS(5879),
    [anon_sym_equals] = ACTIONS(5879),
    [anon_sym_by] = ACTIONS(5879),
    [anon_sym_as] = ACTIONS(5879),
    [anon_sym_is] = ACTIONS(5879),
    [anon_sym_DASH_GT] = ACTIONS(5879),
    [anon_sym_with] = ACTIONS(5879),
    [aux_sym_preproc_if_token3] = ACTIONS(5879),
    [aux_sym_preproc_else_token1] = ACTIONS(5879),
    [aux_sym_preproc_elif_token1] = ACTIONS(5879),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4138] = {
    [sym_argument_list] = STATE(3592),
    [sym_initializer_expression] = STATE(3783),
    [sym_preproc_region] = STATE(4138),
    [sym_preproc_endregion] = STATE(4138),
    [sym_preproc_line] = STATE(4138),
    [sym_preproc_pragma] = STATE(4138),
    [sym_preproc_nullable] = STATE(4138),
    [sym_preproc_error] = STATE(4138),
    [sym_preproc_warning] = STATE(4138),
    [sym_preproc_define] = STATE(4138),
    [sym_preproc_undef] = STATE(4138),
    [anon_sym_SEMI] = ACTIONS(5263),
    [anon_sym_LBRACK] = ACTIONS(5263),
    [anon_sym_COLON] = ACTIONS(5263),
    [anon_sym_COMMA] = ACTIONS(5263),
    [anon_sym_RBRACK] = ACTIONS(5263),
    [anon_sym_LPAREN] = ACTIONS(5776),
    [anon_sym_RPAREN] = ACTIONS(5263),
    [anon_sym_LBRACE] = ACTIONS(1501),
    [anon_sym_RBRACE] = ACTIONS(5263),
    [anon_sym_LT] = ACTIONS(5267),
    [anon_sym_GT] = ACTIONS(5267),
    [anon_sym_in] = ACTIONS(5263),
    [anon_sym_QMARK] = ACTIONS(5267),
    [anon_sym_BANG] = ACTIONS(5267),
    [anon_sym_PLUS_PLUS] = ACTIONS(5263),
    [anon_sym_DASH_DASH] = ACTIONS(5263),
    [anon_sym_PLUS] = ACTIONS(5267),
    [anon_sym_DASH] = ACTIONS(5267),
    [anon_sym_STAR] = ACTIONS(5263),
    [anon_sym_SLASH] = ACTIONS(5267),
    [anon_sym_PERCENT] = ACTIONS(5263),
    [anon_sym_CARET] = ACTIONS(5263),
    [anon_sym_PIPE] = ACTIONS(5267),
    [anon_sym_AMP] = ACTIONS(5267),
    [anon_sym_LT_LT] = ACTIONS(5263),
    [anon_sym_GT_GT] = ACTIONS(5267),
    [anon_sym_GT_GT_GT] = ACTIONS(5263),
    [anon_sym_EQ_EQ] = ACTIONS(5263),
    [anon_sym_BANG_EQ] = ACTIONS(5263),
    [anon_sym_GT_EQ] = ACTIONS(5263),
    [anon_sym_LT_EQ] = ACTIONS(5263),
    [anon_sym_DOT] = ACTIONS(5267),
    [anon_sym_EQ_GT] = ACTIONS(5263),
    [anon_sym_switch] = ACTIONS(5263),
    [anon_sym_DOT_DOT] = ACTIONS(5263),
    [anon_sym_AMP_AMP] = ACTIONS(5263),
    [anon_sym_PIPE_PIPE] = ACTIONS(5263),
    [anon_sym_QMARK_QMARK] = ACTIONS(5263),
    [anon_sym_on] = ACTIONS(5263),
    [anon_sym_equals] = ACTIONS(5263),
    [anon_sym_by] = ACTIONS(5263),
    [anon_sym_as] = ACTIONS(5263),
    [anon_sym_is] = ACTIONS(5263),
    [anon_sym_DASH_GT] = ACTIONS(5263),
    [anon_sym_with] = ACTIONS(5263),
    [aux_sym_preproc_if_token3] = ACTIONS(5263),
    [aux_sym_preproc_else_token1] = ACTIONS(5263),
    [aux_sym_preproc_elif_token1] = ACTIONS(5263),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4139] = {
    [sym_preproc_region] = STATE(4139),
    [sym_preproc_endregion] = STATE(4139),
    [sym_preproc_line] = STATE(4139),
    [sym_preproc_pragma] = STATE(4139),
    [sym_preproc_nullable] = STATE(4139),
    [sym_preproc_error] = STATE(4139),
    [sym_preproc_warning] = STATE(4139),
    [sym_preproc_define] = STATE(4139),
    [sym_preproc_undef] = STATE(4139),
    [anon_sym_SEMI] = ACTIONS(5538),
    [anon_sym_LBRACK] = ACTIONS(5538),
    [anon_sym_COLON] = ACTIONS(5538),
    [anon_sym_COMMA] = ACTIONS(5538),
    [anon_sym_RBRACK] = ACTIONS(5538),
    [anon_sym_LPAREN] = ACTIONS(5538),
    [anon_sym_RPAREN] = ACTIONS(5538),
    [anon_sym_RBRACE] = ACTIONS(5538),
    [anon_sym_LT] = ACTIONS(5540),
    [anon_sym_GT] = ACTIONS(5540),
    [anon_sym_in] = ACTIONS(5538),
    [anon_sym_QMARK] = ACTIONS(5540),
    [anon_sym_BANG] = ACTIONS(5540),
    [anon_sym_PLUS_PLUS] = ACTIONS(5538),
    [anon_sym_DASH_DASH] = ACTIONS(5538),
    [anon_sym_PLUS] = ACTIONS(5540),
    [anon_sym_DASH] = ACTIONS(5540),
    [anon_sym_STAR] = ACTIONS(5538),
    [anon_sym_SLASH] = ACTIONS(5540),
    [anon_sym_PERCENT] = ACTIONS(5538),
    [anon_sym_CARET] = ACTIONS(5538),
    [anon_sym_PIPE] = ACTIONS(5540),
    [anon_sym_AMP] = ACTIONS(5540),
    [anon_sym_LT_LT] = ACTIONS(5538),
    [anon_sym_GT_GT] = ACTIONS(5540),
    [anon_sym_GT_GT_GT] = ACTIONS(5538),
    [anon_sym_EQ_EQ] = ACTIONS(5538),
    [anon_sym_BANG_EQ] = ACTIONS(5538),
    [anon_sym_GT_EQ] = ACTIONS(5538),
    [anon_sym_LT_EQ] = ACTIONS(5538),
    [anon_sym_DOT] = ACTIONS(5540),
    [anon_sym_EQ_GT] = ACTIONS(5538),
    [anon_sym_switch] = ACTIONS(5538),
    [anon_sym_when] = ACTIONS(5538),
    [anon_sym_DOT_DOT] = ACTIONS(5538),
    [anon_sym_and] = ACTIONS(5538),
    [anon_sym_or] = ACTIONS(5538),
    [anon_sym_AMP_AMP] = ACTIONS(5538),
    [anon_sym_PIPE_PIPE] = ACTIONS(5538),
    [anon_sym_QMARK_QMARK] = ACTIONS(5538),
    [anon_sym_on] = ACTIONS(5538),
    [anon_sym_equals] = ACTIONS(5538),
    [anon_sym_by] = ACTIONS(5538),
    [anon_sym_as] = ACTIONS(5538),
    [anon_sym_is] = ACTIONS(5538),
    [anon_sym_DASH_GT] = ACTIONS(5538),
    [anon_sym_with] = ACTIONS(5538),
    [aux_sym_preproc_if_token3] = ACTIONS(5538),
    [aux_sym_preproc_else_token1] = ACTIONS(5538),
    [aux_sym_preproc_elif_token1] = ACTIONS(5538),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4140] = {
    [sym_preproc_region] = STATE(4140),
    [sym_preproc_endregion] = STATE(4140),
    [sym_preproc_line] = STATE(4140),
    [sym_preproc_pragma] = STATE(4140),
    [sym_preproc_nullable] = STATE(4140),
    [sym_preproc_error] = STATE(4140),
    [sym_preproc_warning] = STATE(4140),
    [sym_preproc_define] = STATE(4140),
    [sym_preproc_undef] = STATE(4140),
    [anon_sym_SEMI] = ACTIONS(5580),
    [anon_sym_LBRACK] = ACTIONS(5580),
    [anon_sym_COLON] = ACTIONS(5580),
    [anon_sym_COMMA] = ACTIONS(5580),
    [anon_sym_RBRACK] = ACTIONS(5580),
    [anon_sym_LPAREN] = ACTIONS(5580),
    [anon_sym_RPAREN] = ACTIONS(5580),
    [anon_sym_RBRACE] = ACTIONS(5580),
    [anon_sym_LT] = ACTIONS(5582),
    [anon_sym_GT] = ACTIONS(5582),
    [anon_sym_in] = ACTIONS(5580),
    [anon_sym_QMARK] = ACTIONS(5582),
    [anon_sym_BANG] = ACTIONS(5582),
    [anon_sym_PLUS_PLUS] = ACTIONS(5580),
    [anon_sym_DASH_DASH] = ACTIONS(5580),
    [anon_sym_PLUS] = ACTIONS(5582),
    [anon_sym_DASH] = ACTIONS(5582),
    [anon_sym_STAR] = ACTIONS(5580),
    [anon_sym_SLASH] = ACTIONS(5582),
    [anon_sym_PERCENT] = ACTIONS(5580),
    [anon_sym_CARET] = ACTIONS(5580),
    [anon_sym_PIPE] = ACTIONS(5582),
    [anon_sym_AMP] = ACTIONS(5582),
    [anon_sym_LT_LT] = ACTIONS(5580),
    [anon_sym_GT_GT] = ACTIONS(5582),
    [anon_sym_GT_GT_GT] = ACTIONS(5580),
    [anon_sym_EQ_EQ] = ACTIONS(5580),
    [anon_sym_BANG_EQ] = ACTIONS(5580),
    [anon_sym_GT_EQ] = ACTIONS(5580),
    [anon_sym_LT_EQ] = ACTIONS(5580),
    [anon_sym_DOT] = ACTIONS(5582),
    [anon_sym_EQ_GT] = ACTIONS(5580),
    [anon_sym_switch] = ACTIONS(5580),
    [anon_sym_when] = ACTIONS(5580),
    [anon_sym_DOT_DOT] = ACTIONS(5580),
    [anon_sym_and] = ACTIONS(5580),
    [anon_sym_or] = ACTIONS(5580),
    [anon_sym_AMP_AMP] = ACTIONS(5580),
    [anon_sym_PIPE_PIPE] = ACTIONS(5580),
    [anon_sym_QMARK_QMARK] = ACTIONS(5580),
    [anon_sym_on] = ACTIONS(5580),
    [anon_sym_equals] = ACTIONS(5580),
    [anon_sym_by] = ACTIONS(5580),
    [anon_sym_as] = ACTIONS(5580),
    [anon_sym_is] = ACTIONS(5580),
    [anon_sym_DASH_GT] = ACTIONS(5580),
    [anon_sym_with] = ACTIONS(5580),
    [aux_sym_preproc_if_token3] = ACTIONS(5580),
    [aux_sym_preproc_else_token1] = ACTIONS(5580),
    [aux_sym_preproc_elif_token1] = ACTIONS(5580),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4141] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7124),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9147),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4141),
    [sym_preproc_endregion] = STATE(4141),
    [sym_preproc_line] = STATE(4141),
    [sym_preproc_pragma] = STATE(4141),
    [sym_preproc_nullable] = STATE(4141),
    [sym_preproc_error] = STATE(4141),
    [sym_preproc_warning] = STATE(4141),
    [sym_preproc_define] = STATE(4141),
    [sym_preproc_undef] = STATE(4141),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4142] = {
    [sym__name] = STATE(7882),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(9549),
    [sym_implicit_type] = STATE(8747),
    [sym_array_type] = STATE(8331),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(8345),
    [sym_pointer_type] = STATE(8345),
    [sym__pointer_base_type] = STATE(9367),
    [sym_function_pointer_type] = STATE(8345),
    [sym_function_pointer_parameter] = STATE(9589),
    [sym_ref_type] = STATE(8787),
    [sym__ref_base_type] = STATE(9629),
    [sym_scoped_type] = STATE(8787),
    [sym_tuple_type] = STATE(8056),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4142),
    [sym_preproc_endregion] = STATE(4142),
    [sym_preproc_line] = STATE(4142),
    [sym_preproc_pragma] = STATE(4142),
    [sym_preproc_nullable] = STATE(4142),
    [sym_preproc_error] = STATE(4142),
    [sym_preproc_warning] = STATE(4142),
    [sym_preproc_define] = STATE(4142),
    [sym_preproc_undef] = STATE(4142),
    [aux_sym_function_pointer_type_repeat1] = STATE(4143),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(5976),
    [anon_sym_delegate] = ACTIONS(5747),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_in] = ACTIONS(5978),
    [anon_sym_out] = ACTIONS(5978),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(5980),
    [anon_sym_var] = ACTIONS(5369),
    [sym_predefined_type] = ACTIONS(5982),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4143] = {
    [sym__name] = STATE(7882),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(9570),
    [sym_implicit_type] = STATE(8747),
    [sym_array_type] = STATE(8331),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(8345),
    [sym_pointer_type] = STATE(8345),
    [sym__pointer_base_type] = STATE(9367),
    [sym_function_pointer_type] = STATE(8345),
    [sym_function_pointer_parameter] = STATE(9589),
    [sym_ref_type] = STATE(8787),
    [sym__ref_base_type] = STATE(9629),
    [sym_scoped_type] = STATE(8787),
    [sym_tuple_type] = STATE(8056),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4143),
    [sym_preproc_endregion] = STATE(4143),
    [sym_preproc_line] = STATE(4143),
    [sym_preproc_pragma] = STATE(4143),
    [sym_preproc_nullable] = STATE(4143),
    [sym_preproc_error] = STATE(4143),
    [sym_preproc_warning] = STATE(4143),
    [sym_preproc_define] = STATE(4143),
    [sym_preproc_undef] = STATE(4143),
    [aux_sym_function_pointer_type_repeat1] = STATE(4540),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(5976),
    [anon_sym_delegate] = ACTIONS(5747),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_in] = ACTIONS(5978),
    [anon_sym_out] = ACTIONS(5978),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(5980),
    [anon_sym_var] = ACTIONS(5369),
    [sym_predefined_type] = ACTIONS(5982),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4144] = {
    [sym__name] = STATE(7882),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(9570),
    [sym_implicit_type] = STATE(8747),
    [sym_array_type] = STATE(8331),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(8345),
    [sym_pointer_type] = STATE(8345),
    [sym__pointer_base_type] = STATE(9367),
    [sym_function_pointer_type] = STATE(8345),
    [sym_function_pointer_parameter] = STATE(9589),
    [sym_ref_type] = STATE(8787),
    [sym__ref_base_type] = STATE(9629),
    [sym_scoped_type] = STATE(8787),
    [sym_tuple_type] = STATE(8056),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4144),
    [sym_preproc_endregion] = STATE(4144),
    [sym_preproc_line] = STATE(4144),
    [sym_preproc_pragma] = STATE(4144),
    [sym_preproc_nullable] = STATE(4144),
    [sym_preproc_error] = STATE(4144),
    [sym_preproc_warning] = STATE(4144),
    [sym_preproc_define] = STATE(4144),
    [sym_preproc_undef] = STATE(4144),
    [aux_sym_function_pointer_type_repeat1] = STATE(4145),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(5976),
    [anon_sym_delegate] = ACTIONS(5747),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_in] = ACTIONS(5978),
    [anon_sym_out] = ACTIONS(5978),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(5980),
    [anon_sym_var] = ACTIONS(5369),
    [sym_predefined_type] = ACTIONS(5982),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4145] = {
    [sym__name] = STATE(7882),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(9828),
    [sym_implicit_type] = STATE(8747),
    [sym_array_type] = STATE(8331),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(8345),
    [sym_pointer_type] = STATE(8345),
    [sym__pointer_base_type] = STATE(9367),
    [sym_function_pointer_type] = STATE(8345),
    [sym_function_pointer_parameter] = STATE(9589),
    [sym_ref_type] = STATE(8787),
    [sym__ref_base_type] = STATE(9629),
    [sym_scoped_type] = STATE(8787),
    [sym_tuple_type] = STATE(8056),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4145),
    [sym_preproc_endregion] = STATE(4145),
    [sym_preproc_line] = STATE(4145),
    [sym_preproc_pragma] = STATE(4145),
    [sym_preproc_nullable] = STATE(4145),
    [sym_preproc_error] = STATE(4145),
    [sym_preproc_warning] = STATE(4145),
    [sym_preproc_define] = STATE(4145),
    [sym_preproc_undef] = STATE(4145),
    [aux_sym_function_pointer_type_repeat1] = STATE(4540),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(5976),
    [anon_sym_delegate] = ACTIONS(5747),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_in] = ACTIONS(5978),
    [anon_sym_out] = ACTIONS(5978),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(5980),
    [anon_sym_var] = ACTIONS(5369),
    [sym_predefined_type] = ACTIONS(5982),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4146] = {
    [sym_preproc_region] = STATE(4146),
    [sym_preproc_endregion] = STATE(4146),
    [sym_preproc_line] = STATE(4146),
    [sym_preproc_pragma] = STATE(4146),
    [sym_preproc_nullable] = STATE(4146),
    [sym_preproc_error] = STATE(4146),
    [sym_preproc_warning] = STATE(4146),
    [sym_preproc_define] = STATE(4146),
    [sym_preproc_undef] = STATE(4146),
    [anon_sym_SEMI] = ACTIONS(5286),
    [anon_sym_EQ] = ACTIONS(6002),
    [anon_sym_LBRACK] = ACTIONS(5286),
    [anon_sym_LPAREN] = ACTIONS(5286),
    [anon_sym_LT] = ACTIONS(5288),
    [anon_sym_GT] = ACTIONS(5288),
    [anon_sym_QMARK] = ACTIONS(5288),
    [anon_sym_BANG] = ACTIONS(5288),
    [anon_sym_PLUS_PLUS] = ACTIONS(5286),
    [anon_sym_DASH_DASH] = ACTIONS(5286),
    [anon_sym_PLUS] = ACTIONS(5288),
    [anon_sym_DASH] = ACTIONS(5288),
    [anon_sym_STAR] = ACTIONS(5288),
    [anon_sym_SLASH] = ACTIONS(5288),
    [anon_sym_PERCENT] = ACTIONS(5288),
    [anon_sym_CARET] = ACTIONS(5288),
    [anon_sym_PIPE] = ACTIONS(5288),
    [anon_sym_AMP] = ACTIONS(5288),
    [anon_sym_LT_LT] = ACTIONS(5288),
    [anon_sym_GT_GT] = ACTIONS(5288),
    [anon_sym_GT_GT_GT] = ACTIONS(5288),
    [anon_sym_EQ_EQ] = ACTIONS(5286),
    [anon_sym_BANG_EQ] = ACTIONS(5286),
    [anon_sym_GT_EQ] = ACTIONS(5286),
    [anon_sym_LT_EQ] = ACTIONS(5286),
    [anon_sym_DOT] = ACTIONS(5288),
    [anon_sym_switch] = ACTIONS(5286),
    [anon_sym_DOT_DOT] = ACTIONS(5286),
    [anon_sym_PLUS_EQ] = ACTIONS(6004),
    [anon_sym_DASH_EQ] = ACTIONS(6004),
    [anon_sym_STAR_EQ] = ACTIONS(6004),
    [anon_sym_SLASH_EQ] = ACTIONS(6004),
    [anon_sym_PERCENT_EQ] = ACTIONS(6004),
    [anon_sym_AMP_EQ] = ACTIONS(6004),
    [anon_sym_CARET_EQ] = ACTIONS(6004),
    [anon_sym_PIPE_EQ] = ACTIONS(6004),
    [anon_sym_LT_LT_EQ] = ACTIONS(6004),
    [anon_sym_GT_GT_EQ] = ACTIONS(6004),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(6004),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(6004),
    [anon_sym_AMP_AMP] = ACTIONS(5286),
    [anon_sym_PIPE_PIPE] = ACTIONS(5286),
    [anon_sym_QMARK_QMARK] = ACTIONS(5288),
    [anon_sym_as] = ACTIONS(5286),
    [anon_sym_is] = ACTIONS(5286),
    [anon_sym_DASH_GT] = ACTIONS(5286),
    [anon_sym_with] = ACTIONS(5286),
    [aux_sym_preproc_if_token3] = ACTIONS(5286),
    [aux_sym_preproc_else_token1] = ACTIONS(5286),
    [aux_sym_preproc_elif_token1] = ACTIONS(5286),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4147] = {
    [sym_preproc_region] = STATE(4147),
    [sym_preproc_endregion] = STATE(4147),
    [sym_preproc_line] = STATE(4147),
    [sym_preproc_pragma] = STATE(4147),
    [sym_preproc_nullable] = STATE(4147),
    [sym_preproc_error] = STATE(4147),
    [sym_preproc_warning] = STATE(4147),
    [sym_preproc_define] = STATE(4147),
    [sym_preproc_undef] = STATE(4147),
    [anon_sym_SEMI] = ACTIONS(5960),
    [anon_sym_LBRACK] = ACTIONS(5960),
    [anon_sym_COLON] = ACTIONS(5960),
    [anon_sym_COMMA] = ACTIONS(5960),
    [anon_sym_RBRACK] = ACTIONS(5960),
    [anon_sym_LPAREN] = ACTIONS(5960),
    [anon_sym_RPAREN] = ACTIONS(5960),
    [anon_sym_RBRACE] = ACTIONS(5960),
    [anon_sym_LT] = ACTIONS(5962),
    [anon_sym_GT] = ACTIONS(5962),
    [anon_sym_in] = ACTIONS(5960),
    [anon_sym_QMARK] = ACTIONS(5962),
    [anon_sym_BANG] = ACTIONS(5962),
    [anon_sym_PLUS_PLUS] = ACTIONS(5960),
    [anon_sym_DASH_DASH] = ACTIONS(5960),
    [anon_sym_PLUS] = ACTIONS(5962),
    [anon_sym_DASH] = ACTIONS(5962),
    [anon_sym_STAR] = ACTIONS(5960),
    [anon_sym_SLASH] = ACTIONS(5962),
    [anon_sym_PERCENT] = ACTIONS(5960),
    [anon_sym_CARET] = ACTIONS(5960),
    [anon_sym_PIPE] = ACTIONS(5962),
    [anon_sym_AMP] = ACTIONS(5962),
    [anon_sym_LT_LT] = ACTIONS(5960),
    [anon_sym_GT_GT] = ACTIONS(5962),
    [anon_sym_GT_GT_GT] = ACTIONS(5960),
    [anon_sym_EQ_EQ] = ACTIONS(5960),
    [anon_sym_BANG_EQ] = ACTIONS(5960),
    [anon_sym_GT_EQ] = ACTIONS(5960),
    [anon_sym_LT_EQ] = ACTIONS(5960),
    [anon_sym_DOT] = ACTIONS(5962),
    [anon_sym_EQ_GT] = ACTIONS(5960),
    [anon_sym_switch] = ACTIONS(5960),
    [anon_sym_when] = ACTIONS(5960),
    [anon_sym_DOT_DOT] = ACTIONS(5960),
    [anon_sym_and] = ACTIONS(5960),
    [anon_sym_or] = ACTIONS(5960),
    [anon_sym_AMP_AMP] = ACTIONS(5960),
    [anon_sym_PIPE_PIPE] = ACTIONS(5960),
    [anon_sym_QMARK_QMARK] = ACTIONS(5960),
    [anon_sym_on] = ACTIONS(5960),
    [anon_sym_equals] = ACTIONS(5960),
    [anon_sym_by] = ACTIONS(5960),
    [anon_sym_as] = ACTIONS(5960),
    [anon_sym_is] = ACTIONS(5960),
    [anon_sym_DASH_GT] = ACTIONS(5960),
    [anon_sym_with] = ACTIONS(5960),
    [aux_sym_preproc_if_token3] = ACTIONS(5960),
    [aux_sym_preproc_else_token1] = ACTIONS(5960),
    [aux_sym_preproc_elif_token1] = ACTIONS(5960),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4148] = {
    [sym_preproc_region] = STATE(4148),
    [sym_preproc_endregion] = STATE(4148),
    [sym_preproc_line] = STATE(4148),
    [sym_preproc_pragma] = STATE(4148),
    [sym_preproc_nullable] = STATE(4148),
    [sym_preproc_error] = STATE(4148),
    [sym_preproc_warning] = STATE(4148),
    [sym_preproc_define] = STATE(4148),
    [sym_preproc_undef] = STATE(4148),
    [anon_sym_SEMI] = ACTIONS(5420),
    [anon_sym_LBRACK] = ACTIONS(5420),
    [anon_sym_COLON] = ACTIONS(5420),
    [anon_sym_COMMA] = ACTIONS(5420),
    [anon_sym_RBRACK] = ACTIONS(5420),
    [anon_sym_LPAREN] = ACTIONS(5420),
    [anon_sym_RPAREN] = ACTIONS(5420),
    [anon_sym_RBRACE] = ACTIONS(5420),
    [anon_sym_LT] = ACTIONS(5422),
    [anon_sym_GT] = ACTIONS(5422),
    [anon_sym_in] = ACTIONS(5420),
    [anon_sym_QMARK] = ACTIONS(5422),
    [anon_sym_BANG] = ACTIONS(5422),
    [anon_sym_PLUS_PLUS] = ACTIONS(5420),
    [anon_sym_DASH_DASH] = ACTIONS(5420),
    [anon_sym_PLUS] = ACTIONS(5422),
    [anon_sym_DASH] = ACTIONS(5422),
    [anon_sym_STAR] = ACTIONS(5420),
    [anon_sym_SLASH] = ACTIONS(5422),
    [anon_sym_PERCENT] = ACTIONS(5420),
    [anon_sym_CARET] = ACTIONS(5420),
    [anon_sym_PIPE] = ACTIONS(5422),
    [anon_sym_AMP] = ACTIONS(5422),
    [anon_sym_LT_LT] = ACTIONS(5420),
    [anon_sym_GT_GT] = ACTIONS(5422),
    [anon_sym_GT_GT_GT] = ACTIONS(5420),
    [anon_sym_EQ_EQ] = ACTIONS(5420),
    [anon_sym_BANG_EQ] = ACTIONS(5420),
    [anon_sym_GT_EQ] = ACTIONS(5420),
    [anon_sym_LT_EQ] = ACTIONS(5420),
    [anon_sym_DOT] = ACTIONS(5422),
    [anon_sym_EQ_GT] = ACTIONS(5420),
    [anon_sym_switch] = ACTIONS(5420),
    [anon_sym_when] = ACTIONS(5420),
    [anon_sym_DOT_DOT] = ACTIONS(5420),
    [anon_sym_and] = ACTIONS(5420),
    [anon_sym_or] = ACTIONS(5420),
    [anon_sym_AMP_AMP] = ACTIONS(5420),
    [anon_sym_PIPE_PIPE] = ACTIONS(5420),
    [anon_sym_QMARK_QMARK] = ACTIONS(5420),
    [anon_sym_on] = ACTIONS(5420),
    [anon_sym_equals] = ACTIONS(5420),
    [anon_sym_by] = ACTIONS(5420),
    [anon_sym_as] = ACTIONS(5420),
    [anon_sym_is] = ACTIONS(5420),
    [anon_sym_DASH_GT] = ACTIONS(5420),
    [anon_sym_with] = ACTIONS(5420),
    [aux_sym_preproc_if_token3] = ACTIONS(5420),
    [aux_sym_preproc_else_token1] = ACTIONS(5420),
    [aux_sym_preproc_elif_token1] = ACTIONS(5420),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4149] = {
    [sym_preproc_region] = STATE(4149),
    [sym_preproc_endregion] = STATE(4149),
    [sym_preproc_line] = STATE(4149),
    [sym_preproc_pragma] = STATE(4149),
    [sym_preproc_nullable] = STATE(4149),
    [sym_preproc_error] = STATE(4149),
    [sym_preproc_warning] = STATE(4149),
    [sym_preproc_define] = STATE(4149),
    [sym_preproc_undef] = STATE(4149),
    [anon_sym_EQ] = ACTIONS(6006),
    [anon_sym_LBRACK] = ACTIONS(5286),
    [anon_sym_COLON] = ACTIONS(5286),
    [anon_sym_COMMA] = ACTIONS(5286),
    [anon_sym_LPAREN] = ACTIONS(5286),
    [anon_sym_LT] = ACTIONS(5288),
    [anon_sym_GT] = ACTIONS(5288),
    [anon_sym_QMARK] = ACTIONS(5288),
    [anon_sym_BANG] = ACTIONS(5288),
    [anon_sym_PLUS_PLUS] = ACTIONS(5286),
    [anon_sym_DASH_DASH] = ACTIONS(5286),
    [anon_sym_PLUS] = ACTIONS(5288),
    [anon_sym_DASH] = ACTIONS(5288),
    [anon_sym_STAR] = ACTIONS(5288),
    [anon_sym_SLASH] = ACTIONS(5288),
    [anon_sym_PERCENT] = ACTIONS(5288),
    [anon_sym_CARET] = ACTIONS(5288),
    [anon_sym_PIPE] = ACTIONS(5288),
    [anon_sym_AMP] = ACTIONS(5288),
    [anon_sym_LT_LT] = ACTIONS(5288),
    [anon_sym_GT_GT] = ACTIONS(5288),
    [anon_sym_GT_GT_GT] = ACTIONS(5288),
    [anon_sym_EQ_EQ] = ACTIONS(5286),
    [anon_sym_BANG_EQ] = ACTIONS(5286),
    [anon_sym_GT_EQ] = ACTIONS(5286),
    [anon_sym_LT_EQ] = ACTIONS(5286),
    [anon_sym_DOT] = ACTIONS(5288),
    [anon_sym_switch] = ACTIONS(5286),
    [anon_sym_DOT_DOT] = ACTIONS(5286),
    [anon_sym_PLUS_EQ] = ACTIONS(6008),
    [anon_sym_DASH_EQ] = ACTIONS(6008),
    [anon_sym_STAR_EQ] = ACTIONS(6008),
    [anon_sym_SLASH_EQ] = ACTIONS(6008),
    [anon_sym_PERCENT_EQ] = ACTIONS(6008),
    [anon_sym_AMP_EQ] = ACTIONS(6008),
    [anon_sym_CARET_EQ] = ACTIONS(6008),
    [anon_sym_PIPE_EQ] = ACTIONS(6008),
    [anon_sym_LT_LT_EQ] = ACTIONS(6008),
    [anon_sym_GT_GT_EQ] = ACTIONS(6008),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(6008),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(6008),
    [anon_sym_AMP_AMP] = ACTIONS(5286),
    [anon_sym_PIPE_PIPE] = ACTIONS(5286),
    [anon_sym_QMARK_QMARK] = ACTIONS(5288),
    [anon_sym_into] = ACTIONS(5286),
    [anon_sym_as] = ACTIONS(5286),
    [anon_sym_is] = ACTIONS(5286),
    [anon_sym_DASH_GT] = ACTIONS(5286),
    [anon_sym_with] = ACTIONS(5286),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(5286),
  },
  [4150] = {
    [sym_preproc_region] = STATE(4150),
    [sym_preproc_endregion] = STATE(4150),
    [sym_preproc_line] = STATE(4150),
    [sym_preproc_pragma] = STATE(4150),
    [sym_preproc_nullable] = STATE(4150),
    [sym_preproc_error] = STATE(4150),
    [sym_preproc_warning] = STATE(4150),
    [sym_preproc_define] = STATE(4150),
    [sym_preproc_undef] = STATE(4150),
    [anon_sym_SEMI] = ACTIONS(5470),
    [anon_sym_LBRACK] = ACTIONS(5470),
    [anon_sym_COLON] = ACTIONS(5470),
    [anon_sym_COMMA] = ACTIONS(5470),
    [anon_sym_RBRACK] = ACTIONS(5470),
    [anon_sym_LPAREN] = ACTIONS(5470),
    [anon_sym_RPAREN] = ACTIONS(5470),
    [anon_sym_RBRACE] = ACTIONS(5470),
    [anon_sym_LT] = ACTIONS(5472),
    [anon_sym_GT] = ACTIONS(5472),
    [anon_sym_in] = ACTIONS(5470),
    [anon_sym_QMARK] = ACTIONS(5472),
    [anon_sym_BANG] = ACTIONS(5472),
    [anon_sym_PLUS_PLUS] = ACTIONS(5470),
    [anon_sym_DASH_DASH] = ACTIONS(5470),
    [anon_sym_PLUS] = ACTIONS(5472),
    [anon_sym_DASH] = ACTIONS(5472),
    [anon_sym_STAR] = ACTIONS(5470),
    [anon_sym_SLASH] = ACTIONS(5472),
    [anon_sym_PERCENT] = ACTIONS(5470),
    [anon_sym_CARET] = ACTIONS(5470),
    [anon_sym_PIPE] = ACTIONS(5472),
    [anon_sym_AMP] = ACTIONS(5472),
    [anon_sym_LT_LT] = ACTIONS(5470),
    [anon_sym_GT_GT] = ACTIONS(5472),
    [anon_sym_GT_GT_GT] = ACTIONS(5470),
    [anon_sym_EQ_EQ] = ACTIONS(5470),
    [anon_sym_BANG_EQ] = ACTIONS(5470),
    [anon_sym_GT_EQ] = ACTIONS(5470),
    [anon_sym_LT_EQ] = ACTIONS(5470),
    [anon_sym_DOT] = ACTIONS(5472),
    [anon_sym_EQ_GT] = ACTIONS(5470),
    [anon_sym_switch] = ACTIONS(5470),
    [anon_sym_when] = ACTIONS(5470),
    [anon_sym_DOT_DOT] = ACTIONS(5470),
    [anon_sym_and] = ACTIONS(5470),
    [anon_sym_or] = ACTIONS(5470),
    [anon_sym_AMP_AMP] = ACTIONS(5470),
    [anon_sym_PIPE_PIPE] = ACTIONS(5470),
    [anon_sym_QMARK_QMARK] = ACTIONS(5470),
    [anon_sym_on] = ACTIONS(5470),
    [anon_sym_equals] = ACTIONS(5470),
    [anon_sym_by] = ACTIONS(5470),
    [anon_sym_as] = ACTIONS(5470),
    [anon_sym_is] = ACTIONS(5470),
    [anon_sym_DASH_GT] = ACTIONS(5470),
    [anon_sym_with] = ACTIONS(5470),
    [aux_sym_preproc_if_token3] = ACTIONS(5470),
    [aux_sym_preproc_else_token1] = ACTIONS(5470),
    [aux_sym_preproc_elif_token1] = ACTIONS(5470),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4151] = {
    [sym_initializer_expression] = STATE(3687),
    [sym_preproc_region] = STATE(4151),
    [sym_preproc_endregion] = STATE(4151),
    [sym_preproc_line] = STATE(4151),
    [sym_preproc_pragma] = STATE(4151),
    [sym_preproc_nullable] = STATE(4151),
    [sym_preproc_error] = STATE(4151),
    [sym_preproc_warning] = STATE(4151),
    [sym_preproc_define] = STATE(4151),
    [sym_preproc_undef] = STATE(4151),
    [anon_sym_SEMI] = ACTIONS(5340),
    [anon_sym_LBRACK] = ACTIONS(5336),
    [anon_sym_COLON] = ACTIONS(5340),
    [anon_sym_COMMA] = ACTIONS(5340),
    [anon_sym_RBRACK] = ACTIONS(5340),
    [anon_sym_LPAREN] = ACTIONS(5340),
    [anon_sym_RPAREN] = ACTIONS(5340),
    [anon_sym_LBRACE] = ACTIONS(6010),
    [anon_sym_RBRACE] = ACTIONS(5340),
    [anon_sym_LT] = ACTIONS(5346),
    [anon_sym_GT] = ACTIONS(5346),
    [anon_sym_in] = ACTIONS(5346),
    [anon_sym_QMARK] = ACTIONS(6013),
    [anon_sym_BANG] = ACTIONS(5346),
    [anon_sym_PLUS_PLUS] = ACTIONS(5340),
    [anon_sym_DASH_DASH] = ACTIONS(5340),
    [anon_sym_PLUS] = ACTIONS(5346),
    [anon_sym_DASH] = ACTIONS(5346),
    [anon_sym_STAR] = ACTIONS(5340),
    [anon_sym_SLASH] = ACTIONS(5346),
    [anon_sym_PERCENT] = ACTIONS(5340),
    [anon_sym_CARET] = ACTIONS(5340),
    [anon_sym_PIPE] = ACTIONS(5346),
    [anon_sym_AMP] = ACTIONS(5346),
    [anon_sym_LT_LT] = ACTIONS(5340),
    [anon_sym_GT_GT] = ACTIONS(5346),
    [anon_sym_GT_GT_GT] = ACTIONS(5340),
    [anon_sym_EQ_EQ] = ACTIONS(5340),
    [anon_sym_BANG_EQ] = ACTIONS(5340),
    [anon_sym_GT_EQ] = ACTIONS(5340),
    [anon_sym_LT_EQ] = ACTIONS(5340),
    [anon_sym_DOT] = ACTIONS(5346),
    [anon_sym_EQ_GT] = ACTIONS(5340),
    [anon_sym_switch] = ACTIONS(5340),
    [anon_sym_DOT_DOT] = ACTIONS(5340),
    [anon_sym_AMP_AMP] = ACTIONS(5340),
    [anon_sym_PIPE_PIPE] = ACTIONS(5340),
    [anon_sym_QMARK_QMARK] = ACTIONS(5340),
    [anon_sym_into] = ACTIONS(5340),
    [anon_sym_on] = ACTIONS(5340),
    [anon_sym_equals] = ACTIONS(5340),
    [anon_sym_by] = ACTIONS(5340),
    [anon_sym_as] = ACTIONS(5340),
    [anon_sym_is] = ACTIONS(5340),
    [anon_sym_DASH_GT] = ACTIONS(5340),
    [anon_sym_with] = ACTIONS(5340),
    [aux_sym_preproc_if_token3] = ACTIONS(5340),
    [aux_sym_preproc_else_token1] = ACTIONS(5340),
    [aux_sym_preproc_elif_token1] = ACTIONS(5340),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4152] = {
    [sym_preproc_region] = STATE(4152),
    [sym_preproc_endregion] = STATE(4152),
    [sym_preproc_line] = STATE(4152),
    [sym_preproc_pragma] = STATE(4152),
    [sym_preproc_nullable] = STATE(4152),
    [sym_preproc_error] = STATE(4152),
    [sym_preproc_warning] = STATE(4152),
    [sym_preproc_define] = STATE(4152),
    [sym_preproc_undef] = STATE(4152),
    [anon_sym_SEMI] = ACTIONS(5416),
    [anon_sym_LBRACK] = ACTIONS(5416),
    [anon_sym_COLON] = ACTIONS(5416),
    [anon_sym_COMMA] = ACTIONS(5416),
    [anon_sym_RBRACK] = ACTIONS(5416),
    [anon_sym_LPAREN] = ACTIONS(5416),
    [anon_sym_RPAREN] = ACTIONS(5416),
    [anon_sym_RBRACE] = ACTIONS(5416),
    [anon_sym_LT] = ACTIONS(5418),
    [anon_sym_GT] = ACTIONS(5418),
    [anon_sym_in] = ACTIONS(5416),
    [anon_sym_QMARK] = ACTIONS(5418),
    [anon_sym_BANG] = ACTIONS(5418),
    [anon_sym_PLUS_PLUS] = ACTIONS(5416),
    [anon_sym_DASH_DASH] = ACTIONS(5416),
    [anon_sym_PLUS] = ACTIONS(5418),
    [anon_sym_DASH] = ACTIONS(5418),
    [anon_sym_STAR] = ACTIONS(5416),
    [anon_sym_SLASH] = ACTIONS(5418),
    [anon_sym_PERCENT] = ACTIONS(5416),
    [anon_sym_CARET] = ACTIONS(5416),
    [anon_sym_PIPE] = ACTIONS(5418),
    [anon_sym_AMP] = ACTIONS(5418),
    [anon_sym_LT_LT] = ACTIONS(5416),
    [anon_sym_GT_GT] = ACTIONS(5418),
    [anon_sym_GT_GT_GT] = ACTIONS(5416),
    [anon_sym_EQ_EQ] = ACTIONS(5416),
    [anon_sym_BANG_EQ] = ACTIONS(5416),
    [anon_sym_GT_EQ] = ACTIONS(5416),
    [anon_sym_LT_EQ] = ACTIONS(5416),
    [anon_sym_DOT] = ACTIONS(5418),
    [anon_sym_EQ_GT] = ACTIONS(5416),
    [anon_sym_switch] = ACTIONS(5416),
    [anon_sym_when] = ACTIONS(5416),
    [anon_sym_DOT_DOT] = ACTIONS(5416),
    [anon_sym_and] = ACTIONS(5416),
    [anon_sym_or] = ACTIONS(5416),
    [anon_sym_AMP_AMP] = ACTIONS(5416),
    [anon_sym_PIPE_PIPE] = ACTIONS(5416),
    [anon_sym_QMARK_QMARK] = ACTIONS(5416),
    [anon_sym_on] = ACTIONS(5416),
    [anon_sym_equals] = ACTIONS(5416),
    [anon_sym_by] = ACTIONS(5416),
    [anon_sym_as] = ACTIONS(5416),
    [anon_sym_is] = ACTIONS(5416),
    [anon_sym_DASH_GT] = ACTIONS(5416),
    [anon_sym_with] = ACTIONS(5416),
    [aux_sym_preproc_if_token3] = ACTIONS(5416),
    [aux_sym_preproc_else_token1] = ACTIONS(5416),
    [aux_sym_preproc_elif_token1] = ACTIONS(5416),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4153] = {
    [sym_preproc_region] = STATE(4153),
    [sym_preproc_endregion] = STATE(4153),
    [sym_preproc_line] = STATE(4153),
    [sym_preproc_pragma] = STATE(4153),
    [sym_preproc_nullable] = STATE(4153),
    [sym_preproc_error] = STATE(4153),
    [sym_preproc_warning] = STATE(4153),
    [sym_preproc_define] = STATE(4153),
    [sym_preproc_undef] = STATE(4153),
    [anon_sym_SEMI] = ACTIONS(5861),
    [anon_sym_LBRACK] = ACTIONS(5861),
    [anon_sym_COLON] = ACTIONS(5861),
    [anon_sym_COMMA] = ACTIONS(5861),
    [anon_sym_RBRACK] = ACTIONS(5861),
    [anon_sym_LPAREN] = ACTIONS(5861),
    [anon_sym_RPAREN] = ACTIONS(5861),
    [anon_sym_RBRACE] = ACTIONS(5861),
    [anon_sym_LT] = ACTIONS(5863),
    [anon_sym_GT] = ACTIONS(5863),
    [anon_sym_in] = ACTIONS(5861),
    [anon_sym_QMARK] = ACTIONS(5863),
    [anon_sym_BANG] = ACTIONS(5863),
    [anon_sym_PLUS_PLUS] = ACTIONS(5861),
    [anon_sym_DASH_DASH] = ACTIONS(5861),
    [anon_sym_PLUS] = ACTIONS(5863),
    [anon_sym_DASH] = ACTIONS(5863),
    [anon_sym_STAR] = ACTIONS(5861),
    [anon_sym_SLASH] = ACTIONS(5863),
    [anon_sym_PERCENT] = ACTIONS(5861),
    [anon_sym_CARET] = ACTIONS(5861),
    [anon_sym_PIPE] = ACTIONS(5863),
    [anon_sym_AMP] = ACTIONS(5863),
    [anon_sym_LT_LT] = ACTIONS(5861),
    [anon_sym_GT_GT] = ACTIONS(5863),
    [anon_sym_GT_GT_GT] = ACTIONS(5861),
    [anon_sym_EQ_EQ] = ACTIONS(5861),
    [anon_sym_BANG_EQ] = ACTIONS(5861),
    [anon_sym_GT_EQ] = ACTIONS(5861),
    [anon_sym_LT_EQ] = ACTIONS(5861),
    [anon_sym_DOT] = ACTIONS(5863),
    [anon_sym_EQ_GT] = ACTIONS(5861),
    [anon_sym_switch] = ACTIONS(5861),
    [anon_sym_when] = ACTIONS(5861),
    [anon_sym_DOT_DOT] = ACTIONS(5861),
    [anon_sym_and] = ACTIONS(5861),
    [anon_sym_or] = ACTIONS(5861),
    [anon_sym_AMP_AMP] = ACTIONS(5861),
    [anon_sym_PIPE_PIPE] = ACTIONS(5861),
    [anon_sym_QMARK_QMARK] = ACTIONS(5861),
    [anon_sym_on] = ACTIONS(5861),
    [anon_sym_equals] = ACTIONS(5861),
    [anon_sym_by] = ACTIONS(5861),
    [anon_sym_as] = ACTIONS(5861),
    [anon_sym_is] = ACTIONS(5861),
    [anon_sym_DASH_GT] = ACTIONS(5861),
    [anon_sym_with] = ACTIONS(5861),
    [aux_sym_preproc_if_token3] = ACTIONS(5861),
    [aux_sym_preproc_else_token1] = ACTIONS(5861),
    [aux_sym_preproc_elif_token1] = ACTIONS(5861),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4154] = {
    [sym_preproc_region] = STATE(4154),
    [sym_preproc_endregion] = STATE(4154),
    [sym_preproc_line] = STATE(4154),
    [sym_preproc_pragma] = STATE(4154),
    [sym_preproc_nullable] = STATE(4154),
    [sym_preproc_error] = STATE(4154),
    [sym_preproc_warning] = STATE(4154),
    [sym_preproc_define] = STATE(4154),
    [sym_preproc_undef] = STATE(4154),
    [anon_sym_SEMI] = ACTIONS(5526),
    [anon_sym_LBRACK] = ACTIONS(5526),
    [anon_sym_COLON] = ACTIONS(5526),
    [anon_sym_COMMA] = ACTIONS(5526),
    [anon_sym_RBRACK] = ACTIONS(5526),
    [anon_sym_LPAREN] = ACTIONS(5526),
    [anon_sym_RPAREN] = ACTIONS(5526),
    [anon_sym_RBRACE] = ACTIONS(5526),
    [anon_sym_LT] = ACTIONS(5528),
    [anon_sym_GT] = ACTIONS(5528),
    [anon_sym_in] = ACTIONS(5526),
    [anon_sym_QMARK] = ACTIONS(5528),
    [anon_sym_BANG] = ACTIONS(5528),
    [anon_sym_PLUS_PLUS] = ACTIONS(5526),
    [anon_sym_DASH_DASH] = ACTIONS(5526),
    [anon_sym_PLUS] = ACTIONS(5528),
    [anon_sym_DASH] = ACTIONS(5528),
    [anon_sym_STAR] = ACTIONS(5526),
    [anon_sym_SLASH] = ACTIONS(5528),
    [anon_sym_PERCENT] = ACTIONS(5526),
    [anon_sym_CARET] = ACTIONS(5526),
    [anon_sym_PIPE] = ACTIONS(5528),
    [anon_sym_AMP] = ACTIONS(5528),
    [anon_sym_LT_LT] = ACTIONS(5526),
    [anon_sym_GT_GT] = ACTIONS(5528),
    [anon_sym_GT_GT_GT] = ACTIONS(5526),
    [anon_sym_EQ_EQ] = ACTIONS(5526),
    [anon_sym_BANG_EQ] = ACTIONS(5526),
    [anon_sym_GT_EQ] = ACTIONS(5526),
    [anon_sym_LT_EQ] = ACTIONS(5526),
    [anon_sym_DOT] = ACTIONS(5528),
    [anon_sym_EQ_GT] = ACTIONS(5526),
    [anon_sym_switch] = ACTIONS(5526),
    [anon_sym_when] = ACTIONS(5526),
    [anon_sym_DOT_DOT] = ACTIONS(5526),
    [anon_sym_and] = ACTIONS(5526),
    [anon_sym_or] = ACTIONS(5526),
    [anon_sym_AMP_AMP] = ACTIONS(5526),
    [anon_sym_PIPE_PIPE] = ACTIONS(5526),
    [anon_sym_QMARK_QMARK] = ACTIONS(5526),
    [anon_sym_on] = ACTIONS(5526),
    [anon_sym_equals] = ACTIONS(5526),
    [anon_sym_by] = ACTIONS(5526),
    [anon_sym_as] = ACTIONS(5526),
    [anon_sym_is] = ACTIONS(5526),
    [anon_sym_DASH_GT] = ACTIONS(5526),
    [anon_sym_with] = ACTIONS(5526),
    [aux_sym_preproc_if_token3] = ACTIONS(5526),
    [aux_sym_preproc_else_token1] = ACTIONS(5526),
    [aux_sym_preproc_elif_token1] = ACTIONS(5526),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4155] = {
    [sym_preproc_region] = STATE(4155),
    [sym_preproc_endregion] = STATE(4155),
    [sym_preproc_line] = STATE(4155),
    [sym_preproc_pragma] = STATE(4155),
    [sym_preproc_nullable] = STATE(4155),
    [sym_preproc_error] = STATE(4155),
    [sym_preproc_warning] = STATE(4155),
    [sym_preproc_define] = STATE(4155),
    [sym_preproc_undef] = STATE(4155),
    [anon_sym_SEMI] = ACTIONS(5865),
    [anon_sym_LBRACK] = ACTIONS(5865),
    [anon_sym_COLON] = ACTIONS(5865),
    [anon_sym_COMMA] = ACTIONS(5865),
    [anon_sym_RBRACK] = ACTIONS(5865),
    [anon_sym_LPAREN] = ACTIONS(5865),
    [anon_sym_RPAREN] = ACTIONS(5865),
    [anon_sym_RBRACE] = ACTIONS(5865),
    [anon_sym_LT] = ACTIONS(5867),
    [anon_sym_GT] = ACTIONS(5867),
    [anon_sym_in] = ACTIONS(5865),
    [anon_sym_QMARK] = ACTIONS(5867),
    [anon_sym_BANG] = ACTIONS(5867),
    [anon_sym_PLUS_PLUS] = ACTIONS(5865),
    [anon_sym_DASH_DASH] = ACTIONS(5865),
    [anon_sym_PLUS] = ACTIONS(5867),
    [anon_sym_DASH] = ACTIONS(5867),
    [anon_sym_STAR] = ACTIONS(5865),
    [anon_sym_SLASH] = ACTIONS(5867),
    [anon_sym_PERCENT] = ACTIONS(5865),
    [anon_sym_CARET] = ACTIONS(5865),
    [anon_sym_PIPE] = ACTIONS(5867),
    [anon_sym_AMP] = ACTIONS(5867),
    [anon_sym_LT_LT] = ACTIONS(5865),
    [anon_sym_GT_GT] = ACTIONS(5867),
    [anon_sym_GT_GT_GT] = ACTIONS(5865),
    [anon_sym_EQ_EQ] = ACTIONS(5865),
    [anon_sym_BANG_EQ] = ACTIONS(5865),
    [anon_sym_GT_EQ] = ACTIONS(5865),
    [anon_sym_LT_EQ] = ACTIONS(5865),
    [anon_sym_DOT] = ACTIONS(5867),
    [anon_sym_EQ_GT] = ACTIONS(5865),
    [anon_sym_switch] = ACTIONS(5865),
    [anon_sym_when] = ACTIONS(5865),
    [anon_sym_DOT_DOT] = ACTIONS(5865),
    [anon_sym_and] = ACTIONS(5865),
    [anon_sym_or] = ACTIONS(5865),
    [anon_sym_AMP_AMP] = ACTIONS(5865),
    [anon_sym_PIPE_PIPE] = ACTIONS(5865),
    [anon_sym_QMARK_QMARK] = ACTIONS(5865),
    [anon_sym_on] = ACTIONS(5865),
    [anon_sym_equals] = ACTIONS(5865),
    [anon_sym_by] = ACTIONS(5865),
    [anon_sym_as] = ACTIONS(5865),
    [anon_sym_is] = ACTIONS(5865),
    [anon_sym_DASH_GT] = ACTIONS(5865),
    [anon_sym_with] = ACTIONS(5865),
    [aux_sym_preproc_if_token3] = ACTIONS(5865),
    [aux_sym_preproc_else_token1] = ACTIONS(5865),
    [aux_sym_preproc_elif_token1] = ACTIONS(5865),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4156] = {
    [sym_preproc_region] = STATE(4156),
    [sym_preproc_endregion] = STATE(4156),
    [sym_preproc_line] = STATE(4156),
    [sym_preproc_pragma] = STATE(4156),
    [sym_preproc_nullable] = STATE(4156),
    [sym_preproc_error] = STATE(4156),
    [sym_preproc_warning] = STATE(4156),
    [sym_preproc_define] = STATE(4156),
    [sym_preproc_undef] = STATE(4156),
    [anon_sym_SEMI] = ACTIONS(4310),
    [anon_sym_LBRACK] = ACTIONS(4310),
    [anon_sym_COLON] = ACTIONS(4310),
    [anon_sym_COMMA] = ACTIONS(4310),
    [anon_sym_RBRACK] = ACTIONS(4310),
    [anon_sym_LPAREN] = ACTIONS(4310),
    [anon_sym_RPAREN] = ACTIONS(4310),
    [anon_sym_RBRACE] = ACTIONS(4310),
    [anon_sym_LT] = ACTIONS(5873),
    [anon_sym_GT] = ACTIONS(5873),
    [anon_sym_in] = ACTIONS(4310),
    [anon_sym_QMARK] = ACTIONS(5873),
    [anon_sym_BANG] = ACTIONS(5873),
    [anon_sym_PLUS_PLUS] = ACTIONS(4310),
    [anon_sym_DASH_DASH] = ACTIONS(4310),
    [anon_sym_PLUS] = ACTIONS(5873),
    [anon_sym_DASH] = ACTIONS(5873),
    [anon_sym_STAR] = ACTIONS(4310),
    [anon_sym_SLASH] = ACTIONS(5873),
    [anon_sym_PERCENT] = ACTIONS(4310),
    [anon_sym_CARET] = ACTIONS(4310),
    [anon_sym_PIPE] = ACTIONS(5873),
    [anon_sym_AMP] = ACTIONS(5873),
    [anon_sym_LT_LT] = ACTIONS(4310),
    [anon_sym_GT_GT] = ACTIONS(5873),
    [anon_sym_GT_GT_GT] = ACTIONS(4310),
    [anon_sym_EQ_EQ] = ACTIONS(4310),
    [anon_sym_BANG_EQ] = ACTIONS(4310),
    [anon_sym_GT_EQ] = ACTIONS(4310),
    [anon_sym_LT_EQ] = ACTIONS(4310),
    [anon_sym_DOT] = ACTIONS(5873),
    [anon_sym_EQ_GT] = ACTIONS(4310),
    [anon_sym_switch] = ACTIONS(4310),
    [anon_sym_when] = ACTIONS(4310),
    [anon_sym_DOT_DOT] = ACTIONS(4310),
    [anon_sym_and] = ACTIONS(4310),
    [anon_sym_or] = ACTIONS(4310),
    [anon_sym_AMP_AMP] = ACTIONS(4310),
    [anon_sym_PIPE_PIPE] = ACTIONS(4310),
    [anon_sym_QMARK_QMARK] = ACTIONS(4310),
    [anon_sym_on] = ACTIONS(4310),
    [anon_sym_equals] = ACTIONS(4310),
    [anon_sym_by] = ACTIONS(4310),
    [anon_sym_as] = ACTIONS(4310),
    [anon_sym_is] = ACTIONS(4310),
    [anon_sym_DASH_GT] = ACTIONS(4310),
    [anon_sym_with] = ACTIONS(4310),
    [aux_sym_preproc_if_token3] = ACTIONS(4310),
    [aux_sym_preproc_else_token1] = ACTIONS(4310),
    [aux_sym_preproc_elif_token1] = ACTIONS(4310),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4157] = {
    [sym_preproc_region] = STATE(4157),
    [sym_preproc_endregion] = STATE(4157),
    [sym_preproc_line] = STATE(4157),
    [sym_preproc_pragma] = STATE(4157),
    [sym_preproc_nullable] = STATE(4157),
    [sym_preproc_error] = STATE(4157),
    [sym_preproc_warning] = STATE(4157),
    [sym_preproc_define] = STATE(4157),
    [sym_preproc_undef] = STATE(4157),
    [anon_sym_SEMI] = ACTIONS(5964),
    [anon_sym_LBRACK] = ACTIONS(5964),
    [anon_sym_COLON] = ACTIONS(5964),
    [anon_sym_COMMA] = ACTIONS(5964),
    [anon_sym_RBRACK] = ACTIONS(5964),
    [anon_sym_LPAREN] = ACTIONS(5964),
    [anon_sym_RPAREN] = ACTIONS(5964),
    [anon_sym_RBRACE] = ACTIONS(5964),
    [anon_sym_LT] = ACTIONS(5966),
    [anon_sym_GT] = ACTIONS(5966),
    [anon_sym_in] = ACTIONS(5964),
    [anon_sym_QMARK] = ACTIONS(5966),
    [anon_sym_BANG] = ACTIONS(5966),
    [anon_sym_PLUS_PLUS] = ACTIONS(5964),
    [anon_sym_DASH_DASH] = ACTIONS(5964),
    [anon_sym_PLUS] = ACTIONS(5966),
    [anon_sym_DASH] = ACTIONS(5966),
    [anon_sym_STAR] = ACTIONS(5964),
    [anon_sym_SLASH] = ACTIONS(5966),
    [anon_sym_PERCENT] = ACTIONS(5964),
    [anon_sym_CARET] = ACTIONS(5964),
    [anon_sym_PIPE] = ACTIONS(5966),
    [anon_sym_AMP] = ACTIONS(5966),
    [anon_sym_LT_LT] = ACTIONS(5964),
    [anon_sym_GT_GT] = ACTIONS(5966),
    [anon_sym_GT_GT_GT] = ACTIONS(5964),
    [anon_sym_EQ_EQ] = ACTIONS(5964),
    [anon_sym_BANG_EQ] = ACTIONS(5964),
    [anon_sym_GT_EQ] = ACTIONS(5964),
    [anon_sym_LT_EQ] = ACTIONS(5964),
    [anon_sym_DOT] = ACTIONS(5966),
    [anon_sym_EQ_GT] = ACTIONS(5964),
    [anon_sym_switch] = ACTIONS(5964),
    [anon_sym_when] = ACTIONS(5964),
    [anon_sym_DOT_DOT] = ACTIONS(5964),
    [anon_sym_and] = ACTIONS(5964),
    [anon_sym_or] = ACTIONS(5964),
    [anon_sym_AMP_AMP] = ACTIONS(5964),
    [anon_sym_PIPE_PIPE] = ACTIONS(5964),
    [anon_sym_QMARK_QMARK] = ACTIONS(5964),
    [anon_sym_on] = ACTIONS(5964),
    [anon_sym_equals] = ACTIONS(5964),
    [anon_sym_by] = ACTIONS(5964),
    [anon_sym_as] = ACTIONS(5964),
    [anon_sym_is] = ACTIONS(5964),
    [anon_sym_DASH_GT] = ACTIONS(5964),
    [anon_sym_with] = ACTIONS(5964),
    [aux_sym_preproc_if_token3] = ACTIONS(5964),
    [aux_sym_preproc_else_token1] = ACTIONS(5964),
    [aux_sym_preproc_elif_token1] = ACTIONS(5964),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4158] = {
    [sym_preproc_region] = STATE(4158),
    [sym_preproc_endregion] = STATE(4158),
    [sym_preproc_line] = STATE(4158),
    [sym_preproc_pragma] = STATE(4158),
    [sym_preproc_nullable] = STATE(4158),
    [sym_preproc_error] = STATE(4158),
    [sym_preproc_warning] = STATE(4158),
    [sym_preproc_define] = STATE(4158),
    [sym_preproc_undef] = STATE(4158),
    [anon_sym_SEMI] = ACTIONS(4494),
    [anon_sym_LBRACK] = ACTIONS(4593),
    [anon_sym_COLON] = ACTIONS(4494),
    [anon_sym_COMMA] = ACTIONS(4494),
    [anon_sym_RBRACK] = ACTIONS(4494),
    [anon_sym_LPAREN] = ACTIONS(4494),
    [anon_sym_RPAREN] = ACTIONS(4494),
    [anon_sym_LBRACE] = ACTIONS(4494),
    [anon_sym_RBRACE] = ACTIONS(4494),
    [anon_sym_LT] = ACTIONS(4492),
    [anon_sym_GT] = ACTIONS(4492),
    [anon_sym_QMARK] = ACTIONS(5850),
    [anon_sym_BANG] = ACTIONS(4492),
    [anon_sym_PLUS_PLUS] = ACTIONS(4494),
    [anon_sym_DASH_DASH] = ACTIONS(4494),
    [anon_sym_PLUS] = ACTIONS(4492),
    [anon_sym_DASH] = ACTIONS(4492),
    [anon_sym_STAR] = ACTIONS(4599),
    [anon_sym_SLASH] = ACTIONS(4492),
    [anon_sym_PERCENT] = ACTIONS(4494),
    [anon_sym_CARET] = ACTIONS(4494),
    [anon_sym_PIPE] = ACTIONS(4492),
    [anon_sym_AMP] = ACTIONS(4492),
    [anon_sym_LT_LT] = ACTIONS(4494),
    [anon_sym_GT_GT] = ACTIONS(4492),
    [anon_sym_GT_GT_GT] = ACTIONS(4494),
    [anon_sym_EQ_EQ] = ACTIONS(4494),
    [anon_sym_BANG_EQ] = ACTIONS(4494),
    [anon_sym_GT_EQ] = ACTIONS(4494),
    [anon_sym_LT_EQ] = ACTIONS(4494),
    [anon_sym_DOT] = ACTIONS(6017),
    [anon_sym_EQ_GT] = ACTIONS(4494),
    [anon_sym_switch] = ACTIONS(4494),
    [anon_sym_when] = ACTIONS(4494),
    [anon_sym_DOT_DOT] = ACTIONS(4494),
    [anon_sym_and] = ACTIONS(4494),
    [anon_sym_or] = ACTIONS(4494),
    [anon_sym_AMP_AMP] = ACTIONS(4494),
    [anon_sym_PIPE_PIPE] = ACTIONS(4494),
    [anon_sym_QMARK_QMARK] = ACTIONS(4494),
    [anon_sym_on] = ACTIONS(4494),
    [anon_sym_equals] = ACTIONS(4494),
    [anon_sym_by] = ACTIONS(4494),
    [anon_sym_as] = ACTIONS(4494),
    [anon_sym_is] = ACTIONS(4494),
    [anon_sym_DASH_GT] = ACTIONS(4494),
    [anon_sym_with] = ACTIONS(4494),
    [aux_sym_preproc_if_token3] = ACTIONS(4494),
    [aux_sym_preproc_else_token1] = ACTIONS(4494),
    [aux_sym_preproc_elif_token1] = ACTIONS(4494),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4159] = {
    [sym_preproc_region] = STATE(4159),
    [sym_preproc_endregion] = STATE(4159),
    [sym_preproc_line] = STATE(4159),
    [sym_preproc_pragma] = STATE(4159),
    [sym_preproc_nullable] = STATE(4159),
    [sym_preproc_error] = STATE(4159),
    [sym_preproc_warning] = STATE(4159),
    [sym_preproc_define] = STATE(4159),
    [sym_preproc_undef] = STATE(4159),
    [anon_sym_SEMI] = ACTIONS(4455),
    [anon_sym_LBRACK] = ACTIONS(4455),
    [anon_sym_COLON] = ACTIONS(4455),
    [anon_sym_COMMA] = ACTIONS(4455),
    [anon_sym_RBRACK] = ACTIONS(4455),
    [anon_sym_LPAREN] = ACTIONS(4455),
    [anon_sym_RPAREN] = ACTIONS(4455),
    [anon_sym_LBRACE] = ACTIONS(4455),
    [anon_sym_RBRACE] = ACTIONS(4455),
    [anon_sym_LT] = ACTIONS(4453),
    [anon_sym_GT] = ACTIONS(4453),
    [anon_sym_QMARK] = ACTIONS(4453),
    [anon_sym_BANG] = ACTIONS(4453),
    [anon_sym_PLUS_PLUS] = ACTIONS(4455),
    [anon_sym_DASH_DASH] = ACTIONS(4455),
    [anon_sym_PLUS] = ACTIONS(4453),
    [anon_sym_DASH] = ACTIONS(4453),
    [anon_sym_STAR] = ACTIONS(4455),
    [anon_sym_SLASH] = ACTIONS(4453),
    [anon_sym_PERCENT] = ACTIONS(4455),
    [anon_sym_CARET] = ACTIONS(4455),
    [anon_sym_PIPE] = ACTIONS(4453),
    [anon_sym_AMP] = ACTIONS(4453),
    [anon_sym_LT_LT] = ACTIONS(4455),
    [anon_sym_GT_GT] = ACTIONS(4453),
    [anon_sym_GT_GT_GT] = ACTIONS(4455),
    [anon_sym_EQ_EQ] = ACTIONS(4455),
    [anon_sym_BANG_EQ] = ACTIONS(4455),
    [anon_sym_GT_EQ] = ACTIONS(4455),
    [anon_sym_LT_EQ] = ACTIONS(4455),
    [anon_sym_DOT] = ACTIONS(6017),
    [anon_sym_EQ_GT] = ACTIONS(4455),
    [anon_sym_switch] = ACTIONS(4455),
    [anon_sym_when] = ACTIONS(4455),
    [anon_sym_DOT_DOT] = ACTIONS(4455),
    [anon_sym_and] = ACTIONS(4455),
    [anon_sym_or] = ACTIONS(4455),
    [anon_sym_AMP_AMP] = ACTIONS(4455),
    [anon_sym_PIPE_PIPE] = ACTIONS(4455),
    [anon_sym_QMARK_QMARK] = ACTIONS(4455),
    [anon_sym_on] = ACTIONS(4455),
    [anon_sym_equals] = ACTIONS(4455),
    [anon_sym_by] = ACTIONS(4455),
    [anon_sym_as] = ACTIONS(4455),
    [anon_sym_is] = ACTIONS(4455),
    [anon_sym_DASH_GT] = ACTIONS(4455),
    [anon_sym_with] = ACTIONS(4455),
    [aux_sym_preproc_if_token3] = ACTIONS(4455),
    [aux_sym_preproc_else_token1] = ACTIONS(4455),
    [aux_sym_preproc_elif_token1] = ACTIONS(4455),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4160] = {
    [sym_preproc_region] = STATE(4160),
    [sym_preproc_endregion] = STATE(4160),
    [sym_preproc_line] = STATE(4160),
    [sym_preproc_pragma] = STATE(4160),
    [sym_preproc_nullable] = STATE(4160),
    [sym_preproc_error] = STATE(4160),
    [sym_preproc_warning] = STATE(4160),
    [sym_preproc_define] = STATE(4160),
    [sym_preproc_undef] = STATE(4160),
    [anon_sym_SEMI] = ACTIONS(5648),
    [anon_sym_LBRACK] = ACTIONS(5648),
    [anon_sym_COLON] = ACTIONS(5648),
    [anon_sym_COMMA] = ACTIONS(5648),
    [anon_sym_RBRACK] = ACTIONS(5648),
    [anon_sym_LPAREN] = ACTIONS(5648),
    [anon_sym_RPAREN] = ACTIONS(5648),
    [anon_sym_RBRACE] = ACTIONS(5648),
    [anon_sym_LT] = ACTIONS(5650),
    [anon_sym_GT] = ACTIONS(5650),
    [anon_sym_in] = ACTIONS(5648),
    [anon_sym_QMARK] = ACTIONS(5650),
    [anon_sym_BANG] = ACTIONS(5650),
    [anon_sym_PLUS_PLUS] = ACTIONS(5648),
    [anon_sym_DASH_DASH] = ACTIONS(5648),
    [anon_sym_PLUS] = ACTIONS(5650),
    [anon_sym_DASH] = ACTIONS(5650),
    [anon_sym_STAR] = ACTIONS(5648),
    [anon_sym_SLASH] = ACTIONS(5650),
    [anon_sym_PERCENT] = ACTIONS(5648),
    [anon_sym_CARET] = ACTIONS(5648),
    [anon_sym_PIPE] = ACTIONS(5650),
    [anon_sym_AMP] = ACTIONS(5650),
    [anon_sym_LT_LT] = ACTIONS(5648),
    [anon_sym_GT_GT] = ACTIONS(5650),
    [anon_sym_GT_GT_GT] = ACTIONS(5648),
    [anon_sym_EQ_EQ] = ACTIONS(5648),
    [anon_sym_BANG_EQ] = ACTIONS(5648),
    [anon_sym_GT_EQ] = ACTIONS(5648),
    [anon_sym_LT_EQ] = ACTIONS(5648),
    [anon_sym_DOT] = ACTIONS(5650),
    [anon_sym_EQ_GT] = ACTIONS(5648),
    [anon_sym_switch] = ACTIONS(5648),
    [anon_sym_when] = ACTIONS(5648),
    [anon_sym_DOT_DOT] = ACTIONS(5648),
    [anon_sym_and] = ACTIONS(5648),
    [anon_sym_or] = ACTIONS(5648),
    [anon_sym_AMP_AMP] = ACTIONS(5648),
    [anon_sym_PIPE_PIPE] = ACTIONS(5648),
    [anon_sym_QMARK_QMARK] = ACTIONS(5648),
    [anon_sym_on] = ACTIONS(5648),
    [anon_sym_equals] = ACTIONS(5648),
    [anon_sym_by] = ACTIONS(5648),
    [anon_sym_as] = ACTIONS(5648),
    [anon_sym_is] = ACTIONS(5648),
    [anon_sym_DASH_GT] = ACTIONS(5648),
    [anon_sym_with] = ACTIONS(5648),
    [aux_sym_preproc_if_token3] = ACTIONS(5648),
    [aux_sym_preproc_else_token1] = ACTIONS(5648),
    [aux_sym_preproc_elif_token1] = ACTIONS(5648),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4161] = {
    [sym_preproc_region] = STATE(4161),
    [sym_preproc_endregion] = STATE(4161),
    [sym_preproc_line] = STATE(4161),
    [sym_preproc_pragma] = STATE(4161),
    [sym_preproc_nullable] = STATE(4161),
    [sym_preproc_error] = STATE(4161),
    [sym_preproc_warning] = STATE(4161),
    [sym_preproc_define] = STATE(4161),
    [sym_preproc_undef] = STATE(4161),
    [anon_sym_SEMI] = ACTIONS(5928),
    [anon_sym_LBRACK] = ACTIONS(5928),
    [anon_sym_COLON] = ACTIONS(5928),
    [anon_sym_COMMA] = ACTIONS(5928),
    [anon_sym_RBRACK] = ACTIONS(5928),
    [anon_sym_LPAREN] = ACTIONS(5928),
    [anon_sym_RPAREN] = ACTIONS(5928),
    [anon_sym_RBRACE] = ACTIONS(5928),
    [anon_sym_LT] = ACTIONS(5930),
    [anon_sym_GT] = ACTIONS(5930),
    [anon_sym_in] = ACTIONS(5928),
    [anon_sym_QMARK] = ACTIONS(5930),
    [anon_sym_BANG] = ACTIONS(5930),
    [anon_sym_PLUS_PLUS] = ACTIONS(5928),
    [anon_sym_DASH_DASH] = ACTIONS(5928),
    [anon_sym_PLUS] = ACTIONS(5930),
    [anon_sym_DASH] = ACTIONS(5930),
    [anon_sym_STAR] = ACTIONS(5928),
    [anon_sym_SLASH] = ACTIONS(5930),
    [anon_sym_PERCENT] = ACTIONS(5928),
    [anon_sym_CARET] = ACTIONS(5928),
    [anon_sym_PIPE] = ACTIONS(5930),
    [anon_sym_AMP] = ACTIONS(5930),
    [anon_sym_LT_LT] = ACTIONS(5928),
    [anon_sym_GT_GT] = ACTIONS(5930),
    [anon_sym_GT_GT_GT] = ACTIONS(5928),
    [anon_sym_EQ_EQ] = ACTIONS(5928),
    [anon_sym_BANG_EQ] = ACTIONS(5928),
    [anon_sym_GT_EQ] = ACTIONS(5928),
    [anon_sym_LT_EQ] = ACTIONS(5928),
    [anon_sym_DOT] = ACTIONS(5930),
    [anon_sym_EQ_GT] = ACTIONS(5928),
    [anon_sym_switch] = ACTIONS(5928),
    [anon_sym_when] = ACTIONS(5928),
    [anon_sym_DOT_DOT] = ACTIONS(5928),
    [anon_sym_and] = ACTIONS(5928),
    [anon_sym_or] = ACTIONS(5928),
    [anon_sym_AMP_AMP] = ACTIONS(5928),
    [anon_sym_PIPE_PIPE] = ACTIONS(5928),
    [anon_sym_QMARK_QMARK] = ACTIONS(5928),
    [anon_sym_on] = ACTIONS(5928),
    [anon_sym_equals] = ACTIONS(5928),
    [anon_sym_by] = ACTIONS(5928),
    [anon_sym_as] = ACTIONS(5928),
    [anon_sym_is] = ACTIONS(5928),
    [anon_sym_DASH_GT] = ACTIONS(5928),
    [anon_sym_with] = ACTIONS(5928),
    [aux_sym_preproc_if_token3] = ACTIONS(5928),
    [aux_sym_preproc_else_token1] = ACTIONS(5928),
    [aux_sym_preproc_elif_token1] = ACTIONS(5928),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4162] = {
    [sym_preproc_region] = STATE(4162),
    [sym_preproc_endregion] = STATE(4162),
    [sym_preproc_line] = STATE(4162),
    [sym_preproc_pragma] = STATE(4162),
    [sym_preproc_nullable] = STATE(4162),
    [sym_preproc_error] = STATE(4162),
    [sym_preproc_warning] = STATE(4162),
    [sym_preproc_define] = STATE(4162),
    [sym_preproc_undef] = STATE(4162),
    [anon_sym_SEMI] = ACTIONS(5970),
    [anon_sym_LBRACK] = ACTIONS(5970),
    [anon_sym_COLON] = ACTIONS(5970),
    [anon_sym_COMMA] = ACTIONS(5970),
    [anon_sym_RBRACK] = ACTIONS(5970),
    [anon_sym_LPAREN] = ACTIONS(5970),
    [anon_sym_RPAREN] = ACTIONS(5970),
    [anon_sym_RBRACE] = ACTIONS(5970),
    [anon_sym_LT] = ACTIONS(5972),
    [anon_sym_GT] = ACTIONS(5972),
    [anon_sym_in] = ACTIONS(5970),
    [anon_sym_QMARK] = ACTIONS(5972),
    [anon_sym_BANG] = ACTIONS(5972),
    [anon_sym_PLUS_PLUS] = ACTIONS(5970),
    [anon_sym_DASH_DASH] = ACTIONS(5970),
    [anon_sym_PLUS] = ACTIONS(5972),
    [anon_sym_DASH] = ACTIONS(5972),
    [anon_sym_STAR] = ACTIONS(5970),
    [anon_sym_SLASH] = ACTIONS(5972),
    [anon_sym_PERCENT] = ACTIONS(5970),
    [anon_sym_CARET] = ACTIONS(5970),
    [anon_sym_PIPE] = ACTIONS(5972),
    [anon_sym_AMP] = ACTIONS(5972),
    [anon_sym_LT_LT] = ACTIONS(5970),
    [anon_sym_GT_GT] = ACTIONS(5972),
    [anon_sym_GT_GT_GT] = ACTIONS(5970),
    [anon_sym_EQ_EQ] = ACTIONS(5970),
    [anon_sym_BANG_EQ] = ACTIONS(5970),
    [anon_sym_GT_EQ] = ACTIONS(5970),
    [anon_sym_LT_EQ] = ACTIONS(5970),
    [anon_sym_DOT] = ACTIONS(5972),
    [anon_sym_EQ_GT] = ACTIONS(5970),
    [anon_sym_switch] = ACTIONS(5970),
    [anon_sym_when] = ACTIONS(5970),
    [anon_sym_DOT_DOT] = ACTIONS(5970),
    [anon_sym_and] = ACTIONS(5970),
    [anon_sym_or] = ACTIONS(5970),
    [anon_sym_AMP_AMP] = ACTIONS(5970),
    [anon_sym_PIPE_PIPE] = ACTIONS(5970),
    [anon_sym_QMARK_QMARK] = ACTIONS(5970),
    [anon_sym_on] = ACTIONS(5970),
    [anon_sym_equals] = ACTIONS(5970),
    [anon_sym_by] = ACTIONS(5970),
    [anon_sym_as] = ACTIONS(5970),
    [anon_sym_is] = ACTIONS(5970),
    [anon_sym_DASH_GT] = ACTIONS(5970),
    [anon_sym_with] = ACTIONS(5970),
    [aux_sym_preproc_if_token3] = ACTIONS(5970),
    [aux_sym_preproc_else_token1] = ACTIONS(5970),
    [aux_sym_preproc_elif_token1] = ACTIONS(5970),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4163] = {
    [sym_preproc_region] = STATE(4163),
    [sym_preproc_endregion] = STATE(4163),
    [sym_preproc_line] = STATE(4163),
    [sym_preproc_pragma] = STATE(4163),
    [sym_preproc_nullable] = STATE(4163),
    [sym_preproc_error] = STATE(4163),
    [sym_preproc_warning] = STATE(4163),
    [sym_preproc_define] = STATE(4163),
    [sym_preproc_undef] = STATE(4163),
    [anon_sym_SEMI] = ACTIONS(4310),
    [anon_sym_LBRACK] = ACTIONS(4310),
    [anon_sym_COLON] = ACTIONS(4310),
    [anon_sym_COMMA] = ACTIONS(4310),
    [anon_sym_RBRACK] = ACTIONS(4310),
    [anon_sym_LPAREN] = ACTIONS(4310),
    [anon_sym_RPAREN] = ACTIONS(4310),
    [anon_sym_RBRACE] = ACTIONS(4310),
    [anon_sym_LT] = ACTIONS(5873),
    [anon_sym_GT] = ACTIONS(5873),
    [anon_sym_in] = ACTIONS(4310),
    [anon_sym_QMARK] = ACTIONS(5873),
    [anon_sym_BANG] = ACTIONS(5873),
    [anon_sym_PLUS_PLUS] = ACTIONS(4310),
    [anon_sym_DASH_DASH] = ACTIONS(4310),
    [anon_sym_PLUS] = ACTIONS(5873),
    [anon_sym_DASH] = ACTIONS(5873),
    [anon_sym_STAR] = ACTIONS(4310),
    [anon_sym_SLASH] = ACTIONS(5873),
    [anon_sym_PERCENT] = ACTIONS(4310),
    [anon_sym_CARET] = ACTIONS(4310),
    [anon_sym_PIPE] = ACTIONS(5873),
    [anon_sym_AMP] = ACTIONS(5873),
    [anon_sym_LT_LT] = ACTIONS(4310),
    [anon_sym_GT_GT] = ACTIONS(5873),
    [anon_sym_GT_GT_GT] = ACTIONS(4310),
    [anon_sym_EQ_EQ] = ACTIONS(4310),
    [anon_sym_BANG_EQ] = ACTIONS(4310),
    [anon_sym_GT_EQ] = ACTIONS(4310),
    [anon_sym_LT_EQ] = ACTIONS(4310),
    [anon_sym_DOT] = ACTIONS(5873),
    [anon_sym_EQ_GT] = ACTIONS(4145),
    [anon_sym_switch] = ACTIONS(4310),
    [anon_sym_when] = ACTIONS(4310),
    [anon_sym_DOT_DOT] = ACTIONS(4310),
    [anon_sym_and] = ACTIONS(4310),
    [anon_sym_or] = ACTIONS(4310),
    [anon_sym_AMP_AMP] = ACTIONS(4310),
    [anon_sym_PIPE_PIPE] = ACTIONS(4310),
    [anon_sym_QMARK_QMARK] = ACTIONS(4310),
    [anon_sym_on] = ACTIONS(4310),
    [anon_sym_equals] = ACTIONS(4310),
    [anon_sym_by] = ACTIONS(4310),
    [anon_sym_as] = ACTIONS(4310),
    [anon_sym_is] = ACTIONS(4310),
    [anon_sym_DASH_GT] = ACTIONS(4310),
    [anon_sym_with] = ACTIONS(4310),
    [aux_sym_preproc_if_token3] = ACTIONS(4310),
    [aux_sym_preproc_else_token1] = ACTIONS(4310),
    [aux_sym_preproc_elif_token1] = ACTIONS(4310),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4164] = {
    [sym_preproc_region] = STATE(4164),
    [sym_preproc_endregion] = STATE(4164),
    [sym_preproc_line] = STATE(4164),
    [sym_preproc_pragma] = STATE(4164),
    [sym_preproc_nullable] = STATE(4164),
    [sym_preproc_error] = STATE(4164),
    [sym_preproc_warning] = STATE(4164),
    [sym_preproc_define] = STATE(4164),
    [sym_preproc_undef] = STATE(4164),
    [anon_sym_SEMI] = ACTIONS(4806),
    [anon_sym_LBRACK] = ACTIONS(5883),
    [anon_sym_COLON] = ACTIONS(4806),
    [anon_sym_COMMA] = ACTIONS(4806),
    [anon_sym_RBRACK] = ACTIONS(4806),
    [anon_sym_LPAREN] = ACTIONS(5883),
    [anon_sym_RPAREN] = ACTIONS(4806),
    [anon_sym_RBRACE] = ACTIONS(4806),
    [anon_sym_LT] = ACTIONS(5886),
    [anon_sym_GT] = ACTIONS(5886),
    [anon_sym_in] = ACTIONS(4806),
    [anon_sym_QMARK] = ACTIONS(5886),
    [anon_sym_BANG] = ACTIONS(5886),
    [anon_sym_PLUS_PLUS] = ACTIONS(5883),
    [anon_sym_DASH_DASH] = ACTIONS(5883),
    [anon_sym_PLUS] = ACTIONS(5886),
    [anon_sym_DASH] = ACTIONS(5886),
    [anon_sym_STAR] = ACTIONS(5883),
    [anon_sym_SLASH] = ACTIONS(5886),
    [anon_sym_PERCENT] = ACTIONS(5883),
    [anon_sym_CARET] = ACTIONS(5883),
    [anon_sym_PIPE] = ACTIONS(5886),
    [anon_sym_AMP] = ACTIONS(5886),
    [anon_sym_LT_LT] = ACTIONS(5883),
    [anon_sym_GT_GT] = ACTIONS(5886),
    [anon_sym_GT_GT_GT] = ACTIONS(5883),
    [anon_sym_EQ_EQ] = ACTIONS(5883),
    [anon_sym_BANG_EQ] = ACTIONS(5883),
    [anon_sym_GT_EQ] = ACTIONS(5883),
    [anon_sym_LT_EQ] = ACTIONS(5883),
    [anon_sym_DOT] = ACTIONS(5886),
    [anon_sym_EQ_GT] = ACTIONS(4806),
    [anon_sym_switch] = ACTIONS(5883),
    [anon_sym_when] = ACTIONS(4806),
    [anon_sym_DOT_DOT] = ACTIONS(5883),
    [anon_sym_and] = ACTIONS(4806),
    [anon_sym_or] = ACTIONS(4806),
    [anon_sym_AMP_AMP] = ACTIONS(5883),
    [anon_sym_PIPE_PIPE] = ACTIONS(5883),
    [anon_sym_QMARK_QMARK] = ACTIONS(5883),
    [anon_sym_on] = ACTIONS(4806),
    [anon_sym_equals] = ACTIONS(4806),
    [anon_sym_by] = ACTIONS(4806),
    [anon_sym_as] = ACTIONS(5883),
    [anon_sym_is] = ACTIONS(5883),
    [anon_sym_DASH_GT] = ACTIONS(5883),
    [anon_sym_with] = ACTIONS(5883),
    [aux_sym_preproc_if_token3] = ACTIONS(4806),
    [aux_sym_preproc_else_token1] = ACTIONS(4806),
    [aux_sym_preproc_elif_token1] = ACTIONS(4806),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4165] = {
    [sym_preproc_region] = STATE(4165),
    [sym_preproc_endregion] = STATE(4165),
    [sym_preproc_line] = STATE(4165),
    [sym_preproc_pragma] = STATE(4165),
    [sym_preproc_nullable] = STATE(4165),
    [sym_preproc_error] = STATE(4165),
    [sym_preproc_warning] = STATE(4165),
    [sym_preproc_define] = STATE(4165),
    [sym_preproc_undef] = STATE(4165),
    [anon_sym_SEMI] = ACTIONS(4806),
    [anon_sym_LBRACK] = ACTIONS(5889),
    [anon_sym_COLON] = ACTIONS(4806),
    [anon_sym_COMMA] = ACTIONS(4806),
    [anon_sym_RBRACK] = ACTIONS(4806),
    [anon_sym_LPAREN] = ACTIONS(5889),
    [anon_sym_RPAREN] = ACTIONS(4806),
    [anon_sym_RBRACE] = ACTIONS(4806),
    [anon_sym_LT] = ACTIONS(5892),
    [anon_sym_GT] = ACTIONS(5892),
    [anon_sym_in] = ACTIONS(4806),
    [anon_sym_QMARK] = ACTIONS(5892),
    [anon_sym_BANG] = ACTIONS(5892),
    [anon_sym_PLUS_PLUS] = ACTIONS(5889),
    [anon_sym_DASH_DASH] = ACTIONS(5889),
    [anon_sym_PLUS] = ACTIONS(5892),
    [anon_sym_DASH] = ACTIONS(5892),
    [anon_sym_STAR] = ACTIONS(5889),
    [anon_sym_SLASH] = ACTIONS(5892),
    [anon_sym_PERCENT] = ACTIONS(5889),
    [anon_sym_CARET] = ACTIONS(5889),
    [anon_sym_PIPE] = ACTIONS(5892),
    [anon_sym_AMP] = ACTIONS(5892),
    [anon_sym_LT_LT] = ACTIONS(5889),
    [anon_sym_GT_GT] = ACTIONS(5892),
    [anon_sym_GT_GT_GT] = ACTIONS(5889),
    [anon_sym_EQ_EQ] = ACTIONS(5889),
    [anon_sym_BANG_EQ] = ACTIONS(5889),
    [anon_sym_GT_EQ] = ACTIONS(5889),
    [anon_sym_LT_EQ] = ACTIONS(5889),
    [anon_sym_DOT] = ACTIONS(5892),
    [anon_sym_EQ_GT] = ACTIONS(4806),
    [anon_sym_switch] = ACTIONS(5889),
    [anon_sym_when] = ACTIONS(4806),
    [anon_sym_DOT_DOT] = ACTIONS(5889),
    [anon_sym_and] = ACTIONS(4806),
    [anon_sym_or] = ACTIONS(4806),
    [anon_sym_AMP_AMP] = ACTIONS(5889),
    [anon_sym_PIPE_PIPE] = ACTIONS(5889),
    [anon_sym_QMARK_QMARK] = ACTIONS(5889),
    [anon_sym_on] = ACTIONS(4806),
    [anon_sym_equals] = ACTIONS(4806),
    [anon_sym_by] = ACTIONS(4806),
    [anon_sym_as] = ACTIONS(5889),
    [anon_sym_is] = ACTIONS(5889),
    [anon_sym_DASH_GT] = ACTIONS(5889),
    [anon_sym_with] = ACTIONS(5889),
    [aux_sym_preproc_if_token3] = ACTIONS(4806),
    [aux_sym_preproc_else_token1] = ACTIONS(4806),
    [aux_sym_preproc_elif_token1] = ACTIONS(4806),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4166] = {
    [sym_preproc_region] = STATE(4166),
    [sym_preproc_endregion] = STATE(4166),
    [sym_preproc_line] = STATE(4166),
    [sym_preproc_pragma] = STATE(4166),
    [sym_preproc_nullable] = STATE(4166),
    [sym_preproc_error] = STATE(4166),
    [sym_preproc_warning] = STATE(4166),
    [sym_preproc_define] = STATE(4166),
    [sym_preproc_undef] = STATE(4166),
    [anon_sym_SEMI] = ACTIONS(5913),
    [anon_sym_LBRACK] = ACTIONS(5913),
    [anon_sym_COLON] = ACTIONS(5913),
    [anon_sym_COMMA] = ACTIONS(5913),
    [anon_sym_RBRACK] = ACTIONS(5913),
    [anon_sym_LPAREN] = ACTIONS(5913),
    [anon_sym_RPAREN] = ACTIONS(5913),
    [anon_sym_RBRACE] = ACTIONS(5913),
    [anon_sym_LT] = ACTIONS(5915),
    [anon_sym_GT] = ACTIONS(5915),
    [anon_sym_in] = ACTIONS(5913),
    [anon_sym_QMARK] = ACTIONS(5915),
    [anon_sym_BANG] = ACTIONS(5915),
    [anon_sym_PLUS_PLUS] = ACTIONS(5913),
    [anon_sym_DASH_DASH] = ACTIONS(5913),
    [anon_sym_PLUS] = ACTIONS(5915),
    [anon_sym_DASH] = ACTIONS(5915),
    [anon_sym_STAR] = ACTIONS(5913),
    [anon_sym_SLASH] = ACTIONS(5915),
    [anon_sym_PERCENT] = ACTIONS(5913),
    [anon_sym_CARET] = ACTIONS(5913),
    [anon_sym_PIPE] = ACTIONS(5915),
    [anon_sym_AMP] = ACTIONS(5915),
    [anon_sym_LT_LT] = ACTIONS(5913),
    [anon_sym_GT_GT] = ACTIONS(5915),
    [anon_sym_GT_GT_GT] = ACTIONS(5913),
    [anon_sym_EQ_EQ] = ACTIONS(5913),
    [anon_sym_BANG_EQ] = ACTIONS(5913),
    [anon_sym_GT_EQ] = ACTIONS(5913),
    [anon_sym_LT_EQ] = ACTIONS(5913),
    [anon_sym_DOT] = ACTIONS(5915),
    [anon_sym_EQ_GT] = ACTIONS(5913),
    [anon_sym_switch] = ACTIONS(5913),
    [anon_sym_when] = ACTIONS(5913),
    [anon_sym_DOT_DOT] = ACTIONS(5913),
    [anon_sym_and] = ACTIONS(5913),
    [anon_sym_or] = ACTIONS(5913),
    [anon_sym_AMP_AMP] = ACTIONS(5913),
    [anon_sym_PIPE_PIPE] = ACTIONS(5913),
    [anon_sym_QMARK_QMARK] = ACTIONS(5913),
    [anon_sym_on] = ACTIONS(5913),
    [anon_sym_equals] = ACTIONS(5913),
    [anon_sym_by] = ACTIONS(5913),
    [anon_sym_as] = ACTIONS(5913),
    [anon_sym_is] = ACTIONS(5913),
    [anon_sym_DASH_GT] = ACTIONS(5913),
    [anon_sym_with] = ACTIONS(5913),
    [aux_sym_preproc_if_token3] = ACTIONS(5913),
    [aux_sym_preproc_else_token1] = ACTIONS(5913),
    [aux_sym_preproc_elif_token1] = ACTIONS(5913),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4167] = {
    [sym_preproc_region] = STATE(4167),
    [sym_preproc_endregion] = STATE(4167),
    [sym_preproc_line] = STATE(4167),
    [sym_preproc_pragma] = STATE(4167),
    [sym_preproc_nullable] = STATE(4167),
    [sym_preproc_error] = STATE(4167),
    [sym_preproc_warning] = STATE(4167),
    [sym_preproc_define] = STATE(4167),
    [sym_preproc_undef] = STATE(4167),
    [anon_sym_SEMI] = ACTIONS(5913),
    [anon_sym_LBRACK] = ACTIONS(5913),
    [anon_sym_COLON] = ACTIONS(5913),
    [anon_sym_COMMA] = ACTIONS(5913),
    [anon_sym_RBRACK] = ACTIONS(5913),
    [anon_sym_LPAREN] = ACTIONS(5913),
    [anon_sym_RPAREN] = ACTIONS(5913),
    [anon_sym_RBRACE] = ACTIONS(5913),
    [anon_sym_LT] = ACTIONS(5915),
    [anon_sym_GT] = ACTIONS(5915),
    [anon_sym_in] = ACTIONS(5913),
    [anon_sym_QMARK] = ACTIONS(5915),
    [anon_sym_BANG] = ACTIONS(5915),
    [anon_sym_PLUS_PLUS] = ACTIONS(5913),
    [anon_sym_DASH_DASH] = ACTIONS(5913),
    [anon_sym_PLUS] = ACTIONS(5915),
    [anon_sym_DASH] = ACTIONS(5915),
    [anon_sym_STAR] = ACTIONS(5913),
    [anon_sym_SLASH] = ACTIONS(5915),
    [anon_sym_PERCENT] = ACTIONS(5913),
    [anon_sym_CARET] = ACTIONS(5913),
    [anon_sym_PIPE] = ACTIONS(5915),
    [anon_sym_AMP] = ACTIONS(5915),
    [anon_sym_LT_LT] = ACTIONS(5913),
    [anon_sym_GT_GT] = ACTIONS(5915),
    [anon_sym_GT_GT_GT] = ACTIONS(5913),
    [anon_sym_EQ_EQ] = ACTIONS(5913),
    [anon_sym_BANG_EQ] = ACTIONS(5913),
    [anon_sym_GT_EQ] = ACTIONS(5913),
    [anon_sym_LT_EQ] = ACTIONS(5913),
    [anon_sym_DOT] = ACTIONS(5915),
    [anon_sym_EQ_GT] = ACTIONS(5913),
    [anon_sym_switch] = ACTIONS(5913),
    [anon_sym_when] = ACTIONS(5913),
    [anon_sym_DOT_DOT] = ACTIONS(5913),
    [anon_sym_and] = ACTIONS(5913),
    [anon_sym_or] = ACTIONS(5913),
    [anon_sym_AMP_AMP] = ACTIONS(5913),
    [anon_sym_PIPE_PIPE] = ACTIONS(5913),
    [anon_sym_QMARK_QMARK] = ACTIONS(5913),
    [anon_sym_on] = ACTIONS(5913),
    [anon_sym_equals] = ACTIONS(5913),
    [anon_sym_by] = ACTIONS(5913),
    [anon_sym_as] = ACTIONS(5913),
    [anon_sym_is] = ACTIONS(5913),
    [anon_sym_DASH_GT] = ACTIONS(5913),
    [anon_sym_with] = ACTIONS(5913),
    [aux_sym_preproc_if_token3] = ACTIONS(5913),
    [aux_sym_preproc_else_token1] = ACTIONS(5913),
    [aux_sym_preproc_elif_token1] = ACTIONS(5913),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4168] = {
    [sym_preproc_region] = STATE(4168),
    [sym_preproc_endregion] = STATE(4168),
    [sym_preproc_line] = STATE(4168),
    [sym_preproc_pragma] = STATE(4168),
    [sym_preproc_nullable] = STATE(4168),
    [sym_preproc_error] = STATE(4168),
    [sym_preproc_warning] = STATE(4168),
    [sym_preproc_define] = STATE(4168),
    [sym_preproc_undef] = STATE(4168),
    [anon_sym_SEMI] = ACTIONS(5678),
    [anon_sym_LBRACK] = ACTIONS(5678),
    [anon_sym_COLON] = ACTIONS(5678),
    [anon_sym_COMMA] = ACTIONS(5678),
    [anon_sym_RBRACK] = ACTIONS(5678),
    [anon_sym_LPAREN] = ACTIONS(5678),
    [anon_sym_RPAREN] = ACTIONS(5678),
    [anon_sym_RBRACE] = ACTIONS(5678),
    [anon_sym_LT] = ACTIONS(5680),
    [anon_sym_GT] = ACTIONS(5680),
    [anon_sym_in] = ACTIONS(5678),
    [anon_sym_QMARK] = ACTIONS(5680),
    [anon_sym_BANG] = ACTIONS(5680),
    [anon_sym_PLUS_PLUS] = ACTIONS(5678),
    [anon_sym_DASH_DASH] = ACTIONS(5678),
    [anon_sym_PLUS] = ACTIONS(5680),
    [anon_sym_DASH] = ACTIONS(5680),
    [anon_sym_STAR] = ACTIONS(5678),
    [anon_sym_SLASH] = ACTIONS(5680),
    [anon_sym_PERCENT] = ACTIONS(5678),
    [anon_sym_CARET] = ACTIONS(5678),
    [anon_sym_PIPE] = ACTIONS(5680),
    [anon_sym_AMP] = ACTIONS(5680),
    [anon_sym_LT_LT] = ACTIONS(5678),
    [anon_sym_GT_GT] = ACTIONS(5680),
    [anon_sym_GT_GT_GT] = ACTIONS(5678),
    [anon_sym_EQ_EQ] = ACTIONS(5678),
    [anon_sym_BANG_EQ] = ACTIONS(5678),
    [anon_sym_GT_EQ] = ACTIONS(5678),
    [anon_sym_LT_EQ] = ACTIONS(5678),
    [anon_sym_DOT] = ACTIONS(5680),
    [anon_sym_EQ_GT] = ACTIONS(5678),
    [anon_sym_switch] = ACTIONS(5678),
    [anon_sym_when] = ACTIONS(5678),
    [anon_sym_DOT_DOT] = ACTIONS(5678),
    [anon_sym_and] = ACTIONS(5678),
    [anon_sym_or] = ACTIONS(5678),
    [anon_sym_AMP_AMP] = ACTIONS(5678),
    [anon_sym_PIPE_PIPE] = ACTIONS(5678),
    [anon_sym_QMARK_QMARK] = ACTIONS(5678),
    [anon_sym_on] = ACTIONS(5678),
    [anon_sym_equals] = ACTIONS(5678),
    [anon_sym_by] = ACTIONS(5678),
    [anon_sym_as] = ACTIONS(5678),
    [anon_sym_is] = ACTIONS(5678),
    [anon_sym_DASH_GT] = ACTIONS(5678),
    [anon_sym_with] = ACTIONS(5678),
    [aux_sym_preproc_if_token3] = ACTIONS(5678),
    [aux_sym_preproc_else_token1] = ACTIONS(5678),
    [aux_sym_preproc_elif_token1] = ACTIONS(5678),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4169] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7103),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9498),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4169),
    [sym_preproc_endregion] = STATE(4169),
    [sym_preproc_line] = STATE(4169),
    [sym_preproc_pragma] = STATE(4169),
    [sym_preproc_nullable] = STATE(4169),
    [sym_preproc_error] = STATE(4169),
    [sym_preproc_warning] = STATE(4169),
    [sym_preproc_define] = STATE(4169),
    [sym_preproc_undef] = STATE(4169),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(6019),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4170] = {
    [sym_preproc_region] = STATE(4170),
    [sym_preproc_endregion] = STATE(4170),
    [sym_preproc_line] = STATE(4170),
    [sym_preproc_pragma] = STATE(4170),
    [sym_preproc_nullable] = STATE(4170),
    [sym_preproc_error] = STATE(4170),
    [sym_preproc_warning] = STATE(4170),
    [sym_preproc_define] = STATE(4170),
    [sym_preproc_undef] = STATE(4170),
    [anon_sym_SEMI] = ACTIONS(5652),
    [anon_sym_LBRACK] = ACTIONS(5652),
    [anon_sym_COLON] = ACTIONS(5652),
    [anon_sym_COMMA] = ACTIONS(5652),
    [anon_sym_RBRACK] = ACTIONS(5652),
    [anon_sym_LPAREN] = ACTIONS(5652),
    [anon_sym_RPAREN] = ACTIONS(5652),
    [anon_sym_RBRACE] = ACTIONS(5652),
    [anon_sym_LT] = ACTIONS(5654),
    [anon_sym_GT] = ACTIONS(5654),
    [anon_sym_in] = ACTIONS(5652),
    [anon_sym_QMARK] = ACTIONS(5654),
    [anon_sym_BANG] = ACTIONS(5654),
    [anon_sym_PLUS_PLUS] = ACTIONS(5652),
    [anon_sym_DASH_DASH] = ACTIONS(5652),
    [anon_sym_PLUS] = ACTIONS(5654),
    [anon_sym_DASH] = ACTIONS(5654),
    [anon_sym_STAR] = ACTIONS(5652),
    [anon_sym_SLASH] = ACTIONS(5654),
    [anon_sym_PERCENT] = ACTIONS(5652),
    [anon_sym_CARET] = ACTIONS(5652),
    [anon_sym_PIPE] = ACTIONS(5654),
    [anon_sym_AMP] = ACTIONS(5654),
    [anon_sym_LT_LT] = ACTIONS(5652),
    [anon_sym_GT_GT] = ACTIONS(5654),
    [anon_sym_GT_GT_GT] = ACTIONS(5652),
    [anon_sym_EQ_EQ] = ACTIONS(5652),
    [anon_sym_BANG_EQ] = ACTIONS(5652),
    [anon_sym_GT_EQ] = ACTIONS(5652),
    [anon_sym_LT_EQ] = ACTIONS(5652),
    [anon_sym_DOT] = ACTIONS(5654),
    [anon_sym_EQ_GT] = ACTIONS(5652),
    [anon_sym_switch] = ACTIONS(5652),
    [anon_sym_when] = ACTIONS(5652),
    [anon_sym_DOT_DOT] = ACTIONS(5652),
    [anon_sym_and] = ACTIONS(5652),
    [anon_sym_or] = ACTIONS(5652),
    [anon_sym_AMP_AMP] = ACTIONS(5652),
    [anon_sym_PIPE_PIPE] = ACTIONS(5652),
    [anon_sym_QMARK_QMARK] = ACTIONS(5652),
    [anon_sym_on] = ACTIONS(5652),
    [anon_sym_equals] = ACTIONS(5652),
    [anon_sym_by] = ACTIONS(5652),
    [anon_sym_as] = ACTIONS(5652),
    [anon_sym_is] = ACTIONS(5652),
    [anon_sym_DASH_GT] = ACTIONS(5652),
    [anon_sym_with] = ACTIONS(5652),
    [aux_sym_preproc_if_token3] = ACTIONS(5652),
    [aux_sym_preproc_else_token1] = ACTIONS(5652),
    [aux_sym_preproc_elif_token1] = ACTIONS(5652),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4171] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7113),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9652),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4171),
    [sym_preproc_endregion] = STATE(4171),
    [sym_preproc_line] = STATE(4171),
    [sym_preproc_pragma] = STATE(4171),
    [sym_preproc_nullable] = STATE(4171),
    [sym_preproc_error] = STATE(4171),
    [sym_preproc_warning] = STATE(4171),
    [sym_preproc_define] = STATE(4171),
    [sym_preproc_undef] = STATE(4171),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4172] = {
    [sym__name] = STATE(7882),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(9715),
    [sym_implicit_type] = STATE(8747),
    [sym_array_type] = STATE(8331),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(8345),
    [sym_pointer_type] = STATE(8345),
    [sym__pointer_base_type] = STATE(9367),
    [sym_function_pointer_type] = STATE(8345),
    [sym_function_pointer_parameter] = STATE(9589),
    [sym_ref_type] = STATE(8787),
    [sym__ref_base_type] = STATE(9629),
    [sym_scoped_type] = STATE(8787),
    [sym_tuple_type] = STATE(8056),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4172),
    [sym_preproc_endregion] = STATE(4172),
    [sym_preproc_line] = STATE(4172),
    [sym_preproc_pragma] = STATE(4172),
    [sym_preproc_nullable] = STATE(4172),
    [sym_preproc_error] = STATE(4172),
    [sym_preproc_warning] = STATE(4172),
    [sym_preproc_define] = STATE(4172),
    [sym_preproc_undef] = STATE(4172),
    [aux_sym_function_pointer_type_repeat1] = STATE(4173),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(5976),
    [anon_sym_delegate] = ACTIONS(5747),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_in] = ACTIONS(5978),
    [anon_sym_out] = ACTIONS(5978),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(5980),
    [anon_sym_var] = ACTIONS(5369),
    [sym_predefined_type] = ACTIONS(5982),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4173] = {
    [sym__name] = STATE(7882),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(9886),
    [sym_implicit_type] = STATE(8747),
    [sym_array_type] = STATE(8331),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(8345),
    [sym_pointer_type] = STATE(8345),
    [sym__pointer_base_type] = STATE(9367),
    [sym_function_pointer_type] = STATE(8345),
    [sym_function_pointer_parameter] = STATE(9589),
    [sym_ref_type] = STATE(8787),
    [sym__ref_base_type] = STATE(9629),
    [sym_scoped_type] = STATE(8787),
    [sym_tuple_type] = STATE(8056),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4173),
    [sym_preproc_endregion] = STATE(4173),
    [sym_preproc_line] = STATE(4173),
    [sym_preproc_pragma] = STATE(4173),
    [sym_preproc_nullable] = STATE(4173),
    [sym_preproc_error] = STATE(4173),
    [sym_preproc_warning] = STATE(4173),
    [sym_preproc_define] = STATE(4173),
    [sym_preproc_undef] = STATE(4173),
    [aux_sym_function_pointer_type_repeat1] = STATE(4540),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(5976),
    [anon_sym_delegate] = ACTIONS(5747),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_in] = ACTIONS(5978),
    [anon_sym_out] = ACTIONS(5978),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(5980),
    [anon_sym_var] = ACTIONS(5369),
    [sym_predefined_type] = ACTIONS(5982),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4174] = {
    [sym__name] = STATE(7882),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(9886),
    [sym_implicit_type] = STATE(8747),
    [sym_array_type] = STATE(8331),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(8345),
    [sym_pointer_type] = STATE(8345),
    [sym__pointer_base_type] = STATE(9367),
    [sym_function_pointer_type] = STATE(8345),
    [sym_function_pointer_parameter] = STATE(9589),
    [sym_ref_type] = STATE(8787),
    [sym__ref_base_type] = STATE(9629),
    [sym_scoped_type] = STATE(8787),
    [sym_tuple_type] = STATE(8056),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4174),
    [sym_preproc_endregion] = STATE(4174),
    [sym_preproc_line] = STATE(4174),
    [sym_preproc_pragma] = STATE(4174),
    [sym_preproc_nullable] = STATE(4174),
    [sym_preproc_error] = STATE(4174),
    [sym_preproc_warning] = STATE(4174),
    [sym_preproc_define] = STATE(4174),
    [sym_preproc_undef] = STATE(4174),
    [aux_sym_function_pointer_type_repeat1] = STATE(4175),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(5976),
    [anon_sym_delegate] = ACTIONS(5747),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_in] = ACTIONS(5978),
    [anon_sym_out] = ACTIONS(5978),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(5980),
    [anon_sym_var] = ACTIONS(5369),
    [sym_predefined_type] = ACTIONS(5982),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4175] = {
    [sym__name] = STATE(7882),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(9967),
    [sym_implicit_type] = STATE(8747),
    [sym_array_type] = STATE(8331),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(8345),
    [sym_pointer_type] = STATE(8345),
    [sym__pointer_base_type] = STATE(9367),
    [sym_function_pointer_type] = STATE(8345),
    [sym_function_pointer_parameter] = STATE(9589),
    [sym_ref_type] = STATE(8787),
    [sym__ref_base_type] = STATE(9629),
    [sym_scoped_type] = STATE(8787),
    [sym_tuple_type] = STATE(8056),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4175),
    [sym_preproc_endregion] = STATE(4175),
    [sym_preproc_line] = STATE(4175),
    [sym_preproc_pragma] = STATE(4175),
    [sym_preproc_nullable] = STATE(4175),
    [sym_preproc_error] = STATE(4175),
    [sym_preproc_warning] = STATE(4175),
    [sym_preproc_define] = STATE(4175),
    [sym_preproc_undef] = STATE(4175),
    [aux_sym_function_pointer_type_repeat1] = STATE(4540),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(5976),
    [anon_sym_delegate] = ACTIONS(5747),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_in] = ACTIONS(5978),
    [anon_sym_out] = ACTIONS(5978),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(5980),
    [anon_sym_var] = ACTIONS(5369),
    [sym_predefined_type] = ACTIONS(5982),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4176] = {
    [sym_preproc_region] = STATE(4176),
    [sym_preproc_endregion] = STATE(4176),
    [sym_preproc_line] = STATE(4176),
    [sym_preproc_pragma] = STATE(4176),
    [sym_preproc_nullable] = STATE(4176),
    [sym_preproc_error] = STATE(4176),
    [sym_preproc_warning] = STATE(4176),
    [sym_preproc_define] = STATE(4176),
    [sym_preproc_undef] = STATE(4176),
    [anon_sym_SEMI] = ACTIONS(2031),
    [anon_sym_LBRACK] = ACTIONS(2031),
    [anon_sym_COLON] = ACTIONS(2031),
    [anon_sym_COMMA] = ACTIONS(2031),
    [anon_sym_RBRACK] = ACTIONS(2031),
    [anon_sym_LPAREN] = ACTIONS(6021),
    [anon_sym_RPAREN] = ACTIONS(2031),
    [anon_sym_RBRACE] = ACTIONS(2031),
    [anon_sym_LT] = ACTIONS(2029),
    [anon_sym_GT] = ACTIONS(2029),
    [anon_sym_in] = ACTIONS(2031),
    [anon_sym_QMARK] = ACTIONS(2029),
    [anon_sym_BANG] = ACTIONS(2029),
    [anon_sym_PLUS_PLUS] = ACTIONS(2031),
    [anon_sym_DASH_DASH] = ACTIONS(2031),
    [anon_sym_PLUS] = ACTIONS(2029),
    [anon_sym_DASH] = ACTIONS(2029),
    [anon_sym_STAR] = ACTIONS(2031),
    [anon_sym_SLASH] = ACTIONS(2029),
    [anon_sym_PERCENT] = ACTIONS(2031),
    [anon_sym_CARET] = ACTIONS(2031),
    [anon_sym_PIPE] = ACTIONS(2029),
    [anon_sym_AMP] = ACTIONS(2029),
    [anon_sym_LT_LT] = ACTIONS(2031),
    [anon_sym_GT_GT] = ACTIONS(2029),
    [anon_sym_GT_GT_GT] = ACTIONS(2031),
    [anon_sym_EQ_EQ] = ACTIONS(2031),
    [anon_sym_BANG_EQ] = ACTIONS(2031),
    [anon_sym_GT_EQ] = ACTIONS(2031),
    [anon_sym_LT_EQ] = ACTIONS(2031),
    [anon_sym_DOT] = ACTIONS(2029),
    [anon_sym_EQ_GT] = ACTIONS(2031),
    [anon_sym_switch] = ACTIONS(2031),
    [anon_sym_when] = ACTIONS(2031),
    [anon_sym_DOT_DOT] = ACTIONS(2031),
    [anon_sym_and] = ACTIONS(2031),
    [anon_sym_or] = ACTIONS(2031),
    [anon_sym_AMP_AMP] = ACTIONS(2031),
    [anon_sym_PIPE_PIPE] = ACTIONS(2031),
    [anon_sym_QMARK_QMARK] = ACTIONS(2031),
    [anon_sym_on] = ACTIONS(2031),
    [anon_sym_equals] = ACTIONS(2031),
    [anon_sym_by] = ACTIONS(2031),
    [anon_sym_as] = ACTIONS(2031),
    [anon_sym_is] = ACTIONS(2031),
    [anon_sym_DASH_GT] = ACTIONS(2031),
    [anon_sym_with] = ACTIONS(2031),
    [aux_sym_preproc_if_token3] = ACTIONS(2031),
    [aux_sym_preproc_else_token1] = ACTIONS(2031),
    [aux_sym_preproc_elif_token1] = ACTIONS(2031),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4177] = {
    [sym_preproc_region] = STATE(4177),
    [sym_preproc_endregion] = STATE(4177),
    [sym_preproc_line] = STATE(4177),
    [sym_preproc_pragma] = STATE(4177),
    [sym_preproc_nullable] = STATE(4177),
    [sym_preproc_error] = STATE(4177),
    [sym_preproc_warning] = STATE(4177),
    [sym_preproc_define] = STATE(4177),
    [sym_preproc_undef] = STATE(4177),
    [anon_sym_SEMI] = ACTIONS(5401),
    [anon_sym_LBRACK] = ACTIONS(5401),
    [anon_sym_COLON] = ACTIONS(5401),
    [anon_sym_COMMA] = ACTIONS(5401),
    [anon_sym_RBRACK] = ACTIONS(5401),
    [anon_sym_LPAREN] = ACTIONS(5401),
    [anon_sym_RPAREN] = ACTIONS(5401),
    [anon_sym_RBRACE] = ACTIONS(5401),
    [anon_sym_LT] = ACTIONS(5403),
    [anon_sym_GT] = ACTIONS(5403),
    [anon_sym_in] = ACTIONS(5401),
    [anon_sym_QMARK] = ACTIONS(5403),
    [anon_sym_BANG] = ACTIONS(5403),
    [anon_sym_PLUS_PLUS] = ACTIONS(5401),
    [anon_sym_DASH_DASH] = ACTIONS(5401),
    [anon_sym_PLUS] = ACTIONS(5403),
    [anon_sym_DASH] = ACTIONS(5403),
    [anon_sym_STAR] = ACTIONS(5401),
    [anon_sym_SLASH] = ACTIONS(5403),
    [anon_sym_PERCENT] = ACTIONS(5401),
    [anon_sym_CARET] = ACTIONS(5401),
    [anon_sym_PIPE] = ACTIONS(5403),
    [anon_sym_AMP] = ACTIONS(5403),
    [anon_sym_LT_LT] = ACTIONS(5401),
    [anon_sym_GT_GT] = ACTIONS(5403),
    [anon_sym_GT_GT_GT] = ACTIONS(5401),
    [anon_sym_EQ_EQ] = ACTIONS(5401),
    [anon_sym_BANG_EQ] = ACTIONS(5401),
    [anon_sym_GT_EQ] = ACTIONS(5401),
    [anon_sym_LT_EQ] = ACTIONS(5401),
    [anon_sym_DOT] = ACTIONS(5403),
    [anon_sym_EQ_GT] = ACTIONS(5401),
    [anon_sym_switch] = ACTIONS(5401),
    [anon_sym_when] = ACTIONS(5401),
    [anon_sym_DOT_DOT] = ACTIONS(5401),
    [anon_sym_and] = ACTIONS(5401),
    [anon_sym_or] = ACTIONS(5401),
    [anon_sym_AMP_AMP] = ACTIONS(5401),
    [anon_sym_PIPE_PIPE] = ACTIONS(5401),
    [anon_sym_QMARK_QMARK] = ACTIONS(5401),
    [anon_sym_on] = ACTIONS(5401),
    [anon_sym_equals] = ACTIONS(5401),
    [anon_sym_by] = ACTIONS(5401),
    [anon_sym_as] = ACTIONS(5401),
    [anon_sym_is] = ACTIONS(5401),
    [anon_sym_DASH_GT] = ACTIONS(5401),
    [anon_sym_with] = ACTIONS(5401),
    [aux_sym_preproc_if_token3] = ACTIONS(5401),
    [aux_sym_preproc_else_token1] = ACTIONS(5401),
    [aux_sym_preproc_elif_token1] = ACTIONS(5401),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4178] = {
    [sym_preproc_region] = STATE(4178),
    [sym_preproc_endregion] = STATE(4178),
    [sym_preproc_line] = STATE(4178),
    [sym_preproc_pragma] = STATE(4178),
    [sym_preproc_nullable] = STATE(4178),
    [sym_preproc_error] = STATE(4178),
    [sym_preproc_warning] = STATE(4178),
    [sym_preproc_define] = STATE(4178),
    [sym_preproc_undef] = STATE(4178),
    [anon_sym_EQ] = ACTIONS(6023),
    [anon_sym_LBRACK] = ACTIONS(5286),
    [anon_sym_LPAREN] = ACTIONS(5286),
    [anon_sym_LT] = ACTIONS(5288),
    [anon_sym_GT] = ACTIONS(5288),
    [anon_sym_QMARK] = ACTIONS(5288),
    [anon_sym_BANG] = ACTIONS(5288),
    [anon_sym_PLUS_PLUS] = ACTIONS(5286),
    [anon_sym_DASH_DASH] = ACTIONS(5286),
    [anon_sym_PLUS] = ACTIONS(5288),
    [anon_sym_DASH] = ACTIONS(5288),
    [anon_sym_STAR] = ACTIONS(5288),
    [anon_sym_SLASH] = ACTIONS(5288),
    [anon_sym_PERCENT] = ACTIONS(5288),
    [anon_sym_CARET] = ACTIONS(5288),
    [anon_sym_PIPE] = ACTIONS(5288),
    [anon_sym_AMP] = ACTIONS(5288),
    [anon_sym_LT_LT] = ACTIONS(5288),
    [anon_sym_GT_GT] = ACTIONS(5288),
    [anon_sym_GT_GT_GT] = ACTIONS(5288),
    [anon_sym_EQ_EQ] = ACTIONS(5286),
    [anon_sym_BANG_EQ] = ACTIONS(5286),
    [anon_sym_GT_EQ] = ACTIONS(5286),
    [anon_sym_LT_EQ] = ACTIONS(5286),
    [anon_sym_DOT] = ACTIONS(5288),
    [anon_sym_EQ_GT] = ACTIONS(5286),
    [anon_sym_switch] = ACTIONS(5286),
    [anon_sym_when] = ACTIONS(5286),
    [anon_sym_DOT_DOT] = ACTIONS(5286),
    [anon_sym_and] = ACTIONS(5286),
    [anon_sym_or] = ACTIONS(5286),
    [anon_sym_PLUS_EQ] = ACTIONS(6025),
    [anon_sym_DASH_EQ] = ACTIONS(6025),
    [anon_sym_STAR_EQ] = ACTIONS(6025),
    [anon_sym_SLASH_EQ] = ACTIONS(6025),
    [anon_sym_PERCENT_EQ] = ACTIONS(6025),
    [anon_sym_AMP_EQ] = ACTIONS(6025),
    [anon_sym_CARET_EQ] = ACTIONS(6025),
    [anon_sym_PIPE_EQ] = ACTIONS(6025),
    [anon_sym_LT_LT_EQ] = ACTIONS(6025),
    [anon_sym_GT_GT_EQ] = ACTIONS(6025),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(6025),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(6025),
    [anon_sym_AMP_AMP] = ACTIONS(5286),
    [anon_sym_PIPE_PIPE] = ACTIONS(5286),
    [anon_sym_QMARK_QMARK] = ACTIONS(5288),
    [anon_sym_as] = ACTIONS(5286),
    [anon_sym_is] = ACTIONS(5286),
    [anon_sym_DASH_GT] = ACTIONS(5286),
    [anon_sym_with] = ACTIONS(5286),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4179] = {
    [sym_preproc_region] = STATE(4179),
    [sym_preproc_endregion] = STATE(4179),
    [sym_preproc_line] = STATE(4179),
    [sym_preproc_pragma] = STATE(4179),
    [sym_preproc_nullable] = STATE(4179),
    [sym_preproc_error] = STATE(4179),
    [sym_preproc_warning] = STATE(4179),
    [sym_preproc_define] = STATE(4179),
    [sym_preproc_undef] = STATE(4179),
    [anon_sym_EQ] = ACTIONS(4162),
    [anon_sym_LBRACK] = ACTIONS(4177),
    [anon_sym_COLON] = ACTIONS(4808),
    [anon_sym_LPAREN] = ACTIONS(4177),
    [anon_sym_LT] = ACTIONS(4162),
    [anon_sym_GT] = ACTIONS(4162),
    [anon_sym_QMARK] = ACTIONS(4162),
    [anon_sym_BANG] = ACTIONS(4162),
    [anon_sym_PLUS_PLUS] = ACTIONS(4177),
    [anon_sym_DASH_DASH] = ACTIONS(4177),
    [anon_sym_PLUS] = ACTIONS(4162),
    [anon_sym_DASH] = ACTIONS(4162),
    [anon_sym_STAR] = ACTIONS(4162),
    [anon_sym_SLASH] = ACTIONS(4162),
    [anon_sym_PERCENT] = ACTIONS(4162),
    [anon_sym_CARET] = ACTIONS(4162),
    [anon_sym_PIPE] = ACTIONS(4162),
    [anon_sym_AMP] = ACTIONS(4162),
    [anon_sym_LT_LT] = ACTIONS(4162),
    [anon_sym_GT_GT] = ACTIONS(4162),
    [anon_sym_GT_GT_GT] = ACTIONS(4162),
    [anon_sym_EQ_EQ] = ACTIONS(4177),
    [anon_sym_BANG_EQ] = ACTIONS(4177),
    [anon_sym_GT_EQ] = ACTIONS(4177),
    [anon_sym_LT_EQ] = ACTIONS(4177),
    [anon_sym_DOT] = ACTIONS(4162),
    [anon_sym_switch] = ACTIONS(4177),
    [anon_sym_when] = ACTIONS(4806),
    [anon_sym_DOT_DOT] = ACTIONS(4177),
    [anon_sym_and] = ACTIONS(4806),
    [anon_sym_or] = ACTIONS(4806),
    [anon_sym_PLUS_EQ] = ACTIONS(4177),
    [anon_sym_DASH_EQ] = ACTIONS(4177),
    [anon_sym_STAR_EQ] = ACTIONS(4177),
    [anon_sym_SLASH_EQ] = ACTIONS(4177),
    [anon_sym_PERCENT_EQ] = ACTIONS(4177),
    [anon_sym_AMP_EQ] = ACTIONS(4177),
    [anon_sym_CARET_EQ] = ACTIONS(4177),
    [anon_sym_PIPE_EQ] = ACTIONS(4177),
    [anon_sym_LT_LT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4177),
    [anon_sym_AMP_AMP] = ACTIONS(4177),
    [anon_sym_PIPE_PIPE] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK] = ACTIONS(4162),
    [anon_sym_as] = ACTIONS(4177),
    [anon_sym_is] = ACTIONS(4177),
    [anon_sym_DASH_GT] = ACTIONS(4177),
    [anon_sym_with] = ACTIONS(4177),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4180] = {
    [sym_preproc_region] = STATE(4180),
    [sym_preproc_endregion] = STATE(4180),
    [sym_preproc_line] = STATE(4180),
    [sym_preproc_pragma] = STATE(4180),
    [sym_preproc_nullable] = STATE(4180),
    [sym_preproc_error] = STATE(4180),
    [sym_preproc_warning] = STATE(4180),
    [sym_preproc_define] = STATE(4180),
    [sym_preproc_undef] = STATE(4180),
    [anon_sym_SEMI] = ACTIONS(5932),
    [anon_sym_LBRACK] = ACTIONS(5932),
    [anon_sym_COLON] = ACTIONS(5932),
    [anon_sym_COMMA] = ACTIONS(5932),
    [anon_sym_RBRACK] = ACTIONS(5932),
    [anon_sym_LPAREN] = ACTIONS(5932),
    [anon_sym_RPAREN] = ACTIONS(5932),
    [anon_sym_RBRACE] = ACTIONS(5932),
    [anon_sym_LT] = ACTIONS(5934),
    [anon_sym_GT] = ACTIONS(5934),
    [anon_sym_in] = ACTIONS(5932),
    [anon_sym_QMARK] = ACTIONS(5934),
    [anon_sym_BANG] = ACTIONS(5934),
    [anon_sym_PLUS_PLUS] = ACTIONS(5932),
    [anon_sym_DASH_DASH] = ACTIONS(5932),
    [anon_sym_PLUS] = ACTIONS(5934),
    [anon_sym_DASH] = ACTIONS(5934),
    [anon_sym_STAR] = ACTIONS(5932),
    [anon_sym_SLASH] = ACTIONS(5934),
    [anon_sym_PERCENT] = ACTIONS(5932),
    [anon_sym_CARET] = ACTIONS(5932),
    [anon_sym_PIPE] = ACTIONS(5934),
    [anon_sym_AMP] = ACTIONS(5934),
    [anon_sym_LT_LT] = ACTIONS(5932),
    [anon_sym_GT_GT] = ACTIONS(5934),
    [anon_sym_GT_GT_GT] = ACTIONS(5932),
    [anon_sym_EQ_EQ] = ACTIONS(5932),
    [anon_sym_BANG_EQ] = ACTIONS(5932),
    [anon_sym_GT_EQ] = ACTIONS(5932),
    [anon_sym_LT_EQ] = ACTIONS(5932),
    [anon_sym_DOT] = ACTIONS(5934),
    [anon_sym_EQ_GT] = ACTIONS(5932),
    [anon_sym_switch] = ACTIONS(5932),
    [anon_sym_when] = ACTIONS(5932),
    [anon_sym_DOT_DOT] = ACTIONS(5932),
    [anon_sym_and] = ACTIONS(5932),
    [anon_sym_or] = ACTIONS(5932),
    [anon_sym_AMP_AMP] = ACTIONS(5932),
    [anon_sym_PIPE_PIPE] = ACTIONS(5932),
    [anon_sym_QMARK_QMARK] = ACTIONS(5932),
    [anon_sym_on] = ACTIONS(5932),
    [anon_sym_equals] = ACTIONS(5932),
    [anon_sym_by] = ACTIONS(5932),
    [anon_sym_as] = ACTIONS(5932),
    [anon_sym_is] = ACTIONS(5932),
    [anon_sym_DASH_GT] = ACTIONS(5932),
    [anon_sym_with] = ACTIONS(5932),
    [aux_sym_preproc_if_token3] = ACTIONS(5932),
    [aux_sym_preproc_else_token1] = ACTIONS(5932),
    [aux_sym_preproc_elif_token1] = ACTIONS(5932),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4181] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7137),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9363),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4181),
    [sym_preproc_endregion] = STATE(4181),
    [sym_preproc_line] = STATE(4181),
    [sym_preproc_pragma] = STATE(4181),
    [sym_preproc_nullable] = STATE(4181),
    [sym_preproc_error] = STATE(4181),
    [sym_preproc_warning] = STATE(4181),
    [sym_preproc_define] = STATE(4181),
    [sym_preproc_undef] = STATE(4181),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(6027),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4182] = {
    [sym_preproc_region] = STATE(4182),
    [sym_preproc_endregion] = STATE(4182),
    [sym_preproc_line] = STATE(4182),
    [sym_preproc_pragma] = STATE(4182),
    [sym_preproc_nullable] = STATE(4182),
    [sym_preproc_error] = STATE(4182),
    [sym_preproc_warning] = STATE(4182),
    [sym_preproc_define] = STATE(4182),
    [sym_preproc_undef] = STATE(4182),
    [anon_sym_SEMI] = ACTIONS(5928),
    [anon_sym_LBRACK] = ACTIONS(5928),
    [anon_sym_COLON] = ACTIONS(5928),
    [anon_sym_COMMA] = ACTIONS(5928),
    [anon_sym_RBRACK] = ACTIONS(5928),
    [anon_sym_LPAREN] = ACTIONS(5928),
    [anon_sym_RPAREN] = ACTIONS(5928),
    [anon_sym_RBRACE] = ACTIONS(5928),
    [anon_sym_LT] = ACTIONS(5930),
    [anon_sym_GT] = ACTIONS(5930),
    [anon_sym_in] = ACTIONS(5928),
    [anon_sym_QMARK] = ACTIONS(5930),
    [anon_sym_BANG] = ACTIONS(5930),
    [anon_sym_PLUS_PLUS] = ACTIONS(5928),
    [anon_sym_DASH_DASH] = ACTIONS(5928),
    [anon_sym_PLUS] = ACTIONS(5930),
    [anon_sym_DASH] = ACTIONS(5930),
    [anon_sym_STAR] = ACTIONS(5928),
    [anon_sym_SLASH] = ACTIONS(5930),
    [anon_sym_PERCENT] = ACTIONS(5928),
    [anon_sym_CARET] = ACTIONS(5928),
    [anon_sym_PIPE] = ACTIONS(5930),
    [anon_sym_AMP] = ACTIONS(5930),
    [anon_sym_LT_LT] = ACTIONS(5928),
    [anon_sym_GT_GT] = ACTIONS(5930),
    [anon_sym_GT_GT_GT] = ACTIONS(5928),
    [anon_sym_EQ_EQ] = ACTIONS(5928),
    [anon_sym_BANG_EQ] = ACTIONS(5928),
    [anon_sym_GT_EQ] = ACTIONS(5928),
    [anon_sym_LT_EQ] = ACTIONS(5928),
    [anon_sym_DOT] = ACTIONS(5930),
    [anon_sym_EQ_GT] = ACTIONS(5928),
    [anon_sym_switch] = ACTIONS(5928),
    [anon_sym_when] = ACTIONS(5928),
    [anon_sym_DOT_DOT] = ACTIONS(5928),
    [anon_sym_and] = ACTIONS(5928),
    [anon_sym_or] = ACTIONS(5928),
    [anon_sym_AMP_AMP] = ACTIONS(5928),
    [anon_sym_PIPE_PIPE] = ACTIONS(5928),
    [anon_sym_QMARK_QMARK] = ACTIONS(5928),
    [anon_sym_on] = ACTIONS(5928),
    [anon_sym_equals] = ACTIONS(5928),
    [anon_sym_by] = ACTIONS(5928),
    [anon_sym_as] = ACTIONS(5928),
    [anon_sym_is] = ACTIONS(5928),
    [anon_sym_DASH_GT] = ACTIONS(5928),
    [anon_sym_with] = ACTIONS(5928),
    [aux_sym_preproc_if_token3] = ACTIONS(5928),
    [aux_sym_preproc_else_token1] = ACTIONS(5928),
    [aux_sym_preproc_elif_token1] = ACTIONS(5928),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4183] = {
    [sym_preproc_region] = STATE(4183),
    [sym_preproc_endregion] = STATE(4183),
    [sym_preproc_line] = STATE(4183),
    [sym_preproc_pragma] = STATE(4183),
    [sym_preproc_nullable] = STATE(4183),
    [sym_preproc_error] = STATE(4183),
    [sym_preproc_warning] = STATE(4183),
    [sym_preproc_define] = STATE(4183),
    [sym_preproc_undef] = STATE(4183),
    [anon_sym_SEMI] = ACTIONS(5286),
    [anon_sym_LBRACK] = ACTIONS(5286),
    [anon_sym_COLON] = ACTIONS(5286),
    [anon_sym_COMMA] = ACTIONS(5286),
    [anon_sym_RBRACK] = ACTIONS(5286),
    [anon_sym_LPAREN] = ACTIONS(5286),
    [anon_sym_RPAREN] = ACTIONS(5286),
    [anon_sym_RBRACE] = ACTIONS(5286),
    [anon_sym_LT] = ACTIONS(5288),
    [anon_sym_GT] = ACTIONS(5288),
    [anon_sym_in] = ACTIONS(5286),
    [anon_sym_QMARK] = ACTIONS(5288),
    [anon_sym_BANG] = ACTIONS(5288),
    [anon_sym_PLUS_PLUS] = ACTIONS(5286),
    [anon_sym_DASH_DASH] = ACTIONS(5286),
    [anon_sym_PLUS] = ACTIONS(5288),
    [anon_sym_DASH] = ACTIONS(5288),
    [anon_sym_STAR] = ACTIONS(5286),
    [anon_sym_SLASH] = ACTIONS(5288),
    [anon_sym_PERCENT] = ACTIONS(5286),
    [anon_sym_CARET] = ACTIONS(5286),
    [anon_sym_PIPE] = ACTIONS(5288),
    [anon_sym_AMP] = ACTIONS(5288),
    [anon_sym_LT_LT] = ACTIONS(5286),
    [anon_sym_GT_GT] = ACTIONS(5288),
    [anon_sym_GT_GT_GT] = ACTIONS(5286),
    [anon_sym_EQ_EQ] = ACTIONS(5286),
    [anon_sym_BANG_EQ] = ACTIONS(5286),
    [anon_sym_GT_EQ] = ACTIONS(5286),
    [anon_sym_LT_EQ] = ACTIONS(5286),
    [anon_sym_DOT] = ACTIONS(5288),
    [anon_sym_EQ_GT] = ACTIONS(5286),
    [anon_sym_switch] = ACTIONS(5286),
    [anon_sym_when] = ACTIONS(5286),
    [anon_sym_DOT_DOT] = ACTIONS(5286),
    [anon_sym_and] = ACTIONS(5286),
    [anon_sym_or] = ACTIONS(5286),
    [anon_sym_AMP_AMP] = ACTIONS(5286),
    [anon_sym_PIPE_PIPE] = ACTIONS(5286),
    [anon_sym_QMARK_QMARK] = ACTIONS(5286),
    [anon_sym_on] = ACTIONS(5286),
    [anon_sym_equals] = ACTIONS(5286),
    [anon_sym_by] = ACTIONS(5286),
    [anon_sym_as] = ACTIONS(5286),
    [anon_sym_is] = ACTIONS(5286),
    [anon_sym_DASH_GT] = ACTIONS(5286),
    [anon_sym_with] = ACTIONS(5286),
    [aux_sym_preproc_if_token3] = ACTIONS(5286),
    [aux_sym_preproc_else_token1] = ACTIONS(5286),
    [aux_sym_preproc_elif_token1] = ACTIONS(5286),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4184] = {
    [sym_preproc_region] = STATE(4184),
    [sym_preproc_endregion] = STATE(4184),
    [sym_preproc_line] = STATE(4184),
    [sym_preproc_pragma] = STATE(4184),
    [sym_preproc_nullable] = STATE(4184),
    [sym_preproc_error] = STATE(4184),
    [sym_preproc_warning] = STATE(4184),
    [sym_preproc_define] = STATE(4184),
    [sym_preproc_undef] = STATE(4184),
    [anon_sym_SEMI] = ACTIONS(5628),
    [anon_sym_LBRACK] = ACTIONS(5628),
    [anon_sym_COLON] = ACTIONS(5628),
    [anon_sym_COMMA] = ACTIONS(5628),
    [anon_sym_RBRACK] = ACTIONS(5628),
    [anon_sym_LPAREN] = ACTIONS(5628),
    [anon_sym_RPAREN] = ACTIONS(5628),
    [anon_sym_RBRACE] = ACTIONS(5628),
    [anon_sym_LT] = ACTIONS(5630),
    [anon_sym_GT] = ACTIONS(5630),
    [anon_sym_in] = ACTIONS(5628),
    [anon_sym_QMARK] = ACTIONS(5630),
    [anon_sym_BANG] = ACTIONS(5630),
    [anon_sym_PLUS_PLUS] = ACTIONS(5628),
    [anon_sym_DASH_DASH] = ACTIONS(5628),
    [anon_sym_PLUS] = ACTIONS(5630),
    [anon_sym_DASH] = ACTIONS(5630),
    [anon_sym_STAR] = ACTIONS(5628),
    [anon_sym_SLASH] = ACTIONS(5630),
    [anon_sym_PERCENT] = ACTIONS(5628),
    [anon_sym_CARET] = ACTIONS(5628),
    [anon_sym_PIPE] = ACTIONS(5630),
    [anon_sym_AMP] = ACTIONS(5630),
    [anon_sym_LT_LT] = ACTIONS(5628),
    [anon_sym_GT_GT] = ACTIONS(5630),
    [anon_sym_GT_GT_GT] = ACTIONS(5628),
    [anon_sym_EQ_EQ] = ACTIONS(5628),
    [anon_sym_BANG_EQ] = ACTIONS(5628),
    [anon_sym_GT_EQ] = ACTIONS(5628),
    [anon_sym_LT_EQ] = ACTIONS(5628),
    [anon_sym_DOT] = ACTIONS(5630),
    [anon_sym_EQ_GT] = ACTIONS(5628),
    [anon_sym_switch] = ACTIONS(5628),
    [anon_sym_when] = ACTIONS(5628),
    [anon_sym_DOT_DOT] = ACTIONS(5628),
    [anon_sym_and] = ACTIONS(5628),
    [anon_sym_or] = ACTIONS(5628),
    [anon_sym_AMP_AMP] = ACTIONS(5628),
    [anon_sym_PIPE_PIPE] = ACTIONS(5628),
    [anon_sym_QMARK_QMARK] = ACTIONS(5628),
    [anon_sym_on] = ACTIONS(5628),
    [anon_sym_equals] = ACTIONS(5628),
    [anon_sym_by] = ACTIONS(5628),
    [anon_sym_as] = ACTIONS(5628),
    [anon_sym_is] = ACTIONS(5628),
    [anon_sym_DASH_GT] = ACTIONS(5628),
    [anon_sym_with] = ACTIONS(5628),
    [aux_sym_preproc_if_token3] = ACTIONS(5628),
    [aux_sym_preproc_else_token1] = ACTIONS(5628),
    [aux_sym_preproc_elif_token1] = ACTIONS(5628),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4185] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7140),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9819),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4185),
    [sym_preproc_endregion] = STATE(4185),
    [sym_preproc_line] = STATE(4185),
    [sym_preproc_pragma] = STATE(4185),
    [sym_preproc_nullable] = STATE(4185),
    [sym_preproc_error] = STATE(4185),
    [sym_preproc_warning] = STATE(4185),
    [sym_preproc_define] = STATE(4185),
    [sym_preproc_undef] = STATE(4185),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4186] = {
    [sym__name] = STATE(7882),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(9921),
    [sym_implicit_type] = STATE(8747),
    [sym_array_type] = STATE(8331),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(8345),
    [sym_pointer_type] = STATE(8345),
    [sym__pointer_base_type] = STATE(9367),
    [sym_function_pointer_type] = STATE(8345),
    [sym_function_pointer_parameter] = STATE(9589),
    [sym_ref_type] = STATE(8787),
    [sym__ref_base_type] = STATE(9629),
    [sym_scoped_type] = STATE(8787),
    [sym_tuple_type] = STATE(8056),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4186),
    [sym_preproc_endregion] = STATE(4186),
    [sym_preproc_line] = STATE(4186),
    [sym_preproc_pragma] = STATE(4186),
    [sym_preproc_nullable] = STATE(4186),
    [sym_preproc_error] = STATE(4186),
    [sym_preproc_warning] = STATE(4186),
    [sym_preproc_define] = STATE(4186),
    [sym_preproc_undef] = STATE(4186),
    [aux_sym_function_pointer_type_repeat1] = STATE(4187),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(5976),
    [anon_sym_delegate] = ACTIONS(5747),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_in] = ACTIONS(5978),
    [anon_sym_out] = ACTIONS(5978),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(5980),
    [anon_sym_var] = ACTIONS(5369),
    [sym_predefined_type] = ACTIONS(5982),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4187] = {
    [sym__name] = STATE(7882),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(9396),
    [sym_implicit_type] = STATE(8747),
    [sym_array_type] = STATE(8331),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(8345),
    [sym_pointer_type] = STATE(8345),
    [sym__pointer_base_type] = STATE(9367),
    [sym_function_pointer_type] = STATE(8345),
    [sym_function_pointer_parameter] = STATE(9589),
    [sym_ref_type] = STATE(8787),
    [sym__ref_base_type] = STATE(9629),
    [sym_scoped_type] = STATE(8787),
    [sym_tuple_type] = STATE(8056),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4187),
    [sym_preproc_endregion] = STATE(4187),
    [sym_preproc_line] = STATE(4187),
    [sym_preproc_pragma] = STATE(4187),
    [sym_preproc_nullable] = STATE(4187),
    [sym_preproc_error] = STATE(4187),
    [sym_preproc_warning] = STATE(4187),
    [sym_preproc_define] = STATE(4187),
    [sym_preproc_undef] = STATE(4187),
    [aux_sym_function_pointer_type_repeat1] = STATE(4540),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(5976),
    [anon_sym_delegate] = ACTIONS(5747),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_in] = ACTIONS(5978),
    [anon_sym_out] = ACTIONS(5978),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(5980),
    [anon_sym_var] = ACTIONS(5369),
    [sym_predefined_type] = ACTIONS(5982),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4188] = {
    [sym__name] = STATE(7882),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(9396),
    [sym_implicit_type] = STATE(8747),
    [sym_array_type] = STATE(8331),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(8345),
    [sym_pointer_type] = STATE(8345),
    [sym__pointer_base_type] = STATE(9367),
    [sym_function_pointer_type] = STATE(8345),
    [sym_function_pointer_parameter] = STATE(9589),
    [sym_ref_type] = STATE(8787),
    [sym__ref_base_type] = STATE(9629),
    [sym_scoped_type] = STATE(8787),
    [sym_tuple_type] = STATE(8056),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4188),
    [sym_preproc_endregion] = STATE(4188),
    [sym_preproc_line] = STATE(4188),
    [sym_preproc_pragma] = STATE(4188),
    [sym_preproc_nullable] = STATE(4188),
    [sym_preproc_error] = STATE(4188),
    [sym_preproc_warning] = STATE(4188),
    [sym_preproc_define] = STATE(4188),
    [sym_preproc_undef] = STATE(4188),
    [aux_sym_function_pointer_type_repeat1] = STATE(4189),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(5976),
    [anon_sym_delegate] = ACTIONS(5747),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_in] = ACTIONS(5978),
    [anon_sym_out] = ACTIONS(5978),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(5980),
    [anon_sym_var] = ACTIONS(5369),
    [sym_predefined_type] = ACTIONS(5982),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4189] = {
    [sym__name] = STATE(7882),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(9844),
    [sym_implicit_type] = STATE(8747),
    [sym_array_type] = STATE(8331),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(8345),
    [sym_pointer_type] = STATE(8345),
    [sym__pointer_base_type] = STATE(9367),
    [sym_function_pointer_type] = STATE(8345),
    [sym_function_pointer_parameter] = STATE(9589),
    [sym_ref_type] = STATE(8787),
    [sym__ref_base_type] = STATE(9629),
    [sym_scoped_type] = STATE(8787),
    [sym_tuple_type] = STATE(8056),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4189),
    [sym_preproc_endregion] = STATE(4189),
    [sym_preproc_line] = STATE(4189),
    [sym_preproc_pragma] = STATE(4189),
    [sym_preproc_nullable] = STATE(4189),
    [sym_preproc_error] = STATE(4189),
    [sym_preproc_warning] = STATE(4189),
    [sym_preproc_define] = STATE(4189),
    [sym_preproc_undef] = STATE(4189),
    [aux_sym_function_pointer_type_repeat1] = STATE(4540),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(5976),
    [anon_sym_delegate] = ACTIONS(5747),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_in] = ACTIONS(5978),
    [anon_sym_out] = ACTIONS(5978),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(5980),
    [anon_sym_var] = ACTIONS(5369),
    [sym_predefined_type] = ACTIONS(5982),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4190] = {
    [sym_preproc_region] = STATE(4190),
    [sym_preproc_endregion] = STATE(4190),
    [sym_preproc_line] = STATE(4190),
    [sym_preproc_pragma] = STATE(4190),
    [sym_preproc_nullable] = STATE(4190),
    [sym_preproc_error] = STATE(4190),
    [sym_preproc_warning] = STATE(4190),
    [sym_preproc_define] = STATE(4190),
    [sym_preproc_undef] = STATE(4190),
    [anon_sym_SEMI] = ACTIONS(5846),
    [anon_sym_LBRACK] = ACTIONS(5846),
    [anon_sym_COLON] = ACTIONS(5846),
    [anon_sym_COMMA] = ACTIONS(5846),
    [anon_sym_RBRACK] = ACTIONS(5846),
    [anon_sym_LPAREN] = ACTIONS(5846),
    [anon_sym_RPAREN] = ACTIONS(5846),
    [anon_sym_RBRACE] = ACTIONS(5846),
    [anon_sym_LT] = ACTIONS(5848),
    [anon_sym_GT] = ACTIONS(5848),
    [anon_sym_in] = ACTIONS(5846),
    [anon_sym_QMARK] = ACTIONS(5848),
    [anon_sym_BANG] = ACTIONS(5848),
    [anon_sym_PLUS_PLUS] = ACTIONS(5846),
    [anon_sym_DASH_DASH] = ACTIONS(5846),
    [anon_sym_PLUS] = ACTIONS(5848),
    [anon_sym_DASH] = ACTIONS(5848),
    [anon_sym_STAR] = ACTIONS(5846),
    [anon_sym_SLASH] = ACTIONS(5848),
    [anon_sym_PERCENT] = ACTIONS(5846),
    [anon_sym_CARET] = ACTIONS(5846),
    [anon_sym_PIPE] = ACTIONS(5848),
    [anon_sym_AMP] = ACTIONS(5848),
    [anon_sym_LT_LT] = ACTIONS(5846),
    [anon_sym_GT_GT] = ACTIONS(5848),
    [anon_sym_GT_GT_GT] = ACTIONS(5846),
    [anon_sym_EQ_EQ] = ACTIONS(5846),
    [anon_sym_BANG_EQ] = ACTIONS(5846),
    [anon_sym_GT_EQ] = ACTIONS(5846),
    [anon_sym_LT_EQ] = ACTIONS(5846),
    [anon_sym_DOT] = ACTIONS(5848),
    [anon_sym_EQ_GT] = ACTIONS(5846),
    [anon_sym_switch] = ACTIONS(5846),
    [anon_sym_when] = ACTIONS(5846),
    [anon_sym_DOT_DOT] = ACTIONS(5846),
    [anon_sym_and] = ACTIONS(5846),
    [anon_sym_or] = ACTIONS(5846),
    [anon_sym_AMP_AMP] = ACTIONS(5846),
    [anon_sym_PIPE_PIPE] = ACTIONS(5846),
    [anon_sym_QMARK_QMARK] = ACTIONS(5846),
    [anon_sym_on] = ACTIONS(5846),
    [anon_sym_equals] = ACTIONS(5846),
    [anon_sym_by] = ACTIONS(5846),
    [anon_sym_as] = ACTIONS(5846),
    [anon_sym_is] = ACTIONS(5846),
    [anon_sym_DASH_GT] = ACTIONS(5846),
    [anon_sym_with] = ACTIONS(5846),
    [aux_sym_preproc_if_token3] = ACTIONS(5846),
    [aux_sym_preproc_else_token1] = ACTIONS(5846),
    [aux_sym_preproc_elif_token1] = ACTIONS(5846),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4191] = {
    [sym_preproc_region] = STATE(4191),
    [sym_preproc_endregion] = STATE(4191),
    [sym_preproc_line] = STATE(4191),
    [sym_preproc_pragma] = STATE(4191),
    [sym_preproc_nullable] = STATE(4191),
    [sym_preproc_error] = STATE(4191),
    [sym_preproc_warning] = STATE(4191),
    [sym_preproc_define] = STATE(4191),
    [sym_preproc_undef] = STATE(4191),
    [anon_sym_SEMI] = ACTIONS(5412),
    [anon_sym_LBRACK] = ACTIONS(5412),
    [anon_sym_COLON] = ACTIONS(5412),
    [anon_sym_COMMA] = ACTIONS(5412),
    [anon_sym_RBRACK] = ACTIONS(5412),
    [anon_sym_LPAREN] = ACTIONS(5412),
    [anon_sym_RPAREN] = ACTIONS(5412),
    [anon_sym_RBRACE] = ACTIONS(5412),
    [anon_sym_LT] = ACTIONS(5414),
    [anon_sym_GT] = ACTIONS(5414),
    [anon_sym_in] = ACTIONS(5412),
    [anon_sym_QMARK] = ACTIONS(5414),
    [anon_sym_BANG] = ACTIONS(5414),
    [anon_sym_PLUS_PLUS] = ACTIONS(5412),
    [anon_sym_DASH_DASH] = ACTIONS(5412),
    [anon_sym_PLUS] = ACTIONS(5414),
    [anon_sym_DASH] = ACTIONS(5414),
    [anon_sym_STAR] = ACTIONS(5412),
    [anon_sym_SLASH] = ACTIONS(5414),
    [anon_sym_PERCENT] = ACTIONS(5412),
    [anon_sym_CARET] = ACTIONS(5412),
    [anon_sym_PIPE] = ACTIONS(5414),
    [anon_sym_AMP] = ACTIONS(5414),
    [anon_sym_LT_LT] = ACTIONS(5412),
    [anon_sym_GT_GT] = ACTIONS(5414),
    [anon_sym_GT_GT_GT] = ACTIONS(5412),
    [anon_sym_EQ_EQ] = ACTIONS(5412),
    [anon_sym_BANG_EQ] = ACTIONS(5412),
    [anon_sym_GT_EQ] = ACTIONS(5412),
    [anon_sym_LT_EQ] = ACTIONS(5412),
    [anon_sym_DOT] = ACTIONS(5414),
    [anon_sym_EQ_GT] = ACTIONS(5412),
    [anon_sym_switch] = ACTIONS(5412),
    [anon_sym_when] = ACTIONS(5412),
    [anon_sym_DOT_DOT] = ACTIONS(5412),
    [anon_sym_and] = ACTIONS(5412),
    [anon_sym_or] = ACTIONS(5412),
    [anon_sym_AMP_AMP] = ACTIONS(5412),
    [anon_sym_PIPE_PIPE] = ACTIONS(5412),
    [anon_sym_QMARK_QMARK] = ACTIONS(5412),
    [anon_sym_on] = ACTIONS(5412),
    [anon_sym_equals] = ACTIONS(5412),
    [anon_sym_by] = ACTIONS(5412),
    [anon_sym_as] = ACTIONS(5412),
    [anon_sym_is] = ACTIONS(5412),
    [anon_sym_DASH_GT] = ACTIONS(5412),
    [anon_sym_with] = ACTIONS(5412),
    [aux_sym_preproc_if_token3] = ACTIONS(5412),
    [aux_sym_preproc_else_token1] = ACTIONS(5412),
    [aux_sym_preproc_elif_token1] = ACTIONS(5412),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4192] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(6960),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9128),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4192),
    [sym_preproc_endregion] = STATE(4192),
    [sym_preproc_line] = STATE(4192),
    [sym_preproc_pragma] = STATE(4192),
    [sym_preproc_nullable] = STATE(4192),
    [sym_preproc_error] = STATE(4192),
    [sym_preproc_warning] = STATE(4192),
    [sym_preproc_define] = STATE(4192),
    [sym_preproc_undef] = STATE(4192),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(5974),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4193] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(6961),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9250),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4193),
    [sym_preproc_endregion] = STATE(4193),
    [sym_preproc_line] = STATE(4193),
    [sym_preproc_pragma] = STATE(4193),
    [sym_preproc_nullable] = STATE(4193),
    [sym_preproc_error] = STATE(4193),
    [sym_preproc_warning] = STATE(4193),
    [sym_preproc_define] = STATE(4193),
    [sym_preproc_undef] = STATE(4193),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4194] = {
    [sym__name] = STATE(7882),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(9263),
    [sym_implicit_type] = STATE(8747),
    [sym_array_type] = STATE(8331),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(8345),
    [sym_pointer_type] = STATE(8345),
    [sym__pointer_base_type] = STATE(9367),
    [sym_function_pointer_type] = STATE(8345),
    [sym_function_pointer_parameter] = STATE(9589),
    [sym_ref_type] = STATE(8787),
    [sym__ref_base_type] = STATE(9629),
    [sym_scoped_type] = STATE(8787),
    [sym_tuple_type] = STATE(8056),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4194),
    [sym_preproc_endregion] = STATE(4194),
    [sym_preproc_line] = STATE(4194),
    [sym_preproc_pragma] = STATE(4194),
    [sym_preproc_nullable] = STATE(4194),
    [sym_preproc_error] = STATE(4194),
    [sym_preproc_warning] = STATE(4194),
    [sym_preproc_define] = STATE(4194),
    [sym_preproc_undef] = STATE(4194),
    [aux_sym_function_pointer_type_repeat1] = STATE(4195),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(5976),
    [anon_sym_delegate] = ACTIONS(5747),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_in] = ACTIONS(5978),
    [anon_sym_out] = ACTIONS(5978),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(5980),
    [anon_sym_var] = ACTIONS(5369),
    [sym_predefined_type] = ACTIONS(5982),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4195] = {
    [sym__name] = STATE(7882),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(9301),
    [sym_implicit_type] = STATE(8747),
    [sym_array_type] = STATE(8331),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(8345),
    [sym_pointer_type] = STATE(8345),
    [sym__pointer_base_type] = STATE(9367),
    [sym_function_pointer_type] = STATE(8345),
    [sym_function_pointer_parameter] = STATE(9589),
    [sym_ref_type] = STATE(8787),
    [sym__ref_base_type] = STATE(9629),
    [sym_scoped_type] = STATE(8787),
    [sym_tuple_type] = STATE(8056),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4195),
    [sym_preproc_endregion] = STATE(4195),
    [sym_preproc_line] = STATE(4195),
    [sym_preproc_pragma] = STATE(4195),
    [sym_preproc_nullable] = STATE(4195),
    [sym_preproc_error] = STATE(4195),
    [sym_preproc_warning] = STATE(4195),
    [sym_preproc_define] = STATE(4195),
    [sym_preproc_undef] = STATE(4195),
    [aux_sym_function_pointer_type_repeat1] = STATE(4540),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(5976),
    [anon_sym_delegate] = ACTIONS(5747),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_in] = ACTIONS(5978),
    [anon_sym_out] = ACTIONS(5978),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(5980),
    [anon_sym_var] = ACTIONS(5369),
    [sym_predefined_type] = ACTIONS(5982),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4196] = {
    [sym__name] = STATE(7882),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(9301),
    [sym_implicit_type] = STATE(8747),
    [sym_array_type] = STATE(8331),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(8345),
    [sym_pointer_type] = STATE(8345),
    [sym__pointer_base_type] = STATE(9367),
    [sym_function_pointer_type] = STATE(8345),
    [sym_function_pointer_parameter] = STATE(9589),
    [sym_ref_type] = STATE(8787),
    [sym__ref_base_type] = STATE(9629),
    [sym_scoped_type] = STATE(8787),
    [sym_tuple_type] = STATE(8056),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4196),
    [sym_preproc_endregion] = STATE(4196),
    [sym_preproc_line] = STATE(4196),
    [sym_preproc_pragma] = STATE(4196),
    [sym_preproc_nullable] = STATE(4196),
    [sym_preproc_error] = STATE(4196),
    [sym_preproc_warning] = STATE(4196),
    [sym_preproc_define] = STATE(4196),
    [sym_preproc_undef] = STATE(4196),
    [aux_sym_function_pointer_type_repeat1] = STATE(4197),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(5976),
    [anon_sym_delegate] = ACTIONS(5747),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_in] = ACTIONS(5978),
    [anon_sym_out] = ACTIONS(5978),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(5980),
    [anon_sym_var] = ACTIONS(5369),
    [sym_predefined_type] = ACTIONS(5982),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4197] = {
    [sym__name] = STATE(7882),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(9332),
    [sym_implicit_type] = STATE(8747),
    [sym_array_type] = STATE(8331),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(8345),
    [sym_pointer_type] = STATE(8345),
    [sym__pointer_base_type] = STATE(9367),
    [sym_function_pointer_type] = STATE(8345),
    [sym_function_pointer_parameter] = STATE(9589),
    [sym_ref_type] = STATE(8787),
    [sym__ref_base_type] = STATE(9629),
    [sym_scoped_type] = STATE(8787),
    [sym_tuple_type] = STATE(8056),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4197),
    [sym_preproc_endregion] = STATE(4197),
    [sym_preproc_line] = STATE(4197),
    [sym_preproc_pragma] = STATE(4197),
    [sym_preproc_nullable] = STATE(4197),
    [sym_preproc_error] = STATE(4197),
    [sym_preproc_warning] = STATE(4197),
    [sym_preproc_define] = STATE(4197),
    [sym_preproc_undef] = STATE(4197),
    [aux_sym_function_pointer_type_repeat1] = STATE(4540),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(5976),
    [anon_sym_delegate] = ACTIONS(5747),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_in] = ACTIONS(5978),
    [anon_sym_out] = ACTIONS(5978),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(5980),
    [anon_sym_var] = ACTIONS(5369),
    [sym_predefined_type] = ACTIONS(5982),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4198] = {
    [sym_preproc_region] = STATE(4198),
    [sym_preproc_endregion] = STATE(4198),
    [sym_preproc_line] = STATE(4198),
    [sym_preproc_pragma] = STATE(4198),
    [sym_preproc_nullable] = STATE(4198),
    [sym_preproc_error] = STATE(4198),
    [sym_preproc_warning] = STATE(4198),
    [sym_preproc_define] = STATE(4198),
    [sym_preproc_undef] = STATE(4198),
    [anon_sym_SEMI] = ACTIONS(5909),
    [anon_sym_LBRACK] = ACTIONS(5909),
    [anon_sym_COLON] = ACTIONS(5909),
    [anon_sym_COMMA] = ACTIONS(5909),
    [anon_sym_RBRACK] = ACTIONS(5909),
    [anon_sym_LPAREN] = ACTIONS(5909),
    [anon_sym_RPAREN] = ACTIONS(5909),
    [anon_sym_RBRACE] = ACTIONS(5909),
    [anon_sym_LT] = ACTIONS(5911),
    [anon_sym_GT] = ACTIONS(5911),
    [anon_sym_in] = ACTIONS(5909),
    [anon_sym_QMARK] = ACTIONS(5911),
    [anon_sym_BANG] = ACTIONS(5911),
    [anon_sym_PLUS_PLUS] = ACTIONS(5909),
    [anon_sym_DASH_DASH] = ACTIONS(5909),
    [anon_sym_PLUS] = ACTIONS(5911),
    [anon_sym_DASH] = ACTIONS(5911),
    [anon_sym_STAR] = ACTIONS(5909),
    [anon_sym_SLASH] = ACTIONS(5911),
    [anon_sym_PERCENT] = ACTIONS(5909),
    [anon_sym_CARET] = ACTIONS(5909),
    [anon_sym_PIPE] = ACTIONS(5911),
    [anon_sym_AMP] = ACTIONS(5911),
    [anon_sym_LT_LT] = ACTIONS(5909),
    [anon_sym_GT_GT] = ACTIONS(5911),
    [anon_sym_GT_GT_GT] = ACTIONS(5909),
    [anon_sym_EQ_EQ] = ACTIONS(5909),
    [anon_sym_BANG_EQ] = ACTIONS(5909),
    [anon_sym_GT_EQ] = ACTIONS(5909),
    [anon_sym_LT_EQ] = ACTIONS(5909),
    [anon_sym_DOT] = ACTIONS(5911),
    [anon_sym_EQ_GT] = ACTIONS(5909),
    [anon_sym_switch] = ACTIONS(5909),
    [anon_sym_when] = ACTIONS(5909),
    [anon_sym_DOT_DOT] = ACTIONS(5909),
    [anon_sym_and] = ACTIONS(5909),
    [anon_sym_or] = ACTIONS(5909),
    [anon_sym_AMP_AMP] = ACTIONS(5909),
    [anon_sym_PIPE_PIPE] = ACTIONS(5909),
    [anon_sym_QMARK_QMARK] = ACTIONS(5909),
    [anon_sym_on] = ACTIONS(5909),
    [anon_sym_equals] = ACTIONS(5909),
    [anon_sym_by] = ACTIONS(5909),
    [anon_sym_as] = ACTIONS(5909),
    [anon_sym_is] = ACTIONS(5909),
    [anon_sym_DASH_GT] = ACTIONS(5909),
    [anon_sym_with] = ACTIONS(5909),
    [aux_sym_preproc_if_token3] = ACTIONS(5909),
    [aux_sym_preproc_else_token1] = ACTIONS(5909),
    [aux_sym_preproc_elif_token1] = ACTIONS(5909),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4199] = {
    [sym_preproc_region] = STATE(4199),
    [sym_preproc_endregion] = STATE(4199),
    [sym_preproc_line] = STATE(4199),
    [sym_preproc_pragma] = STATE(4199),
    [sym_preproc_nullable] = STATE(4199),
    [sym_preproc_error] = STATE(4199),
    [sym_preproc_warning] = STATE(4199),
    [sym_preproc_define] = STATE(4199),
    [sym_preproc_undef] = STATE(4199),
    [anon_sym_EQ] = ACTIONS(6029),
    [anon_sym_LBRACK] = ACTIONS(5286),
    [anon_sym_COLON] = ACTIONS(5286),
    [anon_sym_LPAREN] = ACTIONS(5286),
    [anon_sym_LT] = ACTIONS(5288),
    [anon_sym_GT] = ACTIONS(5288),
    [anon_sym_QMARK] = ACTIONS(5288),
    [anon_sym_BANG] = ACTIONS(5288),
    [anon_sym_PLUS_PLUS] = ACTIONS(5286),
    [anon_sym_DASH_DASH] = ACTIONS(5286),
    [anon_sym_PLUS] = ACTIONS(5288),
    [anon_sym_DASH] = ACTIONS(5288),
    [anon_sym_STAR] = ACTIONS(5288),
    [anon_sym_SLASH] = ACTIONS(5288),
    [anon_sym_PERCENT] = ACTIONS(5288),
    [anon_sym_CARET] = ACTIONS(5288),
    [anon_sym_PIPE] = ACTIONS(5288),
    [anon_sym_AMP] = ACTIONS(5288),
    [anon_sym_LT_LT] = ACTIONS(5288),
    [anon_sym_GT_GT] = ACTIONS(5288),
    [anon_sym_GT_GT_GT] = ACTIONS(5288),
    [anon_sym_EQ_EQ] = ACTIONS(5286),
    [anon_sym_BANG_EQ] = ACTIONS(5286),
    [anon_sym_GT_EQ] = ACTIONS(5286),
    [anon_sym_LT_EQ] = ACTIONS(5286),
    [anon_sym_DOT] = ACTIONS(5288),
    [anon_sym_switch] = ACTIONS(5286),
    [anon_sym_when] = ACTIONS(5286),
    [anon_sym_DOT_DOT] = ACTIONS(5286),
    [anon_sym_and] = ACTIONS(5286),
    [anon_sym_or] = ACTIONS(5286),
    [anon_sym_PLUS_EQ] = ACTIONS(6031),
    [anon_sym_DASH_EQ] = ACTIONS(6031),
    [anon_sym_STAR_EQ] = ACTIONS(6031),
    [anon_sym_SLASH_EQ] = ACTIONS(6031),
    [anon_sym_PERCENT_EQ] = ACTIONS(6031),
    [anon_sym_AMP_EQ] = ACTIONS(6031),
    [anon_sym_CARET_EQ] = ACTIONS(6031),
    [anon_sym_PIPE_EQ] = ACTIONS(6031),
    [anon_sym_LT_LT_EQ] = ACTIONS(6031),
    [anon_sym_GT_GT_EQ] = ACTIONS(6031),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(6031),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(6031),
    [anon_sym_AMP_AMP] = ACTIONS(5286),
    [anon_sym_PIPE_PIPE] = ACTIONS(5286),
    [anon_sym_QMARK_QMARK] = ACTIONS(5288),
    [anon_sym_as] = ACTIONS(5286),
    [anon_sym_is] = ACTIONS(5286),
    [anon_sym_DASH_GT] = ACTIONS(5286),
    [anon_sym_with] = ACTIONS(5286),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4200] = {
    [sym_preproc_region] = STATE(4200),
    [sym_preproc_endregion] = STATE(4200),
    [sym_preproc_line] = STATE(4200),
    [sym_preproc_pragma] = STATE(4200),
    [sym_preproc_nullable] = STATE(4200),
    [sym_preproc_error] = STATE(4200),
    [sym_preproc_warning] = STATE(4200),
    [sym_preproc_define] = STATE(4200),
    [sym_preproc_undef] = STATE(4200),
    [anon_sym_EQ] = ACTIONS(6033),
    [anon_sym_LBRACK] = ACTIONS(5286),
    [anon_sym_LPAREN] = ACTIONS(5286),
    [anon_sym_LT] = ACTIONS(5288),
    [anon_sym_GT] = ACTIONS(5288),
    [anon_sym_QMARK] = ACTIONS(5288),
    [anon_sym_BANG] = ACTIONS(5288),
    [anon_sym_PLUS_PLUS] = ACTIONS(5286),
    [anon_sym_DASH_DASH] = ACTIONS(5286),
    [anon_sym_PLUS] = ACTIONS(5288),
    [anon_sym_DASH] = ACTIONS(5288),
    [anon_sym_STAR] = ACTIONS(5288),
    [anon_sym_SLASH] = ACTIONS(5288),
    [anon_sym_PERCENT] = ACTIONS(5288),
    [anon_sym_CARET] = ACTIONS(5288),
    [anon_sym_PIPE] = ACTIONS(5288),
    [anon_sym_AMP] = ACTIONS(5288),
    [anon_sym_LT_LT] = ACTIONS(5288),
    [anon_sym_GT_GT] = ACTIONS(5288),
    [anon_sym_GT_GT_GT] = ACTIONS(5288),
    [anon_sym_EQ_EQ] = ACTIONS(5286),
    [anon_sym_BANG_EQ] = ACTIONS(5286),
    [anon_sym_GT_EQ] = ACTIONS(5286),
    [anon_sym_LT_EQ] = ACTIONS(5286),
    [anon_sym_DOT] = ACTIONS(5288),
    [anon_sym_switch] = ACTIONS(5286),
    [anon_sym_DOT_DOT] = ACTIONS(5286),
    [anon_sym_and] = ACTIONS(5286),
    [anon_sym_or] = ACTIONS(5286),
    [anon_sym_PLUS_EQ] = ACTIONS(6035),
    [anon_sym_DASH_EQ] = ACTIONS(6035),
    [anon_sym_STAR_EQ] = ACTIONS(6035),
    [anon_sym_SLASH_EQ] = ACTIONS(6035),
    [anon_sym_PERCENT_EQ] = ACTIONS(6035),
    [anon_sym_AMP_EQ] = ACTIONS(6035),
    [anon_sym_CARET_EQ] = ACTIONS(6035),
    [anon_sym_PIPE_EQ] = ACTIONS(6035),
    [anon_sym_LT_LT_EQ] = ACTIONS(6035),
    [anon_sym_GT_GT_EQ] = ACTIONS(6035),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(6035),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(6035),
    [anon_sym_AMP_AMP] = ACTIONS(5286),
    [anon_sym_PIPE_PIPE] = ACTIONS(5286),
    [anon_sym_QMARK_QMARK] = ACTIONS(5288),
    [anon_sym_into] = ACTIONS(5286),
    [anon_sym_by] = ACTIONS(5286),
    [anon_sym_as] = ACTIONS(5286),
    [anon_sym_is] = ACTIONS(5286),
    [anon_sym_DASH_GT] = ACTIONS(5286),
    [anon_sym_with] = ACTIONS(5286),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4201] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(6965),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9023),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4201),
    [sym_preproc_endregion] = STATE(4201),
    [sym_preproc_line] = STATE(4201),
    [sym_preproc_pragma] = STATE(4201),
    [sym_preproc_nullable] = STATE(4201),
    [sym_preproc_error] = STATE(4201),
    [sym_preproc_warning] = STATE(4201),
    [sym_preproc_define] = STATE(4201),
    [sym_preproc_undef] = STATE(4201),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(6037),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4202] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(6966),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9059),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4202),
    [sym_preproc_endregion] = STATE(4202),
    [sym_preproc_line] = STATE(4202),
    [sym_preproc_pragma] = STATE(4202),
    [sym_preproc_nullable] = STATE(4202),
    [sym_preproc_error] = STATE(4202),
    [sym_preproc_warning] = STATE(4202),
    [sym_preproc_define] = STATE(4202),
    [sym_preproc_undef] = STATE(4202),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4203] = {
    [sym__name] = STATE(7882),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(9103),
    [sym_implicit_type] = STATE(8747),
    [sym_array_type] = STATE(8331),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(8345),
    [sym_pointer_type] = STATE(8345),
    [sym__pointer_base_type] = STATE(9367),
    [sym_function_pointer_type] = STATE(8345),
    [sym_function_pointer_parameter] = STATE(9589),
    [sym_ref_type] = STATE(8787),
    [sym__ref_base_type] = STATE(9629),
    [sym_scoped_type] = STATE(8787),
    [sym_tuple_type] = STATE(8056),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4203),
    [sym_preproc_endregion] = STATE(4203),
    [sym_preproc_line] = STATE(4203),
    [sym_preproc_pragma] = STATE(4203),
    [sym_preproc_nullable] = STATE(4203),
    [sym_preproc_error] = STATE(4203),
    [sym_preproc_warning] = STATE(4203),
    [sym_preproc_define] = STATE(4203),
    [sym_preproc_undef] = STATE(4203),
    [aux_sym_function_pointer_type_repeat1] = STATE(4204),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(5976),
    [anon_sym_delegate] = ACTIONS(5747),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_in] = ACTIONS(5978),
    [anon_sym_out] = ACTIONS(5978),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(5980),
    [anon_sym_var] = ACTIONS(5369),
    [sym_predefined_type] = ACTIONS(5982),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4204] = {
    [sym__name] = STATE(7882),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(9814),
    [sym_implicit_type] = STATE(8747),
    [sym_array_type] = STATE(8331),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(8345),
    [sym_pointer_type] = STATE(8345),
    [sym__pointer_base_type] = STATE(9367),
    [sym_function_pointer_type] = STATE(8345),
    [sym_function_pointer_parameter] = STATE(9589),
    [sym_ref_type] = STATE(8787),
    [sym__ref_base_type] = STATE(9629),
    [sym_scoped_type] = STATE(8787),
    [sym_tuple_type] = STATE(8056),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4204),
    [sym_preproc_endregion] = STATE(4204),
    [sym_preproc_line] = STATE(4204),
    [sym_preproc_pragma] = STATE(4204),
    [sym_preproc_nullable] = STATE(4204),
    [sym_preproc_error] = STATE(4204),
    [sym_preproc_warning] = STATE(4204),
    [sym_preproc_define] = STATE(4204),
    [sym_preproc_undef] = STATE(4204),
    [aux_sym_function_pointer_type_repeat1] = STATE(4540),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(5976),
    [anon_sym_delegate] = ACTIONS(5747),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_in] = ACTIONS(5978),
    [anon_sym_out] = ACTIONS(5978),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(5980),
    [anon_sym_var] = ACTIONS(5369),
    [sym_predefined_type] = ACTIONS(5982),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4205] = {
    [sym__name] = STATE(7882),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(9814),
    [sym_implicit_type] = STATE(8747),
    [sym_array_type] = STATE(8331),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(8345),
    [sym_pointer_type] = STATE(8345),
    [sym__pointer_base_type] = STATE(9367),
    [sym_function_pointer_type] = STATE(8345),
    [sym_function_pointer_parameter] = STATE(9589),
    [sym_ref_type] = STATE(8787),
    [sym__ref_base_type] = STATE(9629),
    [sym_scoped_type] = STATE(8787),
    [sym_tuple_type] = STATE(8056),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4205),
    [sym_preproc_endregion] = STATE(4205),
    [sym_preproc_line] = STATE(4205),
    [sym_preproc_pragma] = STATE(4205),
    [sym_preproc_nullable] = STATE(4205),
    [sym_preproc_error] = STATE(4205),
    [sym_preproc_warning] = STATE(4205),
    [sym_preproc_define] = STATE(4205),
    [sym_preproc_undef] = STATE(4205),
    [aux_sym_function_pointer_type_repeat1] = STATE(4206),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(5976),
    [anon_sym_delegate] = ACTIONS(5747),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_in] = ACTIONS(5978),
    [anon_sym_out] = ACTIONS(5978),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(5980),
    [anon_sym_var] = ACTIONS(5369),
    [sym_predefined_type] = ACTIONS(5982),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4206] = {
    [sym__name] = STATE(7882),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(9043),
    [sym_implicit_type] = STATE(8747),
    [sym_array_type] = STATE(8331),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(8345),
    [sym_pointer_type] = STATE(8345),
    [sym__pointer_base_type] = STATE(9367),
    [sym_function_pointer_type] = STATE(8345),
    [sym_function_pointer_parameter] = STATE(9589),
    [sym_ref_type] = STATE(8787),
    [sym__ref_base_type] = STATE(9629),
    [sym_scoped_type] = STATE(8787),
    [sym_tuple_type] = STATE(8056),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4206),
    [sym_preproc_endregion] = STATE(4206),
    [sym_preproc_line] = STATE(4206),
    [sym_preproc_pragma] = STATE(4206),
    [sym_preproc_nullable] = STATE(4206),
    [sym_preproc_error] = STATE(4206),
    [sym_preproc_warning] = STATE(4206),
    [sym_preproc_define] = STATE(4206),
    [sym_preproc_undef] = STATE(4206),
    [aux_sym_function_pointer_type_repeat1] = STATE(4540),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(5976),
    [anon_sym_delegate] = ACTIONS(5747),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_in] = ACTIONS(5978),
    [anon_sym_out] = ACTIONS(5978),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(5980),
    [anon_sym_var] = ACTIONS(5369),
    [sym_predefined_type] = ACTIONS(5982),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4207] = {
    [sym_preproc_region] = STATE(4207),
    [sym_preproc_endregion] = STATE(4207),
    [sym_preproc_line] = STATE(4207),
    [sym_preproc_pragma] = STATE(4207),
    [sym_preproc_nullable] = STATE(4207),
    [sym_preproc_error] = STATE(4207),
    [sym_preproc_warning] = STATE(4207),
    [sym_preproc_define] = STATE(4207),
    [sym_preproc_undef] = STATE(4207),
    [anon_sym_SEMI] = ACTIONS(5938),
    [anon_sym_LBRACK] = ACTIONS(5938),
    [anon_sym_COLON] = ACTIONS(5938),
    [anon_sym_COMMA] = ACTIONS(5938),
    [anon_sym_RBRACK] = ACTIONS(5938),
    [anon_sym_LPAREN] = ACTIONS(5938),
    [anon_sym_RPAREN] = ACTIONS(5938),
    [anon_sym_RBRACE] = ACTIONS(5938),
    [anon_sym_LT] = ACTIONS(5940),
    [anon_sym_GT] = ACTIONS(5940),
    [anon_sym_in] = ACTIONS(5938),
    [anon_sym_QMARK] = ACTIONS(5940),
    [anon_sym_BANG] = ACTIONS(5940),
    [anon_sym_PLUS_PLUS] = ACTIONS(5938),
    [anon_sym_DASH_DASH] = ACTIONS(5938),
    [anon_sym_PLUS] = ACTIONS(5940),
    [anon_sym_DASH] = ACTIONS(5940),
    [anon_sym_STAR] = ACTIONS(5938),
    [anon_sym_SLASH] = ACTIONS(5940),
    [anon_sym_PERCENT] = ACTIONS(5938),
    [anon_sym_CARET] = ACTIONS(5938),
    [anon_sym_PIPE] = ACTIONS(5940),
    [anon_sym_AMP] = ACTIONS(5940),
    [anon_sym_LT_LT] = ACTIONS(5938),
    [anon_sym_GT_GT] = ACTIONS(5940),
    [anon_sym_GT_GT_GT] = ACTIONS(5938),
    [anon_sym_EQ_EQ] = ACTIONS(5938),
    [anon_sym_BANG_EQ] = ACTIONS(5938),
    [anon_sym_GT_EQ] = ACTIONS(5938),
    [anon_sym_LT_EQ] = ACTIONS(5938),
    [anon_sym_DOT] = ACTIONS(5940),
    [anon_sym_EQ_GT] = ACTIONS(5938),
    [anon_sym_switch] = ACTIONS(5938),
    [anon_sym_when] = ACTIONS(5938),
    [anon_sym_DOT_DOT] = ACTIONS(5938),
    [anon_sym_and] = ACTIONS(5938),
    [anon_sym_or] = ACTIONS(5938),
    [anon_sym_AMP_AMP] = ACTIONS(5938),
    [anon_sym_PIPE_PIPE] = ACTIONS(5938),
    [anon_sym_QMARK_QMARK] = ACTIONS(5938),
    [anon_sym_on] = ACTIONS(5938),
    [anon_sym_equals] = ACTIONS(5938),
    [anon_sym_by] = ACTIONS(5938),
    [anon_sym_as] = ACTIONS(5938),
    [anon_sym_is] = ACTIONS(5938),
    [anon_sym_DASH_GT] = ACTIONS(5938),
    [anon_sym_with] = ACTIONS(5938),
    [aux_sym_preproc_if_token3] = ACTIONS(5938),
    [aux_sym_preproc_else_token1] = ACTIONS(5938),
    [aux_sym_preproc_elif_token1] = ACTIONS(5938),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4208] = {
    [sym_preproc_region] = STATE(4208),
    [sym_preproc_endregion] = STATE(4208),
    [sym_preproc_line] = STATE(4208),
    [sym_preproc_pragma] = STATE(4208),
    [sym_preproc_nullable] = STATE(4208),
    [sym_preproc_error] = STATE(4208),
    [sym_preproc_warning] = STATE(4208),
    [sym_preproc_define] = STATE(4208),
    [sym_preproc_undef] = STATE(4208),
    [anon_sym_EQ] = ACTIONS(6039),
    [anon_sym_LBRACK] = ACTIONS(5286),
    [anon_sym_LPAREN] = ACTIONS(5286),
    [anon_sym_LT] = ACTIONS(5288),
    [anon_sym_GT] = ACTIONS(5288),
    [anon_sym_QMARK] = ACTIONS(5288),
    [anon_sym_BANG] = ACTIONS(5288),
    [anon_sym_PLUS_PLUS] = ACTIONS(5286),
    [anon_sym_DASH_DASH] = ACTIONS(5286),
    [anon_sym_PLUS] = ACTIONS(5288),
    [anon_sym_DASH] = ACTIONS(5288),
    [anon_sym_STAR] = ACTIONS(5288),
    [anon_sym_SLASH] = ACTIONS(5288),
    [anon_sym_PERCENT] = ACTIONS(5288),
    [anon_sym_CARET] = ACTIONS(5288),
    [anon_sym_PIPE] = ACTIONS(5288),
    [anon_sym_AMP] = ACTIONS(5288),
    [anon_sym_LT_LT] = ACTIONS(5288),
    [anon_sym_GT_GT] = ACTIONS(5288),
    [anon_sym_GT_GT_GT] = ACTIONS(5288),
    [anon_sym_EQ_EQ] = ACTIONS(5286),
    [anon_sym_BANG_EQ] = ACTIONS(5286),
    [anon_sym_GT_EQ] = ACTIONS(5286),
    [anon_sym_LT_EQ] = ACTIONS(5286),
    [anon_sym_DOT] = ACTIONS(5288),
    [anon_sym_switch] = ACTIONS(5286),
    [anon_sym_DOT_DOT] = ACTIONS(5286),
    [anon_sym_and] = ACTIONS(5286),
    [anon_sym_or] = ACTIONS(5286),
    [anon_sym_PLUS_EQ] = ACTIONS(6041),
    [anon_sym_DASH_EQ] = ACTIONS(6041),
    [anon_sym_STAR_EQ] = ACTIONS(6041),
    [anon_sym_SLASH_EQ] = ACTIONS(6041),
    [anon_sym_PERCENT_EQ] = ACTIONS(6041),
    [anon_sym_AMP_EQ] = ACTIONS(6041),
    [anon_sym_CARET_EQ] = ACTIONS(6041),
    [anon_sym_PIPE_EQ] = ACTIONS(6041),
    [anon_sym_LT_LT_EQ] = ACTIONS(6041),
    [anon_sym_GT_GT_EQ] = ACTIONS(6041),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(6041),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(6041),
    [anon_sym_AMP_AMP] = ACTIONS(5286),
    [anon_sym_PIPE_PIPE] = ACTIONS(5286),
    [anon_sym_QMARK_QMARK] = ACTIONS(5288),
    [anon_sym_into] = ACTIONS(5286),
    [anon_sym_equals] = ACTIONS(5286),
    [anon_sym_as] = ACTIONS(5286),
    [anon_sym_is] = ACTIONS(5286),
    [anon_sym_DASH_GT] = ACTIONS(5286),
    [anon_sym_with] = ACTIONS(5286),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4209] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(6969),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9968),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4209),
    [sym_preproc_endregion] = STATE(4209),
    [sym_preproc_line] = STATE(4209),
    [sym_preproc_pragma] = STATE(4209),
    [sym_preproc_nullable] = STATE(4209),
    [sym_preproc_error] = STATE(4209),
    [sym_preproc_warning] = STATE(4209),
    [sym_preproc_define] = STATE(4209),
    [sym_preproc_undef] = STATE(4209),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(6037),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4210] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(6971),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9266),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4210),
    [sym_preproc_endregion] = STATE(4210),
    [sym_preproc_line] = STATE(4210),
    [sym_preproc_pragma] = STATE(4210),
    [sym_preproc_nullable] = STATE(4210),
    [sym_preproc_error] = STATE(4210),
    [sym_preproc_warning] = STATE(4210),
    [sym_preproc_define] = STATE(4210),
    [sym_preproc_undef] = STATE(4210),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4211] = {
    [sym__name] = STATE(7882),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(9275),
    [sym_implicit_type] = STATE(8747),
    [sym_array_type] = STATE(8331),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(8345),
    [sym_pointer_type] = STATE(8345),
    [sym__pointer_base_type] = STATE(9367),
    [sym_function_pointer_type] = STATE(8345),
    [sym_function_pointer_parameter] = STATE(9589),
    [sym_ref_type] = STATE(8787),
    [sym__ref_base_type] = STATE(9629),
    [sym_scoped_type] = STATE(8787),
    [sym_tuple_type] = STATE(8056),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4211),
    [sym_preproc_endregion] = STATE(4211),
    [sym_preproc_line] = STATE(4211),
    [sym_preproc_pragma] = STATE(4211),
    [sym_preproc_nullable] = STATE(4211),
    [sym_preproc_error] = STATE(4211),
    [sym_preproc_warning] = STATE(4211),
    [sym_preproc_define] = STATE(4211),
    [sym_preproc_undef] = STATE(4211),
    [aux_sym_function_pointer_type_repeat1] = STATE(4212),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(5976),
    [anon_sym_delegate] = ACTIONS(5747),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_in] = ACTIONS(5978),
    [anon_sym_out] = ACTIONS(5978),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(5980),
    [anon_sym_var] = ACTIONS(5369),
    [sym_predefined_type] = ACTIONS(5982),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4212] = {
    [sym__name] = STATE(7882),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(9465),
    [sym_implicit_type] = STATE(8747),
    [sym_array_type] = STATE(8331),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(8345),
    [sym_pointer_type] = STATE(8345),
    [sym__pointer_base_type] = STATE(9367),
    [sym_function_pointer_type] = STATE(8345),
    [sym_function_pointer_parameter] = STATE(9589),
    [sym_ref_type] = STATE(8787),
    [sym__ref_base_type] = STATE(9629),
    [sym_scoped_type] = STATE(8787),
    [sym_tuple_type] = STATE(8056),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4212),
    [sym_preproc_endregion] = STATE(4212),
    [sym_preproc_line] = STATE(4212),
    [sym_preproc_pragma] = STATE(4212),
    [sym_preproc_nullable] = STATE(4212),
    [sym_preproc_error] = STATE(4212),
    [sym_preproc_warning] = STATE(4212),
    [sym_preproc_define] = STATE(4212),
    [sym_preproc_undef] = STATE(4212),
    [aux_sym_function_pointer_type_repeat1] = STATE(4540),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(5976),
    [anon_sym_delegate] = ACTIONS(5747),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_in] = ACTIONS(5978),
    [anon_sym_out] = ACTIONS(5978),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(5980),
    [anon_sym_var] = ACTIONS(5369),
    [sym_predefined_type] = ACTIONS(5982),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4213] = {
    [sym__name] = STATE(7882),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(9465),
    [sym_implicit_type] = STATE(8747),
    [sym_array_type] = STATE(8331),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(8345),
    [sym_pointer_type] = STATE(8345),
    [sym__pointer_base_type] = STATE(9367),
    [sym_function_pointer_type] = STATE(8345),
    [sym_function_pointer_parameter] = STATE(9589),
    [sym_ref_type] = STATE(8787),
    [sym__ref_base_type] = STATE(9629),
    [sym_scoped_type] = STATE(8787),
    [sym_tuple_type] = STATE(8056),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4213),
    [sym_preproc_endregion] = STATE(4213),
    [sym_preproc_line] = STATE(4213),
    [sym_preproc_pragma] = STATE(4213),
    [sym_preproc_nullable] = STATE(4213),
    [sym_preproc_error] = STATE(4213),
    [sym_preproc_warning] = STATE(4213),
    [sym_preproc_define] = STATE(4213),
    [sym_preproc_undef] = STATE(4213),
    [aux_sym_function_pointer_type_repeat1] = STATE(4214),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(5976),
    [anon_sym_delegate] = ACTIONS(5747),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_in] = ACTIONS(5978),
    [anon_sym_out] = ACTIONS(5978),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(5980),
    [anon_sym_var] = ACTIONS(5369),
    [sym_predefined_type] = ACTIONS(5982),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4214] = {
    [sym__name] = STATE(7882),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(9523),
    [sym_implicit_type] = STATE(8747),
    [sym_array_type] = STATE(8331),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(8345),
    [sym_pointer_type] = STATE(8345),
    [sym__pointer_base_type] = STATE(9367),
    [sym_function_pointer_type] = STATE(8345),
    [sym_function_pointer_parameter] = STATE(9589),
    [sym_ref_type] = STATE(8787),
    [sym__ref_base_type] = STATE(9629),
    [sym_scoped_type] = STATE(8787),
    [sym_tuple_type] = STATE(8056),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4214),
    [sym_preproc_endregion] = STATE(4214),
    [sym_preproc_line] = STATE(4214),
    [sym_preproc_pragma] = STATE(4214),
    [sym_preproc_nullable] = STATE(4214),
    [sym_preproc_error] = STATE(4214),
    [sym_preproc_warning] = STATE(4214),
    [sym_preproc_define] = STATE(4214),
    [sym_preproc_undef] = STATE(4214),
    [aux_sym_function_pointer_type_repeat1] = STATE(4540),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(5976),
    [anon_sym_delegate] = ACTIONS(5747),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_in] = ACTIONS(5978),
    [anon_sym_out] = ACTIONS(5978),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(5980),
    [anon_sym_var] = ACTIONS(5369),
    [sym_predefined_type] = ACTIONS(5982),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4215] = {
    [sym_preproc_region] = STATE(4215),
    [sym_preproc_endregion] = STATE(4215),
    [sym_preproc_line] = STATE(4215),
    [sym_preproc_pragma] = STATE(4215),
    [sym_preproc_nullable] = STATE(4215),
    [sym_preproc_error] = STATE(4215),
    [sym_preproc_warning] = STATE(4215),
    [sym_preproc_define] = STATE(4215),
    [sym_preproc_undef] = STATE(4215),
    [anon_sym_EQ] = ACTIONS(6043),
    [anon_sym_LBRACK] = ACTIONS(5286),
    [anon_sym_LPAREN] = ACTIONS(5286),
    [anon_sym_LT] = ACTIONS(5288),
    [anon_sym_GT] = ACTIONS(5288),
    [anon_sym_QMARK] = ACTIONS(5288),
    [anon_sym_BANG] = ACTIONS(5288),
    [anon_sym_PLUS_PLUS] = ACTIONS(5286),
    [anon_sym_DASH_DASH] = ACTIONS(5286),
    [anon_sym_PLUS] = ACTIONS(5288),
    [anon_sym_DASH] = ACTIONS(5288),
    [anon_sym_STAR] = ACTIONS(5288),
    [anon_sym_SLASH] = ACTIONS(5288),
    [anon_sym_PERCENT] = ACTIONS(5288),
    [anon_sym_CARET] = ACTIONS(5288),
    [anon_sym_PIPE] = ACTIONS(5288),
    [anon_sym_AMP] = ACTIONS(5288),
    [anon_sym_LT_LT] = ACTIONS(5288),
    [anon_sym_GT_GT] = ACTIONS(5288),
    [anon_sym_GT_GT_GT] = ACTIONS(5288),
    [anon_sym_EQ_EQ] = ACTIONS(5286),
    [anon_sym_BANG_EQ] = ACTIONS(5286),
    [anon_sym_GT_EQ] = ACTIONS(5286),
    [anon_sym_LT_EQ] = ACTIONS(5286),
    [anon_sym_DOT] = ACTIONS(5288),
    [anon_sym_switch] = ACTIONS(5286),
    [anon_sym_DOT_DOT] = ACTIONS(5286),
    [anon_sym_and] = ACTIONS(5286),
    [anon_sym_or] = ACTIONS(5286),
    [anon_sym_PLUS_EQ] = ACTIONS(6045),
    [anon_sym_DASH_EQ] = ACTIONS(6045),
    [anon_sym_STAR_EQ] = ACTIONS(6045),
    [anon_sym_SLASH_EQ] = ACTIONS(6045),
    [anon_sym_PERCENT_EQ] = ACTIONS(6045),
    [anon_sym_AMP_EQ] = ACTIONS(6045),
    [anon_sym_CARET_EQ] = ACTIONS(6045),
    [anon_sym_PIPE_EQ] = ACTIONS(6045),
    [anon_sym_LT_LT_EQ] = ACTIONS(6045),
    [anon_sym_GT_GT_EQ] = ACTIONS(6045),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(6045),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(6045),
    [anon_sym_AMP_AMP] = ACTIONS(5286),
    [anon_sym_PIPE_PIPE] = ACTIONS(5286),
    [anon_sym_QMARK_QMARK] = ACTIONS(5288),
    [anon_sym_into] = ACTIONS(5286),
    [anon_sym_on] = ACTIONS(5286),
    [anon_sym_as] = ACTIONS(5286),
    [anon_sym_is] = ACTIONS(5286),
    [anon_sym_DASH_GT] = ACTIONS(5286),
    [anon_sym_with] = ACTIONS(5286),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4216] = {
    [sym_preproc_region] = STATE(4216),
    [sym_preproc_endregion] = STATE(4216),
    [sym_preproc_line] = STATE(4216),
    [sym_preproc_pragma] = STATE(4216),
    [sym_preproc_nullable] = STATE(4216),
    [sym_preproc_error] = STATE(4216),
    [sym_preproc_warning] = STATE(4216),
    [sym_preproc_define] = STATE(4216),
    [sym_preproc_undef] = STATE(4216),
    [anon_sym_EQ] = ACTIONS(6047),
    [anon_sym_LBRACK] = ACTIONS(5286),
    [anon_sym_COLON] = ACTIONS(5286),
    [anon_sym_COMMA] = ACTIONS(5286),
    [anon_sym_LPAREN] = ACTIONS(5286),
    [anon_sym_RPAREN] = ACTIONS(5286),
    [anon_sym_RBRACE] = ACTIONS(5286),
    [anon_sym_LT] = ACTIONS(5288),
    [anon_sym_GT] = ACTIONS(5288),
    [anon_sym_QMARK] = ACTIONS(5288),
    [anon_sym_BANG] = ACTIONS(5288),
    [anon_sym_PLUS_PLUS] = ACTIONS(5286),
    [anon_sym_DASH_DASH] = ACTIONS(5286),
    [anon_sym_PLUS] = ACTIONS(5288),
    [anon_sym_DASH] = ACTIONS(5288),
    [anon_sym_STAR] = ACTIONS(5288),
    [anon_sym_SLASH] = ACTIONS(5288),
    [anon_sym_PERCENT] = ACTIONS(5288),
    [anon_sym_CARET] = ACTIONS(5288),
    [anon_sym_PIPE] = ACTIONS(5288),
    [anon_sym_AMP] = ACTIONS(5288),
    [anon_sym_LT_LT] = ACTIONS(5288),
    [anon_sym_GT_GT] = ACTIONS(5288),
    [anon_sym_GT_GT_GT] = ACTIONS(5288),
    [anon_sym_EQ_EQ] = ACTIONS(5286),
    [anon_sym_BANG_EQ] = ACTIONS(5286),
    [anon_sym_GT_EQ] = ACTIONS(5286),
    [anon_sym_LT_EQ] = ACTIONS(5286),
    [anon_sym_DOT] = ACTIONS(5288),
    [anon_sym_switch] = ACTIONS(5286),
    [anon_sym_DOT_DOT] = ACTIONS(5286),
    [anon_sym_PLUS_EQ] = ACTIONS(6049),
    [anon_sym_DASH_EQ] = ACTIONS(6049),
    [anon_sym_STAR_EQ] = ACTIONS(6049),
    [anon_sym_SLASH_EQ] = ACTIONS(6049),
    [anon_sym_PERCENT_EQ] = ACTIONS(6049),
    [anon_sym_AMP_EQ] = ACTIONS(6049),
    [anon_sym_CARET_EQ] = ACTIONS(6049),
    [anon_sym_PIPE_EQ] = ACTIONS(6049),
    [anon_sym_LT_LT_EQ] = ACTIONS(6049),
    [anon_sym_GT_GT_EQ] = ACTIONS(6049),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(6049),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(6049),
    [anon_sym_AMP_AMP] = ACTIONS(5286),
    [anon_sym_PIPE_PIPE] = ACTIONS(5286),
    [anon_sym_QMARK_QMARK] = ACTIONS(5288),
    [anon_sym_as] = ACTIONS(5286),
    [anon_sym_is] = ACTIONS(5286),
    [anon_sym_DASH_GT] = ACTIONS(5286),
    [anon_sym_with] = ACTIONS(5286),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4217] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(6975),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9777),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4217),
    [sym_preproc_endregion] = STATE(4217),
    [sym_preproc_line] = STATE(4217),
    [sym_preproc_pragma] = STATE(4217),
    [sym_preproc_nullable] = STATE(4217),
    [sym_preproc_error] = STATE(4217),
    [sym_preproc_warning] = STATE(4217),
    [sym_preproc_define] = STATE(4217),
    [sym_preproc_undef] = STATE(4217),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(6027),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4218] = {
    [sym_preproc_region] = STATE(4218),
    [sym_preproc_endregion] = STATE(4218),
    [sym_preproc_line] = STATE(4218),
    [sym_preproc_pragma] = STATE(4218),
    [sym_preproc_nullable] = STATE(4218),
    [sym_preproc_error] = STATE(4218),
    [sym_preproc_warning] = STATE(4218),
    [sym_preproc_define] = STATE(4218),
    [sym_preproc_undef] = STATE(4218),
    [anon_sym_SEMI] = ACTIONS(5424),
    [anon_sym_LBRACK] = ACTIONS(5424),
    [anon_sym_COLON] = ACTIONS(5424),
    [anon_sym_COMMA] = ACTIONS(5424),
    [anon_sym_RBRACK] = ACTIONS(5424),
    [anon_sym_LPAREN] = ACTIONS(5424),
    [anon_sym_RPAREN] = ACTIONS(5424),
    [anon_sym_RBRACE] = ACTIONS(5424),
    [anon_sym_LT] = ACTIONS(5426),
    [anon_sym_GT] = ACTIONS(5426),
    [anon_sym_in] = ACTIONS(5424),
    [anon_sym_QMARK] = ACTIONS(5426),
    [anon_sym_BANG] = ACTIONS(5426),
    [anon_sym_PLUS_PLUS] = ACTIONS(5424),
    [anon_sym_DASH_DASH] = ACTIONS(5424),
    [anon_sym_PLUS] = ACTIONS(5426),
    [anon_sym_DASH] = ACTIONS(5426),
    [anon_sym_STAR] = ACTIONS(5424),
    [anon_sym_SLASH] = ACTIONS(5426),
    [anon_sym_PERCENT] = ACTIONS(5424),
    [anon_sym_CARET] = ACTIONS(5424),
    [anon_sym_PIPE] = ACTIONS(5426),
    [anon_sym_AMP] = ACTIONS(5426),
    [anon_sym_LT_LT] = ACTIONS(5424),
    [anon_sym_GT_GT] = ACTIONS(5426),
    [anon_sym_GT_GT_GT] = ACTIONS(5424),
    [anon_sym_EQ_EQ] = ACTIONS(5424),
    [anon_sym_BANG_EQ] = ACTIONS(5424),
    [anon_sym_GT_EQ] = ACTIONS(5424),
    [anon_sym_LT_EQ] = ACTIONS(5424),
    [anon_sym_DOT] = ACTIONS(5426),
    [anon_sym_EQ_GT] = ACTIONS(5424),
    [anon_sym_switch] = ACTIONS(5424),
    [anon_sym_when] = ACTIONS(5424),
    [anon_sym_DOT_DOT] = ACTIONS(5424),
    [anon_sym_and] = ACTIONS(5424),
    [anon_sym_or] = ACTIONS(5424),
    [anon_sym_AMP_AMP] = ACTIONS(5424),
    [anon_sym_PIPE_PIPE] = ACTIONS(5424),
    [anon_sym_QMARK_QMARK] = ACTIONS(5424),
    [anon_sym_on] = ACTIONS(5424),
    [anon_sym_equals] = ACTIONS(5424),
    [anon_sym_by] = ACTIONS(5424),
    [anon_sym_as] = ACTIONS(5424),
    [anon_sym_is] = ACTIONS(5424),
    [anon_sym_DASH_GT] = ACTIONS(5424),
    [anon_sym_with] = ACTIONS(5424),
    [aux_sym_preproc_if_token3] = ACTIONS(5424),
    [aux_sym_preproc_else_token1] = ACTIONS(5424),
    [aux_sym_preproc_elif_token1] = ACTIONS(5424),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4219] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(6977),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9922),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4219),
    [sym_preproc_endregion] = STATE(4219),
    [sym_preproc_line] = STATE(4219),
    [sym_preproc_pragma] = STATE(4219),
    [sym_preproc_nullable] = STATE(4219),
    [sym_preproc_error] = STATE(4219),
    [sym_preproc_warning] = STATE(4219),
    [sym_preproc_define] = STATE(4219),
    [sym_preproc_undef] = STATE(4219),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4220] = {
    [sym__name] = STATE(7882),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(9933),
    [sym_implicit_type] = STATE(8747),
    [sym_array_type] = STATE(8331),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(8345),
    [sym_pointer_type] = STATE(8345),
    [sym__pointer_base_type] = STATE(9367),
    [sym_function_pointer_type] = STATE(8345),
    [sym_function_pointer_parameter] = STATE(9589),
    [sym_ref_type] = STATE(8787),
    [sym__ref_base_type] = STATE(9629),
    [sym_scoped_type] = STATE(8787),
    [sym_tuple_type] = STATE(8056),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4220),
    [sym_preproc_endregion] = STATE(4220),
    [sym_preproc_line] = STATE(4220),
    [sym_preproc_pragma] = STATE(4220),
    [sym_preproc_nullable] = STATE(4220),
    [sym_preproc_error] = STATE(4220),
    [sym_preproc_warning] = STATE(4220),
    [sym_preproc_define] = STATE(4220),
    [sym_preproc_undef] = STATE(4220),
    [aux_sym_function_pointer_type_repeat1] = STATE(4221),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(5976),
    [anon_sym_delegate] = ACTIONS(5747),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_in] = ACTIONS(5978),
    [anon_sym_out] = ACTIONS(5978),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(5980),
    [anon_sym_var] = ACTIONS(5369),
    [sym_predefined_type] = ACTIONS(5982),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4221] = {
    [sym__name] = STATE(7882),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(9014),
    [sym_implicit_type] = STATE(8747),
    [sym_array_type] = STATE(8331),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(8345),
    [sym_pointer_type] = STATE(8345),
    [sym__pointer_base_type] = STATE(9367),
    [sym_function_pointer_type] = STATE(8345),
    [sym_function_pointer_parameter] = STATE(9589),
    [sym_ref_type] = STATE(8787),
    [sym__ref_base_type] = STATE(9629),
    [sym_scoped_type] = STATE(8787),
    [sym_tuple_type] = STATE(8056),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4221),
    [sym_preproc_endregion] = STATE(4221),
    [sym_preproc_line] = STATE(4221),
    [sym_preproc_pragma] = STATE(4221),
    [sym_preproc_nullable] = STATE(4221),
    [sym_preproc_error] = STATE(4221),
    [sym_preproc_warning] = STATE(4221),
    [sym_preproc_define] = STATE(4221),
    [sym_preproc_undef] = STATE(4221),
    [aux_sym_function_pointer_type_repeat1] = STATE(4540),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(5976),
    [anon_sym_delegate] = ACTIONS(5747),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_in] = ACTIONS(5978),
    [anon_sym_out] = ACTIONS(5978),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(5980),
    [anon_sym_var] = ACTIONS(5369),
    [sym_predefined_type] = ACTIONS(5982),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4222] = {
    [sym__name] = STATE(7882),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(9014),
    [sym_implicit_type] = STATE(8747),
    [sym_array_type] = STATE(8331),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(8345),
    [sym_pointer_type] = STATE(8345),
    [sym__pointer_base_type] = STATE(9367),
    [sym_function_pointer_type] = STATE(8345),
    [sym_function_pointer_parameter] = STATE(9589),
    [sym_ref_type] = STATE(8787),
    [sym__ref_base_type] = STATE(9629),
    [sym_scoped_type] = STATE(8787),
    [sym_tuple_type] = STATE(8056),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4222),
    [sym_preproc_endregion] = STATE(4222),
    [sym_preproc_line] = STATE(4222),
    [sym_preproc_pragma] = STATE(4222),
    [sym_preproc_nullable] = STATE(4222),
    [sym_preproc_error] = STATE(4222),
    [sym_preproc_warning] = STATE(4222),
    [sym_preproc_define] = STATE(4222),
    [sym_preproc_undef] = STATE(4222),
    [aux_sym_function_pointer_type_repeat1] = STATE(4223),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(5976),
    [anon_sym_delegate] = ACTIONS(5747),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_in] = ACTIONS(5978),
    [anon_sym_out] = ACTIONS(5978),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(5980),
    [anon_sym_var] = ACTIONS(5369),
    [sym_predefined_type] = ACTIONS(5982),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4223] = {
    [sym__name] = STATE(7882),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(9028),
    [sym_implicit_type] = STATE(8747),
    [sym_array_type] = STATE(8331),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(8345),
    [sym_pointer_type] = STATE(8345),
    [sym__pointer_base_type] = STATE(9367),
    [sym_function_pointer_type] = STATE(8345),
    [sym_function_pointer_parameter] = STATE(9589),
    [sym_ref_type] = STATE(8787),
    [sym__ref_base_type] = STATE(9629),
    [sym_scoped_type] = STATE(8787),
    [sym_tuple_type] = STATE(8056),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4223),
    [sym_preproc_endregion] = STATE(4223),
    [sym_preproc_line] = STATE(4223),
    [sym_preproc_pragma] = STATE(4223),
    [sym_preproc_nullable] = STATE(4223),
    [sym_preproc_error] = STATE(4223),
    [sym_preproc_warning] = STATE(4223),
    [sym_preproc_define] = STATE(4223),
    [sym_preproc_undef] = STATE(4223),
    [aux_sym_function_pointer_type_repeat1] = STATE(4540),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(5976),
    [anon_sym_delegate] = ACTIONS(5747),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_in] = ACTIONS(5978),
    [anon_sym_out] = ACTIONS(5978),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(5980),
    [anon_sym_var] = ACTIONS(5369),
    [sym_predefined_type] = ACTIONS(5982),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4224] = {
    [sym_preproc_region] = STATE(4224),
    [sym_preproc_endregion] = STATE(4224),
    [sym_preproc_line] = STATE(4224),
    [sym_preproc_pragma] = STATE(4224),
    [sym_preproc_nullable] = STATE(4224),
    [sym_preproc_error] = STATE(4224),
    [sym_preproc_warning] = STATE(4224),
    [sym_preproc_define] = STATE(4224),
    [sym_preproc_undef] = STATE(4224),
    [anon_sym_EQ] = ACTIONS(6051),
    [anon_sym_LBRACK] = ACTIONS(5286),
    [anon_sym_LPAREN] = ACTIONS(5286),
    [anon_sym_LT] = ACTIONS(5288),
    [anon_sym_GT] = ACTIONS(5288),
    [anon_sym_QMARK] = ACTIONS(5288),
    [anon_sym_BANG] = ACTIONS(5288),
    [anon_sym_PLUS_PLUS] = ACTIONS(5286),
    [anon_sym_DASH_DASH] = ACTIONS(5286),
    [anon_sym_PLUS] = ACTIONS(5288),
    [anon_sym_DASH] = ACTIONS(5288),
    [anon_sym_STAR] = ACTIONS(5288),
    [anon_sym_SLASH] = ACTIONS(5288),
    [anon_sym_PERCENT] = ACTIONS(5288),
    [anon_sym_CARET] = ACTIONS(5288),
    [anon_sym_PIPE] = ACTIONS(5288),
    [anon_sym_AMP] = ACTIONS(5288),
    [anon_sym_LT_LT] = ACTIONS(5288),
    [anon_sym_GT_GT] = ACTIONS(5288),
    [anon_sym_GT_GT_GT] = ACTIONS(5288),
    [anon_sym_EQ_EQ] = ACTIONS(5286),
    [anon_sym_BANG_EQ] = ACTIONS(5286),
    [anon_sym_GT_EQ] = ACTIONS(5286),
    [anon_sym_LT_EQ] = ACTIONS(5286),
    [anon_sym_DOT] = ACTIONS(5288),
    [anon_sym_EQ_GT] = ACTIONS(5286),
    [anon_sym_switch] = ACTIONS(5286),
    [anon_sym_DOT_DOT] = ACTIONS(5286),
    [anon_sym_and] = ACTIONS(5286),
    [anon_sym_or] = ACTIONS(5286),
    [anon_sym_PLUS_EQ] = ACTIONS(6053),
    [anon_sym_DASH_EQ] = ACTIONS(6053),
    [anon_sym_STAR_EQ] = ACTIONS(6053),
    [anon_sym_SLASH_EQ] = ACTIONS(6053),
    [anon_sym_PERCENT_EQ] = ACTIONS(6053),
    [anon_sym_AMP_EQ] = ACTIONS(6053),
    [anon_sym_CARET_EQ] = ACTIONS(6053),
    [anon_sym_PIPE_EQ] = ACTIONS(6053),
    [anon_sym_LT_LT_EQ] = ACTIONS(6053),
    [anon_sym_GT_GT_EQ] = ACTIONS(6053),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(6053),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(6053),
    [anon_sym_AMP_AMP] = ACTIONS(5286),
    [anon_sym_PIPE_PIPE] = ACTIONS(5286),
    [anon_sym_QMARK_QMARK] = ACTIONS(5288),
    [anon_sym_into] = ACTIONS(5286),
    [anon_sym_as] = ACTIONS(5286),
    [anon_sym_is] = ACTIONS(5286),
    [anon_sym_DASH_GT] = ACTIONS(5286),
    [anon_sym_with] = ACTIONS(5286),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4225] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(6981),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9226),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4225),
    [sym_preproc_endregion] = STATE(4225),
    [sym_preproc_line] = STATE(4225),
    [sym_preproc_pragma] = STATE(4225),
    [sym_preproc_nullable] = STATE(4225),
    [sym_preproc_error] = STATE(4225),
    [sym_preproc_warning] = STATE(4225),
    [sym_preproc_define] = STATE(4225),
    [sym_preproc_undef] = STATE(4225),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(6037),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4226] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(6982),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9258),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4226),
    [sym_preproc_endregion] = STATE(4226),
    [sym_preproc_line] = STATE(4226),
    [sym_preproc_pragma] = STATE(4226),
    [sym_preproc_nullable] = STATE(4226),
    [sym_preproc_error] = STATE(4226),
    [sym_preproc_warning] = STATE(4226),
    [sym_preproc_define] = STATE(4226),
    [sym_preproc_undef] = STATE(4226),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4227] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(6986),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9395),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4227),
    [sym_preproc_endregion] = STATE(4227),
    [sym_preproc_line] = STATE(4227),
    [sym_preproc_pragma] = STATE(4227),
    [sym_preproc_nullable] = STATE(4227),
    [sym_preproc_error] = STATE(4227),
    [sym_preproc_warning] = STATE(4227),
    [sym_preproc_define] = STATE(4227),
    [sym_preproc_undef] = STATE(4227),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(6037),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4228] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(6987),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9427),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4228),
    [sym_preproc_endregion] = STATE(4228),
    [sym_preproc_line] = STATE(4228),
    [sym_preproc_pragma] = STATE(4228),
    [sym_preproc_nullable] = STATE(4228),
    [sym_preproc_error] = STATE(4228),
    [sym_preproc_warning] = STATE(4228),
    [sym_preproc_define] = STATE(4228),
    [sym_preproc_undef] = STATE(4228),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4229] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(6990),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9593),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4229),
    [sym_preproc_endregion] = STATE(4229),
    [sym_preproc_line] = STATE(4229),
    [sym_preproc_pragma] = STATE(4229),
    [sym_preproc_nullable] = STATE(4229),
    [sym_preproc_error] = STATE(4229),
    [sym_preproc_warning] = STATE(4229),
    [sym_preproc_define] = STATE(4229),
    [sym_preproc_undef] = STATE(4229),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(6027),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4230] = {
    [sym_preproc_region] = STATE(4230),
    [sym_preproc_endregion] = STATE(4230),
    [sym_preproc_line] = STATE(4230),
    [sym_preproc_pragma] = STATE(4230),
    [sym_preproc_nullable] = STATE(4230),
    [sym_preproc_error] = STATE(4230),
    [sym_preproc_warning] = STATE(4230),
    [sym_preproc_define] = STATE(4230),
    [sym_preproc_undef] = STATE(4230),
    [anon_sym_SEMI] = ACTIONS(2997),
    [anon_sym_LBRACK] = ACTIONS(2997),
    [anon_sym_COLON] = ACTIONS(2997),
    [anon_sym_COMMA] = ACTIONS(2997),
    [anon_sym_RBRACK] = ACTIONS(2997),
    [anon_sym_LPAREN] = ACTIONS(2997),
    [anon_sym_RPAREN] = ACTIONS(2997),
    [anon_sym_RBRACE] = ACTIONS(2997),
    [anon_sym_LT] = ACTIONS(2995),
    [anon_sym_GT] = ACTIONS(2995),
    [anon_sym_in] = ACTIONS(2997),
    [anon_sym_QMARK] = ACTIONS(2995),
    [anon_sym_BANG] = ACTIONS(2995),
    [anon_sym_PLUS_PLUS] = ACTIONS(2997),
    [anon_sym_DASH_DASH] = ACTIONS(2997),
    [anon_sym_PLUS] = ACTIONS(2995),
    [anon_sym_DASH] = ACTIONS(2995),
    [anon_sym_STAR] = ACTIONS(2997),
    [anon_sym_SLASH] = ACTIONS(2995),
    [anon_sym_PERCENT] = ACTIONS(2997),
    [anon_sym_CARET] = ACTIONS(2997),
    [anon_sym_PIPE] = ACTIONS(2995),
    [anon_sym_AMP] = ACTIONS(2995),
    [anon_sym_LT_LT] = ACTIONS(2997),
    [anon_sym_GT_GT] = ACTIONS(2995),
    [anon_sym_GT_GT_GT] = ACTIONS(2997),
    [anon_sym_EQ_EQ] = ACTIONS(2997),
    [anon_sym_BANG_EQ] = ACTIONS(2997),
    [anon_sym_GT_EQ] = ACTIONS(2997),
    [anon_sym_LT_EQ] = ACTIONS(2997),
    [anon_sym_DOT] = ACTIONS(2995),
    [anon_sym_EQ_GT] = ACTIONS(2997),
    [anon_sym_switch] = ACTIONS(2997),
    [anon_sym_when] = ACTIONS(2997),
    [anon_sym_DOT_DOT] = ACTIONS(2997),
    [anon_sym_and] = ACTIONS(2997),
    [anon_sym_or] = ACTIONS(2997),
    [anon_sym_AMP_AMP] = ACTIONS(2997),
    [anon_sym_PIPE_PIPE] = ACTIONS(2997),
    [anon_sym_QMARK_QMARK] = ACTIONS(2997),
    [anon_sym_on] = ACTIONS(2997),
    [anon_sym_equals] = ACTIONS(2997),
    [anon_sym_by] = ACTIONS(2997),
    [anon_sym_as] = ACTIONS(2997),
    [anon_sym_is] = ACTIONS(2997),
    [anon_sym_DASH_GT] = ACTIONS(2997),
    [anon_sym_with] = ACTIONS(2997),
    [aux_sym_preproc_if_token3] = ACTIONS(2997),
    [aux_sym_preproc_else_token1] = ACTIONS(2997),
    [aux_sym_preproc_elif_token1] = ACTIONS(2997),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4231] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(6991),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9607),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4231),
    [sym_preproc_endregion] = STATE(4231),
    [sym_preproc_line] = STATE(4231),
    [sym_preproc_pragma] = STATE(4231),
    [sym_preproc_nullable] = STATE(4231),
    [sym_preproc_error] = STATE(4231),
    [sym_preproc_warning] = STATE(4231),
    [sym_preproc_define] = STATE(4231),
    [sym_preproc_undef] = STATE(4231),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4232] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(6994),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9649),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4232),
    [sym_preproc_endregion] = STATE(4232),
    [sym_preproc_line] = STATE(4232),
    [sym_preproc_pragma] = STATE(4232),
    [sym_preproc_nullable] = STATE(4232),
    [sym_preproc_error] = STATE(4232),
    [sym_preproc_warning] = STATE(4232),
    [sym_preproc_define] = STATE(4232),
    [sym_preproc_undef] = STATE(4232),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(6019),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4233] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(6995),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9660),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4233),
    [sym_preproc_endregion] = STATE(4233),
    [sym_preproc_line] = STATE(4233),
    [sym_preproc_pragma] = STATE(4233),
    [sym_preproc_nullable] = STATE(4233),
    [sym_preproc_error] = STATE(4233),
    [sym_preproc_warning] = STATE(4233),
    [sym_preproc_define] = STATE(4233),
    [sym_preproc_undef] = STATE(4233),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4234] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(6998),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9709),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4234),
    [sym_preproc_endregion] = STATE(4234),
    [sym_preproc_line] = STATE(4234),
    [sym_preproc_pragma] = STATE(4234),
    [sym_preproc_nullable] = STATE(4234),
    [sym_preproc_error] = STATE(4234),
    [sym_preproc_warning] = STATE(4234),
    [sym_preproc_define] = STATE(4234),
    [sym_preproc_undef] = STATE(4234),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(6027),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4235] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7000),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9720),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4235),
    [sym_preproc_endregion] = STATE(4235),
    [sym_preproc_line] = STATE(4235),
    [sym_preproc_pragma] = STATE(4235),
    [sym_preproc_nullable] = STATE(4235),
    [sym_preproc_error] = STATE(4235),
    [sym_preproc_warning] = STATE(4235),
    [sym_preproc_define] = STATE(4235),
    [sym_preproc_undef] = STATE(4235),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4236] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7003),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9781),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4236),
    [sym_preproc_endregion] = STATE(4236),
    [sym_preproc_line] = STATE(4236),
    [sym_preproc_pragma] = STATE(4236),
    [sym_preproc_nullable] = STATE(4236),
    [sym_preproc_error] = STATE(4236),
    [sym_preproc_warning] = STATE(4236),
    [sym_preproc_define] = STATE(4236),
    [sym_preproc_undef] = STATE(4236),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(5974),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4237] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7004),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9794),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4237),
    [sym_preproc_endregion] = STATE(4237),
    [sym_preproc_line] = STATE(4237),
    [sym_preproc_pragma] = STATE(4237),
    [sym_preproc_nullable] = STATE(4237),
    [sym_preproc_error] = STATE(4237),
    [sym_preproc_warning] = STATE(4237),
    [sym_preproc_define] = STATE(4237),
    [sym_preproc_undef] = STATE(4237),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4238] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7008),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9834),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4238),
    [sym_preproc_endregion] = STATE(4238),
    [sym_preproc_line] = STATE(4238),
    [sym_preproc_pragma] = STATE(4238),
    [sym_preproc_nullable] = STATE(4238),
    [sym_preproc_error] = STATE(4238),
    [sym_preproc_warning] = STATE(4238),
    [sym_preproc_define] = STATE(4238),
    [sym_preproc_undef] = STATE(4238),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(6037),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4239] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7009),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9839),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4239),
    [sym_preproc_endregion] = STATE(4239),
    [sym_preproc_line] = STATE(4239),
    [sym_preproc_pragma] = STATE(4239),
    [sym_preproc_nullable] = STATE(4239),
    [sym_preproc_error] = STATE(4239),
    [sym_preproc_warning] = STATE(4239),
    [sym_preproc_define] = STATE(4239),
    [sym_preproc_undef] = STATE(4239),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4240] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7012),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9273),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4240),
    [sym_preproc_endregion] = STATE(4240),
    [sym_preproc_line] = STATE(4240),
    [sym_preproc_pragma] = STATE(4240),
    [sym_preproc_nullable] = STATE(4240),
    [sym_preproc_error] = STATE(4240),
    [sym_preproc_warning] = STATE(4240),
    [sym_preproc_define] = STATE(4240),
    [sym_preproc_undef] = STATE(4240),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(6037),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4241] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7013),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9281),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4241),
    [sym_preproc_endregion] = STATE(4241),
    [sym_preproc_line] = STATE(4241),
    [sym_preproc_pragma] = STATE(4241),
    [sym_preproc_nullable] = STATE(4241),
    [sym_preproc_error] = STATE(4241),
    [sym_preproc_warning] = STATE(4241),
    [sym_preproc_define] = STATE(4241),
    [sym_preproc_undef] = STATE(4241),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4242] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7016),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9879),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4242),
    [sym_preproc_endregion] = STATE(4242),
    [sym_preproc_line] = STATE(4242),
    [sym_preproc_pragma] = STATE(4242),
    [sym_preproc_nullable] = STATE(4242),
    [sym_preproc_error] = STATE(4242),
    [sym_preproc_warning] = STATE(4242),
    [sym_preproc_define] = STATE(4242),
    [sym_preproc_undef] = STATE(4242),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(6037),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4243] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7017),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9888),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4243),
    [sym_preproc_endregion] = STATE(4243),
    [sym_preproc_line] = STATE(4243),
    [sym_preproc_pragma] = STATE(4243),
    [sym_preproc_nullable] = STATE(4243),
    [sym_preproc_error] = STATE(4243),
    [sym_preproc_warning] = STATE(4243),
    [sym_preproc_define] = STATE(4243),
    [sym_preproc_undef] = STATE(4243),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4244] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7020),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9952),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4244),
    [sym_preproc_endregion] = STATE(4244),
    [sym_preproc_line] = STATE(4244),
    [sym_preproc_pragma] = STATE(4244),
    [sym_preproc_nullable] = STATE(4244),
    [sym_preproc_error] = STATE(4244),
    [sym_preproc_warning] = STATE(4244),
    [sym_preproc_define] = STATE(4244),
    [sym_preproc_undef] = STATE(4244),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(6055),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4245] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7021),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9969),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4245),
    [sym_preproc_endregion] = STATE(4245),
    [sym_preproc_line] = STATE(4245),
    [sym_preproc_pragma] = STATE(4245),
    [sym_preproc_nullable] = STATE(4245),
    [sym_preproc_error] = STATE(4245),
    [sym_preproc_warning] = STATE(4245),
    [sym_preproc_define] = STATE(4245),
    [sym_preproc_undef] = STATE(4245),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4246] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7024),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9066),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4246),
    [sym_preproc_endregion] = STATE(4246),
    [sym_preproc_line] = STATE(4246),
    [sym_preproc_pragma] = STATE(4246),
    [sym_preproc_nullable] = STATE(4246),
    [sym_preproc_error] = STATE(4246),
    [sym_preproc_warning] = STATE(4246),
    [sym_preproc_define] = STATE(4246),
    [sym_preproc_undef] = STATE(4246),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(5984),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4247] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7025),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9109),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4247),
    [sym_preproc_endregion] = STATE(4247),
    [sym_preproc_line] = STATE(4247),
    [sym_preproc_pragma] = STATE(4247),
    [sym_preproc_nullable] = STATE(4247),
    [sym_preproc_error] = STATE(4247),
    [sym_preproc_warning] = STATE(4247),
    [sym_preproc_define] = STATE(4247),
    [sym_preproc_undef] = STATE(4247),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4248] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7029),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9919),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4248),
    [sym_preproc_endregion] = STATE(4248),
    [sym_preproc_line] = STATE(4248),
    [sym_preproc_pragma] = STATE(4248),
    [sym_preproc_nullable] = STATE(4248),
    [sym_preproc_error] = STATE(4248),
    [sym_preproc_warning] = STATE(4248),
    [sym_preproc_define] = STATE(4248),
    [sym_preproc_undef] = STATE(4248),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(6019),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4249] = {
    [sym_preproc_region] = STATE(4249),
    [sym_preproc_endregion] = STATE(4249),
    [sym_preproc_line] = STATE(4249),
    [sym_preproc_pragma] = STATE(4249),
    [sym_preproc_nullable] = STATE(4249),
    [sym_preproc_error] = STATE(4249),
    [sym_preproc_warning] = STATE(4249),
    [sym_preproc_define] = STATE(4249),
    [sym_preproc_undef] = STATE(4249),
    [anon_sym_EQ] = ACTIONS(4162),
    [anon_sym_LBRACK] = ACTIONS(4177),
    [anon_sym_COLON] = ACTIONS(4806),
    [anon_sym_LPAREN] = ACTIONS(4177),
    [anon_sym_LT] = ACTIONS(4162),
    [anon_sym_GT] = ACTIONS(4162),
    [anon_sym_QMARK] = ACTIONS(4162),
    [anon_sym_BANG] = ACTIONS(4162),
    [anon_sym_PLUS_PLUS] = ACTIONS(4177),
    [anon_sym_DASH_DASH] = ACTIONS(4177),
    [anon_sym_PLUS] = ACTIONS(4162),
    [anon_sym_DASH] = ACTIONS(4162),
    [anon_sym_STAR] = ACTIONS(4162),
    [anon_sym_SLASH] = ACTIONS(4162),
    [anon_sym_PERCENT] = ACTIONS(4162),
    [anon_sym_CARET] = ACTIONS(4162),
    [anon_sym_PIPE] = ACTIONS(4162),
    [anon_sym_AMP] = ACTIONS(4162),
    [anon_sym_LT_LT] = ACTIONS(4162),
    [anon_sym_GT_GT] = ACTIONS(4162),
    [anon_sym_GT_GT_GT] = ACTIONS(4162),
    [anon_sym_EQ_EQ] = ACTIONS(4177),
    [anon_sym_BANG_EQ] = ACTIONS(4177),
    [anon_sym_GT_EQ] = ACTIONS(4177),
    [anon_sym_LT_EQ] = ACTIONS(4177),
    [anon_sym_DOT] = ACTIONS(4162),
    [anon_sym_switch] = ACTIONS(4177),
    [anon_sym_when] = ACTIONS(4806),
    [anon_sym_DOT_DOT] = ACTIONS(4177),
    [anon_sym_and] = ACTIONS(4806),
    [anon_sym_or] = ACTIONS(4806),
    [anon_sym_PLUS_EQ] = ACTIONS(4177),
    [anon_sym_DASH_EQ] = ACTIONS(4177),
    [anon_sym_STAR_EQ] = ACTIONS(4177),
    [anon_sym_SLASH_EQ] = ACTIONS(4177),
    [anon_sym_PERCENT_EQ] = ACTIONS(4177),
    [anon_sym_AMP_EQ] = ACTIONS(4177),
    [anon_sym_CARET_EQ] = ACTIONS(4177),
    [anon_sym_PIPE_EQ] = ACTIONS(4177),
    [anon_sym_LT_LT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(4177),
    [anon_sym_AMP_AMP] = ACTIONS(4177),
    [anon_sym_PIPE_PIPE] = ACTIONS(4177),
    [anon_sym_QMARK_QMARK] = ACTIONS(4162),
    [anon_sym_as] = ACTIONS(4177),
    [anon_sym_is] = ACTIONS(4177),
    [anon_sym_DASH_GT] = ACTIONS(4177),
    [anon_sym_with] = ACTIONS(4177),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4250] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7030),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(8998),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4250),
    [sym_preproc_endregion] = STATE(4250),
    [sym_preproc_line] = STATE(4250),
    [sym_preproc_pragma] = STATE(4250),
    [sym_preproc_nullable] = STATE(4250),
    [sym_preproc_error] = STATE(4250),
    [sym_preproc_warning] = STATE(4250),
    [sym_preproc_define] = STATE(4250),
    [sym_preproc_undef] = STATE(4250),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4251] = {
    [sym_preproc_region] = STATE(4251),
    [sym_preproc_endregion] = STATE(4251),
    [sym_preproc_line] = STATE(4251),
    [sym_preproc_pragma] = STATE(4251),
    [sym_preproc_nullable] = STATE(4251),
    [sym_preproc_error] = STATE(4251),
    [sym_preproc_warning] = STATE(4251),
    [sym_preproc_define] = STATE(4251),
    [sym_preproc_undef] = STATE(4251),
    [anon_sym_SEMI] = ACTIONS(5514),
    [anon_sym_LBRACK] = ACTIONS(5514),
    [anon_sym_COLON] = ACTIONS(5514),
    [anon_sym_COMMA] = ACTIONS(5514),
    [anon_sym_RBRACK] = ACTIONS(5514),
    [anon_sym_LPAREN] = ACTIONS(5514),
    [anon_sym_RPAREN] = ACTIONS(5514),
    [anon_sym_RBRACE] = ACTIONS(5514),
    [anon_sym_LT] = ACTIONS(5516),
    [anon_sym_GT] = ACTIONS(5516),
    [anon_sym_in] = ACTIONS(5514),
    [anon_sym_QMARK] = ACTIONS(5516),
    [anon_sym_BANG] = ACTIONS(5516),
    [anon_sym_PLUS_PLUS] = ACTIONS(5514),
    [anon_sym_DASH_DASH] = ACTIONS(5514),
    [anon_sym_PLUS] = ACTIONS(5516),
    [anon_sym_DASH] = ACTIONS(5516),
    [anon_sym_STAR] = ACTIONS(5514),
    [anon_sym_SLASH] = ACTIONS(5516),
    [anon_sym_PERCENT] = ACTIONS(5514),
    [anon_sym_CARET] = ACTIONS(5514),
    [anon_sym_PIPE] = ACTIONS(5516),
    [anon_sym_AMP] = ACTIONS(5516),
    [anon_sym_LT_LT] = ACTIONS(5514),
    [anon_sym_GT_GT] = ACTIONS(5516),
    [anon_sym_GT_GT_GT] = ACTIONS(5514),
    [anon_sym_EQ_EQ] = ACTIONS(5514),
    [anon_sym_BANG_EQ] = ACTIONS(5514),
    [anon_sym_GT_EQ] = ACTIONS(5514),
    [anon_sym_LT_EQ] = ACTIONS(5514),
    [anon_sym_DOT] = ACTIONS(5516),
    [anon_sym_EQ_GT] = ACTIONS(5514),
    [anon_sym_switch] = ACTIONS(5514),
    [anon_sym_when] = ACTIONS(5514),
    [anon_sym_DOT_DOT] = ACTIONS(5514),
    [anon_sym_and] = ACTIONS(5514),
    [anon_sym_or] = ACTIONS(5514),
    [anon_sym_AMP_AMP] = ACTIONS(5514),
    [anon_sym_PIPE_PIPE] = ACTIONS(5514),
    [anon_sym_QMARK_QMARK] = ACTIONS(5514),
    [anon_sym_on] = ACTIONS(5514),
    [anon_sym_equals] = ACTIONS(5514),
    [anon_sym_by] = ACTIONS(5514),
    [anon_sym_as] = ACTIONS(5514),
    [anon_sym_is] = ACTIONS(5514),
    [anon_sym_DASH_GT] = ACTIONS(5514),
    [anon_sym_with] = ACTIONS(5514),
    [aux_sym_preproc_if_token3] = ACTIONS(5514),
    [aux_sym_preproc_else_token1] = ACTIONS(5514),
    [aux_sym_preproc_elif_token1] = ACTIONS(5514),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4252] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7034),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9637),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4252),
    [sym_preproc_endregion] = STATE(4252),
    [sym_preproc_line] = STATE(4252),
    [sym_preproc_pragma] = STATE(4252),
    [sym_preproc_nullable] = STATE(4252),
    [sym_preproc_error] = STATE(4252),
    [sym_preproc_warning] = STATE(4252),
    [sym_preproc_define] = STATE(4252),
    [sym_preproc_undef] = STATE(4252),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(6037),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4253] = {
    [sym_preproc_region] = STATE(4253),
    [sym_preproc_endregion] = STATE(4253),
    [sym_preproc_line] = STATE(4253),
    [sym_preproc_pragma] = STATE(4253),
    [sym_preproc_nullable] = STATE(4253),
    [sym_preproc_error] = STATE(4253),
    [sym_preproc_warning] = STATE(4253),
    [sym_preproc_define] = STATE(4253),
    [sym_preproc_undef] = STATE(4253),
    [anon_sym_SEMI] = ACTIONS(5408),
    [anon_sym_LBRACK] = ACTIONS(5408),
    [anon_sym_COLON] = ACTIONS(5408),
    [anon_sym_COMMA] = ACTIONS(5408),
    [anon_sym_RBRACK] = ACTIONS(5408),
    [anon_sym_LPAREN] = ACTIONS(5408),
    [anon_sym_RPAREN] = ACTIONS(5408),
    [anon_sym_RBRACE] = ACTIONS(5408),
    [anon_sym_LT] = ACTIONS(5410),
    [anon_sym_GT] = ACTIONS(5410),
    [anon_sym_in] = ACTIONS(5408),
    [anon_sym_QMARK] = ACTIONS(5410),
    [anon_sym_BANG] = ACTIONS(5410),
    [anon_sym_PLUS_PLUS] = ACTIONS(5408),
    [anon_sym_DASH_DASH] = ACTIONS(5408),
    [anon_sym_PLUS] = ACTIONS(5410),
    [anon_sym_DASH] = ACTIONS(5410),
    [anon_sym_STAR] = ACTIONS(5408),
    [anon_sym_SLASH] = ACTIONS(5410),
    [anon_sym_PERCENT] = ACTIONS(5408),
    [anon_sym_CARET] = ACTIONS(5408),
    [anon_sym_PIPE] = ACTIONS(5410),
    [anon_sym_AMP] = ACTIONS(5410),
    [anon_sym_LT_LT] = ACTIONS(5408),
    [anon_sym_GT_GT] = ACTIONS(5410),
    [anon_sym_GT_GT_GT] = ACTIONS(5408),
    [anon_sym_EQ_EQ] = ACTIONS(5408),
    [anon_sym_BANG_EQ] = ACTIONS(5408),
    [anon_sym_GT_EQ] = ACTIONS(5408),
    [anon_sym_LT_EQ] = ACTIONS(5408),
    [anon_sym_DOT] = ACTIONS(5410),
    [anon_sym_EQ_GT] = ACTIONS(5408),
    [anon_sym_switch] = ACTIONS(5408),
    [anon_sym_when] = ACTIONS(5408),
    [anon_sym_DOT_DOT] = ACTIONS(5408),
    [anon_sym_and] = ACTIONS(5408),
    [anon_sym_or] = ACTIONS(5408),
    [anon_sym_AMP_AMP] = ACTIONS(5408),
    [anon_sym_PIPE_PIPE] = ACTIONS(5408),
    [anon_sym_QMARK_QMARK] = ACTIONS(5408),
    [anon_sym_on] = ACTIONS(5408),
    [anon_sym_equals] = ACTIONS(5408),
    [anon_sym_by] = ACTIONS(5408),
    [anon_sym_as] = ACTIONS(5408),
    [anon_sym_is] = ACTIONS(5408),
    [anon_sym_DASH_GT] = ACTIONS(5408),
    [anon_sym_with] = ACTIONS(5408),
    [aux_sym_preproc_if_token3] = ACTIONS(5408),
    [aux_sym_preproc_else_token1] = ACTIONS(5408),
    [aux_sym_preproc_elif_token1] = ACTIONS(5408),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4254] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7035),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9171),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4254),
    [sym_preproc_endregion] = STATE(4254),
    [sym_preproc_line] = STATE(4254),
    [sym_preproc_pragma] = STATE(4254),
    [sym_preproc_nullable] = STATE(4254),
    [sym_preproc_error] = STATE(4254),
    [sym_preproc_warning] = STATE(4254),
    [sym_preproc_define] = STATE(4254),
    [sym_preproc_undef] = STATE(4254),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4255] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7038),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9230),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4255),
    [sym_preproc_endregion] = STATE(4255),
    [sym_preproc_line] = STATE(4255),
    [sym_preproc_pragma] = STATE(4255),
    [sym_preproc_nullable] = STATE(4255),
    [sym_preproc_error] = STATE(4255),
    [sym_preproc_warning] = STATE(4255),
    [sym_preproc_define] = STATE(4255),
    [sym_preproc_undef] = STATE(4255),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(5974),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4256] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7039),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9254),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4256),
    [sym_preproc_endregion] = STATE(4256),
    [sym_preproc_line] = STATE(4256),
    [sym_preproc_pragma] = STATE(4256),
    [sym_preproc_nullable] = STATE(4256),
    [sym_preproc_error] = STATE(4256),
    [sym_preproc_warning] = STATE(4256),
    [sym_preproc_define] = STATE(4256),
    [sym_preproc_undef] = STATE(4256),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4257] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7042),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9304),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4257),
    [sym_preproc_endregion] = STATE(4257),
    [sym_preproc_line] = STATE(4257),
    [sym_preproc_pragma] = STATE(4257),
    [sym_preproc_nullable] = STATE(4257),
    [sym_preproc_error] = STATE(4257),
    [sym_preproc_warning] = STATE(4257),
    [sym_preproc_define] = STATE(4257),
    [sym_preproc_undef] = STATE(4257),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(6055),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4258] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7043),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9422),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4258),
    [sym_preproc_endregion] = STATE(4258),
    [sym_preproc_line] = STATE(4258),
    [sym_preproc_pragma] = STATE(4258),
    [sym_preproc_nullable] = STATE(4258),
    [sym_preproc_error] = STATE(4258),
    [sym_preproc_warning] = STATE(4258),
    [sym_preproc_define] = STATE(4258),
    [sym_preproc_undef] = STATE(4258),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4259] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7046),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9561),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4259),
    [sym_preproc_endregion] = STATE(4259),
    [sym_preproc_line] = STATE(4259),
    [sym_preproc_pragma] = STATE(4259),
    [sym_preproc_nullable] = STATE(4259),
    [sym_preproc_error] = STATE(4259),
    [sym_preproc_warning] = STATE(4259),
    [sym_preproc_define] = STATE(4259),
    [sym_preproc_undef] = STATE(4259),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(6055),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4260] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7047),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9758),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4260),
    [sym_preproc_endregion] = STATE(4260),
    [sym_preproc_line] = STATE(4260),
    [sym_preproc_pragma] = STATE(4260),
    [sym_preproc_nullable] = STATE(4260),
    [sym_preproc_error] = STATE(4260),
    [sym_preproc_warning] = STATE(4260),
    [sym_preproc_define] = STATE(4260),
    [sym_preproc_undef] = STATE(4260),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4261] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7051),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9036),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4261),
    [sym_preproc_endregion] = STATE(4261),
    [sym_preproc_line] = STATE(4261),
    [sym_preproc_pragma] = STATE(4261),
    [sym_preproc_nullable] = STATE(4261),
    [sym_preproc_error] = STATE(4261),
    [sym_preproc_warning] = STATE(4261),
    [sym_preproc_define] = STATE(4261),
    [sym_preproc_undef] = STATE(4261),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(6027),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4262] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7052),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9061),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4262),
    [sym_preproc_endregion] = STATE(4262),
    [sym_preproc_line] = STATE(4262),
    [sym_preproc_pragma] = STATE(4262),
    [sym_preproc_nullable] = STATE(4262),
    [sym_preproc_error] = STATE(4262),
    [sym_preproc_warning] = STATE(4262),
    [sym_preproc_define] = STATE(4262),
    [sym_preproc_undef] = STATE(4262),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4263] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7055),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9197),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4263),
    [sym_preproc_endregion] = STATE(4263),
    [sym_preproc_line] = STATE(4263),
    [sym_preproc_pragma] = STATE(4263),
    [sym_preproc_nullable] = STATE(4263),
    [sym_preproc_error] = STATE(4263),
    [sym_preproc_warning] = STATE(4263),
    [sym_preproc_define] = STATE(4263),
    [sym_preproc_undef] = STATE(4263),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(6027),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4264] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7056),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9204),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4264),
    [sym_preproc_endregion] = STATE(4264),
    [sym_preproc_line] = STATE(4264),
    [sym_preproc_pragma] = STATE(4264),
    [sym_preproc_nullable] = STATE(4264),
    [sym_preproc_error] = STATE(4264),
    [sym_preproc_warning] = STATE(4264),
    [sym_preproc_define] = STATE(4264),
    [sym_preproc_undef] = STATE(4264),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4265] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7059),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9244),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4265),
    [sym_preproc_endregion] = STATE(4265),
    [sym_preproc_line] = STATE(4265),
    [sym_preproc_pragma] = STATE(4265),
    [sym_preproc_nullable] = STATE(4265),
    [sym_preproc_error] = STATE(4265),
    [sym_preproc_warning] = STATE(4265),
    [sym_preproc_define] = STATE(4265),
    [sym_preproc_undef] = STATE(4265),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(6055),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4266] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7060),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9252),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4266),
    [sym_preproc_endregion] = STATE(4266),
    [sym_preproc_line] = STATE(4266),
    [sym_preproc_pragma] = STATE(4266),
    [sym_preproc_nullable] = STATE(4266),
    [sym_preproc_error] = STATE(4266),
    [sym_preproc_warning] = STATE(4266),
    [sym_preproc_define] = STATE(4266),
    [sym_preproc_undef] = STATE(4266),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4267] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7063),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9296),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4267),
    [sym_preproc_endregion] = STATE(4267),
    [sym_preproc_line] = STATE(4267),
    [sym_preproc_pragma] = STATE(4267),
    [sym_preproc_nullable] = STATE(4267),
    [sym_preproc_error] = STATE(4267),
    [sym_preproc_warning] = STATE(4267),
    [sym_preproc_define] = STATE(4267),
    [sym_preproc_undef] = STATE(4267),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(6027),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4268] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7064),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9315),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4268),
    [sym_preproc_endregion] = STATE(4268),
    [sym_preproc_line] = STATE(4268),
    [sym_preproc_pragma] = STATE(4268),
    [sym_preproc_nullable] = STATE(4268),
    [sym_preproc_error] = STATE(4268),
    [sym_preproc_warning] = STATE(4268),
    [sym_preproc_define] = STATE(4268),
    [sym_preproc_undef] = STATE(4268),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4269] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7067),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9394),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4269),
    [sym_preproc_endregion] = STATE(4269),
    [sym_preproc_line] = STATE(4269),
    [sym_preproc_pragma] = STATE(4269),
    [sym_preproc_nullable] = STATE(4269),
    [sym_preproc_error] = STATE(4269),
    [sym_preproc_warning] = STATE(4269),
    [sym_preproc_define] = STATE(4269),
    [sym_preproc_undef] = STATE(4269),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(6037),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4270] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7068),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9471),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4270),
    [sym_preproc_endregion] = STATE(4270),
    [sym_preproc_line] = STATE(4270),
    [sym_preproc_pragma] = STATE(4270),
    [sym_preproc_nullable] = STATE(4270),
    [sym_preproc_error] = STATE(4270),
    [sym_preproc_warning] = STATE(4270),
    [sym_preproc_define] = STATE(4270),
    [sym_preproc_undef] = STATE(4270),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4271] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7071),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9655),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4271),
    [sym_preproc_endregion] = STATE(4271),
    [sym_preproc_line] = STATE(4271),
    [sym_preproc_pragma] = STATE(4271),
    [sym_preproc_nullable] = STATE(4271),
    [sym_preproc_error] = STATE(4271),
    [sym_preproc_warning] = STATE(4271),
    [sym_preproc_define] = STATE(4271),
    [sym_preproc_undef] = STATE(4271),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(6037),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4272] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7166),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9695),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4272),
    [sym_preproc_endregion] = STATE(4272),
    [sym_preproc_line] = STATE(4272),
    [sym_preproc_pragma] = STATE(4272),
    [sym_preproc_nullable] = STATE(4272),
    [sym_preproc_error] = STATE(4272),
    [sym_preproc_warning] = STATE(4272),
    [sym_preproc_define] = STATE(4272),
    [sym_preproc_undef] = STATE(4272),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4273] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7075),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9337),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4273),
    [sym_preproc_endregion] = STATE(4273),
    [sym_preproc_line] = STATE(4273),
    [sym_preproc_pragma] = STATE(4273),
    [sym_preproc_nullable] = STATE(4273),
    [sym_preproc_error] = STATE(4273),
    [sym_preproc_warning] = STATE(4273),
    [sym_preproc_define] = STATE(4273),
    [sym_preproc_undef] = STATE(4273),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(6019),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4274] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7076),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9342),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4274),
    [sym_preproc_endregion] = STATE(4274),
    [sym_preproc_line] = STATE(4274),
    [sym_preproc_pragma] = STATE(4274),
    [sym_preproc_nullable] = STATE(4274),
    [sym_preproc_error] = STATE(4274),
    [sym_preproc_warning] = STATE(4274),
    [sym_preproc_define] = STATE(4274),
    [sym_preproc_undef] = STATE(4274),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4275] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7079),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9853),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4275),
    [sym_preproc_endregion] = STATE(4275),
    [sym_preproc_line] = STATE(4275),
    [sym_preproc_pragma] = STATE(4275),
    [sym_preproc_nullable] = STATE(4275),
    [sym_preproc_error] = STATE(4275),
    [sym_preproc_warning] = STATE(4275),
    [sym_preproc_define] = STATE(4275),
    [sym_preproc_undef] = STATE(4275),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(6055),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4276] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7080),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9913),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4276),
    [sym_preproc_endregion] = STATE(4276),
    [sym_preproc_line] = STATE(4276),
    [sym_preproc_pragma] = STATE(4276),
    [sym_preproc_nullable] = STATE(4276),
    [sym_preproc_error] = STATE(4276),
    [sym_preproc_warning] = STATE(4276),
    [sym_preproc_define] = STATE(4276),
    [sym_preproc_undef] = STATE(4276),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4277] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7084),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9370),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4277),
    [sym_preproc_endregion] = STATE(4277),
    [sym_preproc_line] = STATE(4277),
    [sym_preproc_pragma] = STATE(4277),
    [sym_preproc_nullable] = STATE(4277),
    [sym_preproc_error] = STATE(4277),
    [sym_preproc_warning] = STATE(4277),
    [sym_preproc_define] = STATE(4277),
    [sym_preproc_undef] = STATE(4277),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4278] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7087),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9037),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4278),
    [sym_preproc_endregion] = STATE(4278),
    [sym_preproc_line] = STATE(4278),
    [sym_preproc_pragma] = STATE(4278),
    [sym_preproc_nullable] = STATE(4278),
    [sym_preproc_error] = STATE(4278),
    [sym_preproc_warning] = STATE(4278),
    [sym_preproc_define] = STATE(4278),
    [sym_preproc_undef] = STATE(4278),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(6037),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4279] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7088),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9047),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4279),
    [sym_preproc_endregion] = STATE(4279),
    [sym_preproc_line] = STATE(4279),
    [sym_preproc_pragma] = STATE(4279),
    [sym_preproc_nullable] = STATE(4279),
    [sym_preproc_error] = STATE(4279),
    [sym_preproc_warning] = STATE(4279),
    [sym_preproc_define] = STATE(4279),
    [sym_preproc_undef] = STATE(4279),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4280] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7093),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9083),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4280),
    [sym_preproc_endregion] = STATE(4280),
    [sym_preproc_line] = STATE(4280),
    [sym_preproc_pragma] = STATE(4280),
    [sym_preproc_nullable] = STATE(4280),
    [sym_preproc_error] = STATE(4280),
    [sym_preproc_warning] = STATE(4280),
    [sym_preproc_define] = STATE(4280),
    [sym_preproc_undef] = STATE(4280),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(6055),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4281] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7094),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9095),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4281),
    [sym_preproc_endregion] = STATE(4281),
    [sym_preproc_line] = STATE(4281),
    [sym_preproc_pragma] = STATE(4281),
    [sym_preproc_nullable] = STATE(4281),
    [sym_preproc_error] = STATE(4281),
    [sym_preproc_warning] = STATE(4281),
    [sym_preproc_define] = STATE(4281),
    [sym_preproc_undef] = STATE(4281),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4282] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7097),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9125),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4282),
    [sym_preproc_endregion] = STATE(4282),
    [sym_preproc_line] = STATE(4282),
    [sym_preproc_pragma] = STATE(4282),
    [sym_preproc_nullable] = STATE(4282),
    [sym_preproc_error] = STATE(4282),
    [sym_preproc_warning] = STATE(4282),
    [sym_preproc_define] = STATE(4282),
    [sym_preproc_undef] = STATE(4282),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(6055),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4283] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7098),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9139),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4283),
    [sym_preproc_endregion] = STATE(4283),
    [sym_preproc_line] = STATE(4283),
    [sym_preproc_pragma] = STATE(4283),
    [sym_preproc_nullable] = STATE(4283),
    [sym_preproc_error] = STATE(4283),
    [sym_preproc_warning] = STATE(4283),
    [sym_preproc_define] = STATE(4283),
    [sym_preproc_undef] = STATE(4283),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4284] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7101),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9199),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4284),
    [sym_preproc_endregion] = STATE(4284),
    [sym_preproc_line] = STATE(4284),
    [sym_preproc_pragma] = STATE(4284),
    [sym_preproc_nullable] = STATE(4284),
    [sym_preproc_error] = STATE(4284),
    [sym_preproc_warning] = STATE(4284),
    [sym_preproc_define] = STATE(4284),
    [sym_preproc_undef] = STATE(4284),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(6055),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4285] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7102),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9234),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4285),
    [sym_preproc_endregion] = STATE(4285),
    [sym_preproc_line] = STATE(4285),
    [sym_preproc_pragma] = STATE(4285),
    [sym_preproc_nullable] = STATE(4285),
    [sym_preproc_error] = STATE(4285),
    [sym_preproc_warning] = STATE(4285),
    [sym_preproc_define] = STATE(4285),
    [sym_preproc_undef] = STATE(4285),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4286] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7108),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9821),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4286),
    [sym_preproc_endregion] = STATE(4286),
    [sym_preproc_line] = STATE(4286),
    [sym_preproc_pragma] = STATE(4286),
    [sym_preproc_nullable] = STATE(4286),
    [sym_preproc_error] = STATE(4286),
    [sym_preproc_warning] = STATE(4286),
    [sym_preproc_define] = STATE(4286),
    [sym_preproc_undef] = STATE(4286),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(5984),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4287] = {
    [sym_preproc_region] = STATE(4287),
    [sym_preproc_endregion] = STATE(4287),
    [sym_preproc_line] = STATE(4287),
    [sym_preproc_pragma] = STATE(4287),
    [sym_preproc_nullable] = STATE(4287),
    [sym_preproc_error] = STATE(4287),
    [sym_preproc_warning] = STATE(4287),
    [sym_preproc_define] = STATE(4287),
    [sym_preproc_undef] = STATE(4287),
    [anon_sym_SEMI] = ACTIONS(5452),
    [anon_sym_LBRACK] = ACTIONS(5452),
    [anon_sym_COLON] = ACTIONS(5452),
    [anon_sym_COMMA] = ACTIONS(5452),
    [anon_sym_RBRACK] = ACTIONS(5452),
    [anon_sym_LPAREN] = ACTIONS(5452),
    [anon_sym_RPAREN] = ACTIONS(5452),
    [anon_sym_RBRACE] = ACTIONS(5452),
    [anon_sym_LT] = ACTIONS(5454),
    [anon_sym_GT] = ACTIONS(5454),
    [anon_sym_in] = ACTIONS(5452),
    [anon_sym_QMARK] = ACTIONS(5454),
    [anon_sym_BANG] = ACTIONS(5454),
    [anon_sym_PLUS_PLUS] = ACTIONS(5452),
    [anon_sym_DASH_DASH] = ACTIONS(5452),
    [anon_sym_PLUS] = ACTIONS(5454),
    [anon_sym_DASH] = ACTIONS(5454),
    [anon_sym_STAR] = ACTIONS(5452),
    [anon_sym_SLASH] = ACTIONS(5454),
    [anon_sym_PERCENT] = ACTIONS(5452),
    [anon_sym_CARET] = ACTIONS(5452),
    [anon_sym_PIPE] = ACTIONS(5454),
    [anon_sym_AMP] = ACTIONS(5454),
    [anon_sym_LT_LT] = ACTIONS(5452),
    [anon_sym_GT_GT] = ACTIONS(5454),
    [anon_sym_GT_GT_GT] = ACTIONS(5452),
    [anon_sym_EQ_EQ] = ACTIONS(5452),
    [anon_sym_BANG_EQ] = ACTIONS(5452),
    [anon_sym_GT_EQ] = ACTIONS(5452),
    [anon_sym_LT_EQ] = ACTIONS(5452),
    [anon_sym_DOT] = ACTIONS(5454),
    [anon_sym_EQ_GT] = ACTIONS(5452),
    [anon_sym_switch] = ACTIONS(5452),
    [anon_sym_when] = ACTIONS(5452),
    [anon_sym_DOT_DOT] = ACTIONS(5452),
    [anon_sym_and] = ACTIONS(5452),
    [anon_sym_or] = ACTIONS(5452),
    [anon_sym_AMP_AMP] = ACTIONS(5452),
    [anon_sym_PIPE_PIPE] = ACTIONS(5452),
    [anon_sym_QMARK_QMARK] = ACTIONS(5452),
    [anon_sym_on] = ACTIONS(5452),
    [anon_sym_equals] = ACTIONS(5452),
    [anon_sym_by] = ACTIONS(5452),
    [anon_sym_as] = ACTIONS(5452),
    [anon_sym_is] = ACTIONS(5452),
    [anon_sym_DASH_GT] = ACTIONS(5452),
    [anon_sym_with] = ACTIONS(5452),
    [aux_sym_preproc_if_token3] = ACTIONS(5452),
    [aux_sym_preproc_else_token1] = ACTIONS(5452),
    [aux_sym_preproc_elif_token1] = ACTIONS(5452),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4288] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7117),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9336),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4288),
    [sym_preproc_endregion] = STATE(4288),
    [sym_preproc_line] = STATE(4288),
    [sym_preproc_pragma] = STATE(4288),
    [sym_preproc_nullable] = STATE(4288),
    [sym_preproc_error] = STATE(4288),
    [sym_preproc_warning] = STATE(4288),
    [sym_preproc_define] = STATE(4288),
    [sym_preproc_undef] = STATE(4288),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4289] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7114),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9175),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4289),
    [sym_preproc_endregion] = STATE(4289),
    [sym_preproc_line] = STATE(4289),
    [sym_preproc_pragma] = STATE(4289),
    [sym_preproc_nullable] = STATE(4289),
    [sym_preproc_error] = STATE(4289),
    [sym_preproc_warning] = STATE(4289),
    [sym_preproc_define] = STATE(4289),
    [sym_preproc_undef] = STATE(4289),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4290] = {
    [sym_preproc_region] = STATE(4290),
    [sym_preproc_endregion] = STATE(4290),
    [sym_preproc_line] = STATE(4290),
    [sym_preproc_pragma] = STATE(4290),
    [sym_preproc_nullable] = STATE(4290),
    [sym_preproc_error] = STATE(4290),
    [sym_preproc_warning] = STATE(4290),
    [sym_preproc_define] = STATE(4290),
    [sym_preproc_undef] = STATE(4290),
    [anon_sym_SEMI] = ACTIONS(2997),
    [anon_sym_LBRACK] = ACTIONS(2997),
    [anon_sym_COLON] = ACTIONS(2997),
    [anon_sym_COMMA] = ACTIONS(2997),
    [anon_sym_RBRACK] = ACTIONS(2997),
    [anon_sym_LPAREN] = ACTIONS(2997),
    [anon_sym_RPAREN] = ACTIONS(2997),
    [anon_sym_RBRACE] = ACTIONS(2997),
    [anon_sym_LT] = ACTIONS(2995),
    [anon_sym_GT] = ACTIONS(2995),
    [anon_sym_in] = ACTIONS(2997),
    [anon_sym_QMARK] = ACTIONS(2995),
    [anon_sym_BANG] = ACTIONS(2995),
    [anon_sym_PLUS_PLUS] = ACTIONS(2997),
    [anon_sym_DASH_DASH] = ACTIONS(2997),
    [anon_sym_PLUS] = ACTIONS(2995),
    [anon_sym_DASH] = ACTIONS(2995),
    [anon_sym_STAR] = ACTIONS(2997),
    [anon_sym_SLASH] = ACTIONS(2995),
    [anon_sym_PERCENT] = ACTIONS(2997),
    [anon_sym_CARET] = ACTIONS(2997),
    [anon_sym_PIPE] = ACTIONS(2995),
    [anon_sym_AMP] = ACTIONS(2995),
    [anon_sym_LT_LT] = ACTIONS(2997),
    [anon_sym_GT_GT] = ACTIONS(2995),
    [anon_sym_GT_GT_GT] = ACTIONS(2997),
    [anon_sym_EQ_EQ] = ACTIONS(2997),
    [anon_sym_BANG_EQ] = ACTIONS(2997),
    [anon_sym_GT_EQ] = ACTIONS(2997),
    [anon_sym_LT_EQ] = ACTIONS(2997),
    [anon_sym_DOT] = ACTIONS(2995),
    [anon_sym_EQ_GT] = ACTIONS(2997),
    [anon_sym_switch] = ACTIONS(2997),
    [anon_sym_when] = ACTIONS(2997),
    [anon_sym_DOT_DOT] = ACTIONS(2997),
    [anon_sym_and] = ACTIONS(2997),
    [anon_sym_or] = ACTIONS(2997),
    [anon_sym_AMP_AMP] = ACTIONS(2997),
    [anon_sym_PIPE_PIPE] = ACTIONS(2997),
    [anon_sym_QMARK_QMARK] = ACTIONS(2997),
    [anon_sym_on] = ACTIONS(2997),
    [anon_sym_equals] = ACTIONS(2997),
    [anon_sym_by] = ACTIONS(2997),
    [anon_sym_as] = ACTIONS(2997),
    [anon_sym_is] = ACTIONS(2997),
    [anon_sym_DASH_GT] = ACTIONS(2997),
    [anon_sym_with] = ACTIONS(2997),
    [aux_sym_preproc_if_token3] = ACTIONS(2997),
    [aux_sym_preproc_else_token1] = ACTIONS(2997),
    [aux_sym_preproc_elif_token1] = ACTIONS(2997),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4291] = {
    [sym_preproc_region] = STATE(4291),
    [sym_preproc_endregion] = STATE(4291),
    [sym_preproc_line] = STATE(4291),
    [sym_preproc_pragma] = STATE(4291),
    [sym_preproc_nullable] = STATE(4291),
    [sym_preproc_error] = STATE(4291),
    [sym_preproc_warning] = STATE(4291),
    [sym_preproc_define] = STATE(4291),
    [sym_preproc_undef] = STATE(4291),
    [anon_sym_SEMI] = ACTIONS(2993),
    [anon_sym_LBRACK] = ACTIONS(2993),
    [anon_sym_COLON] = ACTIONS(2993),
    [anon_sym_COMMA] = ACTIONS(2993),
    [anon_sym_RBRACK] = ACTIONS(2993),
    [anon_sym_LPAREN] = ACTIONS(2993),
    [anon_sym_RPAREN] = ACTIONS(2993),
    [anon_sym_RBRACE] = ACTIONS(2993),
    [anon_sym_LT] = ACTIONS(2991),
    [anon_sym_GT] = ACTIONS(2991),
    [anon_sym_in] = ACTIONS(2993),
    [anon_sym_QMARK] = ACTIONS(2991),
    [anon_sym_BANG] = ACTIONS(2991),
    [anon_sym_PLUS_PLUS] = ACTIONS(2993),
    [anon_sym_DASH_DASH] = ACTIONS(2993),
    [anon_sym_PLUS] = ACTIONS(2991),
    [anon_sym_DASH] = ACTIONS(2991),
    [anon_sym_STAR] = ACTIONS(2993),
    [anon_sym_SLASH] = ACTIONS(2991),
    [anon_sym_PERCENT] = ACTIONS(2993),
    [anon_sym_CARET] = ACTIONS(2993),
    [anon_sym_PIPE] = ACTIONS(2991),
    [anon_sym_AMP] = ACTIONS(2991),
    [anon_sym_LT_LT] = ACTIONS(2993),
    [anon_sym_GT_GT] = ACTIONS(2991),
    [anon_sym_GT_GT_GT] = ACTIONS(2993),
    [anon_sym_EQ_EQ] = ACTIONS(2993),
    [anon_sym_BANG_EQ] = ACTIONS(2993),
    [anon_sym_GT_EQ] = ACTIONS(2993),
    [anon_sym_LT_EQ] = ACTIONS(2993),
    [anon_sym_DOT] = ACTIONS(2991),
    [anon_sym_EQ_GT] = ACTIONS(2993),
    [anon_sym_switch] = ACTIONS(2993),
    [anon_sym_when] = ACTIONS(2993),
    [anon_sym_DOT_DOT] = ACTIONS(2993),
    [anon_sym_and] = ACTIONS(2993),
    [anon_sym_or] = ACTIONS(2993),
    [anon_sym_AMP_AMP] = ACTIONS(2993),
    [anon_sym_PIPE_PIPE] = ACTIONS(2993),
    [anon_sym_QMARK_QMARK] = ACTIONS(2993),
    [anon_sym_on] = ACTIONS(2993),
    [anon_sym_equals] = ACTIONS(2993),
    [anon_sym_by] = ACTIONS(2993),
    [anon_sym_as] = ACTIONS(2993),
    [anon_sym_is] = ACTIONS(2993),
    [anon_sym_DASH_GT] = ACTIONS(2993),
    [anon_sym_with] = ACTIONS(2993),
    [aux_sym_preproc_if_token3] = ACTIONS(2993),
    [aux_sym_preproc_else_token1] = ACTIONS(2993),
    [aux_sym_preproc_elif_token1] = ACTIONS(2993),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4292] = {
    [sym_preproc_region] = STATE(4292),
    [sym_preproc_endregion] = STATE(4292),
    [sym_preproc_line] = STATE(4292),
    [sym_preproc_pragma] = STATE(4292),
    [sym_preproc_nullable] = STATE(4292),
    [sym_preproc_error] = STATE(4292),
    [sym_preproc_warning] = STATE(4292),
    [sym_preproc_define] = STATE(4292),
    [sym_preproc_undef] = STATE(4292),
    [anon_sym_SEMI] = ACTIONS(3039),
    [anon_sym_LBRACK] = ACTIONS(3039),
    [anon_sym_COLON] = ACTIONS(3039),
    [anon_sym_COMMA] = ACTIONS(3039),
    [anon_sym_RBRACK] = ACTIONS(3039),
    [anon_sym_LPAREN] = ACTIONS(3039),
    [anon_sym_RPAREN] = ACTIONS(3039),
    [anon_sym_RBRACE] = ACTIONS(3039),
    [anon_sym_LT] = ACTIONS(3037),
    [anon_sym_GT] = ACTIONS(3037),
    [anon_sym_in] = ACTIONS(3039),
    [anon_sym_QMARK] = ACTIONS(3037),
    [anon_sym_BANG] = ACTIONS(3037),
    [anon_sym_PLUS_PLUS] = ACTIONS(3039),
    [anon_sym_DASH_DASH] = ACTIONS(3039),
    [anon_sym_PLUS] = ACTIONS(3037),
    [anon_sym_DASH] = ACTIONS(3037),
    [anon_sym_STAR] = ACTIONS(3039),
    [anon_sym_SLASH] = ACTIONS(3037),
    [anon_sym_PERCENT] = ACTIONS(3039),
    [anon_sym_CARET] = ACTIONS(3039),
    [anon_sym_PIPE] = ACTIONS(3037),
    [anon_sym_AMP] = ACTIONS(3037),
    [anon_sym_LT_LT] = ACTIONS(3039),
    [anon_sym_GT_GT] = ACTIONS(3037),
    [anon_sym_GT_GT_GT] = ACTIONS(3039),
    [anon_sym_EQ_EQ] = ACTIONS(3039),
    [anon_sym_BANG_EQ] = ACTIONS(3039),
    [anon_sym_GT_EQ] = ACTIONS(3039),
    [anon_sym_LT_EQ] = ACTIONS(3039),
    [anon_sym_DOT] = ACTIONS(3037),
    [anon_sym_EQ_GT] = ACTIONS(3039),
    [anon_sym_switch] = ACTIONS(3039),
    [anon_sym_when] = ACTIONS(3039),
    [anon_sym_DOT_DOT] = ACTIONS(3039),
    [anon_sym_and] = ACTIONS(3039),
    [anon_sym_or] = ACTIONS(3039),
    [anon_sym_AMP_AMP] = ACTIONS(3039),
    [anon_sym_PIPE_PIPE] = ACTIONS(3039),
    [anon_sym_QMARK_QMARK] = ACTIONS(3039),
    [anon_sym_on] = ACTIONS(3039),
    [anon_sym_equals] = ACTIONS(3039),
    [anon_sym_by] = ACTIONS(3039),
    [anon_sym_as] = ACTIONS(3039),
    [anon_sym_is] = ACTIONS(3039),
    [anon_sym_DASH_GT] = ACTIONS(3039),
    [anon_sym_with] = ACTIONS(3039),
    [aux_sym_preproc_if_token3] = ACTIONS(3039),
    [aux_sym_preproc_else_token1] = ACTIONS(3039),
    [aux_sym_preproc_elif_token1] = ACTIONS(3039),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4293] = {
    [sym_preproc_region] = STATE(4293),
    [sym_preproc_endregion] = STATE(4293),
    [sym_preproc_line] = STATE(4293),
    [sym_preproc_pragma] = STATE(4293),
    [sym_preproc_nullable] = STATE(4293),
    [sym_preproc_error] = STATE(4293),
    [sym_preproc_warning] = STATE(4293),
    [sym_preproc_define] = STATE(4293),
    [sym_preproc_undef] = STATE(4293),
    [anon_sym_SEMI] = ACTIONS(5548),
    [anon_sym_LBRACK] = ACTIONS(5548),
    [anon_sym_COLON] = ACTIONS(5548),
    [anon_sym_COMMA] = ACTIONS(5548),
    [anon_sym_RBRACK] = ACTIONS(5548),
    [anon_sym_LPAREN] = ACTIONS(5548),
    [anon_sym_RPAREN] = ACTIONS(5548),
    [anon_sym_RBRACE] = ACTIONS(5548),
    [anon_sym_LT] = ACTIONS(5550),
    [anon_sym_GT] = ACTIONS(5550),
    [anon_sym_in] = ACTIONS(5548),
    [anon_sym_QMARK] = ACTIONS(5550),
    [anon_sym_BANG] = ACTIONS(5550),
    [anon_sym_PLUS_PLUS] = ACTIONS(5548),
    [anon_sym_DASH_DASH] = ACTIONS(5548),
    [anon_sym_PLUS] = ACTIONS(5550),
    [anon_sym_DASH] = ACTIONS(5550),
    [anon_sym_STAR] = ACTIONS(5548),
    [anon_sym_SLASH] = ACTIONS(5550),
    [anon_sym_PERCENT] = ACTIONS(5548),
    [anon_sym_CARET] = ACTIONS(5548),
    [anon_sym_PIPE] = ACTIONS(5550),
    [anon_sym_AMP] = ACTIONS(5550),
    [anon_sym_LT_LT] = ACTIONS(5548),
    [anon_sym_GT_GT] = ACTIONS(5550),
    [anon_sym_GT_GT_GT] = ACTIONS(5548),
    [anon_sym_EQ_EQ] = ACTIONS(5548),
    [anon_sym_BANG_EQ] = ACTIONS(5548),
    [anon_sym_GT_EQ] = ACTIONS(5548),
    [anon_sym_LT_EQ] = ACTIONS(5548),
    [anon_sym_DOT] = ACTIONS(5550),
    [anon_sym_EQ_GT] = ACTIONS(5548),
    [anon_sym_switch] = ACTIONS(5548),
    [anon_sym_when] = ACTIONS(5548),
    [anon_sym_DOT_DOT] = ACTIONS(5548),
    [anon_sym_and] = ACTIONS(5548),
    [anon_sym_or] = ACTIONS(5548),
    [anon_sym_AMP_AMP] = ACTIONS(5548),
    [anon_sym_PIPE_PIPE] = ACTIONS(5548),
    [anon_sym_QMARK_QMARK] = ACTIONS(5548),
    [anon_sym_on] = ACTIONS(5548),
    [anon_sym_equals] = ACTIONS(5548),
    [anon_sym_by] = ACTIONS(5548),
    [anon_sym_as] = ACTIONS(5548),
    [anon_sym_is] = ACTIONS(5548),
    [anon_sym_DASH_GT] = ACTIONS(5548),
    [anon_sym_with] = ACTIONS(5548),
    [aux_sym_preproc_if_token3] = ACTIONS(5548),
    [aux_sym_preproc_else_token1] = ACTIONS(5548),
    [aux_sym_preproc_elif_token1] = ACTIONS(5548),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4294] = {
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7396),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4294),
    [sym_preproc_endregion] = STATE(4294),
    [sym_preproc_line] = STATE(4294),
    [sym_preproc_pragma] = STATE(4294),
    [sym_preproc_nullable] = STATE(4294),
    [sym_preproc_error] = STATE(4294),
    [sym_preproc_warning] = STATE(4294),
    [sym_preproc_define] = STATE(4294),
    [sym_preproc_undef] = STATE(4294),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(6805),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(5309),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_in] = ACTIONS(1113),
    [anon_sym_out] = ACTIONS(1113),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_this] = ACTIONS(1113),
    [anon_sym_scoped] = ACTIONS(5321),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4295] = {
    [sym_preproc_region] = STATE(4295),
    [sym_preproc_endregion] = STATE(4295),
    [sym_preproc_line] = STATE(4295),
    [sym_preproc_pragma] = STATE(4295),
    [sym_preproc_nullable] = STATE(4295),
    [sym_preproc_error] = STATE(4295),
    [sym_preproc_warning] = STATE(4295),
    [sym_preproc_define] = STATE(4295),
    [sym_preproc_undef] = STATE(4295),
    [anon_sym_SEMI] = ACTIONS(5592),
    [anon_sym_LBRACK] = ACTIONS(5592),
    [anon_sym_COLON] = ACTIONS(5592),
    [anon_sym_COMMA] = ACTIONS(5592),
    [anon_sym_RBRACK] = ACTIONS(5592),
    [anon_sym_LPAREN] = ACTIONS(5592),
    [anon_sym_RPAREN] = ACTIONS(5592),
    [anon_sym_RBRACE] = ACTIONS(5592),
    [anon_sym_LT] = ACTIONS(5594),
    [anon_sym_GT] = ACTIONS(5594),
    [anon_sym_in] = ACTIONS(5592),
    [anon_sym_QMARK] = ACTIONS(5594),
    [anon_sym_BANG] = ACTIONS(5594),
    [anon_sym_PLUS_PLUS] = ACTIONS(5592),
    [anon_sym_DASH_DASH] = ACTIONS(5592),
    [anon_sym_PLUS] = ACTIONS(5594),
    [anon_sym_DASH] = ACTIONS(5594),
    [anon_sym_STAR] = ACTIONS(5592),
    [anon_sym_SLASH] = ACTIONS(5594),
    [anon_sym_PERCENT] = ACTIONS(5592),
    [anon_sym_CARET] = ACTIONS(5592),
    [anon_sym_PIPE] = ACTIONS(5594),
    [anon_sym_AMP] = ACTIONS(5594),
    [anon_sym_LT_LT] = ACTIONS(5592),
    [anon_sym_GT_GT] = ACTIONS(5594),
    [anon_sym_GT_GT_GT] = ACTIONS(5592),
    [anon_sym_EQ_EQ] = ACTIONS(5592),
    [anon_sym_BANG_EQ] = ACTIONS(5592),
    [anon_sym_GT_EQ] = ACTIONS(5592),
    [anon_sym_LT_EQ] = ACTIONS(5592),
    [anon_sym_DOT] = ACTIONS(5594),
    [anon_sym_EQ_GT] = ACTIONS(5592),
    [anon_sym_switch] = ACTIONS(5592),
    [anon_sym_when] = ACTIONS(5592),
    [anon_sym_DOT_DOT] = ACTIONS(5592),
    [anon_sym_and] = ACTIONS(5592),
    [anon_sym_or] = ACTIONS(5592),
    [anon_sym_AMP_AMP] = ACTIONS(5592),
    [anon_sym_PIPE_PIPE] = ACTIONS(5592),
    [anon_sym_QMARK_QMARK] = ACTIONS(5592),
    [anon_sym_on] = ACTIONS(5592),
    [anon_sym_equals] = ACTIONS(5592),
    [anon_sym_by] = ACTIONS(5592),
    [anon_sym_as] = ACTIONS(5592),
    [anon_sym_is] = ACTIONS(5592),
    [anon_sym_DASH_GT] = ACTIONS(5592),
    [anon_sym_with] = ACTIONS(5592),
    [aux_sym_preproc_if_token3] = ACTIONS(5592),
    [aux_sym_preproc_else_token1] = ACTIONS(5592),
    [aux_sym_preproc_elif_token1] = ACTIONS(5592),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4296] = {
    [sym_attribute_list] = STATE(4448),
    [sym_preproc_region] = STATE(4296),
    [sym_preproc_endregion] = STATE(4296),
    [sym_preproc_line] = STATE(4296),
    [sym_preproc_pragma] = STATE(4296),
    [sym_preproc_nullable] = STATE(4296),
    [sym_preproc_error] = STATE(4296),
    [sym_preproc_warning] = STATE(4296),
    [sym_preproc_define] = STATE(4296),
    [sym_preproc_undef] = STATE(4296),
    [aux_sym_class_declaration_repeat1] = STATE(4296),
    [sym__identifier_token] = ACTIONS(5394),
    [anon_sym_extern] = ACTIONS(5394),
    [anon_sym_alias] = ACTIONS(5394),
    [anon_sym_global] = ACTIONS(5394),
    [anon_sym_unsafe] = ACTIONS(5394),
    [anon_sym_static] = ACTIONS(5394),
    [anon_sym_LBRACK] = ACTIONS(6057),
    [anon_sym_abstract] = ACTIONS(5394),
    [anon_sym_async] = ACTIONS(5394),
    [anon_sym_const] = ACTIONS(5394),
    [anon_sym_file] = ACTIONS(5394),
    [anon_sym_fixed] = ACTIONS(5394),
    [anon_sym_internal] = ACTIONS(5394),
    [anon_sym_new] = ACTIONS(5394),
    [anon_sym_override] = ACTIONS(5394),
    [anon_sym_partial] = ACTIONS(5394),
    [anon_sym_private] = ACTIONS(5394),
    [anon_sym_protected] = ACTIONS(5394),
    [anon_sym_public] = ACTIONS(5394),
    [anon_sym_readonly] = ACTIONS(5394),
    [anon_sym_required] = ACTIONS(5394),
    [anon_sym_sealed] = ACTIONS(5394),
    [anon_sym_virtual] = ACTIONS(5394),
    [anon_sym_volatile] = ACTIONS(5394),
    [anon_sym_where] = ACTIONS(5394),
    [anon_sym_notnull] = ACTIONS(5394),
    [anon_sym_unmanaged] = ACTIONS(5394),
    [anon_sym_get] = ACTIONS(5394),
    [anon_sym_set] = ACTIONS(5394),
    [anon_sym_add] = ACTIONS(5394),
    [anon_sym_remove] = ACTIONS(5394),
    [anon_sym_init] = ACTIONS(5394),
    [anon_sym_scoped] = ACTIONS(5394),
    [anon_sym_var] = ACTIONS(5394),
    [anon_sym_yield] = ACTIONS(5394),
    [anon_sym_when] = ACTIONS(5394),
    [anon_sym_from] = ACTIONS(5394),
    [anon_sym_into] = ACTIONS(5394),
    [anon_sym_join] = ACTIONS(5394),
    [anon_sym_on] = ACTIONS(5394),
    [anon_sym_equals] = ACTIONS(5394),
    [anon_sym_let] = ACTIONS(5394),
    [anon_sym_orderby] = ACTIONS(5394),
    [anon_sym_ascending] = ACTIONS(5394),
    [anon_sym_descending] = ACTIONS(5394),
    [anon_sym_group] = ACTIONS(5394),
    [anon_sym_by] = ACTIONS(5394),
    [anon_sym_select] = ACTIONS(5394),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4297] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7122),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9628),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4297),
    [sym_preproc_endregion] = STATE(4297),
    [sym_preproc_line] = STATE(4297),
    [sym_preproc_pragma] = STATE(4297),
    [sym_preproc_nullable] = STATE(4297),
    [sym_preproc_error] = STATE(4297),
    [sym_preproc_warning] = STATE(4297),
    [sym_preproc_define] = STATE(4297),
    [sym_preproc_undef] = STATE(4297),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(6027),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4298] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7123),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9631),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4298),
    [sym_preproc_endregion] = STATE(4298),
    [sym_preproc_line] = STATE(4298),
    [sym_preproc_pragma] = STATE(4298),
    [sym_preproc_nullable] = STATE(4298),
    [sym_preproc_error] = STATE(4298),
    [sym_preproc_warning] = STATE(4298),
    [sym_preproc_define] = STATE(4298),
    [sym_preproc_undef] = STATE(4298),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4299] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7126),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9707),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4299),
    [sym_preproc_endregion] = STATE(4299),
    [sym_preproc_line] = STATE(4299),
    [sym_preproc_pragma] = STATE(4299),
    [sym_preproc_nullable] = STATE(4299),
    [sym_preproc_error] = STATE(4299),
    [sym_preproc_warning] = STATE(4299),
    [sym_preproc_define] = STATE(4299),
    [sym_preproc_undef] = STATE(4299),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(5984),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4300] = {
    [sym_preproc_region] = STATE(4300),
    [sym_preproc_endregion] = STATE(4300),
    [sym_preproc_line] = STATE(4300),
    [sym_preproc_pragma] = STATE(4300),
    [sym_preproc_nullable] = STATE(4300),
    [sym_preproc_error] = STATE(4300),
    [sym_preproc_warning] = STATE(4300),
    [sym_preproc_define] = STATE(4300),
    [sym_preproc_undef] = STATE(4300),
    [anon_sym_SEMI] = ACTIONS(3001),
    [anon_sym_LBRACK] = ACTIONS(3001),
    [anon_sym_COLON] = ACTIONS(3001),
    [anon_sym_COMMA] = ACTIONS(3001),
    [anon_sym_RBRACK] = ACTIONS(3001),
    [anon_sym_LPAREN] = ACTIONS(3001),
    [anon_sym_RPAREN] = ACTIONS(3001),
    [anon_sym_RBRACE] = ACTIONS(3001),
    [anon_sym_LT] = ACTIONS(2999),
    [anon_sym_GT] = ACTIONS(2999),
    [anon_sym_in] = ACTIONS(3001),
    [anon_sym_QMARK] = ACTIONS(2999),
    [anon_sym_BANG] = ACTIONS(2999),
    [anon_sym_PLUS_PLUS] = ACTIONS(3001),
    [anon_sym_DASH_DASH] = ACTIONS(3001),
    [anon_sym_PLUS] = ACTIONS(2999),
    [anon_sym_DASH] = ACTIONS(2999),
    [anon_sym_STAR] = ACTIONS(3001),
    [anon_sym_SLASH] = ACTIONS(2999),
    [anon_sym_PERCENT] = ACTIONS(3001),
    [anon_sym_CARET] = ACTIONS(3001),
    [anon_sym_PIPE] = ACTIONS(2999),
    [anon_sym_AMP] = ACTIONS(2999),
    [anon_sym_LT_LT] = ACTIONS(3001),
    [anon_sym_GT_GT] = ACTIONS(2999),
    [anon_sym_GT_GT_GT] = ACTIONS(3001),
    [anon_sym_EQ_EQ] = ACTIONS(3001),
    [anon_sym_BANG_EQ] = ACTIONS(3001),
    [anon_sym_GT_EQ] = ACTIONS(3001),
    [anon_sym_LT_EQ] = ACTIONS(3001),
    [anon_sym_DOT] = ACTIONS(2999),
    [anon_sym_EQ_GT] = ACTIONS(3001),
    [anon_sym_switch] = ACTIONS(3001),
    [anon_sym_when] = ACTIONS(3001),
    [anon_sym_DOT_DOT] = ACTIONS(3001),
    [anon_sym_and] = ACTIONS(3001),
    [anon_sym_or] = ACTIONS(3001),
    [anon_sym_AMP_AMP] = ACTIONS(3001),
    [anon_sym_PIPE_PIPE] = ACTIONS(3001),
    [anon_sym_QMARK_QMARK] = ACTIONS(3001),
    [anon_sym_on] = ACTIONS(3001),
    [anon_sym_equals] = ACTIONS(3001),
    [anon_sym_by] = ACTIONS(3001),
    [anon_sym_as] = ACTIONS(3001),
    [anon_sym_is] = ACTIONS(3001),
    [anon_sym_DASH_GT] = ACTIONS(3001),
    [anon_sym_with] = ACTIONS(3001),
    [aux_sym_preproc_if_token3] = ACTIONS(3001),
    [aux_sym_preproc_else_token1] = ACTIONS(3001),
    [aux_sym_preproc_elif_token1] = ACTIONS(3001),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4301] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7129),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9000),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4301),
    [sym_preproc_endregion] = STATE(4301),
    [sym_preproc_line] = STATE(4301),
    [sym_preproc_pragma] = STATE(4301),
    [sym_preproc_nullable] = STATE(4301),
    [sym_preproc_error] = STATE(4301),
    [sym_preproc_warning] = STATE(4301),
    [sym_preproc_define] = STATE(4301),
    [sym_preproc_undef] = STATE(4301),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4302] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7133),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9546),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4302),
    [sym_preproc_endregion] = STATE(4302),
    [sym_preproc_line] = STATE(4302),
    [sym_preproc_pragma] = STATE(4302),
    [sym_preproc_nullable] = STATE(4302),
    [sym_preproc_error] = STATE(4302),
    [sym_preproc_warning] = STATE(4302),
    [sym_preproc_define] = STATE(4302),
    [sym_preproc_undef] = STATE(4302),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(5984),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4303] = {
    [sym_preproc_region] = STATE(4303),
    [sym_preproc_endregion] = STATE(4303),
    [sym_preproc_line] = STATE(4303),
    [sym_preproc_pragma] = STATE(4303),
    [sym_preproc_nullable] = STATE(4303),
    [sym_preproc_error] = STATE(4303),
    [sym_preproc_warning] = STATE(4303),
    [sym_preproc_define] = STATE(4303),
    [sym_preproc_undef] = STATE(4303),
    [anon_sym_SEMI] = ACTIONS(5480),
    [anon_sym_LBRACK] = ACTIONS(5480),
    [anon_sym_COLON] = ACTIONS(5480),
    [anon_sym_COMMA] = ACTIONS(5480),
    [anon_sym_RBRACK] = ACTIONS(5480),
    [anon_sym_LPAREN] = ACTIONS(5480),
    [anon_sym_RPAREN] = ACTIONS(5480),
    [anon_sym_RBRACE] = ACTIONS(5480),
    [anon_sym_LT] = ACTIONS(5482),
    [anon_sym_GT] = ACTIONS(5482),
    [anon_sym_in] = ACTIONS(5480),
    [anon_sym_QMARK] = ACTIONS(5482),
    [anon_sym_BANG] = ACTIONS(5482),
    [anon_sym_PLUS_PLUS] = ACTIONS(5480),
    [anon_sym_DASH_DASH] = ACTIONS(5480),
    [anon_sym_PLUS] = ACTIONS(5482),
    [anon_sym_DASH] = ACTIONS(5482),
    [anon_sym_STAR] = ACTIONS(5480),
    [anon_sym_SLASH] = ACTIONS(5482),
    [anon_sym_PERCENT] = ACTIONS(5480),
    [anon_sym_CARET] = ACTIONS(5480),
    [anon_sym_PIPE] = ACTIONS(5482),
    [anon_sym_AMP] = ACTIONS(5482),
    [anon_sym_LT_LT] = ACTIONS(5480),
    [anon_sym_GT_GT] = ACTIONS(5482),
    [anon_sym_GT_GT_GT] = ACTIONS(5480),
    [anon_sym_EQ_EQ] = ACTIONS(5480),
    [anon_sym_BANG_EQ] = ACTIONS(5480),
    [anon_sym_GT_EQ] = ACTIONS(5480),
    [anon_sym_LT_EQ] = ACTIONS(5480),
    [anon_sym_DOT] = ACTIONS(5482),
    [anon_sym_EQ_GT] = ACTIONS(5480),
    [anon_sym_switch] = ACTIONS(5480),
    [anon_sym_when] = ACTIONS(5480),
    [anon_sym_DOT_DOT] = ACTIONS(5480),
    [anon_sym_and] = ACTIONS(5480),
    [anon_sym_or] = ACTIONS(5480),
    [anon_sym_AMP_AMP] = ACTIONS(5480),
    [anon_sym_PIPE_PIPE] = ACTIONS(5480),
    [anon_sym_QMARK_QMARK] = ACTIONS(5480),
    [anon_sym_on] = ACTIONS(5480),
    [anon_sym_equals] = ACTIONS(5480),
    [anon_sym_by] = ACTIONS(5480),
    [anon_sym_as] = ACTIONS(5480),
    [anon_sym_is] = ACTIONS(5480),
    [anon_sym_DASH_GT] = ACTIONS(5480),
    [anon_sym_with] = ACTIONS(5480),
    [aux_sym_preproc_if_token3] = ACTIONS(5480),
    [aux_sym_preproc_else_token1] = ACTIONS(5480),
    [aux_sym_preproc_elif_token1] = ACTIONS(5480),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4304] = {
    [sym_preproc_region] = STATE(4304),
    [sym_preproc_endregion] = STATE(4304),
    [sym_preproc_line] = STATE(4304),
    [sym_preproc_pragma] = STATE(4304),
    [sym_preproc_nullable] = STATE(4304),
    [sym_preproc_error] = STATE(4304),
    [sym_preproc_warning] = STATE(4304),
    [sym_preproc_define] = STATE(4304),
    [sym_preproc_undef] = STATE(4304),
    [anon_sym_SEMI] = ACTIONS(5490),
    [anon_sym_LBRACK] = ACTIONS(5490),
    [anon_sym_COLON] = ACTIONS(5490),
    [anon_sym_COMMA] = ACTIONS(5490),
    [anon_sym_RBRACK] = ACTIONS(5490),
    [anon_sym_LPAREN] = ACTIONS(5490),
    [anon_sym_RPAREN] = ACTIONS(5490),
    [anon_sym_RBRACE] = ACTIONS(5490),
    [anon_sym_LT] = ACTIONS(5492),
    [anon_sym_GT] = ACTIONS(5492),
    [anon_sym_in] = ACTIONS(5490),
    [anon_sym_QMARK] = ACTIONS(5492),
    [anon_sym_BANG] = ACTIONS(5492),
    [anon_sym_PLUS_PLUS] = ACTIONS(5490),
    [anon_sym_DASH_DASH] = ACTIONS(5490),
    [anon_sym_PLUS] = ACTIONS(5492),
    [anon_sym_DASH] = ACTIONS(5492),
    [anon_sym_STAR] = ACTIONS(5490),
    [anon_sym_SLASH] = ACTIONS(5492),
    [anon_sym_PERCENT] = ACTIONS(5490),
    [anon_sym_CARET] = ACTIONS(5490),
    [anon_sym_PIPE] = ACTIONS(5492),
    [anon_sym_AMP] = ACTIONS(5492),
    [anon_sym_LT_LT] = ACTIONS(5490),
    [anon_sym_GT_GT] = ACTIONS(5492),
    [anon_sym_GT_GT_GT] = ACTIONS(5490),
    [anon_sym_EQ_EQ] = ACTIONS(5490),
    [anon_sym_BANG_EQ] = ACTIONS(5490),
    [anon_sym_GT_EQ] = ACTIONS(5490),
    [anon_sym_LT_EQ] = ACTIONS(5490),
    [anon_sym_DOT] = ACTIONS(5492),
    [anon_sym_EQ_GT] = ACTIONS(5490),
    [anon_sym_switch] = ACTIONS(5490),
    [anon_sym_when] = ACTIONS(5490),
    [anon_sym_DOT_DOT] = ACTIONS(5490),
    [anon_sym_and] = ACTIONS(5490),
    [anon_sym_or] = ACTIONS(5490),
    [anon_sym_AMP_AMP] = ACTIONS(5490),
    [anon_sym_PIPE_PIPE] = ACTIONS(5490),
    [anon_sym_QMARK_QMARK] = ACTIONS(5490),
    [anon_sym_on] = ACTIONS(5490),
    [anon_sym_equals] = ACTIONS(5490),
    [anon_sym_by] = ACTIONS(5490),
    [anon_sym_as] = ACTIONS(5490),
    [anon_sym_is] = ACTIONS(5490),
    [anon_sym_DASH_GT] = ACTIONS(5490),
    [anon_sym_with] = ACTIONS(5490),
    [aux_sym_preproc_if_token3] = ACTIONS(5490),
    [aux_sym_preproc_else_token1] = ACTIONS(5490),
    [aux_sym_preproc_elif_token1] = ACTIONS(5490),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4305] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7135),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9592),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4305),
    [sym_preproc_endregion] = STATE(4305),
    [sym_preproc_line] = STATE(4305),
    [sym_preproc_pragma] = STATE(4305),
    [sym_preproc_nullable] = STATE(4305),
    [sym_preproc_error] = STATE(4305),
    [sym_preproc_warning] = STATE(4305),
    [sym_preproc_define] = STATE(4305),
    [sym_preproc_undef] = STATE(4305),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4306] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7141),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9841),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4306),
    [sym_preproc_endregion] = STATE(4306),
    [sym_preproc_line] = STATE(4306),
    [sym_preproc_pragma] = STATE(4306),
    [sym_preproc_nullable] = STATE(4306),
    [sym_preproc_error] = STATE(4306),
    [sym_preproc_warning] = STATE(4306),
    [sym_preproc_define] = STATE(4306),
    [sym_preproc_undef] = STATE(4306),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(5984),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4307] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7142),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9867),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4307),
    [sym_preproc_endregion] = STATE(4307),
    [sym_preproc_line] = STATE(4307),
    [sym_preproc_pragma] = STATE(4307),
    [sym_preproc_nullable] = STATE(4307),
    [sym_preproc_error] = STATE(4307),
    [sym_preproc_warning] = STATE(4307),
    [sym_preproc_define] = STATE(4307),
    [sym_preproc_undef] = STATE(4307),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4308] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7145),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9021),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4308),
    [sym_preproc_endregion] = STATE(4308),
    [sym_preproc_line] = STATE(4308),
    [sym_preproc_pragma] = STATE(4308),
    [sym_preproc_nullable] = STATE(4308),
    [sym_preproc_error] = STATE(4308),
    [sym_preproc_warning] = STATE(4308),
    [sym_preproc_define] = STATE(4308),
    [sym_preproc_undef] = STATE(4308),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(5984),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4309] = {
    [sym_preproc_region] = STATE(4309),
    [sym_preproc_endregion] = STATE(4309),
    [sym_preproc_line] = STATE(4309),
    [sym_preproc_pragma] = STATE(4309),
    [sym_preproc_nullable] = STATE(4309),
    [sym_preproc_error] = STATE(4309),
    [sym_preproc_warning] = STATE(4309),
    [sym_preproc_define] = STATE(4309),
    [sym_preproc_undef] = STATE(4309),
    [anon_sym_SEMI] = ACTIONS(5498),
    [anon_sym_LBRACK] = ACTIONS(5498),
    [anon_sym_COLON] = ACTIONS(5498),
    [anon_sym_COMMA] = ACTIONS(5498),
    [anon_sym_RBRACK] = ACTIONS(5498),
    [anon_sym_LPAREN] = ACTIONS(5498),
    [anon_sym_RPAREN] = ACTIONS(5498),
    [anon_sym_RBRACE] = ACTIONS(5498),
    [anon_sym_LT] = ACTIONS(5500),
    [anon_sym_GT] = ACTIONS(5500),
    [anon_sym_in] = ACTIONS(5498),
    [anon_sym_QMARK] = ACTIONS(5500),
    [anon_sym_BANG] = ACTIONS(5500),
    [anon_sym_PLUS_PLUS] = ACTIONS(5498),
    [anon_sym_DASH_DASH] = ACTIONS(5498),
    [anon_sym_PLUS] = ACTIONS(5500),
    [anon_sym_DASH] = ACTIONS(5500),
    [anon_sym_STAR] = ACTIONS(5498),
    [anon_sym_SLASH] = ACTIONS(5500),
    [anon_sym_PERCENT] = ACTIONS(5498),
    [anon_sym_CARET] = ACTIONS(5498),
    [anon_sym_PIPE] = ACTIONS(5500),
    [anon_sym_AMP] = ACTIONS(5500),
    [anon_sym_LT_LT] = ACTIONS(5498),
    [anon_sym_GT_GT] = ACTIONS(5500),
    [anon_sym_GT_GT_GT] = ACTIONS(5498),
    [anon_sym_EQ_EQ] = ACTIONS(5498),
    [anon_sym_BANG_EQ] = ACTIONS(5498),
    [anon_sym_GT_EQ] = ACTIONS(5498),
    [anon_sym_LT_EQ] = ACTIONS(5498),
    [anon_sym_DOT] = ACTIONS(5500),
    [anon_sym_EQ_GT] = ACTIONS(5498),
    [anon_sym_switch] = ACTIONS(5498),
    [anon_sym_when] = ACTIONS(5498),
    [anon_sym_DOT_DOT] = ACTIONS(5498),
    [anon_sym_and] = ACTIONS(5498),
    [anon_sym_or] = ACTIONS(5498),
    [anon_sym_AMP_AMP] = ACTIONS(5498),
    [anon_sym_PIPE_PIPE] = ACTIONS(5498),
    [anon_sym_QMARK_QMARK] = ACTIONS(5498),
    [anon_sym_on] = ACTIONS(5498),
    [anon_sym_equals] = ACTIONS(5498),
    [anon_sym_by] = ACTIONS(5498),
    [anon_sym_as] = ACTIONS(5498),
    [anon_sym_is] = ACTIONS(5498),
    [anon_sym_DASH_GT] = ACTIONS(5498),
    [anon_sym_with] = ACTIONS(5498),
    [aux_sym_preproc_if_token3] = ACTIONS(5498),
    [aux_sym_preproc_else_token1] = ACTIONS(5498),
    [aux_sym_preproc_elif_token1] = ACTIONS(5498),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4310] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7146),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9033),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4310),
    [sym_preproc_endregion] = STATE(4310),
    [sym_preproc_line] = STATE(4310),
    [sym_preproc_pragma] = STATE(4310),
    [sym_preproc_nullable] = STATE(4310),
    [sym_preproc_error] = STATE(4310),
    [sym_preproc_warning] = STATE(4310),
    [sym_preproc_define] = STATE(4310),
    [sym_preproc_undef] = STATE(4310),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4311] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7149),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9077),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4311),
    [sym_preproc_endregion] = STATE(4311),
    [sym_preproc_line] = STATE(4311),
    [sym_preproc_pragma] = STATE(4311),
    [sym_preproc_nullable] = STATE(4311),
    [sym_preproc_error] = STATE(4311),
    [sym_preproc_warning] = STATE(4311),
    [sym_preproc_define] = STATE(4311),
    [sym_preproc_undef] = STATE(4311),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(5984),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4312] = {
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7340),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4312),
    [sym_preproc_endregion] = STATE(4312),
    [sym_preproc_line] = STATE(4312),
    [sym_preproc_pragma] = STATE(4312),
    [sym_preproc_nullable] = STATE(4312),
    [sym_preproc_error] = STATE(4312),
    [sym_preproc_warning] = STATE(4312),
    [sym_preproc_define] = STATE(4312),
    [sym_preproc_undef] = STATE(4312),
    [aux_sym__parameter_type_with_modifiers_repeat1] = STATE(6805),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(5309),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_readonly] = ACTIONS(1113),
    [anon_sym_in] = ACTIONS(1113),
    [anon_sym_out] = ACTIONS(1113),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_this] = ACTIONS(1113),
    [anon_sym_scoped] = ACTIONS(5321),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4313] = {
    [sym_preproc_region] = STATE(4313),
    [sym_preproc_endregion] = STATE(4313),
    [sym_preproc_line] = STATE(4313),
    [sym_preproc_pragma] = STATE(4313),
    [sym_preproc_nullable] = STATE(4313),
    [sym_preproc_error] = STATE(4313),
    [sym_preproc_warning] = STATE(4313),
    [sym_preproc_define] = STATE(4313),
    [sym_preproc_undef] = STATE(4313),
    [anon_sym_SEMI] = ACTIONS(5522),
    [anon_sym_LBRACK] = ACTIONS(5522),
    [anon_sym_COLON] = ACTIONS(5522),
    [anon_sym_COMMA] = ACTIONS(5522),
    [anon_sym_RBRACK] = ACTIONS(5522),
    [anon_sym_LPAREN] = ACTIONS(5522),
    [anon_sym_RPAREN] = ACTIONS(5522),
    [anon_sym_RBRACE] = ACTIONS(5522),
    [anon_sym_LT] = ACTIONS(5524),
    [anon_sym_GT] = ACTIONS(5524),
    [anon_sym_in] = ACTIONS(5522),
    [anon_sym_QMARK] = ACTIONS(5524),
    [anon_sym_BANG] = ACTIONS(5524),
    [anon_sym_PLUS_PLUS] = ACTIONS(5522),
    [anon_sym_DASH_DASH] = ACTIONS(5522),
    [anon_sym_PLUS] = ACTIONS(5524),
    [anon_sym_DASH] = ACTIONS(5524),
    [anon_sym_STAR] = ACTIONS(5522),
    [anon_sym_SLASH] = ACTIONS(5524),
    [anon_sym_PERCENT] = ACTIONS(5522),
    [anon_sym_CARET] = ACTIONS(5522),
    [anon_sym_PIPE] = ACTIONS(5524),
    [anon_sym_AMP] = ACTIONS(5524),
    [anon_sym_LT_LT] = ACTIONS(5522),
    [anon_sym_GT_GT] = ACTIONS(5524),
    [anon_sym_GT_GT_GT] = ACTIONS(5522),
    [anon_sym_EQ_EQ] = ACTIONS(5522),
    [anon_sym_BANG_EQ] = ACTIONS(5522),
    [anon_sym_GT_EQ] = ACTIONS(5522),
    [anon_sym_LT_EQ] = ACTIONS(5522),
    [anon_sym_DOT] = ACTIONS(5524),
    [anon_sym_EQ_GT] = ACTIONS(5522),
    [anon_sym_switch] = ACTIONS(5522),
    [anon_sym_when] = ACTIONS(5522),
    [anon_sym_DOT_DOT] = ACTIONS(5522),
    [anon_sym_and] = ACTIONS(5522),
    [anon_sym_or] = ACTIONS(5522),
    [anon_sym_AMP_AMP] = ACTIONS(5522),
    [anon_sym_PIPE_PIPE] = ACTIONS(5522),
    [anon_sym_QMARK_QMARK] = ACTIONS(5522),
    [anon_sym_on] = ACTIONS(5522),
    [anon_sym_equals] = ACTIONS(5522),
    [anon_sym_by] = ACTIONS(5522),
    [anon_sym_as] = ACTIONS(5522),
    [anon_sym_is] = ACTIONS(5522),
    [anon_sym_DASH_GT] = ACTIONS(5522),
    [anon_sym_with] = ACTIONS(5522),
    [aux_sym_preproc_if_token3] = ACTIONS(5522),
    [aux_sym_preproc_else_token1] = ACTIONS(5522),
    [aux_sym_preproc_elif_token1] = ACTIONS(5522),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4314] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7150),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9088),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4314),
    [sym_preproc_endregion] = STATE(4314),
    [sym_preproc_line] = STATE(4314),
    [sym_preproc_pragma] = STATE(4314),
    [sym_preproc_nullable] = STATE(4314),
    [sym_preproc_error] = STATE(4314),
    [sym_preproc_warning] = STATE(4314),
    [sym_preproc_define] = STATE(4314),
    [sym_preproc_undef] = STATE(4314),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4315] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7153),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9121),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4315),
    [sym_preproc_endregion] = STATE(4315),
    [sym_preproc_line] = STATE(4315),
    [sym_preproc_pragma] = STATE(4315),
    [sym_preproc_nullable] = STATE(4315),
    [sym_preproc_error] = STATE(4315),
    [sym_preproc_warning] = STATE(4315),
    [sym_preproc_define] = STATE(4315),
    [sym_preproc_undef] = STATE(4315),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(5984),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4316] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7154),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9131),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4316),
    [sym_preproc_endregion] = STATE(4316),
    [sym_preproc_line] = STATE(4316),
    [sym_preproc_pragma] = STATE(4316),
    [sym_preproc_nullable] = STATE(4316),
    [sym_preproc_error] = STATE(4316),
    [sym_preproc_warning] = STATE(4316),
    [sym_preproc_define] = STATE(4316),
    [sym_preproc_undef] = STATE(4316),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4317] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7157),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9157),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4317),
    [sym_preproc_endregion] = STATE(4317),
    [sym_preproc_line] = STATE(4317),
    [sym_preproc_pragma] = STATE(4317),
    [sym_preproc_nullable] = STATE(4317),
    [sym_preproc_error] = STATE(4317),
    [sym_preproc_warning] = STATE(4317),
    [sym_preproc_define] = STATE(4317),
    [sym_preproc_undef] = STATE(4317),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(5984),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4318] = {
    [sym_preproc_region] = STATE(4318),
    [sym_preproc_endregion] = STATE(4318),
    [sym_preproc_line] = STATE(4318),
    [sym_preproc_pragma] = STATE(4318),
    [sym_preproc_nullable] = STATE(4318),
    [sym_preproc_error] = STATE(4318),
    [sym_preproc_warning] = STATE(4318),
    [sym_preproc_define] = STATE(4318),
    [sym_preproc_undef] = STATE(4318),
    [anon_sym_SEMI] = ACTIONS(4765),
    [anon_sym_LBRACK] = ACTIONS(4765),
    [anon_sym_COLON] = ACTIONS(4765),
    [anon_sym_COMMA] = ACTIONS(4765),
    [anon_sym_RBRACK] = ACTIONS(4765),
    [anon_sym_LPAREN] = ACTIONS(4765),
    [anon_sym_RPAREN] = ACTIONS(4765),
    [anon_sym_RBRACE] = ACTIONS(4765),
    [anon_sym_LT] = ACTIONS(4767),
    [anon_sym_GT] = ACTIONS(4767),
    [anon_sym_in] = ACTIONS(4765),
    [anon_sym_QMARK] = ACTIONS(4767),
    [anon_sym_BANG] = ACTIONS(4767),
    [anon_sym_PLUS_PLUS] = ACTIONS(4765),
    [anon_sym_DASH_DASH] = ACTIONS(4765),
    [anon_sym_PLUS] = ACTIONS(4767),
    [anon_sym_DASH] = ACTIONS(4767),
    [anon_sym_STAR] = ACTIONS(4765),
    [anon_sym_SLASH] = ACTIONS(4767),
    [anon_sym_PERCENT] = ACTIONS(4765),
    [anon_sym_CARET] = ACTIONS(4765),
    [anon_sym_PIPE] = ACTIONS(4767),
    [anon_sym_AMP] = ACTIONS(4767),
    [anon_sym_LT_LT] = ACTIONS(4765),
    [anon_sym_GT_GT] = ACTIONS(4767),
    [anon_sym_GT_GT_GT] = ACTIONS(4765),
    [anon_sym_EQ_EQ] = ACTIONS(4765),
    [anon_sym_BANG_EQ] = ACTIONS(4765),
    [anon_sym_GT_EQ] = ACTIONS(4765),
    [anon_sym_LT_EQ] = ACTIONS(4765),
    [anon_sym_DOT] = ACTIONS(4767),
    [anon_sym_EQ_GT] = ACTIONS(4765),
    [anon_sym_switch] = ACTIONS(4765),
    [anon_sym_when] = ACTIONS(4765),
    [anon_sym_DOT_DOT] = ACTIONS(4765),
    [anon_sym_and] = ACTIONS(4765),
    [anon_sym_or] = ACTIONS(4765),
    [anon_sym_AMP_AMP] = ACTIONS(4765),
    [anon_sym_PIPE_PIPE] = ACTIONS(4765),
    [anon_sym_QMARK_QMARK] = ACTIONS(4765),
    [anon_sym_on] = ACTIONS(4765),
    [anon_sym_equals] = ACTIONS(4765),
    [anon_sym_by] = ACTIONS(4765),
    [anon_sym_as] = ACTIONS(4765),
    [anon_sym_is] = ACTIONS(4765),
    [anon_sym_DASH_GT] = ACTIONS(4765),
    [anon_sym_with] = ACTIONS(4765),
    [aux_sym_preproc_if_token3] = ACTIONS(4765),
    [aux_sym_preproc_else_token1] = ACTIONS(4765),
    [aux_sym_preproc_elif_token1] = ACTIONS(4765),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4319] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7158),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9165),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4319),
    [sym_preproc_endregion] = STATE(4319),
    [sym_preproc_line] = STATE(4319),
    [sym_preproc_pragma] = STATE(4319),
    [sym_preproc_nullable] = STATE(4319),
    [sym_preproc_error] = STATE(4319),
    [sym_preproc_warning] = STATE(4319),
    [sym_preproc_define] = STATE(4319),
    [sym_preproc_undef] = STATE(4319),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4320] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7161),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9185),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4320),
    [sym_preproc_endregion] = STATE(4320),
    [sym_preproc_line] = STATE(4320),
    [sym_preproc_pragma] = STATE(4320),
    [sym_preproc_nullable] = STATE(4320),
    [sym_preproc_error] = STATE(4320),
    [sym_preproc_warning] = STATE(4320),
    [sym_preproc_define] = STATE(4320),
    [sym_preproc_undef] = STATE(4320),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(5984),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4321] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7162),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9193),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4321),
    [sym_preproc_endregion] = STATE(4321),
    [sym_preproc_line] = STATE(4321),
    [sym_preproc_pragma] = STATE(4321),
    [sym_preproc_nullable] = STATE(4321),
    [sym_preproc_error] = STATE(4321),
    [sym_preproc_warning] = STATE(4321),
    [sym_preproc_define] = STATE(4321),
    [sym_preproc_undef] = STATE(4321),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4322] = {
    [sym_type_parameter_constraint] = STATE(7849),
    [sym_constructor_constraint] = STATE(8006),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(8011),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4322),
    [sym_preproc_endregion] = STATE(4322),
    [sym_preproc_line] = STATE(4322),
    [sym_preproc_pragma] = STATE(4322),
    [sym_preproc_nullable] = STATE(4322),
    [sym_preproc_error] = STATE(4322),
    [sym_preproc_warning] = STATE(4322),
    [sym_preproc_define] = STATE(4322),
    [sym_preproc_undef] = STATE(4322),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_class] = ACTIONS(5986),
    [anon_sym_ref] = ACTIONS(5988),
    [anon_sym_struct] = ACTIONS(5990),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_new] = ACTIONS(5992),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(5994),
    [anon_sym_unmanaged] = ACTIONS(5994),
    [anon_sym_scoped] = ACTIONS(5996),
    [anon_sym_var] = ACTIONS(5369),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4323] = {
    [sym_preproc_region] = STATE(4323),
    [sym_preproc_endregion] = STATE(4323),
    [sym_preproc_line] = STATE(4323),
    [sym_preproc_pragma] = STATE(4323),
    [sym_preproc_nullable] = STATE(4323),
    [sym_preproc_error] = STATE(4323),
    [sym_preproc_warning] = STATE(4323),
    [sym_preproc_define] = STATE(4323),
    [sym_preproc_undef] = STATE(4323),
    [anon_sym_SEMI] = ACTIONS(5518),
    [anon_sym_LBRACK] = ACTIONS(5518),
    [anon_sym_COLON] = ACTIONS(5518),
    [anon_sym_COMMA] = ACTIONS(5518),
    [anon_sym_RBRACK] = ACTIONS(5518),
    [anon_sym_LPAREN] = ACTIONS(5518),
    [anon_sym_RPAREN] = ACTIONS(5518),
    [anon_sym_RBRACE] = ACTIONS(5518),
    [anon_sym_LT] = ACTIONS(5520),
    [anon_sym_GT] = ACTIONS(5520),
    [anon_sym_in] = ACTIONS(5518),
    [anon_sym_QMARK] = ACTIONS(5520),
    [anon_sym_BANG] = ACTIONS(5520),
    [anon_sym_PLUS_PLUS] = ACTIONS(5518),
    [anon_sym_DASH_DASH] = ACTIONS(5518),
    [anon_sym_PLUS] = ACTIONS(5520),
    [anon_sym_DASH] = ACTIONS(5520),
    [anon_sym_STAR] = ACTIONS(5518),
    [anon_sym_SLASH] = ACTIONS(5520),
    [anon_sym_PERCENT] = ACTIONS(5518),
    [anon_sym_CARET] = ACTIONS(5518),
    [anon_sym_PIPE] = ACTIONS(5520),
    [anon_sym_AMP] = ACTIONS(5520),
    [anon_sym_LT_LT] = ACTIONS(5518),
    [anon_sym_GT_GT] = ACTIONS(5520),
    [anon_sym_GT_GT_GT] = ACTIONS(5518),
    [anon_sym_EQ_EQ] = ACTIONS(5518),
    [anon_sym_BANG_EQ] = ACTIONS(5518),
    [anon_sym_GT_EQ] = ACTIONS(5518),
    [anon_sym_LT_EQ] = ACTIONS(5518),
    [anon_sym_DOT] = ACTIONS(5520),
    [anon_sym_EQ_GT] = ACTIONS(5518),
    [anon_sym_switch] = ACTIONS(5518),
    [anon_sym_when] = ACTIONS(5518),
    [anon_sym_DOT_DOT] = ACTIONS(5518),
    [anon_sym_and] = ACTIONS(5518),
    [anon_sym_or] = ACTIONS(5518),
    [anon_sym_AMP_AMP] = ACTIONS(5518),
    [anon_sym_PIPE_PIPE] = ACTIONS(5518),
    [anon_sym_QMARK_QMARK] = ACTIONS(5518),
    [anon_sym_on] = ACTIONS(5518),
    [anon_sym_equals] = ACTIONS(5518),
    [anon_sym_by] = ACTIONS(5518),
    [anon_sym_as] = ACTIONS(5518),
    [anon_sym_is] = ACTIONS(5518),
    [anon_sym_DASH_GT] = ACTIONS(5518),
    [anon_sym_with] = ACTIONS(5518),
    [aux_sym_preproc_if_token3] = ACTIONS(5518),
    [aux_sym_preproc_else_token1] = ACTIONS(5518),
    [aux_sym_preproc_elif_token1] = ACTIONS(5518),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4324] = {
    [sym_preproc_region] = STATE(4324),
    [sym_preproc_endregion] = STATE(4324),
    [sym_preproc_line] = STATE(4324),
    [sym_preproc_pragma] = STATE(4324),
    [sym_preproc_nullable] = STATE(4324),
    [sym_preproc_error] = STATE(4324),
    [sym_preproc_warning] = STATE(4324),
    [sym_preproc_define] = STATE(4324),
    [sym_preproc_undef] = STATE(4324),
    [anon_sym_SEMI] = ACTIONS(5552),
    [anon_sym_LBRACK] = ACTIONS(5552),
    [anon_sym_COLON] = ACTIONS(5552),
    [anon_sym_COMMA] = ACTIONS(5552),
    [anon_sym_RBRACK] = ACTIONS(5552),
    [anon_sym_LPAREN] = ACTIONS(5552),
    [anon_sym_RPAREN] = ACTIONS(5552),
    [anon_sym_RBRACE] = ACTIONS(5552),
    [anon_sym_LT] = ACTIONS(5554),
    [anon_sym_GT] = ACTIONS(5554),
    [anon_sym_in] = ACTIONS(5552),
    [anon_sym_QMARK] = ACTIONS(5554),
    [anon_sym_BANG] = ACTIONS(5554),
    [anon_sym_PLUS_PLUS] = ACTIONS(5552),
    [anon_sym_DASH_DASH] = ACTIONS(5552),
    [anon_sym_PLUS] = ACTIONS(5554),
    [anon_sym_DASH] = ACTIONS(5554),
    [anon_sym_STAR] = ACTIONS(5552),
    [anon_sym_SLASH] = ACTIONS(5554),
    [anon_sym_PERCENT] = ACTIONS(5552),
    [anon_sym_CARET] = ACTIONS(5552),
    [anon_sym_PIPE] = ACTIONS(5554),
    [anon_sym_AMP] = ACTIONS(5554),
    [anon_sym_LT_LT] = ACTIONS(5552),
    [anon_sym_GT_GT] = ACTIONS(5554),
    [anon_sym_GT_GT_GT] = ACTIONS(5552),
    [anon_sym_EQ_EQ] = ACTIONS(5552),
    [anon_sym_BANG_EQ] = ACTIONS(5552),
    [anon_sym_GT_EQ] = ACTIONS(5552),
    [anon_sym_LT_EQ] = ACTIONS(5552),
    [anon_sym_DOT] = ACTIONS(5554),
    [anon_sym_EQ_GT] = ACTIONS(5552),
    [anon_sym_switch] = ACTIONS(5552),
    [anon_sym_when] = ACTIONS(5552),
    [anon_sym_DOT_DOT] = ACTIONS(5552),
    [anon_sym_and] = ACTIONS(5552),
    [anon_sym_or] = ACTIONS(5552),
    [anon_sym_AMP_AMP] = ACTIONS(5552),
    [anon_sym_PIPE_PIPE] = ACTIONS(5552),
    [anon_sym_QMARK_QMARK] = ACTIONS(5552),
    [anon_sym_on] = ACTIONS(5552),
    [anon_sym_equals] = ACTIONS(5552),
    [anon_sym_by] = ACTIONS(5552),
    [anon_sym_as] = ACTIONS(5552),
    [anon_sym_is] = ACTIONS(5552),
    [anon_sym_DASH_GT] = ACTIONS(5552),
    [anon_sym_with] = ACTIONS(5552),
    [aux_sym_preproc_if_token3] = ACTIONS(5552),
    [aux_sym_preproc_else_token1] = ACTIONS(5552),
    [aux_sym_preproc_elif_token1] = ACTIONS(5552),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4325] = {
    [sym_preproc_region] = STATE(4325),
    [sym_preproc_endregion] = STATE(4325),
    [sym_preproc_line] = STATE(4325),
    [sym_preproc_pragma] = STATE(4325),
    [sym_preproc_nullable] = STATE(4325),
    [sym_preproc_error] = STATE(4325),
    [sym_preproc_warning] = STATE(4325),
    [sym_preproc_define] = STATE(4325),
    [sym_preproc_undef] = STATE(4325),
    [anon_sym_SEMI] = ACTIONS(5556),
    [anon_sym_LBRACK] = ACTIONS(5556),
    [anon_sym_COLON] = ACTIONS(5556),
    [anon_sym_COMMA] = ACTIONS(5556),
    [anon_sym_RBRACK] = ACTIONS(5556),
    [anon_sym_LPAREN] = ACTIONS(5556),
    [anon_sym_RPAREN] = ACTIONS(5556),
    [anon_sym_RBRACE] = ACTIONS(5556),
    [anon_sym_LT] = ACTIONS(5558),
    [anon_sym_GT] = ACTIONS(5558),
    [anon_sym_in] = ACTIONS(5556),
    [anon_sym_QMARK] = ACTIONS(5558),
    [anon_sym_BANG] = ACTIONS(5558),
    [anon_sym_PLUS_PLUS] = ACTIONS(5556),
    [anon_sym_DASH_DASH] = ACTIONS(5556),
    [anon_sym_PLUS] = ACTIONS(5558),
    [anon_sym_DASH] = ACTIONS(5558),
    [anon_sym_STAR] = ACTIONS(5556),
    [anon_sym_SLASH] = ACTIONS(5558),
    [anon_sym_PERCENT] = ACTIONS(5556),
    [anon_sym_CARET] = ACTIONS(5556),
    [anon_sym_PIPE] = ACTIONS(5558),
    [anon_sym_AMP] = ACTIONS(5558),
    [anon_sym_LT_LT] = ACTIONS(5556),
    [anon_sym_GT_GT] = ACTIONS(5558),
    [anon_sym_GT_GT_GT] = ACTIONS(5556),
    [anon_sym_EQ_EQ] = ACTIONS(5556),
    [anon_sym_BANG_EQ] = ACTIONS(5556),
    [anon_sym_GT_EQ] = ACTIONS(5556),
    [anon_sym_LT_EQ] = ACTIONS(5556),
    [anon_sym_DOT] = ACTIONS(5558),
    [anon_sym_EQ_GT] = ACTIONS(5556),
    [anon_sym_switch] = ACTIONS(5556),
    [anon_sym_when] = ACTIONS(5556),
    [anon_sym_DOT_DOT] = ACTIONS(5556),
    [anon_sym_and] = ACTIONS(5556),
    [anon_sym_or] = ACTIONS(5556),
    [anon_sym_AMP_AMP] = ACTIONS(5556),
    [anon_sym_PIPE_PIPE] = ACTIONS(5556),
    [anon_sym_QMARK_QMARK] = ACTIONS(5556),
    [anon_sym_on] = ACTIONS(5556),
    [anon_sym_equals] = ACTIONS(5556),
    [anon_sym_by] = ACTIONS(5556),
    [anon_sym_as] = ACTIONS(5556),
    [anon_sym_is] = ACTIONS(5556),
    [anon_sym_DASH_GT] = ACTIONS(5556),
    [anon_sym_with] = ACTIONS(5556),
    [aux_sym_preproc_if_token3] = ACTIONS(5556),
    [aux_sym_preproc_else_token1] = ACTIONS(5556),
    [aux_sym_preproc_elif_token1] = ACTIONS(5556),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4326] = {
    [sym_preproc_region] = STATE(4326),
    [sym_preproc_endregion] = STATE(4326),
    [sym_preproc_line] = STATE(4326),
    [sym_preproc_pragma] = STATE(4326),
    [sym_preproc_nullable] = STATE(4326),
    [sym_preproc_error] = STATE(4326),
    [sym_preproc_warning] = STATE(4326),
    [sym_preproc_define] = STATE(4326),
    [sym_preproc_undef] = STATE(4326),
    [anon_sym_SEMI] = ACTIONS(5564),
    [anon_sym_LBRACK] = ACTIONS(5564),
    [anon_sym_COLON] = ACTIONS(5564),
    [anon_sym_COMMA] = ACTIONS(5564),
    [anon_sym_RBRACK] = ACTIONS(5564),
    [anon_sym_LPAREN] = ACTIONS(5564),
    [anon_sym_RPAREN] = ACTIONS(5564),
    [anon_sym_RBRACE] = ACTIONS(5564),
    [anon_sym_LT] = ACTIONS(5566),
    [anon_sym_GT] = ACTIONS(5566),
    [anon_sym_in] = ACTIONS(5564),
    [anon_sym_QMARK] = ACTIONS(5566),
    [anon_sym_BANG] = ACTIONS(5566),
    [anon_sym_PLUS_PLUS] = ACTIONS(5564),
    [anon_sym_DASH_DASH] = ACTIONS(5564),
    [anon_sym_PLUS] = ACTIONS(5566),
    [anon_sym_DASH] = ACTIONS(5566),
    [anon_sym_STAR] = ACTIONS(5564),
    [anon_sym_SLASH] = ACTIONS(5566),
    [anon_sym_PERCENT] = ACTIONS(5564),
    [anon_sym_CARET] = ACTIONS(5564),
    [anon_sym_PIPE] = ACTIONS(5566),
    [anon_sym_AMP] = ACTIONS(5566),
    [anon_sym_LT_LT] = ACTIONS(5564),
    [anon_sym_GT_GT] = ACTIONS(5566),
    [anon_sym_GT_GT_GT] = ACTIONS(5564),
    [anon_sym_EQ_EQ] = ACTIONS(5564),
    [anon_sym_BANG_EQ] = ACTIONS(5564),
    [anon_sym_GT_EQ] = ACTIONS(5564),
    [anon_sym_LT_EQ] = ACTIONS(5564),
    [anon_sym_DOT] = ACTIONS(5566),
    [anon_sym_EQ_GT] = ACTIONS(5564),
    [anon_sym_switch] = ACTIONS(5564),
    [anon_sym_when] = ACTIONS(5564),
    [anon_sym_DOT_DOT] = ACTIONS(5564),
    [anon_sym_and] = ACTIONS(5564),
    [anon_sym_or] = ACTIONS(5564),
    [anon_sym_AMP_AMP] = ACTIONS(5564),
    [anon_sym_PIPE_PIPE] = ACTIONS(5564),
    [anon_sym_QMARK_QMARK] = ACTIONS(5564),
    [anon_sym_on] = ACTIONS(5564),
    [anon_sym_equals] = ACTIONS(5564),
    [anon_sym_by] = ACTIONS(5564),
    [anon_sym_as] = ACTIONS(5564),
    [anon_sym_is] = ACTIONS(5564),
    [anon_sym_DASH_GT] = ACTIONS(5564),
    [anon_sym_with] = ACTIONS(5564),
    [aux_sym_preproc_if_token3] = ACTIONS(5564),
    [aux_sym_preproc_else_token1] = ACTIONS(5564),
    [aux_sym_preproc_elif_token1] = ACTIONS(5564),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4327] = {
    [sym_preproc_region] = STATE(4327),
    [sym_preproc_endregion] = STATE(4327),
    [sym_preproc_line] = STATE(4327),
    [sym_preproc_pragma] = STATE(4327),
    [sym_preproc_nullable] = STATE(4327),
    [sym_preproc_error] = STATE(4327),
    [sym_preproc_warning] = STATE(4327),
    [sym_preproc_define] = STATE(4327),
    [sym_preproc_undef] = STATE(4327),
    [anon_sym_SEMI] = ACTIONS(5530),
    [anon_sym_LBRACK] = ACTIONS(5530),
    [anon_sym_COLON] = ACTIONS(5530),
    [anon_sym_COMMA] = ACTIONS(5530),
    [anon_sym_RBRACK] = ACTIONS(5530),
    [anon_sym_LPAREN] = ACTIONS(5530),
    [anon_sym_RPAREN] = ACTIONS(5530),
    [anon_sym_RBRACE] = ACTIONS(5530),
    [anon_sym_LT] = ACTIONS(5532),
    [anon_sym_GT] = ACTIONS(5532),
    [anon_sym_in] = ACTIONS(5530),
    [anon_sym_QMARK] = ACTIONS(5532),
    [anon_sym_BANG] = ACTIONS(5532),
    [anon_sym_PLUS_PLUS] = ACTIONS(5530),
    [anon_sym_DASH_DASH] = ACTIONS(5530),
    [anon_sym_PLUS] = ACTIONS(5532),
    [anon_sym_DASH] = ACTIONS(5532),
    [anon_sym_STAR] = ACTIONS(5530),
    [anon_sym_SLASH] = ACTIONS(5532),
    [anon_sym_PERCENT] = ACTIONS(5530),
    [anon_sym_CARET] = ACTIONS(5530),
    [anon_sym_PIPE] = ACTIONS(5532),
    [anon_sym_AMP] = ACTIONS(5532),
    [anon_sym_LT_LT] = ACTIONS(5530),
    [anon_sym_GT_GT] = ACTIONS(5532),
    [anon_sym_GT_GT_GT] = ACTIONS(5530),
    [anon_sym_EQ_EQ] = ACTIONS(5530),
    [anon_sym_BANG_EQ] = ACTIONS(5530),
    [anon_sym_GT_EQ] = ACTIONS(5530),
    [anon_sym_LT_EQ] = ACTIONS(5530),
    [anon_sym_DOT] = ACTIONS(5532),
    [anon_sym_EQ_GT] = ACTIONS(5530),
    [anon_sym_switch] = ACTIONS(5530),
    [anon_sym_when] = ACTIONS(5530),
    [anon_sym_DOT_DOT] = ACTIONS(5530),
    [anon_sym_and] = ACTIONS(5530),
    [anon_sym_or] = ACTIONS(5530),
    [anon_sym_AMP_AMP] = ACTIONS(5530),
    [anon_sym_PIPE_PIPE] = ACTIONS(5530),
    [anon_sym_QMARK_QMARK] = ACTIONS(5530),
    [anon_sym_on] = ACTIONS(5530),
    [anon_sym_equals] = ACTIONS(5530),
    [anon_sym_by] = ACTIONS(5530),
    [anon_sym_as] = ACTIONS(5530),
    [anon_sym_is] = ACTIONS(5530),
    [anon_sym_DASH_GT] = ACTIONS(5530),
    [anon_sym_with] = ACTIONS(5530),
    [aux_sym_preproc_if_token3] = ACTIONS(5530),
    [aux_sym_preproc_else_token1] = ACTIONS(5530),
    [aux_sym_preproc_elif_token1] = ACTIONS(5530),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4328] = {
    [sym_preproc_region] = STATE(4328),
    [sym_preproc_endregion] = STATE(4328),
    [sym_preproc_line] = STATE(4328),
    [sym_preproc_pragma] = STATE(4328),
    [sym_preproc_nullable] = STATE(4328),
    [sym_preproc_error] = STATE(4328),
    [sym_preproc_warning] = STATE(4328),
    [sym_preproc_define] = STATE(4328),
    [sym_preproc_undef] = STATE(4328),
    [anon_sym_SEMI] = ACTIONS(5568),
    [anon_sym_LBRACK] = ACTIONS(5568),
    [anon_sym_COLON] = ACTIONS(5568),
    [anon_sym_COMMA] = ACTIONS(5568),
    [anon_sym_RBRACK] = ACTIONS(5568),
    [anon_sym_LPAREN] = ACTIONS(5568),
    [anon_sym_RPAREN] = ACTIONS(5568),
    [anon_sym_RBRACE] = ACTIONS(5568),
    [anon_sym_LT] = ACTIONS(5570),
    [anon_sym_GT] = ACTIONS(5570),
    [anon_sym_in] = ACTIONS(5568),
    [anon_sym_QMARK] = ACTIONS(5570),
    [anon_sym_BANG] = ACTIONS(5570),
    [anon_sym_PLUS_PLUS] = ACTIONS(5568),
    [anon_sym_DASH_DASH] = ACTIONS(5568),
    [anon_sym_PLUS] = ACTIONS(5570),
    [anon_sym_DASH] = ACTIONS(5570),
    [anon_sym_STAR] = ACTIONS(5568),
    [anon_sym_SLASH] = ACTIONS(5570),
    [anon_sym_PERCENT] = ACTIONS(5568),
    [anon_sym_CARET] = ACTIONS(5568),
    [anon_sym_PIPE] = ACTIONS(5570),
    [anon_sym_AMP] = ACTIONS(5570),
    [anon_sym_LT_LT] = ACTIONS(5568),
    [anon_sym_GT_GT] = ACTIONS(5570),
    [anon_sym_GT_GT_GT] = ACTIONS(5568),
    [anon_sym_EQ_EQ] = ACTIONS(5568),
    [anon_sym_BANG_EQ] = ACTIONS(5568),
    [anon_sym_GT_EQ] = ACTIONS(5568),
    [anon_sym_LT_EQ] = ACTIONS(5568),
    [anon_sym_DOT] = ACTIONS(5570),
    [anon_sym_EQ_GT] = ACTIONS(5568),
    [anon_sym_switch] = ACTIONS(5568),
    [anon_sym_when] = ACTIONS(5568),
    [anon_sym_DOT_DOT] = ACTIONS(5568),
    [anon_sym_and] = ACTIONS(5568),
    [anon_sym_or] = ACTIONS(5568),
    [anon_sym_AMP_AMP] = ACTIONS(5568),
    [anon_sym_PIPE_PIPE] = ACTIONS(5568),
    [anon_sym_QMARK_QMARK] = ACTIONS(5568),
    [anon_sym_on] = ACTIONS(5568),
    [anon_sym_equals] = ACTIONS(5568),
    [anon_sym_by] = ACTIONS(5568),
    [anon_sym_as] = ACTIONS(5568),
    [anon_sym_is] = ACTIONS(5568),
    [anon_sym_DASH_GT] = ACTIONS(5568),
    [anon_sym_with] = ACTIONS(5568),
    [aux_sym_preproc_if_token3] = ACTIONS(5568),
    [aux_sym_preproc_else_token1] = ACTIONS(5568),
    [aux_sym_preproc_elif_token1] = ACTIONS(5568),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4329] = {
    [sym_preproc_region] = STATE(4329),
    [sym_preproc_endregion] = STATE(4329),
    [sym_preproc_line] = STATE(4329),
    [sym_preproc_pragma] = STATE(4329),
    [sym_preproc_nullable] = STATE(4329),
    [sym_preproc_error] = STATE(4329),
    [sym_preproc_warning] = STATE(4329),
    [sym_preproc_define] = STATE(4329),
    [sym_preproc_undef] = STATE(4329),
    [anon_sym_SEMI] = ACTIONS(5576),
    [anon_sym_LBRACK] = ACTIONS(5576),
    [anon_sym_COLON] = ACTIONS(5576),
    [anon_sym_COMMA] = ACTIONS(5576),
    [anon_sym_RBRACK] = ACTIONS(5576),
    [anon_sym_LPAREN] = ACTIONS(5576),
    [anon_sym_RPAREN] = ACTIONS(5576),
    [anon_sym_RBRACE] = ACTIONS(5576),
    [anon_sym_LT] = ACTIONS(5578),
    [anon_sym_GT] = ACTIONS(5578),
    [anon_sym_in] = ACTIONS(5576),
    [anon_sym_QMARK] = ACTIONS(5578),
    [anon_sym_BANG] = ACTIONS(5578),
    [anon_sym_PLUS_PLUS] = ACTIONS(5576),
    [anon_sym_DASH_DASH] = ACTIONS(5576),
    [anon_sym_PLUS] = ACTIONS(5578),
    [anon_sym_DASH] = ACTIONS(5578),
    [anon_sym_STAR] = ACTIONS(5576),
    [anon_sym_SLASH] = ACTIONS(5578),
    [anon_sym_PERCENT] = ACTIONS(5576),
    [anon_sym_CARET] = ACTIONS(5576),
    [anon_sym_PIPE] = ACTIONS(5578),
    [anon_sym_AMP] = ACTIONS(5578),
    [anon_sym_LT_LT] = ACTIONS(5576),
    [anon_sym_GT_GT] = ACTIONS(5578),
    [anon_sym_GT_GT_GT] = ACTIONS(5576),
    [anon_sym_EQ_EQ] = ACTIONS(5576),
    [anon_sym_BANG_EQ] = ACTIONS(5576),
    [anon_sym_GT_EQ] = ACTIONS(5576),
    [anon_sym_LT_EQ] = ACTIONS(5576),
    [anon_sym_DOT] = ACTIONS(5578),
    [anon_sym_EQ_GT] = ACTIONS(5576),
    [anon_sym_switch] = ACTIONS(5576),
    [anon_sym_when] = ACTIONS(5576),
    [anon_sym_DOT_DOT] = ACTIONS(5576),
    [anon_sym_and] = ACTIONS(5576),
    [anon_sym_or] = ACTIONS(5576),
    [anon_sym_AMP_AMP] = ACTIONS(5576),
    [anon_sym_PIPE_PIPE] = ACTIONS(5576),
    [anon_sym_QMARK_QMARK] = ACTIONS(5576),
    [anon_sym_on] = ACTIONS(5576),
    [anon_sym_equals] = ACTIONS(5576),
    [anon_sym_by] = ACTIONS(5576),
    [anon_sym_as] = ACTIONS(5576),
    [anon_sym_is] = ACTIONS(5576),
    [anon_sym_DASH_GT] = ACTIONS(5576),
    [anon_sym_with] = ACTIONS(5576),
    [aux_sym_preproc_if_token3] = ACTIONS(5576),
    [aux_sym_preproc_else_token1] = ACTIONS(5576),
    [aux_sym_preproc_elif_token1] = ACTIONS(5576),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4330] = {
    [sym__name] = STATE(7882),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(9027),
    [sym_implicit_type] = STATE(8747),
    [sym_array_type] = STATE(8331),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(8345),
    [sym_pointer_type] = STATE(8345),
    [sym__pointer_base_type] = STATE(9367),
    [sym_function_pointer_type] = STATE(8345),
    [sym_function_pointer_parameter] = STATE(9589),
    [sym_ref_type] = STATE(8787),
    [sym__ref_base_type] = STATE(9629),
    [sym_scoped_type] = STATE(8787),
    [sym_tuple_type] = STATE(8056),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4330),
    [sym_preproc_endregion] = STATE(4330),
    [sym_preproc_line] = STATE(4330),
    [sym_preproc_pragma] = STATE(4330),
    [sym_preproc_nullable] = STATE(4330),
    [sym_preproc_error] = STATE(4330),
    [sym_preproc_warning] = STATE(4330),
    [sym_preproc_define] = STATE(4330),
    [sym_preproc_undef] = STATE(4330),
    [aux_sym_function_pointer_type_repeat1] = STATE(4540),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(5976),
    [anon_sym_delegate] = ACTIONS(5747),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_in] = ACTIONS(5978),
    [anon_sym_out] = ACTIONS(5978),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(5980),
    [anon_sym_var] = ACTIONS(5369),
    [sym_predefined_type] = ACTIONS(5982),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4331] = {
    [sym_parameter_list] = STATE(9685),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7072),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__lambda_parameters] = STATE(9914),
    [sym_identifier] = STATE(6795),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4331),
    [sym_preproc_endregion] = STATE(4331),
    [sym_preproc_line] = STATE(4331),
    [sym_preproc_pragma] = STATE(4331),
    [sym_preproc_nullable] = STATE(4331),
    [sym_preproc_error] = STATE(4331),
    [sym_preproc_warning] = STATE(4331),
    [sym_preproc_define] = STATE(4331),
    [sym_preproc_undef] = STATE(4331),
    [aux_sym_lambda_expression_repeat1] = STATE(6901),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_static] = ACTIONS(1061),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(5984),
    [anon_sym_async] = ACTIONS(1061),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4332] = {
    [sym_preproc_region] = STATE(4332),
    [sym_preproc_endregion] = STATE(4332),
    [sym_preproc_line] = STATE(4332),
    [sym_preproc_pragma] = STATE(4332),
    [sym_preproc_nullable] = STATE(4332),
    [sym_preproc_error] = STATE(4332),
    [sym_preproc_warning] = STATE(4332),
    [sym_preproc_define] = STATE(4332),
    [sym_preproc_undef] = STATE(4332),
    [anon_sym_SEMI] = ACTIONS(5544),
    [anon_sym_LBRACK] = ACTIONS(5544),
    [anon_sym_COLON] = ACTIONS(5544),
    [anon_sym_COMMA] = ACTIONS(5544),
    [anon_sym_RBRACK] = ACTIONS(5544),
    [anon_sym_LPAREN] = ACTIONS(5544),
    [anon_sym_RPAREN] = ACTIONS(5544),
    [anon_sym_RBRACE] = ACTIONS(5544),
    [anon_sym_LT] = ACTIONS(5546),
    [anon_sym_GT] = ACTIONS(5546),
    [anon_sym_in] = ACTIONS(5544),
    [anon_sym_QMARK] = ACTIONS(5546),
    [anon_sym_BANG] = ACTIONS(5546),
    [anon_sym_PLUS_PLUS] = ACTIONS(5544),
    [anon_sym_DASH_DASH] = ACTIONS(5544),
    [anon_sym_PLUS] = ACTIONS(5546),
    [anon_sym_DASH] = ACTIONS(5546),
    [anon_sym_STAR] = ACTIONS(5544),
    [anon_sym_SLASH] = ACTIONS(5546),
    [anon_sym_PERCENT] = ACTIONS(5544),
    [anon_sym_CARET] = ACTIONS(5544),
    [anon_sym_PIPE] = ACTIONS(5546),
    [anon_sym_AMP] = ACTIONS(5546),
    [anon_sym_LT_LT] = ACTIONS(5544),
    [anon_sym_GT_GT] = ACTIONS(5546),
    [anon_sym_GT_GT_GT] = ACTIONS(5544),
    [anon_sym_EQ_EQ] = ACTIONS(5544),
    [anon_sym_BANG_EQ] = ACTIONS(5544),
    [anon_sym_GT_EQ] = ACTIONS(5544),
    [anon_sym_LT_EQ] = ACTIONS(5544),
    [anon_sym_DOT] = ACTIONS(5546),
    [anon_sym_EQ_GT] = ACTIONS(5544),
    [anon_sym_switch] = ACTIONS(5544),
    [anon_sym_when] = ACTIONS(5544),
    [anon_sym_DOT_DOT] = ACTIONS(5544),
    [anon_sym_and] = ACTIONS(5544),
    [anon_sym_or] = ACTIONS(5544),
    [anon_sym_AMP_AMP] = ACTIONS(5544),
    [anon_sym_PIPE_PIPE] = ACTIONS(5544),
    [anon_sym_QMARK_QMARK] = ACTIONS(5544),
    [anon_sym_on] = ACTIONS(5544),
    [anon_sym_equals] = ACTIONS(5544),
    [anon_sym_by] = ACTIONS(5544),
    [anon_sym_as] = ACTIONS(5544),
    [anon_sym_is] = ACTIONS(5544),
    [anon_sym_DASH_GT] = ACTIONS(5544),
    [anon_sym_with] = ACTIONS(5544),
    [aux_sym_preproc_if_token3] = ACTIONS(5544),
    [aux_sym_preproc_else_token1] = ACTIONS(5544),
    [aux_sym_preproc_elif_token1] = ACTIONS(5544),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4333] = {
    [sym_preproc_region] = STATE(4333),
    [sym_preproc_endregion] = STATE(4333),
    [sym_preproc_line] = STATE(4333),
    [sym_preproc_pragma] = STATE(4333),
    [sym_preproc_nullable] = STATE(4333),
    [sym_preproc_error] = STATE(4333),
    [sym_preproc_warning] = STATE(4333),
    [sym_preproc_define] = STATE(4333),
    [sym_preproc_undef] = STATE(4333),
    [anon_sym_SEMI] = ACTIONS(5895),
    [anon_sym_LBRACK] = ACTIONS(5895),
    [anon_sym_COLON] = ACTIONS(5895),
    [anon_sym_COMMA] = ACTIONS(5895),
    [anon_sym_RBRACK] = ACTIONS(5895),
    [anon_sym_LPAREN] = ACTIONS(5895),
    [anon_sym_RPAREN] = ACTIONS(5895),
    [anon_sym_RBRACE] = ACTIONS(5895),
    [anon_sym_LT] = ACTIONS(5897),
    [anon_sym_GT] = ACTIONS(5897),
    [anon_sym_in] = ACTIONS(5895),
    [anon_sym_QMARK] = ACTIONS(5897),
    [anon_sym_BANG] = ACTIONS(5897),
    [anon_sym_PLUS_PLUS] = ACTIONS(5895),
    [anon_sym_DASH_DASH] = ACTIONS(5895),
    [anon_sym_PLUS] = ACTIONS(5897),
    [anon_sym_DASH] = ACTIONS(5897),
    [anon_sym_STAR] = ACTIONS(5895),
    [anon_sym_SLASH] = ACTIONS(5897),
    [anon_sym_PERCENT] = ACTIONS(5895),
    [anon_sym_CARET] = ACTIONS(5895),
    [anon_sym_PIPE] = ACTIONS(5897),
    [anon_sym_AMP] = ACTIONS(5897),
    [anon_sym_LT_LT] = ACTIONS(5895),
    [anon_sym_GT_GT] = ACTIONS(5897),
    [anon_sym_GT_GT_GT] = ACTIONS(5895),
    [anon_sym_EQ_EQ] = ACTIONS(5895),
    [anon_sym_BANG_EQ] = ACTIONS(5895),
    [anon_sym_GT_EQ] = ACTIONS(5895),
    [anon_sym_LT_EQ] = ACTIONS(5895),
    [anon_sym_DOT] = ACTIONS(5897),
    [anon_sym_EQ_GT] = ACTIONS(5895),
    [anon_sym_switch] = ACTIONS(5895),
    [anon_sym_when] = ACTIONS(5895),
    [anon_sym_DOT_DOT] = ACTIONS(5895),
    [anon_sym_and] = ACTIONS(5895),
    [anon_sym_or] = ACTIONS(5895),
    [anon_sym_AMP_AMP] = ACTIONS(5895),
    [anon_sym_PIPE_PIPE] = ACTIONS(5895),
    [anon_sym_QMARK_QMARK] = ACTIONS(5895),
    [anon_sym_on] = ACTIONS(5895),
    [anon_sym_equals] = ACTIONS(5895),
    [anon_sym_by] = ACTIONS(5895),
    [anon_sym_as] = ACTIONS(5895),
    [anon_sym_is] = ACTIONS(5895),
    [anon_sym_DASH_GT] = ACTIONS(5895),
    [anon_sym_with] = ACTIONS(5895),
    [aux_sym_preproc_if_token3] = ACTIONS(5895),
    [aux_sym_preproc_else_token1] = ACTIONS(5895),
    [aux_sym_preproc_elif_token1] = ACTIONS(5895),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4334] = {
    [sym_preproc_region] = STATE(4334),
    [sym_preproc_endregion] = STATE(4334),
    [sym_preproc_line] = STATE(4334),
    [sym_preproc_pragma] = STATE(4334),
    [sym_preproc_nullable] = STATE(4334),
    [sym_preproc_error] = STATE(4334),
    [sym_preproc_warning] = STATE(4334),
    [sym_preproc_define] = STATE(4334),
    [sym_preproc_undef] = STATE(4334),
    [anon_sym_EQ] = ACTIONS(6060),
    [anon_sym_LBRACK] = ACTIONS(5286),
    [anon_sym_LPAREN] = ACTIONS(5286),
    [anon_sym_LT] = ACTIONS(5288),
    [anon_sym_GT] = ACTIONS(5288),
    [anon_sym_in] = ACTIONS(5286),
    [anon_sym_QMARK] = ACTIONS(5288),
    [anon_sym_BANG] = ACTIONS(5288),
    [anon_sym_PLUS_PLUS] = ACTIONS(5286),
    [anon_sym_DASH_DASH] = ACTIONS(5286),
    [anon_sym_PLUS] = ACTIONS(5288),
    [anon_sym_DASH] = ACTIONS(5288),
    [anon_sym_STAR] = ACTIONS(5288),
    [anon_sym_SLASH] = ACTIONS(5288),
    [anon_sym_PERCENT] = ACTIONS(5288),
    [anon_sym_CARET] = ACTIONS(5288),
    [anon_sym_PIPE] = ACTIONS(5288),
    [anon_sym_AMP] = ACTIONS(5288),
    [anon_sym_LT_LT] = ACTIONS(5288),
    [anon_sym_GT_GT] = ACTIONS(5288),
    [anon_sym_GT_GT_GT] = ACTIONS(5288),
    [anon_sym_EQ_EQ] = ACTIONS(5286),
    [anon_sym_BANG_EQ] = ACTIONS(5286),
    [anon_sym_GT_EQ] = ACTIONS(5286),
    [anon_sym_LT_EQ] = ACTIONS(5286),
    [anon_sym_DOT] = ACTIONS(5288),
    [anon_sym_switch] = ACTIONS(5286),
    [anon_sym_DOT_DOT] = ACTIONS(5286),
    [anon_sym_and] = ACTIONS(5286),
    [anon_sym_or] = ACTIONS(5286),
    [anon_sym_PLUS_EQ] = ACTIONS(6062),
    [anon_sym_DASH_EQ] = ACTIONS(6062),
    [anon_sym_STAR_EQ] = ACTIONS(6062),
    [anon_sym_SLASH_EQ] = ACTIONS(6062),
    [anon_sym_PERCENT_EQ] = ACTIONS(6062),
    [anon_sym_AMP_EQ] = ACTIONS(6062),
    [anon_sym_CARET_EQ] = ACTIONS(6062),
    [anon_sym_PIPE_EQ] = ACTIONS(6062),
    [anon_sym_LT_LT_EQ] = ACTIONS(6062),
    [anon_sym_GT_GT_EQ] = ACTIONS(6062),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(6062),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(6062),
    [anon_sym_AMP_AMP] = ACTIONS(5286),
    [anon_sym_PIPE_PIPE] = ACTIONS(5286),
    [anon_sym_QMARK_QMARK] = ACTIONS(5288),
    [anon_sym_as] = ACTIONS(5286),
    [anon_sym_is] = ACTIONS(5286),
    [anon_sym_DASH_GT] = ACTIONS(5286),
    [anon_sym_with] = ACTIONS(5286),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4335] = {
    [sym_preproc_region] = STATE(4335),
    [sym_preproc_endregion] = STATE(4335),
    [sym_preproc_line] = STATE(4335),
    [sym_preproc_pragma] = STATE(4335),
    [sym_preproc_nullable] = STATE(4335),
    [sym_preproc_error] = STATE(4335),
    [sym_preproc_warning] = STATE(4335),
    [sym_preproc_define] = STATE(4335),
    [sym_preproc_undef] = STATE(4335),
    [anon_sym_EQ] = ACTIONS(6064),
    [anon_sym_LBRACK] = ACTIONS(5286),
    [anon_sym_COLON] = ACTIONS(5286),
    [anon_sym_LPAREN] = ACTIONS(5286),
    [anon_sym_LT] = ACTIONS(5288),
    [anon_sym_GT] = ACTIONS(5288),
    [anon_sym_QMARK] = ACTIONS(5288),
    [anon_sym_BANG] = ACTIONS(5288),
    [anon_sym_PLUS_PLUS] = ACTIONS(5286),
    [anon_sym_DASH_DASH] = ACTIONS(5286),
    [anon_sym_PLUS] = ACTIONS(5288),
    [anon_sym_DASH] = ACTIONS(5288),
    [anon_sym_STAR] = ACTIONS(5288),
    [anon_sym_SLASH] = ACTIONS(5288),
    [anon_sym_PERCENT] = ACTIONS(5288),
    [anon_sym_CARET] = ACTIONS(5288),
    [anon_sym_PIPE] = ACTIONS(5288),
    [anon_sym_AMP] = ACTIONS(5288),
    [anon_sym_LT_LT] = ACTIONS(5288),
    [anon_sym_GT_GT] = ACTIONS(5288),
    [anon_sym_GT_GT_GT] = ACTIONS(5288),
    [anon_sym_EQ_EQ] = ACTIONS(5286),
    [anon_sym_BANG_EQ] = ACTIONS(5286),
    [anon_sym_GT_EQ] = ACTIONS(5286),
    [anon_sym_LT_EQ] = ACTIONS(5286),
    [anon_sym_DOT] = ACTIONS(5288),
    [anon_sym_switch] = ACTIONS(5286),
    [anon_sym_DOT_DOT] = ACTIONS(5286),
    [anon_sym_and] = ACTIONS(5286),
    [anon_sym_or] = ACTIONS(5286),
    [anon_sym_PLUS_EQ] = ACTIONS(6066),
    [anon_sym_DASH_EQ] = ACTIONS(6066),
    [anon_sym_STAR_EQ] = ACTIONS(6066),
    [anon_sym_SLASH_EQ] = ACTIONS(6066),
    [anon_sym_PERCENT_EQ] = ACTIONS(6066),
    [anon_sym_AMP_EQ] = ACTIONS(6066),
    [anon_sym_CARET_EQ] = ACTIONS(6066),
    [anon_sym_PIPE_EQ] = ACTIONS(6066),
    [anon_sym_LT_LT_EQ] = ACTIONS(6066),
    [anon_sym_GT_GT_EQ] = ACTIONS(6066),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(6066),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(6066),
    [anon_sym_AMP_AMP] = ACTIONS(5286),
    [anon_sym_PIPE_PIPE] = ACTIONS(5286),
    [anon_sym_QMARK_QMARK] = ACTIONS(5288),
    [anon_sym_as] = ACTIONS(5286),
    [anon_sym_is] = ACTIONS(5286),
    [anon_sym_DASH_GT] = ACTIONS(5286),
    [anon_sym_with] = ACTIONS(5286),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4336] = {
    [sym_argument_list] = STATE(4293),
    [sym_bracketed_argument_list] = STATE(3050),
    [sym_preproc_region] = STATE(4336),
    [sym_preproc_endregion] = STATE(4336),
    [sym_preproc_line] = STATE(4336),
    [sym_preproc_pragma] = STATE(4336),
    [sym_preproc_nullable] = STATE(4336),
    [sym_preproc_error] = STATE(4336),
    [sym_preproc_warning] = STATE(4336),
    [sym_preproc_define] = STATE(4336),
    [sym_preproc_undef] = STATE(4336),
    [anon_sym_SEMI] = ACTIONS(5292),
    [anon_sym_LBRACK] = ACTIONS(6068),
    [anon_sym_COLON] = ACTIONS(5292),
    [anon_sym_COMMA] = ACTIONS(5292),
    [anon_sym_RBRACK] = ACTIONS(5292),
    [anon_sym_LPAREN] = ACTIONS(5776),
    [anon_sym_RPAREN] = ACTIONS(5292),
    [anon_sym_RBRACE] = ACTIONS(5292),
    [anon_sym_LT] = ACTIONS(5294),
    [anon_sym_GT] = ACTIONS(5294),
    [anon_sym_in] = ACTIONS(5292),
    [anon_sym_QMARK] = ACTIONS(5294),
    [anon_sym_BANG] = ACTIONS(5832),
    [anon_sym_PLUS_PLUS] = ACTIONS(5834),
    [anon_sym_DASH_DASH] = ACTIONS(5834),
    [anon_sym_PLUS] = ACTIONS(5294),
    [anon_sym_DASH] = ACTIONS(5294),
    [anon_sym_STAR] = ACTIONS(5292),
    [anon_sym_SLASH] = ACTIONS(5294),
    [anon_sym_PERCENT] = ACTIONS(5292),
    [anon_sym_CARET] = ACTIONS(5292),
    [anon_sym_PIPE] = ACTIONS(5294),
    [anon_sym_AMP] = ACTIONS(5294),
    [anon_sym_LT_LT] = ACTIONS(5292),
    [anon_sym_GT_GT] = ACTIONS(5294),
    [anon_sym_GT_GT_GT] = ACTIONS(5292),
    [anon_sym_EQ_EQ] = ACTIONS(5292),
    [anon_sym_BANG_EQ] = ACTIONS(5292),
    [anon_sym_GT_EQ] = ACTIONS(5292),
    [anon_sym_LT_EQ] = ACTIONS(5292),
    [anon_sym_DOT] = ACTIONS(4602),
    [anon_sym_EQ_GT] = ACTIONS(5292),
    [anon_sym_switch] = ACTIONS(5292),
    [anon_sym_DOT_DOT] = ACTIONS(5292),
    [anon_sym_AMP_AMP] = ACTIONS(5292),
    [anon_sym_PIPE_PIPE] = ACTIONS(5292),
    [anon_sym_QMARK_QMARK] = ACTIONS(5292),
    [anon_sym_on] = ACTIONS(5292),
    [anon_sym_equals] = ACTIONS(5292),
    [anon_sym_by] = ACTIONS(5292),
    [anon_sym_as] = ACTIONS(5292),
    [anon_sym_is] = ACTIONS(5292),
    [anon_sym_DASH_GT] = ACTIONS(4604),
    [anon_sym_with] = ACTIONS(5292),
    [aux_sym_preproc_if_token3] = ACTIONS(5292),
    [aux_sym_preproc_else_token1] = ACTIONS(5292),
    [aux_sym_preproc_elif_token1] = ACTIONS(5292),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4337] = {
    [sym_preproc_region] = STATE(4337),
    [sym_preproc_endregion] = STATE(4337),
    [sym_preproc_line] = STATE(4337),
    [sym_preproc_pragma] = STATE(4337),
    [sym_preproc_nullable] = STATE(4337),
    [sym_preproc_error] = STATE(4337),
    [sym_preproc_warning] = STATE(4337),
    [sym_preproc_define] = STATE(4337),
    [sym_preproc_undef] = STATE(4337),
    [anon_sym_EQ] = ACTIONS(6070),
    [anon_sym_LBRACK] = ACTIONS(5286),
    [anon_sym_LPAREN] = ACTIONS(5286),
    [anon_sym_LT] = ACTIONS(5288),
    [anon_sym_GT] = ACTIONS(5288),
    [anon_sym_QMARK] = ACTIONS(5288),
    [anon_sym_BANG] = ACTIONS(5288),
    [anon_sym_PLUS_PLUS] = ACTIONS(5286),
    [anon_sym_DASH_DASH] = ACTIONS(5286),
    [anon_sym_PLUS] = ACTIONS(5288),
    [anon_sym_DASH] = ACTIONS(5288),
    [anon_sym_STAR] = ACTIONS(5288),
    [anon_sym_SLASH] = ACTIONS(5288),
    [anon_sym_PERCENT] = ACTIONS(5288),
    [anon_sym_CARET] = ACTIONS(5288),
    [anon_sym_PIPE] = ACTIONS(5288),
    [anon_sym_AMP] = ACTIONS(5288),
    [anon_sym_LT_LT] = ACTIONS(5288),
    [anon_sym_GT_GT] = ACTIONS(5288),
    [anon_sym_GT_GT_GT] = ACTIONS(5288),
    [anon_sym_EQ_EQ] = ACTIONS(5286),
    [anon_sym_BANG_EQ] = ACTIONS(5286),
    [anon_sym_GT_EQ] = ACTIONS(5286),
    [anon_sym_LT_EQ] = ACTIONS(5286),
    [anon_sym_DOT] = ACTIONS(5288),
    [anon_sym_switch] = ACTIONS(5286),
    [anon_sym_DOT_DOT] = ACTIONS(5286),
    [anon_sym_and] = ACTIONS(5286),
    [anon_sym_or] = ACTIONS(5286),
    [anon_sym_PLUS_EQ] = ACTIONS(6072),
    [anon_sym_DASH_EQ] = ACTIONS(6072),
    [anon_sym_STAR_EQ] = ACTIONS(6072),
    [anon_sym_SLASH_EQ] = ACTIONS(6072),
    [anon_sym_PERCENT_EQ] = ACTIONS(6072),
    [anon_sym_AMP_EQ] = ACTIONS(6072),
    [anon_sym_CARET_EQ] = ACTIONS(6072),
    [anon_sym_PIPE_EQ] = ACTIONS(6072),
    [anon_sym_LT_LT_EQ] = ACTIONS(6072),
    [anon_sym_GT_GT_EQ] = ACTIONS(6072),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(6072),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(6072),
    [anon_sym_AMP_AMP] = ACTIONS(5286),
    [anon_sym_PIPE_PIPE] = ACTIONS(5286),
    [anon_sym_QMARK_QMARK] = ACTIONS(5288),
    [anon_sym_by] = ACTIONS(5286),
    [anon_sym_as] = ACTIONS(5286),
    [anon_sym_is] = ACTIONS(5286),
    [anon_sym_DASH_GT] = ACTIONS(5286),
    [anon_sym_with] = ACTIONS(5286),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4338] = {
    [sym_argument_list] = STATE(4293),
    [sym_bracketed_argument_list] = STATE(3050),
    [sym_preproc_region] = STATE(4338),
    [sym_preproc_endregion] = STATE(4338),
    [sym_preproc_line] = STATE(4338),
    [sym_preproc_pragma] = STATE(4338),
    [sym_preproc_nullable] = STATE(4338),
    [sym_preproc_error] = STATE(4338),
    [sym_preproc_warning] = STATE(4338),
    [sym_preproc_define] = STATE(4338),
    [sym_preproc_undef] = STATE(4338),
    [anon_sym_SEMI] = ACTIONS(5325),
    [anon_sym_LBRACK] = ACTIONS(6068),
    [anon_sym_COLON] = ACTIONS(5325),
    [anon_sym_COMMA] = ACTIONS(5325),
    [anon_sym_RBRACK] = ACTIONS(5325),
    [anon_sym_LPAREN] = ACTIONS(5776),
    [anon_sym_RPAREN] = ACTIONS(5325),
    [anon_sym_RBRACE] = ACTIONS(5325),
    [anon_sym_LT] = ACTIONS(5327),
    [anon_sym_GT] = ACTIONS(5327),
    [anon_sym_in] = ACTIONS(5325),
    [anon_sym_QMARK] = ACTIONS(5327),
    [anon_sym_BANG] = ACTIONS(5832),
    [anon_sym_PLUS_PLUS] = ACTIONS(5834),
    [anon_sym_DASH_DASH] = ACTIONS(5834),
    [anon_sym_PLUS] = ACTIONS(5327),
    [anon_sym_DASH] = ACTIONS(5327),
    [anon_sym_STAR] = ACTIONS(5325),
    [anon_sym_SLASH] = ACTIONS(5327),
    [anon_sym_PERCENT] = ACTIONS(5325),
    [anon_sym_CARET] = ACTIONS(5325),
    [anon_sym_PIPE] = ACTIONS(5327),
    [anon_sym_AMP] = ACTIONS(5327),
    [anon_sym_LT_LT] = ACTIONS(5325),
    [anon_sym_GT_GT] = ACTIONS(5327),
    [anon_sym_GT_GT_GT] = ACTIONS(5325),
    [anon_sym_EQ_EQ] = ACTIONS(5325),
    [anon_sym_BANG_EQ] = ACTIONS(5325),
    [anon_sym_GT_EQ] = ACTIONS(5325),
    [anon_sym_LT_EQ] = ACTIONS(5325),
    [anon_sym_DOT] = ACTIONS(4602),
    [anon_sym_EQ_GT] = ACTIONS(5325),
    [anon_sym_switch] = ACTIONS(5325),
    [anon_sym_DOT_DOT] = ACTIONS(5325),
    [anon_sym_AMP_AMP] = ACTIONS(5325),
    [anon_sym_PIPE_PIPE] = ACTIONS(5325),
    [anon_sym_QMARK_QMARK] = ACTIONS(5325),
    [anon_sym_on] = ACTIONS(5325),
    [anon_sym_equals] = ACTIONS(5325),
    [anon_sym_by] = ACTIONS(5325),
    [anon_sym_as] = ACTIONS(5325),
    [anon_sym_is] = ACTIONS(5325),
    [anon_sym_DASH_GT] = ACTIONS(4604),
    [anon_sym_with] = ACTIONS(5325),
    [aux_sym_preproc_if_token3] = ACTIONS(5325),
    [aux_sym_preproc_else_token1] = ACTIONS(5325),
    [aux_sym_preproc_elif_token1] = ACTIONS(5325),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4339] = {
    [sym_preproc_region] = STATE(4339),
    [sym_preproc_endregion] = STATE(4339),
    [sym_preproc_line] = STATE(4339),
    [sym_preproc_pragma] = STATE(4339),
    [sym_preproc_nullable] = STATE(4339),
    [sym_preproc_error] = STATE(4339),
    [sym_preproc_warning] = STATE(4339),
    [sym_preproc_define] = STATE(4339),
    [sym_preproc_undef] = STATE(4339),
    [sym__identifier_token] = ACTIONS(6074),
    [anon_sym_extern] = ACTIONS(6074),
    [anon_sym_alias] = ACTIONS(6074),
    [anon_sym_global] = ACTIONS(6074),
    [anon_sym_unsafe] = ACTIONS(6074),
    [anon_sym_static] = ACTIONS(6074),
    [anon_sym_LBRACK] = ACTIONS(6076),
    [anon_sym_RBRACE] = ACTIONS(6076),
    [anon_sym_abstract] = ACTIONS(6074),
    [anon_sym_async] = ACTIONS(6074),
    [anon_sym_const] = ACTIONS(6074),
    [anon_sym_file] = ACTIONS(6074),
    [anon_sym_fixed] = ACTIONS(6074),
    [anon_sym_internal] = ACTIONS(6074),
    [anon_sym_new] = ACTIONS(6074),
    [anon_sym_override] = ACTIONS(6074),
    [anon_sym_partial] = ACTIONS(6074),
    [anon_sym_private] = ACTIONS(6074),
    [anon_sym_protected] = ACTIONS(6074),
    [anon_sym_public] = ACTIONS(6074),
    [anon_sym_readonly] = ACTIONS(6074),
    [anon_sym_required] = ACTIONS(6074),
    [anon_sym_sealed] = ACTIONS(6074),
    [anon_sym_virtual] = ACTIONS(6074),
    [anon_sym_volatile] = ACTIONS(6074),
    [anon_sym_where] = ACTIONS(6074),
    [anon_sym_notnull] = ACTIONS(6074),
    [anon_sym_unmanaged] = ACTIONS(6074),
    [anon_sym_get] = ACTIONS(6074),
    [anon_sym_set] = ACTIONS(6074),
    [anon_sym_add] = ACTIONS(6074),
    [anon_sym_remove] = ACTIONS(6074),
    [anon_sym_init] = ACTIONS(6074),
    [anon_sym_scoped] = ACTIONS(6074),
    [anon_sym_var] = ACTIONS(6074),
    [anon_sym_yield] = ACTIONS(6074),
    [anon_sym_when] = ACTIONS(6074),
    [anon_sym_from] = ACTIONS(6074),
    [anon_sym_into] = ACTIONS(6074),
    [anon_sym_join] = ACTIONS(6074),
    [anon_sym_on] = ACTIONS(6074),
    [anon_sym_equals] = ACTIONS(6074),
    [anon_sym_let] = ACTIONS(6074),
    [anon_sym_orderby] = ACTIONS(6074),
    [anon_sym_ascending] = ACTIONS(6074),
    [anon_sym_descending] = ACTIONS(6074),
    [anon_sym_group] = ACTIONS(6074),
    [anon_sym_by] = ACTIONS(6074),
    [anon_sym_select] = ACTIONS(6074),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4340] = {
    [sym_preproc_region] = STATE(4340),
    [sym_preproc_endregion] = STATE(4340),
    [sym_preproc_line] = STATE(4340),
    [sym_preproc_pragma] = STATE(4340),
    [sym_preproc_nullable] = STATE(4340),
    [sym_preproc_error] = STATE(4340),
    [sym_preproc_warning] = STATE(4340),
    [sym_preproc_define] = STATE(4340),
    [sym_preproc_undef] = STATE(4340),
    [anon_sym_EQ] = ACTIONS(6047),
    [anon_sym_LBRACK] = ACTIONS(5286),
    [anon_sym_COLON] = ACTIONS(5286),
    [anon_sym_COMMA] = ACTIONS(5286),
    [anon_sym_LPAREN] = ACTIONS(5286),
    [anon_sym_RPAREN] = ACTIONS(6078),
    [anon_sym_LT] = ACTIONS(5288),
    [anon_sym_GT] = ACTIONS(5288),
    [anon_sym_QMARK] = ACTIONS(5288),
    [anon_sym_BANG] = ACTIONS(5288),
    [anon_sym_PLUS_PLUS] = ACTIONS(5286),
    [anon_sym_DASH_DASH] = ACTIONS(5286),
    [anon_sym_PLUS] = ACTIONS(5288),
    [anon_sym_DASH] = ACTIONS(5288),
    [anon_sym_STAR] = ACTIONS(5288),
    [anon_sym_SLASH] = ACTIONS(5288),
    [anon_sym_PERCENT] = ACTIONS(5288),
    [anon_sym_CARET] = ACTIONS(5288),
    [anon_sym_PIPE] = ACTIONS(5288),
    [anon_sym_AMP] = ACTIONS(5288),
    [anon_sym_LT_LT] = ACTIONS(5288),
    [anon_sym_GT_GT] = ACTIONS(5288),
    [anon_sym_GT_GT_GT] = ACTIONS(5288),
    [anon_sym_EQ_EQ] = ACTIONS(5286),
    [anon_sym_BANG_EQ] = ACTIONS(5286),
    [anon_sym_GT_EQ] = ACTIONS(5286),
    [anon_sym_LT_EQ] = ACTIONS(5286),
    [anon_sym_DOT] = ACTIONS(5288),
    [anon_sym_switch] = ACTIONS(5286),
    [anon_sym_DOT_DOT] = ACTIONS(5286),
    [anon_sym_PLUS_EQ] = ACTIONS(6049),
    [anon_sym_DASH_EQ] = ACTIONS(6049),
    [anon_sym_STAR_EQ] = ACTIONS(6049),
    [anon_sym_SLASH_EQ] = ACTIONS(6049),
    [anon_sym_PERCENT_EQ] = ACTIONS(6049),
    [anon_sym_AMP_EQ] = ACTIONS(6049),
    [anon_sym_CARET_EQ] = ACTIONS(6049),
    [anon_sym_PIPE_EQ] = ACTIONS(6049),
    [anon_sym_LT_LT_EQ] = ACTIONS(6049),
    [anon_sym_GT_GT_EQ] = ACTIONS(6049),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(6049),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(6049),
    [anon_sym_AMP_AMP] = ACTIONS(5286),
    [anon_sym_PIPE_PIPE] = ACTIONS(5286),
    [anon_sym_QMARK_QMARK] = ACTIONS(5288),
    [anon_sym_as] = ACTIONS(5286),
    [anon_sym_is] = ACTIONS(5286),
    [anon_sym_DASH_GT] = ACTIONS(5286),
    [anon_sym_with] = ACTIONS(5286),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4341] = {
    [sym_attribute_list] = STATE(4528),
    [sym_preproc_region] = STATE(4341),
    [sym_preproc_endregion] = STATE(4341),
    [sym_preproc_line] = STATE(4341),
    [sym_preproc_pragma] = STATE(4341),
    [sym_preproc_nullable] = STATE(4341),
    [sym_preproc_error] = STATE(4341),
    [sym_preproc_warning] = STATE(4341),
    [sym_preproc_define] = STATE(4341),
    [sym_preproc_undef] = STATE(4341),
    [aux_sym_class_declaration_repeat1] = STATE(4341),
    [sym__identifier_token] = ACTIONS(5394),
    [anon_sym_extern] = ACTIONS(5394),
    [anon_sym_alias] = ACTIONS(5394),
    [anon_sym_global] = ACTIONS(5394),
    [anon_sym_unsafe] = ACTIONS(5394),
    [anon_sym_static] = ACTIONS(5394),
    [anon_sym_LBRACK] = ACTIONS(6080),
    [anon_sym_LPAREN] = ACTIONS(5399),
    [anon_sym_ref] = ACTIONS(5394),
    [anon_sym_delegate] = ACTIONS(5394),
    [anon_sym_abstract] = ACTIONS(5394),
    [anon_sym_async] = ACTIONS(5394),
    [anon_sym_const] = ACTIONS(5394),
    [anon_sym_file] = ACTIONS(5394),
    [anon_sym_fixed] = ACTIONS(5394),
    [anon_sym_internal] = ACTIONS(5394),
    [anon_sym_new] = ACTIONS(5394),
    [anon_sym_override] = ACTIONS(5394),
    [anon_sym_partial] = ACTIONS(5394),
    [anon_sym_private] = ACTIONS(5394),
    [anon_sym_protected] = ACTIONS(5394),
    [anon_sym_public] = ACTIONS(5394),
    [anon_sym_readonly] = ACTIONS(5394),
    [anon_sym_required] = ACTIONS(5394),
    [anon_sym_sealed] = ACTIONS(5394),
    [anon_sym_virtual] = ACTIONS(5394),
    [anon_sym_volatile] = ACTIONS(5394),
    [anon_sym_where] = ACTIONS(5394),
    [anon_sym_notnull] = ACTIONS(5394),
    [anon_sym_unmanaged] = ACTIONS(5394),
    [anon_sym_scoped] = ACTIONS(5394),
    [anon_sym_var] = ACTIONS(5394),
    [sym_predefined_type] = ACTIONS(5394),
    [anon_sym_yield] = ACTIONS(5394),
    [anon_sym_when] = ACTIONS(5394),
    [anon_sym_from] = ACTIONS(5394),
    [anon_sym_into] = ACTIONS(5394),
    [anon_sym_join] = ACTIONS(5394),
    [anon_sym_on] = ACTIONS(5394),
    [anon_sym_equals] = ACTIONS(5394),
    [anon_sym_let] = ACTIONS(5394),
    [anon_sym_orderby] = ACTIONS(5394),
    [anon_sym_ascending] = ACTIONS(5394),
    [anon_sym_descending] = ACTIONS(5394),
    [anon_sym_group] = ACTIONS(5394),
    [anon_sym_by] = ACTIONS(5394),
    [anon_sym_select] = ACTIONS(5394),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4342] = {
    [sym_preproc_region] = STATE(4342),
    [sym_preproc_endregion] = STATE(4342),
    [sym_preproc_line] = STATE(4342),
    [sym_preproc_pragma] = STATE(4342),
    [sym_preproc_nullable] = STATE(4342),
    [sym_preproc_error] = STATE(4342),
    [sym_preproc_warning] = STATE(4342),
    [sym_preproc_define] = STATE(4342),
    [sym_preproc_undef] = STATE(4342),
    [anon_sym_EQ] = ACTIONS(6083),
    [anon_sym_LBRACK] = ACTIONS(5286),
    [anon_sym_LPAREN] = ACTIONS(5286),
    [anon_sym_LT] = ACTIONS(5288),
    [anon_sym_GT] = ACTIONS(5288),
    [anon_sym_QMARK] = ACTIONS(5288),
    [anon_sym_BANG] = ACTIONS(5288),
    [anon_sym_PLUS_PLUS] = ACTIONS(5286),
    [anon_sym_DASH_DASH] = ACTIONS(5286),
    [anon_sym_PLUS] = ACTIONS(5288),
    [anon_sym_DASH] = ACTIONS(5288),
    [anon_sym_STAR] = ACTIONS(5288),
    [anon_sym_SLASH] = ACTIONS(5288),
    [anon_sym_PERCENT] = ACTIONS(5288),
    [anon_sym_CARET] = ACTIONS(5288),
    [anon_sym_PIPE] = ACTIONS(5288),
    [anon_sym_AMP] = ACTIONS(5288),
    [anon_sym_LT_LT] = ACTIONS(5288),
    [anon_sym_GT_GT] = ACTIONS(5288),
    [anon_sym_GT_GT_GT] = ACTIONS(5288),
    [anon_sym_EQ_EQ] = ACTIONS(5286),
    [anon_sym_BANG_EQ] = ACTIONS(5286),
    [anon_sym_GT_EQ] = ACTIONS(5286),
    [anon_sym_LT_EQ] = ACTIONS(5286),
    [anon_sym_DOT] = ACTIONS(5288),
    [anon_sym_switch] = ACTIONS(5286),
    [anon_sym_DOT_DOT] = ACTIONS(5286),
    [anon_sym_and] = ACTIONS(5286),
    [anon_sym_or] = ACTIONS(5286),
    [anon_sym_PLUS_EQ] = ACTIONS(6085),
    [anon_sym_DASH_EQ] = ACTIONS(6085),
    [anon_sym_STAR_EQ] = ACTIONS(6085),
    [anon_sym_SLASH_EQ] = ACTIONS(6085),
    [anon_sym_PERCENT_EQ] = ACTIONS(6085),
    [anon_sym_AMP_EQ] = ACTIONS(6085),
    [anon_sym_CARET_EQ] = ACTIONS(6085),
    [anon_sym_PIPE_EQ] = ACTIONS(6085),
    [anon_sym_LT_LT_EQ] = ACTIONS(6085),
    [anon_sym_GT_GT_EQ] = ACTIONS(6085),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(6085),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(6085),
    [anon_sym_AMP_AMP] = ACTIONS(5286),
    [anon_sym_PIPE_PIPE] = ACTIONS(5286),
    [anon_sym_QMARK_QMARK] = ACTIONS(5288),
    [anon_sym_equals] = ACTIONS(5286),
    [anon_sym_as] = ACTIONS(5286),
    [anon_sym_is] = ACTIONS(5286),
    [anon_sym_DASH_GT] = ACTIONS(5286),
    [anon_sym_with] = ACTIONS(5286),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4343] = {
    [sym_preproc_region] = STATE(4343),
    [sym_preproc_endregion] = STATE(4343),
    [sym_preproc_line] = STATE(4343),
    [sym_preproc_pragma] = STATE(4343),
    [sym_preproc_nullable] = STATE(4343),
    [sym_preproc_error] = STATE(4343),
    [sym_preproc_warning] = STATE(4343),
    [sym_preproc_define] = STATE(4343),
    [sym_preproc_undef] = STATE(4343),
    [anon_sym_SEMI] = ACTIONS(4494),
    [anon_sym_LBRACK] = ACTIONS(4593),
    [anon_sym_COLON] = ACTIONS(4494),
    [anon_sym_COMMA] = ACTIONS(4494),
    [anon_sym_RBRACK] = ACTIONS(4494),
    [anon_sym_LPAREN] = ACTIONS(4494),
    [anon_sym_RPAREN] = ACTIONS(4494),
    [anon_sym_LBRACE] = ACTIONS(4494),
    [anon_sym_RBRACE] = ACTIONS(4494),
    [anon_sym_LT] = ACTIONS(4492),
    [anon_sym_GT] = ACTIONS(4492),
    [anon_sym_in] = ACTIONS(4492),
    [anon_sym_QMARK] = ACTIONS(5375),
    [anon_sym_BANG] = ACTIONS(4492),
    [anon_sym_PLUS_PLUS] = ACTIONS(4494),
    [anon_sym_DASH_DASH] = ACTIONS(4494),
    [anon_sym_PLUS] = ACTIONS(4492),
    [anon_sym_DASH] = ACTIONS(4492),
    [anon_sym_STAR] = ACTIONS(4599),
    [anon_sym_SLASH] = ACTIONS(4492),
    [anon_sym_PERCENT] = ACTIONS(4494),
    [anon_sym_CARET] = ACTIONS(4494),
    [anon_sym_PIPE] = ACTIONS(4492),
    [anon_sym_AMP] = ACTIONS(4492),
    [anon_sym_LT_LT] = ACTIONS(4494),
    [anon_sym_GT_GT] = ACTIONS(4492),
    [anon_sym_GT_GT_GT] = ACTIONS(4494),
    [anon_sym_EQ_EQ] = ACTIONS(4494),
    [anon_sym_BANG_EQ] = ACTIONS(4494),
    [anon_sym_GT_EQ] = ACTIONS(4494),
    [anon_sym_LT_EQ] = ACTIONS(4494),
    [anon_sym_DOT] = ACTIONS(6087),
    [anon_sym_EQ_GT] = ACTIONS(4494),
    [anon_sym_switch] = ACTIONS(4494),
    [anon_sym_DOT_DOT] = ACTIONS(4494),
    [anon_sym_AMP_AMP] = ACTIONS(4494),
    [anon_sym_PIPE_PIPE] = ACTIONS(4494),
    [anon_sym_QMARK_QMARK] = ACTIONS(4494),
    [anon_sym_into] = ACTIONS(4494),
    [anon_sym_on] = ACTIONS(4494),
    [anon_sym_equals] = ACTIONS(4494),
    [anon_sym_by] = ACTIONS(4494),
    [anon_sym_as] = ACTIONS(4494),
    [anon_sym_is] = ACTIONS(4494),
    [anon_sym_DASH_GT] = ACTIONS(4494),
    [anon_sym_with] = ACTIONS(4494),
    [aux_sym_preproc_if_token3] = ACTIONS(4494),
    [aux_sym_preproc_else_token1] = ACTIONS(4494),
    [aux_sym_preproc_elif_token1] = ACTIONS(4494),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4344] = {
    [sym_preproc_region] = STATE(4344),
    [sym_preproc_endregion] = STATE(4344),
    [sym_preproc_line] = STATE(4344),
    [sym_preproc_pragma] = STATE(4344),
    [sym_preproc_nullable] = STATE(4344),
    [sym_preproc_error] = STATE(4344),
    [sym_preproc_warning] = STATE(4344),
    [sym_preproc_define] = STATE(4344),
    [sym_preproc_undef] = STATE(4344),
    [anon_sym_EQ] = ACTIONS(6089),
    [anon_sym_LBRACK] = ACTIONS(5286),
    [anon_sym_LPAREN] = ACTIONS(5286),
    [anon_sym_LT] = ACTIONS(5288),
    [anon_sym_GT] = ACTIONS(5288),
    [anon_sym_QMARK] = ACTIONS(5288),
    [anon_sym_BANG] = ACTIONS(5288),
    [anon_sym_PLUS_PLUS] = ACTIONS(5286),
    [anon_sym_DASH_DASH] = ACTIONS(5286),
    [anon_sym_PLUS] = ACTIONS(5288),
    [anon_sym_DASH] = ACTIONS(5288),
    [anon_sym_STAR] = ACTIONS(5288),
    [anon_sym_SLASH] = ACTIONS(5288),
    [anon_sym_PERCENT] = ACTIONS(5288),
    [anon_sym_CARET] = ACTIONS(5288),
    [anon_sym_PIPE] = ACTIONS(5288),
    [anon_sym_AMP] = ACTIONS(5288),
    [anon_sym_LT_LT] = ACTIONS(5288),
    [anon_sym_GT_GT] = ACTIONS(5288),
    [anon_sym_GT_GT_GT] = ACTIONS(5288),
    [anon_sym_EQ_EQ] = ACTIONS(5286),
    [anon_sym_BANG_EQ] = ACTIONS(5286),
    [anon_sym_GT_EQ] = ACTIONS(5286),
    [anon_sym_LT_EQ] = ACTIONS(5286),
    [anon_sym_DOT] = ACTIONS(5288),
    [anon_sym_switch] = ACTIONS(5286),
    [anon_sym_DOT_DOT] = ACTIONS(5286),
    [anon_sym_and] = ACTIONS(5286),
    [anon_sym_or] = ACTIONS(5286),
    [anon_sym_PLUS_EQ] = ACTIONS(6091),
    [anon_sym_DASH_EQ] = ACTIONS(6091),
    [anon_sym_STAR_EQ] = ACTIONS(6091),
    [anon_sym_SLASH_EQ] = ACTIONS(6091),
    [anon_sym_PERCENT_EQ] = ACTIONS(6091),
    [anon_sym_AMP_EQ] = ACTIONS(6091),
    [anon_sym_CARET_EQ] = ACTIONS(6091),
    [anon_sym_PIPE_EQ] = ACTIONS(6091),
    [anon_sym_LT_LT_EQ] = ACTIONS(6091),
    [anon_sym_GT_GT_EQ] = ACTIONS(6091),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(6091),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(6091),
    [anon_sym_AMP_AMP] = ACTIONS(5286),
    [anon_sym_PIPE_PIPE] = ACTIONS(5286),
    [anon_sym_QMARK_QMARK] = ACTIONS(5288),
    [anon_sym_on] = ACTIONS(5286),
    [anon_sym_as] = ACTIONS(5286),
    [anon_sym_is] = ACTIONS(5286),
    [anon_sym_DASH_GT] = ACTIONS(5286),
    [anon_sym_with] = ACTIONS(5286),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4345] = {
    [sym_preproc_region] = STATE(4345),
    [sym_preproc_endregion] = STATE(4345),
    [sym_preproc_line] = STATE(4345),
    [sym_preproc_pragma] = STATE(4345),
    [sym_preproc_nullable] = STATE(4345),
    [sym_preproc_error] = STATE(4345),
    [sym_preproc_warning] = STATE(4345),
    [sym_preproc_define] = STATE(4345),
    [sym_preproc_undef] = STATE(4345),
    [anon_sym_EQ] = ACTIONS(6093),
    [anon_sym_LBRACK] = ACTIONS(5286),
    [anon_sym_LPAREN] = ACTIONS(5286),
    [anon_sym_LT] = ACTIONS(5288),
    [anon_sym_GT] = ACTIONS(5288),
    [anon_sym_QMARK] = ACTIONS(5288),
    [anon_sym_BANG] = ACTIONS(5288),
    [anon_sym_PLUS_PLUS] = ACTIONS(5286),
    [anon_sym_DASH_DASH] = ACTIONS(5286),
    [anon_sym_PLUS] = ACTIONS(5288),
    [anon_sym_DASH] = ACTIONS(5288),
    [anon_sym_STAR] = ACTIONS(5288),
    [anon_sym_SLASH] = ACTIONS(5288),
    [anon_sym_PERCENT] = ACTIONS(5288),
    [anon_sym_CARET] = ACTIONS(5288),
    [anon_sym_PIPE] = ACTIONS(5288),
    [anon_sym_AMP] = ACTIONS(5288),
    [anon_sym_LT_LT] = ACTIONS(5288),
    [anon_sym_GT_GT] = ACTIONS(5288),
    [anon_sym_GT_GT_GT] = ACTIONS(5288),
    [anon_sym_EQ_EQ] = ACTIONS(5286),
    [anon_sym_BANG_EQ] = ACTIONS(5286),
    [anon_sym_GT_EQ] = ACTIONS(5286),
    [anon_sym_LT_EQ] = ACTIONS(5286),
    [anon_sym_DOT] = ACTIONS(5288),
    [anon_sym_EQ_GT] = ACTIONS(5286),
    [anon_sym_switch] = ACTIONS(5286),
    [anon_sym_DOT_DOT] = ACTIONS(5286),
    [anon_sym_and] = ACTIONS(5286),
    [anon_sym_or] = ACTIONS(5286),
    [anon_sym_PLUS_EQ] = ACTIONS(6095),
    [anon_sym_DASH_EQ] = ACTIONS(6095),
    [anon_sym_STAR_EQ] = ACTIONS(6095),
    [anon_sym_SLASH_EQ] = ACTIONS(6095),
    [anon_sym_PERCENT_EQ] = ACTIONS(6095),
    [anon_sym_AMP_EQ] = ACTIONS(6095),
    [anon_sym_CARET_EQ] = ACTIONS(6095),
    [anon_sym_PIPE_EQ] = ACTIONS(6095),
    [anon_sym_LT_LT_EQ] = ACTIONS(6095),
    [anon_sym_GT_GT_EQ] = ACTIONS(6095),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(6095),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(6095),
    [anon_sym_AMP_AMP] = ACTIONS(5286),
    [anon_sym_PIPE_PIPE] = ACTIONS(5286),
    [anon_sym_QMARK_QMARK] = ACTIONS(5288),
    [anon_sym_as] = ACTIONS(5286),
    [anon_sym_is] = ACTIONS(5286),
    [anon_sym_DASH_GT] = ACTIONS(5286),
    [anon_sym_with] = ACTIONS(5286),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4346] = {
    [sym_preproc_region] = STATE(4346),
    [sym_preproc_endregion] = STATE(4346),
    [sym_preproc_line] = STATE(4346),
    [sym_preproc_pragma] = STATE(4346),
    [sym_preproc_nullable] = STATE(4346),
    [sym_preproc_error] = STATE(4346),
    [sym_preproc_warning] = STATE(4346),
    [sym_preproc_define] = STATE(4346),
    [sym_preproc_undef] = STATE(4346),
    [anon_sym_EQ] = ACTIONS(6097),
    [anon_sym_LBRACK] = ACTIONS(5286),
    [anon_sym_COLON] = ACTIONS(5286),
    [anon_sym_COMMA] = ACTIONS(5286),
    [anon_sym_LPAREN] = ACTIONS(5286),
    [anon_sym_LT] = ACTIONS(5288),
    [anon_sym_GT] = ACTIONS(5288),
    [anon_sym_QMARK] = ACTIONS(5288),
    [anon_sym_BANG] = ACTIONS(5288),
    [anon_sym_PLUS_PLUS] = ACTIONS(5286),
    [anon_sym_DASH_DASH] = ACTIONS(5286),
    [anon_sym_PLUS] = ACTIONS(5288),
    [anon_sym_DASH] = ACTIONS(5288),
    [anon_sym_STAR] = ACTIONS(5288),
    [anon_sym_SLASH] = ACTIONS(5288),
    [anon_sym_PERCENT] = ACTIONS(5288),
    [anon_sym_CARET] = ACTIONS(5288),
    [anon_sym_PIPE] = ACTIONS(5288),
    [anon_sym_AMP] = ACTIONS(5288),
    [anon_sym_LT_LT] = ACTIONS(5288),
    [anon_sym_GT_GT] = ACTIONS(5288),
    [anon_sym_GT_GT_GT] = ACTIONS(5288),
    [anon_sym_EQ_EQ] = ACTIONS(5286),
    [anon_sym_BANG_EQ] = ACTIONS(5286),
    [anon_sym_GT_EQ] = ACTIONS(5286),
    [anon_sym_LT_EQ] = ACTIONS(5286),
    [anon_sym_DOT] = ACTIONS(5288),
    [anon_sym_switch] = ACTIONS(5286),
    [anon_sym_DOT_DOT] = ACTIONS(5286),
    [anon_sym_PLUS_EQ] = ACTIONS(6099),
    [anon_sym_DASH_EQ] = ACTIONS(6099),
    [anon_sym_STAR_EQ] = ACTIONS(6099),
    [anon_sym_SLASH_EQ] = ACTIONS(6099),
    [anon_sym_PERCENT_EQ] = ACTIONS(6099),
    [anon_sym_AMP_EQ] = ACTIONS(6099),
    [anon_sym_CARET_EQ] = ACTIONS(6099),
    [anon_sym_PIPE_EQ] = ACTIONS(6099),
    [anon_sym_LT_LT_EQ] = ACTIONS(6099),
    [anon_sym_GT_GT_EQ] = ACTIONS(6099),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(6099),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(6099),
    [anon_sym_AMP_AMP] = ACTIONS(5286),
    [anon_sym_PIPE_PIPE] = ACTIONS(5286),
    [anon_sym_QMARK_QMARK] = ACTIONS(5288),
    [anon_sym_as] = ACTIONS(5286),
    [anon_sym_is] = ACTIONS(5286),
    [anon_sym_DASH_GT] = ACTIONS(5286),
    [anon_sym_with] = ACTIONS(5286),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
    [sym_interpolation_close_brace] = ACTIONS(5286),
  },
  [4347] = {
    [sym_preproc_region] = STATE(4347),
    [sym_preproc_endregion] = STATE(4347),
    [sym_preproc_line] = STATE(4347),
    [sym_preproc_pragma] = STATE(4347),
    [sym_preproc_nullable] = STATE(4347),
    [sym_preproc_error] = STATE(4347),
    [sym_preproc_warning] = STATE(4347),
    [sym_preproc_define] = STATE(4347),
    [sym_preproc_undef] = STATE(4347),
    [sym__identifier_token] = ACTIONS(6101),
    [anon_sym_extern] = ACTIONS(6101),
    [anon_sym_alias] = ACTIONS(6101),
    [anon_sym_global] = ACTIONS(6101),
    [anon_sym_unsafe] = ACTIONS(6101),
    [anon_sym_static] = ACTIONS(6101),
    [anon_sym_LBRACK] = ACTIONS(6103),
    [anon_sym_RBRACE] = ACTIONS(6103),
    [anon_sym_abstract] = ACTIONS(6101),
    [anon_sym_async] = ACTIONS(6101),
    [anon_sym_const] = ACTIONS(6101),
    [anon_sym_file] = ACTIONS(6101),
    [anon_sym_fixed] = ACTIONS(6101),
    [anon_sym_internal] = ACTIONS(6101),
    [anon_sym_new] = ACTIONS(6101),
    [anon_sym_override] = ACTIONS(6101),
    [anon_sym_partial] = ACTIONS(6101),
    [anon_sym_private] = ACTIONS(6101),
    [anon_sym_protected] = ACTIONS(6101),
    [anon_sym_public] = ACTIONS(6101),
    [anon_sym_readonly] = ACTIONS(6101),
    [anon_sym_required] = ACTIONS(6101),
    [anon_sym_sealed] = ACTIONS(6101),
    [anon_sym_virtual] = ACTIONS(6101),
    [anon_sym_volatile] = ACTIONS(6101),
    [anon_sym_where] = ACTIONS(6101),
    [anon_sym_notnull] = ACTIONS(6101),
    [anon_sym_unmanaged] = ACTIONS(6101),
    [anon_sym_get] = ACTIONS(6101),
    [anon_sym_set] = ACTIONS(6101),
    [anon_sym_add] = ACTIONS(6101),
    [anon_sym_remove] = ACTIONS(6101),
    [anon_sym_init] = ACTIONS(6101),
    [anon_sym_scoped] = ACTIONS(6101),
    [anon_sym_var] = ACTIONS(6101),
    [anon_sym_yield] = ACTIONS(6101),
    [anon_sym_when] = ACTIONS(6101),
    [anon_sym_from] = ACTIONS(6101),
    [anon_sym_into] = ACTIONS(6101),
    [anon_sym_join] = ACTIONS(6101),
    [anon_sym_on] = ACTIONS(6101),
    [anon_sym_equals] = ACTIONS(6101),
    [anon_sym_let] = ACTIONS(6101),
    [anon_sym_orderby] = ACTIONS(6101),
    [anon_sym_ascending] = ACTIONS(6101),
    [anon_sym_descending] = ACTIONS(6101),
    [anon_sym_group] = ACTIONS(6101),
    [anon_sym_by] = ACTIONS(6101),
    [anon_sym_select] = ACTIONS(6101),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4348] = {
    [sym_preproc_region] = STATE(4348),
    [sym_preproc_endregion] = STATE(4348),
    [sym_preproc_line] = STATE(4348),
    [sym_preproc_pragma] = STATE(4348),
    [sym_preproc_nullable] = STATE(4348),
    [sym_preproc_error] = STATE(4348),
    [sym_preproc_warning] = STATE(4348),
    [sym_preproc_define] = STATE(4348),
    [sym_preproc_undef] = STATE(4348),
    [anon_sym_SEMI] = ACTIONS(4455),
    [anon_sym_LBRACK] = ACTIONS(4455),
    [anon_sym_COLON] = ACTIONS(4455),
    [anon_sym_COMMA] = ACTIONS(4455),
    [anon_sym_RBRACK] = ACTIONS(4455),
    [anon_sym_LPAREN] = ACTIONS(4455),
    [anon_sym_RPAREN] = ACTIONS(4455),
    [anon_sym_LBRACE] = ACTIONS(4455),
    [anon_sym_RBRACE] = ACTIONS(4455),
    [anon_sym_LT] = ACTIONS(4453),
    [anon_sym_GT] = ACTIONS(4453),
    [anon_sym_in] = ACTIONS(4453),
    [anon_sym_QMARK] = ACTIONS(4453),
    [anon_sym_BANG] = ACTIONS(4453),
    [anon_sym_PLUS_PLUS] = ACTIONS(4455),
    [anon_sym_DASH_DASH] = ACTIONS(4455),
    [anon_sym_PLUS] = ACTIONS(4453),
    [anon_sym_DASH] = ACTIONS(4453),
    [anon_sym_STAR] = ACTIONS(4455),
    [anon_sym_SLASH] = ACTIONS(4453),
    [anon_sym_PERCENT] = ACTIONS(4455),
    [anon_sym_CARET] = ACTIONS(4455),
    [anon_sym_PIPE] = ACTIONS(4453),
    [anon_sym_AMP] = ACTIONS(4453),
    [anon_sym_LT_LT] = ACTIONS(4455),
    [anon_sym_GT_GT] = ACTIONS(4453),
    [anon_sym_GT_GT_GT] = ACTIONS(4455),
    [anon_sym_EQ_EQ] = ACTIONS(4455),
    [anon_sym_BANG_EQ] = ACTIONS(4455),
    [anon_sym_GT_EQ] = ACTIONS(4455),
    [anon_sym_LT_EQ] = ACTIONS(4455),
    [anon_sym_DOT] = ACTIONS(6087),
    [anon_sym_EQ_GT] = ACTIONS(4455),
    [anon_sym_switch] = ACTIONS(4455),
    [anon_sym_DOT_DOT] = ACTIONS(4455),
    [anon_sym_AMP_AMP] = ACTIONS(4455),
    [anon_sym_PIPE_PIPE] = ACTIONS(4455),
    [anon_sym_QMARK_QMARK] = ACTIONS(4455),
    [anon_sym_into] = ACTIONS(4455),
    [anon_sym_on] = ACTIONS(4455),
    [anon_sym_equals] = ACTIONS(4455),
    [anon_sym_by] = ACTIONS(4455),
    [anon_sym_as] = ACTIONS(4455),
    [anon_sym_is] = ACTIONS(4455),
    [anon_sym_DASH_GT] = ACTIONS(4455),
    [anon_sym_with] = ACTIONS(4455),
    [aux_sym_preproc_if_token3] = ACTIONS(4455),
    [aux_sym_preproc_else_token1] = ACTIONS(4455),
    [aux_sym_preproc_elif_token1] = ACTIONS(4455),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4349] = {
    [sym_preproc_region] = STATE(4349),
    [sym_preproc_endregion] = STATE(4349),
    [sym_preproc_line] = STATE(4349),
    [sym_preproc_pragma] = STATE(4349),
    [sym_preproc_nullable] = STATE(4349),
    [sym_preproc_error] = STATE(4349),
    [sym_preproc_warning] = STATE(4349),
    [sym_preproc_define] = STATE(4349),
    [sym_preproc_undef] = STATE(4349),
    [sym__identifier_token] = ACTIONS(3397),
    [anon_sym_extern] = ACTIONS(3397),
    [anon_sym_alias] = ACTIONS(3397),
    [anon_sym_global] = ACTIONS(3397),
    [anon_sym_unsafe] = ACTIONS(3397),
    [anon_sym_static] = ACTIONS(3397),
    [anon_sym_LBRACK] = ACTIONS(3399),
    [anon_sym_RBRACE] = ACTIONS(3399),
    [anon_sym_abstract] = ACTIONS(3397),
    [anon_sym_async] = ACTIONS(3397),
    [anon_sym_const] = ACTIONS(3397),
    [anon_sym_file] = ACTIONS(3397),
    [anon_sym_fixed] = ACTIONS(3397),
    [anon_sym_internal] = ACTIONS(3397),
    [anon_sym_new] = ACTIONS(3397),
    [anon_sym_override] = ACTIONS(3397),
    [anon_sym_partial] = ACTIONS(3397),
    [anon_sym_private] = ACTIONS(3397),
    [anon_sym_protected] = ACTIONS(3397),
    [anon_sym_public] = ACTIONS(3397),
    [anon_sym_readonly] = ACTIONS(3397),
    [anon_sym_required] = ACTIONS(3397),
    [anon_sym_sealed] = ACTIONS(3397),
    [anon_sym_virtual] = ACTIONS(3397),
    [anon_sym_volatile] = ACTIONS(3397),
    [anon_sym_where] = ACTIONS(3397),
    [anon_sym_notnull] = ACTIONS(3397),
    [anon_sym_unmanaged] = ACTIONS(3397),
    [anon_sym_get] = ACTIONS(3397),
    [anon_sym_set] = ACTIONS(3397),
    [anon_sym_add] = ACTIONS(3397),
    [anon_sym_remove] = ACTIONS(3397),
    [anon_sym_init] = ACTIONS(3397),
    [anon_sym_scoped] = ACTIONS(3397),
    [anon_sym_var] = ACTIONS(3397),
    [anon_sym_yield] = ACTIONS(3397),
    [anon_sym_when] = ACTIONS(3397),
    [anon_sym_from] = ACTIONS(3397),
    [anon_sym_into] = ACTIONS(3397),
    [anon_sym_join] = ACTIONS(3397),
    [anon_sym_on] = ACTIONS(3397),
    [anon_sym_equals] = ACTIONS(3397),
    [anon_sym_let] = ACTIONS(3397),
    [anon_sym_orderby] = ACTIONS(3397),
    [anon_sym_ascending] = ACTIONS(3397),
    [anon_sym_descending] = ACTIONS(3397),
    [anon_sym_group] = ACTIONS(3397),
    [anon_sym_by] = ACTIONS(3397),
    [anon_sym_select] = ACTIONS(3397),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4350] = {
    [sym__name] = STATE(6202),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_ref_type] = STATE(2883),
    [sym__scoped_base_type] = STATE(2885),
    [sym_identifier] = STATE(5346),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_region] = STATE(4350),
    [sym_preproc_endregion] = STATE(4350),
    [sym_preproc_line] = STATE(4350),
    [sym_preproc_pragma] = STATE(4350),
    [sym_preproc_nullable] = STATE(4350),
    [sym_preproc_error] = STATE(4350),
    [sym_preproc_warning] = STATE(4350),
    [sym_preproc_define] = STATE(4350),
    [sym_preproc_undef] = STATE(4350),
    [sym__identifier_token] = ACTIONS(4072),
    [anon_sym_alias] = ACTIONS(4075),
    [anon_sym_global] = ACTIONS(4075),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_COMMA] = ACTIONS(3993),
    [anon_sym_RBRACK] = ACTIONS(3993),
    [anon_sym_LPAREN] = ACTIONS(3993),
    [anon_sym_RPAREN] = ACTIONS(3993),
    [anon_sym_ref] = ACTIONS(4078),
    [anon_sym_LBRACE] = ACTIONS(3993),
    [anon_sym_RBRACE] = ACTIONS(3993),
    [anon_sym_file] = ACTIONS(4075),
    [anon_sym_LT] = ACTIONS(3993),
    [anon_sym_where] = ACTIONS(4075),
    [anon_sym_QMARK] = ACTIONS(3993),
    [anon_sym_notnull] = ACTIONS(4075),
    [anon_sym_unmanaged] = ACTIONS(4075),
    [anon_sym_STAR] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3993),
    [anon_sym_scoped] = ACTIONS(4075),
    [anon_sym_EQ_GT] = ACTIONS(3993),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(4075),
    [anon_sym_yield] = ACTIONS(4075),
    [anon_sym_when] = ACTIONS(4075),
    [sym_discard] = ACTIONS(3995),
    [anon_sym_and] = ACTIONS(3995),
    [anon_sym_or] = ACTIONS(3995),
    [anon_sym_from] = ACTIONS(4075),
    [anon_sym_into] = ACTIONS(4075),
    [anon_sym_join] = ACTIONS(4075),
    [anon_sym_on] = ACTIONS(4075),
    [anon_sym_equals] = ACTIONS(4075),
    [anon_sym_let] = ACTIONS(4075),
    [anon_sym_orderby] = ACTIONS(4075),
    [anon_sym_ascending] = ACTIONS(4075),
    [anon_sym_descending] = ACTIONS(4075),
    [anon_sym_group] = ACTIONS(4075),
    [anon_sym_by] = ACTIONS(4075),
    [anon_sym_select] = ACTIONS(4075),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4351] = {
    [sym_modifier] = STATE(4497),
    [sym_preproc_region] = STATE(4351),
    [sym_preproc_endregion] = STATE(4351),
    [sym_preproc_line] = STATE(4351),
    [sym_preproc_pragma] = STATE(4351),
    [sym_preproc_nullable] = STATE(4351),
    [sym_preproc_error] = STATE(4351),
    [sym_preproc_warning] = STATE(4351),
    [sym_preproc_define] = STATE(4351),
    [sym_preproc_undef] = STATE(4351),
    [aux_sym_class_declaration_repeat2] = STATE(4351),
    [sym__identifier_token] = ACTIONS(5690),
    [anon_sym_extern] = ACTIONS(6105),
    [anon_sym_alias] = ACTIONS(5690),
    [anon_sym_global] = ACTIONS(5690),
    [anon_sym_unsafe] = ACTIONS(6105),
    [anon_sym_static] = ACTIONS(6105),
    [anon_sym_abstract] = ACTIONS(6105),
    [anon_sym_async] = ACTIONS(6105),
    [anon_sym_const] = ACTIONS(6105),
    [anon_sym_file] = ACTIONS(6105),
    [anon_sym_fixed] = ACTIONS(6105),
    [anon_sym_internal] = ACTIONS(6105),
    [anon_sym_new] = ACTIONS(6105),
    [anon_sym_override] = ACTIONS(6105),
    [anon_sym_partial] = ACTIONS(6105),
    [anon_sym_private] = ACTIONS(6105),
    [anon_sym_protected] = ACTIONS(6105),
    [anon_sym_public] = ACTIONS(6105),
    [anon_sym_readonly] = ACTIONS(6105),
    [anon_sym_required] = ACTIONS(6105),
    [anon_sym_sealed] = ACTIONS(6105),
    [anon_sym_virtual] = ACTIONS(6105),
    [anon_sym_volatile] = ACTIONS(6105),
    [anon_sym_where] = ACTIONS(5690),
    [anon_sym_notnull] = ACTIONS(5690),
    [anon_sym_unmanaged] = ACTIONS(5690),
    [anon_sym_get] = ACTIONS(5690),
    [anon_sym_set] = ACTIONS(5690),
    [anon_sym_add] = ACTIONS(5690),
    [anon_sym_remove] = ACTIONS(5690),
    [anon_sym_init] = ACTIONS(5690),
    [anon_sym_scoped] = ACTIONS(5690),
    [anon_sym_var] = ACTIONS(5690),
    [anon_sym_yield] = ACTIONS(5690),
    [anon_sym_when] = ACTIONS(5690),
    [anon_sym_from] = ACTIONS(5690),
    [anon_sym_into] = ACTIONS(5690),
    [anon_sym_join] = ACTIONS(5690),
    [anon_sym_on] = ACTIONS(5690),
    [anon_sym_equals] = ACTIONS(5690),
    [anon_sym_let] = ACTIONS(5690),
    [anon_sym_orderby] = ACTIONS(5690),
    [anon_sym_ascending] = ACTIONS(5690),
    [anon_sym_descending] = ACTIONS(5690),
    [anon_sym_group] = ACTIONS(5690),
    [anon_sym_by] = ACTIONS(5690),
    [anon_sym_select] = ACTIONS(5690),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4352] = {
    [sym_parameter_list] = STATE(8932),
    [sym_block] = STATE(3769),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7393),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4352),
    [sym_preproc_endregion] = STATE(4352),
    [sym_preproc_line] = STATE(4352),
    [sym_preproc_pragma] = STATE(4352),
    [sym_preproc_nullable] = STATE(4352),
    [sym_preproc_error] = STATE(4352),
    [sym_preproc_warning] = STATE(4352),
    [sym_preproc_define] = STATE(4352),
    [sym_preproc_undef] = STATE(4352),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_LBRACE] = ACTIONS(6108),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_STAR] = ACTIONS(6110),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4353] = {
    [sym_preproc_region] = STATE(4353),
    [sym_preproc_endregion] = STATE(4353),
    [sym_preproc_line] = STATE(4353),
    [sym_preproc_pragma] = STATE(4353),
    [sym_preproc_nullable] = STATE(4353),
    [sym_preproc_error] = STATE(4353),
    [sym_preproc_warning] = STATE(4353),
    [sym_preproc_define] = STATE(4353),
    [sym_preproc_undef] = STATE(4353),
    [sym__identifier_token] = ACTIONS(6112),
    [anon_sym_extern] = ACTIONS(6112),
    [anon_sym_alias] = ACTIONS(6112),
    [anon_sym_global] = ACTIONS(6112),
    [anon_sym_unsafe] = ACTIONS(6112),
    [anon_sym_static] = ACTIONS(6112),
    [anon_sym_LBRACK] = ACTIONS(6114),
    [anon_sym_RBRACE] = ACTIONS(6114),
    [anon_sym_abstract] = ACTIONS(6112),
    [anon_sym_async] = ACTIONS(6112),
    [anon_sym_const] = ACTIONS(6112),
    [anon_sym_file] = ACTIONS(6112),
    [anon_sym_fixed] = ACTIONS(6112),
    [anon_sym_internal] = ACTIONS(6112),
    [anon_sym_new] = ACTIONS(6112),
    [anon_sym_override] = ACTIONS(6112),
    [anon_sym_partial] = ACTIONS(6112),
    [anon_sym_private] = ACTIONS(6112),
    [anon_sym_protected] = ACTIONS(6112),
    [anon_sym_public] = ACTIONS(6112),
    [anon_sym_readonly] = ACTIONS(6112),
    [anon_sym_required] = ACTIONS(6112),
    [anon_sym_sealed] = ACTIONS(6112),
    [anon_sym_virtual] = ACTIONS(6112),
    [anon_sym_volatile] = ACTIONS(6112),
    [anon_sym_where] = ACTIONS(6112),
    [anon_sym_notnull] = ACTIONS(6112),
    [anon_sym_unmanaged] = ACTIONS(6112),
    [anon_sym_get] = ACTIONS(6112),
    [anon_sym_set] = ACTIONS(6112),
    [anon_sym_add] = ACTIONS(6112),
    [anon_sym_remove] = ACTIONS(6112),
    [anon_sym_init] = ACTIONS(6112),
    [anon_sym_scoped] = ACTIONS(6112),
    [anon_sym_var] = ACTIONS(6112),
    [anon_sym_yield] = ACTIONS(6112),
    [anon_sym_when] = ACTIONS(6112),
    [anon_sym_from] = ACTIONS(6112),
    [anon_sym_into] = ACTIONS(6112),
    [anon_sym_join] = ACTIONS(6112),
    [anon_sym_on] = ACTIONS(6112),
    [anon_sym_equals] = ACTIONS(6112),
    [anon_sym_let] = ACTIONS(6112),
    [anon_sym_orderby] = ACTIONS(6112),
    [anon_sym_ascending] = ACTIONS(6112),
    [anon_sym_descending] = ACTIONS(6112),
    [anon_sym_group] = ACTIONS(6112),
    [anon_sym_by] = ACTIONS(6112),
    [anon_sym_select] = ACTIONS(6112),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4354] = {
    [sym_argument_list] = STATE(4293),
    [sym_bracketed_argument_list] = STATE(3050),
    [sym_preproc_region] = STATE(4354),
    [sym_preproc_endregion] = STATE(4354),
    [sym_preproc_line] = STATE(4354),
    [sym_preproc_pragma] = STATE(4354),
    [sym_preproc_nullable] = STATE(4354),
    [sym_preproc_error] = STATE(4354),
    [sym_preproc_warning] = STATE(4354),
    [sym_preproc_define] = STATE(4354),
    [sym_preproc_undef] = STATE(4354),
    [anon_sym_SEMI] = ACTIONS(5271),
    [anon_sym_LBRACK] = ACTIONS(6068),
    [anon_sym_COLON] = ACTIONS(5271),
    [anon_sym_COMMA] = ACTIONS(5271),
    [anon_sym_RBRACK] = ACTIONS(5271),
    [anon_sym_LPAREN] = ACTIONS(5776),
    [anon_sym_RPAREN] = ACTIONS(5271),
    [anon_sym_RBRACE] = ACTIONS(5271),
    [anon_sym_LT] = ACTIONS(5275),
    [anon_sym_GT] = ACTIONS(5275),
    [anon_sym_in] = ACTIONS(5271),
    [anon_sym_QMARK] = ACTIONS(5275),
    [anon_sym_BANG] = ACTIONS(5832),
    [anon_sym_PLUS_PLUS] = ACTIONS(5834),
    [anon_sym_DASH_DASH] = ACTIONS(5834),
    [anon_sym_PLUS] = ACTIONS(5275),
    [anon_sym_DASH] = ACTIONS(5275),
    [anon_sym_STAR] = ACTIONS(5271),
    [anon_sym_SLASH] = ACTIONS(5275),
    [anon_sym_PERCENT] = ACTIONS(5271),
    [anon_sym_CARET] = ACTIONS(5271),
    [anon_sym_PIPE] = ACTIONS(5275),
    [anon_sym_AMP] = ACTIONS(5275),
    [anon_sym_LT_LT] = ACTIONS(5271),
    [anon_sym_GT_GT] = ACTIONS(5275),
    [anon_sym_GT_GT_GT] = ACTIONS(5271),
    [anon_sym_EQ_EQ] = ACTIONS(5271),
    [anon_sym_BANG_EQ] = ACTIONS(5271),
    [anon_sym_GT_EQ] = ACTIONS(5271),
    [anon_sym_LT_EQ] = ACTIONS(5271),
    [anon_sym_DOT] = ACTIONS(4602),
    [anon_sym_EQ_GT] = ACTIONS(5271),
    [anon_sym_switch] = ACTIONS(5271),
    [anon_sym_DOT_DOT] = ACTIONS(5271),
    [anon_sym_AMP_AMP] = ACTIONS(5271),
    [anon_sym_PIPE_PIPE] = ACTIONS(5271),
    [anon_sym_QMARK_QMARK] = ACTIONS(5271),
    [anon_sym_on] = ACTIONS(5271),
    [anon_sym_equals] = ACTIONS(5271),
    [anon_sym_by] = ACTIONS(5271),
    [anon_sym_as] = ACTIONS(5271),
    [anon_sym_is] = ACTIONS(5271),
    [anon_sym_DASH_GT] = ACTIONS(4604),
    [anon_sym_with] = ACTIONS(5271),
    [aux_sym_preproc_if_token3] = ACTIONS(5271),
    [aux_sym_preproc_else_token1] = ACTIONS(5271),
    [aux_sym_preproc_elif_token1] = ACTIONS(5271),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4355] = {
    [sym_preproc_region] = STATE(4355),
    [sym_preproc_endregion] = STATE(4355),
    [sym_preproc_line] = STATE(4355),
    [sym_preproc_pragma] = STATE(4355),
    [sym_preproc_nullable] = STATE(4355),
    [sym_preproc_error] = STATE(4355),
    [sym_preproc_warning] = STATE(4355),
    [sym_preproc_define] = STATE(4355),
    [sym_preproc_undef] = STATE(4355),
    [sym__identifier_token] = ACTIONS(6116),
    [anon_sym_extern] = ACTIONS(6116),
    [anon_sym_alias] = ACTIONS(6116),
    [anon_sym_global] = ACTIONS(6116),
    [anon_sym_unsafe] = ACTIONS(6116),
    [anon_sym_static] = ACTIONS(6116),
    [anon_sym_LBRACK] = ACTIONS(6118),
    [anon_sym_RBRACE] = ACTIONS(6118),
    [anon_sym_abstract] = ACTIONS(6116),
    [anon_sym_async] = ACTIONS(6116),
    [anon_sym_const] = ACTIONS(6116),
    [anon_sym_file] = ACTIONS(6116),
    [anon_sym_fixed] = ACTIONS(6116),
    [anon_sym_internal] = ACTIONS(6116),
    [anon_sym_new] = ACTIONS(6116),
    [anon_sym_override] = ACTIONS(6116),
    [anon_sym_partial] = ACTIONS(6116),
    [anon_sym_private] = ACTIONS(6116),
    [anon_sym_protected] = ACTIONS(6116),
    [anon_sym_public] = ACTIONS(6116),
    [anon_sym_readonly] = ACTIONS(6116),
    [anon_sym_required] = ACTIONS(6116),
    [anon_sym_sealed] = ACTIONS(6116),
    [anon_sym_virtual] = ACTIONS(6116),
    [anon_sym_volatile] = ACTIONS(6116),
    [anon_sym_where] = ACTIONS(6116),
    [anon_sym_notnull] = ACTIONS(6116),
    [anon_sym_unmanaged] = ACTIONS(6116),
    [anon_sym_get] = ACTIONS(6116),
    [anon_sym_set] = ACTIONS(6116),
    [anon_sym_add] = ACTIONS(6116),
    [anon_sym_remove] = ACTIONS(6116),
    [anon_sym_init] = ACTIONS(6116),
    [anon_sym_scoped] = ACTIONS(6116),
    [anon_sym_var] = ACTIONS(6116),
    [anon_sym_yield] = ACTIONS(6116),
    [anon_sym_when] = ACTIONS(6116),
    [anon_sym_from] = ACTIONS(6116),
    [anon_sym_into] = ACTIONS(6116),
    [anon_sym_join] = ACTIONS(6116),
    [anon_sym_on] = ACTIONS(6116),
    [anon_sym_equals] = ACTIONS(6116),
    [anon_sym_let] = ACTIONS(6116),
    [anon_sym_orderby] = ACTIONS(6116),
    [anon_sym_ascending] = ACTIONS(6116),
    [anon_sym_descending] = ACTIONS(6116),
    [anon_sym_group] = ACTIONS(6116),
    [anon_sym_by] = ACTIONS(6116),
    [anon_sym_select] = ACTIONS(6116),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4356] = {
    [sym_preproc_region] = STATE(4356),
    [sym_preproc_endregion] = STATE(4356),
    [sym_preproc_line] = STATE(4356),
    [sym_preproc_pragma] = STATE(4356),
    [sym_preproc_nullable] = STATE(4356),
    [sym_preproc_error] = STATE(4356),
    [sym_preproc_warning] = STATE(4356),
    [sym_preproc_define] = STATE(4356),
    [sym_preproc_undef] = STATE(4356),
    [sym__identifier_token] = ACTIONS(3401),
    [anon_sym_extern] = ACTIONS(3401),
    [anon_sym_alias] = ACTIONS(3401),
    [anon_sym_global] = ACTIONS(3401),
    [anon_sym_unsafe] = ACTIONS(3401),
    [anon_sym_static] = ACTIONS(3401),
    [anon_sym_LBRACK] = ACTIONS(3403),
    [anon_sym_RBRACE] = ACTIONS(3403),
    [anon_sym_abstract] = ACTIONS(3401),
    [anon_sym_async] = ACTIONS(3401),
    [anon_sym_const] = ACTIONS(3401),
    [anon_sym_file] = ACTIONS(3401),
    [anon_sym_fixed] = ACTIONS(3401),
    [anon_sym_internal] = ACTIONS(3401),
    [anon_sym_new] = ACTIONS(3401),
    [anon_sym_override] = ACTIONS(3401),
    [anon_sym_partial] = ACTIONS(3401),
    [anon_sym_private] = ACTIONS(3401),
    [anon_sym_protected] = ACTIONS(3401),
    [anon_sym_public] = ACTIONS(3401),
    [anon_sym_readonly] = ACTIONS(3401),
    [anon_sym_required] = ACTIONS(3401),
    [anon_sym_sealed] = ACTIONS(3401),
    [anon_sym_virtual] = ACTIONS(3401),
    [anon_sym_volatile] = ACTIONS(3401),
    [anon_sym_where] = ACTIONS(3401),
    [anon_sym_notnull] = ACTIONS(3401),
    [anon_sym_unmanaged] = ACTIONS(3401),
    [anon_sym_get] = ACTIONS(3401),
    [anon_sym_set] = ACTIONS(3401),
    [anon_sym_add] = ACTIONS(3401),
    [anon_sym_remove] = ACTIONS(3401),
    [anon_sym_init] = ACTIONS(3401),
    [anon_sym_scoped] = ACTIONS(3401),
    [anon_sym_var] = ACTIONS(3401),
    [anon_sym_yield] = ACTIONS(3401),
    [anon_sym_when] = ACTIONS(3401),
    [anon_sym_from] = ACTIONS(3401),
    [anon_sym_into] = ACTIONS(3401),
    [anon_sym_join] = ACTIONS(3401),
    [anon_sym_on] = ACTIONS(3401),
    [anon_sym_equals] = ACTIONS(3401),
    [anon_sym_let] = ACTIONS(3401),
    [anon_sym_orderby] = ACTIONS(3401),
    [anon_sym_ascending] = ACTIONS(3401),
    [anon_sym_descending] = ACTIONS(3401),
    [anon_sym_group] = ACTIONS(3401),
    [anon_sym_by] = ACTIONS(3401),
    [anon_sym_select] = ACTIONS(3401),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4357] = {
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(6020),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4357),
    [sym_preproc_endregion] = STATE(4357),
    [sym_preproc_line] = STATE(4357),
    [sym_preproc_pragma] = STATE(4357),
    [sym_preproc_nullable] = STATE(4357),
    [sym_preproc_error] = STATE(4357),
    [sym_preproc_warning] = STATE(4357),
    [sym_preproc_define] = STATE(4357),
    [sym_preproc_undef] = STATE(4357),
    [sym__identifier_token] = ACTIONS(2669),
    [anon_sym_alias] = ACTIONS(2669),
    [anon_sym_global] = ACTIONS(2669),
    [anon_sym_LPAREN] = ACTIONS(2695),
    [anon_sym_ref] = ACTIONS(2669),
    [anon_sym_delegate] = ACTIONS(2669),
    [anon_sym_file] = ACTIONS(2669),
    [anon_sym_readonly] = ACTIONS(2669),
    [anon_sym_in] = ACTIONS(2669),
    [anon_sym_out] = ACTIONS(2669),
    [anon_sym_where] = ACTIONS(2669),
    [anon_sym_notnull] = ACTIONS(2669),
    [anon_sym_unmanaged] = ACTIONS(2669),
    [anon_sym_this] = ACTIONS(2669),
    [anon_sym_scoped] = ACTIONS(2669),
    [anon_sym_var] = ACTIONS(2669),
    [sym_predefined_type] = ACTIONS(2669),
    [anon_sym_yield] = ACTIONS(2669),
    [anon_sym_when] = ACTIONS(2669),
    [anon_sym_from] = ACTIONS(2669),
    [anon_sym_into] = ACTIONS(2669),
    [anon_sym_join] = ACTIONS(2669),
    [anon_sym_on] = ACTIONS(2669),
    [anon_sym_equals] = ACTIONS(2669),
    [anon_sym_let] = ACTIONS(2669),
    [anon_sym_orderby] = ACTIONS(2669),
    [anon_sym_ascending] = ACTIONS(2669),
    [anon_sym_descending] = ACTIONS(2669),
    [anon_sym_group] = ACTIONS(2669),
    [anon_sym_by] = ACTIONS(2669),
    [anon_sym_select] = ACTIONS(2669),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4358] = {
    [sym_preproc_region] = STATE(4358),
    [sym_preproc_endregion] = STATE(4358),
    [sym_preproc_line] = STATE(4358),
    [sym_preproc_pragma] = STATE(4358),
    [sym_preproc_nullable] = STATE(4358),
    [sym_preproc_error] = STATE(4358),
    [sym_preproc_warning] = STATE(4358),
    [sym_preproc_define] = STATE(4358),
    [sym_preproc_undef] = STATE(4358),
    [sym__identifier_token] = ACTIONS(2995),
    [anon_sym_extern] = ACTIONS(2995),
    [anon_sym_alias] = ACTIONS(2995),
    [anon_sym_global] = ACTIONS(2995),
    [anon_sym_unsafe] = ACTIONS(2995),
    [anon_sym_static] = ACTIONS(2995),
    [anon_sym_LBRACK] = ACTIONS(2997),
    [anon_sym_RBRACE] = ACTIONS(2997),
    [anon_sym_abstract] = ACTIONS(2995),
    [anon_sym_async] = ACTIONS(2995),
    [anon_sym_const] = ACTIONS(2995),
    [anon_sym_file] = ACTIONS(2995),
    [anon_sym_fixed] = ACTIONS(2995),
    [anon_sym_internal] = ACTIONS(2995),
    [anon_sym_new] = ACTIONS(2995),
    [anon_sym_override] = ACTIONS(2995),
    [anon_sym_partial] = ACTIONS(2995),
    [anon_sym_private] = ACTIONS(2995),
    [anon_sym_protected] = ACTIONS(2995),
    [anon_sym_public] = ACTIONS(2995),
    [anon_sym_readonly] = ACTIONS(2995),
    [anon_sym_required] = ACTIONS(2995),
    [anon_sym_sealed] = ACTIONS(2995),
    [anon_sym_virtual] = ACTIONS(2995),
    [anon_sym_volatile] = ACTIONS(2995),
    [anon_sym_where] = ACTIONS(2995),
    [anon_sym_notnull] = ACTIONS(2995),
    [anon_sym_unmanaged] = ACTIONS(2995),
    [anon_sym_get] = ACTIONS(2995),
    [anon_sym_set] = ACTIONS(2995),
    [anon_sym_add] = ACTIONS(2995),
    [anon_sym_remove] = ACTIONS(2995),
    [anon_sym_init] = ACTIONS(2995),
    [anon_sym_scoped] = ACTIONS(2995),
    [anon_sym_var] = ACTIONS(2995),
    [anon_sym_yield] = ACTIONS(2995),
    [anon_sym_when] = ACTIONS(2995),
    [anon_sym_from] = ACTIONS(2995),
    [anon_sym_into] = ACTIONS(2995),
    [anon_sym_join] = ACTIONS(2995),
    [anon_sym_on] = ACTIONS(2995),
    [anon_sym_equals] = ACTIONS(2995),
    [anon_sym_let] = ACTIONS(2995),
    [anon_sym_orderby] = ACTIONS(2995),
    [anon_sym_ascending] = ACTIONS(2995),
    [anon_sym_descending] = ACTIONS(2995),
    [anon_sym_group] = ACTIONS(2995),
    [anon_sym_by] = ACTIONS(2995),
    [anon_sym_select] = ACTIONS(2995),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4359] = {
    [sym_preproc_region] = STATE(4359),
    [sym_preproc_endregion] = STATE(4359),
    [sym_preproc_line] = STATE(4359),
    [sym_preproc_pragma] = STATE(4359),
    [sym_preproc_nullable] = STATE(4359),
    [sym_preproc_error] = STATE(4359),
    [sym_preproc_warning] = STATE(4359),
    [sym_preproc_define] = STATE(4359),
    [sym_preproc_undef] = STATE(4359),
    [sym__identifier_token] = ACTIONS(3037),
    [anon_sym_extern] = ACTIONS(3037),
    [anon_sym_alias] = ACTIONS(3037),
    [anon_sym_global] = ACTIONS(3037),
    [anon_sym_unsafe] = ACTIONS(3037),
    [anon_sym_static] = ACTIONS(3037),
    [anon_sym_LBRACK] = ACTIONS(3039),
    [anon_sym_RBRACE] = ACTIONS(3039),
    [anon_sym_abstract] = ACTIONS(3037),
    [anon_sym_async] = ACTIONS(3037),
    [anon_sym_const] = ACTIONS(3037),
    [anon_sym_file] = ACTIONS(3037),
    [anon_sym_fixed] = ACTIONS(3037),
    [anon_sym_internal] = ACTIONS(3037),
    [anon_sym_new] = ACTIONS(3037),
    [anon_sym_override] = ACTIONS(3037),
    [anon_sym_partial] = ACTIONS(3037),
    [anon_sym_private] = ACTIONS(3037),
    [anon_sym_protected] = ACTIONS(3037),
    [anon_sym_public] = ACTIONS(3037),
    [anon_sym_readonly] = ACTIONS(3037),
    [anon_sym_required] = ACTIONS(3037),
    [anon_sym_sealed] = ACTIONS(3037),
    [anon_sym_virtual] = ACTIONS(3037),
    [anon_sym_volatile] = ACTIONS(3037),
    [anon_sym_where] = ACTIONS(3037),
    [anon_sym_notnull] = ACTIONS(3037),
    [anon_sym_unmanaged] = ACTIONS(3037),
    [anon_sym_get] = ACTIONS(3037),
    [anon_sym_set] = ACTIONS(3037),
    [anon_sym_add] = ACTIONS(3037),
    [anon_sym_remove] = ACTIONS(3037),
    [anon_sym_init] = ACTIONS(3037),
    [anon_sym_scoped] = ACTIONS(3037),
    [anon_sym_var] = ACTIONS(3037),
    [anon_sym_yield] = ACTIONS(3037),
    [anon_sym_when] = ACTIONS(3037),
    [anon_sym_from] = ACTIONS(3037),
    [anon_sym_into] = ACTIONS(3037),
    [anon_sym_join] = ACTIONS(3037),
    [anon_sym_on] = ACTIONS(3037),
    [anon_sym_equals] = ACTIONS(3037),
    [anon_sym_let] = ACTIONS(3037),
    [anon_sym_orderby] = ACTIONS(3037),
    [anon_sym_ascending] = ACTIONS(3037),
    [anon_sym_descending] = ACTIONS(3037),
    [anon_sym_group] = ACTIONS(3037),
    [anon_sym_by] = ACTIONS(3037),
    [anon_sym_select] = ACTIONS(3037),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4360] = {
    [sym_preproc_region] = STATE(4360),
    [sym_preproc_endregion] = STATE(4360),
    [sym_preproc_line] = STATE(4360),
    [sym_preproc_pragma] = STATE(4360),
    [sym_preproc_nullable] = STATE(4360),
    [sym_preproc_error] = STATE(4360),
    [sym_preproc_warning] = STATE(4360),
    [sym_preproc_define] = STATE(4360),
    [sym_preproc_undef] = STATE(4360),
    [anon_sym_EQ] = ACTIONS(6120),
    [anon_sym_LBRACK] = ACTIONS(5286),
    [anon_sym_LPAREN] = ACTIONS(5286),
    [anon_sym_LT] = ACTIONS(5288),
    [anon_sym_GT] = ACTIONS(5288),
    [anon_sym_QMARK] = ACTIONS(5288),
    [anon_sym_BANG] = ACTIONS(5288),
    [anon_sym_PLUS_PLUS] = ACTIONS(5286),
    [anon_sym_DASH_DASH] = ACTIONS(5286),
    [anon_sym_PLUS] = ACTIONS(5288),
    [anon_sym_DASH] = ACTIONS(5288),
    [anon_sym_STAR] = ACTIONS(5288),
    [anon_sym_SLASH] = ACTIONS(5288),
    [anon_sym_PERCENT] = ACTIONS(5288),
    [anon_sym_CARET] = ACTIONS(5288),
    [anon_sym_PIPE] = ACTIONS(5288),
    [anon_sym_AMP] = ACTIONS(5288),
    [anon_sym_LT_LT] = ACTIONS(5288),
    [anon_sym_GT_GT] = ACTIONS(5288),
    [anon_sym_GT_GT_GT] = ACTIONS(5288),
    [anon_sym_EQ_EQ] = ACTIONS(5286),
    [anon_sym_BANG_EQ] = ACTIONS(5286),
    [anon_sym_GT_EQ] = ACTIONS(5286),
    [anon_sym_LT_EQ] = ACTIONS(5286),
    [anon_sym_DOT] = ACTIONS(5288),
    [anon_sym_switch] = ACTIONS(5286),
    [anon_sym_DOT_DOT] = ACTIONS(5286),
    [anon_sym_PLUS_EQ] = ACTIONS(6122),
    [anon_sym_DASH_EQ] = ACTIONS(6122),
    [anon_sym_STAR_EQ] = ACTIONS(6122),
    [anon_sym_SLASH_EQ] = ACTIONS(6122),
    [anon_sym_PERCENT_EQ] = ACTIONS(6122),
    [anon_sym_AMP_EQ] = ACTIONS(6122),
    [anon_sym_CARET_EQ] = ACTIONS(6122),
    [anon_sym_PIPE_EQ] = ACTIONS(6122),
    [anon_sym_LT_LT_EQ] = ACTIONS(6122),
    [anon_sym_GT_GT_EQ] = ACTIONS(6122),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(6122),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(6122),
    [anon_sym_AMP_AMP] = ACTIONS(5286),
    [anon_sym_PIPE_PIPE] = ACTIONS(5286),
    [anon_sym_QMARK_QMARK] = ACTIONS(5288),
    [anon_sym_as] = ACTIONS(5286),
    [anon_sym_is] = ACTIONS(5286),
    [anon_sym_DASH_GT] = ACTIONS(5286),
    [anon_sym_with] = ACTIONS(5286),
    [aux_sym_preproc_if_token3] = ACTIONS(5286),
    [aux_sym_preproc_else_token1] = ACTIONS(5286),
    [aux_sym_preproc_elif_token1] = ACTIONS(5286),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4361] = {
    [sym_argument_list] = STATE(4412),
    [sym_initializer_expression] = STATE(4595),
    [sym_preproc_region] = STATE(4361),
    [sym_preproc_endregion] = STATE(4361),
    [sym_preproc_line] = STATE(4361),
    [sym_preproc_pragma] = STATE(4361),
    [sym_preproc_nullable] = STATE(4361),
    [sym_preproc_error] = STATE(4361),
    [sym_preproc_warning] = STATE(4361),
    [sym_preproc_define] = STATE(4361),
    [sym_preproc_undef] = STATE(4361),
    [anon_sym_LBRACK] = ACTIONS(5263),
    [anon_sym_COMMA] = ACTIONS(5263),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_LT] = ACTIONS(5267),
    [anon_sym_GT] = ACTIONS(5267),
    [anon_sym_where] = ACTIONS(5263),
    [anon_sym_QMARK] = ACTIONS(5267),
    [anon_sym_BANG] = ACTIONS(5267),
    [anon_sym_PLUS_PLUS] = ACTIONS(5263),
    [anon_sym_DASH_DASH] = ACTIONS(5263),
    [anon_sym_PLUS] = ACTIONS(5267),
    [anon_sym_DASH] = ACTIONS(5267),
    [anon_sym_STAR] = ACTIONS(5263),
    [anon_sym_SLASH] = ACTIONS(5267),
    [anon_sym_PERCENT] = ACTIONS(5263),
    [anon_sym_CARET] = ACTIONS(5263),
    [anon_sym_PIPE] = ACTIONS(5267),
    [anon_sym_AMP] = ACTIONS(5267),
    [anon_sym_LT_LT] = ACTIONS(5263),
    [anon_sym_GT_GT] = ACTIONS(5267),
    [anon_sym_GT_GT_GT] = ACTIONS(5263),
    [anon_sym_EQ_EQ] = ACTIONS(5263),
    [anon_sym_BANG_EQ] = ACTIONS(5263),
    [anon_sym_GT_EQ] = ACTIONS(5263),
    [anon_sym_LT_EQ] = ACTIONS(5263),
    [anon_sym_DOT] = ACTIONS(5267),
    [anon_sym_switch] = ACTIONS(5263),
    [anon_sym_DOT_DOT] = ACTIONS(5263),
    [anon_sym_and] = ACTIONS(5263),
    [anon_sym_or] = ACTIONS(5267),
    [anon_sym_AMP_AMP] = ACTIONS(5263),
    [anon_sym_PIPE_PIPE] = ACTIONS(5263),
    [anon_sym_QMARK_QMARK] = ACTIONS(5263),
    [anon_sym_from] = ACTIONS(5263),
    [anon_sym_into] = ACTIONS(5263),
    [anon_sym_join] = ACTIONS(5263),
    [anon_sym_let] = ACTIONS(5263),
    [anon_sym_orderby] = ACTIONS(5263),
    [anon_sym_ascending] = ACTIONS(5263),
    [anon_sym_descending] = ACTIONS(5263),
    [anon_sym_group] = ACTIONS(5263),
    [anon_sym_select] = ACTIONS(5263),
    [anon_sym_as] = ACTIONS(5267),
    [anon_sym_is] = ACTIONS(5263),
    [anon_sym_DASH_GT] = ACTIONS(5263),
    [anon_sym_with] = ACTIONS(5263),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4362] = {
    [sym_parameter_list] = STATE(8932),
    [sym_block] = STATE(3769),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7354),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4362),
    [sym_preproc_endregion] = STATE(4362),
    [sym_preproc_line] = STATE(4362),
    [sym_preproc_pragma] = STATE(4362),
    [sym_preproc_nullable] = STATE(4362),
    [sym_preproc_error] = STATE(4362),
    [sym_preproc_warning] = STATE(4362),
    [sym_preproc_define] = STATE(4362),
    [sym_preproc_undef] = STATE(4362),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(4367),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_LBRACE] = ACTIONS(6108),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_STAR] = ACTIONS(6110),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4363] = {
    [sym_preproc_region] = STATE(4363),
    [sym_preproc_endregion] = STATE(4363),
    [sym_preproc_line] = STATE(4363),
    [sym_preproc_pragma] = STATE(4363),
    [sym_preproc_nullable] = STATE(4363),
    [sym_preproc_error] = STATE(4363),
    [sym_preproc_warning] = STATE(4363),
    [sym_preproc_define] = STATE(4363),
    [sym_preproc_undef] = STATE(4363),
    [sym__identifier_token] = ACTIONS(3049),
    [anon_sym_extern] = ACTIONS(3049),
    [anon_sym_alias] = ACTIONS(3049),
    [anon_sym_global] = ACTIONS(3049),
    [anon_sym_unsafe] = ACTIONS(3049),
    [anon_sym_static] = ACTIONS(3049),
    [anon_sym_LBRACK] = ACTIONS(3051),
    [anon_sym_RBRACE] = ACTIONS(3051),
    [anon_sym_abstract] = ACTIONS(3049),
    [anon_sym_async] = ACTIONS(3049),
    [anon_sym_const] = ACTIONS(3049),
    [anon_sym_file] = ACTIONS(3049),
    [anon_sym_fixed] = ACTIONS(3049),
    [anon_sym_internal] = ACTIONS(3049),
    [anon_sym_new] = ACTIONS(3049),
    [anon_sym_override] = ACTIONS(3049),
    [anon_sym_partial] = ACTIONS(3049),
    [anon_sym_private] = ACTIONS(3049),
    [anon_sym_protected] = ACTIONS(3049),
    [anon_sym_public] = ACTIONS(3049),
    [anon_sym_readonly] = ACTIONS(3049),
    [anon_sym_required] = ACTIONS(3049),
    [anon_sym_sealed] = ACTIONS(3049),
    [anon_sym_virtual] = ACTIONS(3049),
    [anon_sym_volatile] = ACTIONS(3049),
    [anon_sym_where] = ACTIONS(3049),
    [anon_sym_notnull] = ACTIONS(3049),
    [anon_sym_unmanaged] = ACTIONS(3049),
    [anon_sym_get] = ACTIONS(3049),
    [anon_sym_set] = ACTIONS(3049),
    [anon_sym_add] = ACTIONS(3049),
    [anon_sym_remove] = ACTIONS(3049),
    [anon_sym_init] = ACTIONS(3049),
    [anon_sym_scoped] = ACTIONS(3049),
    [anon_sym_var] = ACTIONS(3049),
    [anon_sym_yield] = ACTIONS(3049),
    [anon_sym_when] = ACTIONS(3049),
    [anon_sym_from] = ACTIONS(3049),
    [anon_sym_into] = ACTIONS(3049),
    [anon_sym_join] = ACTIONS(3049),
    [anon_sym_on] = ACTIONS(3049),
    [anon_sym_equals] = ACTIONS(3049),
    [anon_sym_let] = ACTIONS(3049),
    [anon_sym_orderby] = ACTIONS(3049),
    [anon_sym_ascending] = ACTIONS(3049),
    [anon_sym_descending] = ACTIONS(3049),
    [anon_sym_group] = ACTIONS(3049),
    [anon_sym_by] = ACTIONS(3049),
    [anon_sym_select] = ACTIONS(3049),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4364] = {
    [sym_preproc_region] = STATE(4364),
    [sym_preproc_endregion] = STATE(4364),
    [sym_preproc_line] = STATE(4364),
    [sym_preproc_pragma] = STATE(4364),
    [sym_preproc_nullable] = STATE(4364),
    [sym_preproc_error] = STATE(4364),
    [sym_preproc_warning] = STATE(4364),
    [sym_preproc_define] = STATE(4364),
    [sym_preproc_undef] = STATE(4364),
    [anon_sym_SEMI] = ACTIONS(5286),
    [anon_sym_EQ] = ACTIONS(6126),
    [anon_sym_LBRACK] = ACTIONS(5286),
    [anon_sym_COMMA] = ACTIONS(5286),
    [anon_sym_LPAREN] = ACTIONS(5286),
    [anon_sym_RBRACE] = ACTIONS(5286),
    [anon_sym_LT] = ACTIONS(5288),
    [anon_sym_GT] = ACTIONS(5288),
    [anon_sym_QMARK] = ACTIONS(5288),
    [anon_sym_BANG] = ACTIONS(5288),
    [anon_sym_PLUS_PLUS] = ACTIONS(5286),
    [anon_sym_DASH_DASH] = ACTIONS(5286),
    [anon_sym_PLUS] = ACTIONS(5288),
    [anon_sym_DASH] = ACTIONS(5288),
    [anon_sym_STAR] = ACTIONS(5288),
    [anon_sym_SLASH] = ACTIONS(5288),
    [anon_sym_PERCENT] = ACTIONS(5288),
    [anon_sym_CARET] = ACTIONS(5288),
    [anon_sym_PIPE] = ACTIONS(5288),
    [anon_sym_AMP] = ACTIONS(5288),
    [anon_sym_LT_LT] = ACTIONS(5288),
    [anon_sym_GT_GT] = ACTIONS(5288),
    [anon_sym_GT_GT_GT] = ACTIONS(5288),
    [anon_sym_EQ_EQ] = ACTIONS(5286),
    [anon_sym_BANG_EQ] = ACTIONS(5286),
    [anon_sym_GT_EQ] = ACTIONS(5286),
    [anon_sym_LT_EQ] = ACTIONS(5286),
    [anon_sym_DOT] = ACTIONS(5288),
    [anon_sym_switch] = ACTIONS(5286),
    [anon_sym_DOT_DOT] = ACTIONS(5286),
    [anon_sym_PLUS_EQ] = ACTIONS(6128),
    [anon_sym_DASH_EQ] = ACTIONS(6128),
    [anon_sym_STAR_EQ] = ACTIONS(6128),
    [anon_sym_SLASH_EQ] = ACTIONS(6128),
    [anon_sym_PERCENT_EQ] = ACTIONS(6128),
    [anon_sym_AMP_EQ] = ACTIONS(6128),
    [anon_sym_CARET_EQ] = ACTIONS(6128),
    [anon_sym_PIPE_EQ] = ACTIONS(6128),
    [anon_sym_LT_LT_EQ] = ACTIONS(6128),
    [anon_sym_GT_GT_EQ] = ACTIONS(6128),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(6128),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(6128),
    [anon_sym_AMP_AMP] = ACTIONS(5286),
    [anon_sym_PIPE_PIPE] = ACTIONS(5286),
    [anon_sym_QMARK_QMARK] = ACTIONS(5288),
    [anon_sym_as] = ACTIONS(5286),
    [anon_sym_is] = ACTIONS(5286),
    [anon_sym_DASH_GT] = ACTIONS(5286),
    [anon_sym_with] = ACTIONS(5286),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4365] = {
    [sym_preproc_region] = STATE(4365),
    [sym_preproc_endregion] = STATE(4365),
    [sym_preproc_line] = STATE(4365),
    [sym_preproc_pragma] = STATE(4365),
    [sym_preproc_nullable] = STATE(4365),
    [sym_preproc_error] = STATE(4365),
    [sym_preproc_warning] = STATE(4365),
    [sym_preproc_define] = STATE(4365),
    [sym_preproc_undef] = STATE(4365),
    [anon_sym_EQ] = ACTIONS(5998),
    [anon_sym_LBRACK] = ACTIONS(5286),
    [anon_sym_COMMA] = ACTIONS(5286),
    [anon_sym_LPAREN] = ACTIONS(5286),
    [anon_sym_RPAREN] = ACTIONS(6130),
    [anon_sym_LT] = ACTIONS(5288),
    [anon_sym_GT] = ACTIONS(5288),
    [anon_sym_QMARK] = ACTIONS(5288),
    [anon_sym_BANG] = ACTIONS(5288),
    [anon_sym_PLUS_PLUS] = ACTIONS(5286),
    [anon_sym_DASH_DASH] = ACTIONS(5286),
    [anon_sym_PLUS] = ACTIONS(5288),
    [anon_sym_DASH] = ACTIONS(5288),
    [anon_sym_STAR] = ACTIONS(5288),
    [anon_sym_SLASH] = ACTIONS(5288),
    [anon_sym_PERCENT] = ACTIONS(5288),
    [anon_sym_CARET] = ACTIONS(5288),
    [anon_sym_PIPE] = ACTIONS(5288),
    [anon_sym_AMP] = ACTIONS(5288),
    [anon_sym_LT_LT] = ACTIONS(5288),
    [anon_sym_GT_GT] = ACTIONS(5288),
    [anon_sym_GT_GT_GT] = ACTIONS(5288),
    [anon_sym_EQ_EQ] = ACTIONS(5286),
    [anon_sym_BANG_EQ] = ACTIONS(5286),
    [anon_sym_GT_EQ] = ACTIONS(5286),
    [anon_sym_LT_EQ] = ACTIONS(5286),
    [anon_sym_DOT] = ACTIONS(5288),
    [anon_sym_switch] = ACTIONS(5286),
    [anon_sym_DOT_DOT] = ACTIONS(5286),
    [anon_sym_PLUS_EQ] = ACTIONS(6000),
    [anon_sym_DASH_EQ] = ACTIONS(6000),
    [anon_sym_STAR_EQ] = ACTIONS(6000),
    [anon_sym_SLASH_EQ] = ACTIONS(6000),
    [anon_sym_PERCENT_EQ] = ACTIONS(6000),
    [anon_sym_AMP_EQ] = ACTIONS(6000),
    [anon_sym_CARET_EQ] = ACTIONS(6000),
    [anon_sym_PIPE_EQ] = ACTIONS(6000),
    [anon_sym_LT_LT_EQ] = ACTIONS(6000),
    [anon_sym_GT_GT_EQ] = ACTIONS(6000),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(6000),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(6000),
    [anon_sym_AMP_AMP] = ACTIONS(5286),
    [anon_sym_PIPE_PIPE] = ACTIONS(5286),
    [anon_sym_QMARK_QMARK] = ACTIONS(5288),
    [anon_sym_as] = ACTIONS(5286),
    [anon_sym_is] = ACTIONS(5286),
    [anon_sym_DASH_GT] = ACTIONS(5286),
    [anon_sym_with] = ACTIONS(5286),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4366] = {
    [sym_preproc_region] = STATE(4366),
    [sym_preproc_endregion] = STATE(4366),
    [sym_preproc_line] = STATE(4366),
    [sym_preproc_pragma] = STATE(4366),
    [sym_preproc_nullable] = STATE(4366),
    [sym_preproc_error] = STATE(4366),
    [sym_preproc_warning] = STATE(4366),
    [sym_preproc_define] = STATE(4366),
    [sym_preproc_undef] = STATE(4366),
    [anon_sym_EQ] = ACTIONS(5998),
    [anon_sym_LBRACK] = ACTIONS(5286),
    [anon_sym_COMMA] = ACTIONS(5286),
    [anon_sym_LPAREN] = ACTIONS(5286),
    [anon_sym_RPAREN] = ACTIONS(6078),
    [anon_sym_LT] = ACTIONS(5288),
    [anon_sym_GT] = ACTIONS(5288),
    [anon_sym_QMARK] = ACTIONS(5288),
    [anon_sym_BANG] = ACTIONS(5288),
    [anon_sym_PLUS_PLUS] = ACTIONS(5286),
    [anon_sym_DASH_DASH] = ACTIONS(5286),
    [anon_sym_PLUS] = ACTIONS(5288),
    [anon_sym_DASH] = ACTIONS(5288),
    [anon_sym_STAR] = ACTIONS(5288),
    [anon_sym_SLASH] = ACTIONS(5288),
    [anon_sym_PERCENT] = ACTIONS(5288),
    [anon_sym_CARET] = ACTIONS(5288),
    [anon_sym_PIPE] = ACTIONS(5288),
    [anon_sym_AMP] = ACTIONS(5288),
    [anon_sym_LT_LT] = ACTIONS(5288),
    [anon_sym_GT_GT] = ACTIONS(5288),
    [anon_sym_GT_GT_GT] = ACTIONS(5288),
    [anon_sym_EQ_EQ] = ACTIONS(5286),
    [anon_sym_BANG_EQ] = ACTIONS(5286),
    [anon_sym_GT_EQ] = ACTIONS(5286),
    [anon_sym_LT_EQ] = ACTIONS(5286),
    [anon_sym_DOT] = ACTIONS(5288),
    [anon_sym_switch] = ACTIONS(5286),
    [anon_sym_DOT_DOT] = ACTIONS(5286),
    [anon_sym_PLUS_EQ] = ACTIONS(6000),
    [anon_sym_DASH_EQ] = ACTIONS(6000),
    [anon_sym_STAR_EQ] = ACTIONS(6000),
    [anon_sym_SLASH_EQ] = ACTIONS(6000),
    [anon_sym_PERCENT_EQ] = ACTIONS(6000),
    [anon_sym_AMP_EQ] = ACTIONS(6000),
    [anon_sym_CARET_EQ] = ACTIONS(6000),
    [anon_sym_PIPE_EQ] = ACTIONS(6000),
    [anon_sym_LT_LT_EQ] = ACTIONS(6000),
    [anon_sym_GT_GT_EQ] = ACTIONS(6000),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(6000),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(6000),
    [anon_sym_AMP_AMP] = ACTIONS(5286),
    [anon_sym_PIPE_PIPE] = ACTIONS(5286),
    [anon_sym_QMARK_QMARK] = ACTIONS(5288),
    [anon_sym_as] = ACTIONS(5286),
    [anon_sym_is] = ACTIONS(5286),
    [anon_sym_DASH_GT] = ACTIONS(5286),
    [anon_sym_with] = ACTIONS(5286),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4367] = {
    [sym__name] = STATE(7943),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(8681),
    [sym_implicit_type] = STATE(8787),
    [sym_array_type] = STATE(8347),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9367),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(8787),
    [sym_scoped_type] = STATE(8787),
    [sym_tuple_type] = STATE(8173),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4367),
    [sym_preproc_endregion] = STATE(4367),
    [sym_preproc_line] = STATE(4367),
    [sym_preproc_pragma] = STATE(4367),
    [sym_preproc_nullable] = STATE(4367),
    [sym_preproc_error] = STATE(4367),
    [sym_preproc_warning] = STATE(4367),
    [sym_preproc_define] = STATE(4367),
    [sym_preproc_undef] = STATE(4367),
    [aux_sym_type_argument_list_repeat1] = STATE(8703),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_COMMA] = ACTIONS(5743),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(5745),
    [anon_sym_delegate] = ACTIONS(5747),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_GT] = ACTIONS(6132),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(5753),
    [anon_sym_var] = ACTIONS(5369),
    [sym_predefined_type] = ACTIONS(5755),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4368] = {
    [sym_block] = STATE(2503),
    [sym_preproc_region] = STATE(4368),
    [sym_preproc_endregion] = STATE(4368),
    [sym_preproc_line] = STATE(4368),
    [sym_preproc_pragma] = STATE(4368),
    [sym_preproc_nullable] = STATE(4368),
    [sym_preproc_error] = STATE(4368),
    [sym_preproc_warning] = STATE(4368),
    [sym_preproc_define] = STATE(4368),
    [sym_preproc_undef] = STATE(4368),
    [sym__identifier_token] = ACTIONS(4042),
    [anon_sym_extern] = ACTIONS(4042),
    [anon_sym_alias] = ACTIONS(4042),
    [anon_sym_global] = ACTIONS(4042),
    [anon_sym_unsafe] = ACTIONS(4042),
    [anon_sym_static] = ACTIONS(4042),
    [anon_sym_LPAREN] = ACTIONS(5474),
    [anon_sym_ref] = ACTIONS(4042),
    [anon_sym_LBRACE] = ACTIONS(5788),
    [anon_sym_delegate] = ACTIONS(4042),
    [anon_sym_abstract] = ACTIONS(4042),
    [anon_sym_async] = ACTIONS(4042),
    [anon_sym_const] = ACTIONS(4042),
    [anon_sym_file] = ACTIONS(4042),
    [anon_sym_fixed] = ACTIONS(4042),
    [anon_sym_internal] = ACTIONS(4042),
    [anon_sym_new] = ACTIONS(4042),
    [anon_sym_override] = ACTIONS(4042),
    [anon_sym_partial] = ACTIONS(4042),
    [anon_sym_private] = ACTIONS(4042),
    [anon_sym_protected] = ACTIONS(4042),
    [anon_sym_public] = ACTIONS(4042),
    [anon_sym_readonly] = ACTIONS(4042),
    [anon_sym_required] = ACTIONS(4042),
    [anon_sym_sealed] = ACTIONS(4042),
    [anon_sym_virtual] = ACTIONS(4042),
    [anon_sym_volatile] = ACTIONS(4042),
    [anon_sym_where] = ACTIONS(4042),
    [anon_sym_notnull] = ACTIONS(4042),
    [anon_sym_unmanaged] = ACTIONS(4042),
    [anon_sym_scoped] = ACTIONS(4042),
    [anon_sym_var] = ACTIONS(4042),
    [sym_predefined_type] = ACTIONS(4042),
    [anon_sym_yield] = ACTIONS(4042),
    [anon_sym_when] = ACTIONS(4042),
    [anon_sym_from] = ACTIONS(4042),
    [anon_sym_into] = ACTIONS(4042),
    [anon_sym_join] = ACTIONS(4042),
    [anon_sym_on] = ACTIONS(4042),
    [anon_sym_equals] = ACTIONS(4042),
    [anon_sym_let] = ACTIONS(4042),
    [anon_sym_orderby] = ACTIONS(4042),
    [anon_sym_ascending] = ACTIONS(4042),
    [anon_sym_descending] = ACTIONS(4042),
    [anon_sym_group] = ACTIONS(4042),
    [anon_sym_by] = ACTIONS(4042),
    [anon_sym_select] = ACTIONS(4042),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4369] = {
    [sym_preproc_region] = STATE(4369),
    [sym_preproc_endregion] = STATE(4369),
    [sym_preproc_line] = STATE(4369),
    [sym_preproc_pragma] = STATE(4369),
    [sym_preproc_nullable] = STATE(4369),
    [sym_preproc_error] = STATE(4369),
    [sym_preproc_warning] = STATE(4369),
    [sym_preproc_define] = STATE(4369),
    [sym_preproc_undef] = STATE(4369),
    [anon_sym_EQ] = ACTIONS(6134),
    [anon_sym_LBRACK] = ACTIONS(5286),
    [anon_sym_LPAREN] = ACTIONS(5286),
    [anon_sym_LT] = ACTIONS(5288),
    [anon_sym_GT] = ACTIONS(5288),
    [anon_sym_QMARK] = ACTIONS(5288),
    [anon_sym_BANG] = ACTIONS(5288),
    [anon_sym_PLUS_PLUS] = ACTIONS(5286),
    [anon_sym_DASH_DASH] = ACTIONS(5286),
    [anon_sym_PLUS] = ACTIONS(5288),
    [anon_sym_DASH] = ACTIONS(5288),
    [anon_sym_STAR] = ACTIONS(5288),
    [anon_sym_SLASH] = ACTIONS(5288),
    [anon_sym_PERCENT] = ACTIONS(5288),
    [anon_sym_CARET] = ACTIONS(5288),
    [anon_sym_PIPE] = ACTIONS(5288),
    [anon_sym_AMP] = ACTIONS(5288),
    [anon_sym_LT_LT] = ACTIONS(5288),
    [anon_sym_GT_GT] = ACTIONS(5288),
    [anon_sym_GT_GT_GT] = ACTIONS(5288),
    [anon_sym_EQ_EQ] = ACTIONS(5286),
    [anon_sym_BANG_EQ] = ACTIONS(5286),
    [anon_sym_GT_EQ] = ACTIONS(5286),
    [anon_sym_LT_EQ] = ACTIONS(5286),
    [anon_sym_DOT] = ACTIONS(5288),
    [anon_sym_EQ_GT] = ACTIONS(5286),
    [anon_sym_switch] = ACTIONS(5286),
    [anon_sym_DOT_DOT] = ACTIONS(5286),
    [anon_sym_PLUS_EQ] = ACTIONS(6136),
    [anon_sym_DASH_EQ] = ACTIONS(6136),
    [anon_sym_STAR_EQ] = ACTIONS(6136),
    [anon_sym_SLASH_EQ] = ACTIONS(6136),
    [anon_sym_PERCENT_EQ] = ACTIONS(6136),
    [anon_sym_AMP_EQ] = ACTIONS(6136),
    [anon_sym_CARET_EQ] = ACTIONS(6136),
    [anon_sym_PIPE_EQ] = ACTIONS(6136),
    [anon_sym_LT_LT_EQ] = ACTIONS(6136),
    [anon_sym_GT_GT_EQ] = ACTIONS(6136),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(6136),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(6136),
    [anon_sym_AMP_AMP] = ACTIONS(5286),
    [anon_sym_PIPE_PIPE] = ACTIONS(5286),
    [anon_sym_QMARK_QMARK] = ACTIONS(5288),
    [anon_sym_into] = ACTIONS(5286),
    [anon_sym_as] = ACTIONS(5286),
    [anon_sym_is] = ACTIONS(5286),
    [anon_sym_DASH_GT] = ACTIONS(5286),
    [anon_sym_with] = ACTIONS(5286),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4370] = {
    [sym_block] = STATE(2662),
    [sym_preproc_region] = STATE(4370),
    [sym_preproc_endregion] = STATE(4370),
    [sym_preproc_line] = STATE(4370),
    [sym_preproc_pragma] = STATE(4370),
    [sym_preproc_nullable] = STATE(4370),
    [sym_preproc_error] = STATE(4370),
    [sym_preproc_warning] = STATE(4370),
    [sym_preproc_define] = STATE(4370),
    [sym_preproc_undef] = STATE(4370),
    [sym__identifier_token] = ACTIONS(4042),
    [anon_sym_extern] = ACTIONS(4042),
    [anon_sym_alias] = ACTIONS(4042),
    [anon_sym_global] = ACTIONS(4042),
    [anon_sym_unsafe] = ACTIONS(4042),
    [anon_sym_static] = ACTIONS(4042),
    [anon_sym_LPAREN] = ACTIONS(5474),
    [anon_sym_ref] = ACTIONS(4042),
    [anon_sym_LBRACE] = ACTIONS(6138),
    [anon_sym_delegate] = ACTIONS(4042),
    [anon_sym_abstract] = ACTIONS(4042),
    [anon_sym_async] = ACTIONS(4042),
    [anon_sym_const] = ACTIONS(4042),
    [anon_sym_file] = ACTIONS(4042),
    [anon_sym_fixed] = ACTIONS(4042),
    [anon_sym_internal] = ACTIONS(4042),
    [anon_sym_new] = ACTIONS(4042),
    [anon_sym_override] = ACTIONS(4042),
    [anon_sym_partial] = ACTIONS(4042),
    [anon_sym_private] = ACTIONS(4042),
    [anon_sym_protected] = ACTIONS(4042),
    [anon_sym_public] = ACTIONS(4042),
    [anon_sym_readonly] = ACTIONS(4042),
    [anon_sym_required] = ACTIONS(4042),
    [anon_sym_sealed] = ACTIONS(4042),
    [anon_sym_virtual] = ACTIONS(4042),
    [anon_sym_volatile] = ACTIONS(4042),
    [anon_sym_where] = ACTIONS(4042),
    [anon_sym_notnull] = ACTIONS(4042),
    [anon_sym_unmanaged] = ACTIONS(4042),
    [anon_sym_scoped] = ACTIONS(4042),
    [anon_sym_var] = ACTIONS(4042),
    [sym_predefined_type] = ACTIONS(4042),
    [anon_sym_yield] = ACTIONS(4042),
    [anon_sym_when] = ACTIONS(4042),
    [anon_sym_from] = ACTIONS(4042),
    [anon_sym_into] = ACTIONS(4042),
    [anon_sym_join] = ACTIONS(4042),
    [anon_sym_on] = ACTIONS(4042),
    [anon_sym_equals] = ACTIONS(4042),
    [anon_sym_let] = ACTIONS(4042),
    [anon_sym_orderby] = ACTIONS(4042),
    [anon_sym_ascending] = ACTIONS(4042),
    [anon_sym_descending] = ACTIONS(4042),
    [anon_sym_group] = ACTIONS(4042),
    [anon_sym_by] = ACTIONS(4042),
    [anon_sym_select] = ACTIONS(4042),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4371] = {
    [sym_tuple_pattern] = STATE(8499),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7206),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8977),
    [sym_identifier] = STATE(6767),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4371),
    [sym_preproc_endregion] = STATE(4371),
    [sym_preproc_line] = STATE(4371),
    [sym_preproc_pragma] = STATE(4371),
    [sym_preproc_nullable] = STATE(4371),
    [sym_preproc_error] = STATE(4371),
    [sym_preproc_warning] = STATE(4371),
    [sym_preproc_define] = STATE(4371),
    [sym_preproc_undef] = STATE(4371),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(5319),
    [anon_sym_ref] = ACTIONS(4078),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(6140),
    [anon_sym_var] = ACTIONS(5369),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [sym_discard] = ACTIONS(5323),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4372] = {
    [sym_argument_list] = STATE(3576),
    [sym__name] = STATE(4958),
    [sym_alias_qualified_name] = STATE(3588),
    [sym__simple_name] = STATE(3588),
    [sym_qualified_name] = STATE(3588),
    [sym_generic_name] = STATE(3597),
    [sym_type] = STATE(3557),
    [sym_implicit_type] = STATE(3596),
    [sym_array_type] = STATE(4853),
    [sym__array_base_type] = STATE(8805),
    [sym_nullable_type] = STATE(3612),
    [sym_pointer_type] = STATE(3612),
    [sym__pointer_base_type] = STATE(9071),
    [sym_function_pointer_type] = STATE(3612),
    [sym_ref_type] = STATE(3596),
    [sym_scoped_type] = STATE(3596),
    [sym_tuple_type] = STATE(3621),
    [sym_identifier] = STATE(4574),
    [sym__reserved_identifier] = STATE(3572),
    [sym_preproc_region] = STATE(4372),
    [sym_preproc_endregion] = STATE(4372),
    [sym_preproc_line] = STATE(4372),
    [sym_preproc_pragma] = STATE(4372),
    [sym_preproc_nullable] = STATE(4372),
    [sym_preproc_error] = STATE(4372),
    [sym_preproc_warning] = STATE(4372),
    [sym_preproc_define] = STATE(4372),
    [sym_preproc_undef] = STATE(4372),
    [sym__identifier_token] = ACTIONS(4328),
    [anon_sym_alias] = ACTIONS(4330),
    [anon_sym_global] = ACTIONS(4330),
    [anon_sym_LBRACK] = ACTIONS(6142),
    [anon_sym_LPAREN] = ACTIONS(6144),
    [anon_sym_ref] = ACTIONS(4693),
    [anon_sym_LBRACE] = ACTIONS(6146),
    [anon_sym_delegate] = ACTIONS(6148),
    [anon_sym_file] = ACTIONS(4330),
    [anon_sym_where] = ACTIONS(4330),
    [anon_sym_notnull] = ACTIONS(4330),
    [anon_sym_unmanaged] = ACTIONS(4330),
    [anon_sym_scoped] = ACTIONS(6150),
    [anon_sym_var] = ACTIONS(6152),
    [sym_predefined_type] = ACTIONS(6154),
    [anon_sym_yield] = ACTIONS(4330),
    [anon_sym_when] = ACTIONS(4330),
    [anon_sym_from] = ACTIONS(4330),
    [anon_sym_into] = ACTIONS(4330),
    [anon_sym_join] = ACTIONS(4330),
    [anon_sym_on] = ACTIONS(4330),
    [anon_sym_equals] = ACTIONS(4330),
    [anon_sym_let] = ACTIONS(4330),
    [anon_sym_orderby] = ACTIONS(4330),
    [anon_sym_ascending] = ACTIONS(4330),
    [anon_sym_descending] = ACTIONS(4330),
    [anon_sym_group] = ACTIONS(4330),
    [anon_sym_by] = ACTIONS(4330),
    [anon_sym_select] = ACTIONS(4330),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4373] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4373),
    [sym_preproc_endregion] = STATE(4373),
    [sym_preproc_line] = STATE(4373),
    [sym_preproc_pragma] = STATE(4373),
    [sym_preproc_nullable] = STATE(4373),
    [sym_preproc_error] = STATE(4373),
    [sym_preproc_warning] = STATE(4373),
    [sym_preproc_define] = STATE(4373),
    [sym_preproc_undef] = STATE(4373),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(5292),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(5294),
    [anon_sym_GT] = ACTIONS(5294),
    [anon_sym_where] = ACTIONS(5292),
    [anon_sym_QMARK] = ACTIONS(5294),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(5294),
    [anon_sym_DASH] = ACTIONS(5294),
    [anon_sym_STAR] = ACTIONS(5292),
    [anon_sym_SLASH] = ACTIONS(5294),
    [anon_sym_PERCENT] = ACTIONS(5292),
    [anon_sym_CARET] = ACTIONS(5292),
    [anon_sym_PIPE] = ACTIONS(5294),
    [anon_sym_AMP] = ACTIONS(5294),
    [anon_sym_LT_LT] = ACTIONS(5292),
    [anon_sym_GT_GT] = ACTIONS(5294),
    [anon_sym_GT_GT_GT] = ACTIONS(5292),
    [anon_sym_EQ_EQ] = ACTIONS(5292),
    [anon_sym_BANG_EQ] = ACTIONS(5292),
    [anon_sym_GT_EQ] = ACTIONS(5292),
    [anon_sym_LT_EQ] = ACTIONS(5292),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(5292),
    [anon_sym_DOT_DOT] = ACTIONS(5292),
    [anon_sym_and] = ACTIONS(5292),
    [anon_sym_or] = ACTIONS(5294),
    [anon_sym_AMP_AMP] = ACTIONS(5292),
    [anon_sym_PIPE_PIPE] = ACTIONS(5292),
    [anon_sym_QMARK_QMARK] = ACTIONS(5292),
    [anon_sym_from] = ACTIONS(5292),
    [anon_sym_into] = ACTIONS(5292),
    [anon_sym_join] = ACTIONS(5292),
    [anon_sym_let] = ACTIONS(5292),
    [anon_sym_orderby] = ACTIONS(5292),
    [anon_sym_ascending] = ACTIONS(5292),
    [anon_sym_descending] = ACTIONS(5292),
    [anon_sym_group] = ACTIONS(5292),
    [anon_sym_select] = ACTIONS(5292),
    [anon_sym_as] = ACTIONS(5294),
    [anon_sym_is] = ACTIONS(5292),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(5292),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4374] = {
    [sym_argument_list] = STATE(3920),
    [sym__name] = STATE(6204),
    [sym_alias_qualified_name] = STATE(4085),
    [sym__simple_name] = STATE(4085),
    [sym_qualified_name] = STATE(4085),
    [sym_generic_name] = STATE(3959),
    [sym_type] = STATE(3834),
    [sym_implicit_type] = STATE(4031),
    [sym_array_type] = STATE(6065),
    [sym__array_base_type] = STATE(8941),
    [sym_nullable_type] = STATE(3961),
    [sym_pointer_type] = STATE(3961),
    [sym__pointer_base_type] = STATE(9806),
    [sym_function_pointer_type] = STATE(3961),
    [sym_ref_type] = STATE(4031),
    [sym_scoped_type] = STATE(4031),
    [sym_tuple_type] = STATE(3962),
    [sym_identifier] = STATE(5502),
    [sym__reserved_identifier] = STATE(3911),
    [sym_preproc_region] = STATE(4374),
    [sym_preproc_endregion] = STATE(4374),
    [sym_preproc_line] = STATE(4374),
    [sym_preproc_pragma] = STATE(4374),
    [sym_preproc_nullable] = STATE(4374),
    [sym_preproc_error] = STATE(4374),
    [sym_preproc_warning] = STATE(4374),
    [sym_preproc_define] = STATE(4374),
    [sym_preproc_undef] = STATE(4374),
    [sym__identifier_token] = ACTIONS(4248),
    [anon_sym_alias] = ACTIONS(4250),
    [anon_sym_global] = ACTIONS(4250),
    [anon_sym_LBRACK] = ACTIONS(6162),
    [anon_sym_LPAREN] = ACTIONS(6164),
    [anon_sym_ref] = ACTIONS(4542),
    [anon_sym_LBRACE] = ACTIONS(6166),
    [anon_sym_delegate] = ACTIONS(6168),
    [anon_sym_file] = ACTIONS(4250),
    [anon_sym_where] = ACTIONS(4250),
    [anon_sym_notnull] = ACTIONS(4250),
    [anon_sym_unmanaged] = ACTIONS(4250),
    [anon_sym_scoped] = ACTIONS(6170),
    [anon_sym_var] = ACTIONS(6172),
    [sym_predefined_type] = ACTIONS(6174),
    [anon_sym_yield] = ACTIONS(4250),
    [anon_sym_when] = ACTIONS(4250),
    [anon_sym_from] = ACTIONS(4250),
    [anon_sym_into] = ACTIONS(4250),
    [anon_sym_join] = ACTIONS(4250),
    [anon_sym_on] = ACTIONS(4250),
    [anon_sym_equals] = ACTIONS(4250),
    [anon_sym_let] = ACTIONS(4250),
    [anon_sym_orderby] = ACTIONS(4250),
    [anon_sym_ascending] = ACTIONS(4250),
    [anon_sym_descending] = ACTIONS(4250),
    [anon_sym_group] = ACTIONS(4250),
    [anon_sym_by] = ACTIONS(4250),
    [anon_sym_select] = ACTIONS(4250),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4375] = {
    [sym_argument_list] = STATE(3863),
    [sym__name] = STATE(3904),
    [sym_alias_qualified_name] = STATE(3924),
    [sym__simple_name] = STATE(3924),
    [sym_qualified_name] = STATE(3924),
    [sym_generic_name] = STATE(3900),
    [sym_type] = STATE(3806),
    [sym_implicit_type] = STATE(3943),
    [sym_array_type] = STATE(3866),
    [sym__array_base_type] = STATE(8893),
    [sym_nullable_type] = STATE(3885),
    [sym_pointer_type] = STATE(3885),
    [sym__pointer_base_type] = STATE(9659),
    [sym_function_pointer_type] = STATE(3885),
    [sym_ref_type] = STATE(3943),
    [sym_scoped_type] = STATE(3943),
    [sym_tuple_type] = STATE(3880),
    [sym_identifier] = STATE(3808),
    [sym__reserved_identifier] = STATE(3871),
    [sym_preproc_region] = STATE(4375),
    [sym_preproc_endregion] = STATE(4375),
    [sym_preproc_line] = STATE(4375),
    [sym_preproc_pragma] = STATE(4375),
    [sym_preproc_nullable] = STATE(4375),
    [sym_preproc_error] = STATE(4375),
    [sym_preproc_warning] = STATE(4375),
    [sym_preproc_define] = STATE(4375),
    [sym_preproc_undef] = STATE(4375),
    [sym__identifier_token] = ACTIONS(4223),
    [anon_sym_alias] = ACTIONS(4225),
    [anon_sym_global] = ACTIONS(4225),
    [anon_sym_LBRACK] = ACTIONS(6176),
    [anon_sym_LPAREN] = ACTIONS(6178),
    [anon_sym_ref] = ACTIONS(4227),
    [anon_sym_LBRACE] = ACTIONS(6180),
    [anon_sym_delegate] = ACTIONS(6182),
    [anon_sym_file] = ACTIONS(4225),
    [anon_sym_where] = ACTIONS(4225),
    [anon_sym_notnull] = ACTIONS(4225),
    [anon_sym_unmanaged] = ACTIONS(4225),
    [anon_sym_scoped] = ACTIONS(6184),
    [anon_sym_var] = ACTIONS(6186),
    [sym_predefined_type] = ACTIONS(6188),
    [anon_sym_yield] = ACTIONS(4225),
    [anon_sym_when] = ACTIONS(4225),
    [anon_sym_from] = ACTIONS(4225),
    [anon_sym_into] = ACTIONS(4225),
    [anon_sym_join] = ACTIONS(4225),
    [anon_sym_on] = ACTIONS(4225),
    [anon_sym_equals] = ACTIONS(4225),
    [anon_sym_let] = ACTIONS(4225),
    [anon_sym_orderby] = ACTIONS(4225),
    [anon_sym_ascending] = ACTIONS(4225),
    [anon_sym_descending] = ACTIONS(4225),
    [anon_sym_group] = ACTIONS(4225),
    [anon_sym_by] = ACTIONS(4225),
    [anon_sym_select] = ACTIONS(4225),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4376] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4376),
    [sym_preproc_endregion] = STATE(4376),
    [sym_preproc_line] = STATE(4376),
    [sym_preproc_pragma] = STATE(4376),
    [sym_preproc_nullable] = STATE(4376),
    [sym_preproc_error] = STATE(4376),
    [sym_preproc_warning] = STATE(4376),
    [sym_preproc_define] = STATE(4376),
    [sym_preproc_undef] = STATE(4376),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(6190),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(6192),
    [anon_sym_GT] = ACTIONS(6192),
    [anon_sym_where] = ACTIONS(6190),
    [anon_sym_QMARK] = ACTIONS(6194),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(6196),
    [anon_sym_DASH] = ACTIONS(6196),
    [anon_sym_STAR] = ACTIONS(6198),
    [anon_sym_SLASH] = ACTIONS(6200),
    [anon_sym_PERCENT] = ACTIONS(6198),
    [anon_sym_CARET] = ACTIONS(6202),
    [anon_sym_PIPE] = ACTIONS(6204),
    [anon_sym_AMP] = ACTIONS(6206),
    [anon_sym_LT_LT] = ACTIONS(6208),
    [anon_sym_GT_GT] = ACTIONS(6210),
    [anon_sym_GT_GT_GT] = ACTIONS(6208),
    [anon_sym_EQ_EQ] = ACTIONS(6212),
    [anon_sym_BANG_EQ] = ACTIONS(6212),
    [anon_sym_GT_EQ] = ACTIONS(6214),
    [anon_sym_LT_EQ] = ACTIONS(6214),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(6216),
    [anon_sym_DOT_DOT] = ACTIONS(6218),
    [anon_sym_and] = ACTIONS(6190),
    [anon_sym_or] = ACTIONS(6220),
    [anon_sym_AMP_AMP] = ACTIONS(6222),
    [anon_sym_PIPE_PIPE] = ACTIONS(6224),
    [anon_sym_QMARK_QMARK] = ACTIONS(6226),
    [anon_sym_from] = ACTIONS(6190),
    [anon_sym_into] = ACTIONS(6190),
    [anon_sym_join] = ACTIONS(6190),
    [anon_sym_let] = ACTIONS(6190),
    [anon_sym_orderby] = ACTIONS(6190),
    [anon_sym_ascending] = ACTIONS(6190),
    [anon_sym_descending] = ACTIONS(6190),
    [anon_sym_group] = ACTIONS(6190),
    [anon_sym_select] = ACTIONS(6190),
    [anon_sym_as] = ACTIONS(6228),
    [anon_sym_is] = ACTIONS(6230),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(6232),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4377] = {
    [sym_initializer_expression] = STATE(4621),
    [sym_preproc_region] = STATE(4377),
    [sym_preproc_endregion] = STATE(4377),
    [sym_preproc_line] = STATE(4377),
    [sym_preproc_pragma] = STATE(4377),
    [sym_preproc_nullable] = STATE(4377),
    [sym_preproc_error] = STATE(4377),
    [sym_preproc_warning] = STATE(4377),
    [sym_preproc_define] = STATE(4377),
    [sym_preproc_undef] = STATE(4377),
    [anon_sym_LBRACK] = ACTIONS(5298),
    [anon_sym_COMMA] = ACTIONS(5296),
    [anon_sym_LPAREN] = ACTIONS(5296),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_LT] = ACTIONS(5301),
    [anon_sym_GT] = ACTIONS(5301),
    [anon_sym_where] = ACTIONS(5296),
    [anon_sym_QMARK] = ACTIONS(5301),
    [anon_sym_BANG] = ACTIONS(5301),
    [anon_sym_PLUS_PLUS] = ACTIONS(5296),
    [anon_sym_DASH_DASH] = ACTIONS(5296),
    [anon_sym_PLUS] = ACTIONS(5301),
    [anon_sym_DASH] = ACTIONS(5301),
    [anon_sym_STAR] = ACTIONS(5296),
    [anon_sym_SLASH] = ACTIONS(5301),
    [anon_sym_PERCENT] = ACTIONS(5296),
    [anon_sym_CARET] = ACTIONS(5296),
    [anon_sym_PIPE] = ACTIONS(5301),
    [anon_sym_AMP] = ACTIONS(5301),
    [anon_sym_LT_LT] = ACTIONS(5296),
    [anon_sym_GT_GT] = ACTIONS(5301),
    [anon_sym_GT_GT_GT] = ACTIONS(5296),
    [anon_sym_EQ_EQ] = ACTIONS(5296),
    [anon_sym_BANG_EQ] = ACTIONS(5296),
    [anon_sym_GT_EQ] = ACTIONS(5296),
    [anon_sym_LT_EQ] = ACTIONS(5296),
    [anon_sym_DOT] = ACTIONS(5301),
    [anon_sym_switch] = ACTIONS(5296),
    [anon_sym_DOT_DOT] = ACTIONS(5296),
    [anon_sym_and] = ACTIONS(5296),
    [anon_sym_or] = ACTIONS(5301),
    [anon_sym_AMP_AMP] = ACTIONS(5296),
    [anon_sym_PIPE_PIPE] = ACTIONS(5296),
    [anon_sym_QMARK_QMARK] = ACTIONS(5296),
    [anon_sym_from] = ACTIONS(5296),
    [anon_sym_into] = ACTIONS(5296),
    [anon_sym_join] = ACTIONS(5296),
    [anon_sym_let] = ACTIONS(5296),
    [anon_sym_orderby] = ACTIONS(5296),
    [anon_sym_ascending] = ACTIONS(5296),
    [anon_sym_descending] = ACTIONS(5296),
    [anon_sym_group] = ACTIONS(5296),
    [anon_sym_select] = ACTIONS(5296),
    [anon_sym_as] = ACTIONS(5301),
    [anon_sym_is] = ACTIONS(5296),
    [anon_sym_DASH_GT] = ACTIONS(5296),
    [anon_sym_with] = ACTIONS(5296),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4378] = {
    [sym_preproc_region] = STATE(4378),
    [sym_preproc_endregion] = STATE(4378),
    [sym_preproc_line] = STATE(4378),
    [sym_preproc_pragma] = STATE(4378),
    [sym_preproc_nullable] = STATE(4378),
    [sym_preproc_error] = STATE(4378),
    [sym_preproc_warning] = STATE(4378),
    [sym_preproc_define] = STATE(4378),
    [sym_preproc_undef] = STATE(4378),
    [anon_sym_EQ] = ACTIONS(6234),
    [anon_sym_LBRACK] = ACTIONS(5286),
    [anon_sym_LPAREN] = ACTIONS(5286),
    [anon_sym_LT] = ACTIONS(5288),
    [anon_sym_GT] = ACTIONS(5288),
    [anon_sym_QMARK] = ACTIONS(5288),
    [anon_sym_BANG] = ACTIONS(5288),
    [anon_sym_PLUS_PLUS] = ACTIONS(5286),
    [anon_sym_DASH_DASH] = ACTIONS(5286),
    [anon_sym_PLUS] = ACTIONS(5288),
    [anon_sym_DASH] = ACTIONS(5288),
    [anon_sym_STAR] = ACTIONS(5288),
    [anon_sym_SLASH] = ACTIONS(5288),
    [anon_sym_PERCENT] = ACTIONS(5288),
    [anon_sym_CARET] = ACTIONS(5288),
    [anon_sym_PIPE] = ACTIONS(5288),
    [anon_sym_AMP] = ACTIONS(5288),
    [anon_sym_LT_LT] = ACTIONS(5288),
    [anon_sym_GT_GT] = ACTIONS(5288),
    [anon_sym_GT_GT_GT] = ACTIONS(5288),
    [anon_sym_EQ_EQ] = ACTIONS(5286),
    [anon_sym_BANG_EQ] = ACTIONS(5286),
    [anon_sym_GT_EQ] = ACTIONS(5286),
    [anon_sym_LT_EQ] = ACTIONS(5286),
    [anon_sym_DOT] = ACTIONS(5288),
    [anon_sym_switch] = ACTIONS(5286),
    [anon_sym_DOT_DOT] = ACTIONS(5286),
    [anon_sym_PLUS_EQ] = ACTIONS(6236),
    [anon_sym_DASH_EQ] = ACTIONS(6236),
    [anon_sym_STAR_EQ] = ACTIONS(6236),
    [anon_sym_SLASH_EQ] = ACTIONS(6236),
    [anon_sym_PERCENT_EQ] = ACTIONS(6236),
    [anon_sym_AMP_EQ] = ACTIONS(6236),
    [anon_sym_CARET_EQ] = ACTIONS(6236),
    [anon_sym_PIPE_EQ] = ACTIONS(6236),
    [anon_sym_LT_LT_EQ] = ACTIONS(6236),
    [anon_sym_GT_GT_EQ] = ACTIONS(6236),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(6236),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(6236),
    [anon_sym_AMP_AMP] = ACTIONS(5286),
    [anon_sym_PIPE_PIPE] = ACTIONS(5286),
    [anon_sym_QMARK_QMARK] = ACTIONS(5288),
    [anon_sym_into] = ACTIONS(5286),
    [anon_sym_by] = ACTIONS(5286),
    [anon_sym_as] = ACTIONS(5286),
    [anon_sym_is] = ACTIONS(5286),
    [anon_sym_DASH_GT] = ACTIONS(5286),
    [anon_sym_with] = ACTIONS(5286),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4379] = {
    [sym_argument_list] = STATE(4446),
    [sym__name] = STATE(2992),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2956),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2944),
    [sym_type] = STATE(4361),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(4405),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_identifier] = STATE(2920),
    [sym__reserved_identifier] = STATE(2928),
    [sym_preproc_region] = STATE(4379),
    [sym_preproc_endregion] = STATE(4379),
    [sym_preproc_line] = STATE(4379),
    [sym_preproc_pragma] = STATE(4379),
    [sym_preproc_nullable] = STATE(4379),
    [sym_preproc_error] = STATE(4379),
    [sym_preproc_warning] = STATE(4379),
    [sym_preproc_define] = STATE(4379),
    [sym_preproc_undef] = STATE(4379),
    [sym__identifier_token] = ACTIONS(4536),
    [anon_sym_alias] = ACTIONS(4538),
    [anon_sym_global] = ACTIONS(4538),
    [anon_sym_LBRACK] = ACTIONS(6238),
    [anon_sym_LPAREN] = ACTIONS(6240),
    [anon_sym_ref] = ACTIONS(4632),
    [anon_sym_LBRACE] = ACTIONS(6242),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_file] = ACTIONS(4538),
    [anon_sym_where] = ACTIONS(4538),
    [anon_sym_notnull] = ACTIONS(4538),
    [anon_sym_unmanaged] = ACTIONS(4538),
    [anon_sym_scoped] = ACTIONS(6244),
    [anon_sym_var] = ACTIONS(6246),
    [sym_predefined_type] = ACTIONS(6248),
    [anon_sym_yield] = ACTIONS(4538),
    [anon_sym_when] = ACTIONS(4538),
    [anon_sym_from] = ACTIONS(4538),
    [anon_sym_into] = ACTIONS(4538),
    [anon_sym_join] = ACTIONS(4538),
    [anon_sym_on] = ACTIONS(4538),
    [anon_sym_equals] = ACTIONS(4538),
    [anon_sym_let] = ACTIONS(4538),
    [anon_sym_orderby] = ACTIONS(4538),
    [anon_sym_ascending] = ACTIONS(4538),
    [anon_sym_descending] = ACTIONS(4538),
    [anon_sym_group] = ACTIONS(4538),
    [anon_sym_by] = ACTIONS(4538),
    [anon_sym_select] = ACTIONS(4538),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4380] = {
    [sym__name] = STATE(7943),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(8590),
    [sym_implicit_type] = STATE(8787),
    [sym_array_type] = STATE(8347),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9367),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(8787),
    [sym_scoped_type] = STATE(8787),
    [sym_tuple_type] = STATE(8173),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4380),
    [sym_preproc_endregion] = STATE(4380),
    [sym_preproc_line] = STATE(4380),
    [sym_preproc_pragma] = STATE(4380),
    [sym_preproc_nullable] = STATE(4380),
    [sym_preproc_error] = STATE(4380),
    [sym_preproc_warning] = STATE(4380),
    [sym_preproc_define] = STATE(4380),
    [sym_preproc_undef] = STATE(4380),
    [aux_sym_type_argument_list_repeat1] = STATE(8591),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_COMMA] = ACTIONS(5743),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(5745),
    [anon_sym_delegate] = ACTIONS(5747),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_GT] = ACTIONS(6250),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(5753),
    [anon_sym_var] = ACTIONS(5369),
    [sym_predefined_type] = ACTIONS(5755),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4381] = {
    [sym__name] = STATE(7943),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(8421),
    [sym_implicit_type] = STATE(8787),
    [sym_array_type] = STATE(8347),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9367),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(8787),
    [sym_scoped_type] = STATE(8787),
    [sym_tuple_type] = STATE(8173),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4381),
    [sym_preproc_endregion] = STATE(4381),
    [sym_preproc_line] = STATE(4381),
    [sym_preproc_pragma] = STATE(4381),
    [sym_preproc_nullable] = STATE(4381),
    [sym_preproc_error] = STATE(4381),
    [sym_preproc_warning] = STATE(4381),
    [sym_preproc_define] = STATE(4381),
    [sym_preproc_undef] = STATE(4381),
    [aux_sym_type_argument_list_repeat1] = STATE(8426),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_COMMA] = ACTIONS(5743),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(5745),
    [anon_sym_delegate] = ACTIONS(5747),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_GT] = ACTIONS(5749),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(5753),
    [anon_sym_var] = ACTIONS(5369),
    [sym_predefined_type] = ACTIONS(5755),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4382] = {
    [sym_argument_list] = STATE(3576),
    [sym__name] = STATE(4343),
    [sym_alias_qualified_name] = STATE(3588),
    [sym__simple_name] = STATE(3588),
    [sym_qualified_name] = STATE(3588),
    [sym_generic_name] = STATE(3597),
    [sym_type] = STATE(3557),
    [sym_implicit_type] = STATE(3596),
    [sym_array_type] = STATE(4151),
    [sym__array_base_type] = STATE(8805),
    [sym_nullable_type] = STATE(3612),
    [sym_pointer_type] = STATE(3612),
    [sym__pointer_base_type] = STATE(9071),
    [sym_function_pointer_type] = STATE(3612),
    [sym_ref_type] = STATE(3596),
    [sym_scoped_type] = STATE(3596),
    [sym_tuple_type] = STATE(3621),
    [sym_identifier] = STATE(4004),
    [sym__reserved_identifier] = STATE(3572),
    [sym_preproc_region] = STATE(4382),
    [sym_preproc_endregion] = STATE(4382),
    [sym_preproc_line] = STATE(4382),
    [sym_preproc_pragma] = STATE(4382),
    [sym_preproc_nullable] = STATE(4382),
    [sym_preproc_error] = STATE(4382),
    [sym_preproc_warning] = STATE(4382),
    [sym_preproc_define] = STATE(4382),
    [sym_preproc_undef] = STATE(4382),
    [sym__identifier_token] = ACTIONS(4328),
    [anon_sym_alias] = ACTIONS(4330),
    [anon_sym_global] = ACTIONS(4330),
    [anon_sym_LBRACK] = ACTIONS(6142),
    [anon_sym_LPAREN] = ACTIONS(6144),
    [anon_sym_ref] = ACTIONS(4332),
    [anon_sym_LBRACE] = ACTIONS(6146),
    [anon_sym_delegate] = ACTIONS(6148),
    [anon_sym_file] = ACTIONS(4330),
    [anon_sym_where] = ACTIONS(4330),
    [anon_sym_notnull] = ACTIONS(4330),
    [anon_sym_unmanaged] = ACTIONS(4330),
    [anon_sym_scoped] = ACTIONS(6252),
    [anon_sym_var] = ACTIONS(6152),
    [sym_predefined_type] = ACTIONS(6154),
    [anon_sym_yield] = ACTIONS(4330),
    [anon_sym_when] = ACTIONS(4330),
    [anon_sym_from] = ACTIONS(4330),
    [anon_sym_into] = ACTIONS(4330),
    [anon_sym_join] = ACTIONS(4330),
    [anon_sym_on] = ACTIONS(4330),
    [anon_sym_equals] = ACTIONS(4330),
    [anon_sym_let] = ACTIONS(4330),
    [anon_sym_orderby] = ACTIONS(4330),
    [anon_sym_ascending] = ACTIONS(4330),
    [anon_sym_descending] = ACTIONS(4330),
    [anon_sym_group] = ACTIONS(4330),
    [anon_sym_by] = ACTIONS(4330),
    [anon_sym_select] = ACTIONS(4330),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4383] = {
    [sym_argument_list] = STATE(3594),
    [sym__name] = STATE(3744),
    [sym_alias_qualified_name] = STATE(3680),
    [sym__simple_name] = STATE(3680),
    [sym_qualified_name] = STATE(3680),
    [sym_generic_name] = STATE(3648),
    [sym_type] = STATE(4138),
    [sym_implicit_type] = STATE(3707),
    [sym_array_type] = STATE(3586),
    [sym__array_base_type] = STATE(8829),
    [sym_nullable_type] = STATE(3681),
    [sym_pointer_type] = STATE(3681),
    [sym__pointer_base_type] = STATE(9538),
    [sym_function_pointer_type] = STATE(3681),
    [sym_ref_type] = STATE(3707),
    [sym_scoped_type] = STATE(3707),
    [sym_tuple_type] = STATE(3631),
    [sym_identifier] = STATE(3590),
    [sym__reserved_identifier] = STATE(3625),
    [sym_preproc_region] = STATE(4383),
    [sym_preproc_endregion] = STATE(4383),
    [sym_preproc_line] = STATE(4383),
    [sym_preproc_pragma] = STATE(4383),
    [sym_preproc_nullable] = STATE(4383),
    [sym_preproc_error] = STATE(4383),
    [sym_preproc_warning] = STATE(4383),
    [sym_preproc_define] = STATE(4383),
    [sym_preproc_undef] = STATE(4383),
    [sym__identifier_token] = ACTIONS(4349),
    [anon_sym_alias] = ACTIONS(4351),
    [anon_sym_global] = ACTIONS(4351),
    [anon_sym_LBRACK] = ACTIONS(4506),
    [anon_sym_LPAREN] = ACTIONS(4508),
    [anon_sym_ref] = ACTIONS(4729),
    [anon_sym_LBRACE] = ACTIONS(4510),
    [anon_sym_delegate] = ACTIONS(4512),
    [anon_sym_file] = ACTIONS(4351),
    [anon_sym_where] = ACTIONS(4351),
    [anon_sym_notnull] = ACTIONS(4351),
    [anon_sym_unmanaged] = ACTIONS(4351),
    [anon_sym_scoped] = ACTIONS(6254),
    [anon_sym_var] = ACTIONS(4516),
    [sym_predefined_type] = ACTIONS(4518),
    [anon_sym_yield] = ACTIONS(4351),
    [anon_sym_when] = ACTIONS(4351),
    [anon_sym_from] = ACTIONS(4351),
    [anon_sym_into] = ACTIONS(4351),
    [anon_sym_join] = ACTIONS(4351),
    [anon_sym_on] = ACTIONS(4351),
    [anon_sym_equals] = ACTIONS(4351),
    [anon_sym_let] = ACTIONS(4351),
    [anon_sym_orderby] = ACTIONS(4351),
    [anon_sym_ascending] = ACTIONS(4351),
    [anon_sym_descending] = ACTIONS(4351),
    [anon_sym_group] = ACTIONS(4351),
    [anon_sym_by] = ACTIONS(4351),
    [anon_sym_select] = ACTIONS(4351),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4384] = {
    [sym_preproc_region] = STATE(4384),
    [sym_preproc_endregion] = STATE(4384),
    [sym_preproc_line] = STATE(4384),
    [sym_preproc_pragma] = STATE(4384),
    [sym_preproc_nullable] = STATE(4384),
    [sym_preproc_error] = STATE(4384),
    [sym_preproc_warning] = STATE(4384),
    [sym_preproc_define] = STATE(4384),
    [sym_preproc_undef] = STATE(4384),
    [anon_sym_EQ] = ACTIONS(5998),
    [anon_sym_LBRACK] = ACTIONS(5286),
    [anon_sym_COMMA] = ACTIONS(5286),
    [anon_sym_LPAREN] = ACTIONS(5286),
    [anon_sym_RPAREN] = ACTIONS(6256),
    [anon_sym_LT] = ACTIONS(5288),
    [anon_sym_GT] = ACTIONS(5288),
    [anon_sym_QMARK] = ACTIONS(5288),
    [anon_sym_BANG] = ACTIONS(5288),
    [anon_sym_PLUS_PLUS] = ACTIONS(5286),
    [anon_sym_DASH_DASH] = ACTIONS(5286),
    [anon_sym_PLUS] = ACTIONS(5288),
    [anon_sym_DASH] = ACTIONS(5288),
    [anon_sym_STAR] = ACTIONS(5288),
    [anon_sym_SLASH] = ACTIONS(5288),
    [anon_sym_PERCENT] = ACTIONS(5288),
    [anon_sym_CARET] = ACTIONS(5288),
    [anon_sym_PIPE] = ACTIONS(5288),
    [anon_sym_AMP] = ACTIONS(5288),
    [anon_sym_LT_LT] = ACTIONS(5288),
    [anon_sym_GT_GT] = ACTIONS(5288),
    [anon_sym_GT_GT_GT] = ACTIONS(5288),
    [anon_sym_EQ_EQ] = ACTIONS(5286),
    [anon_sym_BANG_EQ] = ACTIONS(5286),
    [anon_sym_GT_EQ] = ACTIONS(5286),
    [anon_sym_LT_EQ] = ACTIONS(5286),
    [anon_sym_DOT] = ACTIONS(5288),
    [anon_sym_switch] = ACTIONS(5286),
    [anon_sym_DOT_DOT] = ACTIONS(5286),
    [anon_sym_PLUS_EQ] = ACTIONS(6000),
    [anon_sym_DASH_EQ] = ACTIONS(6000),
    [anon_sym_STAR_EQ] = ACTIONS(6000),
    [anon_sym_SLASH_EQ] = ACTIONS(6000),
    [anon_sym_PERCENT_EQ] = ACTIONS(6000),
    [anon_sym_AMP_EQ] = ACTIONS(6000),
    [anon_sym_CARET_EQ] = ACTIONS(6000),
    [anon_sym_PIPE_EQ] = ACTIONS(6000),
    [anon_sym_LT_LT_EQ] = ACTIONS(6000),
    [anon_sym_GT_GT_EQ] = ACTIONS(6000),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(6000),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(6000),
    [anon_sym_AMP_AMP] = ACTIONS(5286),
    [anon_sym_PIPE_PIPE] = ACTIONS(5286),
    [anon_sym_QMARK_QMARK] = ACTIONS(5288),
    [anon_sym_as] = ACTIONS(5286),
    [anon_sym_is] = ACTIONS(5286),
    [anon_sym_DASH_GT] = ACTIONS(5286),
    [anon_sym_with] = ACTIONS(5286),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4385] = {
    [sym_argument_list] = STATE(3920),
    [sym__name] = STATE(4158),
    [sym_alias_qualified_name] = STATE(4085),
    [sym__simple_name] = STATE(4085),
    [sym_qualified_name] = STATE(4085),
    [sym_generic_name] = STATE(3959),
    [sym_type] = STATE(3834),
    [sym_implicit_type] = STATE(4031),
    [sym_array_type] = STATE(4039),
    [sym__array_base_type] = STATE(8941),
    [sym_nullable_type] = STATE(3961),
    [sym_pointer_type] = STATE(3961),
    [sym__pointer_base_type] = STATE(9806),
    [sym_function_pointer_type] = STATE(3961),
    [sym_ref_type] = STATE(4031),
    [sym_scoped_type] = STATE(4031),
    [sym_tuple_type] = STATE(3962),
    [sym_identifier] = STATE(3889),
    [sym__reserved_identifier] = STATE(3911),
    [sym_preproc_region] = STATE(4385),
    [sym_preproc_endregion] = STATE(4385),
    [sym_preproc_line] = STATE(4385),
    [sym_preproc_pragma] = STATE(4385),
    [sym_preproc_nullable] = STATE(4385),
    [sym_preproc_error] = STATE(4385),
    [sym_preproc_warning] = STATE(4385),
    [sym_preproc_define] = STATE(4385),
    [sym_preproc_undef] = STATE(4385),
    [sym__identifier_token] = ACTIONS(4248),
    [anon_sym_alias] = ACTIONS(4250),
    [anon_sym_global] = ACTIONS(4250),
    [anon_sym_LBRACK] = ACTIONS(6162),
    [anon_sym_LPAREN] = ACTIONS(6164),
    [anon_sym_ref] = ACTIONS(4658),
    [anon_sym_LBRACE] = ACTIONS(6166),
    [anon_sym_delegate] = ACTIONS(6168),
    [anon_sym_file] = ACTIONS(4250),
    [anon_sym_where] = ACTIONS(4250),
    [anon_sym_notnull] = ACTIONS(4250),
    [anon_sym_unmanaged] = ACTIONS(4250),
    [anon_sym_scoped] = ACTIONS(6258),
    [anon_sym_var] = ACTIONS(6172),
    [sym_predefined_type] = ACTIONS(6174),
    [anon_sym_yield] = ACTIONS(4250),
    [anon_sym_when] = ACTIONS(4250),
    [anon_sym_from] = ACTIONS(4250),
    [anon_sym_into] = ACTIONS(4250),
    [anon_sym_join] = ACTIONS(4250),
    [anon_sym_on] = ACTIONS(4250),
    [anon_sym_equals] = ACTIONS(4250),
    [anon_sym_let] = ACTIONS(4250),
    [anon_sym_orderby] = ACTIONS(4250),
    [anon_sym_ascending] = ACTIONS(4250),
    [anon_sym_descending] = ACTIONS(4250),
    [anon_sym_group] = ACTIONS(4250),
    [anon_sym_by] = ACTIONS(4250),
    [anon_sym_select] = ACTIONS(4250),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4386] = {
    [sym_preproc_region] = STATE(4386),
    [sym_preproc_endregion] = STATE(4386),
    [sym_preproc_line] = STATE(4386),
    [sym_preproc_pragma] = STATE(4386),
    [sym_preproc_nullable] = STATE(4386),
    [sym_preproc_error] = STATE(4386),
    [sym_preproc_warning] = STATE(4386),
    [sym_preproc_define] = STATE(4386),
    [sym_preproc_undef] = STATE(4386),
    [anon_sym_EQ] = ACTIONS(5998),
    [anon_sym_LBRACK] = ACTIONS(5286),
    [anon_sym_COMMA] = ACTIONS(5286),
    [anon_sym_LPAREN] = ACTIONS(5286),
    [anon_sym_RPAREN] = ACTIONS(6260),
    [anon_sym_LT] = ACTIONS(5288),
    [anon_sym_GT] = ACTIONS(5288),
    [anon_sym_QMARK] = ACTIONS(5288),
    [anon_sym_BANG] = ACTIONS(5288),
    [anon_sym_PLUS_PLUS] = ACTIONS(5286),
    [anon_sym_DASH_DASH] = ACTIONS(5286),
    [anon_sym_PLUS] = ACTIONS(5288),
    [anon_sym_DASH] = ACTIONS(5288),
    [anon_sym_STAR] = ACTIONS(5288),
    [anon_sym_SLASH] = ACTIONS(5288),
    [anon_sym_PERCENT] = ACTIONS(5288),
    [anon_sym_CARET] = ACTIONS(5288),
    [anon_sym_PIPE] = ACTIONS(5288),
    [anon_sym_AMP] = ACTIONS(5288),
    [anon_sym_LT_LT] = ACTIONS(5288),
    [anon_sym_GT_GT] = ACTIONS(5288),
    [anon_sym_GT_GT_GT] = ACTIONS(5288),
    [anon_sym_EQ_EQ] = ACTIONS(5286),
    [anon_sym_BANG_EQ] = ACTIONS(5286),
    [anon_sym_GT_EQ] = ACTIONS(5286),
    [anon_sym_LT_EQ] = ACTIONS(5286),
    [anon_sym_DOT] = ACTIONS(5288),
    [anon_sym_switch] = ACTIONS(5286),
    [anon_sym_DOT_DOT] = ACTIONS(5286),
    [anon_sym_PLUS_EQ] = ACTIONS(6000),
    [anon_sym_DASH_EQ] = ACTIONS(6000),
    [anon_sym_STAR_EQ] = ACTIONS(6000),
    [anon_sym_SLASH_EQ] = ACTIONS(6000),
    [anon_sym_PERCENT_EQ] = ACTIONS(6000),
    [anon_sym_AMP_EQ] = ACTIONS(6000),
    [anon_sym_CARET_EQ] = ACTIONS(6000),
    [anon_sym_PIPE_EQ] = ACTIONS(6000),
    [anon_sym_LT_LT_EQ] = ACTIONS(6000),
    [anon_sym_GT_GT_EQ] = ACTIONS(6000),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(6000),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(6000),
    [anon_sym_AMP_AMP] = ACTIONS(5286),
    [anon_sym_PIPE_PIPE] = ACTIONS(5286),
    [anon_sym_QMARK_QMARK] = ACTIONS(5288),
    [anon_sym_as] = ACTIONS(5286),
    [anon_sym_is] = ACTIONS(5286),
    [anon_sym_DASH_GT] = ACTIONS(5286),
    [anon_sym_with] = ACTIONS(5286),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4387] = {
    [sym_argument_list] = STATE(3863),
    [sym__name] = STATE(3904),
    [sym_alias_qualified_name] = STATE(3924),
    [sym__simple_name] = STATE(3924),
    [sym_qualified_name] = STATE(3924),
    [sym_generic_name] = STATE(3900),
    [sym_type] = STATE(3806),
    [sym_implicit_type] = STATE(3943),
    [sym_array_type] = STATE(3866),
    [sym__array_base_type] = STATE(8893),
    [sym_nullable_type] = STATE(3885),
    [sym_pointer_type] = STATE(3885),
    [sym__pointer_base_type] = STATE(9659),
    [sym_function_pointer_type] = STATE(3885),
    [sym_ref_type] = STATE(3943),
    [sym_scoped_type] = STATE(3943),
    [sym_tuple_type] = STATE(3880),
    [sym_identifier] = STATE(3808),
    [sym__reserved_identifier] = STATE(3871),
    [sym_preproc_region] = STATE(4387),
    [sym_preproc_endregion] = STATE(4387),
    [sym_preproc_line] = STATE(4387),
    [sym_preproc_pragma] = STATE(4387),
    [sym_preproc_nullable] = STATE(4387),
    [sym_preproc_error] = STATE(4387),
    [sym_preproc_warning] = STATE(4387),
    [sym_preproc_define] = STATE(4387),
    [sym_preproc_undef] = STATE(4387),
    [sym__identifier_token] = ACTIONS(4223),
    [anon_sym_alias] = ACTIONS(4225),
    [anon_sym_global] = ACTIONS(4225),
    [anon_sym_LBRACK] = ACTIONS(6176),
    [anon_sym_LPAREN] = ACTIONS(6178),
    [anon_sym_ref] = ACTIONS(4530),
    [anon_sym_LBRACE] = ACTIONS(6180),
    [anon_sym_delegate] = ACTIONS(6182),
    [anon_sym_file] = ACTIONS(4225),
    [anon_sym_where] = ACTIONS(4225),
    [anon_sym_notnull] = ACTIONS(4225),
    [anon_sym_unmanaged] = ACTIONS(4225),
    [anon_sym_scoped] = ACTIONS(6262),
    [anon_sym_var] = ACTIONS(6186),
    [sym_predefined_type] = ACTIONS(6188),
    [anon_sym_yield] = ACTIONS(4225),
    [anon_sym_when] = ACTIONS(4225),
    [anon_sym_from] = ACTIONS(4225),
    [anon_sym_into] = ACTIONS(4225),
    [anon_sym_join] = ACTIONS(4225),
    [anon_sym_on] = ACTIONS(4225),
    [anon_sym_equals] = ACTIONS(4225),
    [anon_sym_let] = ACTIONS(4225),
    [anon_sym_orderby] = ACTIONS(4225),
    [anon_sym_ascending] = ACTIONS(4225),
    [anon_sym_descending] = ACTIONS(4225),
    [anon_sym_group] = ACTIONS(4225),
    [anon_sym_by] = ACTIONS(4225),
    [anon_sym_select] = ACTIONS(4225),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4388] = {
    [sym_argument_list] = STATE(3576),
    [sym__name] = STATE(4343),
    [sym_alias_qualified_name] = STATE(3588),
    [sym__simple_name] = STATE(3588),
    [sym_qualified_name] = STATE(3588),
    [sym_generic_name] = STATE(3597),
    [sym_type] = STATE(3557),
    [sym_implicit_type] = STATE(3596),
    [sym_array_type] = STATE(4151),
    [sym__array_base_type] = STATE(8805),
    [sym_nullable_type] = STATE(3612),
    [sym_pointer_type] = STATE(3612),
    [sym__pointer_base_type] = STATE(9071),
    [sym_function_pointer_type] = STATE(3612),
    [sym_ref_type] = STATE(3596),
    [sym_scoped_type] = STATE(3596),
    [sym_tuple_type] = STATE(3621),
    [sym_identifier] = STATE(4004),
    [sym__reserved_identifier] = STATE(3572),
    [sym_preproc_region] = STATE(4388),
    [sym_preproc_endregion] = STATE(4388),
    [sym_preproc_line] = STATE(4388),
    [sym_preproc_pragma] = STATE(4388),
    [sym_preproc_nullable] = STATE(4388),
    [sym_preproc_error] = STATE(4388),
    [sym_preproc_warning] = STATE(4388),
    [sym_preproc_define] = STATE(4388),
    [sym_preproc_undef] = STATE(4388),
    [sym__identifier_token] = ACTIONS(4328),
    [anon_sym_alias] = ACTIONS(4330),
    [anon_sym_global] = ACTIONS(4330),
    [anon_sym_LBRACK] = ACTIONS(6142),
    [anon_sym_LPAREN] = ACTIONS(6144),
    [anon_sym_ref] = ACTIONS(4731),
    [anon_sym_LBRACE] = ACTIONS(6146),
    [anon_sym_delegate] = ACTIONS(6148),
    [anon_sym_file] = ACTIONS(4330),
    [anon_sym_where] = ACTIONS(4330),
    [anon_sym_notnull] = ACTIONS(4330),
    [anon_sym_unmanaged] = ACTIONS(4330),
    [anon_sym_scoped] = ACTIONS(6264),
    [anon_sym_var] = ACTIONS(6152),
    [sym_predefined_type] = ACTIONS(6154),
    [anon_sym_yield] = ACTIONS(4330),
    [anon_sym_when] = ACTIONS(4330),
    [anon_sym_from] = ACTIONS(4330),
    [anon_sym_into] = ACTIONS(4330),
    [anon_sym_join] = ACTIONS(4330),
    [anon_sym_on] = ACTIONS(4330),
    [anon_sym_equals] = ACTIONS(4330),
    [anon_sym_let] = ACTIONS(4330),
    [anon_sym_orderby] = ACTIONS(4330),
    [anon_sym_ascending] = ACTIONS(4330),
    [anon_sym_descending] = ACTIONS(4330),
    [anon_sym_group] = ACTIONS(4330),
    [anon_sym_by] = ACTIONS(4330),
    [anon_sym_select] = ACTIONS(4330),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4389] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4389),
    [sym_preproc_endregion] = STATE(4389),
    [sym_preproc_line] = STATE(4389),
    [sym_preproc_pragma] = STATE(4389),
    [sym_preproc_nullable] = STATE(4389),
    [sym_preproc_error] = STATE(4389),
    [sym_preproc_warning] = STATE(4389),
    [sym_preproc_define] = STATE(4389),
    [sym_preproc_undef] = STATE(4389),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(5325),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(5327),
    [anon_sym_GT] = ACTIONS(5327),
    [anon_sym_where] = ACTIONS(5325),
    [anon_sym_QMARK] = ACTIONS(5327),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(5327),
    [anon_sym_DASH] = ACTIONS(5327),
    [anon_sym_STAR] = ACTIONS(5325),
    [anon_sym_SLASH] = ACTIONS(5327),
    [anon_sym_PERCENT] = ACTIONS(5325),
    [anon_sym_CARET] = ACTIONS(5325),
    [anon_sym_PIPE] = ACTIONS(5327),
    [anon_sym_AMP] = ACTIONS(5327),
    [anon_sym_LT_LT] = ACTIONS(5325),
    [anon_sym_GT_GT] = ACTIONS(5327),
    [anon_sym_GT_GT_GT] = ACTIONS(5325),
    [anon_sym_EQ_EQ] = ACTIONS(5325),
    [anon_sym_BANG_EQ] = ACTIONS(5325),
    [anon_sym_GT_EQ] = ACTIONS(5325),
    [anon_sym_LT_EQ] = ACTIONS(5325),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(5325),
    [anon_sym_DOT_DOT] = ACTIONS(5325),
    [anon_sym_and] = ACTIONS(5325),
    [anon_sym_or] = ACTIONS(5327),
    [anon_sym_AMP_AMP] = ACTIONS(5325),
    [anon_sym_PIPE_PIPE] = ACTIONS(5325),
    [anon_sym_QMARK_QMARK] = ACTIONS(5325),
    [anon_sym_from] = ACTIONS(5325),
    [anon_sym_into] = ACTIONS(5325),
    [anon_sym_join] = ACTIONS(5325),
    [anon_sym_let] = ACTIONS(5325),
    [anon_sym_orderby] = ACTIONS(5325),
    [anon_sym_ascending] = ACTIONS(5325),
    [anon_sym_descending] = ACTIONS(5325),
    [anon_sym_group] = ACTIONS(5325),
    [anon_sym_select] = ACTIONS(5325),
    [anon_sym_as] = ACTIONS(5327),
    [anon_sym_is] = ACTIONS(5325),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(5325),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4390] = {
    [sym_block] = STATE(8905),
    [sym_preproc_region] = STATE(4390),
    [sym_preproc_endregion] = STATE(4390),
    [sym_preproc_line] = STATE(4390),
    [sym_preproc_pragma] = STATE(4390),
    [sym_preproc_nullable] = STATE(4390),
    [sym_preproc_error] = STATE(4390),
    [sym_preproc_warning] = STATE(4390),
    [sym_preproc_define] = STATE(4390),
    [sym_preproc_undef] = STATE(4390),
    [sym__identifier_token] = ACTIONS(4042),
    [anon_sym_extern] = ACTIONS(4042),
    [anon_sym_alias] = ACTIONS(4042),
    [anon_sym_global] = ACTIONS(4042),
    [anon_sym_unsafe] = ACTIONS(4042),
    [anon_sym_static] = ACTIONS(4042),
    [anon_sym_LPAREN] = ACTIONS(5474),
    [anon_sym_ref] = ACTIONS(4042),
    [anon_sym_LBRACE] = ACTIONS(6108),
    [anon_sym_delegate] = ACTIONS(4042),
    [anon_sym_abstract] = ACTIONS(4042),
    [anon_sym_async] = ACTIONS(4042),
    [anon_sym_const] = ACTIONS(4042),
    [anon_sym_file] = ACTIONS(4042),
    [anon_sym_fixed] = ACTIONS(4042),
    [anon_sym_internal] = ACTIONS(4042),
    [anon_sym_new] = ACTIONS(4042),
    [anon_sym_override] = ACTIONS(4042),
    [anon_sym_partial] = ACTIONS(4042),
    [anon_sym_private] = ACTIONS(4042),
    [anon_sym_protected] = ACTIONS(4042),
    [anon_sym_public] = ACTIONS(4042),
    [anon_sym_readonly] = ACTIONS(4042),
    [anon_sym_required] = ACTIONS(4042),
    [anon_sym_sealed] = ACTIONS(4042),
    [anon_sym_virtual] = ACTIONS(4042),
    [anon_sym_volatile] = ACTIONS(4042),
    [anon_sym_where] = ACTIONS(4042),
    [anon_sym_notnull] = ACTIONS(4042),
    [anon_sym_unmanaged] = ACTIONS(4042),
    [anon_sym_scoped] = ACTIONS(4042),
    [anon_sym_var] = ACTIONS(4042),
    [sym_predefined_type] = ACTIONS(4042),
    [anon_sym_yield] = ACTIONS(4042),
    [anon_sym_when] = ACTIONS(4042),
    [anon_sym_from] = ACTIONS(4042),
    [anon_sym_into] = ACTIONS(4042),
    [anon_sym_join] = ACTIONS(4042),
    [anon_sym_on] = ACTIONS(4042),
    [anon_sym_equals] = ACTIONS(4042),
    [anon_sym_let] = ACTIONS(4042),
    [anon_sym_orderby] = ACTIONS(4042),
    [anon_sym_ascending] = ACTIONS(4042),
    [anon_sym_descending] = ACTIONS(4042),
    [anon_sym_group] = ACTIONS(4042),
    [anon_sym_by] = ACTIONS(4042),
    [anon_sym_select] = ACTIONS(4042),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4391] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4391),
    [sym_preproc_endregion] = STATE(4391),
    [sym_preproc_line] = STATE(4391),
    [sym_preproc_pragma] = STATE(4391),
    [sym_preproc_nullable] = STATE(4391),
    [sym_preproc_error] = STATE(4391),
    [sym_preproc_warning] = STATE(4391),
    [sym_preproc_define] = STATE(4391),
    [sym_preproc_undef] = STATE(4391),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(6266),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(6192),
    [anon_sym_GT] = ACTIONS(6192),
    [anon_sym_where] = ACTIONS(6266),
    [anon_sym_QMARK] = ACTIONS(6194),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(6196),
    [anon_sym_DASH] = ACTIONS(6196),
    [anon_sym_STAR] = ACTIONS(6198),
    [anon_sym_SLASH] = ACTIONS(6200),
    [anon_sym_PERCENT] = ACTIONS(6198),
    [anon_sym_CARET] = ACTIONS(6202),
    [anon_sym_PIPE] = ACTIONS(6204),
    [anon_sym_AMP] = ACTIONS(6206),
    [anon_sym_LT_LT] = ACTIONS(6208),
    [anon_sym_GT_GT] = ACTIONS(6210),
    [anon_sym_GT_GT_GT] = ACTIONS(6208),
    [anon_sym_EQ_EQ] = ACTIONS(6212),
    [anon_sym_BANG_EQ] = ACTIONS(6212),
    [anon_sym_GT_EQ] = ACTIONS(6214),
    [anon_sym_LT_EQ] = ACTIONS(6214),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(6216),
    [anon_sym_DOT_DOT] = ACTIONS(6218),
    [anon_sym_and] = ACTIONS(6266),
    [anon_sym_or] = ACTIONS(6268),
    [anon_sym_AMP_AMP] = ACTIONS(6222),
    [anon_sym_PIPE_PIPE] = ACTIONS(6224),
    [anon_sym_QMARK_QMARK] = ACTIONS(6226),
    [anon_sym_from] = ACTIONS(6266),
    [anon_sym_into] = ACTIONS(6266),
    [anon_sym_join] = ACTIONS(6266),
    [anon_sym_let] = ACTIONS(6266),
    [anon_sym_orderby] = ACTIONS(6266),
    [anon_sym_ascending] = ACTIONS(6266),
    [anon_sym_descending] = ACTIONS(6266),
    [anon_sym_group] = ACTIONS(6266),
    [anon_sym_select] = ACTIONS(6266),
    [anon_sym_as] = ACTIONS(6228),
    [anon_sym_is] = ACTIONS(6230),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(6232),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4392] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4392),
    [sym_preproc_endregion] = STATE(4392),
    [sym_preproc_line] = STATE(4392),
    [sym_preproc_pragma] = STATE(4392),
    [sym_preproc_nullable] = STATE(4392),
    [sym_preproc_error] = STATE(4392),
    [sym_preproc_warning] = STATE(4392),
    [sym_preproc_define] = STATE(4392),
    [sym_preproc_undef] = STATE(4392),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(6270),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(6192),
    [anon_sym_GT] = ACTIONS(6192),
    [anon_sym_where] = ACTIONS(6270),
    [anon_sym_QMARK] = ACTIONS(6194),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(6196),
    [anon_sym_DASH] = ACTIONS(6196),
    [anon_sym_STAR] = ACTIONS(6198),
    [anon_sym_SLASH] = ACTIONS(6200),
    [anon_sym_PERCENT] = ACTIONS(6198),
    [anon_sym_CARET] = ACTIONS(6202),
    [anon_sym_PIPE] = ACTIONS(6204),
    [anon_sym_AMP] = ACTIONS(6206),
    [anon_sym_LT_LT] = ACTIONS(6208),
    [anon_sym_GT_GT] = ACTIONS(6210),
    [anon_sym_GT_GT_GT] = ACTIONS(6208),
    [anon_sym_EQ_EQ] = ACTIONS(6212),
    [anon_sym_BANG_EQ] = ACTIONS(6212),
    [anon_sym_GT_EQ] = ACTIONS(6214),
    [anon_sym_LT_EQ] = ACTIONS(6214),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(6216),
    [anon_sym_DOT_DOT] = ACTIONS(6218),
    [anon_sym_and] = ACTIONS(6270),
    [anon_sym_or] = ACTIONS(6272),
    [anon_sym_AMP_AMP] = ACTIONS(6222),
    [anon_sym_PIPE_PIPE] = ACTIONS(6224),
    [anon_sym_QMARK_QMARK] = ACTIONS(6226),
    [anon_sym_from] = ACTIONS(6270),
    [anon_sym_into] = ACTIONS(6270),
    [anon_sym_join] = ACTIONS(6270),
    [anon_sym_let] = ACTIONS(6270),
    [anon_sym_orderby] = ACTIONS(6270),
    [anon_sym_ascending] = ACTIONS(6270),
    [anon_sym_descending] = ACTIONS(6270),
    [anon_sym_group] = ACTIONS(6270),
    [anon_sym_select] = ACTIONS(6270),
    [anon_sym_as] = ACTIONS(6228),
    [anon_sym_is] = ACTIONS(6230),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(6232),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4393] = {
    [sym_argument_list] = STATE(3576),
    [sym__name] = STATE(4343),
    [sym_alias_qualified_name] = STATE(3588),
    [sym__simple_name] = STATE(3588),
    [sym_qualified_name] = STATE(3588),
    [sym_generic_name] = STATE(3597),
    [sym_type] = STATE(3557),
    [sym_implicit_type] = STATE(3596),
    [sym_array_type] = STATE(4151),
    [sym__array_base_type] = STATE(8805),
    [sym_nullable_type] = STATE(3612),
    [sym_pointer_type] = STATE(3612),
    [sym__pointer_base_type] = STATE(9071),
    [sym_function_pointer_type] = STATE(3612),
    [sym_ref_type] = STATE(3596),
    [sym_scoped_type] = STATE(3596),
    [sym_tuple_type] = STATE(3621),
    [sym_identifier] = STATE(4004),
    [sym__reserved_identifier] = STATE(3572),
    [sym_preproc_region] = STATE(4393),
    [sym_preproc_endregion] = STATE(4393),
    [sym_preproc_line] = STATE(4393),
    [sym_preproc_pragma] = STATE(4393),
    [sym_preproc_nullable] = STATE(4393),
    [sym_preproc_error] = STATE(4393),
    [sym_preproc_warning] = STATE(4393),
    [sym_preproc_define] = STATE(4393),
    [sym_preproc_undef] = STATE(4393),
    [sym__identifier_token] = ACTIONS(4328),
    [anon_sym_alias] = ACTIONS(4330),
    [anon_sym_global] = ACTIONS(4330),
    [anon_sym_LBRACK] = ACTIONS(6142),
    [anon_sym_LPAREN] = ACTIONS(6144),
    [anon_sym_ref] = ACTIONS(4727),
    [anon_sym_LBRACE] = ACTIONS(6146),
    [anon_sym_delegate] = ACTIONS(6148),
    [anon_sym_file] = ACTIONS(4330),
    [anon_sym_where] = ACTIONS(4330),
    [anon_sym_notnull] = ACTIONS(4330),
    [anon_sym_unmanaged] = ACTIONS(4330),
    [anon_sym_scoped] = ACTIONS(6274),
    [anon_sym_var] = ACTIONS(6152),
    [sym_predefined_type] = ACTIONS(6154),
    [anon_sym_yield] = ACTIONS(4330),
    [anon_sym_when] = ACTIONS(4330),
    [anon_sym_from] = ACTIONS(4330),
    [anon_sym_into] = ACTIONS(4330),
    [anon_sym_join] = ACTIONS(4330),
    [anon_sym_on] = ACTIONS(4330),
    [anon_sym_equals] = ACTIONS(4330),
    [anon_sym_let] = ACTIONS(4330),
    [anon_sym_orderby] = ACTIONS(4330),
    [anon_sym_ascending] = ACTIONS(4330),
    [anon_sym_descending] = ACTIONS(4330),
    [anon_sym_group] = ACTIONS(4330),
    [anon_sym_by] = ACTIONS(4330),
    [anon_sym_select] = ACTIONS(4330),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4394] = {
    [sym_argument_list] = STATE(3594),
    [sym__name] = STATE(3744),
    [sym_alias_qualified_name] = STATE(3680),
    [sym__simple_name] = STATE(3680),
    [sym_qualified_name] = STATE(3680),
    [sym_generic_name] = STATE(3648),
    [sym_type] = STATE(4138),
    [sym_implicit_type] = STATE(3707),
    [sym_array_type] = STATE(3586),
    [sym__array_base_type] = STATE(8829),
    [sym_nullable_type] = STATE(3681),
    [sym_pointer_type] = STATE(3681),
    [sym__pointer_base_type] = STATE(9538),
    [sym_function_pointer_type] = STATE(3681),
    [sym_ref_type] = STATE(3707),
    [sym_scoped_type] = STATE(3707),
    [sym_tuple_type] = STATE(3631),
    [sym_identifier] = STATE(3590),
    [sym__reserved_identifier] = STATE(3625),
    [sym_preproc_region] = STATE(4394),
    [sym_preproc_endregion] = STATE(4394),
    [sym_preproc_line] = STATE(4394),
    [sym_preproc_pragma] = STATE(4394),
    [sym_preproc_nullable] = STATE(4394),
    [sym_preproc_error] = STATE(4394),
    [sym_preproc_warning] = STATE(4394),
    [sym_preproc_define] = STATE(4394),
    [sym_preproc_undef] = STATE(4394),
    [sym__identifier_token] = ACTIONS(4349),
    [anon_sym_alias] = ACTIONS(4351),
    [anon_sym_global] = ACTIONS(4351),
    [anon_sym_LBRACK] = ACTIONS(4506),
    [anon_sym_LPAREN] = ACTIONS(4508),
    [anon_sym_ref] = ACTIONS(4353),
    [anon_sym_LBRACE] = ACTIONS(4510),
    [anon_sym_delegate] = ACTIONS(4512),
    [anon_sym_file] = ACTIONS(4351),
    [anon_sym_where] = ACTIONS(4351),
    [anon_sym_notnull] = ACTIONS(4351),
    [anon_sym_unmanaged] = ACTIONS(4351),
    [anon_sym_scoped] = ACTIONS(4514),
    [anon_sym_var] = ACTIONS(4516),
    [sym_predefined_type] = ACTIONS(4518),
    [anon_sym_yield] = ACTIONS(4351),
    [anon_sym_when] = ACTIONS(4351),
    [anon_sym_from] = ACTIONS(4351),
    [anon_sym_into] = ACTIONS(4351),
    [anon_sym_join] = ACTIONS(4351),
    [anon_sym_on] = ACTIONS(4351),
    [anon_sym_equals] = ACTIONS(4351),
    [anon_sym_let] = ACTIONS(4351),
    [anon_sym_orderby] = ACTIONS(4351),
    [anon_sym_ascending] = ACTIONS(4351),
    [anon_sym_descending] = ACTIONS(4351),
    [anon_sym_group] = ACTIONS(4351),
    [anon_sym_by] = ACTIONS(4351),
    [anon_sym_select] = ACTIONS(4351),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4395] = {
    [sym__name] = STATE(7943),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(8475),
    [sym_implicit_type] = STATE(8787),
    [sym_array_type] = STATE(8347),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9367),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(8787),
    [sym_scoped_type] = STATE(8787),
    [sym_tuple_type] = STATE(8173),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4395),
    [sym_preproc_endregion] = STATE(4395),
    [sym_preproc_line] = STATE(4395),
    [sym_preproc_pragma] = STATE(4395),
    [sym_preproc_nullable] = STATE(4395),
    [sym_preproc_error] = STATE(4395),
    [sym_preproc_warning] = STATE(4395),
    [sym_preproc_define] = STATE(4395),
    [sym_preproc_undef] = STATE(4395),
    [aux_sym_type_argument_list_repeat1] = STATE(8480),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_COMMA] = ACTIONS(5743),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(5745),
    [anon_sym_delegate] = ACTIONS(5747),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_GT] = ACTIONS(6276),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(5753),
    [anon_sym_var] = ACTIONS(5369),
    [sym_predefined_type] = ACTIONS(5755),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4396] = {
    [sym_argument_list] = STATE(3920),
    [sym__name] = STATE(4158),
    [sym_alias_qualified_name] = STATE(4085),
    [sym__simple_name] = STATE(4085),
    [sym_qualified_name] = STATE(4085),
    [sym_generic_name] = STATE(3959),
    [sym_type] = STATE(3834),
    [sym_implicit_type] = STATE(4031),
    [sym_array_type] = STATE(4039),
    [sym__array_base_type] = STATE(8941),
    [sym_nullable_type] = STATE(3961),
    [sym_pointer_type] = STATE(3961),
    [sym__pointer_base_type] = STATE(9806),
    [sym_function_pointer_type] = STATE(3961),
    [sym_ref_type] = STATE(4031),
    [sym_scoped_type] = STATE(4031),
    [sym_tuple_type] = STATE(3962),
    [sym_identifier] = STATE(3889),
    [sym__reserved_identifier] = STATE(3911),
    [sym_preproc_region] = STATE(4396),
    [sym_preproc_endregion] = STATE(4396),
    [sym_preproc_line] = STATE(4396),
    [sym_preproc_pragma] = STATE(4396),
    [sym_preproc_nullable] = STATE(4396),
    [sym_preproc_error] = STATE(4396),
    [sym_preproc_warning] = STATE(4396),
    [sym_preproc_define] = STATE(4396),
    [sym_preproc_undef] = STATE(4396),
    [sym__identifier_token] = ACTIONS(4248),
    [anon_sym_alias] = ACTIONS(4250),
    [anon_sym_global] = ACTIONS(4250),
    [anon_sym_LBRACK] = ACTIONS(6162),
    [anon_sym_LPAREN] = ACTIONS(6164),
    [anon_sym_ref] = ACTIONS(4523),
    [anon_sym_LBRACE] = ACTIONS(6166),
    [anon_sym_delegate] = ACTIONS(6168),
    [anon_sym_file] = ACTIONS(4250),
    [anon_sym_where] = ACTIONS(4250),
    [anon_sym_notnull] = ACTIONS(4250),
    [anon_sym_unmanaged] = ACTIONS(4250),
    [anon_sym_scoped] = ACTIONS(6278),
    [anon_sym_var] = ACTIONS(6172),
    [sym_predefined_type] = ACTIONS(6174),
    [anon_sym_yield] = ACTIONS(4250),
    [anon_sym_when] = ACTIONS(4250),
    [anon_sym_from] = ACTIONS(4250),
    [anon_sym_into] = ACTIONS(4250),
    [anon_sym_join] = ACTIONS(4250),
    [anon_sym_on] = ACTIONS(4250),
    [anon_sym_equals] = ACTIONS(4250),
    [anon_sym_let] = ACTIONS(4250),
    [anon_sym_orderby] = ACTIONS(4250),
    [anon_sym_ascending] = ACTIONS(4250),
    [anon_sym_descending] = ACTIONS(4250),
    [anon_sym_group] = ACTIONS(4250),
    [anon_sym_by] = ACTIONS(4250),
    [anon_sym_select] = ACTIONS(4250),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4397] = {
    [sym_modifier] = STATE(4634),
    [sym_preproc_region] = STATE(4397),
    [sym_preproc_endregion] = STATE(4397),
    [sym_preproc_line] = STATE(4397),
    [sym_preproc_pragma] = STATE(4397),
    [sym_preproc_nullable] = STATE(4397),
    [sym_preproc_error] = STATE(4397),
    [sym_preproc_warning] = STATE(4397),
    [sym_preproc_define] = STATE(4397),
    [sym_preproc_undef] = STATE(4397),
    [aux_sym_class_declaration_repeat2] = STATE(4397),
    [sym__identifier_token] = ACTIONS(5690),
    [anon_sym_extern] = ACTIONS(6280),
    [anon_sym_alias] = ACTIONS(5690),
    [anon_sym_global] = ACTIONS(5690),
    [anon_sym_unsafe] = ACTIONS(6280),
    [anon_sym_static] = ACTIONS(6280),
    [anon_sym_LPAREN] = ACTIONS(5695),
    [anon_sym_ref] = ACTIONS(5690),
    [anon_sym_delegate] = ACTIONS(5690),
    [anon_sym_abstract] = ACTIONS(6280),
    [anon_sym_async] = ACTIONS(6280),
    [anon_sym_const] = ACTIONS(6280),
    [anon_sym_file] = ACTIONS(6280),
    [anon_sym_fixed] = ACTIONS(6280),
    [anon_sym_internal] = ACTIONS(6280),
    [anon_sym_new] = ACTIONS(6280),
    [anon_sym_override] = ACTIONS(6280),
    [anon_sym_partial] = ACTIONS(6280),
    [anon_sym_private] = ACTIONS(6280),
    [anon_sym_protected] = ACTIONS(6280),
    [anon_sym_public] = ACTIONS(6280),
    [anon_sym_readonly] = ACTIONS(6280),
    [anon_sym_required] = ACTIONS(6280),
    [anon_sym_sealed] = ACTIONS(6280),
    [anon_sym_virtual] = ACTIONS(6280),
    [anon_sym_volatile] = ACTIONS(6280),
    [anon_sym_where] = ACTIONS(5690),
    [anon_sym_notnull] = ACTIONS(5690),
    [anon_sym_unmanaged] = ACTIONS(5690),
    [anon_sym_scoped] = ACTIONS(5690),
    [anon_sym_var] = ACTIONS(5690),
    [sym_predefined_type] = ACTIONS(5690),
    [anon_sym_yield] = ACTIONS(5690),
    [anon_sym_when] = ACTIONS(5690),
    [anon_sym_from] = ACTIONS(5690),
    [anon_sym_into] = ACTIONS(5690),
    [anon_sym_join] = ACTIONS(5690),
    [anon_sym_on] = ACTIONS(5690),
    [anon_sym_equals] = ACTIONS(5690),
    [anon_sym_let] = ACTIONS(5690),
    [anon_sym_orderby] = ACTIONS(5690),
    [anon_sym_ascending] = ACTIONS(5690),
    [anon_sym_descending] = ACTIONS(5690),
    [anon_sym_group] = ACTIONS(5690),
    [anon_sym_by] = ACTIONS(5690),
    [anon_sym_select] = ACTIONS(5690),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4398] = {
    [sym__name] = STATE(7943),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(8674),
    [sym_implicit_type] = STATE(8787),
    [sym_array_type] = STATE(8347),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9367),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(8787),
    [sym_scoped_type] = STATE(8787),
    [sym_tuple_type] = STATE(8173),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4398),
    [sym_preproc_endregion] = STATE(4398),
    [sym_preproc_line] = STATE(4398),
    [sym_preproc_pragma] = STATE(4398),
    [sym_preproc_nullable] = STATE(4398),
    [sym_preproc_error] = STATE(4398),
    [sym_preproc_warning] = STATE(4398),
    [sym_preproc_define] = STATE(4398),
    [sym_preproc_undef] = STATE(4398),
    [aux_sym_type_argument_list_repeat1] = STATE(8675),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_COMMA] = ACTIONS(5743),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(5745),
    [anon_sym_delegate] = ACTIONS(5747),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_GT] = ACTIONS(6283),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(5753),
    [anon_sym_var] = ACTIONS(5369),
    [sym_predefined_type] = ACTIONS(5755),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4399] = {
    [sym_preproc_region] = STATE(4399),
    [sym_preproc_endregion] = STATE(4399),
    [sym_preproc_line] = STATE(4399),
    [sym_preproc_pragma] = STATE(4399),
    [sym_preproc_nullable] = STATE(4399),
    [sym_preproc_error] = STATE(4399),
    [sym_preproc_warning] = STATE(4399),
    [sym_preproc_define] = STATE(4399),
    [sym_preproc_undef] = STATE(4399),
    [anon_sym_EQ] = ACTIONS(6285),
    [anon_sym_LBRACK] = ACTIONS(5286),
    [anon_sym_LPAREN] = ACTIONS(5286),
    [anon_sym_LT] = ACTIONS(5288),
    [anon_sym_GT] = ACTIONS(5288),
    [anon_sym_QMARK] = ACTIONS(5288),
    [anon_sym_BANG] = ACTIONS(5288),
    [anon_sym_PLUS_PLUS] = ACTIONS(5286),
    [anon_sym_DASH_DASH] = ACTIONS(5286),
    [anon_sym_PLUS] = ACTIONS(5288),
    [anon_sym_DASH] = ACTIONS(5288),
    [anon_sym_STAR] = ACTIONS(5288),
    [anon_sym_SLASH] = ACTIONS(5288),
    [anon_sym_PERCENT] = ACTIONS(5288),
    [anon_sym_CARET] = ACTIONS(5288),
    [anon_sym_PIPE] = ACTIONS(5288),
    [anon_sym_AMP] = ACTIONS(5288),
    [anon_sym_LT_LT] = ACTIONS(5288),
    [anon_sym_GT_GT] = ACTIONS(5288),
    [anon_sym_GT_GT_GT] = ACTIONS(5288),
    [anon_sym_EQ_EQ] = ACTIONS(5286),
    [anon_sym_BANG_EQ] = ACTIONS(5286),
    [anon_sym_GT_EQ] = ACTIONS(5286),
    [anon_sym_LT_EQ] = ACTIONS(5286),
    [anon_sym_DOT] = ACTIONS(5288),
    [anon_sym_switch] = ACTIONS(5286),
    [anon_sym_DOT_DOT] = ACTIONS(5286),
    [anon_sym_PLUS_EQ] = ACTIONS(6287),
    [anon_sym_DASH_EQ] = ACTIONS(6287),
    [anon_sym_STAR_EQ] = ACTIONS(6287),
    [anon_sym_SLASH_EQ] = ACTIONS(6287),
    [anon_sym_PERCENT_EQ] = ACTIONS(6287),
    [anon_sym_AMP_EQ] = ACTIONS(6287),
    [anon_sym_CARET_EQ] = ACTIONS(6287),
    [anon_sym_PIPE_EQ] = ACTIONS(6287),
    [anon_sym_LT_LT_EQ] = ACTIONS(6287),
    [anon_sym_GT_GT_EQ] = ACTIONS(6287),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(6287),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(6287),
    [anon_sym_AMP_AMP] = ACTIONS(5286),
    [anon_sym_PIPE_PIPE] = ACTIONS(5286),
    [anon_sym_QMARK_QMARK] = ACTIONS(5288),
    [anon_sym_into] = ACTIONS(5286),
    [anon_sym_equals] = ACTIONS(5286),
    [anon_sym_as] = ACTIONS(5286),
    [anon_sym_is] = ACTIONS(5286),
    [anon_sym_DASH_GT] = ACTIONS(5286),
    [anon_sym_with] = ACTIONS(5286),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4400] = {
    [sym_argument_list] = STATE(3920),
    [sym__name] = STATE(4158),
    [sym_alias_qualified_name] = STATE(4085),
    [sym__simple_name] = STATE(4085),
    [sym_qualified_name] = STATE(4085),
    [sym_generic_name] = STATE(3959),
    [sym_type] = STATE(3834),
    [sym_implicit_type] = STATE(4031),
    [sym_array_type] = STATE(4039),
    [sym__array_base_type] = STATE(8941),
    [sym_nullable_type] = STATE(3961),
    [sym_pointer_type] = STATE(3961),
    [sym__pointer_base_type] = STATE(9806),
    [sym_function_pointer_type] = STATE(3961),
    [sym_ref_type] = STATE(4031),
    [sym_scoped_type] = STATE(4031),
    [sym_tuple_type] = STATE(3962),
    [sym_identifier] = STATE(3889),
    [sym__reserved_identifier] = STATE(3911),
    [sym_preproc_region] = STATE(4400),
    [sym_preproc_endregion] = STATE(4400),
    [sym_preproc_line] = STATE(4400),
    [sym_preproc_pragma] = STATE(4400),
    [sym_preproc_nullable] = STATE(4400),
    [sym_preproc_error] = STATE(4400),
    [sym_preproc_warning] = STATE(4400),
    [sym_preproc_define] = STATE(4400),
    [sym_preproc_undef] = STATE(4400),
    [sym__identifier_token] = ACTIONS(4248),
    [anon_sym_alias] = ACTIONS(4250),
    [anon_sym_global] = ACTIONS(4250),
    [anon_sym_LBRACK] = ACTIONS(6162),
    [anon_sym_LPAREN] = ACTIONS(6164),
    [anon_sym_ref] = ACTIONS(4648),
    [anon_sym_LBRACE] = ACTIONS(6166),
    [anon_sym_delegate] = ACTIONS(6168),
    [anon_sym_file] = ACTIONS(4250),
    [anon_sym_where] = ACTIONS(4250),
    [anon_sym_notnull] = ACTIONS(4250),
    [anon_sym_unmanaged] = ACTIONS(4250),
    [anon_sym_scoped] = ACTIONS(6289),
    [anon_sym_var] = ACTIONS(6172),
    [sym_predefined_type] = ACTIONS(6174),
    [anon_sym_yield] = ACTIONS(4250),
    [anon_sym_when] = ACTIONS(4250),
    [anon_sym_from] = ACTIONS(4250),
    [anon_sym_into] = ACTIONS(4250),
    [anon_sym_join] = ACTIONS(4250),
    [anon_sym_on] = ACTIONS(4250),
    [anon_sym_equals] = ACTIONS(4250),
    [anon_sym_let] = ACTIONS(4250),
    [anon_sym_orderby] = ACTIONS(4250),
    [anon_sym_ascending] = ACTIONS(4250),
    [anon_sym_descending] = ACTIONS(4250),
    [anon_sym_group] = ACTIONS(4250),
    [anon_sym_by] = ACTIONS(4250),
    [anon_sym_select] = ACTIONS(4250),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4401] = {
    [sym_argument_list] = STATE(5221),
    [sym__name] = STATE(5270),
    [sym_alias_qualified_name] = STATE(5341),
    [sym__simple_name] = STATE(5341),
    [sym_qualified_name] = STATE(5341),
    [sym_generic_name] = STATE(5408),
    [sym_type] = STATE(5065),
    [sym_implicit_type] = STATE(5336),
    [sym_array_type] = STATE(5177),
    [sym__array_base_type] = STATE(8724),
    [sym_nullable_type] = STATE(5262),
    [sym_pointer_type] = STATE(5262),
    [sym__pointer_base_type] = STATE(9858),
    [sym_function_pointer_type] = STATE(5262),
    [sym_ref_type] = STATE(5336),
    [sym_scoped_type] = STATE(5336),
    [sym_tuple_type] = STATE(5321),
    [sym_identifier] = STATE(5076),
    [sym__reserved_identifier] = STATE(5173),
    [sym_preproc_region] = STATE(4401),
    [sym_preproc_endregion] = STATE(4401),
    [sym_preproc_line] = STATE(4401),
    [sym_preproc_pragma] = STATE(4401),
    [sym_preproc_nullable] = STATE(4401),
    [sym_preproc_error] = STATE(4401),
    [sym_preproc_warning] = STATE(4401),
    [sym_preproc_define] = STATE(4401),
    [sym_preproc_undef] = STATE(4401),
    [sym__identifier_token] = ACTIONS(4457),
    [anon_sym_alias] = ACTIONS(4459),
    [anon_sym_global] = ACTIONS(4459),
    [anon_sym_LBRACK] = ACTIONS(6291),
    [anon_sym_LPAREN] = ACTIONS(6293),
    [anon_sym_ref] = ACTIONS(4474),
    [anon_sym_LBRACE] = ACTIONS(6295),
    [anon_sym_delegate] = ACTIONS(6297),
    [anon_sym_file] = ACTIONS(4459),
    [anon_sym_where] = ACTIONS(4459),
    [anon_sym_notnull] = ACTIONS(4459),
    [anon_sym_unmanaged] = ACTIONS(4459),
    [anon_sym_scoped] = ACTIONS(6299),
    [anon_sym_var] = ACTIONS(6301),
    [sym_predefined_type] = ACTIONS(6303),
    [anon_sym_yield] = ACTIONS(4459),
    [anon_sym_when] = ACTIONS(4459),
    [anon_sym_from] = ACTIONS(4459),
    [anon_sym_into] = ACTIONS(4459),
    [anon_sym_join] = ACTIONS(4459),
    [anon_sym_on] = ACTIONS(4459),
    [anon_sym_equals] = ACTIONS(4459),
    [anon_sym_let] = ACTIONS(4459),
    [anon_sym_orderby] = ACTIONS(4459),
    [anon_sym_ascending] = ACTIONS(4459),
    [anon_sym_descending] = ACTIONS(4459),
    [anon_sym_group] = ACTIONS(4459),
    [anon_sym_by] = ACTIONS(4459),
    [anon_sym_select] = ACTIONS(4459),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4402] = {
    [sym__name] = STATE(7943),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(8469),
    [sym_implicit_type] = STATE(8787),
    [sym_array_type] = STATE(8347),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9367),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(8787),
    [sym_scoped_type] = STATE(8787),
    [sym_tuple_type] = STATE(8173),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4402),
    [sym_preproc_endregion] = STATE(4402),
    [sym_preproc_line] = STATE(4402),
    [sym_preproc_pragma] = STATE(4402),
    [sym_preproc_nullable] = STATE(4402),
    [sym_preproc_error] = STATE(4402),
    [sym_preproc_warning] = STATE(4402),
    [sym_preproc_define] = STATE(4402),
    [sym_preproc_undef] = STATE(4402),
    [aux_sym_type_argument_list_repeat1] = STATE(8470),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_COMMA] = ACTIONS(5743),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(5745),
    [anon_sym_delegate] = ACTIONS(5747),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_GT] = ACTIONS(6305),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(5753),
    [anon_sym_var] = ACTIONS(5369),
    [sym_predefined_type] = ACTIONS(5755),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4403] = {
    [sym_preproc_region] = STATE(4403),
    [sym_preproc_endregion] = STATE(4403),
    [sym_preproc_line] = STATE(4403),
    [sym_preproc_pragma] = STATE(4403),
    [sym_preproc_nullable] = STATE(4403),
    [sym_preproc_error] = STATE(4403),
    [sym_preproc_warning] = STATE(4403),
    [sym_preproc_define] = STATE(4403),
    [sym_preproc_undef] = STATE(4403),
    [sym__identifier_token] = ACTIONS(5711),
    [anon_sym_extern] = ACTIONS(5711),
    [anon_sym_alias] = ACTIONS(5711),
    [anon_sym_global] = ACTIONS(5711),
    [anon_sym_unsafe] = ACTIONS(5711),
    [anon_sym_static] = ACTIONS(5711),
    [anon_sym_LBRACK] = ACTIONS(5713),
    [anon_sym_abstract] = ACTIONS(5711),
    [anon_sym_async] = ACTIONS(5711),
    [anon_sym_const] = ACTIONS(5711),
    [anon_sym_file] = ACTIONS(5711),
    [anon_sym_fixed] = ACTIONS(5711),
    [anon_sym_internal] = ACTIONS(5711),
    [anon_sym_new] = ACTIONS(5711),
    [anon_sym_override] = ACTIONS(5711),
    [anon_sym_partial] = ACTIONS(5711),
    [anon_sym_private] = ACTIONS(5711),
    [anon_sym_protected] = ACTIONS(5711),
    [anon_sym_public] = ACTIONS(5711),
    [anon_sym_readonly] = ACTIONS(5711),
    [anon_sym_required] = ACTIONS(5711),
    [anon_sym_sealed] = ACTIONS(5711),
    [anon_sym_virtual] = ACTIONS(5711),
    [anon_sym_volatile] = ACTIONS(5711),
    [anon_sym_where] = ACTIONS(5711),
    [anon_sym_notnull] = ACTIONS(5711),
    [anon_sym_unmanaged] = ACTIONS(5711),
    [anon_sym_get] = ACTIONS(5711),
    [anon_sym_set] = ACTIONS(5711),
    [anon_sym_add] = ACTIONS(5711),
    [anon_sym_remove] = ACTIONS(5711),
    [anon_sym_init] = ACTIONS(5711),
    [anon_sym_scoped] = ACTIONS(5711),
    [anon_sym_var] = ACTIONS(5711),
    [anon_sym_yield] = ACTIONS(5711),
    [anon_sym_when] = ACTIONS(5711),
    [anon_sym_from] = ACTIONS(5711),
    [anon_sym_into] = ACTIONS(5711),
    [anon_sym_join] = ACTIONS(5711),
    [anon_sym_on] = ACTIONS(5711),
    [anon_sym_equals] = ACTIONS(5711),
    [anon_sym_let] = ACTIONS(5711),
    [anon_sym_orderby] = ACTIONS(5711),
    [anon_sym_ascending] = ACTIONS(5711),
    [anon_sym_descending] = ACTIONS(5711),
    [anon_sym_group] = ACTIONS(5711),
    [anon_sym_by] = ACTIONS(5711),
    [anon_sym_select] = ACTIONS(5711),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4404] = {
    [sym_argument_list] = STATE(3594),
    [sym__name] = STATE(3744),
    [sym_alias_qualified_name] = STATE(3680),
    [sym__simple_name] = STATE(3680),
    [sym_qualified_name] = STATE(3680),
    [sym_generic_name] = STATE(3648),
    [sym_type] = STATE(4138),
    [sym_implicit_type] = STATE(3707),
    [sym_array_type] = STATE(3586),
    [sym__array_base_type] = STATE(8829),
    [sym_nullable_type] = STATE(3681),
    [sym_pointer_type] = STATE(3681),
    [sym__pointer_base_type] = STATE(9538),
    [sym_function_pointer_type] = STATE(3681),
    [sym_ref_type] = STATE(3707),
    [sym_scoped_type] = STATE(3707),
    [sym_tuple_type] = STATE(3631),
    [sym_identifier] = STATE(3590),
    [sym__reserved_identifier] = STATE(3625),
    [sym_preproc_region] = STATE(4404),
    [sym_preproc_endregion] = STATE(4404),
    [sym_preproc_line] = STATE(4404),
    [sym_preproc_pragma] = STATE(4404),
    [sym_preproc_nullable] = STATE(4404),
    [sym_preproc_error] = STATE(4404),
    [sym_preproc_warning] = STATE(4404),
    [sym_preproc_define] = STATE(4404),
    [sym_preproc_undef] = STATE(4404),
    [sym__identifier_token] = ACTIONS(4349),
    [anon_sym_alias] = ACTIONS(4351),
    [anon_sym_global] = ACTIONS(4351),
    [anon_sym_LBRACK] = ACTIONS(4506),
    [anon_sym_LPAREN] = ACTIONS(4508),
    [anon_sym_ref] = ACTIONS(4721),
    [anon_sym_LBRACE] = ACTIONS(4510),
    [anon_sym_delegate] = ACTIONS(4512),
    [anon_sym_file] = ACTIONS(4351),
    [anon_sym_where] = ACTIONS(4351),
    [anon_sym_notnull] = ACTIONS(4351),
    [anon_sym_unmanaged] = ACTIONS(4351),
    [anon_sym_scoped] = ACTIONS(6307),
    [anon_sym_var] = ACTIONS(4516),
    [sym_predefined_type] = ACTIONS(4518),
    [anon_sym_yield] = ACTIONS(4351),
    [anon_sym_when] = ACTIONS(4351),
    [anon_sym_from] = ACTIONS(4351),
    [anon_sym_into] = ACTIONS(4351),
    [anon_sym_join] = ACTIONS(4351),
    [anon_sym_on] = ACTIONS(4351),
    [anon_sym_equals] = ACTIONS(4351),
    [anon_sym_let] = ACTIONS(4351),
    [anon_sym_orderby] = ACTIONS(4351),
    [anon_sym_ascending] = ACTIONS(4351),
    [anon_sym_descending] = ACTIONS(4351),
    [anon_sym_group] = ACTIONS(4351),
    [anon_sym_by] = ACTIONS(4351),
    [anon_sym_select] = ACTIONS(4351),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4405] = {
    [sym_initializer_expression] = STATE(4606),
    [sym_preproc_region] = STATE(4405),
    [sym_preproc_endregion] = STATE(4405),
    [sym_preproc_line] = STATE(4405),
    [sym_preproc_pragma] = STATE(4405),
    [sym_preproc_nullable] = STATE(4405),
    [sym_preproc_error] = STATE(4405),
    [sym_preproc_warning] = STATE(4405),
    [sym_preproc_define] = STATE(4405),
    [sym_preproc_undef] = STATE(4405),
    [anon_sym_LBRACK] = ACTIONS(5336),
    [anon_sym_COMMA] = ACTIONS(5340),
    [anon_sym_LPAREN] = ACTIONS(5340),
    [anon_sym_LBRACE] = ACTIONS(6309),
    [anon_sym_LT] = ACTIONS(5346),
    [anon_sym_GT] = ACTIONS(5346),
    [anon_sym_where] = ACTIONS(5340),
    [anon_sym_QMARK] = ACTIONS(6312),
    [anon_sym_BANG] = ACTIONS(5346),
    [anon_sym_PLUS_PLUS] = ACTIONS(5340),
    [anon_sym_DASH_DASH] = ACTIONS(5340),
    [anon_sym_PLUS] = ACTIONS(5346),
    [anon_sym_DASH] = ACTIONS(5346),
    [anon_sym_STAR] = ACTIONS(5340),
    [anon_sym_SLASH] = ACTIONS(5346),
    [anon_sym_PERCENT] = ACTIONS(5340),
    [anon_sym_CARET] = ACTIONS(5340),
    [anon_sym_PIPE] = ACTIONS(5346),
    [anon_sym_AMP] = ACTIONS(5346),
    [anon_sym_LT_LT] = ACTIONS(5340),
    [anon_sym_GT_GT] = ACTIONS(5346),
    [anon_sym_GT_GT_GT] = ACTIONS(5340),
    [anon_sym_EQ_EQ] = ACTIONS(5340),
    [anon_sym_BANG_EQ] = ACTIONS(5340),
    [anon_sym_GT_EQ] = ACTIONS(5340),
    [anon_sym_LT_EQ] = ACTIONS(5340),
    [anon_sym_DOT] = ACTIONS(5346),
    [anon_sym_switch] = ACTIONS(5340),
    [anon_sym_DOT_DOT] = ACTIONS(5340),
    [anon_sym_and] = ACTIONS(5340),
    [anon_sym_or] = ACTIONS(5346),
    [anon_sym_AMP_AMP] = ACTIONS(5340),
    [anon_sym_PIPE_PIPE] = ACTIONS(5340),
    [anon_sym_QMARK_QMARK] = ACTIONS(5340),
    [anon_sym_from] = ACTIONS(5340),
    [anon_sym_into] = ACTIONS(5340),
    [anon_sym_join] = ACTIONS(5340),
    [anon_sym_let] = ACTIONS(5340),
    [anon_sym_orderby] = ACTIONS(5340),
    [anon_sym_ascending] = ACTIONS(5340),
    [anon_sym_descending] = ACTIONS(5340),
    [anon_sym_group] = ACTIONS(5340),
    [anon_sym_select] = ACTIONS(5340),
    [anon_sym_as] = ACTIONS(5346),
    [anon_sym_is] = ACTIONS(5340),
    [anon_sym_DASH_GT] = ACTIONS(5340),
    [anon_sym_with] = ACTIONS(5340),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4406] = {
    [sym__name] = STATE(7943),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(8630),
    [sym_implicit_type] = STATE(8787),
    [sym_array_type] = STATE(8347),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9367),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(8787),
    [sym_scoped_type] = STATE(8787),
    [sym_tuple_type] = STATE(8173),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4406),
    [sym_preproc_endregion] = STATE(4406),
    [sym_preproc_line] = STATE(4406),
    [sym_preproc_pragma] = STATE(4406),
    [sym_preproc_nullable] = STATE(4406),
    [sym_preproc_error] = STATE(4406),
    [sym_preproc_warning] = STATE(4406),
    [sym_preproc_define] = STATE(4406),
    [sym_preproc_undef] = STATE(4406),
    [aux_sym_type_argument_list_repeat1] = STATE(8632),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_COMMA] = ACTIONS(5743),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(5745),
    [anon_sym_delegate] = ACTIONS(5747),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_GT] = ACTIONS(6316),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(5753),
    [anon_sym_var] = ACTIONS(5369),
    [sym_predefined_type] = ACTIONS(5755),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4407] = {
    [sym__name] = STATE(7943),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(8536),
    [sym_implicit_type] = STATE(8787),
    [sym_array_type] = STATE(8347),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9367),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(8787),
    [sym_scoped_type] = STATE(8787),
    [sym_tuple_type] = STATE(8173),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4407),
    [sym_preproc_endregion] = STATE(4407),
    [sym_preproc_line] = STATE(4407),
    [sym_preproc_pragma] = STATE(4407),
    [sym_preproc_nullable] = STATE(4407),
    [sym_preproc_error] = STATE(4407),
    [sym_preproc_warning] = STATE(4407),
    [sym_preproc_define] = STATE(4407),
    [sym_preproc_undef] = STATE(4407),
    [aux_sym_type_argument_list_repeat1] = STATE(8537),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_COMMA] = ACTIONS(5743),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(5745),
    [anon_sym_delegate] = ACTIONS(5747),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_GT] = ACTIONS(6318),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(5753),
    [anon_sym_var] = ACTIONS(5369),
    [sym_predefined_type] = ACTIONS(5755),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4408] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4408),
    [sym_preproc_endregion] = STATE(4408),
    [sym_preproc_line] = STATE(4408),
    [sym_preproc_pragma] = STATE(4408),
    [sym_preproc_nullable] = STATE(4408),
    [sym_preproc_error] = STATE(4408),
    [sym_preproc_warning] = STATE(4408),
    [sym_preproc_define] = STATE(4408),
    [sym_preproc_undef] = STATE(4408),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(6320),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(6192),
    [anon_sym_GT] = ACTIONS(6192),
    [anon_sym_where] = ACTIONS(6320),
    [anon_sym_QMARK] = ACTIONS(6194),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(6196),
    [anon_sym_DASH] = ACTIONS(6196),
    [anon_sym_STAR] = ACTIONS(6198),
    [anon_sym_SLASH] = ACTIONS(6200),
    [anon_sym_PERCENT] = ACTIONS(6198),
    [anon_sym_CARET] = ACTIONS(6202),
    [anon_sym_PIPE] = ACTIONS(6204),
    [anon_sym_AMP] = ACTIONS(6206),
    [anon_sym_LT_LT] = ACTIONS(6208),
    [anon_sym_GT_GT] = ACTIONS(6210),
    [anon_sym_GT_GT_GT] = ACTIONS(6208),
    [anon_sym_EQ_EQ] = ACTIONS(6212),
    [anon_sym_BANG_EQ] = ACTIONS(6212),
    [anon_sym_GT_EQ] = ACTIONS(6214),
    [anon_sym_LT_EQ] = ACTIONS(6214),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(6216),
    [anon_sym_DOT_DOT] = ACTIONS(6218),
    [anon_sym_and] = ACTIONS(6320),
    [anon_sym_or] = ACTIONS(6322),
    [anon_sym_AMP_AMP] = ACTIONS(6222),
    [anon_sym_PIPE_PIPE] = ACTIONS(6224),
    [anon_sym_QMARK_QMARK] = ACTIONS(6226),
    [anon_sym_from] = ACTIONS(6320),
    [anon_sym_into] = ACTIONS(6320),
    [anon_sym_join] = ACTIONS(6320),
    [anon_sym_let] = ACTIONS(6320),
    [anon_sym_orderby] = ACTIONS(6320),
    [anon_sym_ascending] = ACTIONS(6320),
    [anon_sym_descending] = ACTIONS(6320),
    [anon_sym_group] = ACTIONS(6320),
    [anon_sym_select] = ACTIONS(6320),
    [anon_sym_as] = ACTIONS(6228),
    [anon_sym_is] = ACTIONS(6230),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(6232),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4409] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4409),
    [sym_preproc_endregion] = STATE(4409),
    [sym_preproc_line] = STATE(4409),
    [sym_preproc_pragma] = STATE(4409),
    [sym_preproc_nullable] = STATE(4409),
    [sym_preproc_error] = STATE(4409),
    [sym_preproc_warning] = STATE(4409),
    [sym_preproc_define] = STATE(4409),
    [sym_preproc_undef] = STATE(4409),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(6324),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(6192),
    [anon_sym_GT] = ACTIONS(6192),
    [anon_sym_where] = ACTIONS(6324),
    [anon_sym_QMARK] = ACTIONS(6194),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(6196),
    [anon_sym_DASH] = ACTIONS(6196),
    [anon_sym_STAR] = ACTIONS(6198),
    [anon_sym_SLASH] = ACTIONS(6200),
    [anon_sym_PERCENT] = ACTIONS(6198),
    [anon_sym_CARET] = ACTIONS(6202),
    [anon_sym_PIPE] = ACTIONS(6204),
    [anon_sym_AMP] = ACTIONS(6206),
    [anon_sym_LT_LT] = ACTIONS(6208),
    [anon_sym_GT_GT] = ACTIONS(6210),
    [anon_sym_GT_GT_GT] = ACTIONS(6208),
    [anon_sym_EQ_EQ] = ACTIONS(6212),
    [anon_sym_BANG_EQ] = ACTIONS(6212),
    [anon_sym_GT_EQ] = ACTIONS(6214),
    [anon_sym_LT_EQ] = ACTIONS(6214),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(6216),
    [anon_sym_DOT_DOT] = ACTIONS(6218),
    [anon_sym_and] = ACTIONS(6324),
    [anon_sym_or] = ACTIONS(6326),
    [anon_sym_AMP_AMP] = ACTIONS(6222),
    [anon_sym_PIPE_PIPE] = ACTIONS(6224),
    [anon_sym_QMARK_QMARK] = ACTIONS(6226),
    [anon_sym_from] = ACTIONS(6324),
    [anon_sym_into] = ACTIONS(6324),
    [anon_sym_join] = ACTIONS(6324),
    [anon_sym_let] = ACTIONS(6324),
    [anon_sym_orderby] = ACTIONS(6324),
    [anon_sym_ascending] = ACTIONS(6324),
    [anon_sym_descending] = ACTIONS(6324),
    [anon_sym_group] = ACTIONS(6324),
    [anon_sym_select] = ACTIONS(6324),
    [anon_sym_as] = ACTIONS(6228),
    [anon_sym_is] = ACTIONS(6230),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(6232),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4410] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4410),
    [sym_preproc_endregion] = STATE(4410),
    [sym_preproc_line] = STATE(4410),
    [sym_preproc_pragma] = STATE(4410),
    [sym_preproc_nullable] = STATE(4410),
    [sym_preproc_error] = STATE(4410),
    [sym_preproc_warning] = STATE(4410),
    [sym_preproc_define] = STATE(4410),
    [sym_preproc_undef] = STATE(4410),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(6328),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(6330),
    [anon_sym_GT] = ACTIONS(6330),
    [anon_sym_where] = ACTIONS(6328),
    [anon_sym_QMARK] = ACTIONS(6330),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(6330),
    [anon_sym_DASH] = ACTIONS(6330),
    [anon_sym_STAR] = ACTIONS(6328),
    [anon_sym_SLASH] = ACTIONS(6330),
    [anon_sym_PERCENT] = ACTIONS(6328),
    [anon_sym_CARET] = ACTIONS(6328),
    [anon_sym_PIPE] = ACTIONS(6330),
    [anon_sym_AMP] = ACTIONS(6330),
    [anon_sym_LT_LT] = ACTIONS(6328),
    [anon_sym_GT_GT] = ACTIONS(6330),
    [anon_sym_GT_GT_GT] = ACTIONS(6328),
    [anon_sym_EQ_EQ] = ACTIONS(6328),
    [anon_sym_BANG_EQ] = ACTIONS(6328),
    [anon_sym_GT_EQ] = ACTIONS(6328),
    [anon_sym_LT_EQ] = ACTIONS(6328),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(6328),
    [anon_sym_DOT_DOT] = ACTIONS(6218),
    [anon_sym_and] = ACTIONS(6328),
    [anon_sym_or] = ACTIONS(6330),
    [anon_sym_AMP_AMP] = ACTIONS(6328),
    [anon_sym_PIPE_PIPE] = ACTIONS(6328),
    [anon_sym_QMARK_QMARK] = ACTIONS(6328),
    [anon_sym_from] = ACTIONS(6328),
    [anon_sym_into] = ACTIONS(6328),
    [anon_sym_join] = ACTIONS(6328),
    [anon_sym_let] = ACTIONS(6328),
    [anon_sym_orderby] = ACTIONS(6328),
    [anon_sym_ascending] = ACTIONS(6328),
    [anon_sym_descending] = ACTIONS(6328),
    [anon_sym_group] = ACTIONS(6328),
    [anon_sym_select] = ACTIONS(6328),
    [anon_sym_as] = ACTIONS(6330),
    [anon_sym_is] = ACTIONS(6328),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(6328),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4411] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4411),
    [sym_preproc_endregion] = STATE(4411),
    [sym_preproc_line] = STATE(4411),
    [sym_preproc_pragma] = STATE(4411),
    [sym_preproc_nullable] = STATE(4411),
    [sym_preproc_error] = STATE(4411),
    [sym_preproc_warning] = STATE(4411),
    [sym_preproc_define] = STATE(4411),
    [sym_preproc_undef] = STATE(4411),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(5416),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(6192),
    [anon_sym_GT] = ACTIONS(6192),
    [anon_sym_where] = ACTIONS(5416),
    [anon_sym_QMARK] = ACTIONS(6194),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(6196),
    [anon_sym_DASH] = ACTIONS(6196),
    [anon_sym_STAR] = ACTIONS(6198),
    [anon_sym_SLASH] = ACTIONS(6200),
    [anon_sym_PERCENT] = ACTIONS(6198),
    [anon_sym_CARET] = ACTIONS(6202),
    [anon_sym_PIPE] = ACTIONS(6204),
    [anon_sym_AMP] = ACTIONS(6206),
    [anon_sym_LT_LT] = ACTIONS(6208),
    [anon_sym_GT_GT] = ACTIONS(6210),
    [anon_sym_GT_GT_GT] = ACTIONS(6208),
    [anon_sym_EQ_EQ] = ACTIONS(6212),
    [anon_sym_BANG_EQ] = ACTIONS(6212),
    [anon_sym_GT_EQ] = ACTIONS(6214),
    [anon_sym_LT_EQ] = ACTIONS(6214),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(6216),
    [anon_sym_DOT_DOT] = ACTIONS(6218),
    [anon_sym_and] = ACTIONS(5416),
    [anon_sym_or] = ACTIONS(5418),
    [anon_sym_AMP_AMP] = ACTIONS(6222),
    [anon_sym_PIPE_PIPE] = ACTIONS(6224),
    [anon_sym_QMARK_QMARK] = ACTIONS(6226),
    [anon_sym_from] = ACTIONS(5416),
    [anon_sym_into] = ACTIONS(5416),
    [anon_sym_join] = ACTIONS(5416),
    [anon_sym_let] = ACTIONS(5416),
    [anon_sym_orderby] = ACTIONS(5416),
    [anon_sym_ascending] = ACTIONS(5416),
    [anon_sym_descending] = ACTIONS(5416),
    [anon_sym_group] = ACTIONS(5416),
    [anon_sym_select] = ACTIONS(5416),
    [anon_sym_as] = ACTIONS(6228),
    [anon_sym_is] = ACTIONS(6230),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(6232),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4412] = {
    [sym_initializer_expression] = STATE(4688),
    [sym_preproc_region] = STATE(4412),
    [sym_preproc_endregion] = STATE(4412),
    [sym_preproc_line] = STATE(4412),
    [sym_preproc_pragma] = STATE(4412),
    [sym_preproc_nullable] = STATE(4412),
    [sym_preproc_error] = STATE(4412),
    [sym_preproc_warning] = STATE(4412),
    [sym_preproc_define] = STATE(4412),
    [sym_preproc_undef] = STATE(4412),
    [anon_sym_LBRACK] = ACTIONS(5303),
    [anon_sym_COMMA] = ACTIONS(5303),
    [anon_sym_LPAREN] = ACTIONS(5303),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_LT] = ACTIONS(5305),
    [anon_sym_GT] = ACTIONS(5305),
    [anon_sym_where] = ACTIONS(5303),
    [anon_sym_QMARK] = ACTIONS(5305),
    [anon_sym_BANG] = ACTIONS(5305),
    [anon_sym_PLUS_PLUS] = ACTIONS(5303),
    [anon_sym_DASH_DASH] = ACTIONS(5303),
    [anon_sym_PLUS] = ACTIONS(5305),
    [anon_sym_DASH] = ACTIONS(5305),
    [anon_sym_STAR] = ACTIONS(5303),
    [anon_sym_SLASH] = ACTIONS(5305),
    [anon_sym_PERCENT] = ACTIONS(5303),
    [anon_sym_CARET] = ACTIONS(5303),
    [anon_sym_PIPE] = ACTIONS(5305),
    [anon_sym_AMP] = ACTIONS(5305),
    [anon_sym_LT_LT] = ACTIONS(5303),
    [anon_sym_GT_GT] = ACTIONS(5305),
    [anon_sym_GT_GT_GT] = ACTIONS(5303),
    [anon_sym_EQ_EQ] = ACTIONS(5303),
    [anon_sym_BANG_EQ] = ACTIONS(5303),
    [anon_sym_GT_EQ] = ACTIONS(5303),
    [anon_sym_LT_EQ] = ACTIONS(5303),
    [anon_sym_DOT] = ACTIONS(5305),
    [anon_sym_switch] = ACTIONS(5303),
    [anon_sym_DOT_DOT] = ACTIONS(5303),
    [anon_sym_and] = ACTIONS(5303),
    [anon_sym_or] = ACTIONS(5305),
    [anon_sym_AMP_AMP] = ACTIONS(5303),
    [anon_sym_PIPE_PIPE] = ACTIONS(5303),
    [anon_sym_QMARK_QMARK] = ACTIONS(5303),
    [anon_sym_from] = ACTIONS(5303),
    [anon_sym_into] = ACTIONS(5303),
    [anon_sym_join] = ACTIONS(5303),
    [anon_sym_let] = ACTIONS(5303),
    [anon_sym_orderby] = ACTIONS(5303),
    [anon_sym_ascending] = ACTIONS(5303),
    [anon_sym_descending] = ACTIONS(5303),
    [anon_sym_group] = ACTIONS(5303),
    [anon_sym_select] = ACTIONS(5303),
    [anon_sym_as] = ACTIONS(5305),
    [anon_sym_is] = ACTIONS(5303),
    [anon_sym_DASH_GT] = ACTIONS(5303),
    [anon_sym_with] = ACTIONS(5303),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4413] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4413),
    [sym_preproc_endregion] = STATE(4413),
    [sym_preproc_line] = STATE(4413),
    [sym_preproc_pragma] = STATE(4413),
    [sym_preproc_nullable] = STATE(4413),
    [sym_preproc_error] = STATE(4413),
    [sym_preproc_warning] = STATE(4413),
    [sym_preproc_define] = STATE(4413),
    [sym_preproc_undef] = STATE(4413),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(5644),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(6192),
    [anon_sym_GT] = ACTIONS(6192),
    [anon_sym_where] = ACTIONS(5644),
    [anon_sym_QMARK] = ACTIONS(6194),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(6196),
    [anon_sym_DASH] = ACTIONS(6196),
    [anon_sym_STAR] = ACTIONS(6198),
    [anon_sym_SLASH] = ACTIONS(6200),
    [anon_sym_PERCENT] = ACTIONS(6198),
    [anon_sym_CARET] = ACTIONS(6202),
    [anon_sym_PIPE] = ACTIONS(6204),
    [anon_sym_AMP] = ACTIONS(6206),
    [anon_sym_LT_LT] = ACTIONS(6208),
    [anon_sym_GT_GT] = ACTIONS(6210),
    [anon_sym_GT_GT_GT] = ACTIONS(6208),
    [anon_sym_EQ_EQ] = ACTIONS(6212),
    [anon_sym_BANG_EQ] = ACTIONS(6212),
    [anon_sym_GT_EQ] = ACTIONS(6214),
    [anon_sym_LT_EQ] = ACTIONS(6214),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(6216),
    [anon_sym_DOT_DOT] = ACTIONS(6218),
    [anon_sym_and] = ACTIONS(5644),
    [anon_sym_or] = ACTIONS(5646),
    [anon_sym_AMP_AMP] = ACTIONS(6222),
    [anon_sym_PIPE_PIPE] = ACTIONS(6224),
    [anon_sym_QMARK_QMARK] = ACTIONS(6226),
    [anon_sym_from] = ACTIONS(5644),
    [anon_sym_into] = ACTIONS(5644),
    [anon_sym_join] = ACTIONS(5644),
    [anon_sym_let] = ACTIONS(5644),
    [anon_sym_orderby] = ACTIONS(5644),
    [anon_sym_ascending] = ACTIONS(5644),
    [anon_sym_descending] = ACTIONS(5644),
    [anon_sym_group] = ACTIONS(5644),
    [anon_sym_select] = ACTIONS(5644),
    [anon_sym_as] = ACTIONS(6228),
    [anon_sym_is] = ACTIONS(6230),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(6232),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4414] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4414),
    [sym_preproc_endregion] = STATE(4414),
    [sym_preproc_line] = STATE(4414),
    [sym_preproc_pragma] = STATE(4414),
    [sym_preproc_nullable] = STATE(4414),
    [sym_preproc_error] = STATE(4414),
    [sym_preproc_warning] = STATE(4414),
    [sym_preproc_define] = STATE(4414),
    [sym_preproc_undef] = STATE(4414),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(6332),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(6192),
    [anon_sym_GT] = ACTIONS(6192),
    [anon_sym_where] = ACTIONS(6332),
    [anon_sym_QMARK] = ACTIONS(6194),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(6196),
    [anon_sym_DASH] = ACTIONS(6196),
    [anon_sym_STAR] = ACTIONS(6198),
    [anon_sym_SLASH] = ACTIONS(6200),
    [anon_sym_PERCENT] = ACTIONS(6198),
    [anon_sym_CARET] = ACTIONS(6202),
    [anon_sym_PIPE] = ACTIONS(6204),
    [anon_sym_AMP] = ACTIONS(6206),
    [anon_sym_LT_LT] = ACTIONS(6208),
    [anon_sym_GT_GT] = ACTIONS(6210),
    [anon_sym_GT_GT_GT] = ACTIONS(6208),
    [anon_sym_EQ_EQ] = ACTIONS(6212),
    [anon_sym_BANG_EQ] = ACTIONS(6212),
    [anon_sym_GT_EQ] = ACTIONS(6214),
    [anon_sym_LT_EQ] = ACTIONS(6214),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(6216),
    [anon_sym_DOT_DOT] = ACTIONS(6218),
    [anon_sym_and] = ACTIONS(6332),
    [anon_sym_or] = ACTIONS(6334),
    [anon_sym_AMP_AMP] = ACTIONS(6222),
    [anon_sym_PIPE_PIPE] = ACTIONS(6224),
    [anon_sym_QMARK_QMARK] = ACTIONS(6226),
    [anon_sym_from] = ACTIONS(6332),
    [anon_sym_into] = ACTIONS(6332),
    [anon_sym_join] = ACTIONS(6332),
    [anon_sym_let] = ACTIONS(6332),
    [anon_sym_orderby] = ACTIONS(6332),
    [anon_sym_ascending] = ACTIONS(6332),
    [anon_sym_descending] = ACTIONS(6332),
    [anon_sym_group] = ACTIONS(6332),
    [anon_sym_select] = ACTIONS(6332),
    [anon_sym_as] = ACTIONS(6228),
    [anon_sym_is] = ACTIONS(6230),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(6232),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4415] = {
    [sym_block] = STATE(2271),
    [sym_preproc_region] = STATE(4415),
    [sym_preproc_endregion] = STATE(4415),
    [sym_preproc_line] = STATE(4415),
    [sym_preproc_pragma] = STATE(4415),
    [sym_preproc_nullable] = STATE(4415),
    [sym_preproc_error] = STATE(4415),
    [sym_preproc_warning] = STATE(4415),
    [sym_preproc_define] = STATE(4415),
    [sym_preproc_undef] = STATE(4415),
    [sym__identifier_token] = ACTIONS(4042),
    [anon_sym_extern] = ACTIONS(4042),
    [anon_sym_alias] = ACTIONS(4042),
    [anon_sym_global] = ACTIONS(4042),
    [anon_sym_unsafe] = ACTIONS(4042),
    [anon_sym_static] = ACTIONS(4042),
    [anon_sym_LPAREN] = ACTIONS(5474),
    [anon_sym_ref] = ACTIONS(4042),
    [anon_sym_LBRACE] = ACTIONS(5786),
    [anon_sym_delegate] = ACTIONS(4042),
    [anon_sym_abstract] = ACTIONS(4042),
    [anon_sym_async] = ACTIONS(4042),
    [anon_sym_const] = ACTIONS(4042),
    [anon_sym_file] = ACTIONS(4042),
    [anon_sym_fixed] = ACTIONS(4042),
    [anon_sym_internal] = ACTIONS(4042),
    [anon_sym_new] = ACTIONS(4042),
    [anon_sym_override] = ACTIONS(4042),
    [anon_sym_partial] = ACTIONS(4042),
    [anon_sym_private] = ACTIONS(4042),
    [anon_sym_protected] = ACTIONS(4042),
    [anon_sym_public] = ACTIONS(4042),
    [anon_sym_readonly] = ACTIONS(4042),
    [anon_sym_required] = ACTIONS(4042),
    [anon_sym_sealed] = ACTIONS(4042),
    [anon_sym_virtual] = ACTIONS(4042),
    [anon_sym_volatile] = ACTIONS(4042),
    [anon_sym_where] = ACTIONS(4042),
    [anon_sym_notnull] = ACTIONS(4042),
    [anon_sym_unmanaged] = ACTIONS(4042),
    [anon_sym_scoped] = ACTIONS(4042),
    [anon_sym_var] = ACTIONS(4042),
    [sym_predefined_type] = ACTIONS(4042),
    [anon_sym_yield] = ACTIONS(4042),
    [anon_sym_when] = ACTIONS(4042),
    [anon_sym_from] = ACTIONS(4042),
    [anon_sym_into] = ACTIONS(4042),
    [anon_sym_join] = ACTIONS(4042),
    [anon_sym_on] = ACTIONS(4042),
    [anon_sym_equals] = ACTIONS(4042),
    [anon_sym_let] = ACTIONS(4042),
    [anon_sym_orderby] = ACTIONS(4042),
    [anon_sym_ascending] = ACTIONS(4042),
    [anon_sym_descending] = ACTIONS(4042),
    [anon_sym_group] = ACTIONS(4042),
    [anon_sym_by] = ACTIONS(4042),
    [anon_sym_select] = ACTIONS(4042),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4416] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4416),
    [sym_preproc_endregion] = STATE(4416),
    [sym_preproc_line] = STATE(4416),
    [sym_preproc_pragma] = STATE(4416),
    [sym_preproc_nullable] = STATE(4416),
    [sym_preproc_error] = STATE(4416),
    [sym_preproc_warning] = STATE(4416),
    [sym_preproc_define] = STATE(4416),
    [sym_preproc_undef] = STATE(4416),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(5424),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(6192),
    [anon_sym_GT] = ACTIONS(6192),
    [anon_sym_where] = ACTIONS(5424),
    [anon_sym_QMARK] = ACTIONS(6194),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(6196),
    [anon_sym_DASH] = ACTIONS(6196),
    [anon_sym_STAR] = ACTIONS(6198),
    [anon_sym_SLASH] = ACTIONS(6200),
    [anon_sym_PERCENT] = ACTIONS(6198),
    [anon_sym_CARET] = ACTIONS(6202),
    [anon_sym_PIPE] = ACTIONS(6204),
    [anon_sym_AMP] = ACTIONS(6206),
    [anon_sym_LT_LT] = ACTIONS(6208),
    [anon_sym_GT_GT] = ACTIONS(6210),
    [anon_sym_GT_GT_GT] = ACTIONS(6208),
    [anon_sym_EQ_EQ] = ACTIONS(6212),
    [anon_sym_BANG_EQ] = ACTIONS(6212),
    [anon_sym_GT_EQ] = ACTIONS(6214),
    [anon_sym_LT_EQ] = ACTIONS(6214),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(6216),
    [anon_sym_DOT_DOT] = ACTIONS(6218),
    [anon_sym_and] = ACTIONS(5424),
    [anon_sym_or] = ACTIONS(5426),
    [anon_sym_AMP_AMP] = ACTIONS(6222),
    [anon_sym_PIPE_PIPE] = ACTIONS(6224),
    [anon_sym_QMARK_QMARK] = ACTIONS(6226),
    [anon_sym_from] = ACTIONS(5424),
    [anon_sym_into] = ACTIONS(5424),
    [anon_sym_join] = ACTIONS(5424),
    [anon_sym_let] = ACTIONS(5424),
    [anon_sym_orderby] = ACTIONS(5424),
    [anon_sym_ascending] = ACTIONS(5424),
    [anon_sym_descending] = ACTIONS(5424),
    [anon_sym_group] = ACTIONS(5424),
    [anon_sym_select] = ACTIONS(5424),
    [anon_sym_as] = ACTIONS(6228),
    [anon_sym_is] = ACTIONS(6230),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(6232),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4417] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4417),
    [sym_preproc_endregion] = STATE(4417),
    [sym_preproc_line] = STATE(4417),
    [sym_preproc_pragma] = STATE(4417),
    [sym_preproc_nullable] = STATE(4417),
    [sym_preproc_error] = STATE(4417),
    [sym_preproc_warning] = STATE(4417),
    [sym_preproc_define] = STATE(4417),
    [sym_preproc_undef] = STATE(4417),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(6336),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(6192),
    [anon_sym_GT] = ACTIONS(6192),
    [anon_sym_where] = ACTIONS(6336),
    [anon_sym_QMARK] = ACTIONS(6194),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(6196),
    [anon_sym_DASH] = ACTIONS(6196),
    [anon_sym_STAR] = ACTIONS(6198),
    [anon_sym_SLASH] = ACTIONS(6200),
    [anon_sym_PERCENT] = ACTIONS(6198),
    [anon_sym_CARET] = ACTIONS(6202),
    [anon_sym_PIPE] = ACTIONS(6204),
    [anon_sym_AMP] = ACTIONS(6206),
    [anon_sym_LT_LT] = ACTIONS(6208),
    [anon_sym_GT_GT] = ACTIONS(6210),
    [anon_sym_GT_GT_GT] = ACTIONS(6208),
    [anon_sym_EQ_EQ] = ACTIONS(6212),
    [anon_sym_BANG_EQ] = ACTIONS(6212),
    [anon_sym_GT_EQ] = ACTIONS(6214),
    [anon_sym_LT_EQ] = ACTIONS(6214),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(6216),
    [anon_sym_DOT_DOT] = ACTIONS(6218),
    [anon_sym_and] = ACTIONS(6336),
    [anon_sym_or] = ACTIONS(6338),
    [anon_sym_AMP_AMP] = ACTIONS(6222),
    [anon_sym_PIPE_PIPE] = ACTIONS(6224),
    [anon_sym_QMARK_QMARK] = ACTIONS(6226),
    [anon_sym_from] = ACTIONS(6336),
    [anon_sym_into] = ACTIONS(6336),
    [anon_sym_join] = ACTIONS(6336),
    [anon_sym_let] = ACTIONS(6336),
    [anon_sym_orderby] = ACTIONS(6336),
    [anon_sym_ascending] = ACTIONS(6336),
    [anon_sym_descending] = ACTIONS(6336),
    [anon_sym_group] = ACTIONS(6336),
    [anon_sym_select] = ACTIONS(6336),
    [anon_sym_as] = ACTIONS(6228),
    [anon_sym_is] = ACTIONS(6230),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(6232),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4418] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4418),
    [sym_preproc_endregion] = STATE(4418),
    [sym_preproc_line] = STATE(4418),
    [sym_preproc_pragma] = STATE(4418),
    [sym_preproc_nullable] = STATE(4418),
    [sym_preproc_error] = STATE(4418),
    [sym_preproc_warning] = STATE(4418),
    [sym_preproc_define] = STATE(4418),
    [sym_preproc_undef] = STATE(4418),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(5572),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(6192),
    [anon_sym_GT] = ACTIONS(6192),
    [anon_sym_where] = ACTIONS(5572),
    [anon_sym_QMARK] = ACTIONS(6194),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(6196),
    [anon_sym_DASH] = ACTIONS(6196),
    [anon_sym_STAR] = ACTIONS(6198),
    [anon_sym_SLASH] = ACTIONS(6200),
    [anon_sym_PERCENT] = ACTIONS(6198),
    [anon_sym_CARET] = ACTIONS(6202),
    [anon_sym_PIPE] = ACTIONS(6204),
    [anon_sym_AMP] = ACTIONS(6206),
    [anon_sym_LT_LT] = ACTIONS(6208),
    [anon_sym_GT_GT] = ACTIONS(6210),
    [anon_sym_GT_GT_GT] = ACTIONS(6208),
    [anon_sym_EQ_EQ] = ACTIONS(6212),
    [anon_sym_BANG_EQ] = ACTIONS(6212),
    [anon_sym_GT_EQ] = ACTIONS(6214),
    [anon_sym_LT_EQ] = ACTIONS(6214),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(6216),
    [anon_sym_DOT_DOT] = ACTIONS(6218),
    [anon_sym_and] = ACTIONS(5572),
    [anon_sym_or] = ACTIONS(5574),
    [anon_sym_AMP_AMP] = ACTIONS(6222),
    [anon_sym_PIPE_PIPE] = ACTIONS(6224),
    [anon_sym_QMARK_QMARK] = ACTIONS(6226),
    [anon_sym_from] = ACTIONS(5572),
    [anon_sym_into] = ACTIONS(5572),
    [anon_sym_join] = ACTIONS(5572),
    [anon_sym_let] = ACTIONS(5572),
    [anon_sym_orderby] = ACTIONS(5572),
    [anon_sym_ascending] = ACTIONS(5572),
    [anon_sym_descending] = ACTIONS(5572),
    [anon_sym_group] = ACTIONS(5572),
    [anon_sym_select] = ACTIONS(5572),
    [anon_sym_as] = ACTIONS(6228),
    [anon_sym_is] = ACTIONS(6230),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(6232),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4419] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4419),
    [sym_preproc_endregion] = STATE(4419),
    [sym_preproc_line] = STATE(4419),
    [sym_preproc_pragma] = STATE(4419),
    [sym_preproc_nullable] = STATE(4419),
    [sym_preproc_error] = STATE(4419),
    [sym_preproc_warning] = STATE(4419),
    [sym_preproc_define] = STATE(4419),
    [sym_preproc_undef] = STATE(4419),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(5584),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(6192),
    [anon_sym_GT] = ACTIONS(6192),
    [anon_sym_where] = ACTIONS(5584),
    [anon_sym_QMARK] = ACTIONS(6194),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(6196),
    [anon_sym_DASH] = ACTIONS(6196),
    [anon_sym_STAR] = ACTIONS(6198),
    [anon_sym_SLASH] = ACTIONS(6200),
    [anon_sym_PERCENT] = ACTIONS(6198),
    [anon_sym_CARET] = ACTIONS(6202),
    [anon_sym_PIPE] = ACTIONS(6204),
    [anon_sym_AMP] = ACTIONS(6206),
    [anon_sym_LT_LT] = ACTIONS(6208),
    [anon_sym_GT_GT] = ACTIONS(6210),
    [anon_sym_GT_GT_GT] = ACTIONS(6208),
    [anon_sym_EQ_EQ] = ACTIONS(6212),
    [anon_sym_BANG_EQ] = ACTIONS(6212),
    [anon_sym_GT_EQ] = ACTIONS(6214),
    [anon_sym_LT_EQ] = ACTIONS(6214),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(6216),
    [anon_sym_DOT_DOT] = ACTIONS(6218),
    [anon_sym_and] = ACTIONS(5584),
    [anon_sym_or] = ACTIONS(5586),
    [anon_sym_AMP_AMP] = ACTIONS(6222),
    [anon_sym_PIPE_PIPE] = ACTIONS(6224),
    [anon_sym_QMARK_QMARK] = ACTIONS(6226),
    [anon_sym_from] = ACTIONS(5584),
    [anon_sym_into] = ACTIONS(5584),
    [anon_sym_join] = ACTIONS(5584),
    [anon_sym_let] = ACTIONS(5584),
    [anon_sym_orderby] = ACTIONS(5584),
    [anon_sym_ascending] = ACTIONS(5584),
    [anon_sym_descending] = ACTIONS(5584),
    [anon_sym_group] = ACTIONS(5584),
    [anon_sym_select] = ACTIONS(5584),
    [anon_sym_as] = ACTIONS(6228),
    [anon_sym_is] = ACTIONS(6230),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(6232),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4420] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4420),
    [sym_preproc_endregion] = STATE(4420),
    [sym_preproc_line] = STATE(4420),
    [sym_preproc_pragma] = STATE(4420),
    [sym_preproc_nullable] = STATE(4420),
    [sym_preproc_error] = STATE(4420),
    [sym_preproc_warning] = STATE(4420),
    [sym_preproc_define] = STATE(4420),
    [sym_preproc_undef] = STATE(4420),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(5624),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(6192),
    [anon_sym_GT] = ACTIONS(6192),
    [anon_sym_where] = ACTIONS(5624),
    [anon_sym_QMARK] = ACTIONS(6194),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(6196),
    [anon_sym_DASH] = ACTIONS(6196),
    [anon_sym_STAR] = ACTIONS(6198),
    [anon_sym_SLASH] = ACTIONS(6200),
    [anon_sym_PERCENT] = ACTIONS(6198),
    [anon_sym_CARET] = ACTIONS(6202),
    [anon_sym_PIPE] = ACTIONS(6204),
    [anon_sym_AMP] = ACTIONS(6206),
    [anon_sym_LT_LT] = ACTIONS(6208),
    [anon_sym_GT_GT] = ACTIONS(6210),
    [anon_sym_GT_GT_GT] = ACTIONS(6208),
    [anon_sym_EQ_EQ] = ACTIONS(6212),
    [anon_sym_BANG_EQ] = ACTIONS(6212),
    [anon_sym_GT_EQ] = ACTIONS(6214),
    [anon_sym_LT_EQ] = ACTIONS(6214),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(6216),
    [anon_sym_DOT_DOT] = ACTIONS(6218),
    [anon_sym_and] = ACTIONS(5624),
    [anon_sym_or] = ACTIONS(5626),
    [anon_sym_AMP_AMP] = ACTIONS(6222),
    [anon_sym_PIPE_PIPE] = ACTIONS(6224),
    [anon_sym_QMARK_QMARK] = ACTIONS(6226),
    [anon_sym_from] = ACTIONS(5624),
    [anon_sym_into] = ACTIONS(5624),
    [anon_sym_join] = ACTIONS(5624),
    [anon_sym_let] = ACTIONS(5624),
    [anon_sym_orderby] = ACTIONS(5624),
    [anon_sym_ascending] = ACTIONS(5624),
    [anon_sym_descending] = ACTIONS(5624),
    [anon_sym_group] = ACTIONS(5624),
    [anon_sym_select] = ACTIONS(5624),
    [anon_sym_as] = ACTIONS(6228),
    [anon_sym_is] = ACTIONS(6230),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(6232),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4421] = {
    [sym_argument_list] = STATE(3594),
    [sym__name] = STATE(5936),
    [sym_alias_qualified_name] = STATE(3680),
    [sym__simple_name] = STATE(3680),
    [sym_qualified_name] = STATE(3680),
    [sym_generic_name] = STATE(3648),
    [sym_type] = STATE(4138),
    [sym_implicit_type] = STATE(3707),
    [sym_array_type] = STATE(3586),
    [sym__array_base_type] = STATE(8829),
    [sym_nullable_type] = STATE(3681),
    [sym_pointer_type] = STATE(3681),
    [sym__pointer_base_type] = STATE(9538),
    [sym_function_pointer_type] = STATE(3681),
    [sym_ref_type] = STATE(3707),
    [sym_scoped_type] = STATE(3707),
    [sym_tuple_type] = STATE(3631),
    [sym_identifier] = STATE(5255),
    [sym__reserved_identifier] = STATE(3625),
    [sym_preproc_region] = STATE(4421),
    [sym_preproc_endregion] = STATE(4421),
    [sym_preproc_line] = STATE(4421),
    [sym_preproc_pragma] = STATE(4421),
    [sym_preproc_nullable] = STATE(4421),
    [sym_preproc_error] = STATE(4421),
    [sym_preproc_warning] = STATE(4421),
    [sym_preproc_define] = STATE(4421),
    [sym_preproc_undef] = STATE(4421),
    [sym__identifier_token] = ACTIONS(4349),
    [anon_sym_alias] = ACTIONS(4351),
    [anon_sym_global] = ACTIONS(4351),
    [anon_sym_LBRACK] = ACTIONS(4506),
    [anon_sym_LPAREN] = ACTIONS(4508),
    [anon_sym_ref] = ACTIONS(4528),
    [anon_sym_LBRACE] = ACTIONS(4510),
    [anon_sym_delegate] = ACTIONS(4512),
    [anon_sym_file] = ACTIONS(4351),
    [anon_sym_where] = ACTIONS(4351),
    [anon_sym_notnull] = ACTIONS(4351),
    [anon_sym_unmanaged] = ACTIONS(4351),
    [anon_sym_scoped] = ACTIONS(6340),
    [anon_sym_var] = ACTIONS(4516),
    [sym_predefined_type] = ACTIONS(4518),
    [anon_sym_yield] = ACTIONS(4351),
    [anon_sym_when] = ACTIONS(4351),
    [anon_sym_from] = ACTIONS(4351),
    [anon_sym_into] = ACTIONS(4351),
    [anon_sym_join] = ACTIONS(4351),
    [anon_sym_on] = ACTIONS(4351),
    [anon_sym_equals] = ACTIONS(4351),
    [anon_sym_let] = ACTIONS(4351),
    [anon_sym_orderby] = ACTIONS(4351),
    [anon_sym_ascending] = ACTIONS(4351),
    [anon_sym_descending] = ACTIONS(4351),
    [anon_sym_group] = ACTIONS(4351),
    [anon_sym_by] = ACTIONS(4351),
    [anon_sym_select] = ACTIONS(4351),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4422] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4422),
    [sym_preproc_endregion] = STATE(4422),
    [sym_preproc_line] = STATE(4422),
    [sym_preproc_pragma] = STATE(4422),
    [sym_preproc_nullable] = STATE(4422),
    [sym_preproc_error] = STATE(4422),
    [sym_preproc_warning] = STATE(4422),
    [sym_preproc_define] = STATE(4422),
    [sym_preproc_undef] = STATE(4422),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(6342),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(6344),
    [anon_sym_GT] = ACTIONS(6344),
    [anon_sym_where] = ACTIONS(6342),
    [anon_sym_QMARK] = ACTIONS(6344),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(6196),
    [anon_sym_DASH] = ACTIONS(6196),
    [anon_sym_STAR] = ACTIONS(6198),
    [anon_sym_SLASH] = ACTIONS(6200),
    [anon_sym_PERCENT] = ACTIONS(6198),
    [anon_sym_CARET] = ACTIONS(6342),
    [anon_sym_PIPE] = ACTIONS(6344),
    [anon_sym_AMP] = ACTIONS(6344),
    [anon_sym_LT_LT] = ACTIONS(6208),
    [anon_sym_GT_GT] = ACTIONS(6210),
    [anon_sym_GT_GT_GT] = ACTIONS(6208),
    [anon_sym_EQ_EQ] = ACTIONS(6342),
    [anon_sym_BANG_EQ] = ACTIONS(6342),
    [anon_sym_GT_EQ] = ACTIONS(6342),
    [anon_sym_LT_EQ] = ACTIONS(6342),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(6216),
    [anon_sym_DOT_DOT] = ACTIONS(6218),
    [anon_sym_and] = ACTIONS(6342),
    [anon_sym_or] = ACTIONS(6344),
    [anon_sym_AMP_AMP] = ACTIONS(6342),
    [anon_sym_PIPE_PIPE] = ACTIONS(6342),
    [anon_sym_QMARK_QMARK] = ACTIONS(6342),
    [anon_sym_from] = ACTIONS(6342),
    [anon_sym_into] = ACTIONS(6342),
    [anon_sym_join] = ACTIONS(6342),
    [anon_sym_let] = ACTIONS(6342),
    [anon_sym_orderby] = ACTIONS(6342),
    [anon_sym_ascending] = ACTIONS(6342),
    [anon_sym_descending] = ACTIONS(6342),
    [anon_sym_group] = ACTIONS(6342),
    [anon_sym_select] = ACTIONS(6342),
    [anon_sym_as] = ACTIONS(6344),
    [anon_sym_is] = ACTIONS(6342),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(6232),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4423] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4423),
    [sym_preproc_endregion] = STATE(4423),
    [sym_preproc_line] = STATE(4423),
    [sym_preproc_pragma] = STATE(4423),
    [sym_preproc_nullable] = STATE(4423),
    [sym_preproc_error] = STATE(4423),
    [sym_preproc_warning] = STATE(4423),
    [sym_preproc_define] = STATE(4423),
    [sym_preproc_undef] = STATE(4423),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(6342),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(6344),
    [anon_sym_GT] = ACTIONS(6344),
    [anon_sym_where] = ACTIONS(6342),
    [anon_sym_QMARK] = ACTIONS(6344),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(6344),
    [anon_sym_DASH] = ACTIONS(6344),
    [anon_sym_STAR] = ACTIONS(6198),
    [anon_sym_SLASH] = ACTIONS(6200),
    [anon_sym_PERCENT] = ACTIONS(6198),
    [anon_sym_CARET] = ACTIONS(6342),
    [anon_sym_PIPE] = ACTIONS(6344),
    [anon_sym_AMP] = ACTIONS(6344),
    [anon_sym_LT_LT] = ACTIONS(6342),
    [anon_sym_GT_GT] = ACTIONS(6344),
    [anon_sym_GT_GT_GT] = ACTIONS(6342),
    [anon_sym_EQ_EQ] = ACTIONS(6342),
    [anon_sym_BANG_EQ] = ACTIONS(6342),
    [anon_sym_GT_EQ] = ACTIONS(6342),
    [anon_sym_LT_EQ] = ACTIONS(6342),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(6216),
    [anon_sym_DOT_DOT] = ACTIONS(6218),
    [anon_sym_and] = ACTIONS(6342),
    [anon_sym_or] = ACTIONS(6344),
    [anon_sym_AMP_AMP] = ACTIONS(6342),
    [anon_sym_PIPE_PIPE] = ACTIONS(6342),
    [anon_sym_QMARK_QMARK] = ACTIONS(6342),
    [anon_sym_from] = ACTIONS(6342),
    [anon_sym_into] = ACTIONS(6342),
    [anon_sym_join] = ACTIONS(6342),
    [anon_sym_let] = ACTIONS(6342),
    [anon_sym_orderby] = ACTIONS(6342),
    [anon_sym_ascending] = ACTIONS(6342),
    [anon_sym_descending] = ACTIONS(6342),
    [anon_sym_group] = ACTIONS(6342),
    [anon_sym_select] = ACTIONS(6342),
    [anon_sym_as] = ACTIONS(6344),
    [anon_sym_is] = ACTIONS(6342),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(6232),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4424] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4424),
    [sym_preproc_endregion] = STATE(4424),
    [sym_preproc_line] = STATE(4424),
    [sym_preproc_pragma] = STATE(4424),
    [sym_preproc_nullable] = STATE(4424),
    [sym_preproc_error] = STATE(4424),
    [sym_preproc_warning] = STATE(4424),
    [sym_preproc_define] = STATE(4424),
    [sym_preproc_undef] = STATE(4424),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(6342),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(6344),
    [anon_sym_GT] = ACTIONS(6344),
    [anon_sym_where] = ACTIONS(6342),
    [anon_sym_QMARK] = ACTIONS(6344),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(6344),
    [anon_sym_DASH] = ACTIONS(6344),
    [anon_sym_STAR] = ACTIONS(6342),
    [anon_sym_SLASH] = ACTIONS(6344),
    [anon_sym_PERCENT] = ACTIONS(6342),
    [anon_sym_CARET] = ACTIONS(6342),
    [anon_sym_PIPE] = ACTIONS(6344),
    [anon_sym_AMP] = ACTIONS(6344),
    [anon_sym_LT_LT] = ACTIONS(6342),
    [anon_sym_GT_GT] = ACTIONS(6344),
    [anon_sym_GT_GT_GT] = ACTIONS(6342),
    [anon_sym_EQ_EQ] = ACTIONS(6342),
    [anon_sym_BANG_EQ] = ACTIONS(6342),
    [anon_sym_GT_EQ] = ACTIONS(6342),
    [anon_sym_LT_EQ] = ACTIONS(6342),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(6216),
    [anon_sym_DOT_DOT] = ACTIONS(6218),
    [anon_sym_and] = ACTIONS(6342),
    [anon_sym_or] = ACTIONS(6344),
    [anon_sym_AMP_AMP] = ACTIONS(6342),
    [anon_sym_PIPE_PIPE] = ACTIONS(6342),
    [anon_sym_QMARK_QMARK] = ACTIONS(6342),
    [anon_sym_from] = ACTIONS(6342),
    [anon_sym_into] = ACTIONS(6342),
    [anon_sym_join] = ACTIONS(6342),
    [anon_sym_let] = ACTIONS(6342),
    [anon_sym_orderby] = ACTIONS(6342),
    [anon_sym_ascending] = ACTIONS(6342),
    [anon_sym_descending] = ACTIONS(6342),
    [anon_sym_group] = ACTIONS(6342),
    [anon_sym_select] = ACTIONS(6342),
    [anon_sym_as] = ACTIONS(6344),
    [anon_sym_is] = ACTIONS(6342),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(6232),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4425] = {
    [sym__name] = STATE(7943),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(8501),
    [sym_implicit_type] = STATE(8787),
    [sym_array_type] = STATE(8347),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9367),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(8787),
    [sym_scoped_type] = STATE(8787),
    [sym_tuple_type] = STATE(8173),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4425),
    [sym_preproc_endregion] = STATE(4425),
    [sym_preproc_line] = STATE(4425),
    [sym_preproc_pragma] = STATE(4425),
    [sym_preproc_nullable] = STATE(4425),
    [sym_preproc_error] = STATE(4425),
    [sym_preproc_warning] = STATE(4425),
    [sym_preproc_define] = STATE(4425),
    [sym_preproc_undef] = STATE(4425),
    [aux_sym_type_argument_list_repeat1] = STATE(8511),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_COMMA] = ACTIONS(5743),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(5745),
    [anon_sym_delegate] = ACTIONS(5747),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_GT] = ACTIONS(6346),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(5753),
    [anon_sym_var] = ACTIONS(5369),
    [sym_predefined_type] = ACTIONS(5755),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4426] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4426),
    [sym_preproc_endregion] = STATE(4426),
    [sym_preproc_line] = STATE(4426),
    [sym_preproc_pragma] = STATE(4426),
    [sym_preproc_nullable] = STATE(4426),
    [sym_preproc_error] = STATE(4426),
    [sym_preproc_warning] = STATE(4426),
    [sym_preproc_define] = STATE(4426),
    [sym_preproc_undef] = STATE(4426),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(6342),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(6344),
    [anon_sym_GT] = ACTIONS(6344),
    [anon_sym_where] = ACTIONS(6342),
    [anon_sym_QMARK] = ACTIONS(6344),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(6196),
    [anon_sym_DASH] = ACTIONS(6196),
    [anon_sym_STAR] = ACTIONS(6198),
    [anon_sym_SLASH] = ACTIONS(6200),
    [anon_sym_PERCENT] = ACTIONS(6198),
    [anon_sym_CARET] = ACTIONS(6342),
    [anon_sym_PIPE] = ACTIONS(6344),
    [anon_sym_AMP] = ACTIONS(6344),
    [anon_sym_LT_LT] = ACTIONS(6342),
    [anon_sym_GT_GT] = ACTIONS(6344),
    [anon_sym_GT_GT_GT] = ACTIONS(6342),
    [anon_sym_EQ_EQ] = ACTIONS(6342),
    [anon_sym_BANG_EQ] = ACTIONS(6342),
    [anon_sym_GT_EQ] = ACTIONS(6342),
    [anon_sym_LT_EQ] = ACTIONS(6342),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(6216),
    [anon_sym_DOT_DOT] = ACTIONS(6218),
    [anon_sym_and] = ACTIONS(6342),
    [anon_sym_or] = ACTIONS(6344),
    [anon_sym_AMP_AMP] = ACTIONS(6342),
    [anon_sym_PIPE_PIPE] = ACTIONS(6342),
    [anon_sym_QMARK_QMARK] = ACTIONS(6342),
    [anon_sym_from] = ACTIONS(6342),
    [anon_sym_into] = ACTIONS(6342),
    [anon_sym_join] = ACTIONS(6342),
    [anon_sym_let] = ACTIONS(6342),
    [anon_sym_orderby] = ACTIONS(6342),
    [anon_sym_ascending] = ACTIONS(6342),
    [anon_sym_descending] = ACTIONS(6342),
    [anon_sym_group] = ACTIONS(6342),
    [anon_sym_select] = ACTIONS(6342),
    [anon_sym_as] = ACTIONS(6344),
    [anon_sym_is] = ACTIONS(6342),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(6232),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4427] = {
    [sym_argument_list] = STATE(3920),
    [sym__name] = STATE(4158),
    [sym_alias_qualified_name] = STATE(4085),
    [sym__simple_name] = STATE(4085),
    [sym_qualified_name] = STATE(4085),
    [sym_generic_name] = STATE(3959),
    [sym_type] = STATE(3834),
    [sym_implicit_type] = STATE(4031),
    [sym_array_type] = STATE(4039),
    [sym__array_base_type] = STATE(8941),
    [sym_nullable_type] = STATE(3961),
    [sym_pointer_type] = STATE(3961),
    [sym__pointer_base_type] = STATE(9806),
    [sym_function_pointer_type] = STATE(3961),
    [sym_ref_type] = STATE(4031),
    [sym_scoped_type] = STATE(4031),
    [sym_tuple_type] = STATE(3962),
    [sym_identifier] = STATE(3889),
    [sym__reserved_identifier] = STATE(3911),
    [sym_preproc_region] = STATE(4427),
    [sym_preproc_endregion] = STATE(4427),
    [sym_preproc_line] = STATE(4427),
    [sym_preproc_pragma] = STATE(4427),
    [sym_preproc_nullable] = STATE(4427),
    [sym_preproc_error] = STATE(4427),
    [sym_preproc_warning] = STATE(4427),
    [sym_preproc_define] = STATE(4427),
    [sym_preproc_undef] = STATE(4427),
    [sym__identifier_token] = ACTIONS(4248),
    [anon_sym_alias] = ACTIONS(4250),
    [anon_sym_global] = ACTIONS(4250),
    [anon_sym_LBRACK] = ACTIONS(6162),
    [anon_sym_LPAREN] = ACTIONS(6164),
    [anon_sym_ref] = ACTIONS(4691),
    [anon_sym_LBRACE] = ACTIONS(6166),
    [anon_sym_delegate] = ACTIONS(6168),
    [anon_sym_file] = ACTIONS(4250),
    [anon_sym_where] = ACTIONS(4250),
    [anon_sym_notnull] = ACTIONS(4250),
    [anon_sym_unmanaged] = ACTIONS(4250),
    [anon_sym_scoped] = ACTIONS(6348),
    [anon_sym_var] = ACTIONS(6172),
    [sym_predefined_type] = ACTIONS(6174),
    [anon_sym_yield] = ACTIONS(4250),
    [anon_sym_when] = ACTIONS(4250),
    [anon_sym_from] = ACTIONS(4250),
    [anon_sym_into] = ACTIONS(4250),
    [anon_sym_join] = ACTIONS(4250),
    [anon_sym_on] = ACTIONS(4250),
    [anon_sym_equals] = ACTIONS(4250),
    [anon_sym_let] = ACTIONS(4250),
    [anon_sym_orderby] = ACTIONS(4250),
    [anon_sym_ascending] = ACTIONS(4250),
    [anon_sym_descending] = ACTIONS(4250),
    [anon_sym_group] = ACTIONS(4250),
    [anon_sym_by] = ACTIONS(4250),
    [anon_sym_select] = ACTIONS(4250),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4428] = {
    [sym_argument_list] = STATE(3920),
    [sym__name] = STATE(4158),
    [sym_alias_qualified_name] = STATE(4085),
    [sym__simple_name] = STATE(4085),
    [sym_qualified_name] = STATE(4085),
    [sym_generic_name] = STATE(3959),
    [sym_type] = STATE(3834),
    [sym_implicit_type] = STATE(4031),
    [sym_array_type] = STATE(4039),
    [sym__array_base_type] = STATE(8941),
    [sym_nullable_type] = STATE(3961),
    [sym_pointer_type] = STATE(3961),
    [sym__pointer_base_type] = STATE(9806),
    [sym_function_pointer_type] = STATE(3961),
    [sym_ref_type] = STATE(4031),
    [sym_scoped_type] = STATE(4031),
    [sym_tuple_type] = STATE(3962),
    [sym_identifier] = STATE(3889),
    [sym__reserved_identifier] = STATE(3911),
    [sym_preproc_region] = STATE(4428),
    [sym_preproc_endregion] = STATE(4428),
    [sym_preproc_line] = STATE(4428),
    [sym_preproc_pragma] = STATE(4428),
    [sym_preproc_nullable] = STATE(4428),
    [sym_preproc_error] = STATE(4428),
    [sym_preproc_warning] = STATE(4428),
    [sym_preproc_define] = STATE(4428),
    [sym_preproc_undef] = STATE(4428),
    [sym__identifier_token] = ACTIONS(4248),
    [anon_sym_alias] = ACTIONS(4250),
    [anon_sym_global] = ACTIONS(4250),
    [anon_sym_LBRACK] = ACTIONS(6162),
    [anon_sym_LPAREN] = ACTIONS(6164),
    [anon_sym_ref] = ACTIONS(4252),
    [anon_sym_LBRACE] = ACTIONS(6166),
    [anon_sym_delegate] = ACTIONS(6168),
    [anon_sym_file] = ACTIONS(4250),
    [anon_sym_where] = ACTIONS(4250),
    [anon_sym_notnull] = ACTIONS(4250),
    [anon_sym_unmanaged] = ACTIONS(4250),
    [anon_sym_scoped] = ACTIONS(6350),
    [anon_sym_var] = ACTIONS(6172),
    [sym_predefined_type] = ACTIONS(6174),
    [anon_sym_yield] = ACTIONS(4250),
    [anon_sym_when] = ACTIONS(4250),
    [anon_sym_from] = ACTIONS(4250),
    [anon_sym_into] = ACTIONS(4250),
    [anon_sym_join] = ACTIONS(4250),
    [anon_sym_on] = ACTIONS(4250),
    [anon_sym_equals] = ACTIONS(4250),
    [anon_sym_let] = ACTIONS(4250),
    [anon_sym_orderby] = ACTIONS(4250),
    [anon_sym_ascending] = ACTIONS(4250),
    [anon_sym_descending] = ACTIONS(4250),
    [anon_sym_group] = ACTIONS(4250),
    [anon_sym_by] = ACTIONS(4250),
    [anon_sym_select] = ACTIONS(4250),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4429] = {
    [sym_argument_list] = STATE(3594),
    [sym__name] = STATE(3744),
    [sym_alias_qualified_name] = STATE(3680),
    [sym__simple_name] = STATE(3680),
    [sym_qualified_name] = STATE(3680),
    [sym_generic_name] = STATE(3648),
    [sym_type] = STATE(4138),
    [sym_implicit_type] = STATE(3707),
    [sym_array_type] = STATE(3586),
    [sym__array_base_type] = STATE(8829),
    [sym_nullable_type] = STATE(3681),
    [sym_pointer_type] = STATE(3681),
    [sym__pointer_base_type] = STATE(9538),
    [sym_function_pointer_type] = STATE(3681),
    [sym_ref_type] = STATE(3707),
    [sym_scoped_type] = STATE(3707),
    [sym_tuple_type] = STATE(3631),
    [sym_identifier] = STATE(3590),
    [sym__reserved_identifier] = STATE(3625),
    [sym_preproc_region] = STATE(4429),
    [sym_preproc_endregion] = STATE(4429),
    [sym_preproc_line] = STATE(4429),
    [sym_preproc_pragma] = STATE(4429),
    [sym_preproc_nullable] = STATE(4429),
    [sym_preproc_error] = STATE(4429),
    [sym_preproc_warning] = STATE(4429),
    [sym_preproc_define] = STATE(4429),
    [sym_preproc_undef] = STATE(4429),
    [sym__identifier_token] = ACTIONS(4349),
    [anon_sym_alias] = ACTIONS(4351),
    [anon_sym_global] = ACTIONS(4351),
    [anon_sym_LBRACK] = ACTIONS(4506),
    [anon_sym_LPAREN] = ACTIONS(4508),
    [anon_sym_ref] = ACTIONS(4723),
    [anon_sym_LBRACE] = ACTIONS(4510),
    [anon_sym_delegate] = ACTIONS(4512),
    [anon_sym_file] = ACTIONS(4351),
    [anon_sym_where] = ACTIONS(4351),
    [anon_sym_notnull] = ACTIONS(4351),
    [anon_sym_unmanaged] = ACTIONS(4351),
    [anon_sym_scoped] = ACTIONS(6352),
    [anon_sym_var] = ACTIONS(4516),
    [sym_predefined_type] = ACTIONS(4518),
    [anon_sym_yield] = ACTIONS(4351),
    [anon_sym_when] = ACTIONS(4351),
    [anon_sym_from] = ACTIONS(4351),
    [anon_sym_into] = ACTIONS(4351),
    [anon_sym_join] = ACTIONS(4351),
    [anon_sym_on] = ACTIONS(4351),
    [anon_sym_equals] = ACTIONS(4351),
    [anon_sym_let] = ACTIONS(4351),
    [anon_sym_orderby] = ACTIONS(4351),
    [anon_sym_ascending] = ACTIONS(4351),
    [anon_sym_descending] = ACTIONS(4351),
    [anon_sym_group] = ACTIONS(4351),
    [anon_sym_by] = ACTIONS(4351),
    [anon_sym_select] = ACTIONS(4351),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4430] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4430),
    [sym_preproc_endregion] = STATE(4430),
    [sym_preproc_line] = STATE(4430),
    [sym_preproc_pragma] = STATE(4430),
    [sym_preproc_nullable] = STATE(4430),
    [sym_preproc_error] = STATE(4430),
    [sym_preproc_warning] = STATE(4430),
    [sym_preproc_define] = STATE(4430),
    [sym_preproc_undef] = STATE(4430),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(6342),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(6192),
    [anon_sym_GT] = ACTIONS(6192),
    [anon_sym_where] = ACTIONS(6342),
    [anon_sym_QMARK] = ACTIONS(6344),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(6196),
    [anon_sym_DASH] = ACTIONS(6196),
    [anon_sym_STAR] = ACTIONS(6198),
    [anon_sym_SLASH] = ACTIONS(6200),
    [anon_sym_PERCENT] = ACTIONS(6198),
    [anon_sym_CARET] = ACTIONS(6342),
    [anon_sym_PIPE] = ACTIONS(6344),
    [anon_sym_AMP] = ACTIONS(6206),
    [anon_sym_LT_LT] = ACTIONS(6208),
    [anon_sym_GT_GT] = ACTIONS(6210),
    [anon_sym_GT_GT_GT] = ACTIONS(6208),
    [anon_sym_EQ_EQ] = ACTIONS(6212),
    [anon_sym_BANG_EQ] = ACTIONS(6212),
    [anon_sym_GT_EQ] = ACTIONS(6214),
    [anon_sym_LT_EQ] = ACTIONS(6214),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(6216),
    [anon_sym_DOT_DOT] = ACTIONS(6218),
    [anon_sym_and] = ACTIONS(6342),
    [anon_sym_or] = ACTIONS(6344),
    [anon_sym_AMP_AMP] = ACTIONS(6342),
    [anon_sym_PIPE_PIPE] = ACTIONS(6342),
    [anon_sym_QMARK_QMARK] = ACTIONS(6342),
    [anon_sym_from] = ACTIONS(6342),
    [anon_sym_into] = ACTIONS(6342),
    [anon_sym_join] = ACTIONS(6342),
    [anon_sym_let] = ACTIONS(6342),
    [anon_sym_orderby] = ACTIONS(6342),
    [anon_sym_ascending] = ACTIONS(6342),
    [anon_sym_descending] = ACTIONS(6342),
    [anon_sym_group] = ACTIONS(6342),
    [anon_sym_select] = ACTIONS(6342),
    [anon_sym_as] = ACTIONS(6228),
    [anon_sym_is] = ACTIONS(6230),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(6232),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4431] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4431),
    [sym_preproc_endregion] = STATE(4431),
    [sym_preproc_line] = STATE(4431),
    [sym_preproc_pragma] = STATE(4431),
    [sym_preproc_nullable] = STATE(4431),
    [sym_preproc_error] = STATE(4431),
    [sym_preproc_warning] = STATE(4431),
    [sym_preproc_define] = STATE(4431),
    [sym_preproc_undef] = STATE(4431),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(6342),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(6192),
    [anon_sym_GT] = ACTIONS(6192),
    [anon_sym_where] = ACTIONS(6342),
    [anon_sym_QMARK] = ACTIONS(6344),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(6196),
    [anon_sym_DASH] = ACTIONS(6196),
    [anon_sym_STAR] = ACTIONS(6198),
    [anon_sym_SLASH] = ACTIONS(6200),
    [anon_sym_PERCENT] = ACTIONS(6198),
    [anon_sym_CARET] = ACTIONS(6202),
    [anon_sym_PIPE] = ACTIONS(6344),
    [anon_sym_AMP] = ACTIONS(6206),
    [anon_sym_LT_LT] = ACTIONS(6208),
    [anon_sym_GT_GT] = ACTIONS(6210),
    [anon_sym_GT_GT_GT] = ACTIONS(6208),
    [anon_sym_EQ_EQ] = ACTIONS(6212),
    [anon_sym_BANG_EQ] = ACTIONS(6212),
    [anon_sym_GT_EQ] = ACTIONS(6214),
    [anon_sym_LT_EQ] = ACTIONS(6214),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(6216),
    [anon_sym_DOT_DOT] = ACTIONS(6218),
    [anon_sym_and] = ACTIONS(6342),
    [anon_sym_or] = ACTIONS(6344),
    [anon_sym_AMP_AMP] = ACTIONS(6342),
    [anon_sym_PIPE_PIPE] = ACTIONS(6342),
    [anon_sym_QMARK_QMARK] = ACTIONS(6342),
    [anon_sym_from] = ACTIONS(6342),
    [anon_sym_into] = ACTIONS(6342),
    [anon_sym_join] = ACTIONS(6342),
    [anon_sym_let] = ACTIONS(6342),
    [anon_sym_orderby] = ACTIONS(6342),
    [anon_sym_ascending] = ACTIONS(6342),
    [anon_sym_descending] = ACTIONS(6342),
    [anon_sym_group] = ACTIONS(6342),
    [anon_sym_select] = ACTIONS(6342),
    [anon_sym_as] = ACTIONS(6228),
    [anon_sym_is] = ACTIONS(6230),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(6232),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4432] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4432),
    [sym_preproc_endregion] = STATE(4432),
    [sym_preproc_line] = STATE(4432),
    [sym_preproc_pragma] = STATE(4432),
    [sym_preproc_nullable] = STATE(4432),
    [sym_preproc_error] = STATE(4432),
    [sym_preproc_warning] = STATE(4432),
    [sym_preproc_define] = STATE(4432),
    [sym_preproc_undef] = STATE(4432),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(6342),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(6192),
    [anon_sym_GT] = ACTIONS(6192),
    [anon_sym_where] = ACTIONS(6342),
    [anon_sym_QMARK] = ACTIONS(6344),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(6196),
    [anon_sym_DASH] = ACTIONS(6196),
    [anon_sym_STAR] = ACTIONS(6198),
    [anon_sym_SLASH] = ACTIONS(6200),
    [anon_sym_PERCENT] = ACTIONS(6198),
    [anon_sym_CARET] = ACTIONS(6342),
    [anon_sym_PIPE] = ACTIONS(6344),
    [anon_sym_AMP] = ACTIONS(6344),
    [anon_sym_LT_LT] = ACTIONS(6208),
    [anon_sym_GT_GT] = ACTIONS(6210),
    [anon_sym_GT_GT_GT] = ACTIONS(6208),
    [anon_sym_EQ_EQ] = ACTIONS(6212),
    [anon_sym_BANG_EQ] = ACTIONS(6212),
    [anon_sym_GT_EQ] = ACTIONS(6214),
    [anon_sym_LT_EQ] = ACTIONS(6214),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(6216),
    [anon_sym_DOT_DOT] = ACTIONS(6218),
    [anon_sym_and] = ACTIONS(6342),
    [anon_sym_or] = ACTIONS(6344),
    [anon_sym_AMP_AMP] = ACTIONS(6342),
    [anon_sym_PIPE_PIPE] = ACTIONS(6342),
    [anon_sym_QMARK_QMARK] = ACTIONS(6342),
    [anon_sym_from] = ACTIONS(6342),
    [anon_sym_into] = ACTIONS(6342),
    [anon_sym_join] = ACTIONS(6342),
    [anon_sym_let] = ACTIONS(6342),
    [anon_sym_orderby] = ACTIONS(6342),
    [anon_sym_ascending] = ACTIONS(6342),
    [anon_sym_descending] = ACTIONS(6342),
    [anon_sym_group] = ACTIONS(6342),
    [anon_sym_select] = ACTIONS(6342),
    [anon_sym_as] = ACTIONS(6228),
    [anon_sym_is] = ACTIONS(6230),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(6232),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4433] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4433),
    [sym_preproc_endregion] = STATE(4433),
    [sym_preproc_line] = STATE(4433),
    [sym_preproc_pragma] = STATE(4433),
    [sym_preproc_nullable] = STATE(4433),
    [sym_preproc_error] = STATE(4433),
    [sym_preproc_warning] = STATE(4433),
    [sym_preproc_define] = STATE(4433),
    [sym_preproc_undef] = STATE(4433),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(6342),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(6192),
    [anon_sym_GT] = ACTIONS(6192),
    [anon_sym_where] = ACTIONS(6342),
    [anon_sym_QMARK] = ACTIONS(6344),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(6196),
    [anon_sym_DASH] = ACTIONS(6196),
    [anon_sym_STAR] = ACTIONS(6198),
    [anon_sym_SLASH] = ACTIONS(6200),
    [anon_sym_PERCENT] = ACTIONS(6198),
    [anon_sym_CARET] = ACTIONS(6342),
    [anon_sym_PIPE] = ACTIONS(6344),
    [anon_sym_AMP] = ACTIONS(6344),
    [anon_sym_LT_LT] = ACTIONS(6208),
    [anon_sym_GT_GT] = ACTIONS(6210),
    [anon_sym_GT_GT_GT] = ACTIONS(6208),
    [anon_sym_EQ_EQ] = ACTIONS(6342),
    [anon_sym_BANG_EQ] = ACTIONS(6342),
    [anon_sym_GT_EQ] = ACTIONS(6214),
    [anon_sym_LT_EQ] = ACTIONS(6214),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(6216),
    [anon_sym_DOT_DOT] = ACTIONS(6218),
    [anon_sym_and] = ACTIONS(6342),
    [anon_sym_or] = ACTIONS(6344),
    [anon_sym_AMP_AMP] = ACTIONS(6342),
    [anon_sym_PIPE_PIPE] = ACTIONS(6342),
    [anon_sym_QMARK_QMARK] = ACTIONS(6342),
    [anon_sym_from] = ACTIONS(6342),
    [anon_sym_into] = ACTIONS(6342),
    [anon_sym_join] = ACTIONS(6342),
    [anon_sym_let] = ACTIONS(6342),
    [anon_sym_orderby] = ACTIONS(6342),
    [anon_sym_ascending] = ACTIONS(6342),
    [anon_sym_descending] = ACTIONS(6342),
    [anon_sym_group] = ACTIONS(6342),
    [anon_sym_select] = ACTIONS(6342),
    [anon_sym_as] = ACTIONS(6228),
    [anon_sym_is] = ACTIONS(6230),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(6232),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4434] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4434),
    [sym_preproc_endregion] = STATE(4434),
    [sym_preproc_line] = STATE(4434),
    [sym_preproc_pragma] = STATE(4434),
    [sym_preproc_nullable] = STATE(4434),
    [sym_preproc_error] = STATE(4434),
    [sym_preproc_warning] = STATE(4434),
    [sym_preproc_define] = STATE(4434),
    [sym_preproc_undef] = STATE(4434),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(6342),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(6192),
    [anon_sym_GT] = ACTIONS(6192),
    [anon_sym_where] = ACTIONS(6342),
    [anon_sym_QMARK] = ACTIONS(6344),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(6196),
    [anon_sym_DASH] = ACTIONS(6196),
    [anon_sym_STAR] = ACTIONS(6198),
    [anon_sym_SLASH] = ACTIONS(6200),
    [anon_sym_PERCENT] = ACTIONS(6198),
    [anon_sym_CARET] = ACTIONS(6202),
    [anon_sym_PIPE] = ACTIONS(6204),
    [anon_sym_AMP] = ACTIONS(6206),
    [anon_sym_LT_LT] = ACTIONS(6208),
    [anon_sym_GT_GT] = ACTIONS(6210),
    [anon_sym_GT_GT_GT] = ACTIONS(6208),
    [anon_sym_EQ_EQ] = ACTIONS(6212),
    [anon_sym_BANG_EQ] = ACTIONS(6212),
    [anon_sym_GT_EQ] = ACTIONS(6214),
    [anon_sym_LT_EQ] = ACTIONS(6214),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(6216),
    [anon_sym_DOT_DOT] = ACTIONS(6218),
    [anon_sym_and] = ACTIONS(6342),
    [anon_sym_or] = ACTIONS(6344),
    [anon_sym_AMP_AMP] = ACTIONS(6342),
    [anon_sym_PIPE_PIPE] = ACTIONS(6342),
    [anon_sym_QMARK_QMARK] = ACTIONS(6342),
    [anon_sym_from] = ACTIONS(6342),
    [anon_sym_into] = ACTIONS(6342),
    [anon_sym_join] = ACTIONS(6342),
    [anon_sym_let] = ACTIONS(6342),
    [anon_sym_orderby] = ACTIONS(6342),
    [anon_sym_ascending] = ACTIONS(6342),
    [anon_sym_descending] = ACTIONS(6342),
    [anon_sym_group] = ACTIONS(6342),
    [anon_sym_select] = ACTIONS(6342),
    [anon_sym_as] = ACTIONS(6228),
    [anon_sym_is] = ACTIONS(6230),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(6232),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4435] = {
    [sym__name] = STATE(7943),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(8648),
    [sym_implicit_type] = STATE(8787),
    [sym_array_type] = STATE(8347),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9367),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(8787),
    [sym_scoped_type] = STATE(8787),
    [sym_tuple_type] = STATE(8173),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4435),
    [sym_preproc_endregion] = STATE(4435),
    [sym_preproc_line] = STATE(4435),
    [sym_preproc_pragma] = STATE(4435),
    [sym_preproc_nullable] = STATE(4435),
    [sym_preproc_error] = STATE(4435),
    [sym_preproc_warning] = STATE(4435),
    [sym_preproc_define] = STATE(4435),
    [sym_preproc_undef] = STATE(4435),
    [aux_sym_type_argument_list_repeat1] = STATE(8649),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_COMMA] = ACTIONS(5743),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(5745),
    [anon_sym_delegate] = ACTIONS(5747),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_GT] = ACTIONS(6354),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(5753),
    [anon_sym_var] = ACTIONS(5369),
    [sym_predefined_type] = ACTIONS(5755),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4436] = {
    [sym_preproc_region] = STATE(4436),
    [sym_preproc_endregion] = STATE(4436),
    [sym_preproc_line] = STATE(4436),
    [sym_preproc_pragma] = STATE(4436),
    [sym_preproc_nullable] = STATE(4436),
    [sym_preproc_error] = STATE(4436),
    [sym_preproc_warning] = STATE(4436),
    [sym_preproc_define] = STATE(4436),
    [sym_preproc_undef] = STATE(4436),
    [anon_sym_EQ] = ACTIONS(5998),
    [anon_sym_LBRACK] = ACTIONS(5286),
    [anon_sym_COMMA] = ACTIONS(5286),
    [anon_sym_LPAREN] = ACTIONS(5286),
    [anon_sym_RPAREN] = ACTIONS(6356),
    [anon_sym_LT] = ACTIONS(5288),
    [anon_sym_GT] = ACTIONS(5288),
    [anon_sym_QMARK] = ACTIONS(5288),
    [anon_sym_BANG] = ACTIONS(5288),
    [anon_sym_PLUS_PLUS] = ACTIONS(5286),
    [anon_sym_DASH_DASH] = ACTIONS(5286),
    [anon_sym_PLUS] = ACTIONS(5288),
    [anon_sym_DASH] = ACTIONS(5288),
    [anon_sym_STAR] = ACTIONS(5288),
    [anon_sym_SLASH] = ACTIONS(5288),
    [anon_sym_PERCENT] = ACTIONS(5288),
    [anon_sym_CARET] = ACTIONS(5288),
    [anon_sym_PIPE] = ACTIONS(5288),
    [anon_sym_AMP] = ACTIONS(5288),
    [anon_sym_LT_LT] = ACTIONS(5288),
    [anon_sym_GT_GT] = ACTIONS(5288),
    [anon_sym_GT_GT_GT] = ACTIONS(5288),
    [anon_sym_EQ_EQ] = ACTIONS(5286),
    [anon_sym_BANG_EQ] = ACTIONS(5286),
    [anon_sym_GT_EQ] = ACTIONS(5286),
    [anon_sym_LT_EQ] = ACTIONS(5286),
    [anon_sym_DOT] = ACTIONS(5288),
    [anon_sym_switch] = ACTIONS(5286),
    [anon_sym_DOT_DOT] = ACTIONS(5286),
    [anon_sym_PLUS_EQ] = ACTIONS(6000),
    [anon_sym_DASH_EQ] = ACTIONS(6000),
    [anon_sym_STAR_EQ] = ACTIONS(6000),
    [anon_sym_SLASH_EQ] = ACTIONS(6000),
    [anon_sym_PERCENT_EQ] = ACTIONS(6000),
    [anon_sym_AMP_EQ] = ACTIONS(6000),
    [anon_sym_CARET_EQ] = ACTIONS(6000),
    [anon_sym_PIPE_EQ] = ACTIONS(6000),
    [anon_sym_LT_LT_EQ] = ACTIONS(6000),
    [anon_sym_GT_GT_EQ] = ACTIONS(6000),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(6000),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(6000),
    [anon_sym_AMP_AMP] = ACTIONS(5286),
    [anon_sym_PIPE_PIPE] = ACTIONS(5286),
    [anon_sym_QMARK_QMARK] = ACTIONS(5288),
    [anon_sym_as] = ACTIONS(5286),
    [anon_sym_is] = ACTIONS(5286),
    [anon_sym_DASH_GT] = ACTIONS(5286),
    [anon_sym_with] = ACTIONS(5286),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4437] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4437),
    [sym_preproc_endregion] = STATE(4437),
    [sym_preproc_line] = STATE(4437),
    [sym_preproc_pragma] = STATE(4437),
    [sym_preproc_nullable] = STATE(4437),
    [sym_preproc_error] = STATE(4437),
    [sym_preproc_warning] = STATE(4437),
    [sym_preproc_define] = STATE(4437),
    [sym_preproc_undef] = STATE(4437),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(6342),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(6192),
    [anon_sym_GT] = ACTIONS(6192),
    [anon_sym_where] = ACTIONS(6342),
    [anon_sym_QMARK] = ACTIONS(6344),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(6196),
    [anon_sym_DASH] = ACTIONS(6196),
    [anon_sym_STAR] = ACTIONS(6198),
    [anon_sym_SLASH] = ACTIONS(6200),
    [anon_sym_PERCENT] = ACTIONS(6198),
    [anon_sym_CARET] = ACTIONS(6202),
    [anon_sym_PIPE] = ACTIONS(6204),
    [anon_sym_AMP] = ACTIONS(6206),
    [anon_sym_LT_LT] = ACTIONS(6208),
    [anon_sym_GT_GT] = ACTIONS(6210),
    [anon_sym_GT_GT_GT] = ACTIONS(6208),
    [anon_sym_EQ_EQ] = ACTIONS(6212),
    [anon_sym_BANG_EQ] = ACTIONS(6212),
    [anon_sym_GT_EQ] = ACTIONS(6214),
    [anon_sym_LT_EQ] = ACTIONS(6214),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(6216),
    [anon_sym_DOT_DOT] = ACTIONS(6218),
    [anon_sym_and] = ACTIONS(6342),
    [anon_sym_or] = ACTIONS(6344),
    [anon_sym_AMP_AMP] = ACTIONS(6222),
    [anon_sym_PIPE_PIPE] = ACTIONS(6342),
    [anon_sym_QMARK_QMARK] = ACTIONS(6342),
    [anon_sym_from] = ACTIONS(6342),
    [anon_sym_into] = ACTIONS(6342),
    [anon_sym_join] = ACTIONS(6342),
    [anon_sym_let] = ACTIONS(6342),
    [anon_sym_orderby] = ACTIONS(6342),
    [anon_sym_ascending] = ACTIONS(6342),
    [anon_sym_descending] = ACTIONS(6342),
    [anon_sym_group] = ACTIONS(6342),
    [anon_sym_select] = ACTIONS(6342),
    [anon_sym_as] = ACTIONS(6228),
    [anon_sym_is] = ACTIONS(6230),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(6232),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4438] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4438),
    [sym_preproc_endregion] = STATE(4438),
    [sym_preproc_line] = STATE(4438),
    [sym_preproc_pragma] = STATE(4438),
    [sym_preproc_nullable] = STATE(4438),
    [sym_preproc_error] = STATE(4438),
    [sym_preproc_warning] = STATE(4438),
    [sym_preproc_define] = STATE(4438),
    [sym_preproc_undef] = STATE(4438),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(6342),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(6192),
    [anon_sym_GT] = ACTIONS(6192),
    [anon_sym_where] = ACTIONS(6342),
    [anon_sym_QMARK] = ACTIONS(6344),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(6196),
    [anon_sym_DASH] = ACTIONS(6196),
    [anon_sym_STAR] = ACTIONS(6198),
    [anon_sym_SLASH] = ACTIONS(6200),
    [anon_sym_PERCENT] = ACTIONS(6198),
    [anon_sym_CARET] = ACTIONS(6202),
    [anon_sym_PIPE] = ACTIONS(6204),
    [anon_sym_AMP] = ACTIONS(6206),
    [anon_sym_LT_LT] = ACTIONS(6208),
    [anon_sym_GT_GT] = ACTIONS(6210),
    [anon_sym_GT_GT_GT] = ACTIONS(6208),
    [anon_sym_EQ_EQ] = ACTIONS(6212),
    [anon_sym_BANG_EQ] = ACTIONS(6212),
    [anon_sym_GT_EQ] = ACTIONS(6214),
    [anon_sym_LT_EQ] = ACTIONS(6214),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(6216),
    [anon_sym_DOT_DOT] = ACTIONS(6218),
    [anon_sym_and] = ACTIONS(6342),
    [anon_sym_or] = ACTIONS(6344),
    [anon_sym_AMP_AMP] = ACTIONS(6222),
    [anon_sym_PIPE_PIPE] = ACTIONS(6224),
    [anon_sym_QMARK_QMARK] = ACTIONS(6226),
    [anon_sym_from] = ACTIONS(6342),
    [anon_sym_into] = ACTIONS(6342),
    [anon_sym_join] = ACTIONS(6342),
    [anon_sym_let] = ACTIONS(6342),
    [anon_sym_orderby] = ACTIONS(6342),
    [anon_sym_ascending] = ACTIONS(6342),
    [anon_sym_descending] = ACTIONS(6342),
    [anon_sym_group] = ACTIONS(6342),
    [anon_sym_select] = ACTIONS(6342),
    [anon_sym_as] = ACTIONS(6228),
    [anon_sym_is] = ACTIONS(6230),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(6232),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4439] = {
    [sym_argument_list] = STATE(3594),
    [sym__name] = STATE(3744),
    [sym_alias_qualified_name] = STATE(3680),
    [sym__simple_name] = STATE(3680),
    [sym_qualified_name] = STATE(3680),
    [sym_generic_name] = STATE(3648),
    [sym_type] = STATE(4930),
    [sym_implicit_type] = STATE(3707),
    [sym_array_type] = STATE(3586),
    [sym__array_base_type] = STATE(8829),
    [sym_nullable_type] = STATE(3681),
    [sym_pointer_type] = STATE(3681),
    [sym__pointer_base_type] = STATE(9538),
    [sym_function_pointer_type] = STATE(3681),
    [sym_ref_type] = STATE(3707),
    [sym_scoped_type] = STATE(3707),
    [sym_tuple_type] = STATE(3631),
    [sym_identifier] = STATE(3590),
    [sym__reserved_identifier] = STATE(3625),
    [sym_preproc_region] = STATE(4439),
    [sym_preproc_endregion] = STATE(4439),
    [sym_preproc_line] = STATE(4439),
    [sym_preproc_pragma] = STATE(4439),
    [sym_preproc_nullable] = STATE(4439),
    [sym_preproc_error] = STATE(4439),
    [sym_preproc_warning] = STATE(4439),
    [sym_preproc_define] = STATE(4439),
    [sym_preproc_undef] = STATE(4439),
    [sym__identifier_token] = ACTIONS(4349),
    [anon_sym_alias] = ACTIONS(4351),
    [anon_sym_global] = ACTIONS(4351),
    [anon_sym_LBRACK] = ACTIONS(4506),
    [anon_sym_LPAREN] = ACTIONS(6358),
    [anon_sym_ref] = ACTIONS(4678),
    [anon_sym_LBRACE] = ACTIONS(4510),
    [anon_sym_delegate] = ACTIONS(4512),
    [anon_sym_file] = ACTIONS(4351),
    [anon_sym_where] = ACTIONS(4351),
    [anon_sym_notnull] = ACTIONS(4351),
    [anon_sym_unmanaged] = ACTIONS(4351),
    [anon_sym_scoped] = ACTIONS(6360),
    [anon_sym_var] = ACTIONS(4516),
    [sym_predefined_type] = ACTIONS(4518),
    [anon_sym_yield] = ACTIONS(4351),
    [anon_sym_when] = ACTIONS(4351),
    [anon_sym_from] = ACTIONS(4351),
    [anon_sym_into] = ACTIONS(4351),
    [anon_sym_join] = ACTIONS(4351),
    [anon_sym_on] = ACTIONS(4351),
    [anon_sym_equals] = ACTIONS(4351),
    [anon_sym_let] = ACTIONS(4351),
    [anon_sym_orderby] = ACTIONS(4351),
    [anon_sym_ascending] = ACTIONS(4351),
    [anon_sym_descending] = ACTIONS(4351),
    [anon_sym_group] = ACTIONS(4351),
    [anon_sym_by] = ACTIONS(4351),
    [anon_sym_select] = ACTIONS(4351),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4440] = {
    [sym_argument_list] = STATE(4446),
    [sym__name] = STATE(2992),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2956),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2944),
    [sym_type] = STATE(4361),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(4405),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_identifier] = STATE(2920),
    [sym__reserved_identifier] = STATE(2928),
    [sym_preproc_region] = STATE(4440),
    [sym_preproc_endregion] = STATE(4440),
    [sym_preproc_line] = STATE(4440),
    [sym_preproc_pragma] = STATE(4440),
    [sym_preproc_nullable] = STATE(4440),
    [sym_preproc_error] = STATE(4440),
    [sym_preproc_warning] = STATE(4440),
    [sym_preproc_define] = STATE(4440),
    [sym_preproc_undef] = STATE(4440),
    [sym__identifier_token] = ACTIONS(4536),
    [anon_sym_alias] = ACTIONS(4538),
    [anon_sym_global] = ACTIONS(4538),
    [anon_sym_LBRACK] = ACTIONS(6238),
    [anon_sym_LPAREN] = ACTIONS(6240),
    [anon_sym_ref] = ACTIONS(4540),
    [anon_sym_LBRACE] = ACTIONS(6242),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_file] = ACTIONS(4538),
    [anon_sym_where] = ACTIONS(4538),
    [anon_sym_notnull] = ACTIONS(4538),
    [anon_sym_unmanaged] = ACTIONS(4538),
    [anon_sym_scoped] = ACTIONS(6362),
    [anon_sym_var] = ACTIONS(6246),
    [sym_predefined_type] = ACTIONS(6248),
    [anon_sym_yield] = ACTIONS(4538),
    [anon_sym_when] = ACTIONS(4538),
    [anon_sym_from] = ACTIONS(4538),
    [anon_sym_into] = ACTIONS(4538),
    [anon_sym_join] = ACTIONS(4538),
    [anon_sym_on] = ACTIONS(4538),
    [anon_sym_equals] = ACTIONS(4538),
    [anon_sym_let] = ACTIONS(4538),
    [anon_sym_orderby] = ACTIONS(4538),
    [anon_sym_ascending] = ACTIONS(4538),
    [anon_sym_descending] = ACTIONS(4538),
    [anon_sym_group] = ACTIONS(4538),
    [anon_sym_by] = ACTIONS(4538),
    [anon_sym_select] = ACTIONS(4538),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4441] = {
    [sym_preproc_region] = STATE(4441),
    [sym_preproc_endregion] = STATE(4441),
    [sym_preproc_line] = STATE(4441),
    [sym_preproc_pragma] = STATE(4441),
    [sym_preproc_nullable] = STATE(4441),
    [sym_preproc_error] = STATE(4441),
    [sym_preproc_warning] = STATE(4441),
    [sym_preproc_define] = STATE(4441),
    [sym_preproc_undef] = STATE(4441),
    [sym__identifier_token] = ACTIONS(5697),
    [anon_sym_extern] = ACTIONS(5697),
    [anon_sym_alias] = ACTIONS(5697),
    [anon_sym_global] = ACTIONS(5697),
    [anon_sym_unsafe] = ACTIONS(5697),
    [anon_sym_static] = ACTIONS(5697),
    [anon_sym_LBRACK] = ACTIONS(5699),
    [anon_sym_abstract] = ACTIONS(5697),
    [anon_sym_async] = ACTIONS(5697),
    [anon_sym_const] = ACTIONS(5697),
    [anon_sym_file] = ACTIONS(5697),
    [anon_sym_fixed] = ACTIONS(5697),
    [anon_sym_internal] = ACTIONS(5697),
    [anon_sym_new] = ACTIONS(5697),
    [anon_sym_override] = ACTIONS(5697),
    [anon_sym_partial] = ACTIONS(5697),
    [anon_sym_private] = ACTIONS(5697),
    [anon_sym_protected] = ACTIONS(5697),
    [anon_sym_public] = ACTIONS(5697),
    [anon_sym_readonly] = ACTIONS(5697),
    [anon_sym_required] = ACTIONS(5697),
    [anon_sym_sealed] = ACTIONS(5697),
    [anon_sym_virtual] = ACTIONS(5697),
    [anon_sym_volatile] = ACTIONS(5697),
    [anon_sym_where] = ACTIONS(5697),
    [anon_sym_notnull] = ACTIONS(5697),
    [anon_sym_unmanaged] = ACTIONS(5697),
    [anon_sym_get] = ACTIONS(5697),
    [anon_sym_set] = ACTIONS(5697),
    [anon_sym_add] = ACTIONS(5697),
    [anon_sym_remove] = ACTIONS(5697),
    [anon_sym_init] = ACTIONS(5697),
    [anon_sym_scoped] = ACTIONS(5697),
    [anon_sym_var] = ACTIONS(5697),
    [anon_sym_yield] = ACTIONS(5697),
    [anon_sym_when] = ACTIONS(5697),
    [anon_sym_from] = ACTIONS(5697),
    [anon_sym_into] = ACTIONS(5697),
    [anon_sym_join] = ACTIONS(5697),
    [anon_sym_on] = ACTIONS(5697),
    [anon_sym_equals] = ACTIONS(5697),
    [anon_sym_let] = ACTIONS(5697),
    [anon_sym_orderby] = ACTIONS(5697),
    [anon_sym_ascending] = ACTIONS(5697),
    [anon_sym_descending] = ACTIONS(5697),
    [anon_sym_group] = ACTIONS(5697),
    [anon_sym_by] = ACTIONS(5697),
    [anon_sym_select] = ACTIONS(5697),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4442] = {
    [sym_preproc_region] = STATE(4442),
    [sym_preproc_endregion] = STATE(4442),
    [sym_preproc_line] = STATE(4442),
    [sym_preproc_pragma] = STATE(4442),
    [sym_preproc_nullable] = STATE(4442),
    [sym_preproc_error] = STATE(4442),
    [sym_preproc_warning] = STATE(4442),
    [sym_preproc_define] = STATE(4442),
    [sym_preproc_undef] = STATE(4442),
    [sym__identifier_token] = ACTIONS(5723),
    [anon_sym_extern] = ACTIONS(5723),
    [anon_sym_alias] = ACTIONS(5723),
    [anon_sym_global] = ACTIONS(5723),
    [anon_sym_unsafe] = ACTIONS(5723),
    [anon_sym_static] = ACTIONS(5723),
    [anon_sym_LBRACK] = ACTIONS(5725),
    [anon_sym_abstract] = ACTIONS(5723),
    [anon_sym_async] = ACTIONS(5723),
    [anon_sym_const] = ACTIONS(5723),
    [anon_sym_file] = ACTIONS(5723),
    [anon_sym_fixed] = ACTIONS(5723),
    [anon_sym_internal] = ACTIONS(5723),
    [anon_sym_new] = ACTIONS(5723),
    [anon_sym_override] = ACTIONS(5723),
    [anon_sym_partial] = ACTIONS(5723),
    [anon_sym_private] = ACTIONS(5723),
    [anon_sym_protected] = ACTIONS(5723),
    [anon_sym_public] = ACTIONS(5723),
    [anon_sym_readonly] = ACTIONS(5723),
    [anon_sym_required] = ACTIONS(5723),
    [anon_sym_sealed] = ACTIONS(5723),
    [anon_sym_virtual] = ACTIONS(5723),
    [anon_sym_volatile] = ACTIONS(5723),
    [anon_sym_where] = ACTIONS(5723),
    [anon_sym_notnull] = ACTIONS(5723),
    [anon_sym_unmanaged] = ACTIONS(5723),
    [anon_sym_get] = ACTIONS(5723),
    [anon_sym_set] = ACTIONS(5723),
    [anon_sym_add] = ACTIONS(5723),
    [anon_sym_remove] = ACTIONS(5723),
    [anon_sym_init] = ACTIONS(5723),
    [anon_sym_scoped] = ACTIONS(5723),
    [anon_sym_var] = ACTIONS(5723),
    [anon_sym_yield] = ACTIONS(5723),
    [anon_sym_when] = ACTIONS(5723),
    [anon_sym_from] = ACTIONS(5723),
    [anon_sym_into] = ACTIONS(5723),
    [anon_sym_join] = ACTIONS(5723),
    [anon_sym_on] = ACTIONS(5723),
    [anon_sym_equals] = ACTIONS(5723),
    [anon_sym_let] = ACTIONS(5723),
    [anon_sym_orderby] = ACTIONS(5723),
    [anon_sym_ascending] = ACTIONS(5723),
    [anon_sym_descending] = ACTIONS(5723),
    [anon_sym_group] = ACTIONS(5723),
    [anon_sym_by] = ACTIONS(5723),
    [anon_sym_select] = ACTIONS(5723),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4443] = {
    [sym__name] = STATE(7943),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(8643),
    [sym_implicit_type] = STATE(8787),
    [sym_array_type] = STATE(8347),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9367),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(8787),
    [sym_scoped_type] = STATE(8787),
    [sym_tuple_type] = STATE(8173),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4443),
    [sym_preproc_endregion] = STATE(4443),
    [sym_preproc_line] = STATE(4443),
    [sym_preproc_pragma] = STATE(4443),
    [sym_preproc_nullable] = STATE(4443),
    [sym_preproc_error] = STATE(4443),
    [sym_preproc_warning] = STATE(4443),
    [sym_preproc_define] = STATE(4443),
    [sym_preproc_undef] = STATE(4443),
    [aux_sym_type_argument_list_repeat1] = STATE(8644),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_COMMA] = ACTIONS(5743),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(5745),
    [anon_sym_delegate] = ACTIONS(5747),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_GT] = ACTIONS(6364),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(5753),
    [anon_sym_var] = ACTIONS(5369),
    [sym_predefined_type] = ACTIONS(5755),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4444] = {
    [sym_argument_list] = STATE(3863),
    [sym__name] = STATE(3904),
    [sym_alias_qualified_name] = STATE(3924),
    [sym__simple_name] = STATE(3924),
    [sym_qualified_name] = STATE(3924),
    [sym_generic_name] = STATE(3900),
    [sym_type] = STATE(3806),
    [sym_implicit_type] = STATE(3943),
    [sym_array_type] = STATE(3866),
    [sym__array_base_type] = STATE(8893),
    [sym_nullable_type] = STATE(3885),
    [sym_pointer_type] = STATE(3885),
    [sym__pointer_base_type] = STATE(9659),
    [sym_function_pointer_type] = STATE(3885),
    [sym_ref_type] = STATE(3943),
    [sym_scoped_type] = STATE(3943),
    [sym_tuple_type] = STATE(3880),
    [sym_identifier] = STATE(3808),
    [sym__reserved_identifier] = STATE(3871),
    [sym_preproc_region] = STATE(4444),
    [sym_preproc_endregion] = STATE(4444),
    [sym_preproc_line] = STATE(4444),
    [sym_preproc_pragma] = STATE(4444),
    [sym_preproc_nullable] = STATE(4444),
    [sym_preproc_error] = STATE(4444),
    [sym_preproc_warning] = STATE(4444),
    [sym_preproc_define] = STATE(4444),
    [sym_preproc_undef] = STATE(4444),
    [sym__identifier_token] = ACTIONS(4223),
    [anon_sym_alias] = ACTIONS(4225),
    [anon_sym_global] = ACTIONS(4225),
    [anon_sym_LBRACK] = ACTIONS(6176),
    [anon_sym_LPAREN] = ACTIONS(6178),
    [anon_sym_ref] = ACTIONS(4638),
    [anon_sym_LBRACE] = ACTIONS(6180),
    [anon_sym_delegate] = ACTIONS(6182),
    [anon_sym_file] = ACTIONS(4225),
    [anon_sym_where] = ACTIONS(4225),
    [anon_sym_notnull] = ACTIONS(4225),
    [anon_sym_unmanaged] = ACTIONS(4225),
    [anon_sym_scoped] = ACTIONS(6366),
    [anon_sym_var] = ACTIONS(6186),
    [sym_predefined_type] = ACTIONS(6188),
    [anon_sym_yield] = ACTIONS(4225),
    [anon_sym_when] = ACTIONS(4225),
    [anon_sym_from] = ACTIONS(4225),
    [anon_sym_into] = ACTIONS(4225),
    [anon_sym_join] = ACTIONS(4225),
    [anon_sym_on] = ACTIONS(4225),
    [anon_sym_equals] = ACTIONS(4225),
    [anon_sym_let] = ACTIONS(4225),
    [anon_sym_orderby] = ACTIONS(4225),
    [anon_sym_ascending] = ACTIONS(4225),
    [anon_sym_descending] = ACTIONS(4225),
    [anon_sym_group] = ACTIONS(4225),
    [anon_sym_by] = ACTIONS(4225),
    [anon_sym_select] = ACTIONS(4225),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4445] = {
    [sym__name] = STATE(7943),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(8662),
    [sym_implicit_type] = STATE(8787),
    [sym_array_type] = STATE(8347),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9367),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(8787),
    [sym_scoped_type] = STATE(8787),
    [sym_tuple_type] = STATE(8173),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4445),
    [sym_preproc_endregion] = STATE(4445),
    [sym_preproc_line] = STATE(4445),
    [sym_preproc_pragma] = STATE(4445),
    [sym_preproc_nullable] = STATE(4445),
    [sym_preproc_error] = STATE(4445),
    [sym_preproc_warning] = STATE(4445),
    [sym_preproc_define] = STATE(4445),
    [sym_preproc_undef] = STATE(4445),
    [aux_sym_type_argument_list_repeat1] = STATE(8664),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_COMMA] = ACTIONS(5743),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(5745),
    [anon_sym_delegate] = ACTIONS(5747),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_GT] = ACTIONS(6368),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(5753),
    [anon_sym_var] = ACTIONS(5369),
    [sym_predefined_type] = ACTIONS(5755),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4446] = {
    [sym_initializer_expression] = STATE(4593),
    [sym_preproc_region] = STATE(4446),
    [sym_preproc_endregion] = STATE(4446),
    [sym_preproc_line] = STATE(4446),
    [sym_preproc_pragma] = STATE(4446),
    [sym_preproc_nullable] = STATE(4446),
    [sym_preproc_error] = STATE(4446),
    [sym_preproc_warning] = STATE(4446),
    [sym_preproc_define] = STATE(4446),
    [sym_preproc_undef] = STATE(4446),
    [anon_sym_LBRACK] = ACTIONS(5315),
    [anon_sym_COMMA] = ACTIONS(5315),
    [anon_sym_LPAREN] = ACTIONS(5315),
    [anon_sym_LBRACE] = ACTIONS(1691),
    [anon_sym_LT] = ACTIONS(5317),
    [anon_sym_GT] = ACTIONS(5317),
    [anon_sym_where] = ACTIONS(5315),
    [anon_sym_QMARK] = ACTIONS(5317),
    [anon_sym_BANG] = ACTIONS(5317),
    [anon_sym_PLUS_PLUS] = ACTIONS(5315),
    [anon_sym_DASH_DASH] = ACTIONS(5315),
    [anon_sym_PLUS] = ACTIONS(5317),
    [anon_sym_DASH] = ACTIONS(5317),
    [anon_sym_STAR] = ACTIONS(5315),
    [anon_sym_SLASH] = ACTIONS(5317),
    [anon_sym_PERCENT] = ACTIONS(5315),
    [anon_sym_CARET] = ACTIONS(5315),
    [anon_sym_PIPE] = ACTIONS(5317),
    [anon_sym_AMP] = ACTIONS(5317),
    [anon_sym_LT_LT] = ACTIONS(5315),
    [anon_sym_GT_GT] = ACTIONS(5317),
    [anon_sym_GT_GT_GT] = ACTIONS(5315),
    [anon_sym_EQ_EQ] = ACTIONS(5315),
    [anon_sym_BANG_EQ] = ACTIONS(5315),
    [anon_sym_GT_EQ] = ACTIONS(5315),
    [anon_sym_LT_EQ] = ACTIONS(5315),
    [anon_sym_DOT] = ACTIONS(5317),
    [anon_sym_switch] = ACTIONS(5315),
    [anon_sym_DOT_DOT] = ACTIONS(5315),
    [anon_sym_and] = ACTIONS(5315),
    [anon_sym_or] = ACTIONS(5317),
    [anon_sym_AMP_AMP] = ACTIONS(5315),
    [anon_sym_PIPE_PIPE] = ACTIONS(5315),
    [anon_sym_QMARK_QMARK] = ACTIONS(5315),
    [anon_sym_from] = ACTIONS(5315),
    [anon_sym_into] = ACTIONS(5315),
    [anon_sym_join] = ACTIONS(5315),
    [anon_sym_let] = ACTIONS(5315),
    [anon_sym_orderby] = ACTIONS(5315),
    [anon_sym_ascending] = ACTIONS(5315),
    [anon_sym_descending] = ACTIONS(5315),
    [anon_sym_group] = ACTIONS(5315),
    [anon_sym_select] = ACTIONS(5315),
    [anon_sym_as] = ACTIONS(5317),
    [anon_sym_is] = ACTIONS(5315),
    [anon_sym_DASH_GT] = ACTIONS(5315),
    [anon_sym_with] = ACTIONS(5315),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4447] = {
    [sym__name] = STATE(7943),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(8539),
    [sym_implicit_type] = STATE(8787),
    [sym_array_type] = STATE(8347),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9367),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(8787),
    [sym_scoped_type] = STATE(8787),
    [sym_tuple_type] = STATE(8173),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4447),
    [sym_preproc_endregion] = STATE(4447),
    [sym_preproc_line] = STATE(4447),
    [sym_preproc_pragma] = STATE(4447),
    [sym_preproc_nullable] = STATE(4447),
    [sym_preproc_error] = STATE(4447),
    [sym_preproc_warning] = STATE(4447),
    [sym_preproc_define] = STATE(4447),
    [sym_preproc_undef] = STATE(4447),
    [aux_sym_type_argument_list_repeat1] = STATE(8540),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_COMMA] = ACTIONS(5743),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(5745),
    [anon_sym_delegate] = ACTIONS(5747),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_GT] = ACTIONS(6370),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(5753),
    [anon_sym_var] = ACTIONS(5369),
    [sym_predefined_type] = ACTIONS(5755),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4448] = {
    [sym_preproc_region] = STATE(4448),
    [sym_preproc_endregion] = STATE(4448),
    [sym_preproc_line] = STATE(4448),
    [sym_preproc_pragma] = STATE(4448),
    [sym_preproc_nullable] = STATE(4448),
    [sym_preproc_error] = STATE(4448),
    [sym_preproc_warning] = STATE(4448),
    [sym_preproc_define] = STATE(4448),
    [sym_preproc_undef] = STATE(4448),
    [sym__identifier_token] = ACTIONS(5701),
    [anon_sym_extern] = ACTIONS(5701),
    [anon_sym_alias] = ACTIONS(5701),
    [anon_sym_global] = ACTIONS(5701),
    [anon_sym_unsafe] = ACTIONS(5701),
    [anon_sym_static] = ACTIONS(5701),
    [anon_sym_LBRACK] = ACTIONS(5703),
    [anon_sym_abstract] = ACTIONS(5701),
    [anon_sym_async] = ACTIONS(5701),
    [anon_sym_const] = ACTIONS(5701),
    [anon_sym_file] = ACTIONS(5701),
    [anon_sym_fixed] = ACTIONS(5701),
    [anon_sym_internal] = ACTIONS(5701),
    [anon_sym_new] = ACTIONS(5701),
    [anon_sym_override] = ACTIONS(5701),
    [anon_sym_partial] = ACTIONS(5701),
    [anon_sym_private] = ACTIONS(5701),
    [anon_sym_protected] = ACTIONS(5701),
    [anon_sym_public] = ACTIONS(5701),
    [anon_sym_readonly] = ACTIONS(5701),
    [anon_sym_required] = ACTIONS(5701),
    [anon_sym_sealed] = ACTIONS(5701),
    [anon_sym_virtual] = ACTIONS(5701),
    [anon_sym_volatile] = ACTIONS(5701),
    [anon_sym_where] = ACTIONS(5701),
    [anon_sym_notnull] = ACTIONS(5701),
    [anon_sym_unmanaged] = ACTIONS(5701),
    [anon_sym_get] = ACTIONS(5701),
    [anon_sym_set] = ACTIONS(5701),
    [anon_sym_add] = ACTIONS(5701),
    [anon_sym_remove] = ACTIONS(5701),
    [anon_sym_init] = ACTIONS(5701),
    [anon_sym_scoped] = ACTIONS(5701),
    [anon_sym_var] = ACTIONS(5701),
    [anon_sym_yield] = ACTIONS(5701),
    [anon_sym_when] = ACTIONS(5701),
    [anon_sym_from] = ACTIONS(5701),
    [anon_sym_into] = ACTIONS(5701),
    [anon_sym_join] = ACTIONS(5701),
    [anon_sym_on] = ACTIONS(5701),
    [anon_sym_equals] = ACTIONS(5701),
    [anon_sym_let] = ACTIONS(5701),
    [anon_sym_orderby] = ACTIONS(5701),
    [anon_sym_ascending] = ACTIONS(5701),
    [anon_sym_descending] = ACTIONS(5701),
    [anon_sym_group] = ACTIONS(5701),
    [anon_sym_by] = ACTIONS(5701),
    [anon_sym_select] = ACTIONS(5701),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4449] = {
    [sym_argument_list] = STATE(3594),
    [sym__name] = STATE(3744),
    [sym_alias_qualified_name] = STATE(3680),
    [sym__simple_name] = STATE(3680),
    [sym_qualified_name] = STATE(3680),
    [sym_generic_name] = STATE(3648),
    [sym_type] = STATE(4138),
    [sym_implicit_type] = STATE(3707),
    [sym_array_type] = STATE(5141),
    [sym__array_base_type] = STATE(8829),
    [sym_nullable_type] = STATE(3681),
    [sym_pointer_type] = STATE(3681),
    [sym__pointer_base_type] = STATE(9538),
    [sym_function_pointer_type] = STATE(3681),
    [sym_ref_type] = STATE(3707),
    [sym_scoped_type] = STATE(3707),
    [sym_tuple_type] = STATE(3631),
    [sym_identifier] = STATE(3590),
    [sym__reserved_identifier] = STATE(3625),
    [sym_preproc_region] = STATE(4449),
    [sym_preproc_endregion] = STATE(4449),
    [sym_preproc_line] = STATE(4449),
    [sym_preproc_pragma] = STATE(4449),
    [sym_preproc_nullable] = STATE(4449),
    [sym_preproc_error] = STATE(4449),
    [sym_preproc_warning] = STATE(4449),
    [sym_preproc_define] = STATE(4449),
    [sym_preproc_undef] = STATE(4449),
    [sym__identifier_token] = ACTIONS(4349),
    [anon_sym_alias] = ACTIONS(4351),
    [anon_sym_global] = ACTIONS(4351),
    [anon_sym_LBRACK] = ACTIONS(4506),
    [anon_sym_LPAREN] = ACTIONS(4508),
    [anon_sym_ref] = ACTIONS(4353),
    [anon_sym_LBRACE] = ACTIONS(4510),
    [anon_sym_delegate] = ACTIONS(4512),
    [anon_sym_file] = ACTIONS(4351),
    [anon_sym_where] = ACTIONS(4351),
    [anon_sym_notnull] = ACTIONS(4351),
    [anon_sym_unmanaged] = ACTIONS(4351),
    [anon_sym_scoped] = ACTIONS(4514),
    [anon_sym_var] = ACTIONS(4516),
    [sym_predefined_type] = ACTIONS(4518),
    [anon_sym_yield] = ACTIONS(4351),
    [anon_sym_when] = ACTIONS(4351),
    [anon_sym_from] = ACTIONS(4351),
    [anon_sym_into] = ACTIONS(4351),
    [anon_sym_join] = ACTIONS(4351),
    [anon_sym_on] = ACTIONS(4351),
    [anon_sym_equals] = ACTIONS(4351),
    [anon_sym_let] = ACTIONS(4351),
    [anon_sym_orderby] = ACTIONS(4351),
    [anon_sym_ascending] = ACTIONS(4351),
    [anon_sym_descending] = ACTIONS(4351),
    [anon_sym_group] = ACTIONS(4351),
    [anon_sym_by] = ACTIONS(4351),
    [anon_sym_select] = ACTIONS(4351),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4450] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4450),
    [sym_preproc_endregion] = STATE(4450),
    [sym_preproc_line] = STATE(4450),
    [sym_preproc_pragma] = STATE(4450),
    [sym_preproc_nullable] = STATE(4450),
    [sym_preproc_error] = STATE(4450),
    [sym_preproc_warning] = STATE(4450),
    [sym_preproc_define] = STATE(4450),
    [sym_preproc_undef] = STATE(4450),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(1227),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(1229),
    [anon_sym_GT] = ACTIONS(1229),
    [anon_sym_where] = ACTIONS(1227),
    [anon_sym_QMARK] = ACTIONS(1229),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(1229),
    [anon_sym_DASH] = ACTIONS(1229),
    [anon_sym_STAR] = ACTIONS(1227),
    [anon_sym_SLASH] = ACTIONS(1229),
    [anon_sym_PERCENT] = ACTIONS(1227),
    [anon_sym_CARET] = ACTIONS(1227),
    [anon_sym_PIPE] = ACTIONS(1229),
    [anon_sym_AMP] = ACTIONS(1229),
    [anon_sym_LT_LT] = ACTIONS(1227),
    [anon_sym_GT_GT] = ACTIONS(1229),
    [anon_sym_GT_GT_GT] = ACTIONS(1227),
    [anon_sym_EQ_EQ] = ACTIONS(1227),
    [anon_sym_BANG_EQ] = ACTIONS(1227),
    [anon_sym_GT_EQ] = ACTIONS(1227),
    [anon_sym_LT_EQ] = ACTIONS(1227),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(1227),
    [anon_sym_DOT_DOT] = ACTIONS(6218),
    [anon_sym_and] = ACTIONS(1227),
    [anon_sym_or] = ACTIONS(1229),
    [anon_sym_AMP_AMP] = ACTIONS(1227),
    [anon_sym_PIPE_PIPE] = ACTIONS(1227),
    [anon_sym_QMARK_QMARK] = ACTIONS(1227),
    [anon_sym_from] = ACTIONS(1227),
    [anon_sym_into] = ACTIONS(1227),
    [anon_sym_join] = ACTIONS(1227),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_orderby] = ACTIONS(1227),
    [anon_sym_ascending] = ACTIONS(1227),
    [anon_sym_descending] = ACTIONS(1227),
    [anon_sym_group] = ACTIONS(1227),
    [anon_sym_select] = ACTIONS(1227),
    [anon_sym_as] = ACTIONS(1229),
    [anon_sym_is] = ACTIONS(1227),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(1227),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4451] = {
    [sym_argument_list] = STATE(3576),
    [sym__name] = STATE(4343),
    [sym_alias_qualified_name] = STATE(3588),
    [sym__simple_name] = STATE(3588),
    [sym_qualified_name] = STATE(3588),
    [sym_generic_name] = STATE(3597),
    [sym_type] = STATE(3557),
    [sym_implicit_type] = STATE(3596),
    [sym_array_type] = STATE(4151),
    [sym__array_base_type] = STATE(8805),
    [sym_nullable_type] = STATE(3612),
    [sym_pointer_type] = STATE(3612),
    [sym__pointer_base_type] = STATE(9071),
    [sym_function_pointer_type] = STATE(3612),
    [sym_ref_type] = STATE(3596),
    [sym_scoped_type] = STATE(3596),
    [sym_tuple_type] = STATE(3621),
    [sym_identifier] = STATE(4004),
    [sym__reserved_identifier] = STATE(3572),
    [sym_preproc_region] = STATE(4451),
    [sym_preproc_endregion] = STATE(4451),
    [sym_preproc_line] = STATE(4451),
    [sym_preproc_pragma] = STATE(4451),
    [sym_preproc_nullable] = STATE(4451),
    [sym_preproc_error] = STATE(4451),
    [sym_preproc_warning] = STATE(4451),
    [sym_preproc_define] = STATE(4451),
    [sym_preproc_undef] = STATE(4451),
    [sym__identifier_token] = ACTIONS(4328),
    [anon_sym_alias] = ACTIONS(4330),
    [anon_sym_global] = ACTIONS(4330),
    [anon_sym_LBRACK] = ACTIONS(6142),
    [anon_sym_LPAREN] = ACTIONS(6144),
    [anon_sym_ref] = ACTIONS(4725),
    [anon_sym_LBRACE] = ACTIONS(6146),
    [anon_sym_delegate] = ACTIONS(6148),
    [anon_sym_file] = ACTIONS(4330),
    [anon_sym_where] = ACTIONS(4330),
    [anon_sym_notnull] = ACTIONS(4330),
    [anon_sym_unmanaged] = ACTIONS(4330),
    [anon_sym_scoped] = ACTIONS(6372),
    [anon_sym_var] = ACTIONS(6152),
    [sym_predefined_type] = ACTIONS(6154),
    [anon_sym_yield] = ACTIONS(4330),
    [anon_sym_when] = ACTIONS(4330),
    [anon_sym_from] = ACTIONS(4330),
    [anon_sym_into] = ACTIONS(4330),
    [anon_sym_join] = ACTIONS(4330),
    [anon_sym_on] = ACTIONS(4330),
    [anon_sym_equals] = ACTIONS(4330),
    [anon_sym_let] = ACTIONS(4330),
    [anon_sym_orderby] = ACTIONS(4330),
    [anon_sym_ascending] = ACTIONS(4330),
    [anon_sym_descending] = ACTIONS(4330),
    [anon_sym_group] = ACTIONS(4330),
    [anon_sym_by] = ACTIONS(4330),
    [anon_sym_select] = ACTIONS(4330),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4452] = {
    [sym__name] = STATE(7943),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(8678),
    [sym_implicit_type] = STATE(8787),
    [sym_array_type] = STATE(8347),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9367),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(8787),
    [sym_scoped_type] = STATE(8787),
    [sym_tuple_type] = STATE(8173),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4452),
    [sym_preproc_endregion] = STATE(4452),
    [sym_preproc_line] = STATE(4452),
    [sym_preproc_pragma] = STATE(4452),
    [sym_preproc_nullable] = STATE(4452),
    [sym_preproc_error] = STATE(4452),
    [sym_preproc_warning] = STATE(4452),
    [sym_preproc_define] = STATE(4452),
    [sym_preproc_undef] = STATE(4452),
    [aux_sym_type_argument_list_repeat1] = STATE(8679),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_COMMA] = ACTIONS(5743),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(5745),
    [anon_sym_delegate] = ACTIONS(5747),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_GT] = ACTIONS(6374),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(5753),
    [anon_sym_var] = ACTIONS(5369),
    [sym_predefined_type] = ACTIONS(5755),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4453] = {
    [sym_argument_list] = STATE(3863),
    [sym__name] = STATE(3904),
    [sym_alias_qualified_name] = STATE(3924),
    [sym__simple_name] = STATE(3924),
    [sym_qualified_name] = STATE(3924),
    [sym_generic_name] = STATE(3900),
    [sym_type] = STATE(3806),
    [sym_implicit_type] = STATE(3943),
    [sym_array_type] = STATE(3866),
    [sym__array_base_type] = STATE(8893),
    [sym_nullable_type] = STATE(3885),
    [sym_pointer_type] = STATE(3885),
    [sym__pointer_base_type] = STATE(9659),
    [sym_function_pointer_type] = STATE(3885),
    [sym_ref_type] = STATE(3943),
    [sym_scoped_type] = STATE(3943),
    [sym_tuple_type] = STATE(3880),
    [sym_identifier] = STATE(3808),
    [sym__reserved_identifier] = STATE(3871),
    [sym_preproc_region] = STATE(4453),
    [sym_preproc_endregion] = STATE(4453),
    [sym_preproc_line] = STATE(4453),
    [sym_preproc_pragma] = STATE(4453),
    [sym_preproc_nullable] = STATE(4453),
    [sym_preproc_error] = STATE(4453),
    [sym_preproc_warning] = STATE(4453),
    [sym_preproc_define] = STATE(4453),
    [sym_preproc_undef] = STATE(4453),
    [sym__identifier_token] = ACTIONS(4223),
    [anon_sym_alias] = ACTIONS(4225),
    [anon_sym_global] = ACTIONS(4225),
    [anon_sym_LBRACK] = ACTIONS(6176),
    [anon_sym_LPAREN] = ACTIONS(6178),
    [anon_sym_ref] = ACTIONS(4644),
    [anon_sym_LBRACE] = ACTIONS(6180),
    [anon_sym_delegate] = ACTIONS(6182),
    [anon_sym_file] = ACTIONS(4225),
    [anon_sym_where] = ACTIONS(4225),
    [anon_sym_notnull] = ACTIONS(4225),
    [anon_sym_unmanaged] = ACTIONS(4225),
    [anon_sym_scoped] = ACTIONS(6376),
    [anon_sym_var] = ACTIONS(6186),
    [sym_predefined_type] = ACTIONS(6188),
    [anon_sym_yield] = ACTIONS(4225),
    [anon_sym_when] = ACTIONS(4225),
    [anon_sym_from] = ACTIONS(4225),
    [anon_sym_into] = ACTIONS(4225),
    [anon_sym_join] = ACTIONS(4225),
    [anon_sym_on] = ACTIONS(4225),
    [anon_sym_equals] = ACTIONS(4225),
    [anon_sym_let] = ACTIONS(4225),
    [anon_sym_orderby] = ACTIONS(4225),
    [anon_sym_ascending] = ACTIONS(4225),
    [anon_sym_descending] = ACTIONS(4225),
    [anon_sym_group] = ACTIONS(4225),
    [anon_sym_by] = ACTIONS(4225),
    [anon_sym_select] = ACTIONS(4225),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4454] = {
    [sym_argument_list] = STATE(3863),
    [sym__name] = STATE(3904),
    [sym_alias_qualified_name] = STATE(3924),
    [sym__simple_name] = STATE(3924),
    [sym_qualified_name] = STATE(3924),
    [sym_generic_name] = STATE(3900),
    [sym_type] = STATE(3806),
    [sym_implicit_type] = STATE(3943),
    [sym_array_type] = STATE(3866),
    [sym__array_base_type] = STATE(8893),
    [sym_nullable_type] = STATE(3885),
    [sym_pointer_type] = STATE(3885),
    [sym__pointer_base_type] = STATE(9659),
    [sym_function_pointer_type] = STATE(3885),
    [sym_ref_type] = STATE(3943),
    [sym_scoped_type] = STATE(3943),
    [sym_tuple_type] = STATE(3880),
    [sym_identifier] = STATE(3808),
    [sym__reserved_identifier] = STATE(3871),
    [sym_preproc_region] = STATE(4454),
    [sym_preproc_endregion] = STATE(4454),
    [sym_preproc_line] = STATE(4454),
    [sym_preproc_pragma] = STATE(4454),
    [sym_preproc_nullable] = STATE(4454),
    [sym_preproc_error] = STATE(4454),
    [sym_preproc_warning] = STATE(4454),
    [sym_preproc_define] = STATE(4454),
    [sym_preproc_undef] = STATE(4454),
    [sym__identifier_token] = ACTIONS(4223),
    [anon_sym_alias] = ACTIONS(4225),
    [anon_sym_global] = ACTIONS(4225),
    [anon_sym_LBRACK] = ACTIONS(6176),
    [anon_sym_LPAREN] = ACTIONS(6178),
    [anon_sym_ref] = ACTIONS(4660),
    [anon_sym_LBRACE] = ACTIONS(6180),
    [anon_sym_delegate] = ACTIONS(6182),
    [anon_sym_file] = ACTIONS(4225),
    [anon_sym_where] = ACTIONS(4225),
    [anon_sym_notnull] = ACTIONS(4225),
    [anon_sym_unmanaged] = ACTIONS(4225),
    [anon_sym_scoped] = ACTIONS(6378),
    [anon_sym_var] = ACTIONS(6186),
    [sym_predefined_type] = ACTIONS(6188),
    [anon_sym_yield] = ACTIONS(4225),
    [anon_sym_when] = ACTIONS(4225),
    [anon_sym_from] = ACTIONS(4225),
    [anon_sym_into] = ACTIONS(4225),
    [anon_sym_join] = ACTIONS(4225),
    [anon_sym_on] = ACTIONS(4225),
    [anon_sym_equals] = ACTIONS(4225),
    [anon_sym_let] = ACTIONS(4225),
    [anon_sym_orderby] = ACTIONS(4225),
    [anon_sym_ascending] = ACTIONS(4225),
    [anon_sym_descending] = ACTIONS(4225),
    [anon_sym_group] = ACTIONS(4225),
    [anon_sym_by] = ACTIONS(4225),
    [anon_sym_select] = ACTIONS(4225),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4455] = {
    [sym_preproc_region] = STATE(4455),
    [sym_preproc_endregion] = STATE(4455),
    [sym_preproc_line] = STATE(4455),
    [sym_preproc_pragma] = STATE(4455),
    [sym_preproc_nullable] = STATE(4455),
    [sym_preproc_error] = STATE(4455),
    [sym_preproc_warning] = STATE(4455),
    [sym_preproc_define] = STATE(4455),
    [sym_preproc_undef] = STATE(4455),
    [sym__identifier_token] = ACTIONS(5719),
    [anon_sym_extern] = ACTIONS(5719),
    [anon_sym_alias] = ACTIONS(5719),
    [anon_sym_global] = ACTIONS(5719),
    [anon_sym_unsafe] = ACTIONS(5719),
    [anon_sym_static] = ACTIONS(5719),
    [anon_sym_LBRACK] = ACTIONS(5721),
    [anon_sym_abstract] = ACTIONS(5719),
    [anon_sym_async] = ACTIONS(5719),
    [anon_sym_const] = ACTIONS(5719),
    [anon_sym_file] = ACTIONS(5719),
    [anon_sym_fixed] = ACTIONS(5719),
    [anon_sym_internal] = ACTIONS(5719),
    [anon_sym_new] = ACTIONS(5719),
    [anon_sym_override] = ACTIONS(5719),
    [anon_sym_partial] = ACTIONS(5719),
    [anon_sym_private] = ACTIONS(5719),
    [anon_sym_protected] = ACTIONS(5719),
    [anon_sym_public] = ACTIONS(5719),
    [anon_sym_readonly] = ACTIONS(5719),
    [anon_sym_required] = ACTIONS(5719),
    [anon_sym_sealed] = ACTIONS(5719),
    [anon_sym_virtual] = ACTIONS(5719),
    [anon_sym_volatile] = ACTIONS(5719),
    [anon_sym_where] = ACTIONS(5719),
    [anon_sym_notnull] = ACTIONS(5719),
    [anon_sym_unmanaged] = ACTIONS(5719),
    [anon_sym_get] = ACTIONS(5719),
    [anon_sym_set] = ACTIONS(5719),
    [anon_sym_add] = ACTIONS(5719),
    [anon_sym_remove] = ACTIONS(5719),
    [anon_sym_init] = ACTIONS(5719),
    [anon_sym_scoped] = ACTIONS(5719),
    [anon_sym_var] = ACTIONS(5719),
    [anon_sym_yield] = ACTIONS(5719),
    [anon_sym_when] = ACTIONS(5719),
    [anon_sym_from] = ACTIONS(5719),
    [anon_sym_into] = ACTIONS(5719),
    [anon_sym_join] = ACTIONS(5719),
    [anon_sym_on] = ACTIONS(5719),
    [anon_sym_equals] = ACTIONS(5719),
    [anon_sym_let] = ACTIONS(5719),
    [anon_sym_orderby] = ACTIONS(5719),
    [anon_sym_ascending] = ACTIONS(5719),
    [anon_sym_descending] = ACTIONS(5719),
    [anon_sym_group] = ACTIONS(5719),
    [anon_sym_by] = ACTIONS(5719),
    [anon_sym_select] = ACTIONS(5719),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4456] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4456),
    [sym_preproc_endregion] = STATE(4456),
    [sym_preproc_line] = STATE(4456),
    [sym_preproc_pragma] = STATE(4456),
    [sym_preproc_nullable] = STATE(4456),
    [sym_preproc_error] = STATE(4456),
    [sym_preproc_warning] = STATE(4456),
    [sym_preproc_define] = STATE(4456),
    [sym_preproc_undef] = STATE(4456),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(5271),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(5275),
    [anon_sym_GT] = ACTIONS(5275),
    [anon_sym_where] = ACTIONS(5271),
    [anon_sym_QMARK] = ACTIONS(5275),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(5275),
    [anon_sym_DASH] = ACTIONS(5275),
    [anon_sym_STAR] = ACTIONS(5271),
    [anon_sym_SLASH] = ACTIONS(5275),
    [anon_sym_PERCENT] = ACTIONS(5271),
    [anon_sym_CARET] = ACTIONS(5271),
    [anon_sym_PIPE] = ACTIONS(5275),
    [anon_sym_AMP] = ACTIONS(5275),
    [anon_sym_LT_LT] = ACTIONS(5271),
    [anon_sym_GT_GT] = ACTIONS(5275),
    [anon_sym_GT_GT_GT] = ACTIONS(5271),
    [anon_sym_EQ_EQ] = ACTIONS(5271),
    [anon_sym_BANG_EQ] = ACTIONS(5271),
    [anon_sym_GT_EQ] = ACTIONS(5271),
    [anon_sym_LT_EQ] = ACTIONS(5271),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(5271),
    [anon_sym_DOT_DOT] = ACTIONS(5271),
    [anon_sym_and] = ACTIONS(5271),
    [anon_sym_or] = ACTIONS(5275),
    [anon_sym_AMP_AMP] = ACTIONS(5271),
    [anon_sym_PIPE_PIPE] = ACTIONS(5271),
    [anon_sym_QMARK_QMARK] = ACTIONS(5271),
    [anon_sym_from] = ACTIONS(5271),
    [anon_sym_into] = ACTIONS(5271),
    [anon_sym_join] = ACTIONS(5271),
    [anon_sym_let] = ACTIONS(5271),
    [anon_sym_orderby] = ACTIONS(5271),
    [anon_sym_ascending] = ACTIONS(5271),
    [anon_sym_descending] = ACTIONS(5271),
    [anon_sym_group] = ACTIONS(5271),
    [anon_sym_select] = ACTIONS(5271),
    [anon_sym_as] = ACTIONS(5275),
    [anon_sym_is] = ACTIONS(5271),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(5271),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4457] = {
    [sym_preproc_region] = STATE(4457),
    [sym_preproc_endregion] = STATE(4457),
    [sym_preproc_line] = STATE(4457),
    [sym_preproc_pragma] = STATE(4457),
    [sym_preproc_nullable] = STATE(4457),
    [sym_preproc_error] = STATE(4457),
    [sym_preproc_warning] = STATE(4457),
    [sym_preproc_define] = STATE(4457),
    [sym_preproc_undef] = STATE(4457),
    [anon_sym_EQ] = ACTIONS(5998),
    [anon_sym_LBRACK] = ACTIONS(5286),
    [anon_sym_COMMA] = ACTIONS(5286),
    [anon_sym_LPAREN] = ACTIONS(5286),
    [anon_sym_RPAREN] = ACTIONS(6380),
    [anon_sym_LT] = ACTIONS(5288),
    [anon_sym_GT] = ACTIONS(5288),
    [anon_sym_QMARK] = ACTIONS(5288),
    [anon_sym_BANG] = ACTIONS(5288),
    [anon_sym_PLUS_PLUS] = ACTIONS(5286),
    [anon_sym_DASH_DASH] = ACTIONS(5286),
    [anon_sym_PLUS] = ACTIONS(5288),
    [anon_sym_DASH] = ACTIONS(5288),
    [anon_sym_STAR] = ACTIONS(5288),
    [anon_sym_SLASH] = ACTIONS(5288),
    [anon_sym_PERCENT] = ACTIONS(5288),
    [anon_sym_CARET] = ACTIONS(5288),
    [anon_sym_PIPE] = ACTIONS(5288),
    [anon_sym_AMP] = ACTIONS(5288),
    [anon_sym_LT_LT] = ACTIONS(5288),
    [anon_sym_GT_GT] = ACTIONS(5288),
    [anon_sym_GT_GT_GT] = ACTIONS(5288),
    [anon_sym_EQ_EQ] = ACTIONS(5286),
    [anon_sym_BANG_EQ] = ACTIONS(5286),
    [anon_sym_GT_EQ] = ACTIONS(5286),
    [anon_sym_LT_EQ] = ACTIONS(5286),
    [anon_sym_DOT] = ACTIONS(5288),
    [anon_sym_switch] = ACTIONS(5286),
    [anon_sym_DOT_DOT] = ACTIONS(5286),
    [anon_sym_PLUS_EQ] = ACTIONS(6000),
    [anon_sym_DASH_EQ] = ACTIONS(6000),
    [anon_sym_STAR_EQ] = ACTIONS(6000),
    [anon_sym_SLASH_EQ] = ACTIONS(6000),
    [anon_sym_PERCENT_EQ] = ACTIONS(6000),
    [anon_sym_AMP_EQ] = ACTIONS(6000),
    [anon_sym_CARET_EQ] = ACTIONS(6000),
    [anon_sym_PIPE_EQ] = ACTIONS(6000),
    [anon_sym_LT_LT_EQ] = ACTIONS(6000),
    [anon_sym_GT_GT_EQ] = ACTIONS(6000),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(6000),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(6000),
    [anon_sym_AMP_AMP] = ACTIONS(5286),
    [anon_sym_PIPE_PIPE] = ACTIONS(5286),
    [anon_sym_QMARK_QMARK] = ACTIONS(5288),
    [anon_sym_as] = ACTIONS(5286),
    [anon_sym_is] = ACTIONS(5286),
    [anon_sym_DASH_GT] = ACTIONS(5286),
    [anon_sym_with] = ACTIONS(5286),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4458] = {
    [sym_preproc_region] = STATE(4458),
    [sym_preproc_endregion] = STATE(4458),
    [sym_preproc_line] = STATE(4458),
    [sym_preproc_pragma] = STATE(4458),
    [sym_preproc_nullable] = STATE(4458),
    [sym_preproc_error] = STATE(4458),
    [sym_preproc_warning] = STATE(4458),
    [sym_preproc_define] = STATE(4458),
    [sym_preproc_undef] = STATE(4458),
    [anon_sym_EQ] = ACTIONS(6382),
    [anon_sym_LBRACK] = ACTIONS(5286),
    [anon_sym_LPAREN] = ACTIONS(5286),
    [anon_sym_LT] = ACTIONS(5288),
    [anon_sym_GT] = ACTIONS(5288),
    [anon_sym_QMARK] = ACTIONS(5288),
    [anon_sym_BANG] = ACTIONS(5288),
    [anon_sym_PLUS_PLUS] = ACTIONS(5286),
    [anon_sym_DASH_DASH] = ACTIONS(5286),
    [anon_sym_PLUS] = ACTIONS(5288),
    [anon_sym_DASH] = ACTIONS(5288),
    [anon_sym_STAR] = ACTIONS(5288),
    [anon_sym_SLASH] = ACTIONS(5288),
    [anon_sym_PERCENT] = ACTIONS(5288),
    [anon_sym_CARET] = ACTIONS(5288),
    [anon_sym_PIPE] = ACTIONS(5288),
    [anon_sym_AMP] = ACTIONS(5288),
    [anon_sym_LT_LT] = ACTIONS(5288),
    [anon_sym_GT_GT] = ACTIONS(5288),
    [anon_sym_GT_GT_GT] = ACTIONS(5288),
    [anon_sym_EQ_EQ] = ACTIONS(5286),
    [anon_sym_BANG_EQ] = ACTIONS(5286),
    [anon_sym_GT_EQ] = ACTIONS(5286),
    [anon_sym_LT_EQ] = ACTIONS(5286),
    [anon_sym_DOT] = ACTIONS(5288),
    [anon_sym_switch] = ACTIONS(5286),
    [anon_sym_DOT_DOT] = ACTIONS(5286),
    [anon_sym_PLUS_EQ] = ACTIONS(6384),
    [anon_sym_DASH_EQ] = ACTIONS(6384),
    [anon_sym_STAR_EQ] = ACTIONS(6384),
    [anon_sym_SLASH_EQ] = ACTIONS(6384),
    [anon_sym_PERCENT_EQ] = ACTIONS(6384),
    [anon_sym_AMP_EQ] = ACTIONS(6384),
    [anon_sym_CARET_EQ] = ACTIONS(6384),
    [anon_sym_PIPE_EQ] = ACTIONS(6384),
    [anon_sym_LT_LT_EQ] = ACTIONS(6384),
    [anon_sym_GT_GT_EQ] = ACTIONS(6384),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(6384),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(6384),
    [anon_sym_AMP_AMP] = ACTIONS(5286),
    [anon_sym_PIPE_PIPE] = ACTIONS(5286),
    [anon_sym_QMARK_QMARK] = ACTIONS(5288),
    [anon_sym_into] = ACTIONS(5286),
    [anon_sym_on] = ACTIONS(5286),
    [anon_sym_as] = ACTIONS(5286),
    [anon_sym_is] = ACTIONS(5286),
    [anon_sym_DASH_GT] = ACTIONS(5286),
    [anon_sym_with] = ACTIONS(5286),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4459] = {
    [sym_argument_list] = STATE(5221),
    [sym__name] = STATE(5270),
    [sym_alias_qualified_name] = STATE(5341),
    [sym__simple_name] = STATE(5341),
    [sym_qualified_name] = STATE(5341),
    [sym_generic_name] = STATE(5408),
    [sym_type] = STATE(5065),
    [sym_implicit_type] = STATE(5336),
    [sym_array_type] = STATE(5177),
    [sym__array_base_type] = STATE(8724),
    [sym_nullable_type] = STATE(5262),
    [sym_pointer_type] = STATE(5262),
    [sym__pointer_base_type] = STATE(9858),
    [sym_function_pointer_type] = STATE(5262),
    [sym_ref_type] = STATE(5336),
    [sym_scoped_type] = STATE(5336),
    [sym_tuple_type] = STATE(5321),
    [sym_identifier] = STATE(5076),
    [sym__reserved_identifier] = STATE(5173),
    [sym_preproc_region] = STATE(4459),
    [sym_preproc_endregion] = STATE(4459),
    [sym_preproc_line] = STATE(4459),
    [sym_preproc_pragma] = STATE(4459),
    [sym_preproc_nullable] = STATE(4459),
    [sym_preproc_error] = STATE(4459),
    [sym_preproc_warning] = STATE(4459),
    [sym_preproc_define] = STATE(4459),
    [sym_preproc_undef] = STATE(4459),
    [sym__identifier_token] = ACTIONS(4457),
    [anon_sym_alias] = ACTIONS(4459),
    [anon_sym_global] = ACTIONS(4459),
    [anon_sym_LBRACK] = ACTIONS(6291),
    [anon_sym_LPAREN] = ACTIONS(6293),
    [anon_sym_ref] = ACTIONS(4461),
    [anon_sym_LBRACE] = ACTIONS(6295),
    [anon_sym_delegate] = ACTIONS(6297),
    [anon_sym_file] = ACTIONS(4459),
    [anon_sym_where] = ACTIONS(4459),
    [anon_sym_notnull] = ACTIONS(4459),
    [anon_sym_unmanaged] = ACTIONS(4459),
    [anon_sym_scoped] = ACTIONS(6386),
    [anon_sym_var] = ACTIONS(6301),
    [sym_predefined_type] = ACTIONS(6303),
    [anon_sym_yield] = ACTIONS(4459),
    [anon_sym_when] = ACTIONS(4459),
    [anon_sym_from] = ACTIONS(4459),
    [anon_sym_into] = ACTIONS(4459),
    [anon_sym_join] = ACTIONS(4459),
    [anon_sym_on] = ACTIONS(4459),
    [anon_sym_equals] = ACTIONS(4459),
    [anon_sym_let] = ACTIONS(4459),
    [anon_sym_orderby] = ACTIONS(4459),
    [anon_sym_ascending] = ACTIONS(4459),
    [anon_sym_descending] = ACTIONS(4459),
    [anon_sym_group] = ACTIONS(4459),
    [anon_sym_by] = ACTIONS(4459),
    [anon_sym_select] = ACTIONS(4459),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4460] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4460),
    [sym_preproc_endregion] = STATE(4460),
    [sym_preproc_line] = STATE(4460),
    [sym_preproc_pragma] = STATE(4460),
    [sym_preproc_nullable] = STATE(4460),
    [sym_preproc_error] = STATE(4460),
    [sym_preproc_warning] = STATE(4460),
    [sym_preproc_define] = STATE(4460),
    [sym_preproc_undef] = STATE(4460),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(6342),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(6388),
    [anon_sym_GT] = ACTIONS(6388),
    [anon_sym_where] = ACTIONS(6342),
    [anon_sym_QMARK] = ACTIONS(6344),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(6390),
    [anon_sym_DASH] = ACTIONS(6390),
    [anon_sym_STAR] = ACTIONS(6392),
    [anon_sym_SLASH] = ACTIONS(6394),
    [anon_sym_PERCENT] = ACTIONS(6392),
    [anon_sym_CARET] = ACTIONS(6342),
    [anon_sym_PIPE] = ACTIONS(6344),
    [anon_sym_AMP] = ACTIONS(6344),
    [anon_sym_LT_LT] = ACTIONS(6396),
    [anon_sym_GT_GT] = ACTIONS(6398),
    [anon_sym_GT_GT_GT] = ACTIONS(6396),
    [anon_sym_EQ_EQ] = ACTIONS(6400),
    [anon_sym_BANG_EQ] = ACTIONS(6400),
    [anon_sym_GT_EQ] = ACTIONS(6402),
    [anon_sym_LT_EQ] = ACTIONS(6402),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(6216),
    [anon_sym_DOT_DOT] = ACTIONS(6404),
    [anon_sym_and] = ACTIONS(6342),
    [anon_sym_or] = ACTIONS(6344),
    [anon_sym_AMP_AMP] = ACTIONS(6342),
    [anon_sym_PIPE_PIPE] = ACTIONS(6342),
    [anon_sym_QMARK_QMARK] = ACTIONS(6342),
    [anon_sym_from] = ACTIONS(6342),
    [anon_sym_join] = ACTIONS(6342),
    [anon_sym_let] = ACTIONS(6342),
    [anon_sym_orderby] = ACTIONS(6342),
    [anon_sym_ascending] = ACTIONS(6342),
    [anon_sym_descending] = ACTIONS(6342),
    [anon_sym_group] = ACTIONS(6342),
    [anon_sym_select] = ACTIONS(6342),
    [anon_sym_as] = ACTIONS(6406),
    [anon_sym_is] = ACTIONS(6408),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(6232),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4461] = {
    [sym_argument_list] = STATE(4044),
    [sym_bracketed_argument_list] = STATE(3189),
    [sym_preproc_region] = STATE(4461),
    [sym_preproc_endregion] = STATE(4461),
    [sym_preproc_line] = STATE(4461),
    [sym_preproc_pragma] = STATE(4461),
    [sym_preproc_nullable] = STATE(4461),
    [sym_preproc_error] = STATE(4461),
    [sym_preproc_warning] = STATE(4461),
    [sym_preproc_define] = STATE(4461),
    [sym_preproc_undef] = STATE(4461),
    [anon_sym_SEMI] = ACTIONS(5572),
    [anon_sym_LBRACK] = ACTIONS(5778),
    [anon_sym_COMMA] = ACTIONS(5572),
    [anon_sym_RBRACK] = ACTIONS(5572),
    [anon_sym_LPAREN] = ACTIONS(5759),
    [anon_sym_RPAREN] = ACTIONS(5572),
    [anon_sym_RBRACE] = ACTIONS(5572),
    [anon_sym_LT] = ACTIONS(6410),
    [anon_sym_GT] = ACTIONS(6410),
    [anon_sym_in] = ACTIONS(5574),
    [anon_sym_QMARK] = ACTIONS(6412),
    [anon_sym_BANG] = ACTIONS(5780),
    [anon_sym_PLUS_PLUS] = ACTIONS(5782),
    [anon_sym_DASH_DASH] = ACTIONS(5782),
    [anon_sym_PLUS] = ACTIONS(6414),
    [anon_sym_DASH] = ACTIONS(6414),
    [anon_sym_STAR] = ACTIONS(6416),
    [anon_sym_SLASH] = ACTIONS(6418),
    [anon_sym_PERCENT] = ACTIONS(6416),
    [anon_sym_CARET] = ACTIONS(6420),
    [anon_sym_PIPE] = ACTIONS(6422),
    [anon_sym_AMP] = ACTIONS(6424),
    [anon_sym_LT_LT] = ACTIONS(6426),
    [anon_sym_GT_GT] = ACTIONS(6428),
    [anon_sym_GT_GT_GT] = ACTIONS(6426),
    [anon_sym_EQ_EQ] = ACTIONS(6430),
    [anon_sym_BANG_EQ] = ACTIONS(6430),
    [anon_sym_GT_EQ] = ACTIONS(6432),
    [anon_sym_LT_EQ] = ACTIONS(6432),
    [anon_sym_DOT] = ACTIONS(4634),
    [anon_sym_switch] = ACTIONS(6434),
    [anon_sym_DOT_DOT] = ACTIONS(6436),
    [anon_sym_and] = ACTIONS(5572),
    [anon_sym_or] = ACTIONS(5572),
    [anon_sym_AMP_AMP] = ACTIONS(6438),
    [anon_sym_PIPE_PIPE] = ACTIONS(6440),
    [anon_sym_QMARK_QMARK] = ACTIONS(6442),
    [anon_sym_into] = ACTIONS(5572),
    [anon_sym_as] = ACTIONS(6444),
    [anon_sym_is] = ACTIONS(6446),
    [anon_sym_DASH_GT] = ACTIONS(4636),
    [anon_sym_with] = ACTIONS(6448),
    [aux_sym_preproc_if_token3] = ACTIONS(5572),
    [aux_sym_preproc_else_token1] = ACTIONS(5572),
    [aux_sym_preproc_elif_token1] = ACTIONS(5572),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4462] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4462),
    [sym_preproc_endregion] = STATE(4462),
    [sym_preproc_line] = STATE(4462),
    [sym_preproc_pragma] = STATE(4462),
    [sym_preproc_nullable] = STATE(4462),
    [sym_preproc_error] = STATE(4462),
    [sym_preproc_warning] = STATE(4462),
    [sym_preproc_define] = STATE(4462),
    [sym_preproc_undef] = STATE(4462),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(5416),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(6388),
    [anon_sym_GT] = ACTIONS(6388),
    [anon_sym_where] = ACTIONS(5416),
    [anon_sym_QMARK] = ACTIONS(6450),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(6390),
    [anon_sym_DASH] = ACTIONS(6390),
    [anon_sym_STAR] = ACTIONS(6392),
    [anon_sym_SLASH] = ACTIONS(6394),
    [anon_sym_PERCENT] = ACTIONS(6392),
    [anon_sym_CARET] = ACTIONS(6452),
    [anon_sym_PIPE] = ACTIONS(6454),
    [anon_sym_AMP] = ACTIONS(6456),
    [anon_sym_LT_LT] = ACTIONS(6396),
    [anon_sym_GT_GT] = ACTIONS(6398),
    [anon_sym_GT_GT_GT] = ACTIONS(6396),
    [anon_sym_EQ_EQ] = ACTIONS(6400),
    [anon_sym_BANG_EQ] = ACTIONS(6400),
    [anon_sym_GT_EQ] = ACTIONS(6402),
    [anon_sym_LT_EQ] = ACTIONS(6402),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(6216),
    [anon_sym_DOT_DOT] = ACTIONS(6404),
    [anon_sym_and] = ACTIONS(5416),
    [anon_sym_or] = ACTIONS(5418),
    [anon_sym_AMP_AMP] = ACTIONS(6458),
    [anon_sym_PIPE_PIPE] = ACTIONS(6460),
    [anon_sym_QMARK_QMARK] = ACTIONS(6462),
    [anon_sym_from] = ACTIONS(5416),
    [anon_sym_join] = ACTIONS(5416),
    [anon_sym_let] = ACTIONS(5416),
    [anon_sym_orderby] = ACTIONS(5416),
    [anon_sym_ascending] = ACTIONS(5416),
    [anon_sym_descending] = ACTIONS(5416),
    [anon_sym_group] = ACTIONS(5416),
    [anon_sym_select] = ACTIONS(5416),
    [anon_sym_as] = ACTIONS(6406),
    [anon_sym_is] = ACTIONS(6408),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(6232),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4463] = {
    [sym_argument_list] = STATE(4044),
    [sym_bracketed_argument_list] = STATE(3189),
    [sym_preproc_region] = STATE(4463),
    [sym_preproc_endregion] = STATE(4463),
    [sym_preproc_line] = STATE(4463),
    [sym_preproc_pragma] = STATE(4463),
    [sym_preproc_nullable] = STATE(4463),
    [sym_preproc_error] = STATE(4463),
    [sym_preproc_warning] = STATE(4463),
    [sym_preproc_define] = STATE(4463),
    [sym_preproc_undef] = STATE(4463),
    [anon_sym_SEMI] = ACTIONS(6266),
    [anon_sym_LBRACK] = ACTIONS(5778),
    [anon_sym_COMMA] = ACTIONS(6266),
    [anon_sym_RBRACK] = ACTIONS(6266),
    [anon_sym_LPAREN] = ACTIONS(5759),
    [anon_sym_RPAREN] = ACTIONS(6266),
    [anon_sym_RBRACE] = ACTIONS(6266),
    [anon_sym_LT] = ACTIONS(6410),
    [anon_sym_GT] = ACTIONS(6410),
    [anon_sym_in] = ACTIONS(6268),
    [anon_sym_QMARK] = ACTIONS(6412),
    [anon_sym_BANG] = ACTIONS(5780),
    [anon_sym_PLUS_PLUS] = ACTIONS(5782),
    [anon_sym_DASH_DASH] = ACTIONS(5782),
    [anon_sym_PLUS] = ACTIONS(6414),
    [anon_sym_DASH] = ACTIONS(6414),
    [anon_sym_STAR] = ACTIONS(6416),
    [anon_sym_SLASH] = ACTIONS(6418),
    [anon_sym_PERCENT] = ACTIONS(6416),
    [anon_sym_CARET] = ACTIONS(6420),
    [anon_sym_PIPE] = ACTIONS(6422),
    [anon_sym_AMP] = ACTIONS(6424),
    [anon_sym_LT_LT] = ACTIONS(6426),
    [anon_sym_GT_GT] = ACTIONS(6428),
    [anon_sym_GT_GT_GT] = ACTIONS(6426),
    [anon_sym_EQ_EQ] = ACTIONS(6430),
    [anon_sym_BANG_EQ] = ACTIONS(6430),
    [anon_sym_GT_EQ] = ACTIONS(6432),
    [anon_sym_LT_EQ] = ACTIONS(6432),
    [anon_sym_DOT] = ACTIONS(4634),
    [anon_sym_switch] = ACTIONS(6434),
    [anon_sym_DOT_DOT] = ACTIONS(6436),
    [anon_sym_and] = ACTIONS(6266),
    [anon_sym_or] = ACTIONS(6266),
    [anon_sym_AMP_AMP] = ACTIONS(6438),
    [anon_sym_PIPE_PIPE] = ACTIONS(6440),
    [anon_sym_QMARK_QMARK] = ACTIONS(6442),
    [anon_sym_into] = ACTIONS(6266),
    [anon_sym_as] = ACTIONS(6444),
    [anon_sym_is] = ACTIONS(6446),
    [anon_sym_DASH_GT] = ACTIONS(4636),
    [anon_sym_with] = ACTIONS(6448),
    [aux_sym_preproc_if_token3] = ACTIONS(6266),
    [aux_sym_preproc_else_token1] = ACTIONS(6266),
    [aux_sym_preproc_elif_token1] = ACTIONS(6266),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4464] = {
    [sym_preproc_region] = STATE(4464),
    [sym_preproc_endregion] = STATE(4464),
    [sym_preproc_line] = STATE(4464),
    [sym_preproc_pragma] = STATE(4464),
    [sym_preproc_nullable] = STATE(4464),
    [sym_preproc_error] = STATE(4464),
    [sym_preproc_warning] = STATE(4464),
    [sym_preproc_define] = STATE(4464),
    [sym_preproc_undef] = STATE(4464),
    [anon_sym_LBRACK] = ACTIONS(5382),
    [anon_sym_COMMA] = ACTIONS(5382),
    [anon_sym_LPAREN] = ACTIONS(5382),
    [anon_sym_LT] = ACTIONS(5384),
    [anon_sym_GT] = ACTIONS(5384),
    [anon_sym_where] = ACTIONS(5382),
    [anon_sym_QMARK] = ACTIONS(5384),
    [anon_sym_BANG] = ACTIONS(5384),
    [anon_sym_PLUS_PLUS] = ACTIONS(5382),
    [anon_sym_DASH_DASH] = ACTIONS(5382),
    [anon_sym_PLUS] = ACTIONS(5384),
    [anon_sym_DASH] = ACTIONS(5384),
    [anon_sym_STAR] = ACTIONS(5382),
    [anon_sym_SLASH] = ACTIONS(5384),
    [anon_sym_PERCENT] = ACTIONS(5382),
    [anon_sym_CARET] = ACTIONS(5382),
    [anon_sym_PIPE] = ACTIONS(5384),
    [anon_sym_AMP] = ACTIONS(5384),
    [anon_sym_LT_LT] = ACTIONS(5382),
    [anon_sym_GT_GT] = ACTIONS(5384),
    [anon_sym_GT_GT_GT] = ACTIONS(5382),
    [anon_sym_EQ_EQ] = ACTIONS(5382),
    [anon_sym_BANG_EQ] = ACTIONS(5382),
    [anon_sym_GT_EQ] = ACTIONS(5382),
    [anon_sym_LT_EQ] = ACTIONS(5382),
    [anon_sym_DOT] = ACTIONS(5384),
    [anon_sym_switch] = ACTIONS(5382),
    [anon_sym_DOT_DOT] = ACTIONS(5382),
    [anon_sym_and] = ACTIONS(5382),
    [anon_sym_or] = ACTIONS(5384),
    [anon_sym_AMP_AMP] = ACTIONS(5382),
    [anon_sym_PIPE_PIPE] = ACTIONS(5382),
    [anon_sym_QMARK_QMARK] = ACTIONS(5382),
    [anon_sym_from] = ACTIONS(5382),
    [anon_sym_into] = ACTIONS(5382),
    [anon_sym_join] = ACTIONS(5382),
    [anon_sym_let] = ACTIONS(5382),
    [anon_sym_orderby] = ACTIONS(5382),
    [anon_sym_ascending] = ACTIONS(5382),
    [anon_sym_descending] = ACTIONS(5382),
    [anon_sym_group] = ACTIONS(5382),
    [anon_sym_select] = ACTIONS(5382),
    [anon_sym_as] = ACTIONS(5384),
    [anon_sym_is] = ACTIONS(5382),
    [anon_sym_DASH_GT] = ACTIONS(5382),
    [anon_sym_with] = ACTIONS(5382),
    [sym_string_literal_encoding] = ACTIONS(6464),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4465] = {
    [sym_argument_list] = STATE(4044),
    [sym_bracketed_argument_list] = STATE(3189),
    [sym_preproc_region] = STATE(4465),
    [sym_preproc_endregion] = STATE(4465),
    [sym_preproc_line] = STATE(4465),
    [sym_preproc_pragma] = STATE(4465),
    [sym_preproc_nullable] = STATE(4465),
    [sym_preproc_error] = STATE(4465),
    [sym_preproc_warning] = STATE(4465),
    [sym_preproc_define] = STATE(4465),
    [sym_preproc_undef] = STATE(4465),
    [anon_sym_SEMI] = ACTIONS(6320),
    [anon_sym_LBRACK] = ACTIONS(5778),
    [anon_sym_COMMA] = ACTIONS(6320),
    [anon_sym_RBRACK] = ACTIONS(6320),
    [anon_sym_LPAREN] = ACTIONS(5759),
    [anon_sym_RPAREN] = ACTIONS(6320),
    [anon_sym_RBRACE] = ACTIONS(6320),
    [anon_sym_LT] = ACTIONS(6410),
    [anon_sym_GT] = ACTIONS(6410),
    [anon_sym_in] = ACTIONS(6322),
    [anon_sym_QMARK] = ACTIONS(6412),
    [anon_sym_BANG] = ACTIONS(5780),
    [anon_sym_PLUS_PLUS] = ACTIONS(5782),
    [anon_sym_DASH_DASH] = ACTIONS(5782),
    [anon_sym_PLUS] = ACTIONS(6414),
    [anon_sym_DASH] = ACTIONS(6414),
    [anon_sym_STAR] = ACTIONS(6416),
    [anon_sym_SLASH] = ACTIONS(6418),
    [anon_sym_PERCENT] = ACTIONS(6416),
    [anon_sym_CARET] = ACTIONS(6420),
    [anon_sym_PIPE] = ACTIONS(6422),
    [anon_sym_AMP] = ACTIONS(6424),
    [anon_sym_LT_LT] = ACTIONS(6426),
    [anon_sym_GT_GT] = ACTIONS(6428),
    [anon_sym_GT_GT_GT] = ACTIONS(6426),
    [anon_sym_EQ_EQ] = ACTIONS(6430),
    [anon_sym_BANG_EQ] = ACTIONS(6430),
    [anon_sym_GT_EQ] = ACTIONS(6432),
    [anon_sym_LT_EQ] = ACTIONS(6432),
    [anon_sym_DOT] = ACTIONS(4634),
    [anon_sym_switch] = ACTIONS(6434),
    [anon_sym_DOT_DOT] = ACTIONS(6436),
    [anon_sym_and] = ACTIONS(6320),
    [anon_sym_or] = ACTIONS(6320),
    [anon_sym_AMP_AMP] = ACTIONS(6438),
    [anon_sym_PIPE_PIPE] = ACTIONS(6440),
    [anon_sym_QMARK_QMARK] = ACTIONS(6442),
    [anon_sym_into] = ACTIONS(6320),
    [anon_sym_as] = ACTIONS(6444),
    [anon_sym_is] = ACTIONS(6446),
    [anon_sym_DASH_GT] = ACTIONS(4636),
    [anon_sym_with] = ACTIONS(6448),
    [aux_sym_preproc_if_token3] = ACTIONS(6320),
    [aux_sym_preproc_else_token1] = ACTIONS(6320),
    [aux_sym_preproc_elif_token1] = ACTIONS(6320),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4466] = {
    [sym_argument_list] = STATE(4044),
    [sym_bracketed_argument_list] = STATE(3189),
    [sym_preproc_region] = STATE(4466),
    [sym_preproc_endregion] = STATE(4466),
    [sym_preproc_line] = STATE(4466),
    [sym_preproc_pragma] = STATE(4466),
    [sym_preproc_nullable] = STATE(4466),
    [sym_preproc_error] = STATE(4466),
    [sym_preproc_warning] = STATE(4466),
    [sym_preproc_define] = STATE(4466),
    [sym_preproc_undef] = STATE(4466),
    [anon_sym_SEMI] = ACTIONS(6332),
    [anon_sym_LBRACK] = ACTIONS(5778),
    [anon_sym_COMMA] = ACTIONS(6332),
    [anon_sym_RBRACK] = ACTIONS(6332),
    [anon_sym_LPAREN] = ACTIONS(5759),
    [anon_sym_RPAREN] = ACTIONS(6332),
    [anon_sym_RBRACE] = ACTIONS(6332),
    [anon_sym_LT] = ACTIONS(6410),
    [anon_sym_GT] = ACTIONS(6410),
    [anon_sym_in] = ACTIONS(6334),
    [anon_sym_QMARK] = ACTIONS(6412),
    [anon_sym_BANG] = ACTIONS(5780),
    [anon_sym_PLUS_PLUS] = ACTIONS(5782),
    [anon_sym_DASH_DASH] = ACTIONS(5782),
    [anon_sym_PLUS] = ACTIONS(6414),
    [anon_sym_DASH] = ACTIONS(6414),
    [anon_sym_STAR] = ACTIONS(6416),
    [anon_sym_SLASH] = ACTIONS(6418),
    [anon_sym_PERCENT] = ACTIONS(6416),
    [anon_sym_CARET] = ACTIONS(6420),
    [anon_sym_PIPE] = ACTIONS(6422),
    [anon_sym_AMP] = ACTIONS(6424),
    [anon_sym_LT_LT] = ACTIONS(6426),
    [anon_sym_GT_GT] = ACTIONS(6428),
    [anon_sym_GT_GT_GT] = ACTIONS(6426),
    [anon_sym_EQ_EQ] = ACTIONS(6430),
    [anon_sym_BANG_EQ] = ACTIONS(6430),
    [anon_sym_GT_EQ] = ACTIONS(6432),
    [anon_sym_LT_EQ] = ACTIONS(6432),
    [anon_sym_DOT] = ACTIONS(4634),
    [anon_sym_switch] = ACTIONS(6434),
    [anon_sym_DOT_DOT] = ACTIONS(6436),
    [anon_sym_and] = ACTIONS(6332),
    [anon_sym_or] = ACTIONS(6332),
    [anon_sym_AMP_AMP] = ACTIONS(6438),
    [anon_sym_PIPE_PIPE] = ACTIONS(6440),
    [anon_sym_QMARK_QMARK] = ACTIONS(6442),
    [anon_sym_into] = ACTIONS(6332),
    [anon_sym_as] = ACTIONS(6444),
    [anon_sym_is] = ACTIONS(6446),
    [anon_sym_DASH_GT] = ACTIONS(4636),
    [anon_sym_with] = ACTIONS(6448),
    [aux_sym_preproc_if_token3] = ACTIONS(6332),
    [aux_sym_preproc_else_token1] = ACTIONS(6332),
    [aux_sym_preproc_elif_token1] = ACTIONS(6332),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4467] = {
    [sym_preproc_region] = STATE(4467),
    [sym_preproc_endregion] = STATE(4467),
    [sym_preproc_line] = STATE(4467),
    [sym_preproc_pragma] = STATE(4467),
    [sym_preproc_nullable] = STATE(4467),
    [sym_preproc_error] = STATE(4467),
    [sym_preproc_warning] = STATE(4467),
    [sym_preproc_define] = STATE(4467),
    [sym_preproc_undef] = STATE(4467),
    [sym__identifier_token] = ACTIONS(5711),
    [anon_sym_extern] = ACTIONS(5711),
    [anon_sym_alias] = ACTIONS(5711),
    [anon_sym_global] = ACTIONS(5711),
    [anon_sym_unsafe] = ACTIONS(5711),
    [anon_sym_static] = ACTIONS(5711),
    [anon_sym_LBRACK] = ACTIONS(5713),
    [anon_sym_LPAREN] = ACTIONS(5713),
    [anon_sym_ref] = ACTIONS(5711),
    [anon_sym_delegate] = ACTIONS(5711),
    [anon_sym_abstract] = ACTIONS(5711),
    [anon_sym_async] = ACTIONS(5711),
    [anon_sym_const] = ACTIONS(5711),
    [anon_sym_file] = ACTIONS(5711),
    [anon_sym_fixed] = ACTIONS(5711),
    [anon_sym_internal] = ACTIONS(5711),
    [anon_sym_new] = ACTIONS(5711),
    [anon_sym_override] = ACTIONS(5711),
    [anon_sym_partial] = ACTIONS(5711),
    [anon_sym_private] = ACTIONS(5711),
    [anon_sym_protected] = ACTIONS(5711),
    [anon_sym_public] = ACTIONS(5711),
    [anon_sym_readonly] = ACTIONS(5711),
    [anon_sym_required] = ACTIONS(5711),
    [anon_sym_sealed] = ACTIONS(5711),
    [anon_sym_virtual] = ACTIONS(5711),
    [anon_sym_volatile] = ACTIONS(5711),
    [anon_sym_where] = ACTIONS(5711),
    [anon_sym_notnull] = ACTIONS(5711),
    [anon_sym_unmanaged] = ACTIONS(5711),
    [anon_sym_scoped] = ACTIONS(5711),
    [anon_sym_var] = ACTIONS(5711),
    [sym_predefined_type] = ACTIONS(5711),
    [anon_sym_yield] = ACTIONS(5711),
    [anon_sym_when] = ACTIONS(5711),
    [anon_sym_from] = ACTIONS(5711),
    [anon_sym_into] = ACTIONS(5711),
    [anon_sym_join] = ACTIONS(5711),
    [anon_sym_on] = ACTIONS(5711),
    [anon_sym_equals] = ACTIONS(5711),
    [anon_sym_let] = ACTIONS(5711),
    [anon_sym_orderby] = ACTIONS(5711),
    [anon_sym_ascending] = ACTIONS(5711),
    [anon_sym_descending] = ACTIONS(5711),
    [anon_sym_group] = ACTIONS(5711),
    [anon_sym_by] = ACTIONS(5711),
    [anon_sym_select] = ACTIONS(5711),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4468] = {
    [sym_preproc_region] = STATE(4468),
    [sym_preproc_endregion] = STATE(4468),
    [sym_preproc_line] = STATE(4468),
    [sym_preproc_pragma] = STATE(4468),
    [sym_preproc_nullable] = STATE(4468),
    [sym_preproc_error] = STATE(4468),
    [sym_preproc_warning] = STATE(4468),
    [sym_preproc_define] = STATE(4468),
    [sym_preproc_undef] = STATE(4468),
    [anon_sym_EQ] = ACTIONS(6466),
    [anon_sym_LBRACK] = ACTIONS(5286),
    [anon_sym_COLON] = ACTIONS(5286),
    [anon_sym_LPAREN] = ACTIONS(5286),
    [anon_sym_LT] = ACTIONS(5288),
    [anon_sym_GT] = ACTIONS(5288),
    [anon_sym_QMARK] = ACTIONS(5288),
    [anon_sym_BANG] = ACTIONS(5288),
    [anon_sym_PLUS_PLUS] = ACTIONS(5286),
    [anon_sym_DASH_DASH] = ACTIONS(5286),
    [anon_sym_PLUS] = ACTIONS(5288),
    [anon_sym_DASH] = ACTIONS(5288),
    [anon_sym_STAR] = ACTIONS(5288),
    [anon_sym_SLASH] = ACTIONS(5288),
    [anon_sym_PERCENT] = ACTIONS(5288),
    [anon_sym_CARET] = ACTIONS(5288),
    [anon_sym_PIPE] = ACTIONS(5288),
    [anon_sym_AMP] = ACTIONS(5288),
    [anon_sym_LT_LT] = ACTIONS(5288),
    [anon_sym_GT_GT] = ACTIONS(5288),
    [anon_sym_GT_GT_GT] = ACTIONS(5288),
    [anon_sym_EQ_EQ] = ACTIONS(5286),
    [anon_sym_BANG_EQ] = ACTIONS(5286),
    [anon_sym_GT_EQ] = ACTIONS(5286),
    [anon_sym_LT_EQ] = ACTIONS(5286),
    [anon_sym_DOT] = ACTIONS(5288),
    [anon_sym_switch] = ACTIONS(5286),
    [anon_sym_DOT_DOT] = ACTIONS(5286),
    [anon_sym_PLUS_EQ] = ACTIONS(6468),
    [anon_sym_DASH_EQ] = ACTIONS(6468),
    [anon_sym_STAR_EQ] = ACTIONS(6468),
    [anon_sym_SLASH_EQ] = ACTIONS(6468),
    [anon_sym_PERCENT_EQ] = ACTIONS(6468),
    [anon_sym_AMP_EQ] = ACTIONS(6468),
    [anon_sym_CARET_EQ] = ACTIONS(6468),
    [anon_sym_PIPE_EQ] = ACTIONS(6468),
    [anon_sym_LT_LT_EQ] = ACTIONS(6468),
    [anon_sym_GT_GT_EQ] = ACTIONS(6468),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(6468),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(6468),
    [anon_sym_AMP_AMP] = ACTIONS(5286),
    [anon_sym_PIPE_PIPE] = ACTIONS(5286),
    [anon_sym_QMARK_QMARK] = ACTIONS(5288),
    [anon_sym_as] = ACTIONS(5286),
    [anon_sym_is] = ACTIONS(5286),
    [anon_sym_DASH_GT] = ACTIONS(5286),
    [anon_sym_with] = ACTIONS(5286),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4469] = {
    [sym_argument_list] = STATE(4044),
    [sym_bracketed_argument_list] = STATE(3189),
    [sym_preproc_region] = STATE(4469),
    [sym_preproc_endregion] = STATE(4469),
    [sym_preproc_line] = STATE(4469),
    [sym_preproc_pragma] = STATE(4469),
    [sym_preproc_nullable] = STATE(4469),
    [sym_preproc_error] = STATE(4469),
    [sym_preproc_warning] = STATE(4469),
    [sym_preproc_define] = STATE(4469),
    [sym_preproc_undef] = STATE(4469),
    [anon_sym_SEMI] = ACTIONS(5584),
    [anon_sym_LBRACK] = ACTIONS(5778),
    [anon_sym_COMMA] = ACTIONS(5584),
    [anon_sym_RBRACK] = ACTIONS(5584),
    [anon_sym_LPAREN] = ACTIONS(5759),
    [anon_sym_RPAREN] = ACTIONS(5584),
    [anon_sym_RBRACE] = ACTIONS(5584),
    [anon_sym_LT] = ACTIONS(6410),
    [anon_sym_GT] = ACTIONS(6410),
    [anon_sym_in] = ACTIONS(5586),
    [anon_sym_QMARK] = ACTIONS(6412),
    [anon_sym_BANG] = ACTIONS(5780),
    [anon_sym_PLUS_PLUS] = ACTIONS(5782),
    [anon_sym_DASH_DASH] = ACTIONS(5782),
    [anon_sym_PLUS] = ACTIONS(6414),
    [anon_sym_DASH] = ACTIONS(6414),
    [anon_sym_STAR] = ACTIONS(6416),
    [anon_sym_SLASH] = ACTIONS(6418),
    [anon_sym_PERCENT] = ACTIONS(6416),
    [anon_sym_CARET] = ACTIONS(6420),
    [anon_sym_PIPE] = ACTIONS(6422),
    [anon_sym_AMP] = ACTIONS(6424),
    [anon_sym_LT_LT] = ACTIONS(6426),
    [anon_sym_GT_GT] = ACTIONS(6428),
    [anon_sym_GT_GT_GT] = ACTIONS(6426),
    [anon_sym_EQ_EQ] = ACTIONS(6430),
    [anon_sym_BANG_EQ] = ACTIONS(6430),
    [anon_sym_GT_EQ] = ACTIONS(6432),
    [anon_sym_LT_EQ] = ACTIONS(6432),
    [anon_sym_DOT] = ACTIONS(4634),
    [anon_sym_switch] = ACTIONS(6434),
    [anon_sym_DOT_DOT] = ACTIONS(6436),
    [anon_sym_and] = ACTIONS(5584),
    [anon_sym_or] = ACTIONS(5584),
    [anon_sym_AMP_AMP] = ACTIONS(6438),
    [anon_sym_PIPE_PIPE] = ACTIONS(6440),
    [anon_sym_QMARK_QMARK] = ACTIONS(6442),
    [anon_sym_into] = ACTIONS(5584),
    [anon_sym_as] = ACTIONS(6444),
    [anon_sym_is] = ACTIONS(6446),
    [anon_sym_DASH_GT] = ACTIONS(4636),
    [anon_sym_with] = ACTIONS(6448),
    [aux_sym_preproc_if_token3] = ACTIONS(5584),
    [aux_sym_preproc_else_token1] = ACTIONS(5584),
    [aux_sym_preproc_elif_token1] = ACTIONS(5584),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4470] = {
    [sym_argument_list] = STATE(4044),
    [sym_bracketed_argument_list] = STATE(3189),
    [sym_preproc_region] = STATE(4470),
    [sym_preproc_endregion] = STATE(4470),
    [sym_preproc_line] = STATE(4470),
    [sym_preproc_pragma] = STATE(4470),
    [sym_preproc_nullable] = STATE(4470),
    [sym_preproc_error] = STATE(4470),
    [sym_preproc_warning] = STATE(4470),
    [sym_preproc_define] = STATE(4470),
    [sym_preproc_undef] = STATE(4470),
    [anon_sym_SEMI] = ACTIONS(5624),
    [anon_sym_LBRACK] = ACTIONS(5778),
    [anon_sym_COMMA] = ACTIONS(5624),
    [anon_sym_RBRACK] = ACTIONS(5624),
    [anon_sym_LPAREN] = ACTIONS(5759),
    [anon_sym_RPAREN] = ACTIONS(5624),
    [anon_sym_RBRACE] = ACTIONS(5624),
    [anon_sym_LT] = ACTIONS(6410),
    [anon_sym_GT] = ACTIONS(6410),
    [anon_sym_in] = ACTIONS(5626),
    [anon_sym_QMARK] = ACTIONS(6412),
    [anon_sym_BANG] = ACTIONS(5780),
    [anon_sym_PLUS_PLUS] = ACTIONS(5782),
    [anon_sym_DASH_DASH] = ACTIONS(5782),
    [anon_sym_PLUS] = ACTIONS(6414),
    [anon_sym_DASH] = ACTIONS(6414),
    [anon_sym_STAR] = ACTIONS(6416),
    [anon_sym_SLASH] = ACTIONS(6418),
    [anon_sym_PERCENT] = ACTIONS(6416),
    [anon_sym_CARET] = ACTIONS(6420),
    [anon_sym_PIPE] = ACTIONS(6422),
    [anon_sym_AMP] = ACTIONS(6424),
    [anon_sym_LT_LT] = ACTIONS(6426),
    [anon_sym_GT_GT] = ACTIONS(6428),
    [anon_sym_GT_GT_GT] = ACTIONS(6426),
    [anon_sym_EQ_EQ] = ACTIONS(6430),
    [anon_sym_BANG_EQ] = ACTIONS(6430),
    [anon_sym_GT_EQ] = ACTIONS(6432),
    [anon_sym_LT_EQ] = ACTIONS(6432),
    [anon_sym_DOT] = ACTIONS(4634),
    [anon_sym_switch] = ACTIONS(6434),
    [anon_sym_DOT_DOT] = ACTIONS(6436),
    [anon_sym_and] = ACTIONS(5624),
    [anon_sym_or] = ACTIONS(5624),
    [anon_sym_AMP_AMP] = ACTIONS(6438),
    [anon_sym_PIPE_PIPE] = ACTIONS(6440),
    [anon_sym_QMARK_QMARK] = ACTIONS(6442),
    [anon_sym_into] = ACTIONS(5624),
    [anon_sym_as] = ACTIONS(6444),
    [anon_sym_is] = ACTIONS(6446),
    [anon_sym_DASH_GT] = ACTIONS(4636),
    [anon_sym_with] = ACTIONS(6448),
    [aux_sym_preproc_if_token3] = ACTIONS(5624),
    [aux_sym_preproc_else_token1] = ACTIONS(5624),
    [aux_sym_preproc_elif_token1] = ACTIONS(5624),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4471] = {
    [sym_argument_list] = STATE(4044),
    [sym_bracketed_argument_list] = STATE(3189),
    [sym_preproc_region] = STATE(4471),
    [sym_preproc_endregion] = STATE(4471),
    [sym_preproc_line] = STATE(4471),
    [sym_preproc_pragma] = STATE(4471),
    [sym_preproc_nullable] = STATE(4471),
    [sym_preproc_error] = STATE(4471),
    [sym_preproc_warning] = STATE(4471),
    [sym_preproc_define] = STATE(4471),
    [sym_preproc_undef] = STATE(4471),
    [anon_sym_SEMI] = ACTIONS(6342),
    [anon_sym_LBRACK] = ACTIONS(5778),
    [anon_sym_COMMA] = ACTIONS(6342),
    [anon_sym_RBRACK] = ACTIONS(6342),
    [anon_sym_LPAREN] = ACTIONS(5759),
    [anon_sym_RPAREN] = ACTIONS(6342),
    [anon_sym_RBRACE] = ACTIONS(6342),
    [anon_sym_LT] = ACTIONS(6410),
    [anon_sym_GT] = ACTIONS(6410),
    [anon_sym_in] = ACTIONS(6344),
    [anon_sym_QMARK] = ACTIONS(6344),
    [anon_sym_BANG] = ACTIONS(5780),
    [anon_sym_PLUS_PLUS] = ACTIONS(5782),
    [anon_sym_DASH_DASH] = ACTIONS(5782),
    [anon_sym_PLUS] = ACTIONS(6414),
    [anon_sym_DASH] = ACTIONS(6414),
    [anon_sym_STAR] = ACTIONS(6416),
    [anon_sym_SLASH] = ACTIONS(6418),
    [anon_sym_PERCENT] = ACTIONS(6416),
    [anon_sym_CARET] = ACTIONS(6420),
    [anon_sym_PIPE] = ACTIONS(6422),
    [anon_sym_AMP] = ACTIONS(6424),
    [anon_sym_LT_LT] = ACTIONS(6426),
    [anon_sym_GT_GT] = ACTIONS(6428),
    [anon_sym_GT_GT_GT] = ACTIONS(6426),
    [anon_sym_EQ_EQ] = ACTIONS(6430),
    [anon_sym_BANG_EQ] = ACTIONS(6430),
    [anon_sym_GT_EQ] = ACTIONS(6432),
    [anon_sym_LT_EQ] = ACTIONS(6432),
    [anon_sym_DOT] = ACTIONS(4634),
    [anon_sym_switch] = ACTIONS(6434),
    [anon_sym_DOT_DOT] = ACTIONS(6436),
    [anon_sym_and] = ACTIONS(6342),
    [anon_sym_or] = ACTIONS(6342),
    [anon_sym_AMP_AMP] = ACTIONS(6438),
    [anon_sym_PIPE_PIPE] = ACTIONS(6440),
    [anon_sym_QMARK_QMARK] = ACTIONS(6442),
    [anon_sym_into] = ACTIONS(6342),
    [anon_sym_as] = ACTIONS(6444),
    [anon_sym_is] = ACTIONS(6446),
    [anon_sym_DASH_GT] = ACTIONS(4636),
    [anon_sym_with] = ACTIONS(6448),
    [aux_sym_preproc_if_token3] = ACTIONS(6342),
    [aux_sym_preproc_else_token1] = ACTIONS(6342),
    [aux_sym_preproc_elif_token1] = ACTIONS(6342),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4472] = {
    [sym_preproc_region] = STATE(4472),
    [sym_preproc_endregion] = STATE(4472),
    [sym_preproc_line] = STATE(4472),
    [sym_preproc_pragma] = STATE(4472),
    [sym_preproc_nullable] = STATE(4472),
    [sym_preproc_error] = STATE(4472),
    [sym_preproc_warning] = STATE(4472),
    [sym_preproc_define] = STATE(4472),
    [sym_preproc_undef] = STATE(4472),
    [sym__identifier_token] = ACTIONS(5723),
    [anon_sym_extern] = ACTIONS(5723),
    [anon_sym_alias] = ACTIONS(5723),
    [anon_sym_global] = ACTIONS(5723),
    [anon_sym_unsafe] = ACTIONS(5723),
    [anon_sym_static] = ACTIONS(5723),
    [anon_sym_LBRACK] = ACTIONS(5725),
    [anon_sym_LPAREN] = ACTIONS(5725),
    [anon_sym_ref] = ACTIONS(5723),
    [anon_sym_delegate] = ACTIONS(5723),
    [anon_sym_abstract] = ACTIONS(5723),
    [anon_sym_async] = ACTIONS(5723),
    [anon_sym_const] = ACTIONS(5723),
    [anon_sym_file] = ACTIONS(5723),
    [anon_sym_fixed] = ACTIONS(5723),
    [anon_sym_internal] = ACTIONS(5723),
    [anon_sym_new] = ACTIONS(5723),
    [anon_sym_override] = ACTIONS(5723),
    [anon_sym_partial] = ACTIONS(5723),
    [anon_sym_private] = ACTIONS(5723),
    [anon_sym_protected] = ACTIONS(5723),
    [anon_sym_public] = ACTIONS(5723),
    [anon_sym_readonly] = ACTIONS(5723),
    [anon_sym_required] = ACTIONS(5723),
    [anon_sym_sealed] = ACTIONS(5723),
    [anon_sym_virtual] = ACTIONS(5723),
    [anon_sym_volatile] = ACTIONS(5723),
    [anon_sym_where] = ACTIONS(5723),
    [anon_sym_notnull] = ACTIONS(5723),
    [anon_sym_unmanaged] = ACTIONS(5723),
    [anon_sym_scoped] = ACTIONS(5723),
    [anon_sym_var] = ACTIONS(5723),
    [sym_predefined_type] = ACTIONS(5723),
    [anon_sym_yield] = ACTIONS(5723),
    [anon_sym_when] = ACTIONS(5723),
    [anon_sym_from] = ACTIONS(5723),
    [anon_sym_into] = ACTIONS(5723),
    [anon_sym_join] = ACTIONS(5723),
    [anon_sym_on] = ACTIONS(5723),
    [anon_sym_equals] = ACTIONS(5723),
    [anon_sym_let] = ACTIONS(5723),
    [anon_sym_orderby] = ACTIONS(5723),
    [anon_sym_ascending] = ACTIONS(5723),
    [anon_sym_descending] = ACTIONS(5723),
    [anon_sym_group] = ACTIONS(5723),
    [anon_sym_by] = ACTIONS(5723),
    [anon_sym_select] = ACTIONS(5723),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4473] = {
    [sym_preproc_region] = STATE(4473),
    [sym_preproc_endregion] = STATE(4473),
    [sym_preproc_line] = STATE(4473),
    [sym_preproc_pragma] = STATE(4473),
    [sym_preproc_nullable] = STATE(4473),
    [sym_preproc_error] = STATE(4473),
    [sym_preproc_warning] = STATE(4473),
    [sym_preproc_define] = STATE(4473),
    [sym_preproc_undef] = STATE(4473),
    [anon_sym_EQ] = ACTIONS(6470),
    [anon_sym_LBRACK] = ACTIONS(5286),
    [anon_sym_LPAREN] = ACTIONS(5286),
    [anon_sym_LT] = ACTIONS(5288),
    [anon_sym_GT] = ACTIONS(5288),
    [anon_sym_in] = ACTIONS(5286),
    [anon_sym_QMARK] = ACTIONS(5288),
    [anon_sym_BANG] = ACTIONS(5288),
    [anon_sym_PLUS_PLUS] = ACTIONS(5286),
    [anon_sym_DASH_DASH] = ACTIONS(5286),
    [anon_sym_PLUS] = ACTIONS(5288),
    [anon_sym_DASH] = ACTIONS(5288),
    [anon_sym_STAR] = ACTIONS(5288),
    [anon_sym_SLASH] = ACTIONS(5288),
    [anon_sym_PERCENT] = ACTIONS(5288),
    [anon_sym_CARET] = ACTIONS(5288),
    [anon_sym_PIPE] = ACTIONS(5288),
    [anon_sym_AMP] = ACTIONS(5288),
    [anon_sym_LT_LT] = ACTIONS(5288),
    [anon_sym_GT_GT] = ACTIONS(5288),
    [anon_sym_GT_GT_GT] = ACTIONS(5288),
    [anon_sym_EQ_EQ] = ACTIONS(5286),
    [anon_sym_BANG_EQ] = ACTIONS(5286),
    [anon_sym_GT_EQ] = ACTIONS(5286),
    [anon_sym_LT_EQ] = ACTIONS(5286),
    [anon_sym_DOT] = ACTIONS(5288),
    [anon_sym_switch] = ACTIONS(5286),
    [anon_sym_DOT_DOT] = ACTIONS(5286),
    [anon_sym_PLUS_EQ] = ACTIONS(6472),
    [anon_sym_DASH_EQ] = ACTIONS(6472),
    [anon_sym_STAR_EQ] = ACTIONS(6472),
    [anon_sym_SLASH_EQ] = ACTIONS(6472),
    [anon_sym_PERCENT_EQ] = ACTIONS(6472),
    [anon_sym_AMP_EQ] = ACTIONS(6472),
    [anon_sym_CARET_EQ] = ACTIONS(6472),
    [anon_sym_PIPE_EQ] = ACTIONS(6472),
    [anon_sym_LT_LT_EQ] = ACTIONS(6472),
    [anon_sym_GT_GT_EQ] = ACTIONS(6472),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(6472),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(6472),
    [anon_sym_AMP_AMP] = ACTIONS(5286),
    [anon_sym_PIPE_PIPE] = ACTIONS(5286),
    [anon_sym_QMARK_QMARK] = ACTIONS(5288),
    [anon_sym_as] = ACTIONS(5286),
    [anon_sym_is] = ACTIONS(5286),
    [anon_sym_DASH_GT] = ACTIONS(5286),
    [anon_sym_with] = ACTIONS(5286),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4474] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4474),
    [sym_preproc_endregion] = STATE(4474),
    [sym_preproc_line] = STATE(4474),
    [sym_preproc_pragma] = STATE(4474),
    [sym_preproc_nullable] = STATE(4474),
    [sym_preproc_error] = STATE(4474),
    [sym_preproc_warning] = STATE(4474),
    [sym_preproc_define] = STATE(4474),
    [sym_preproc_undef] = STATE(4474),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(6328),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(6330),
    [anon_sym_GT] = ACTIONS(6330),
    [anon_sym_where] = ACTIONS(6328),
    [anon_sym_QMARK] = ACTIONS(6330),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(6330),
    [anon_sym_DASH] = ACTIONS(6330),
    [anon_sym_STAR] = ACTIONS(6328),
    [anon_sym_SLASH] = ACTIONS(6330),
    [anon_sym_PERCENT] = ACTIONS(6328),
    [anon_sym_CARET] = ACTIONS(6328),
    [anon_sym_PIPE] = ACTIONS(6330),
    [anon_sym_AMP] = ACTIONS(6330),
    [anon_sym_LT_LT] = ACTIONS(6328),
    [anon_sym_GT_GT] = ACTIONS(6330),
    [anon_sym_GT_GT_GT] = ACTIONS(6328),
    [anon_sym_EQ_EQ] = ACTIONS(6328),
    [anon_sym_BANG_EQ] = ACTIONS(6328),
    [anon_sym_GT_EQ] = ACTIONS(6328),
    [anon_sym_LT_EQ] = ACTIONS(6328),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(6328),
    [anon_sym_DOT_DOT] = ACTIONS(6404),
    [anon_sym_and] = ACTIONS(6328),
    [anon_sym_or] = ACTIONS(6330),
    [anon_sym_AMP_AMP] = ACTIONS(6328),
    [anon_sym_PIPE_PIPE] = ACTIONS(6328),
    [anon_sym_QMARK_QMARK] = ACTIONS(6328),
    [anon_sym_from] = ACTIONS(6328),
    [anon_sym_join] = ACTIONS(6328),
    [anon_sym_let] = ACTIONS(6328),
    [anon_sym_orderby] = ACTIONS(6328),
    [anon_sym_ascending] = ACTIONS(6328),
    [anon_sym_descending] = ACTIONS(6328),
    [anon_sym_group] = ACTIONS(6328),
    [anon_sym_select] = ACTIONS(6328),
    [anon_sym_as] = ACTIONS(6330),
    [anon_sym_is] = ACTIONS(6328),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(6328),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4475] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4475),
    [sym_preproc_endregion] = STATE(4475),
    [sym_preproc_line] = STATE(4475),
    [sym_preproc_pragma] = STATE(4475),
    [sym_preproc_nullable] = STATE(4475),
    [sym_preproc_error] = STATE(4475),
    [sym_preproc_warning] = STATE(4475),
    [sym_preproc_define] = STATE(4475),
    [sym_preproc_undef] = STATE(4475),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(1227),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(1229),
    [anon_sym_GT] = ACTIONS(1229),
    [anon_sym_where] = ACTIONS(1227),
    [anon_sym_QMARK] = ACTIONS(1229),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(1229),
    [anon_sym_DASH] = ACTIONS(1229),
    [anon_sym_STAR] = ACTIONS(1227),
    [anon_sym_SLASH] = ACTIONS(1229),
    [anon_sym_PERCENT] = ACTIONS(1227),
    [anon_sym_CARET] = ACTIONS(1227),
    [anon_sym_PIPE] = ACTIONS(1229),
    [anon_sym_AMP] = ACTIONS(1229),
    [anon_sym_LT_LT] = ACTIONS(1227),
    [anon_sym_GT_GT] = ACTIONS(1229),
    [anon_sym_GT_GT_GT] = ACTIONS(1227),
    [anon_sym_EQ_EQ] = ACTIONS(1227),
    [anon_sym_BANG_EQ] = ACTIONS(1227),
    [anon_sym_GT_EQ] = ACTIONS(1227),
    [anon_sym_LT_EQ] = ACTIONS(1227),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(1227),
    [anon_sym_DOT_DOT] = ACTIONS(6404),
    [anon_sym_and] = ACTIONS(1227),
    [anon_sym_or] = ACTIONS(1229),
    [anon_sym_AMP_AMP] = ACTIONS(1227),
    [anon_sym_PIPE_PIPE] = ACTIONS(1227),
    [anon_sym_QMARK_QMARK] = ACTIONS(1227),
    [anon_sym_from] = ACTIONS(1227),
    [anon_sym_join] = ACTIONS(1227),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_orderby] = ACTIONS(1227),
    [anon_sym_ascending] = ACTIONS(1227),
    [anon_sym_descending] = ACTIONS(1227),
    [anon_sym_group] = ACTIONS(1227),
    [anon_sym_select] = ACTIONS(1227),
    [anon_sym_as] = ACTIONS(1229),
    [anon_sym_is] = ACTIONS(1227),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(1227),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4476] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4476),
    [sym_preproc_endregion] = STATE(4476),
    [sym_preproc_line] = STATE(4476),
    [sym_preproc_pragma] = STATE(4476),
    [sym_preproc_nullable] = STATE(4476),
    [sym_preproc_error] = STATE(4476),
    [sym_preproc_warning] = STATE(4476),
    [sym_preproc_define] = STATE(4476),
    [sym_preproc_undef] = STATE(4476),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(5644),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(6388),
    [anon_sym_GT] = ACTIONS(6388),
    [anon_sym_where] = ACTIONS(5644),
    [anon_sym_QMARK] = ACTIONS(6450),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(6390),
    [anon_sym_DASH] = ACTIONS(6390),
    [anon_sym_STAR] = ACTIONS(6392),
    [anon_sym_SLASH] = ACTIONS(6394),
    [anon_sym_PERCENT] = ACTIONS(6392),
    [anon_sym_CARET] = ACTIONS(6452),
    [anon_sym_PIPE] = ACTIONS(6454),
    [anon_sym_AMP] = ACTIONS(6456),
    [anon_sym_LT_LT] = ACTIONS(6396),
    [anon_sym_GT_GT] = ACTIONS(6398),
    [anon_sym_GT_GT_GT] = ACTIONS(6396),
    [anon_sym_EQ_EQ] = ACTIONS(6400),
    [anon_sym_BANG_EQ] = ACTIONS(6400),
    [anon_sym_GT_EQ] = ACTIONS(6402),
    [anon_sym_LT_EQ] = ACTIONS(6402),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(6216),
    [anon_sym_DOT_DOT] = ACTIONS(6404),
    [anon_sym_and] = ACTIONS(5644),
    [anon_sym_or] = ACTIONS(5646),
    [anon_sym_AMP_AMP] = ACTIONS(6458),
    [anon_sym_PIPE_PIPE] = ACTIONS(6460),
    [anon_sym_QMARK_QMARK] = ACTIONS(6462),
    [anon_sym_from] = ACTIONS(5644),
    [anon_sym_join] = ACTIONS(5644),
    [anon_sym_let] = ACTIONS(5644),
    [anon_sym_orderby] = ACTIONS(5644),
    [anon_sym_ascending] = ACTIONS(5644),
    [anon_sym_descending] = ACTIONS(5644),
    [anon_sym_group] = ACTIONS(5644),
    [anon_sym_select] = ACTIONS(5644),
    [anon_sym_as] = ACTIONS(6406),
    [anon_sym_is] = ACTIONS(6408),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(6232),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4477] = {
    [sym_preproc_region] = STATE(4477),
    [sym_preproc_endregion] = STATE(4477),
    [sym_preproc_line] = STATE(4477),
    [sym_preproc_pragma] = STATE(4477),
    [sym_preproc_nullable] = STATE(4477),
    [sym_preproc_error] = STATE(4477),
    [sym_preproc_warning] = STATE(4477),
    [sym_preproc_define] = STATE(4477),
    [sym_preproc_undef] = STATE(4477),
    [aux_sym__query_body_repeat2] = STATE(4478),
    [anon_sym_LBRACK] = ACTIONS(6474),
    [anon_sym_COMMA] = ACTIONS(6474),
    [anon_sym_LPAREN] = ACTIONS(6474),
    [anon_sym_LT] = ACTIONS(6476),
    [anon_sym_GT] = ACTIONS(6476),
    [anon_sym_where] = ACTIONS(6474),
    [anon_sym_QMARK] = ACTIONS(6476),
    [anon_sym_BANG] = ACTIONS(6476),
    [anon_sym_PLUS_PLUS] = ACTIONS(6474),
    [anon_sym_DASH_DASH] = ACTIONS(6474),
    [anon_sym_PLUS] = ACTIONS(6476),
    [anon_sym_DASH] = ACTIONS(6476),
    [anon_sym_STAR] = ACTIONS(6474),
    [anon_sym_SLASH] = ACTIONS(6476),
    [anon_sym_PERCENT] = ACTIONS(6474),
    [anon_sym_CARET] = ACTIONS(6474),
    [anon_sym_PIPE] = ACTIONS(6476),
    [anon_sym_AMP] = ACTIONS(6476),
    [anon_sym_LT_LT] = ACTIONS(6474),
    [anon_sym_GT_GT] = ACTIONS(6476),
    [anon_sym_GT_GT_GT] = ACTIONS(6474),
    [anon_sym_EQ_EQ] = ACTIONS(6474),
    [anon_sym_BANG_EQ] = ACTIONS(6474),
    [anon_sym_GT_EQ] = ACTIONS(6474),
    [anon_sym_LT_EQ] = ACTIONS(6474),
    [anon_sym_DOT] = ACTIONS(6476),
    [anon_sym_switch] = ACTIONS(6474),
    [anon_sym_DOT_DOT] = ACTIONS(6474),
    [anon_sym_and] = ACTIONS(6474),
    [anon_sym_or] = ACTIONS(6476),
    [anon_sym_AMP_AMP] = ACTIONS(6474),
    [anon_sym_PIPE_PIPE] = ACTIONS(6474),
    [anon_sym_QMARK_QMARK] = ACTIONS(6474),
    [anon_sym_from] = ACTIONS(6474),
    [anon_sym_into] = ACTIONS(6478),
    [anon_sym_join] = ACTIONS(6474),
    [anon_sym_let] = ACTIONS(6474),
    [anon_sym_orderby] = ACTIONS(6474),
    [anon_sym_ascending] = ACTIONS(6474),
    [anon_sym_descending] = ACTIONS(6474),
    [anon_sym_group] = ACTIONS(6474),
    [anon_sym_select] = ACTIONS(6474),
    [anon_sym_as] = ACTIONS(6476),
    [anon_sym_is] = ACTIONS(6474),
    [anon_sym_DASH_GT] = ACTIONS(6474),
    [anon_sym_with] = ACTIONS(6474),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4478] = {
    [sym_preproc_region] = STATE(4478),
    [sym_preproc_endregion] = STATE(4478),
    [sym_preproc_line] = STATE(4478),
    [sym_preproc_pragma] = STATE(4478),
    [sym_preproc_nullable] = STATE(4478),
    [sym_preproc_error] = STATE(4478),
    [sym_preproc_warning] = STATE(4478),
    [sym_preproc_define] = STATE(4478),
    [sym_preproc_undef] = STATE(4478),
    [aux_sym__query_body_repeat2] = STATE(4481),
    [anon_sym_LBRACK] = ACTIONS(6480),
    [anon_sym_COMMA] = ACTIONS(6480),
    [anon_sym_LPAREN] = ACTIONS(6480),
    [anon_sym_LT] = ACTIONS(6482),
    [anon_sym_GT] = ACTIONS(6482),
    [anon_sym_where] = ACTIONS(6480),
    [anon_sym_QMARK] = ACTIONS(6482),
    [anon_sym_BANG] = ACTIONS(6482),
    [anon_sym_PLUS_PLUS] = ACTIONS(6480),
    [anon_sym_DASH_DASH] = ACTIONS(6480),
    [anon_sym_PLUS] = ACTIONS(6482),
    [anon_sym_DASH] = ACTIONS(6482),
    [anon_sym_STAR] = ACTIONS(6480),
    [anon_sym_SLASH] = ACTIONS(6482),
    [anon_sym_PERCENT] = ACTIONS(6480),
    [anon_sym_CARET] = ACTIONS(6480),
    [anon_sym_PIPE] = ACTIONS(6482),
    [anon_sym_AMP] = ACTIONS(6482),
    [anon_sym_LT_LT] = ACTIONS(6480),
    [anon_sym_GT_GT] = ACTIONS(6482),
    [anon_sym_GT_GT_GT] = ACTIONS(6480),
    [anon_sym_EQ_EQ] = ACTIONS(6480),
    [anon_sym_BANG_EQ] = ACTIONS(6480),
    [anon_sym_GT_EQ] = ACTIONS(6480),
    [anon_sym_LT_EQ] = ACTIONS(6480),
    [anon_sym_DOT] = ACTIONS(6482),
    [anon_sym_switch] = ACTIONS(6480),
    [anon_sym_DOT_DOT] = ACTIONS(6480),
    [anon_sym_and] = ACTIONS(6480),
    [anon_sym_or] = ACTIONS(6482),
    [anon_sym_AMP_AMP] = ACTIONS(6480),
    [anon_sym_PIPE_PIPE] = ACTIONS(6480),
    [anon_sym_QMARK_QMARK] = ACTIONS(6480),
    [anon_sym_from] = ACTIONS(6480),
    [anon_sym_into] = ACTIONS(6478),
    [anon_sym_join] = ACTIONS(6480),
    [anon_sym_let] = ACTIONS(6480),
    [anon_sym_orderby] = ACTIONS(6480),
    [anon_sym_ascending] = ACTIONS(6480),
    [anon_sym_descending] = ACTIONS(6480),
    [anon_sym_group] = ACTIONS(6480),
    [anon_sym_select] = ACTIONS(6480),
    [anon_sym_as] = ACTIONS(6482),
    [anon_sym_is] = ACTIONS(6480),
    [anon_sym_DASH_GT] = ACTIONS(6480),
    [anon_sym_with] = ACTIONS(6480),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4479] = {
    [sym_preproc_region] = STATE(4479),
    [sym_preproc_endregion] = STATE(4479),
    [sym_preproc_line] = STATE(4479),
    [sym_preproc_pragma] = STATE(4479),
    [sym_preproc_nullable] = STATE(4479),
    [sym_preproc_error] = STATE(4479),
    [sym_preproc_warning] = STATE(4479),
    [sym_preproc_define] = STATE(4479),
    [sym_preproc_undef] = STATE(4479),
    [aux_sym__query_body_repeat2] = STATE(4482),
    [anon_sym_LBRACK] = ACTIONS(6480),
    [anon_sym_COMMA] = ACTIONS(6480),
    [anon_sym_LPAREN] = ACTIONS(6480),
    [anon_sym_LT] = ACTIONS(6482),
    [anon_sym_GT] = ACTIONS(6482),
    [anon_sym_where] = ACTIONS(6480),
    [anon_sym_QMARK] = ACTIONS(6482),
    [anon_sym_BANG] = ACTIONS(6482),
    [anon_sym_PLUS_PLUS] = ACTIONS(6480),
    [anon_sym_DASH_DASH] = ACTIONS(6480),
    [anon_sym_PLUS] = ACTIONS(6482),
    [anon_sym_DASH] = ACTIONS(6482),
    [anon_sym_STAR] = ACTIONS(6480),
    [anon_sym_SLASH] = ACTIONS(6482),
    [anon_sym_PERCENT] = ACTIONS(6480),
    [anon_sym_CARET] = ACTIONS(6480),
    [anon_sym_PIPE] = ACTIONS(6482),
    [anon_sym_AMP] = ACTIONS(6482),
    [anon_sym_LT_LT] = ACTIONS(6480),
    [anon_sym_GT_GT] = ACTIONS(6482),
    [anon_sym_GT_GT_GT] = ACTIONS(6480),
    [anon_sym_EQ_EQ] = ACTIONS(6480),
    [anon_sym_BANG_EQ] = ACTIONS(6480),
    [anon_sym_GT_EQ] = ACTIONS(6480),
    [anon_sym_LT_EQ] = ACTIONS(6480),
    [anon_sym_DOT] = ACTIONS(6482),
    [anon_sym_switch] = ACTIONS(6480),
    [anon_sym_DOT_DOT] = ACTIONS(6480),
    [anon_sym_and] = ACTIONS(6480),
    [anon_sym_or] = ACTIONS(6482),
    [anon_sym_AMP_AMP] = ACTIONS(6480),
    [anon_sym_PIPE_PIPE] = ACTIONS(6480),
    [anon_sym_QMARK_QMARK] = ACTIONS(6480),
    [anon_sym_from] = ACTIONS(6480),
    [anon_sym_into] = ACTIONS(6478),
    [anon_sym_join] = ACTIONS(6480),
    [anon_sym_let] = ACTIONS(6480),
    [anon_sym_orderby] = ACTIONS(6480),
    [anon_sym_ascending] = ACTIONS(6480),
    [anon_sym_descending] = ACTIONS(6480),
    [anon_sym_group] = ACTIONS(6480),
    [anon_sym_select] = ACTIONS(6480),
    [anon_sym_as] = ACTIONS(6482),
    [anon_sym_is] = ACTIONS(6480),
    [anon_sym_DASH_GT] = ACTIONS(6480),
    [anon_sym_with] = ACTIONS(6480),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4480] = {
    [sym_argument_list] = STATE(4044),
    [sym_bracketed_argument_list] = STATE(3189),
    [sym_preproc_region] = STATE(4480),
    [sym_preproc_endregion] = STATE(4480),
    [sym_preproc_line] = STATE(4480),
    [sym_preproc_pragma] = STATE(4480),
    [sym_preproc_nullable] = STATE(4480),
    [sym_preproc_error] = STATE(4480),
    [sym_preproc_warning] = STATE(4480),
    [sym_preproc_define] = STATE(4480),
    [sym_preproc_undef] = STATE(4480),
    [anon_sym_SEMI] = ACTIONS(1227),
    [anon_sym_LBRACK] = ACTIONS(5778),
    [anon_sym_COMMA] = ACTIONS(1227),
    [anon_sym_RBRACK] = ACTIONS(1227),
    [anon_sym_LPAREN] = ACTIONS(5759),
    [anon_sym_RPAREN] = ACTIONS(1227),
    [anon_sym_RBRACE] = ACTIONS(1227),
    [anon_sym_LT] = ACTIONS(1229),
    [anon_sym_GT] = ACTIONS(1229),
    [anon_sym_in] = ACTIONS(1229),
    [anon_sym_QMARK] = ACTIONS(1229),
    [anon_sym_BANG] = ACTIONS(5780),
    [anon_sym_PLUS_PLUS] = ACTIONS(5782),
    [anon_sym_DASH_DASH] = ACTIONS(5782),
    [anon_sym_PLUS] = ACTIONS(1229),
    [anon_sym_DASH] = ACTIONS(1229),
    [anon_sym_STAR] = ACTIONS(1227),
    [anon_sym_SLASH] = ACTIONS(1229),
    [anon_sym_PERCENT] = ACTIONS(1227),
    [anon_sym_CARET] = ACTIONS(1227),
    [anon_sym_PIPE] = ACTIONS(1229),
    [anon_sym_AMP] = ACTIONS(1229),
    [anon_sym_LT_LT] = ACTIONS(1227),
    [anon_sym_GT_GT] = ACTIONS(1229),
    [anon_sym_GT_GT_GT] = ACTIONS(1227),
    [anon_sym_EQ_EQ] = ACTIONS(1227),
    [anon_sym_BANG_EQ] = ACTIONS(1227),
    [anon_sym_GT_EQ] = ACTIONS(1227),
    [anon_sym_LT_EQ] = ACTIONS(1227),
    [anon_sym_DOT] = ACTIONS(4634),
    [anon_sym_switch] = ACTIONS(1227),
    [anon_sym_DOT_DOT] = ACTIONS(6436),
    [anon_sym_and] = ACTIONS(1227),
    [anon_sym_or] = ACTIONS(1227),
    [anon_sym_AMP_AMP] = ACTIONS(1227),
    [anon_sym_PIPE_PIPE] = ACTIONS(1227),
    [anon_sym_QMARK_QMARK] = ACTIONS(1227),
    [anon_sym_into] = ACTIONS(1227),
    [anon_sym_as] = ACTIONS(1227),
    [anon_sym_is] = ACTIONS(1227),
    [anon_sym_DASH_GT] = ACTIONS(4636),
    [anon_sym_with] = ACTIONS(1227),
    [aux_sym_preproc_if_token3] = ACTIONS(1227),
    [aux_sym_preproc_else_token1] = ACTIONS(1227),
    [aux_sym_preproc_elif_token1] = ACTIONS(1227),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4481] = {
    [sym_preproc_region] = STATE(4481),
    [sym_preproc_endregion] = STATE(4481),
    [sym_preproc_line] = STATE(4481),
    [sym_preproc_pragma] = STATE(4481),
    [sym_preproc_nullable] = STATE(4481),
    [sym_preproc_error] = STATE(4481),
    [sym_preproc_warning] = STATE(4481),
    [sym_preproc_define] = STATE(4481),
    [sym_preproc_undef] = STATE(4481),
    [aux_sym__query_body_repeat2] = STATE(4481),
    [anon_sym_LBRACK] = ACTIONS(6484),
    [anon_sym_COMMA] = ACTIONS(6484),
    [anon_sym_LPAREN] = ACTIONS(6484),
    [anon_sym_LT] = ACTIONS(6486),
    [anon_sym_GT] = ACTIONS(6486),
    [anon_sym_where] = ACTIONS(6484),
    [anon_sym_QMARK] = ACTIONS(6486),
    [anon_sym_BANG] = ACTIONS(6486),
    [anon_sym_PLUS_PLUS] = ACTIONS(6484),
    [anon_sym_DASH_DASH] = ACTIONS(6484),
    [anon_sym_PLUS] = ACTIONS(6486),
    [anon_sym_DASH] = ACTIONS(6486),
    [anon_sym_STAR] = ACTIONS(6484),
    [anon_sym_SLASH] = ACTIONS(6486),
    [anon_sym_PERCENT] = ACTIONS(6484),
    [anon_sym_CARET] = ACTIONS(6484),
    [anon_sym_PIPE] = ACTIONS(6486),
    [anon_sym_AMP] = ACTIONS(6486),
    [anon_sym_LT_LT] = ACTIONS(6484),
    [anon_sym_GT_GT] = ACTIONS(6486),
    [anon_sym_GT_GT_GT] = ACTIONS(6484),
    [anon_sym_EQ_EQ] = ACTIONS(6484),
    [anon_sym_BANG_EQ] = ACTIONS(6484),
    [anon_sym_GT_EQ] = ACTIONS(6484),
    [anon_sym_LT_EQ] = ACTIONS(6484),
    [anon_sym_DOT] = ACTIONS(6486),
    [anon_sym_switch] = ACTIONS(6484),
    [anon_sym_DOT_DOT] = ACTIONS(6484),
    [anon_sym_and] = ACTIONS(6484),
    [anon_sym_or] = ACTIONS(6486),
    [anon_sym_AMP_AMP] = ACTIONS(6484),
    [anon_sym_PIPE_PIPE] = ACTIONS(6484),
    [anon_sym_QMARK_QMARK] = ACTIONS(6484),
    [anon_sym_from] = ACTIONS(6484),
    [anon_sym_into] = ACTIONS(6488),
    [anon_sym_join] = ACTIONS(6484),
    [anon_sym_let] = ACTIONS(6484),
    [anon_sym_orderby] = ACTIONS(6484),
    [anon_sym_ascending] = ACTIONS(6484),
    [anon_sym_descending] = ACTIONS(6484),
    [anon_sym_group] = ACTIONS(6484),
    [anon_sym_select] = ACTIONS(6484),
    [anon_sym_as] = ACTIONS(6486),
    [anon_sym_is] = ACTIONS(6484),
    [anon_sym_DASH_GT] = ACTIONS(6484),
    [anon_sym_with] = ACTIONS(6484),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4482] = {
    [sym_preproc_region] = STATE(4482),
    [sym_preproc_endregion] = STATE(4482),
    [sym_preproc_line] = STATE(4482),
    [sym_preproc_pragma] = STATE(4482),
    [sym_preproc_nullable] = STATE(4482),
    [sym_preproc_error] = STATE(4482),
    [sym_preproc_warning] = STATE(4482),
    [sym_preproc_define] = STATE(4482),
    [sym_preproc_undef] = STATE(4482),
    [aux_sym__query_body_repeat2] = STATE(4481),
    [anon_sym_LBRACK] = ACTIONS(6491),
    [anon_sym_COMMA] = ACTIONS(6491),
    [anon_sym_LPAREN] = ACTIONS(6491),
    [anon_sym_LT] = ACTIONS(6493),
    [anon_sym_GT] = ACTIONS(6493),
    [anon_sym_where] = ACTIONS(6491),
    [anon_sym_QMARK] = ACTIONS(6493),
    [anon_sym_BANG] = ACTIONS(6493),
    [anon_sym_PLUS_PLUS] = ACTIONS(6491),
    [anon_sym_DASH_DASH] = ACTIONS(6491),
    [anon_sym_PLUS] = ACTIONS(6493),
    [anon_sym_DASH] = ACTIONS(6493),
    [anon_sym_STAR] = ACTIONS(6491),
    [anon_sym_SLASH] = ACTIONS(6493),
    [anon_sym_PERCENT] = ACTIONS(6491),
    [anon_sym_CARET] = ACTIONS(6491),
    [anon_sym_PIPE] = ACTIONS(6493),
    [anon_sym_AMP] = ACTIONS(6493),
    [anon_sym_LT_LT] = ACTIONS(6491),
    [anon_sym_GT_GT] = ACTIONS(6493),
    [anon_sym_GT_GT_GT] = ACTIONS(6491),
    [anon_sym_EQ_EQ] = ACTIONS(6491),
    [anon_sym_BANG_EQ] = ACTIONS(6491),
    [anon_sym_GT_EQ] = ACTIONS(6491),
    [anon_sym_LT_EQ] = ACTIONS(6491),
    [anon_sym_DOT] = ACTIONS(6493),
    [anon_sym_switch] = ACTIONS(6491),
    [anon_sym_DOT_DOT] = ACTIONS(6491),
    [anon_sym_and] = ACTIONS(6491),
    [anon_sym_or] = ACTIONS(6493),
    [anon_sym_AMP_AMP] = ACTIONS(6491),
    [anon_sym_PIPE_PIPE] = ACTIONS(6491),
    [anon_sym_QMARK_QMARK] = ACTIONS(6491),
    [anon_sym_from] = ACTIONS(6491),
    [anon_sym_into] = ACTIONS(6478),
    [anon_sym_join] = ACTIONS(6491),
    [anon_sym_let] = ACTIONS(6491),
    [anon_sym_orderby] = ACTIONS(6491),
    [anon_sym_ascending] = ACTIONS(6491),
    [anon_sym_descending] = ACTIONS(6491),
    [anon_sym_group] = ACTIONS(6491),
    [anon_sym_select] = ACTIONS(6491),
    [anon_sym_as] = ACTIONS(6493),
    [anon_sym_is] = ACTIONS(6491),
    [anon_sym_DASH_GT] = ACTIONS(6491),
    [anon_sym_with] = ACTIONS(6491),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4483] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4483),
    [sym_preproc_endregion] = STATE(4483),
    [sym_preproc_line] = STATE(4483),
    [sym_preproc_pragma] = STATE(4483),
    [sym_preproc_nullable] = STATE(4483),
    [sym_preproc_error] = STATE(4483),
    [sym_preproc_warning] = STATE(4483),
    [sym_preproc_define] = STATE(4483),
    [sym_preproc_undef] = STATE(4483),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(6342),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(6344),
    [anon_sym_GT] = ACTIONS(6344),
    [anon_sym_where] = ACTIONS(6342),
    [anon_sym_QMARK] = ACTIONS(6344),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(6390),
    [anon_sym_DASH] = ACTIONS(6390),
    [anon_sym_STAR] = ACTIONS(6392),
    [anon_sym_SLASH] = ACTIONS(6394),
    [anon_sym_PERCENT] = ACTIONS(6392),
    [anon_sym_CARET] = ACTIONS(6342),
    [anon_sym_PIPE] = ACTIONS(6344),
    [anon_sym_AMP] = ACTIONS(6344),
    [anon_sym_LT_LT] = ACTIONS(6396),
    [anon_sym_GT_GT] = ACTIONS(6398),
    [anon_sym_GT_GT_GT] = ACTIONS(6396),
    [anon_sym_EQ_EQ] = ACTIONS(6342),
    [anon_sym_BANG_EQ] = ACTIONS(6342),
    [anon_sym_GT_EQ] = ACTIONS(6342),
    [anon_sym_LT_EQ] = ACTIONS(6342),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(6216),
    [anon_sym_DOT_DOT] = ACTIONS(6404),
    [anon_sym_and] = ACTIONS(6342),
    [anon_sym_or] = ACTIONS(6344),
    [anon_sym_AMP_AMP] = ACTIONS(6342),
    [anon_sym_PIPE_PIPE] = ACTIONS(6342),
    [anon_sym_QMARK_QMARK] = ACTIONS(6342),
    [anon_sym_from] = ACTIONS(6342),
    [anon_sym_join] = ACTIONS(6342),
    [anon_sym_let] = ACTIONS(6342),
    [anon_sym_orderby] = ACTIONS(6342),
    [anon_sym_ascending] = ACTIONS(6342),
    [anon_sym_descending] = ACTIONS(6342),
    [anon_sym_group] = ACTIONS(6342),
    [anon_sym_select] = ACTIONS(6342),
    [anon_sym_as] = ACTIONS(6344),
    [anon_sym_is] = ACTIONS(6342),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(6232),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4484] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4484),
    [sym_preproc_endregion] = STATE(4484),
    [sym_preproc_line] = STATE(4484),
    [sym_preproc_pragma] = STATE(4484),
    [sym_preproc_nullable] = STATE(4484),
    [sym_preproc_error] = STATE(4484),
    [sym_preproc_warning] = STATE(4484),
    [sym_preproc_define] = STATE(4484),
    [sym_preproc_undef] = STATE(4484),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(6342),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(6344),
    [anon_sym_GT] = ACTIONS(6344),
    [anon_sym_where] = ACTIONS(6342),
    [anon_sym_QMARK] = ACTIONS(6344),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(6344),
    [anon_sym_DASH] = ACTIONS(6344),
    [anon_sym_STAR] = ACTIONS(6392),
    [anon_sym_SLASH] = ACTIONS(6394),
    [anon_sym_PERCENT] = ACTIONS(6392),
    [anon_sym_CARET] = ACTIONS(6342),
    [anon_sym_PIPE] = ACTIONS(6344),
    [anon_sym_AMP] = ACTIONS(6344),
    [anon_sym_LT_LT] = ACTIONS(6342),
    [anon_sym_GT_GT] = ACTIONS(6344),
    [anon_sym_GT_GT_GT] = ACTIONS(6342),
    [anon_sym_EQ_EQ] = ACTIONS(6342),
    [anon_sym_BANG_EQ] = ACTIONS(6342),
    [anon_sym_GT_EQ] = ACTIONS(6342),
    [anon_sym_LT_EQ] = ACTIONS(6342),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(6216),
    [anon_sym_DOT_DOT] = ACTIONS(6404),
    [anon_sym_and] = ACTIONS(6342),
    [anon_sym_or] = ACTIONS(6344),
    [anon_sym_AMP_AMP] = ACTIONS(6342),
    [anon_sym_PIPE_PIPE] = ACTIONS(6342),
    [anon_sym_QMARK_QMARK] = ACTIONS(6342),
    [anon_sym_from] = ACTIONS(6342),
    [anon_sym_join] = ACTIONS(6342),
    [anon_sym_let] = ACTIONS(6342),
    [anon_sym_orderby] = ACTIONS(6342),
    [anon_sym_ascending] = ACTIONS(6342),
    [anon_sym_descending] = ACTIONS(6342),
    [anon_sym_group] = ACTIONS(6342),
    [anon_sym_select] = ACTIONS(6342),
    [anon_sym_as] = ACTIONS(6344),
    [anon_sym_is] = ACTIONS(6342),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(6232),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4485] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4485),
    [sym_preproc_endregion] = STATE(4485),
    [sym_preproc_line] = STATE(4485),
    [sym_preproc_pragma] = STATE(4485),
    [sym_preproc_nullable] = STATE(4485),
    [sym_preproc_error] = STATE(4485),
    [sym_preproc_warning] = STATE(4485),
    [sym_preproc_define] = STATE(4485),
    [sym_preproc_undef] = STATE(4485),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(6342),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(6344),
    [anon_sym_GT] = ACTIONS(6344),
    [anon_sym_where] = ACTIONS(6342),
    [anon_sym_QMARK] = ACTIONS(6344),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(6344),
    [anon_sym_DASH] = ACTIONS(6344),
    [anon_sym_STAR] = ACTIONS(6342),
    [anon_sym_SLASH] = ACTIONS(6344),
    [anon_sym_PERCENT] = ACTIONS(6342),
    [anon_sym_CARET] = ACTIONS(6342),
    [anon_sym_PIPE] = ACTIONS(6344),
    [anon_sym_AMP] = ACTIONS(6344),
    [anon_sym_LT_LT] = ACTIONS(6342),
    [anon_sym_GT_GT] = ACTIONS(6344),
    [anon_sym_GT_GT_GT] = ACTIONS(6342),
    [anon_sym_EQ_EQ] = ACTIONS(6342),
    [anon_sym_BANG_EQ] = ACTIONS(6342),
    [anon_sym_GT_EQ] = ACTIONS(6342),
    [anon_sym_LT_EQ] = ACTIONS(6342),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(6216),
    [anon_sym_DOT_DOT] = ACTIONS(6404),
    [anon_sym_and] = ACTIONS(6342),
    [anon_sym_or] = ACTIONS(6344),
    [anon_sym_AMP_AMP] = ACTIONS(6342),
    [anon_sym_PIPE_PIPE] = ACTIONS(6342),
    [anon_sym_QMARK_QMARK] = ACTIONS(6342),
    [anon_sym_from] = ACTIONS(6342),
    [anon_sym_join] = ACTIONS(6342),
    [anon_sym_let] = ACTIONS(6342),
    [anon_sym_orderby] = ACTIONS(6342),
    [anon_sym_ascending] = ACTIONS(6342),
    [anon_sym_descending] = ACTIONS(6342),
    [anon_sym_group] = ACTIONS(6342),
    [anon_sym_select] = ACTIONS(6342),
    [anon_sym_as] = ACTIONS(6344),
    [anon_sym_is] = ACTIONS(6342),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(6232),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4486] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4486),
    [sym_preproc_endregion] = STATE(4486),
    [sym_preproc_line] = STATE(4486),
    [sym_preproc_pragma] = STATE(4486),
    [sym_preproc_nullable] = STATE(4486),
    [sym_preproc_error] = STATE(4486),
    [sym_preproc_warning] = STATE(4486),
    [sym_preproc_define] = STATE(4486),
    [sym_preproc_undef] = STATE(4486),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(6342),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(6344),
    [anon_sym_GT] = ACTIONS(6344),
    [anon_sym_where] = ACTIONS(6342),
    [anon_sym_QMARK] = ACTIONS(6344),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(6390),
    [anon_sym_DASH] = ACTIONS(6390),
    [anon_sym_STAR] = ACTIONS(6392),
    [anon_sym_SLASH] = ACTIONS(6394),
    [anon_sym_PERCENT] = ACTIONS(6392),
    [anon_sym_CARET] = ACTIONS(6342),
    [anon_sym_PIPE] = ACTIONS(6344),
    [anon_sym_AMP] = ACTIONS(6344),
    [anon_sym_LT_LT] = ACTIONS(6342),
    [anon_sym_GT_GT] = ACTIONS(6344),
    [anon_sym_GT_GT_GT] = ACTIONS(6342),
    [anon_sym_EQ_EQ] = ACTIONS(6342),
    [anon_sym_BANG_EQ] = ACTIONS(6342),
    [anon_sym_GT_EQ] = ACTIONS(6342),
    [anon_sym_LT_EQ] = ACTIONS(6342),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(6216),
    [anon_sym_DOT_DOT] = ACTIONS(6404),
    [anon_sym_and] = ACTIONS(6342),
    [anon_sym_or] = ACTIONS(6344),
    [anon_sym_AMP_AMP] = ACTIONS(6342),
    [anon_sym_PIPE_PIPE] = ACTIONS(6342),
    [anon_sym_QMARK_QMARK] = ACTIONS(6342),
    [anon_sym_from] = ACTIONS(6342),
    [anon_sym_join] = ACTIONS(6342),
    [anon_sym_let] = ACTIONS(6342),
    [anon_sym_orderby] = ACTIONS(6342),
    [anon_sym_ascending] = ACTIONS(6342),
    [anon_sym_descending] = ACTIONS(6342),
    [anon_sym_group] = ACTIONS(6342),
    [anon_sym_select] = ACTIONS(6342),
    [anon_sym_as] = ACTIONS(6344),
    [anon_sym_is] = ACTIONS(6342),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(6232),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4487] = {
    [sym_preproc_region] = STATE(4487),
    [sym_preproc_endregion] = STATE(4487),
    [sym_preproc_line] = STATE(4487),
    [sym_preproc_pragma] = STATE(4487),
    [sym_preproc_nullable] = STATE(4487),
    [sym_preproc_error] = STATE(4487),
    [sym_preproc_warning] = STATE(4487),
    [sym_preproc_define] = STATE(4487),
    [sym_preproc_undef] = STATE(4487),
    [anon_sym_EQ] = ACTIONS(6495),
    [anon_sym_LBRACK] = ACTIONS(5286),
    [anon_sym_LPAREN] = ACTIONS(5286),
    [anon_sym_LT] = ACTIONS(5288),
    [anon_sym_GT] = ACTIONS(5288),
    [anon_sym_QMARK] = ACTIONS(5288),
    [anon_sym_BANG] = ACTIONS(5288),
    [anon_sym_PLUS_PLUS] = ACTIONS(5286),
    [anon_sym_DASH_DASH] = ACTIONS(5286),
    [anon_sym_PLUS] = ACTIONS(5288),
    [anon_sym_DASH] = ACTIONS(5288),
    [anon_sym_STAR] = ACTIONS(5288),
    [anon_sym_SLASH] = ACTIONS(5288),
    [anon_sym_PERCENT] = ACTIONS(5288),
    [anon_sym_CARET] = ACTIONS(5288),
    [anon_sym_PIPE] = ACTIONS(5288),
    [anon_sym_AMP] = ACTIONS(5288),
    [anon_sym_LT_LT] = ACTIONS(5288),
    [anon_sym_GT_GT] = ACTIONS(5288),
    [anon_sym_GT_GT_GT] = ACTIONS(5288),
    [anon_sym_EQ_EQ] = ACTIONS(5286),
    [anon_sym_BANG_EQ] = ACTIONS(5286),
    [anon_sym_GT_EQ] = ACTIONS(5286),
    [anon_sym_LT_EQ] = ACTIONS(5286),
    [anon_sym_DOT] = ACTIONS(5288),
    [anon_sym_EQ_GT] = ACTIONS(5286),
    [anon_sym_switch] = ACTIONS(5286),
    [anon_sym_DOT_DOT] = ACTIONS(5286),
    [anon_sym_PLUS_EQ] = ACTIONS(6497),
    [anon_sym_DASH_EQ] = ACTIONS(6497),
    [anon_sym_STAR_EQ] = ACTIONS(6497),
    [anon_sym_SLASH_EQ] = ACTIONS(6497),
    [anon_sym_PERCENT_EQ] = ACTIONS(6497),
    [anon_sym_AMP_EQ] = ACTIONS(6497),
    [anon_sym_CARET_EQ] = ACTIONS(6497),
    [anon_sym_PIPE_EQ] = ACTIONS(6497),
    [anon_sym_LT_LT_EQ] = ACTIONS(6497),
    [anon_sym_GT_GT_EQ] = ACTIONS(6497),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(6497),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(6497),
    [anon_sym_AMP_AMP] = ACTIONS(5286),
    [anon_sym_PIPE_PIPE] = ACTIONS(5286),
    [anon_sym_QMARK_QMARK] = ACTIONS(5288),
    [anon_sym_as] = ACTIONS(5286),
    [anon_sym_is] = ACTIONS(5286),
    [anon_sym_DASH_GT] = ACTIONS(5286),
    [anon_sym_with] = ACTIONS(5286),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4488] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4488),
    [sym_preproc_endregion] = STATE(4488),
    [sym_preproc_line] = STATE(4488),
    [sym_preproc_pragma] = STATE(4488),
    [sym_preproc_nullable] = STATE(4488),
    [sym_preproc_error] = STATE(4488),
    [sym_preproc_warning] = STATE(4488),
    [sym_preproc_define] = STATE(4488),
    [sym_preproc_undef] = STATE(4488),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(6332),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(6388),
    [anon_sym_GT] = ACTIONS(6388),
    [anon_sym_where] = ACTIONS(6332),
    [anon_sym_QMARK] = ACTIONS(6450),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(6390),
    [anon_sym_DASH] = ACTIONS(6390),
    [anon_sym_STAR] = ACTIONS(6392),
    [anon_sym_SLASH] = ACTIONS(6394),
    [anon_sym_PERCENT] = ACTIONS(6392),
    [anon_sym_CARET] = ACTIONS(6452),
    [anon_sym_PIPE] = ACTIONS(6454),
    [anon_sym_AMP] = ACTIONS(6456),
    [anon_sym_LT_LT] = ACTIONS(6396),
    [anon_sym_GT_GT] = ACTIONS(6398),
    [anon_sym_GT_GT_GT] = ACTIONS(6396),
    [anon_sym_EQ_EQ] = ACTIONS(6400),
    [anon_sym_BANG_EQ] = ACTIONS(6400),
    [anon_sym_GT_EQ] = ACTIONS(6402),
    [anon_sym_LT_EQ] = ACTIONS(6402),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(6216),
    [anon_sym_DOT_DOT] = ACTIONS(6404),
    [anon_sym_and] = ACTIONS(6332),
    [anon_sym_or] = ACTIONS(6334),
    [anon_sym_AMP_AMP] = ACTIONS(6458),
    [anon_sym_PIPE_PIPE] = ACTIONS(6460),
    [anon_sym_QMARK_QMARK] = ACTIONS(6462),
    [anon_sym_from] = ACTIONS(6332),
    [anon_sym_join] = ACTIONS(6332),
    [anon_sym_let] = ACTIONS(6332),
    [anon_sym_orderby] = ACTIONS(6332),
    [anon_sym_ascending] = ACTIONS(6332),
    [anon_sym_descending] = ACTIONS(6332),
    [anon_sym_group] = ACTIONS(6332),
    [anon_sym_select] = ACTIONS(6332),
    [anon_sym_as] = ACTIONS(6406),
    [anon_sym_is] = ACTIONS(6408),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(6232),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4489] = {
    [sym_preproc_region] = STATE(4489),
    [sym_preproc_endregion] = STATE(4489),
    [sym_preproc_line] = STATE(4489),
    [sym_preproc_pragma] = STATE(4489),
    [sym_preproc_nullable] = STATE(4489),
    [sym_preproc_error] = STATE(4489),
    [sym_preproc_warning] = STATE(4489),
    [sym_preproc_define] = STATE(4489),
    [sym_preproc_undef] = STATE(4489),
    [anon_sym_EQ] = ACTIONS(6499),
    [anon_sym_LBRACK] = ACTIONS(5286),
    [anon_sym_LPAREN] = ACTIONS(5286),
    [anon_sym_LT] = ACTIONS(5288),
    [anon_sym_GT] = ACTIONS(5288),
    [anon_sym_QMARK] = ACTIONS(5288),
    [anon_sym_BANG] = ACTIONS(5288),
    [anon_sym_PLUS_PLUS] = ACTIONS(5286),
    [anon_sym_DASH_DASH] = ACTIONS(5286),
    [anon_sym_PLUS] = ACTIONS(5288),
    [anon_sym_DASH] = ACTIONS(5288),
    [anon_sym_STAR] = ACTIONS(5288),
    [anon_sym_SLASH] = ACTIONS(5288),
    [anon_sym_PERCENT] = ACTIONS(5288),
    [anon_sym_CARET] = ACTIONS(5288),
    [anon_sym_PIPE] = ACTIONS(5288),
    [anon_sym_AMP] = ACTIONS(5288),
    [anon_sym_LT_LT] = ACTIONS(5288),
    [anon_sym_GT_GT] = ACTIONS(5288),
    [anon_sym_GT_GT_GT] = ACTIONS(5288),
    [anon_sym_EQ_EQ] = ACTIONS(5286),
    [anon_sym_BANG_EQ] = ACTIONS(5286),
    [anon_sym_GT_EQ] = ACTIONS(5286),
    [anon_sym_LT_EQ] = ACTIONS(5286),
    [anon_sym_DOT] = ACTIONS(5288),
    [anon_sym_switch] = ACTIONS(5286),
    [anon_sym_DOT_DOT] = ACTIONS(5286),
    [anon_sym_PLUS_EQ] = ACTIONS(6501),
    [anon_sym_DASH_EQ] = ACTIONS(6501),
    [anon_sym_STAR_EQ] = ACTIONS(6501),
    [anon_sym_SLASH_EQ] = ACTIONS(6501),
    [anon_sym_PERCENT_EQ] = ACTIONS(6501),
    [anon_sym_AMP_EQ] = ACTIONS(6501),
    [anon_sym_CARET_EQ] = ACTIONS(6501),
    [anon_sym_PIPE_EQ] = ACTIONS(6501),
    [anon_sym_LT_LT_EQ] = ACTIONS(6501),
    [anon_sym_GT_GT_EQ] = ACTIONS(6501),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(6501),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(6501),
    [anon_sym_AMP_AMP] = ACTIONS(5286),
    [anon_sym_PIPE_PIPE] = ACTIONS(5286),
    [anon_sym_QMARK_QMARK] = ACTIONS(5288),
    [anon_sym_by] = ACTIONS(5286),
    [anon_sym_as] = ACTIONS(5286),
    [anon_sym_is] = ACTIONS(5286),
    [anon_sym_DASH_GT] = ACTIONS(5286),
    [anon_sym_with] = ACTIONS(5286),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4490] = {
    [sym_preproc_region] = STATE(4490),
    [sym_preproc_endregion] = STATE(4490),
    [sym_preproc_line] = STATE(4490),
    [sym_preproc_pragma] = STATE(4490),
    [sym_preproc_nullable] = STATE(4490),
    [sym_preproc_error] = STATE(4490),
    [sym_preproc_warning] = STATE(4490),
    [sym_preproc_define] = STATE(4490),
    [sym_preproc_undef] = STATE(4490),
    [anon_sym_LBRACK] = ACTIONS(5388),
    [anon_sym_COMMA] = ACTIONS(5388),
    [anon_sym_LPAREN] = ACTIONS(5388),
    [anon_sym_LT] = ACTIONS(5390),
    [anon_sym_GT] = ACTIONS(5390),
    [anon_sym_where] = ACTIONS(5388),
    [anon_sym_QMARK] = ACTIONS(5390),
    [anon_sym_BANG] = ACTIONS(5390),
    [anon_sym_PLUS_PLUS] = ACTIONS(5388),
    [anon_sym_DASH_DASH] = ACTIONS(5388),
    [anon_sym_PLUS] = ACTIONS(5390),
    [anon_sym_DASH] = ACTIONS(5390),
    [anon_sym_STAR] = ACTIONS(5388),
    [anon_sym_SLASH] = ACTIONS(5390),
    [anon_sym_PERCENT] = ACTIONS(5388),
    [anon_sym_CARET] = ACTIONS(5388),
    [anon_sym_PIPE] = ACTIONS(5390),
    [anon_sym_AMP] = ACTIONS(5390),
    [anon_sym_LT_LT] = ACTIONS(5388),
    [anon_sym_GT_GT] = ACTIONS(5390),
    [anon_sym_GT_GT_GT] = ACTIONS(5388),
    [anon_sym_EQ_EQ] = ACTIONS(5388),
    [anon_sym_BANG_EQ] = ACTIONS(5388),
    [anon_sym_GT_EQ] = ACTIONS(5388),
    [anon_sym_LT_EQ] = ACTIONS(5388),
    [anon_sym_DOT] = ACTIONS(5390),
    [anon_sym_switch] = ACTIONS(5388),
    [anon_sym_DOT_DOT] = ACTIONS(5388),
    [anon_sym_and] = ACTIONS(5388),
    [anon_sym_or] = ACTIONS(5390),
    [anon_sym_AMP_AMP] = ACTIONS(5388),
    [anon_sym_PIPE_PIPE] = ACTIONS(5388),
    [anon_sym_QMARK_QMARK] = ACTIONS(5388),
    [anon_sym_from] = ACTIONS(5388),
    [anon_sym_into] = ACTIONS(5388),
    [anon_sym_join] = ACTIONS(5388),
    [anon_sym_let] = ACTIONS(5388),
    [anon_sym_orderby] = ACTIONS(5388),
    [anon_sym_ascending] = ACTIONS(5388),
    [anon_sym_descending] = ACTIONS(5388),
    [anon_sym_group] = ACTIONS(5388),
    [anon_sym_select] = ACTIONS(5388),
    [anon_sym_as] = ACTIONS(5390),
    [anon_sym_is] = ACTIONS(5388),
    [anon_sym_DASH_GT] = ACTIONS(5388),
    [anon_sym_with] = ACTIONS(5388),
    [aux_sym_raw_string_literal_token1] = ACTIONS(6503),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4491] = {
    [sym_preproc_region] = STATE(4491),
    [sym_preproc_endregion] = STATE(4491),
    [sym_preproc_line] = STATE(4491),
    [sym_preproc_pragma] = STATE(4491),
    [sym_preproc_nullable] = STATE(4491),
    [sym_preproc_error] = STATE(4491),
    [sym_preproc_warning] = STATE(4491),
    [sym_preproc_define] = STATE(4491),
    [sym_preproc_undef] = STATE(4491),
    [anon_sym_LBRACK] = ACTIONS(5363),
    [anon_sym_COMMA] = ACTIONS(5363),
    [anon_sym_LPAREN] = ACTIONS(5363),
    [anon_sym_LT] = ACTIONS(5365),
    [anon_sym_GT] = ACTIONS(5365),
    [anon_sym_where] = ACTIONS(5363),
    [anon_sym_QMARK] = ACTIONS(5365),
    [anon_sym_BANG] = ACTIONS(5365),
    [anon_sym_PLUS_PLUS] = ACTIONS(5363),
    [anon_sym_DASH_DASH] = ACTIONS(5363),
    [anon_sym_PLUS] = ACTIONS(5365),
    [anon_sym_DASH] = ACTIONS(5365),
    [anon_sym_STAR] = ACTIONS(5363),
    [anon_sym_SLASH] = ACTIONS(5365),
    [anon_sym_PERCENT] = ACTIONS(5363),
    [anon_sym_CARET] = ACTIONS(5363),
    [anon_sym_PIPE] = ACTIONS(5365),
    [anon_sym_AMP] = ACTIONS(5365),
    [anon_sym_LT_LT] = ACTIONS(5363),
    [anon_sym_GT_GT] = ACTIONS(5365),
    [anon_sym_GT_GT_GT] = ACTIONS(5363),
    [anon_sym_EQ_EQ] = ACTIONS(5363),
    [anon_sym_BANG_EQ] = ACTIONS(5363),
    [anon_sym_GT_EQ] = ACTIONS(5363),
    [anon_sym_LT_EQ] = ACTIONS(5363),
    [anon_sym_DOT] = ACTIONS(5365),
    [anon_sym_switch] = ACTIONS(5363),
    [anon_sym_DOT_DOT] = ACTIONS(5363),
    [anon_sym_and] = ACTIONS(5363),
    [anon_sym_or] = ACTIONS(5365),
    [anon_sym_AMP_AMP] = ACTIONS(5363),
    [anon_sym_PIPE_PIPE] = ACTIONS(5363),
    [anon_sym_QMARK_QMARK] = ACTIONS(5363),
    [anon_sym_from] = ACTIONS(5363),
    [anon_sym_into] = ACTIONS(5363),
    [anon_sym_join] = ACTIONS(5363),
    [anon_sym_let] = ACTIONS(5363),
    [anon_sym_orderby] = ACTIONS(5363),
    [anon_sym_ascending] = ACTIONS(5363),
    [anon_sym_descending] = ACTIONS(5363),
    [anon_sym_group] = ACTIONS(5363),
    [anon_sym_select] = ACTIONS(5363),
    [anon_sym_as] = ACTIONS(5365),
    [anon_sym_is] = ACTIONS(5363),
    [anon_sym_DASH_GT] = ACTIONS(5363),
    [anon_sym_with] = ACTIONS(5363),
    [sym_string_literal_encoding] = ACTIONS(6505),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4492] = {
    [sym_argument_list] = STATE(4044),
    [sym_bracketed_argument_list] = STATE(3189),
    [sym_preproc_region] = STATE(4492),
    [sym_preproc_endregion] = STATE(4492),
    [sym_preproc_line] = STATE(4492),
    [sym_preproc_pragma] = STATE(4492),
    [sym_preproc_nullable] = STATE(4492),
    [sym_preproc_error] = STATE(4492),
    [sym_preproc_warning] = STATE(4492),
    [sym_preproc_define] = STATE(4492),
    [sym_preproc_undef] = STATE(4492),
    [anon_sym_SEMI] = ACTIONS(5424),
    [anon_sym_LBRACK] = ACTIONS(5778),
    [anon_sym_COMMA] = ACTIONS(5424),
    [anon_sym_RBRACK] = ACTIONS(5424),
    [anon_sym_LPAREN] = ACTIONS(5759),
    [anon_sym_RPAREN] = ACTIONS(5424),
    [anon_sym_RBRACE] = ACTIONS(5424),
    [anon_sym_LT] = ACTIONS(6410),
    [anon_sym_GT] = ACTIONS(6410),
    [anon_sym_in] = ACTIONS(5426),
    [anon_sym_QMARK] = ACTIONS(6412),
    [anon_sym_BANG] = ACTIONS(5780),
    [anon_sym_PLUS_PLUS] = ACTIONS(5782),
    [anon_sym_DASH_DASH] = ACTIONS(5782),
    [anon_sym_PLUS] = ACTIONS(6414),
    [anon_sym_DASH] = ACTIONS(6414),
    [anon_sym_STAR] = ACTIONS(6416),
    [anon_sym_SLASH] = ACTIONS(6418),
    [anon_sym_PERCENT] = ACTIONS(6416),
    [anon_sym_CARET] = ACTIONS(6420),
    [anon_sym_PIPE] = ACTIONS(6422),
    [anon_sym_AMP] = ACTIONS(6424),
    [anon_sym_LT_LT] = ACTIONS(6426),
    [anon_sym_GT_GT] = ACTIONS(6428),
    [anon_sym_GT_GT_GT] = ACTIONS(6426),
    [anon_sym_EQ_EQ] = ACTIONS(6430),
    [anon_sym_BANG_EQ] = ACTIONS(6430),
    [anon_sym_GT_EQ] = ACTIONS(6432),
    [anon_sym_LT_EQ] = ACTIONS(6432),
    [anon_sym_DOT] = ACTIONS(4634),
    [anon_sym_switch] = ACTIONS(6434),
    [anon_sym_DOT_DOT] = ACTIONS(6436),
    [anon_sym_and] = ACTIONS(5424),
    [anon_sym_or] = ACTIONS(5424),
    [anon_sym_AMP_AMP] = ACTIONS(6438),
    [anon_sym_PIPE_PIPE] = ACTIONS(6440),
    [anon_sym_QMARK_QMARK] = ACTIONS(6442),
    [anon_sym_into] = ACTIONS(5424),
    [anon_sym_as] = ACTIONS(6444),
    [anon_sym_is] = ACTIONS(6446),
    [anon_sym_DASH_GT] = ACTIONS(4636),
    [anon_sym_with] = ACTIONS(6448),
    [aux_sym_preproc_if_token3] = ACTIONS(5424),
    [aux_sym_preproc_else_token1] = ACTIONS(5424),
    [aux_sym_preproc_elif_token1] = ACTIONS(5424),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4493] = {
    [sym_preproc_region] = STATE(4493),
    [sym_preproc_endregion] = STATE(4493),
    [sym_preproc_line] = STATE(4493),
    [sym_preproc_pragma] = STATE(4493),
    [sym_preproc_nullable] = STATE(4493),
    [sym_preproc_error] = STATE(4493),
    [sym_preproc_warning] = STATE(4493),
    [sym_preproc_define] = STATE(4493),
    [sym_preproc_undef] = STATE(4493),
    [sym__identifier_token] = ACTIONS(5719),
    [anon_sym_extern] = ACTIONS(5719),
    [anon_sym_alias] = ACTIONS(5719),
    [anon_sym_global] = ACTIONS(5719),
    [anon_sym_unsafe] = ACTIONS(5719),
    [anon_sym_static] = ACTIONS(5719),
    [anon_sym_LBRACK] = ACTIONS(5721),
    [anon_sym_LPAREN] = ACTIONS(5721),
    [anon_sym_ref] = ACTIONS(5719),
    [anon_sym_delegate] = ACTIONS(5719),
    [anon_sym_abstract] = ACTIONS(5719),
    [anon_sym_async] = ACTIONS(5719),
    [anon_sym_const] = ACTIONS(5719),
    [anon_sym_file] = ACTIONS(5719),
    [anon_sym_fixed] = ACTIONS(5719),
    [anon_sym_internal] = ACTIONS(5719),
    [anon_sym_new] = ACTIONS(5719),
    [anon_sym_override] = ACTIONS(5719),
    [anon_sym_partial] = ACTIONS(5719),
    [anon_sym_private] = ACTIONS(5719),
    [anon_sym_protected] = ACTIONS(5719),
    [anon_sym_public] = ACTIONS(5719),
    [anon_sym_readonly] = ACTIONS(5719),
    [anon_sym_required] = ACTIONS(5719),
    [anon_sym_sealed] = ACTIONS(5719),
    [anon_sym_virtual] = ACTIONS(5719),
    [anon_sym_volatile] = ACTIONS(5719),
    [anon_sym_where] = ACTIONS(5719),
    [anon_sym_notnull] = ACTIONS(5719),
    [anon_sym_unmanaged] = ACTIONS(5719),
    [anon_sym_scoped] = ACTIONS(5719),
    [anon_sym_var] = ACTIONS(5719),
    [sym_predefined_type] = ACTIONS(5719),
    [anon_sym_yield] = ACTIONS(5719),
    [anon_sym_when] = ACTIONS(5719),
    [anon_sym_from] = ACTIONS(5719),
    [anon_sym_into] = ACTIONS(5719),
    [anon_sym_join] = ACTIONS(5719),
    [anon_sym_on] = ACTIONS(5719),
    [anon_sym_equals] = ACTIONS(5719),
    [anon_sym_let] = ACTIONS(5719),
    [anon_sym_orderby] = ACTIONS(5719),
    [anon_sym_ascending] = ACTIONS(5719),
    [anon_sym_descending] = ACTIONS(5719),
    [anon_sym_group] = ACTIONS(5719),
    [anon_sym_by] = ACTIONS(5719),
    [anon_sym_select] = ACTIONS(5719),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4494] = {
    [sym_argument_list] = STATE(4044),
    [sym_bracketed_argument_list] = STATE(3189),
    [sym_preproc_region] = STATE(4494),
    [sym_preproc_endregion] = STATE(4494),
    [sym_preproc_line] = STATE(4494),
    [sym_preproc_pragma] = STATE(4494),
    [sym_preproc_nullable] = STATE(4494),
    [sym_preproc_error] = STATE(4494),
    [sym_preproc_warning] = STATE(4494),
    [sym_preproc_define] = STATE(4494),
    [sym_preproc_undef] = STATE(4494),
    [anon_sym_SEMI] = ACTIONS(6270),
    [anon_sym_LBRACK] = ACTIONS(5778),
    [anon_sym_COMMA] = ACTIONS(6270),
    [anon_sym_RBRACK] = ACTIONS(6270),
    [anon_sym_LPAREN] = ACTIONS(5759),
    [anon_sym_RPAREN] = ACTIONS(6270),
    [anon_sym_RBRACE] = ACTIONS(6270),
    [anon_sym_LT] = ACTIONS(6410),
    [anon_sym_GT] = ACTIONS(6410),
    [anon_sym_in] = ACTIONS(6272),
    [anon_sym_QMARK] = ACTIONS(6412),
    [anon_sym_BANG] = ACTIONS(5780),
    [anon_sym_PLUS_PLUS] = ACTIONS(5782),
    [anon_sym_DASH_DASH] = ACTIONS(5782),
    [anon_sym_PLUS] = ACTIONS(6414),
    [anon_sym_DASH] = ACTIONS(6414),
    [anon_sym_STAR] = ACTIONS(6416),
    [anon_sym_SLASH] = ACTIONS(6418),
    [anon_sym_PERCENT] = ACTIONS(6416),
    [anon_sym_CARET] = ACTIONS(6420),
    [anon_sym_PIPE] = ACTIONS(6422),
    [anon_sym_AMP] = ACTIONS(6424),
    [anon_sym_LT_LT] = ACTIONS(6426),
    [anon_sym_GT_GT] = ACTIONS(6428),
    [anon_sym_GT_GT_GT] = ACTIONS(6426),
    [anon_sym_EQ_EQ] = ACTIONS(6430),
    [anon_sym_BANG_EQ] = ACTIONS(6430),
    [anon_sym_GT_EQ] = ACTIONS(6432),
    [anon_sym_LT_EQ] = ACTIONS(6432),
    [anon_sym_DOT] = ACTIONS(4634),
    [anon_sym_switch] = ACTIONS(6434),
    [anon_sym_DOT_DOT] = ACTIONS(6436),
    [anon_sym_and] = ACTIONS(6270),
    [anon_sym_or] = ACTIONS(6270),
    [anon_sym_AMP_AMP] = ACTIONS(6438),
    [anon_sym_PIPE_PIPE] = ACTIONS(6440),
    [anon_sym_QMARK_QMARK] = ACTIONS(6442),
    [anon_sym_into] = ACTIONS(6270),
    [anon_sym_as] = ACTIONS(6444),
    [anon_sym_is] = ACTIONS(6446),
    [anon_sym_DASH_GT] = ACTIONS(4636),
    [anon_sym_with] = ACTIONS(6448),
    [aux_sym_preproc_if_token3] = ACTIONS(6270),
    [aux_sym_preproc_else_token1] = ACTIONS(6270),
    [aux_sym_preproc_elif_token1] = ACTIONS(6270),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4495] = {
    [sym_argument_list] = STATE(4044),
    [sym_bracketed_argument_list] = STATE(3189),
    [sym_preproc_region] = STATE(4495),
    [sym_preproc_endregion] = STATE(4495),
    [sym_preproc_line] = STATE(4495),
    [sym_preproc_pragma] = STATE(4495),
    [sym_preproc_nullable] = STATE(4495),
    [sym_preproc_error] = STATE(4495),
    [sym_preproc_warning] = STATE(4495),
    [sym_preproc_define] = STATE(4495),
    [sym_preproc_undef] = STATE(4495),
    [anon_sym_SEMI] = ACTIONS(6342),
    [anon_sym_LBRACK] = ACTIONS(5778),
    [anon_sym_COMMA] = ACTIONS(6342),
    [anon_sym_RBRACK] = ACTIONS(6342),
    [anon_sym_LPAREN] = ACTIONS(5759),
    [anon_sym_RPAREN] = ACTIONS(6342),
    [anon_sym_RBRACE] = ACTIONS(6342),
    [anon_sym_LT] = ACTIONS(6344),
    [anon_sym_GT] = ACTIONS(6344),
    [anon_sym_in] = ACTIONS(6344),
    [anon_sym_QMARK] = ACTIONS(6344),
    [anon_sym_BANG] = ACTIONS(5780),
    [anon_sym_PLUS_PLUS] = ACTIONS(5782),
    [anon_sym_DASH_DASH] = ACTIONS(5782),
    [anon_sym_PLUS] = ACTIONS(6414),
    [anon_sym_DASH] = ACTIONS(6414),
    [anon_sym_STAR] = ACTIONS(6416),
    [anon_sym_SLASH] = ACTIONS(6418),
    [anon_sym_PERCENT] = ACTIONS(6416),
    [anon_sym_CARET] = ACTIONS(6342),
    [anon_sym_PIPE] = ACTIONS(6344),
    [anon_sym_AMP] = ACTIONS(6344),
    [anon_sym_LT_LT] = ACTIONS(6426),
    [anon_sym_GT_GT] = ACTIONS(6428),
    [anon_sym_GT_GT_GT] = ACTIONS(6426),
    [anon_sym_EQ_EQ] = ACTIONS(6342),
    [anon_sym_BANG_EQ] = ACTIONS(6342),
    [anon_sym_GT_EQ] = ACTIONS(6342),
    [anon_sym_LT_EQ] = ACTIONS(6342),
    [anon_sym_DOT] = ACTIONS(4634),
    [anon_sym_switch] = ACTIONS(6434),
    [anon_sym_DOT_DOT] = ACTIONS(6436),
    [anon_sym_and] = ACTIONS(6342),
    [anon_sym_or] = ACTIONS(6342),
    [anon_sym_AMP_AMP] = ACTIONS(6342),
    [anon_sym_PIPE_PIPE] = ACTIONS(6342),
    [anon_sym_QMARK_QMARK] = ACTIONS(6342),
    [anon_sym_into] = ACTIONS(6342),
    [anon_sym_as] = ACTIONS(6342),
    [anon_sym_is] = ACTIONS(6342),
    [anon_sym_DASH_GT] = ACTIONS(4636),
    [anon_sym_with] = ACTIONS(6448),
    [aux_sym_preproc_if_token3] = ACTIONS(6342),
    [aux_sym_preproc_else_token1] = ACTIONS(6342),
    [aux_sym_preproc_elif_token1] = ACTIONS(6342),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4496] = {
    [sym_preproc_region] = STATE(4496),
    [sym_preproc_endregion] = STATE(4496),
    [sym_preproc_line] = STATE(4496),
    [sym_preproc_pragma] = STATE(4496),
    [sym_preproc_nullable] = STATE(4496),
    [sym_preproc_error] = STATE(4496),
    [sym_preproc_warning] = STATE(4496),
    [sym_preproc_define] = STATE(4496),
    [sym_preproc_undef] = STATE(4496),
    [sym__identifier_token] = ACTIONS(4042),
    [anon_sym_extern] = ACTIONS(4042),
    [anon_sym_alias] = ACTIONS(4042),
    [anon_sym_global] = ACTIONS(4042),
    [anon_sym_unsafe] = ACTIONS(4042),
    [anon_sym_static] = ACTIONS(4042),
    [anon_sym_abstract] = ACTIONS(4042),
    [anon_sym_async] = ACTIONS(4042),
    [anon_sym_const] = ACTIONS(4042),
    [anon_sym_file] = ACTIONS(4042),
    [anon_sym_fixed] = ACTIONS(4042),
    [anon_sym_internal] = ACTIONS(4042),
    [anon_sym_new] = ACTIONS(4042),
    [anon_sym_override] = ACTIONS(4042),
    [anon_sym_partial] = ACTIONS(4042),
    [anon_sym_private] = ACTIONS(4042),
    [anon_sym_protected] = ACTIONS(4042),
    [anon_sym_public] = ACTIONS(4042),
    [anon_sym_readonly] = ACTIONS(4042),
    [anon_sym_required] = ACTIONS(4042),
    [anon_sym_sealed] = ACTIONS(4042),
    [anon_sym_virtual] = ACTIONS(4042),
    [anon_sym_volatile] = ACTIONS(4042),
    [anon_sym_where] = ACTIONS(4042),
    [anon_sym_notnull] = ACTIONS(4042),
    [anon_sym_unmanaged] = ACTIONS(4042),
    [anon_sym_get] = ACTIONS(4042),
    [anon_sym_set] = ACTIONS(4042),
    [anon_sym_add] = ACTIONS(4042),
    [anon_sym_remove] = ACTIONS(4042),
    [anon_sym_init] = ACTIONS(4042),
    [anon_sym_scoped] = ACTIONS(4042),
    [anon_sym_var] = ACTIONS(4042),
    [anon_sym_yield] = ACTIONS(4042),
    [anon_sym_when] = ACTIONS(4042),
    [anon_sym_from] = ACTIONS(4042),
    [anon_sym_into] = ACTIONS(4042),
    [anon_sym_join] = ACTIONS(4042),
    [anon_sym_on] = ACTIONS(4042),
    [anon_sym_equals] = ACTIONS(4042),
    [anon_sym_let] = ACTIONS(4042),
    [anon_sym_orderby] = ACTIONS(4042),
    [anon_sym_ascending] = ACTIONS(4042),
    [anon_sym_descending] = ACTIONS(4042),
    [anon_sym_group] = ACTIONS(4042),
    [anon_sym_by] = ACTIONS(4042),
    [anon_sym_select] = ACTIONS(4042),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4497] = {
    [sym_preproc_region] = STATE(4497),
    [sym_preproc_endregion] = STATE(4497),
    [sym_preproc_line] = STATE(4497),
    [sym_preproc_pragma] = STATE(4497),
    [sym_preproc_nullable] = STATE(4497),
    [sym_preproc_error] = STATE(4497),
    [sym_preproc_warning] = STATE(4497),
    [sym_preproc_define] = STATE(4497),
    [sym_preproc_undef] = STATE(4497),
    [sym__identifier_token] = ACTIONS(5761),
    [anon_sym_extern] = ACTIONS(5761),
    [anon_sym_alias] = ACTIONS(5761),
    [anon_sym_global] = ACTIONS(5761),
    [anon_sym_unsafe] = ACTIONS(5761),
    [anon_sym_static] = ACTIONS(5761),
    [anon_sym_abstract] = ACTIONS(5761),
    [anon_sym_async] = ACTIONS(5761),
    [anon_sym_const] = ACTIONS(5761),
    [anon_sym_file] = ACTIONS(5761),
    [anon_sym_fixed] = ACTIONS(5761),
    [anon_sym_internal] = ACTIONS(5761),
    [anon_sym_new] = ACTIONS(5761),
    [anon_sym_override] = ACTIONS(5761),
    [anon_sym_partial] = ACTIONS(5761),
    [anon_sym_private] = ACTIONS(5761),
    [anon_sym_protected] = ACTIONS(5761),
    [anon_sym_public] = ACTIONS(5761),
    [anon_sym_readonly] = ACTIONS(5761),
    [anon_sym_required] = ACTIONS(5761),
    [anon_sym_sealed] = ACTIONS(5761),
    [anon_sym_virtual] = ACTIONS(5761),
    [anon_sym_volatile] = ACTIONS(5761),
    [anon_sym_where] = ACTIONS(5761),
    [anon_sym_notnull] = ACTIONS(5761),
    [anon_sym_unmanaged] = ACTIONS(5761),
    [anon_sym_get] = ACTIONS(5761),
    [anon_sym_set] = ACTIONS(5761),
    [anon_sym_add] = ACTIONS(5761),
    [anon_sym_remove] = ACTIONS(5761),
    [anon_sym_init] = ACTIONS(5761),
    [anon_sym_scoped] = ACTIONS(5761),
    [anon_sym_var] = ACTIONS(5761),
    [anon_sym_yield] = ACTIONS(5761),
    [anon_sym_when] = ACTIONS(5761),
    [anon_sym_from] = ACTIONS(5761),
    [anon_sym_into] = ACTIONS(5761),
    [anon_sym_join] = ACTIONS(5761),
    [anon_sym_on] = ACTIONS(5761),
    [anon_sym_equals] = ACTIONS(5761),
    [anon_sym_let] = ACTIONS(5761),
    [anon_sym_orderby] = ACTIONS(5761),
    [anon_sym_ascending] = ACTIONS(5761),
    [anon_sym_descending] = ACTIONS(5761),
    [anon_sym_group] = ACTIONS(5761),
    [anon_sym_by] = ACTIONS(5761),
    [anon_sym_select] = ACTIONS(5761),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4498] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4498),
    [sym_preproc_endregion] = STATE(4498),
    [sym_preproc_line] = STATE(4498),
    [sym_preproc_pragma] = STATE(4498),
    [sym_preproc_nullable] = STATE(4498),
    [sym_preproc_error] = STATE(4498),
    [sym_preproc_warning] = STATE(4498),
    [sym_preproc_define] = STATE(4498),
    [sym_preproc_undef] = STATE(4498),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(5424),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(6388),
    [anon_sym_GT] = ACTIONS(6388),
    [anon_sym_where] = ACTIONS(5424),
    [anon_sym_QMARK] = ACTIONS(6450),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(6390),
    [anon_sym_DASH] = ACTIONS(6390),
    [anon_sym_STAR] = ACTIONS(6392),
    [anon_sym_SLASH] = ACTIONS(6394),
    [anon_sym_PERCENT] = ACTIONS(6392),
    [anon_sym_CARET] = ACTIONS(6452),
    [anon_sym_PIPE] = ACTIONS(6454),
    [anon_sym_AMP] = ACTIONS(6456),
    [anon_sym_LT_LT] = ACTIONS(6396),
    [anon_sym_GT_GT] = ACTIONS(6398),
    [anon_sym_GT_GT_GT] = ACTIONS(6396),
    [anon_sym_EQ_EQ] = ACTIONS(6400),
    [anon_sym_BANG_EQ] = ACTIONS(6400),
    [anon_sym_GT_EQ] = ACTIONS(6402),
    [anon_sym_LT_EQ] = ACTIONS(6402),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(6216),
    [anon_sym_DOT_DOT] = ACTIONS(6404),
    [anon_sym_and] = ACTIONS(5424),
    [anon_sym_or] = ACTIONS(5426),
    [anon_sym_AMP_AMP] = ACTIONS(6458),
    [anon_sym_PIPE_PIPE] = ACTIONS(6460),
    [anon_sym_QMARK_QMARK] = ACTIONS(6462),
    [anon_sym_from] = ACTIONS(5424),
    [anon_sym_join] = ACTIONS(5424),
    [anon_sym_let] = ACTIONS(5424),
    [anon_sym_orderby] = ACTIONS(5424),
    [anon_sym_ascending] = ACTIONS(5424),
    [anon_sym_descending] = ACTIONS(5424),
    [anon_sym_group] = ACTIONS(5424),
    [anon_sym_select] = ACTIONS(5424),
    [anon_sym_as] = ACTIONS(6406),
    [anon_sym_is] = ACTIONS(6408),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(6232),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4499] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4499),
    [sym_preproc_endregion] = STATE(4499),
    [sym_preproc_line] = STATE(4499),
    [sym_preproc_pragma] = STATE(4499),
    [sym_preproc_nullable] = STATE(4499),
    [sym_preproc_error] = STATE(4499),
    [sym_preproc_warning] = STATE(4499),
    [sym_preproc_define] = STATE(4499),
    [sym_preproc_undef] = STATE(4499),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(6342),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(6388),
    [anon_sym_GT] = ACTIONS(6388),
    [anon_sym_where] = ACTIONS(6342),
    [anon_sym_QMARK] = ACTIONS(6344),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(6390),
    [anon_sym_DASH] = ACTIONS(6390),
    [anon_sym_STAR] = ACTIONS(6392),
    [anon_sym_SLASH] = ACTIONS(6394),
    [anon_sym_PERCENT] = ACTIONS(6392),
    [anon_sym_CARET] = ACTIONS(6342),
    [anon_sym_PIPE] = ACTIONS(6344),
    [anon_sym_AMP] = ACTIONS(6456),
    [anon_sym_LT_LT] = ACTIONS(6396),
    [anon_sym_GT_GT] = ACTIONS(6398),
    [anon_sym_GT_GT_GT] = ACTIONS(6396),
    [anon_sym_EQ_EQ] = ACTIONS(6400),
    [anon_sym_BANG_EQ] = ACTIONS(6400),
    [anon_sym_GT_EQ] = ACTIONS(6402),
    [anon_sym_LT_EQ] = ACTIONS(6402),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(6216),
    [anon_sym_DOT_DOT] = ACTIONS(6404),
    [anon_sym_and] = ACTIONS(6342),
    [anon_sym_or] = ACTIONS(6344),
    [anon_sym_AMP_AMP] = ACTIONS(6342),
    [anon_sym_PIPE_PIPE] = ACTIONS(6342),
    [anon_sym_QMARK_QMARK] = ACTIONS(6342),
    [anon_sym_from] = ACTIONS(6342),
    [anon_sym_join] = ACTIONS(6342),
    [anon_sym_let] = ACTIONS(6342),
    [anon_sym_orderby] = ACTIONS(6342),
    [anon_sym_ascending] = ACTIONS(6342),
    [anon_sym_descending] = ACTIONS(6342),
    [anon_sym_group] = ACTIONS(6342),
    [anon_sym_select] = ACTIONS(6342),
    [anon_sym_as] = ACTIONS(6406),
    [anon_sym_is] = ACTIONS(6408),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(6232),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4500] = {
    [sym_preproc_region] = STATE(4500),
    [sym_preproc_endregion] = STATE(4500),
    [sym_preproc_line] = STATE(4500),
    [sym_preproc_pragma] = STATE(4500),
    [sym_preproc_nullable] = STATE(4500),
    [sym_preproc_error] = STATE(4500),
    [sym_preproc_warning] = STATE(4500),
    [sym_preproc_define] = STATE(4500),
    [sym_preproc_undef] = STATE(4500),
    [anon_sym_LBRACK] = ACTIONS(4310),
    [anon_sym_COMMA] = ACTIONS(4310),
    [anon_sym_LPAREN] = ACTIONS(4310),
    [anon_sym_LT] = ACTIONS(5873),
    [anon_sym_GT] = ACTIONS(5873),
    [anon_sym_where] = ACTIONS(4310),
    [anon_sym_QMARK] = ACTIONS(5873),
    [anon_sym_BANG] = ACTIONS(5873),
    [anon_sym_PLUS_PLUS] = ACTIONS(4310),
    [anon_sym_DASH_DASH] = ACTIONS(4310),
    [anon_sym_PLUS] = ACTIONS(5873),
    [anon_sym_DASH] = ACTIONS(5873),
    [anon_sym_STAR] = ACTIONS(4310),
    [anon_sym_SLASH] = ACTIONS(5873),
    [anon_sym_PERCENT] = ACTIONS(4310),
    [anon_sym_CARET] = ACTIONS(4310),
    [anon_sym_PIPE] = ACTIONS(5873),
    [anon_sym_AMP] = ACTIONS(5873),
    [anon_sym_LT_LT] = ACTIONS(4310),
    [anon_sym_GT_GT] = ACTIONS(5873),
    [anon_sym_GT_GT_GT] = ACTIONS(4310),
    [anon_sym_EQ_EQ] = ACTIONS(4310),
    [anon_sym_BANG_EQ] = ACTIONS(4310),
    [anon_sym_GT_EQ] = ACTIONS(4310),
    [anon_sym_LT_EQ] = ACTIONS(4310),
    [anon_sym_DOT] = ACTIONS(5873),
    [anon_sym_EQ_GT] = ACTIONS(4145),
    [anon_sym_switch] = ACTIONS(4310),
    [anon_sym_DOT_DOT] = ACTIONS(4310),
    [anon_sym_and] = ACTIONS(4310),
    [anon_sym_or] = ACTIONS(5873),
    [anon_sym_AMP_AMP] = ACTIONS(4310),
    [anon_sym_PIPE_PIPE] = ACTIONS(4310),
    [anon_sym_QMARK_QMARK] = ACTIONS(4310),
    [anon_sym_from] = ACTIONS(4310),
    [anon_sym_into] = ACTIONS(4310),
    [anon_sym_join] = ACTIONS(4310),
    [anon_sym_let] = ACTIONS(4310),
    [anon_sym_orderby] = ACTIONS(4310),
    [anon_sym_ascending] = ACTIONS(4310),
    [anon_sym_descending] = ACTIONS(4310),
    [anon_sym_group] = ACTIONS(4310),
    [anon_sym_select] = ACTIONS(4310),
    [anon_sym_as] = ACTIONS(5873),
    [anon_sym_is] = ACTIONS(4310),
    [anon_sym_DASH_GT] = ACTIONS(4310),
    [anon_sym_with] = ACTIONS(4310),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4501] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4501),
    [sym_preproc_endregion] = STATE(4501),
    [sym_preproc_line] = STATE(4501),
    [sym_preproc_pragma] = STATE(4501),
    [sym_preproc_nullable] = STATE(4501),
    [sym_preproc_error] = STATE(4501),
    [sym_preproc_warning] = STATE(4501),
    [sym_preproc_define] = STATE(4501),
    [sym_preproc_undef] = STATE(4501),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(6342),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(6388),
    [anon_sym_GT] = ACTIONS(6388),
    [anon_sym_where] = ACTIONS(6342),
    [anon_sym_QMARK] = ACTIONS(6344),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(6390),
    [anon_sym_DASH] = ACTIONS(6390),
    [anon_sym_STAR] = ACTIONS(6392),
    [anon_sym_SLASH] = ACTIONS(6394),
    [anon_sym_PERCENT] = ACTIONS(6392),
    [anon_sym_CARET] = ACTIONS(6452),
    [anon_sym_PIPE] = ACTIONS(6344),
    [anon_sym_AMP] = ACTIONS(6456),
    [anon_sym_LT_LT] = ACTIONS(6396),
    [anon_sym_GT_GT] = ACTIONS(6398),
    [anon_sym_GT_GT_GT] = ACTIONS(6396),
    [anon_sym_EQ_EQ] = ACTIONS(6400),
    [anon_sym_BANG_EQ] = ACTIONS(6400),
    [anon_sym_GT_EQ] = ACTIONS(6402),
    [anon_sym_LT_EQ] = ACTIONS(6402),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(6216),
    [anon_sym_DOT_DOT] = ACTIONS(6404),
    [anon_sym_and] = ACTIONS(6342),
    [anon_sym_or] = ACTIONS(6344),
    [anon_sym_AMP_AMP] = ACTIONS(6342),
    [anon_sym_PIPE_PIPE] = ACTIONS(6342),
    [anon_sym_QMARK_QMARK] = ACTIONS(6342),
    [anon_sym_from] = ACTIONS(6342),
    [anon_sym_join] = ACTIONS(6342),
    [anon_sym_let] = ACTIONS(6342),
    [anon_sym_orderby] = ACTIONS(6342),
    [anon_sym_ascending] = ACTIONS(6342),
    [anon_sym_descending] = ACTIONS(6342),
    [anon_sym_group] = ACTIONS(6342),
    [anon_sym_select] = ACTIONS(6342),
    [anon_sym_as] = ACTIONS(6406),
    [anon_sym_is] = ACTIONS(6408),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(6232),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4502] = {
    [sym_argument_list] = STATE(4044),
    [sym_bracketed_argument_list] = STATE(3189),
    [sym_preproc_region] = STATE(4502),
    [sym_preproc_endregion] = STATE(4502),
    [sym_preproc_line] = STATE(4502),
    [sym_preproc_pragma] = STATE(4502),
    [sym_preproc_nullable] = STATE(4502),
    [sym_preproc_error] = STATE(4502),
    [sym_preproc_warning] = STATE(4502),
    [sym_preproc_define] = STATE(4502),
    [sym_preproc_undef] = STATE(4502),
    [anon_sym_SEMI] = ACTIONS(6328),
    [anon_sym_LBRACK] = ACTIONS(5778),
    [anon_sym_COMMA] = ACTIONS(6328),
    [anon_sym_RBRACK] = ACTIONS(6328),
    [anon_sym_LPAREN] = ACTIONS(5759),
    [anon_sym_RPAREN] = ACTIONS(6328),
    [anon_sym_RBRACE] = ACTIONS(6328),
    [anon_sym_LT] = ACTIONS(6330),
    [anon_sym_GT] = ACTIONS(6330),
    [anon_sym_in] = ACTIONS(6330),
    [anon_sym_QMARK] = ACTIONS(6330),
    [anon_sym_BANG] = ACTIONS(5780),
    [anon_sym_PLUS_PLUS] = ACTIONS(5782),
    [anon_sym_DASH_DASH] = ACTIONS(5782),
    [anon_sym_PLUS] = ACTIONS(6330),
    [anon_sym_DASH] = ACTIONS(6330),
    [anon_sym_STAR] = ACTIONS(6328),
    [anon_sym_SLASH] = ACTIONS(6330),
    [anon_sym_PERCENT] = ACTIONS(6328),
    [anon_sym_CARET] = ACTIONS(6328),
    [anon_sym_PIPE] = ACTIONS(6330),
    [anon_sym_AMP] = ACTIONS(6330),
    [anon_sym_LT_LT] = ACTIONS(6328),
    [anon_sym_GT_GT] = ACTIONS(6330),
    [anon_sym_GT_GT_GT] = ACTIONS(6328),
    [anon_sym_EQ_EQ] = ACTIONS(6328),
    [anon_sym_BANG_EQ] = ACTIONS(6328),
    [anon_sym_GT_EQ] = ACTIONS(6328),
    [anon_sym_LT_EQ] = ACTIONS(6328),
    [anon_sym_DOT] = ACTIONS(4634),
    [anon_sym_switch] = ACTIONS(6328),
    [anon_sym_DOT_DOT] = ACTIONS(6436),
    [anon_sym_and] = ACTIONS(6328),
    [anon_sym_or] = ACTIONS(6328),
    [anon_sym_AMP_AMP] = ACTIONS(6328),
    [anon_sym_PIPE_PIPE] = ACTIONS(6328),
    [anon_sym_QMARK_QMARK] = ACTIONS(6328),
    [anon_sym_into] = ACTIONS(6328),
    [anon_sym_as] = ACTIONS(6328),
    [anon_sym_is] = ACTIONS(6328),
    [anon_sym_DASH_GT] = ACTIONS(4636),
    [anon_sym_with] = ACTIONS(6328),
    [aux_sym_preproc_if_token3] = ACTIONS(6328),
    [aux_sym_preproc_else_token1] = ACTIONS(6328),
    [aux_sym_preproc_elif_token1] = ACTIONS(6328),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4503] = {
    [sym_preproc_region] = STATE(4503),
    [sym_preproc_endregion] = STATE(4503),
    [sym_preproc_line] = STATE(4503),
    [sym_preproc_pragma] = STATE(4503),
    [sym_preproc_nullable] = STATE(4503),
    [sym_preproc_error] = STATE(4503),
    [sym_preproc_warning] = STATE(4503),
    [sym_preproc_define] = STATE(4503),
    [sym_preproc_undef] = STATE(4503),
    [sym__identifier_token] = ACTIONS(5697),
    [anon_sym_extern] = ACTIONS(5697),
    [anon_sym_alias] = ACTIONS(5697),
    [anon_sym_global] = ACTIONS(5697),
    [anon_sym_unsafe] = ACTIONS(5697),
    [anon_sym_static] = ACTIONS(5697),
    [anon_sym_LBRACK] = ACTIONS(5699),
    [anon_sym_LPAREN] = ACTIONS(5699),
    [anon_sym_ref] = ACTIONS(5697),
    [anon_sym_delegate] = ACTIONS(5697),
    [anon_sym_abstract] = ACTIONS(5697),
    [anon_sym_async] = ACTIONS(5697),
    [anon_sym_const] = ACTIONS(5697),
    [anon_sym_file] = ACTIONS(5697),
    [anon_sym_fixed] = ACTIONS(5697),
    [anon_sym_internal] = ACTIONS(5697),
    [anon_sym_new] = ACTIONS(5697),
    [anon_sym_override] = ACTIONS(5697),
    [anon_sym_partial] = ACTIONS(5697),
    [anon_sym_private] = ACTIONS(5697),
    [anon_sym_protected] = ACTIONS(5697),
    [anon_sym_public] = ACTIONS(5697),
    [anon_sym_readonly] = ACTIONS(5697),
    [anon_sym_required] = ACTIONS(5697),
    [anon_sym_sealed] = ACTIONS(5697),
    [anon_sym_virtual] = ACTIONS(5697),
    [anon_sym_volatile] = ACTIONS(5697),
    [anon_sym_where] = ACTIONS(5697),
    [anon_sym_notnull] = ACTIONS(5697),
    [anon_sym_unmanaged] = ACTIONS(5697),
    [anon_sym_scoped] = ACTIONS(5697),
    [anon_sym_var] = ACTIONS(5697),
    [sym_predefined_type] = ACTIONS(5697),
    [anon_sym_yield] = ACTIONS(5697),
    [anon_sym_when] = ACTIONS(5697),
    [anon_sym_from] = ACTIONS(5697),
    [anon_sym_into] = ACTIONS(5697),
    [anon_sym_join] = ACTIONS(5697),
    [anon_sym_on] = ACTIONS(5697),
    [anon_sym_equals] = ACTIONS(5697),
    [anon_sym_let] = ACTIONS(5697),
    [anon_sym_orderby] = ACTIONS(5697),
    [anon_sym_ascending] = ACTIONS(5697),
    [anon_sym_descending] = ACTIONS(5697),
    [anon_sym_group] = ACTIONS(5697),
    [anon_sym_by] = ACTIONS(5697),
    [anon_sym_select] = ACTIONS(5697),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4504] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4504),
    [sym_preproc_endregion] = STATE(4504),
    [sym_preproc_line] = STATE(4504),
    [sym_preproc_pragma] = STATE(4504),
    [sym_preproc_nullable] = STATE(4504),
    [sym_preproc_error] = STATE(4504),
    [sym_preproc_warning] = STATE(4504),
    [sym_preproc_define] = STATE(4504),
    [sym_preproc_undef] = STATE(4504),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(6324),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(6388),
    [anon_sym_GT] = ACTIONS(6388),
    [anon_sym_where] = ACTIONS(6324),
    [anon_sym_QMARK] = ACTIONS(6450),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(6390),
    [anon_sym_DASH] = ACTIONS(6390),
    [anon_sym_STAR] = ACTIONS(6392),
    [anon_sym_SLASH] = ACTIONS(6394),
    [anon_sym_PERCENT] = ACTIONS(6392),
    [anon_sym_CARET] = ACTIONS(6452),
    [anon_sym_PIPE] = ACTIONS(6454),
    [anon_sym_AMP] = ACTIONS(6456),
    [anon_sym_LT_LT] = ACTIONS(6396),
    [anon_sym_GT_GT] = ACTIONS(6398),
    [anon_sym_GT_GT_GT] = ACTIONS(6396),
    [anon_sym_EQ_EQ] = ACTIONS(6400),
    [anon_sym_BANG_EQ] = ACTIONS(6400),
    [anon_sym_GT_EQ] = ACTIONS(6402),
    [anon_sym_LT_EQ] = ACTIONS(6402),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(6216),
    [anon_sym_DOT_DOT] = ACTIONS(6404),
    [anon_sym_and] = ACTIONS(6324),
    [anon_sym_or] = ACTIONS(6326),
    [anon_sym_AMP_AMP] = ACTIONS(6458),
    [anon_sym_PIPE_PIPE] = ACTIONS(6460),
    [anon_sym_QMARK_QMARK] = ACTIONS(6462),
    [anon_sym_from] = ACTIONS(6324),
    [anon_sym_join] = ACTIONS(6324),
    [anon_sym_let] = ACTIONS(6324),
    [anon_sym_orderby] = ACTIONS(6324),
    [anon_sym_ascending] = ACTIONS(6324),
    [anon_sym_descending] = ACTIONS(6324),
    [anon_sym_group] = ACTIONS(6324),
    [anon_sym_select] = ACTIONS(6324),
    [anon_sym_as] = ACTIONS(6406),
    [anon_sym_is] = ACTIONS(6408),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(6232),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4505] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4505),
    [sym_preproc_endregion] = STATE(4505),
    [sym_preproc_line] = STATE(4505),
    [sym_preproc_pragma] = STATE(4505),
    [sym_preproc_nullable] = STATE(4505),
    [sym_preproc_error] = STATE(4505),
    [sym_preproc_warning] = STATE(4505),
    [sym_preproc_define] = STATE(4505),
    [sym_preproc_undef] = STATE(4505),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(6342),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(6388),
    [anon_sym_GT] = ACTIONS(6388),
    [anon_sym_where] = ACTIONS(6342),
    [anon_sym_QMARK] = ACTIONS(6344),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(6390),
    [anon_sym_DASH] = ACTIONS(6390),
    [anon_sym_STAR] = ACTIONS(6392),
    [anon_sym_SLASH] = ACTIONS(6394),
    [anon_sym_PERCENT] = ACTIONS(6392),
    [anon_sym_CARET] = ACTIONS(6452),
    [anon_sym_PIPE] = ACTIONS(6454),
    [anon_sym_AMP] = ACTIONS(6456),
    [anon_sym_LT_LT] = ACTIONS(6396),
    [anon_sym_GT_GT] = ACTIONS(6398),
    [anon_sym_GT_GT_GT] = ACTIONS(6396),
    [anon_sym_EQ_EQ] = ACTIONS(6400),
    [anon_sym_BANG_EQ] = ACTIONS(6400),
    [anon_sym_GT_EQ] = ACTIONS(6402),
    [anon_sym_LT_EQ] = ACTIONS(6402),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(6216),
    [anon_sym_DOT_DOT] = ACTIONS(6404),
    [anon_sym_and] = ACTIONS(6342),
    [anon_sym_or] = ACTIONS(6344),
    [anon_sym_AMP_AMP] = ACTIONS(6342),
    [anon_sym_PIPE_PIPE] = ACTIONS(6342),
    [anon_sym_QMARK_QMARK] = ACTIONS(6342),
    [anon_sym_from] = ACTIONS(6342),
    [anon_sym_join] = ACTIONS(6342),
    [anon_sym_let] = ACTIONS(6342),
    [anon_sym_orderby] = ACTIONS(6342),
    [anon_sym_ascending] = ACTIONS(6342),
    [anon_sym_descending] = ACTIONS(6342),
    [anon_sym_group] = ACTIONS(6342),
    [anon_sym_select] = ACTIONS(6342),
    [anon_sym_as] = ACTIONS(6406),
    [anon_sym_is] = ACTIONS(6408),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(6232),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4506] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4506),
    [sym_preproc_endregion] = STATE(4506),
    [sym_preproc_line] = STATE(4506),
    [sym_preproc_pragma] = STATE(4506),
    [sym_preproc_nullable] = STATE(4506),
    [sym_preproc_error] = STATE(4506),
    [sym_preproc_warning] = STATE(4506),
    [sym_preproc_define] = STATE(4506),
    [sym_preproc_undef] = STATE(4506),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(6342),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(6388),
    [anon_sym_GT] = ACTIONS(6388),
    [anon_sym_where] = ACTIONS(6342),
    [anon_sym_QMARK] = ACTIONS(6344),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(6390),
    [anon_sym_DASH] = ACTIONS(6390),
    [anon_sym_STAR] = ACTIONS(6392),
    [anon_sym_SLASH] = ACTIONS(6394),
    [anon_sym_PERCENT] = ACTIONS(6392),
    [anon_sym_CARET] = ACTIONS(6452),
    [anon_sym_PIPE] = ACTIONS(6454),
    [anon_sym_AMP] = ACTIONS(6456),
    [anon_sym_LT_LT] = ACTIONS(6396),
    [anon_sym_GT_GT] = ACTIONS(6398),
    [anon_sym_GT_GT_GT] = ACTIONS(6396),
    [anon_sym_EQ_EQ] = ACTIONS(6400),
    [anon_sym_BANG_EQ] = ACTIONS(6400),
    [anon_sym_GT_EQ] = ACTIONS(6402),
    [anon_sym_LT_EQ] = ACTIONS(6402),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(6216),
    [anon_sym_DOT_DOT] = ACTIONS(6404),
    [anon_sym_and] = ACTIONS(6342),
    [anon_sym_or] = ACTIONS(6344),
    [anon_sym_AMP_AMP] = ACTIONS(6458),
    [anon_sym_PIPE_PIPE] = ACTIONS(6342),
    [anon_sym_QMARK_QMARK] = ACTIONS(6342),
    [anon_sym_from] = ACTIONS(6342),
    [anon_sym_join] = ACTIONS(6342),
    [anon_sym_let] = ACTIONS(6342),
    [anon_sym_orderby] = ACTIONS(6342),
    [anon_sym_ascending] = ACTIONS(6342),
    [anon_sym_descending] = ACTIONS(6342),
    [anon_sym_group] = ACTIONS(6342),
    [anon_sym_select] = ACTIONS(6342),
    [anon_sym_as] = ACTIONS(6406),
    [anon_sym_is] = ACTIONS(6408),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(6232),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4507] = {
    [sym_preproc_region] = STATE(4507),
    [sym_preproc_endregion] = STATE(4507),
    [sym_preproc_line] = STATE(4507),
    [sym_preproc_pragma] = STATE(4507),
    [sym_preproc_nullable] = STATE(4507),
    [sym_preproc_error] = STATE(4507),
    [sym_preproc_warning] = STATE(4507),
    [sym_preproc_define] = STATE(4507),
    [sym_preproc_undef] = STATE(4507),
    [anon_sym_LBRACK] = ACTIONS(5353),
    [anon_sym_COMMA] = ACTIONS(5353),
    [anon_sym_LPAREN] = ACTIONS(5353),
    [anon_sym_LBRACE] = ACTIONS(5353),
    [anon_sym_LT] = ACTIONS(5355),
    [anon_sym_GT] = ACTIONS(5355),
    [anon_sym_where] = ACTIONS(5353),
    [anon_sym_QMARK] = ACTIONS(5355),
    [anon_sym_BANG] = ACTIONS(5355),
    [anon_sym_PLUS_PLUS] = ACTIONS(5353),
    [anon_sym_DASH_DASH] = ACTIONS(5353),
    [anon_sym_PLUS] = ACTIONS(5355),
    [anon_sym_DASH] = ACTIONS(5355),
    [anon_sym_STAR] = ACTIONS(5353),
    [anon_sym_SLASH] = ACTIONS(5355),
    [anon_sym_PERCENT] = ACTIONS(5353),
    [anon_sym_CARET] = ACTIONS(5353),
    [anon_sym_PIPE] = ACTIONS(5355),
    [anon_sym_AMP] = ACTIONS(5355),
    [anon_sym_LT_LT] = ACTIONS(5353),
    [anon_sym_GT_GT] = ACTIONS(5355),
    [anon_sym_GT_GT_GT] = ACTIONS(5353),
    [anon_sym_EQ_EQ] = ACTIONS(5353),
    [anon_sym_BANG_EQ] = ACTIONS(5353),
    [anon_sym_GT_EQ] = ACTIONS(5353),
    [anon_sym_LT_EQ] = ACTIONS(5353),
    [anon_sym_DOT] = ACTIONS(5355),
    [anon_sym_switch] = ACTIONS(5353),
    [anon_sym_DOT_DOT] = ACTIONS(5353),
    [anon_sym_and] = ACTIONS(5353),
    [anon_sym_or] = ACTIONS(5355),
    [anon_sym_AMP_AMP] = ACTIONS(5353),
    [anon_sym_PIPE_PIPE] = ACTIONS(5353),
    [anon_sym_QMARK_QMARK] = ACTIONS(5353),
    [anon_sym_from] = ACTIONS(5353),
    [anon_sym_into] = ACTIONS(5353),
    [anon_sym_join] = ACTIONS(5353),
    [anon_sym_let] = ACTIONS(5353),
    [anon_sym_orderby] = ACTIONS(5353),
    [anon_sym_ascending] = ACTIONS(5353),
    [anon_sym_descending] = ACTIONS(5353),
    [anon_sym_group] = ACTIONS(5353),
    [anon_sym_select] = ACTIONS(5353),
    [anon_sym_as] = ACTIONS(5355),
    [anon_sym_is] = ACTIONS(5353),
    [anon_sym_DASH_GT] = ACTIONS(5353),
    [anon_sym_with] = ACTIONS(5353),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4508] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4508),
    [sym_preproc_endregion] = STATE(4508),
    [sym_preproc_line] = STATE(4508),
    [sym_preproc_pragma] = STATE(4508),
    [sym_preproc_nullable] = STATE(4508),
    [sym_preproc_error] = STATE(4508),
    [sym_preproc_warning] = STATE(4508),
    [sym_preproc_define] = STATE(4508),
    [sym_preproc_undef] = STATE(4508),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(6342),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(6388),
    [anon_sym_GT] = ACTIONS(6388),
    [anon_sym_where] = ACTIONS(6342),
    [anon_sym_QMARK] = ACTIONS(6344),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(6390),
    [anon_sym_DASH] = ACTIONS(6390),
    [anon_sym_STAR] = ACTIONS(6392),
    [anon_sym_SLASH] = ACTIONS(6394),
    [anon_sym_PERCENT] = ACTIONS(6392),
    [anon_sym_CARET] = ACTIONS(6452),
    [anon_sym_PIPE] = ACTIONS(6454),
    [anon_sym_AMP] = ACTIONS(6456),
    [anon_sym_LT_LT] = ACTIONS(6396),
    [anon_sym_GT_GT] = ACTIONS(6398),
    [anon_sym_GT_GT_GT] = ACTIONS(6396),
    [anon_sym_EQ_EQ] = ACTIONS(6400),
    [anon_sym_BANG_EQ] = ACTIONS(6400),
    [anon_sym_GT_EQ] = ACTIONS(6402),
    [anon_sym_LT_EQ] = ACTIONS(6402),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(6216),
    [anon_sym_DOT_DOT] = ACTIONS(6404),
    [anon_sym_and] = ACTIONS(6342),
    [anon_sym_or] = ACTIONS(6344),
    [anon_sym_AMP_AMP] = ACTIONS(6458),
    [anon_sym_PIPE_PIPE] = ACTIONS(6460),
    [anon_sym_QMARK_QMARK] = ACTIONS(6462),
    [anon_sym_from] = ACTIONS(6342),
    [anon_sym_join] = ACTIONS(6342),
    [anon_sym_let] = ACTIONS(6342),
    [anon_sym_orderby] = ACTIONS(6342),
    [anon_sym_ascending] = ACTIONS(6342),
    [anon_sym_descending] = ACTIONS(6342),
    [anon_sym_group] = ACTIONS(6342),
    [anon_sym_select] = ACTIONS(6342),
    [anon_sym_as] = ACTIONS(6406),
    [anon_sym_is] = ACTIONS(6408),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(6232),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4509] = {
    [sym__name] = STATE(7882),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(6020),
    [sym_implicit_type] = STATE(8747),
    [sym_array_type] = STATE(8331),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(8345),
    [sym_pointer_type] = STATE(8345),
    [sym__pointer_base_type] = STATE(9367),
    [sym_function_pointer_type] = STATE(8345),
    [sym_ref_type] = STATE(8787),
    [sym__ref_base_type] = STATE(9462),
    [sym_scoped_type] = STATE(8787),
    [sym_tuple_type] = STATE(8056),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4509),
    [sym_preproc_endregion] = STATE(4509),
    [sym_preproc_line] = STATE(4509),
    [sym_preproc_pragma] = STATE(4509),
    [sym_preproc_nullable] = STATE(4509),
    [sym_preproc_error] = STATE(4509),
    [sym_preproc_warning] = STATE(4509),
    [sym_preproc_define] = STATE(4509),
    [sym_preproc_undef] = STATE(4509),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(6507),
    [anon_sym_delegate] = ACTIONS(5747),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_readonly] = ACTIONS(6509),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(5980),
    [anon_sym_var] = ACTIONS(5369),
    [sym_predefined_type] = ACTIONS(5982),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4510] = {
    [sym_argument_list] = STATE(4044),
    [sym_bracketed_argument_list] = STATE(3189),
    [sym_preproc_region] = STATE(4510),
    [sym_preproc_endregion] = STATE(4510),
    [sym_preproc_line] = STATE(4510),
    [sym_preproc_pragma] = STATE(4510),
    [sym_preproc_nullable] = STATE(4510),
    [sym_preproc_error] = STATE(4510),
    [sym_preproc_warning] = STATE(4510),
    [sym_preproc_define] = STATE(4510),
    [sym_preproc_undef] = STATE(4510),
    [anon_sym_SEMI] = ACTIONS(6342),
    [anon_sym_LBRACK] = ACTIONS(5778),
    [anon_sym_COMMA] = ACTIONS(6342),
    [anon_sym_RBRACK] = ACTIONS(6342),
    [anon_sym_LPAREN] = ACTIONS(5759),
    [anon_sym_RPAREN] = ACTIONS(6342),
    [anon_sym_RBRACE] = ACTIONS(6342),
    [anon_sym_LT] = ACTIONS(6410),
    [anon_sym_GT] = ACTIONS(6410),
    [anon_sym_in] = ACTIONS(6344),
    [anon_sym_QMARK] = ACTIONS(6344),
    [anon_sym_BANG] = ACTIONS(5780),
    [anon_sym_PLUS_PLUS] = ACTIONS(5782),
    [anon_sym_DASH_DASH] = ACTIONS(5782),
    [anon_sym_PLUS] = ACTIONS(6414),
    [anon_sym_DASH] = ACTIONS(6414),
    [anon_sym_STAR] = ACTIONS(6416),
    [anon_sym_SLASH] = ACTIONS(6418),
    [anon_sym_PERCENT] = ACTIONS(6416),
    [anon_sym_CARET] = ACTIONS(6420),
    [anon_sym_PIPE] = ACTIONS(6422),
    [anon_sym_AMP] = ACTIONS(6424),
    [anon_sym_LT_LT] = ACTIONS(6426),
    [anon_sym_GT_GT] = ACTIONS(6428),
    [anon_sym_GT_GT_GT] = ACTIONS(6426),
    [anon_sym_EQ_EQ] = ACTIONS(6430),
    [anon_sym_BANG_EQ] = ACTIONS(6430),
    [anon_sym_GT_EQ] = ACTIONS(6432),
    [anon_sym_LT_EQ] = ACTIONS(6432),
    [anon_sym_DOT] = ACTIONS(4634),
    [anon_sym_switch] = ACTIONS(6434),
    [anon_sym_DOT_DOT] = ACTIONS(6436),
    [anon_sym_and] = ACTIONS(6342),
    [anon_sym_or] = ACTIONS(6342),
    [anon_sym_AMP_AMP] = ACTIONS(6342),
    [anon_sym_PIPE_PIPE] = ACTIONS(6342),
    [anon_sym_QMARK_QMARK] = ACTIONS(6342),
    [anon_sym_into] = ACTIONS(6342),
    [anon_sym_as] = ACTIONS(6444),
    [anon_sym_is] = ACTIONS(6446),
    [anon_sym_DASH_GT] = ACTIONS(4636),
    [anon_sym_with] = ACTIONS(6448),
    [aux_sym_preproc_if_token3] = ACTIONS(6342),
    [aux_sym_preproc_else_token1] = ACTIONS(6342),
    [aux_sym_preproc_elif_token1] = ACTIONS(6342),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4511] = {
    [sym_argument_list] = STATE(4044),
    [sym_bracketed_argument_list] = STATE(3189),
    [sym_preproc_region] = STATE(4511),
    [sym_preproc_endregion] = STATE(4511),
    [sym_preproc_line] = STATE(4511),
    [sym_preproc_pragma] = STATE(4511),
    [sym_preproc_nullable] = STATE(4511),
    [sym_preproc_error] = STATE(4511),
    [sym_preproc_warning] = STATE(4511),
    [sym_preproc_define] = STATE(4511),
    [sym_preproc_undef] = STATE(4511),
    [anon_sym_SEMI] = ACTIONS(6342),
    [anon_sym_LBRACK] = ACTIONS(5778),
    [anon_sym_COMMA] = ACTIONS(6342),
    [anon_sym_RBRACK] = ACTIONS(6342),
    [anon_sym_LPAREN] = ACTIONS(5759),
    [anon_sym_RPAREN] = ACTIONS(6342),
    [anon_sym_RBRACE] = ACTIONS(6342),
    [anon_sym_LT] = ACTIONS(6344),
    [anon_sym_GT] = ACTIONS(6344),
    [anon_sym_in] = ACTIONS(6344),
    [anon_sym_QMARK] = ACTIONS(6344),
    [anon_sym_BANG] = ACTIONS(5780),
    [anon_sym_PLUS_PLUS] = ACTIONS(5782),
    [anon_sym_DASH_DASH] = ACTIONS(5782),
    [anon_sym_PLUS] = ACTIONS(6344),
    [anon_sym_DASH] = ACTIONS(6344),
    [anon_sym_STAR] = ACTIONS(6416),
    [anon_sym_SLASH] = ACTIONS(6418),
    [anon_sym_PERCENT] = ACTIONS(6416),
    [anon_sym_CARET] = ACTIONS(6342),
    [anon_sym_PIPE] = ACTIONS(6344),
    [anon_sym_AMP] = ACTIONS(6344),
    [anon_sym_LT_LT] = ACTIONS(6342),
    [anon_sym_GT_GT] = ACTIONS(6344),
    [anon_sym_GT_GT_GT] = ACTIONS(6342),
    [anon_sym_EQ_EQ] = ACTIONS(6342),
    [anon_sym_BANG_EQ] = ACTIONS(6342),
    [anon_sym_GT_EQ] = ACTIONS(6342),
    [anon_sym_LT_EQ] = ACTIONS(6342),
    [anon_sym_DOT] = ACTIONS(4634),
    [anon_sym_switch] = ACTIONS(6434),
    [anon_sym_DOT_DOT] = ACTIONS(6436),
    [anon_sym_and] = ACTIONS(6342),
    [anon_sym_or] = ACTIONS(6342),
    [anon_sym_AMP_AMP] = ACTIONS(6342),
    [anon_sym_PIPE_PIPE] = ACTIONS(6342),
    [anon_sym_QMARK_QMARK] = ACTIONS(6342),
    [anon_sym_into] = ACTIONS(6342),
    [anon_sym_as] = ACTIONS(6342),
    [anon_sym_is] = ACTIONS(6342),
    [anon_sym_DASH_GT] = ACTIONS(4636),
    [anon_sym_with] = ACTIONS(6448),
    [aux_sym_preproc_if_token3] = ACTIONS(6342),
    [aux_sym_preproc_else_token1] = ACTIONS(6342),
    [aux_sym_preproc_elif_token1] = ACTIONS(6342),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4512] = {
    [sym_argument_list] = STATE(4044),
    [sym_bracketed_argument_list] = STATE(3189),
    [sym_preproc_region] = STATE(4512),
    [sym_preproc_endregion] = STATE(4512),
    [sym_preproc_line] = STATE(4512),
    [sym_preproc_pragma] = STATE(4512),
    [sym_preproc_nullable] = STATE(4512),
    [sym_preproc_error] = STATE(4512),
    [sym_preproc_warning] = STATE(4512),
    [sym_preproc_define] = STATE(4512),
    [sym_preproc_undef] = STATE(4512),
    [anon_sym_SEMI] = ACTIONS(6342),
    [anon_sym_LBRACK] = ACTIONS(5778),
    [anon_sym_COMMA] = ACTIONS(6342),
    [anon_sym_RBRACK] = ACTIONS(6342),
    [anon_sym_LPAREN] = ACTIONS(5759),
    [anon_sym_RPAREN] = ACTIONS(6342),
    [anon_sym_RBRACE] = ACTIONS(6342),
    [anon_sym_LT] = ACTIONS(6344),
    [anon_sym_GT] = ACTIONS(6344),
    [anon_sym_in] = ACTIONS(6344),
    [anon_sym_QMARK] = ACTIONS(6344),
    [anon_sym_BANG] = ACTIONS(5780),
    [anon_sym_PLUS_PLUS] = ACTIONS(5782),
    [anon_sym_DASH_DASH] = ACTIONS(5782),
    [anon_sym_PLUS] = ACTIONS(6344),
    [anon_sym_DASH] = ACTIONS(6344),
    [anon_sym_STAR] = ACTIONS(6342),
    [anon_sym_SLASH] = ACTIONS(6344),
    [anon_sym_PERCENT] = ACTIONS(6342),
    [anon_sym_CARET] = ACTIONS(6342),
    [anon_sym_PIPE] = ACTIONS(6344),
    [anon_sym_AMP] = ACTIONS(6344),
    [anon_sym_LT_LT] = ACTIONS(6342),
    [anon_sym_GT_GT] = ACTIONS(6344),
    [anon_sym_GT_GT_GT] = ACTIONS(6342),
    [anon_sym_EQ_EQ] = ACTIONS(6342),
    [anon_sym_BANG_EQ] = ACTIONS(6342),
    [anon_sym_GT_EQ] = ACTIONS(6342),
    [anon_sym_LT_EQ] = ACTIONS(6342),
    [anon_sym_DOT] = ACTIONS(4634),
    [anon_sym_switch] = ACTIONS(6434),
    [anon_sym_DOT_DOT] = ACTIONS(6436),
    [anon_sym_and] = ACTIONS(6342),
    [anon_sym_or] = ACTIONS(6342),
    [anon_sym_AMP_AMP] = ACTIONS(6342),
    [anon_sym_PIPE_PIPE] = ACTIONS(6342),
    [anon_sym_QMARK_QMARK] = ACTIONS(6342),
    [anon_sym_into] = ACTIONS(6342),
    [anon_sym_as] = ACTIONS(6342),
    [anon_sym_is] = ACTIONS(6342),
    [anon_sym_DASH_GT] = ACTIONS(4636),
    [anon_sym_with] = ACTIONS(6448),
    [aux_sym_preproc_if_token3] = ACTIONS(6342),
    [aux_sym_preproc_else_token1] = ACTIONS(6342),
    [aux_sym_preproc_elif_token1] = ACTIONS(6342),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4513] = {
    [sym_preproc_region] = STATE(4513),
    [sym_preproc_endregion] = STATE(4513),
    [sym_preproc_line] = STATE(4513),
    [sym_preproc_pragma] = STATE(4513),
    [sym_preproc_nullable] = STATE(4513),
    [sym_preproc_error] = STATE(4513),
    [sym_preproc_warning] = STATE(4513),
    [sym_preproc_define] = STATE(4513),
    [sym_preproc_undef] = STATE(4513),
    [sym__identifier_token] = ACTIONS(4122),
    [anon_sym_alias] = ACTIONS(4122),
    [anon_sym_SEMI] = ACTIONS(4124),
    [anon_sym_global] = ACTIONS(4122),
    [anon_sym_EQ] = ACTIONS(4122),
    [anon_sym_LBRACK] = ACTIONS(4124),
    [anon_sym_COLON] = ACTIONS(4122),
    [anon_sym_COMMA] = ACTIONS(4124),
    [anon_sym_RBRACK] = ACTIONS(4124),
    [anon_sym_LPAREN] = ACTIONS(4124),
    [anon_sym_RPAREN] = ACTIONS(4124),
    [anon_sym_LBRACE] = ACTIONS(4124),
    [anon_sym_RBRACE] = ACTIONS(4124),
    [anon_sym_file] = ACTIONS(4122),
    [anon_sym_LT] = ACTIONS(4124),
    [anon_sym_GT] = ACTIONS(4124),
    [anon_sym_in] = ACTIONS(4122),
    [anon_sym_where] = ACTIONS(4122),
    [anon_sym_QMARK] = ACTIONS(4124),
    [anon_sym_notnull] = ACTIONS(4122),
    [anon_sym_unmanaged] = ACTIONS(4122),
    [anon_sym_operator] = ACTIONS(4122),
    [anon_sym_STAR] = ACTIONS(4124),
    [anon_sym_this] = ACTIONS(4122),
    [anon_sym_DOT] = ACTIONS(4124),
    [anon_sym_scoped] = ACTIONS(4122),
    [anon_sym_EQ_GT] = ACTIONS(4124),
    [anon_sym_COLON_COLON] = ACTIONS(4124),
    [anon_sym_var] = ACTIONS(4122),
    [anon_sym_yield] = ACTIONS(4122),
    [anon_sym_when] = ACTIONS(4122),
    [sym_discard] = ACTIONS(4122),
    [anon_sym_and] = ACTIONS(4122),
    [anon_sym_or] = ACTIONS(4122),
    [anon_sym_from] = ACTIONS(4122),
    [anon_sym_into] = ACTIONS(4122),
    [anon_sym_join] = ACTIONS(4122),
    [anon_sym_on] = ACTIONS(4122),
    [anon_sym_equals] = ACTIONS(4122),
    [anon_sym_let] = ACTIONS(4122),
    [anon_sym_orderby] = ACTIONS(4122),
    [anon_sym_ascending] = ACTIONS(4122),
    [anon_sym_descending] = ACTIONS(4122),
    [anon_sym_group] = ACTIONS(4122),
    [anon_sym_by] = ACTIONS(4122),
    [anon_sym_select] = ACTIONS(4122),
    [anon_sym_DASH_GT] = ACTIONS(4124),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4514] = {
    [sym_argument_list] = STATE(4044),
    [sym_bracketed_argument_list] = STATE(3189),
    [sym_preproc_region] = STATE(4514),
    [sym_preproc_endregion] = STATE(4514),
    [sym_preproc_line] = STATE(4514),
    [sym_preproc_pragma] = STATE(4514),
    [sym_preproc_nullable] = STATE(4514),
    [sym_preproc_error] = STATE(4514),
    [sym_preproc_warning] = STATE(4514),
    [sym_preproc_define] = STATE(4514),
    [sym_preproc_undef] = STATE(4514),
    [anon_sym_SEMI] = ACTIONS(6190),
    [anon_sym_LBRACK] = ACTIONS(5778),
    [anon_sym_COMMA] = ACTIONS(6190),
    [anon_sym_RBRACK] = ACTIONS(6190),
    [anon_sym_LPAREN] = ACTIONS(5759),
    [anon_sym_RPAREN] = ACTIONS(6190),
    [anon_sym_RBRACE] = ACTIONS(6190),
    [anon_sym_LT] = ACTIONS(6410),
    [anon_sym_GT] = ACTIONS(6410),
    [anon_sym_in] = ACTIONS(6220),
    [anon_sym_QMARK] = ACTIONS(6412),
    [anon_sym_BANG] = ACTIONS(5780),
    [anon_sym_PLUS_PLUS] = ACTIONS(5782),
    [anon_sym_DASH_DASH] = ACTIONS(5782),
    [anon_sym_PLUS] = ACTIONS(6414),
    [anon_sym_DASH] = ACTIONS(6414),
    [anon_sym_STAR] = ACTIONS(6416),
    [anon_sym_SLASH] = ACTIONS(6418),
    [anon_sym_PERCENT] = ACTIONS(6416),
    [anon_sym_CARET] = ACTIONS(6420),
    [anon_sym_PIPE] = ACTIONS(6422),
    [anon_sym_AMP] = ACTIONS(6424),
    [anon_sym_LT_LT] = ACTIONS(6426),
    [anon_sym_GT_GT] = ACTIONS(6428),
    [anon_sym_GT_GT_GT] = ACTIONS(6426),
    [anon_sym_EQ_EQ] = ACTIONS(6430),
    [anon_sym_BANG_EQ] = ACTIONS(6430),
    [anon_sym_GT_EQ] = ACTIONS(6432),
    [anon_sym_LT_EQ] = ACTIONS(6432),
    [anon_sym_DOT] = ACTIONS(4634),
    [anon_sym_switch] = ACTIONS(6434),
    [anon_sym_DOT_DOT] = ACTIONS(6436),
    [anon_sym_and] = ACTIONS(6190),
    [anon_sym_or] = ACTIONS(6190),
    [anon_sym_AMP_AMP] = ACTIONS(6438),
    [anon_sym_PIPE_PIPE] = ACTIONS(6440),
    [anon_sym_QMARK_QMARK] = ACTIONS(6442),
    [anon_sym_into] = ACTIONS(6190),
    [anon_sym_as] = ACTIONS(6444),
    [anon_sym_is] = ACTIONS(6446),
    [anon_sym_DASH_GT] = ACTIONS(4636),
    [anon_sym_with] = ACTIONS(6448),
    [aux_sym_preproc_if_token3] = ACTIONS(6190),
    [aux_sym_preproc_else_token1] = ACTIONS(6190),
    [aux_sym_preproc_elif_token1] = ACTIONS(6190),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4515] = {
    [sym_argument_list] = STATE(4044),
    [sym_bracketed_argument_list] = STATE(3189),
    [sym_preproc_region] = STATE(4515),
    [sym_preproc_endregion] = STATE(4515),
    [sym_preproc_line] = STATE(4515),
    [sym_preproc_pragma] = STATE(4515),
    [sym_preproc_nullable] = STATE(4515),
    [sym_preproc_error] = STATE(4515),
    [sym_preproc_warning] = STATE(4515),
    [sym_preproc_define] = STATE(4515),
    [sym_preproc_undef] = STATE(4515),
    [anon_sym_SEMI] = ACTIONS(6342),
    [anon_sym_LBRACK] = ACTIONS(5778),
    [anon_sym_COMMA] = ACTIONS(6342),
    [anon_sym_RBRACK] = ACTIONS(6342),
    [anon_sym_LPAREN] = ACTIONS(5759),
    [anon_sym_RPAREN] = ACTIONS(6342),
    [anon_sym_RBRACE] = ACTIONS(6342),
    [anon_sym_LT] = ACTIONS(6410),
    [anon_sym_GT] = ACTIONS(6410),
    [anon_sym_in] = ACTIONS(6344),
    [anon_sym_QMARK] = ACTIONS(6344),
    [anon_sym_BANG] = ACTIONS(5780),
    [anon_sym_PLUS_PLUS] = ACTIONS(5782),
    [anon_sym_DASH_DASH] = ACTIONS(5782),
    [anon_sym_PLUS] = ACTIONS(6414),
    [anon_sym_DASH] = ACTIONS(6414),
    [anon_sym_STAR] = ACTIONS(6416),
    [anon_sym_SLASH] = ACTIONS(6418),
    [anon_sym_PERCENT] = ACTIONS(6416),
    [anon_sym_CARET] = ACTIONS(6342),
    [anon_sym_PIPE] = ACTIONS(6344),
    [anon_sym_AMP] = ACTIONS(6424),
    [anon_sym_LT_LT] = ACTIONS(6426),
    [anon_sym_GT_GT] = ACTIONS(6428),
    [anon_sym_GT_GT_GT] = ACTIONS(6426),
    [anon_sym_EQ_EQ] = ACTIONS(6430),
    [anon_sym_BANG_EQ] = ACTIONS(6430),
    [anon_sym_GT_EQ] = ACTIONS(6432),
    [anon_sym_LT_EQ] = ACTIONS(6432),
    [anon_sym_DOT] = ACTIONS(4634),
    [anon_sym_switch] = ACTIONS(6434),
    [anon_sym_DOT_DOT] = ACTIONS(6436),
    [anon_sym_and] = ACTIONS(6342),
    [anon_sym_or] = ACTIONS(6342),
    [anon_sym_AMP_AMP] = ACTIONS(6342),
    [anon_sym_PIPE_PIPE] = ACTIONS(6342),
    [anon_sym_QMARK_QMARK] = ACTIONS(6342),
    [anon_sym_into] = ACTIONS(6342),
    [anon_sym_as] = ACTIONS(6444),
    [anon_sym_is] = ACTIONS(6446),
    [anon_sym_DASH_GT] = ACTIONS(4636),
    [anon_sym_with] = ACTIONS(6448),
    [aux_sym_preproc_if_token3] = ACTIONS(6342),
    [aux_sym_preproc_else_token1] = ACTIONS(6342),
    [aux_sym_preproc_elif_token1] = ACTIONS(6342),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4516] = {
    [sym_preproc_region] = STATE(4516),
    [sym_preproc_endregion] = STATE(4516),
    [sym_preproc_line] = STATE(4516),
    [sym_preproc_pragma] = STATE(4516),
    [sym_preproc_nullable] = STATE(4516),
    [sym_preproc_error] = STATE(4516),
    [sym_preproc_warning] = STATE(4516),
    [sym_preproc_define] = STATE(4516),
    [sym_preproc_undef] = STATE(4516),
    [anon_sym_LBRACK] = ACTIONS(5378),
    [anon_sym_COMMA] = ACTIONS(5378),
    [anon_sym_LPAREN] = ACTIONS(5378),
    [anon_sym_LBRACE] = ACTIONS(5378),
    [anon_sym_LT] = ACTIONS(5380),
    [anon_sym_GT] = ACTIONS(5380),
    [anon_sym_where] = ACTIONS(5378),
    [anon_sym_QMARK] = ACTIONS(5380),
    [anon_sym_BANG] = ACTIONS(5380),
    [anon_sym_PLUS_PLUS] = ACTIONS(5378),
    [anon_sym_DASH_DASH] = ACTIONS(5378),
    [anon_sym_PLUS] = ACTIONS(5380),
    [anon_sym_DASH] = ACTIONS(5380),
    [anon_sym_STAR] = ACTIONS(5378),
    [anon_sym_SLASH] = ACTIONS(5380),
    [anon_sym_PERCENT] = ACTIONS(5378),
    [anon_sym_CARET] = ACTIONS(5378),
    [anon_sym_PIPE] = ACTIONS(5380),
    [anon_sym_AMP] = ACTIONS(5380),
    [anon_sym_LT_LT] = ACTIONS(5378),
    [anon_sym_GT_GT] = ACTIONS(5380),
    [anon_sym_GT_GT_GT] = ACTIONS(5378),
    [anon_sym_EQ_EQ] = ACTIONS(5378),
    [anon_sym_BANG_EQ] = ACTIONS(5378),
    [anon_sym_GT_EQ] = ACTIONS(5378),
    [anon_sym_LT_EQ] = ACTIONS(5378),
    [anon_sym_DOT] = ACTIONS(5380),
    [anon_sym_switch] = ACTIONS(5378),
    [anon_sym_DOT_DOT] = ACTIONS(5378),
    [anon_sym_and] = ACTIONS(5378),
    [anon_sym_or] = ACTIONS(5380),
    [anon_sym_AMP_AMP] = ACTIONS(5378),
    [anon_sym_PIPE_PIPE] = ACTIONS(5378),
    [anon_sym_QMARK_QMARK] = ACTIONS(5378),
    [anon_sym_from] = ACTIONS(5378),
    [anon_sym_into] = ACTIONS(5378),
    [anon_sym_join] = ACTIONS(5378),
    [anon_sym_let] = ACTIONS(5378),
    [anon_sym_orderby] = ACTIONS(5378),
    [anon_sym_ascending] = ACTIONS(5378),
    [anon_sym_descending] = ACTIONS(5378),
    [anon_sym_group] = ACTIONS(5378),
    [anon_sym_select] = ACTIONS(5378),
    [anon_sym_as] = ACTIONS(5380),
    [anon_sym_is] = ACTIONS(5378),
    [anon_sym_DASH_GT] = ACTIONS(5378),
    [anon_sym_with] = ACTIONS(5378),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4517] = {
    [sym_argument_list] = STATE(4044),
    [sym_bracketed_argument_list] = STATE(3189),
    [sym_preproc_region] = STATE(4517),
    [sym_preproc_endregion] = STATE(4517),
    [sym_preproc_line] = STATE(4517),
    [sym_preproc_pragma] = STATE(4517),
    [sym_preproc_nullable] = STATE(4517),
    [sym_preproc_error] = STATE(4517),
    [sym_preproc_warning] = STATE(4517),
    [sym_preproc_define] = STATE(4517),
    [sym_preproc_undef] = STATE(4517),
    [anon_sym_SEMI] = ACTIONS(6342),
    [anon_sym_LBRACK] = ACTIONS(5778),
    [anon_sym_COMMA] = ACTIONS(6342),
    [anon_sym_RBRACK] = ACTIONS(6342),
    [anon_sym_LPAREN] = ACTIONS(5759),
    [anon_sym_RPAREN] = ACTIONS(6342),
    [anon_sym_RBRACE] = ACTIONS(6342),
    [anon_sym_LT] = ACTIONS(6410),
    [anon_sym_GT] = ACTIONS(6410),
    [anon_sym_in] = ACTIONS(6344),
    [anon_sym_QMARK] = ACTIONS(6344),
    [anon_sym_BANG] = ACTIONS(5780),
    [anon_sym_PLUS_PLUS] = ACTIONS(5782),
    [anon_sym_DASH_DASH] = ACTIONS(5782),
    [anon_sym_PLUS] = ACTIONS(6414),
    [anon_sym_DASH] = ACTIONS(6414),
    [anon_sym_STAR] = ACTIONS(6416),
    [anon_sym_SLASH] = ACTIONS(6418),
    [anon_sym_PERCENT] = ACTIONS(6416),
    [anon_sym_CARET] = ACTIONS(6420),
    [anon_sym_PIPE] = ACTIONS(6344),
    [anon_sym_AMP] = ACTIONS(6424),
    [anon_sym_LT_LT] = ACTIONS(6426),
    [anon_sym_GT_GT] = ACTIONS(6428),
    [anon_sym_GT_GT_GT] = ACTIONS(6426),
    [anon_sym_EQ_EQ] = ACTIONS(6430),
    [anon_sym_BANG_EQ] = ACTIONS(6430),
    [anon_sym_GT_EQ] = ACTIONS(6432),
    [anon_sym_LT_EQ] = ACTIONS(6432),
    [anon_sym_DOT] = ACTIONS(4634),
    [anon_sym_switch] = ACTIONS(6434),
    [anon_sym_DOT_DOT] = ACTIONS(6436),
    [anon_sym_and] = ACTIONS(6342),
    [anon_sym_or] = ACTIONS(6342),
    [anon_sym_AMP_AMP] = ACTIONS(6342),
    [anon_sym_PIPE_PIPE] = ACTIONS(6342),
    [anon_sym_QMARK_QMARK] = ACTIONS(6342),
    [anon_sym_into] = ACTIONS(6342),
    [anon_sym_as] = ACTIONS(6444),
    [anon_sym_is] = ACTIONS(6446),
    [anon_sym_DASH_GT] = ACTIONS(4636),
    [anon_sym_with] = ACTIONS(6448),
    [aux_sym_preproc_if_token3] = ACTIONS(6342),
    [aux_sym_preproc_else_token1] = ACTIONS(6342),
    [aux_sym_preproc_elif_token1] = ACTIONS(6342),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4518] = {
    [sym_preproc_region] = STATE(4518),
    [sym_preproc_endregion] = STATE(4518),
    [sym_preproc_line] = STATE(4518),
    [sym_preproc_pragma] = STATE(4518),
    [sym_preproc_nullable] = STATE(4518),
    [sym_preproc_error] = STATE(4518),
    [sym_preproc_warning] = STATE(4518),
    [sym_preproc_define] = STATE(4518),
    [sym_preproc_undef] = STATE(4518),
    [anon_sym_EQ] = ACTIONS(6511),
    [anon_sym_LBRACK] = ACTIONS(5286),
    [anon_sym_LPAREN] = ACTIONS(5286),
    [anon_sym_LT] = ACTIONS(5288),
    [anon_sym_GT] = ACTIONS(5288),
    [anon_sym_QMARK] = ACTIONS(5288),
    [anon_sym_BANG] = ACTIONS(5288),
    [anon_sym_PLUS_PLUS] = ACTIONS(5286),
    [anon_sym_DASH_DASH] = ACTIONS(5286),
    [anon_sym_PLUS] = ACTIONS(5288),
    [anon_sym_DASH] = ACTIONS(5288),
    [anon_sym_STAR] = ACTIONS(5288),
    [anon_sym_SLASH] = ACTIONS(5288),
    [anon_sym_PERCENT] = ACTIONS(5288),
    [anon_sym_CARET] = ACTIONS(5288),
    [anon_sym_PIPE] = ACTIONS(5288),
    [anon_sym_AMP] = ACTIONS(5288),
    [anon_sym_LT_LT] = ACTIONS(5288),
    [anon_sym_GT_GT] = ACTIONS(5288),
    [anon_sym_GT_GT_GT] = ACTIONS(5288),
    [anon_sym_EQ_EQ] = ACTIONS(5286),
    [anon_sym_BANG_EQ] = ACTIONS(5286),
    [anon_sym_GT_EQ] = ACTIONS(5286),
    [anon_sym_LT_EQ] = ACTIONS(5286),
    [anon_sym_DOT] = ACTIONS(5288),
    [anon_sym_switch] = ACTIONS(5286),
    [anon_sym_DOT_DOT] = ACTIONS(5286),
    [anon_sym_PLUS_EQ] = ACTIONS(6513),
    [anon_sym_DASH_EQ] = ACTIONS(6513),
    [anon_sym_STAR_EQ] = ACTIONS(6513),
    [anon_sym_SLASH_EQ] = ACTIONS(6513),
    [anon_sym_PERCENT_EQ] = ACTIONS(6513),
    [anon_sym_AMP_EQ] = ACTIONS(6513),
    [anon_sym_CARET_EQ] = ACTIONS(6513),
    [anon_sym_PIPE_EQ] = ACTIONS(6513),
    [anon_sym_LT_LT_EQ] = ACTIONS(6513),
    [anon_sym_GT_GT_EQ] = ACTIONS(6513),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(6513),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(6513),
    [anon_sym_AMP_AMP] = ACTIONS(5286),
    [anon_sym_PIPE_PIPE] = ACTIONS(5286),
    [anon_sym_QMARK_QMARK] = ACTIONS(5288),
    [anon_sym_equals] = ACTIONS(5286),
    [anon_sym_as] = ACTIONS(5286),
    [anon_sym_is] = ACTIONS(5286),
    [anon_sym_DASH_GT] = ACTIONS(5286),
    [anon_sym_with] = ACTIONS(5286),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4519] = {
    [sym_argument_list] = STATE(4044),
    [sym_bracketed_argument_list] = STATE(3189),
    [sym_preproc_region] = STATE(4519),
    [sym_preproc_endregion] = STATE(4519),
    [sym_preproc_line] = STATE(4519),
    [sym_preproc_pragma] = STATE(4519),
    [sym_preproc_nullable] = STATE(4519),
    [sym_preproc_error] = STATE(4519),
    [sym_preproc_warning] = STATE(4519),
    [sym_preproc_define] = STATE(4519),
    [sym_preproc_undef] = STATE(4519),
    [anon_sym_SEMI] = ACTIONS(6336),
    [anon_sym_LBRACK] = ACTIONS(5778),
    [anon_sym_COMMA] = ACTIONS(6336),
    [anon_sym_RBRACK] = ACTIONS(6336),
    [anon_sym_LPAREN] = ACTIONS(5759),
    [anon_sym_RPAREN] = ACTIONS(6336),
    [anon_sym_RBRACE] = ACTIONS(6336),
    [anon_sym_LT] = ACTIONS(6410),
    [anon_sym_GT] = ACTIONS(6410),
    [anon_sym_in] = ACTIONS(6338),
    [anon_sym_QMARK] = ACTIONS(6412),
    [anon_sym_BANG] = ACTIONS(5780),
    [anon_sym_PLUS_PLUS] = ACTIONS(5782),
    [anon_sym_DASH_DASH] = ACTIONS(5782),
    [anon_sym_PLUS] = ACTIONS(6414),
    [anon_sym_DASH] = ACTIONS(6414),
    [anon_sym_STAR] = ACTIONS(6416),
    [anon_sym_SLASH] = ACTIONS(6418),
    [anon_sym_PERCENT] = ACTIONS(6416),
    [anon_sym_CARET] = ACTIONS(6420),
    [anon_sym_PIPE] = ACTIONS(6422),
    [anon_sym_AMP] = ACTIONS(6424),
    [anon_sym_LT_LT] = ACTIONS(6426),
    [anon_sym_GT_GT] = ACTIONS(6428),
    [anon_sym_GT_GT_GT] = ACTIONS(6426),
    [anon_sym_EQ_EQ] = ACTIONS(6430),
    [anon_sym_BANG_EQ] = ACTIONS(6430),
    [anon_sym_GT_EQ] = ACTIONS(6432),
    [anon_sym_LT_EQ] = ACTIONS(6432),
    [anon_sym_DOT] = ACTIONS(4634),
    [anon_sym_switch] = ACTIONS(6434),
    [anon_sym_DOT_DOT] = ACTIONS(6436),
    [anon_sym_and] = ACTIONS(6336),
    [anon_sym_or] = ACTIONS(6336),
    [anon_sym_AMP_AMP] = ACTIONS(6438),
    [anon_sym_PIPE_PIPE] = ACTIONS(6440),
    [anon_sym_QMARK_QMARK] = ACTIONS(6442),
    [anon_sym_into] = ACTIONS(6336),
    [anon_sym_as] = ACTIONS(6444),
    [anon_sym_is] = ACTIONS(6446),
    [anon_sym_DASH_GT] = ACTIONS(4636),
    [anon_sym_with] = ACTIONS(6448),
    [aux_sym_preproc_if_token3] = ACTIONS(6336),
    [aux_sym_preproc_else_token1] = ACTIONS(6336),
    [aux_sym_preproc_elif_token1] = ACTIONS(6336),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4520] = {
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(6020),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4520),
    [sym_preproc_endregion] = STATE(4520),
    [sym_preproc_line] = STATE(4520),
    [sym_preproc_pragma] = STATE(4520),
    [sym_preproc_nullable] = STATE(4520),
    [sym_preproc_error] = STATE(4520),
    [sym_preproc_warning] = STATE(4520),
    [sym_preproc_define] = STATE(4520),
    [sym_preproc_undef] = STATE(4520),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_struct] = ACTIONS(4280),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_readonly] = ACTIONS(2767),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4521] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4521),
    [sym_preproc_endregion] = STATE(4521),
    [sym_preproc_line] = STATE(4521),
    [sym_preproc_pragma] = STATE(4521),
    [sym_preproc_nullable] = STATE(4521),
    [sym_preproc_error] = STATE(4521),
    [sym_preproc_warning] = STATE(4521),
    [sym_preproc_define] = STATE(4521),
    [sym_preproc_undef] = STATE(4521),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(6190),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(6388),
    [anon_sym_GT] = ACTIONS(6388),
    [anon_sym_where] = ACTIONS(6190),
    [anon_sym_QMARK] = ACTIONS(6450),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(6390),
    [anon_sym_DASH] = ACTIONS(6390),
    [anon_sym_STAR] = ACTIONS(6392),
    [anon_sym_SLASH] = ACTIONS(6394),
    [anon_sym_PERCENT] = ACTIONS(6392),
    [anon_sym_CARET] = ACTIONS(6452),
    [anon_sym_PIPE] = ACTIONS(6454),
    [anon_sym_AMP] = ACTIONS(6456),
    [anon_sym_LT_LT] = ACTIONS(6396),
    [anon_sym_GT_GT] = ACTIONS(6398),
    [anon_sym_GT_GT_GT] = ACTIONS(6396),
    [anon_sym_EQ_EQ] = ACTIONS(6400),
    [anon_sym_BANG_EQ] = ACTIONS(6400),
    [anon_sym_GT_EQ] = ACTIONS(6402),
    [anon_sym_LT_EQ] = ACTIONS(6402),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(6216),
    [anon_sym_DOT_DOT] = ACTIONS(6404),
    [anon_sym_and] = ACTIONS(6190),
    [anon_sym_or] = ACTIONS(6220),
    [anon_sym_AMP_AMP] = ACTIONS(6458),
    [anon_sym_PIPE_PIPE] = ACTIONS(6460),
    [anon_sym_QMARK_QMARK] = ACTIONS(6462),
    [anon_sym_from] = ACTIONS(6190),
    [anon_sym_join] = ACTIONS(6190),
    [anon_sym_let] = ACTIONS(6190),
    [anon_sym_orderby] = ACTIONS(6190),
    [anon_sym_ascending] = ACTIONS(6190),
    [anon_sym_descending] = ACTIONS(6190),
    [anon_sym_group] = ACTIONS(6190),
    [anon_sym_select] = ACTIONS(6190),
    [anon_sym_as] = ACTIONS(6406),
    [anon_sym_is] = ACTIONS(6408),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(6232),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4522] = {
    [sym_argument_list] = STATE(4044),
    [sym_bracketed_argument_list] = STATE(3189),
    [sym_preproc_region] = STATE(4522),
    [sym_preproc_endregion] = STATE(4522),
    [sym_preproc_line] = STATE(4522),
    [sym_preproc_pragma] = STATE(4522),
    [sym_preproc_nullable] = STATE(4522),
    [sym_preproc_error] = STATE(4522),
    [sym_preproc_warning] = STATE(4522),
    [sym_preproc_define] = STATE(4522),
    [sym_preproc_undef] = STATE(4522),
    [anon_sym_SEMI] = ACTIONS(6342),
    [anon_sym_LBRACK] = ACTIONS(5778),
    [anon_sym_COMMA] = ACTIONS(6342),
    [anon_sym_RBRACK] = ACTIONS(6342),
    [anon_sym_LPAREN] = ACTIONS(5759),
    [anon_sym_RPAREN] = ACTIONS(6342),
    [anon_sym_RBRACE] = ACTIONS(6342),
    [anon_sym_LT] = ACTIONS(6410),
    [anon_sym_GT] = ACTIONS(6410),
    [anon_sym_in] = ACTIONS(6344),
    [anon_sym_QMARK] = ACTIONS(6344),
    [anon_sym_BANG] = ACTIONS(5780),
    [anon_sym_PLUS_PLUS] = ACTIONS(5782),
    [anon_sym_DASH_DASH] = ACTIONS(5782),
    [anon_sym_PLUS] = ACTIONS(6414),
    [anon_sym_DASH] = ACTIONS(6414),
    [anon_sym_STAR] = ACTIONS(6416),
    [anon_sym_SLASH] = ACTIONS(6418),
    [anon_sym_PERCENT] = ACTIONS(6416),
    [anon_sym_CARET] = ACTIONS(6420),
    [anon_sym_PIPE] = ACTIONS(6422),
    [anon_sym_AMP] = ACTIONS(6424),
    [anon_sym_LT_LT] = ACTIONS(6426),
    [anon_sym_GT_GT] = ACTIONS(6428),
    [anon_sym_GT_GT_GT] = ACTIONS(6426),
    [anon_sym_EQ_EQ] = ACTIONS(6430),
    [anon_sym_BANG_EQ] = ACTIONS(6430),
    [anon_sym_GT_EQ] = ACTIONS(6432),
    [anon_sym_LT_EQ] = ACTIONS(6432),
    [anon_sym_DOT] = ACTIONS(4634),
    [anon_sym_switch] = ACTIONS(6434),
    [anon_sym_DOT_DOT] = ACTIONS(6436),
    [anon_sym_and] = ACTIONS(6342),
    [anon_sym_or] = ACTIONS(6342),
    [anon_sym_AMP_AMP] = ACTIONS(6438),
    [anon_sym_PIPE_PIPE] = ACTIONS(6342),
    [anon_sym_QMARK_QMARK] = ACTIONS(6342),
    [anon_sym_into] = ACTIONS(6342),
    [anon_sym_as] = ACTIONS(6444),
    [anon_sym_is] = ACTIONS(6446),
    [anon_sym_DASH_GT] = ACTIONS(4636),
    [anon_sym_with] = ACTIONS(6448),
    [aux_sym_preproc_if_token3] = ACTIONS(6342),
    [aux_sym_preproc_else_token1] = ACTIONS(6342),
    [aux_sym_preproc_elif_token1] = ACTIONS(6342),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4523] = {
    [sym_preproc_region] = STATE(4523),
    [sym_preproc_endregion] = STATE(4523),
    [sym_preproc_line] = STATE(4523),
    [sym_preproc_pragma] = STATE(4523),
    [sym_preproc_nullable] = STATE(4523),
    [sym_preproc_error] = STATE(4523),
    [sym_preproc_warning] = STATE(4523),
    [sym_preproc_define] = STATE(4523),
    [sym_preproc_undef] = STATE(4523),
    [anon_sym_LBRACK] = ACTIONS(5359),
    [anon_sym_COMMA] = ACTIONS(5359),
    [anon_sym_LPAREN] = ACTIONS(5359),
    [anon_sym_LBRACE] = ACTIONS(5359),
    [anon_sym_LT] = ACTIONS(5361),
    [anon_sym_GT] = ACTIONS(5361),
    [anon_sym_where] = ACTIONS(5359),
    [anon_sym_QMARK] = ACTIONS(5361),
    [anon_sym_BANG] = ACTIONS(5361),
    [anon_sym_PLUS_PLUS] = ACTIONS(5359),
    [anon_sym_DASH_DASH] = ACTIONS(5359),
    [anon_sym_PLUS] = ACTIONS(5361),
    [anon_sym_DASH] = ACTIONS(5361),
    [anon_sym_STAR] = ACTIONS(5359),
    [anon_sym_SLASH] = ACTIONS(5361),
    [anon_sym_PERCENT] = ACTIONS(5359),
    [anon_sym_CARET] = ACTIONS(5359),
    [anon_sym_PIPE] = ACTIONS(5361),
    [anon_sym_AMP] = ACTIONS(5361),
    [anon_sym_LT_LT] = ACTIONS(5359),
    [anon_sym_GT_GT] = ACTIONS(5361),
    [anon_sym_GT_GT_GT] = ACTIONS(5359),
    [anon_sym_EQ_EQ] = ACTIONS(5359),
    [anon_sym_BANG_EQ] = ACTIONS(5359),
    [anon_sym_GT_EQ] = ACTIONS(5359),
    [anon_sym_LT_EQ] = ACTIONS(5359),
    [anon_sym_DOT] = ACTIONS(5361),
    [anon_sym_switch] = ACTIONS(5359),
    [anon_sym_DOT_DOT] = ACTIONS(5359),
    [anon_sym_and] = ACTIONS(5359),
    [anon_sym_or] = ACTIONS(5361),
    [anon_sym_AMP_AMP] = ACTIONS(5359),
    [anon_sym_PIPE_PIPE] = ACTIONS(5359),
    [anon_sym_QMARK_QMARK] = ACTIONS(5359),
    [anon_sym_from] = ACTIONS(5359),
    [anon_sym_into] = ACTIONS(5359),
    [anon_sym_join] = ACTIONS(5359),
    [anon_sym_let] = ACTIONS(5359),
    [anon_sym_orderby] = ACTIONS(5359),
    [anon_sym_ascending] = ACTIONS(5359),
    [anon_sym_descending] = ACTIONS(5359),
    [anon_sym_group] = ACTIONS(5359),
    [anon_sym_select] = ACTIONS(5359),
    [anon_sym_as] = ACTIONS(5361),
    [anon_sym_is] = ACTIONS(5359),
    [anon_sym_DASH_GT] = ACTIONS(5359),
    [anon_sym_with] = ACTIONS(5359),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4524] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4524),
    [sym_preproc_endregion] = STATE(4524),
    [sym_preproc_line] = STATE(4524),
    [sym_preproc_pragma] = STATE(4524),
    [sym_preproc_nullable] = STATE(4524),
    [sym_preproc_error] = STATE(4524),
    [sym_preproc_warning] = STATE(4524),
    [sym_preproc_define] = STATE(4524),
    [sym_preproc_undef] = STATE(4524),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(6336),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(6388),
    [anon_sym_GT] = ACTIONS(6388),
    [anon_sym_where] = ACTIONS(6336),
    [anon_sym_QMARK] = ACTIONS(6450),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(6390),
    [anon_sym_DASH] = ACTIONS(6390),
    [anon_sym_STAR] = ACTIONS(6392),
    [anon_sym_SLASH] = ACTIONS(6394),
    [anon_sym_PERCENT] = ACTIONS(6392),
    [anon_sym_CARET] = ACTIONS(6452),
    [anon_sym_PIPE] = ACTIONS(6454),
    [anon_sym_AMP] = ACTIONS(6456),
    [anon_sym_LT_LT] = ACTIONS(6396),
    [anon_sym_GT_GT] = ACTIONS(6398),
    [anon_sym_GT_GT_GT] = ACTIONS(6396),
    [anon_sym_EQ_EQ] = ACTIONS(6400),
    [anon_sym_BANG_EQ] = ACTIONS(6400),
    [anon_sym_GT_EQ] = ACTIONS(6402),
    [anon_sym_LT_EQ] = ACTIONS(6402),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(6216),
    [anon_sym_DOT_DOT] = ACTIONS(6404),
    [anon_sym_and] = ACTIONS(6336),
    [anon_sym_or] = ACTIONS(6338),
    [anon_sym_AMP_AMP] = ACTIONS(6458),
    [anon_sym_PIPE_PIPE] = ACTIONS(6460),
    [anon_sym_QMARK_QMARK] = ACTIONS(6462),
    [anon_sym_from] = ACTIONS(6336),
    [anon_sym_join] = ACTIONS(6336),
    [anon_sym_let] = ACTIONS(6336),
    [anon_sym_orderby] = ACTIONS(6336),
    [anon_sym_ascending] = ACTIONS(6336),
    [anon_sym_descending] = ACTIONS(6336),
    [anon_sym_group] = ACTIONS(6336),
    [anon_sym_select] = ACTIONS(6336),
    [anon_sym_as] = ACTIONS(6406),
    [anon_sym_is] = ACTIONS(6408),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(6232),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4525] = {
    [sym_argument_list] = STATE(4044),
    [sym_bracketed_argument_list] = STATE(3189),
    [sym_preproc_region] = STATE(4525),
    [sym_preproc_endregion] = STATE(4525),
    [sym_preproc_line] = STATE(4525),
    [sym_preproc_pragma] = STATE(4525),
    [sym_preproc_nullable] = STATE(4525),
    [sym_preproc_error] = STATE(4525),
    [sym_preproc_warning] = STATE(4525),
    [sym_preproc_define] = STATE(4525),
    [sym_preproc_undef] = STATE(4525),
    [anon_sym_SEMI] = ACTIONS(6342),
    [anon_sym_LBRACK] = ACTIONS(5778),
    [anon_sym_COMMA] = ACTIONS(6342),
    [anon_sym_RBRACK] = ACTIONS(6342),
    [anon_sym_LPAREN] = ACTIONS(5759),
    [anon_sym_RPAREN] = ACTIONS(6342),
    [anon_sym_RBRACE] = ACTIONS(6342),
    [anon_sym_LT] = ACTIONS(6410),
    [anon_sym_GT] = ACTIONS(6410),
    [anon_sym_in] = ACTIONS(6344),
    [anon_sym_QMARK] = ACTIONS(6344),
    [anon_sym_BANG] = ACTIONS(5780),
    [anon_sym_PLUS_PLUS] = ACTIONS(5782),
    [anon_sym_DASH_DASH] = ACTIONS(5782),
    [anon_sym_PLUS] = ACTIONS(6414),
    [anon_sym_DASH] = ACTIONS(6414),
    [anon_sym_STAR] = ACTIONS(6416),
    [anon_sym_SLASH] = ACTIONS(6418),
    [anon_sym_PERCENT] = ACTIONS(6416),
    [anon_sym_CARET] = ACTIONS(6342),
    [anon_sym_PIPE] = ACTIONS(6344),
    [anon_sym_AMP] = ACTIONS(6344),
    [anon_sym_LT_LT] = ACTIONS(6426),
    [anon_sym_GT_GT] = ACTIONS(6428),
    [anon_sym_GT_GT_GT] = ACTIONS(6426),
    [anon_sym_EQ_EQ] = ACTIONS(6430),
    [anon_sym_BANG_EQ] = ACTIONS(6430),
    [anon_sym_GT_EQ] = ACTIONS(6432),
    [anon_sym_LT_EQ] = ACTIONS(6432),
    [anon_sym_DOT] = ACTIONS(4634),
    [anon_sym_switch] = ACTIONS(6434),
    [anon_sym_DOT_DOT] = ACTIONS(6436),
    [anon_sym_and] = ACTIONS(6342),
    [anon_sym_or] = ACTIONS(6342),
    [anon_sym_AMP_AMP] = ACTIONS(6342),
    [anon_sym_PIPE_PIPE] = ACTIONS(6342),
    [anon_sym_QMARK_QMARK] = ACTIONS(6342),
    [anon_sym_into] = ACTIONS(6342),
    [anon_sym_as] = ACTIONS(6444),
    [anon_sym_is] = ACTIONS(6446),
    [anon_sym_DASH_GT] = ACTIONS(4636),
    [anon_sym_with] = ACTIONS(6448),
    [aux_sym_preproc_if_token3] = ACTIONS(6342),
    [aux_sym_preproc_else_token1] = ACTIONS(6342),
    [aux_sym_preproc_elif_token1] = ACTIONS(6342),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4526] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4526),
    [sym_preproc_endregion] = STATE(4526),
    [sym_preproc_line] = STATE(4526),
    [sym_preproc_pragma] = STATE(4526),
    [sym_preproc_nullable] = STATE(4526),
    [sym_preproc_error] = STATE(4526),
    [sym_preproc_warning] = STATE(4526),
    [sym_preproc_define] = STATE(4526),
    [sym_preproc_undef] = STATE(4526),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(5572),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(6388),
    [anon_sym_GT] = ACTIONS(6388),
    [anon_sym_where] = ACTIONS(5572),
    [anon_sym_QMARK] = ACTIONS(6450),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(6390),
    [anon_sym_DASH] = ACTIONS(6390),
    [anon_sym_STAR] = ACTIONS(6392),
    [anon_sym_SLASH] = ACTIONS(6394),
    [anon_sym_PERCENT] = ACTIONS(6392),
    [anon_sym_CARET] = ACTIONS(6452),
    [anon_sym_PIPE] = ACTIONS(6454),
    [anon_sym_AMP] = ACTIONS(6456),
    [anon_sym_LT_LT] = ACTIONS(6396),
    [anon_sym_GT_GT] = ACTIONS(6398),
    [anon_sym_GT_GT_GT] = ACTIONS(6396),
    [anon_sym_EQ_EQ] = ACTIONS(6400),
    [anon_sym_BANG_EQ] = ACTIONS(6400),
    [anon_sym_GT_EQ] = ACTIONS(6402),
    [anon_sym_LT_EQ] = ACTIONS(6402),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(6216),
    [anon_sym_DOT_DOT] = ACTIONS(6404),
    [anon_sym_and] = ACTIONS(5572),
    [anon_sym_or] = ACTIONS(5574),
    [anon_sym_AMP_AMP] = ACTIONS(6458),
    [anon_sym_PIPE_PIPE] = ACTIONS(6460),
    [anon_sym_QMARK_QMARK] = ACTIONS(6462),
    [anon_sym_from] = ACTIONS(5572),
    [anon_sym_join] = ACTIONS(5572),
    [anon_sym_let] = ACTIONS(5572),
    [anon_sym_orderby] = ACTIONS(5572),
    [anon_sym_ascending] = ACTIONS(5572),
    [anon_sym_descending] = ACTIONS(5572),
    [anon_sym_group] = ACTIONS(5572),
    [anon_sym_select] = ACTIONS(5572),
    [anon_sym_as] = ACTIONS(6406),
    [anon_sym_is] = ACTIONS(6408),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(6232),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4527] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4527),
    [sym_preproc_endregion] = STATE(4527),
    [sym_preproc_line] = STATE(4527),
    [sym_preproc_pragma] = STATE(4527),
    [sym_preproc_nullable] = STATE(4527),
    [sym_preproc_error] = STATE(4527),
    [sym_preproc_warning] = STATE(4527),
    [sym_preproc_define] = STATE(4527),
    [sym_preproc_undef] = STATE(4527),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(5584),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(6388),
    [anon_sym_GT] = ACTIONS(6388),
    [anon_sym_where] = ACTIONS(5584),
    [anon_sym_QMARK] = ACTIONS(6450),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(6390),
    [anon_sym_DASH] = ACTIONS(6390),
    [anon_sym_STAR] = ACTIONS(6392),
    [anon_sym_SLASH] = ACTIONS(6394),
    [anon_sym_PERCENT] = ACTIONS(6392),
    [anon_sym_CARET] = ACTIONS(6452),
    [anon_sym_PIPE] = ACTIONS(6454),
    [anon_sym_AMP] = ACTIONS(6456),
    [anon_sym_LT_LT] = ACTIONS(6396),
    [anon_sym_GT_GT] = ACTIONS(6398),
    [anon_sym_GT_GT_GT] = ACTIONS(6396),
    [anon_sym_EQ_EQ] = ACTIONS(6400),
    [anon_sym_BANG_EQ] = ACTIONS(6400),
    [anon_sym_GT_EQ] = ACTIONS(6402),
    [anon_sym_LT_EQ] = ACTIONS(6402),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(6216),
    [anon_sym_DOT_DOT] = ACTIONS(6404),
    [anon_sym_and] = ACTIONS(5584),
    [anon_sym_or] = ACTIONS(5586),
    [anon_sym_AMP_AMP] = ACTIONS(6458),
    [anon_sym_PIPE_PIPE] = ACTIONS(6460),
    [anon_sym_QMARK_QMARK] = ACTIONS(6462),
    [anon_sym_from] = ACTIONS(5584),
    [anon_sym_join] = ACTIONS(5584),
    [anon_sym_let] = ACTIONS(5584),
    [anon_sym_orderby] = ACTIONS(5584),
    [anon_sym_ascending] = ACTIONS(5584),
    [anon_sym_descending] = ACTIONS(5584),
    [anon_sym_group] = ACTIONS(5584),
    [anon_sym_select] = ACTIONS(5584),
    [anon_sym_as] = ACTIONS(6406),
    [anon_sym_is] = ACTIONS(6408),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(6232),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4528] = {
    [sym_preproc_region] = STATE(4528),
    [sym_preproc_endregion] = STATE(4528),
    [sym_preproc_line] = STATE(4528),
    [sym_preproc_pragma] = STATE(4528),
    [sym_preproc_nullable] = STATE(4528),
    [sym_preproc_error] = STATE(4528),
    [sym_preproc_warning] = STATE(4528),
    [sym_preproc_define] = STATE(4528),
    [sym_preproc_undef] = STATE(4528),
    [sym__identifier_token] = ACTIONS(5701),
    [anon_sym_extern] = ACTIONS(5701),
    [anon_sym_alias] = ACTIONS(5701),
    [anon_sym_global] = ACTIONS(5701),
    [anon_sym_unsafe] = ACTIONS(5701),
    [anon_sym_static] = ACTIONS(5701),
    [anon_sym_LBRACK] = ACTIONS(5703),
    [anon_sym_LPAREN] = ACTIONS(5703),
    [anon_sym_ref] = ACTIONS(5701),
    [anon_sym_delegate] = ACTIONS(5701),
    [anon_sym_abstract] = ACTIONS(5701),
    [anon_sym_async] = ACTIONS(5701),
    [anon_sym_const] = ACTIONS(5701),
    [anon_sym_file] = ACTIONS(5701),
    [anon_sym_fixed] = ACTIONS(5701),
    [anon_sym_internal] = ACTIONS(5701),
    [anon_sym_new] = ACTIONS(5701),
    [anon_sym_override] = ACTIONS(5701),
    [anon_sym_partial] = ACTIONS(5701),
    [anon_sym_private] = ACTIONS(5701),
    [anon_sym_protected] = ACTIONS(5701),
    [anon_sym_public] = ACTIONS(5701),
    [anon_sym_readonly] = ACTIONS(5701),
    [anon_sym_required] = ACTIONS(5701),
    [anon_sym_sealed] = ACTIONS(5701),
    [anon_sym_virtual] = ACTIONS(5701),
    [anon_sym_volatile] = ACTIONS(5701),
    [anon_sym_where] = ACTIONS(5701),
    [anon_sym_notnull] = ACTIONS(5701),
    [anon_sym_unmanaged] = ACTIONS(5701),
    [anon_sym_scoped] = ACTIONS(5701),
    [anon_sym_var] = ACTIONS(5701),
    [sym_predefined_type] = ACTIONS(5701),
    [anon_sym_yield] = ACTIONS(5701),
    [anon_sym_when] = ACTIONS(5701),
    [anon_sym_from] = ACTIONS(5701),
    [anon_sym_into] = ACTIONS(5701),
    [anon_sym_join] = ACTIONS(5701),
    [anon_sym_on] = ACTIONS(5701),
    [anon_sym_equals] = ACTIONS(5701),
    [anon_sym_let] = ACTIONS(5701),
    [anon_sym_orderby] = ACTIONS(5701),
    [anon_sym_ascending] = ACTIONS(5701),
    [anon_sym_descending] = ACTIONS(5701),
    [anon_sym_group] = ACTIONS(5701),
    [anon_sym_by] = ACTIONS(5701),
    [anon_sym_select] = ACTIONS(5701),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4529] = {
    [sym_preproc_region] = STATE(4529),
    [sym_preproc_endregion] = STATE(4529),
    [sym_preproc_line] = STATE(4529),
    [sym_preproc_pragma] = STATE(4529),
    [sym_preproc_nullable] = STATE(4529),
    [sym_preproc_error] = STATE(4529),
    [sym_preproc_warning] = STATE(4529),
    [sym_preproc_define] = STATE(4529),
    [sym_preproc_undef] = STATE(4529),
    [sym__identifier_token] = ACTIONS(3995),
    [anon_sym_alias] = ACTIONS(3995),
    [anon_sym_SEMI] = ACTIONS(3993),
    [anon_sym_global] = ACTIONS(3995),
    [anon_sym_EQ] = ACTIONS(3995),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_COLON] = ACTIONS(3995),
    [anon_sym_COMMA] = ACTIONS(3993),
    [anon_sym_RBRACK] = ACTIONS(3993),
    [anon_sym_LPAREN] = ACTIONS(3993),
    [anon_sym_RPAREN] = ACTIONS(3993),
    [anon_sym_LBRACE] = ACTIONS(3993),
    [anon_sym_RBRACE] = ACTIONS(3993),
    [anon_sym_file] = ACTIONS(3995),
    [anon_sym_LT] = ACTIONS(3993),
    [anon_sym_GT] = ACTIONS(3993),
    [anon_sym_in] = ACTIONS(3995),
    [anon_sym_where] = ACTIONS(3995),
    [anon_sym_QMARK] = ACTIONS(3993),
    [anon_sym_notnull] = ACTIONS(3995),
    [anon_sym_unmanaged] = ACTIONS(3995),
    [anon_sym_operator] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3993),
    [anon_sym_this] = ACTIONS(3995),
    [anon_sym_DOT] = ACTIONS(3993),
    [anon_sym_scoped] = ACTIONS(3995),
    [anon_sym_EQ_GT] = ACTIONS(3993),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(3995),
    [anon_sym_yield] = ACTIONS(3995),
    [anon_sym_when] = ACTIONS(3995),
    [sym_discard] = ACTIONS(3995),
    [anon_sym_and] = ACTIONS(3995),
    [anon_sym_or] = ACTIONS(3995),
    [anon_sym_from] = ACTIONS(3995),
    [anon_sym_into] = ACTIONS(3995),
    [anon_sym_join] = ACTIONS(3995),
    [anon_sym_on] = ACTIONS(3995),
    [anon_sym_equals] = ACTIONS(3995),
    [anon_sym_let] = ACTIONS(3995),
    [anon_sym_orderby] = ACTIONS(3995),
    [anon_sym_ascending] = ACTIONS(3995),
    [anon_sym_descending] = ACTIONS(3995),
    [anon_sym_group] = ACTIONS(3995),
    [anon_sym_by] = ACTIONS(3995),
    [anon_sym_select] = ACTIONS(3995),
    [anon_sym_DASH_GT] = ACTIONS(3993),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4530] = {
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(6020),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4530),
    [sym_preproc_endregion] = STATE(4530),
    [sym_preproc_line] = STATE(4530),
    [sym_preproc_pragma] = STATE(4530),
    [sym_preproc_nullable] = STATE(4530),
    [sym_preproc_error] = STATE(4530),
    [sym_preproc_warning] = STATE(4530),
    [sym_preproc_define] = STATE(4530),
    [sym_preproc_undef] = STATE(4530),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_struct] = ACTIONS(4419),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_readonly] = ACTIONS(2767),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4531] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4531),
    [sym_preproc_endregion] = STATE(4531),
    [sym_preproc_line] = STATE(4531),
    [sym_preproc_pragma] = STATE(4531),
    [sym_preproc_nullable] = STATE(4531),
    [sym_preproc_error] = STATE(4531),
    [sym_preproc_warning] = STATE(4531),
    [sym_preproc_define] = STATE(4531),
    [sym_preproc_undef] = STATE(4531),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(5624),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(6388),
    [anon_sym_GT] = ACTIONS(6388),
    [anon_sym_where] = ACTIONS(5624),
    [anon_sym_QMARK] = ACTIONS(6450),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(6390),
    [anon_sym_DASH] = ACTIONS(6390),
    [anon_sym_STAR] = ACTIONS(6392),
    [anon_sym_SLASH] = ACTIONS(6394),
    [anon_sym_PERCENT] = ACTIONS(6392),
    [anon_sym_CARET] = ACTIONS(6452),
    [anon_sym_PIPE] = ACTIONS(6454),
    [anon_sym_AMP] = ACTIONS(6456),
    [anon_sym_LT_LT] = ACTIONS(6396),
    [anon_sym_GT_GT] = ACTIONS(6398),
    [anon_sym_GT_GT_GT] = ACTIONS(6396),
    [anon_sym_EQ_EQ] = ACTIONS(6400),
    [anon_sym_BANG_EQ] = ACTIONS(6400),
    [anon_sym_GT_EQ] = ACTIONS(6402),
    [anon_sym_LT_EQ] = ACTIONS(6402),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(6216),
    [anon_sym_DOT_DOT] = ACTIONS(6404),
    [anon_sym_and] = ACTIONS(5624),
    [anon_sym_or] = ACTIONS(5626),
    [anon_sym_AMP_AMP] = ACTIONS(6458),
    [anon_sym_PIPE_PIPE] = ACTIONS(6460),
    [anon_sym_QMARK_QMARK] = ACTIONS(6462),
    [anon_sym_from] = ACTIONS(5624),
    [anon_sym_join] = ACTIONS(5624),
    [anon_sym_let] = ACTIONS(5624),
    [anon_sym_orderby] = ACTIONS(5624),
    [anon_sym_ascending] = ACTIONS(5624),
    [anon_sym_descending] = ACTIONS(5624),
    [anon_sym_group] = ACTIONS(5624),
    [anon_sym_select] = ACTIONS(5624),
    [anon_sym_as] = ACTIONS(6406),
    [anon_sym_is] = ACTIONS(6408),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(6232),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4532] = {
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(6020),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4532),
    [sym_preproc_endregion] = STATE(4532),
    [sym_preproc_line] = STATE(4532),
    [sym_preproc_pragma] = STATE(4532),
    [sym_preproc_nullable] = STATE(4532),
    [sym_preproc_error] = STATE(4532),
    [sym_preproc_warning] = STATE(4532),
    [sym_preproc_define] = STATE(4532),
    [sym_preproc_undef] = STATE(4532),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_struct] = ACTIONS(6515),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_readonly] = ACTIONS(2767),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4533] = {
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(6020),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4533),
    [sym_preproc_endregion] = STATE(4533),
    [sym_preproc_line] = STATE(4533),
    [sym_preproc_pragma] = STATE(4533),
    [sym_preproc_nullable] = STATE(4533),
    [sym_preproc_error] = STATE(4533),
    [sym_preproc_warning] = STATE(4533),
    [sym_preproc_define] = STATE(4533),
    [sym_preproc_undef] = STATE(4533),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_struct] = ACTIONS(4563),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_readonly] = ACTIONS(2767),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4534] = {
    [sym_argument_list] = STATE(4044),
    [sym_bracketed_argument_list] = STATE(3189),
    [sym_preproc_region] = STATE(4534),
    [sym_preproc_endregion] = STATE(4534),
    [sym_preproc_line] = STATE(4534),
    [sym_preproc_pragma] = STATE(4534),
    [sym_preproc_nullable] = STATE(4534),
    [sym_preproc_error] = STATE(4534),
    [sym_preproc_warning] = STATE(4534),
    [sym_preproc_define] = STATE(4534),
    [sym_preproc_undef] = STATE(4534),
    [anon_sym_SEMI] = ACTIONS(6342),
    [anon_sym_LBRACK] = ACTIONS(5778),
    [anon_sym_COMMA] = ACTIONS(6342),
    [anon_sym_RBRACK] = ACTIONS(6342),
    [anon_sym_LPAREN] = ACTIONS(5759),
    [anon_sym_RPAREN] = ACTIONS(6342),
    [anon_sym_RBRACE] = ACTIONS(6342),
    [anon_sym_LT] = ACTIONS(6344),
    [anon_sym_GT] = ACTIONS(6344),
    [anon_sym_in] = ACTIONS(6344),
    [anon_sym_QMARK] = ACTIONS(6344),
    [anon_sym_BANG] = ACTIONS(5780),
    [anon_sym_PLUS_PLUS] = ACTIONS(5782),
    [anon_sym_DASH_DASH] = ACTIONS(5782),
    [anon_sym_PLUS] = ACTIONS(6414),
    [anon_sym_DASH] = ACTIONS(6414),
    [anon_sym_STAR] = ACTIONS(6416),
    [anon_sym_SLASH] = ACTIONS(6418),
    [anon_sym_PERCENT] = ACTIONS(6416),
    [anon_sym_CARET] = ACTIONS(6342),
    [anon_sym_PIPE] = ACTIONS(6344),
    [anon_sym_AMP] = ACTIONS(6344),
    [anon_sym_LT_LT] = ACTIONS(6342),
    [anon_sym_GT_GT] = ACTIONS(6344),
    [anon_sym_GT_GT_GT] = ACTIONS(6342),
    [anon_sym_EQ_EQ] = ACTIONS(6342),
    [anon_sym_BANG_EQ] = ACTIONS(6342),
    [anon_sym_GT_EQ] = ACTIONS(6342),
    [anon_sym_LT_EQ] = ACTIONS(6342),
    [anon_sym_DOT] = ACTIONS(4634),
    [anon_sym_switch] = ACTIONS(6434),
    [anon_sym_DOT_DOT] = ACTIONS(6436),
    [anon_sym_and] = ACTIONS(6342),
    [anon_sym_or] = ACTIONS(6342),
    [anon_sym_AMP_AMP] = ACTIONS(6342),
    [anon_sym_PIPE_PIPE] = ACTIONS(6342),
    [anon_sym_QMARK_QMARK] = ACTIONS(6342),
    [anon_sym_into] = ACTIONS(6342),
    [anon_sym_as] = ACTIONS(6342),
    [anon_sym_is] = ACTIONS(6342),
    [anon_sym_DASH_GT] = ACTIONS(4636),
    [anon_sym_with] = ACTIONS(6448),
    [aux_sym_preproc_if_token3] = ACTIONS(6342),
    [aux_sym_preproc_else_token1] = ACTIONS(6342),
    [aux_sym_preproc_elif_token1] = ACTIONS(6342),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4535] = {
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(6020),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4535),
    [sym_preproc_endregion] = STATE(4535),
    [sym_preproc_line] = STATE(4535),
    [sym_preproc_pragma] = STATE(4535),
    [sym_preproc_nullable] = STATE(4535),
    [sym_preproc_error] = STATE(4535),
    [sym_preproc_warning] = STATE(4535),
    [sym_preproc_define] = STATE(4535),
    [sym_preproc_undef] = STATE(4535),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_struct] = ACTIONS(4610),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_readonly] = ACTIONS(2767),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4536] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4536),
    [sym_preproc_endregion] = STATE(4536),
    [sym_preproc_line] = STATE(4536),
    [sym_preproc_pragma] = STATE(4536),
    [sym_preproc_nullable] = STATE(4536),
    [sym_preproc_error] = STATE(4536),
    [sym_preproc_warning] = STATE(4536),
    [sym_preproc_define] = STATE(4536),
    [sym_preproc_undef] = STATE(4536),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(6320),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(6388),
    [anon_sym_GT] = ACTIONS(6388),
    [anon_sym_where] = ACTIONS(6320),
    [anon_sym_QMARK] = ACTIONS(6450),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(6390),
    [anon_sym_DASH] = ACTIONS(6390),
    [anon_sym_STAR] = ACTIONS(6392),
    [anon_sym_SLASH] = ACTIONS(6394),
    [anon_sym_PERCENT] = ACTIONS(6392),
    [anon_sym_CARET] = ACTIONS(6452),
    [anon_sym_PIPE] = ACTIONS(6454),
    [anon_sym_AMP] = ACTIONS(6456),
    [anon_sym_LT_LT] = ACTIONS(6396),
    [anon_sym_GT_GT] = ACTIONS(6398),
    [anon_sym_GT_GT_GT] = ACTIONS(6396),
    [anon_sym_EQ_EQ] = ACTIONS(6400),
    [anon_sym_BANG_EQ] = ACTIONS(6400),
    [anon_sym_GT_EQ] = ACTIONS(6402),
    [anon_sym_LT_EQ] = ACTIONS(6402),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(6216),
    [anon_sym_DOT_DOT] = ACTIONS(6404),
    [anon_sym_and] = ACTIONS(6320),
    [anon_sym_or] = ACTIONS(6322),
    [anon_sym_AMP_AMP] = ACTIONS(6458),
    [anon_sym_PIPE_PIPE] = ACTIONS(6460),
    [anon_sym_QMARK_QMARK] = ACTIONS(6462),
    [anon_sym_from] = ACTIONS(6320),
    [anon_sym_join] = ACTIONS(6320),
    [anon_sym_let] = ACTIONS(6320),
    [anon_sym_orderby] = ACTIONS(6320),
    [anon_sym_ascending] = ACTIONS(6320),
    [anon_sym_descending] = ACTIONS(6320),
    [anon_sym_group] = ACTIONS(6320),
    [anon_sym_select] = ACTIONS(6320),
    [anon_sym_as] = ACTIONS(6406),
    [anon_sym_is] = ACTIONS(6408),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(6232),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4537] = {
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(6020),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4537),
    [sym_preproc_endregion] = STATE(4537),
    [sym_preproc_line] = STATE(4537),
    [sym_preproc_pragma] = STATE(4537),
    [sym_preproc_nullable] = STATE(4537),
    [sym_preproc_error] = STATE(4537),
    [sym_preproc_warning] = STATE(4537),
    [sym_preproc_define] = STATE(4537),
    [sym_preproc_undef] = STATE(4537),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_struct] = ACTIONS(6517),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_readonly] = ACTIONS(2767),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4538] = {
    [sym_argument_list] = STATE(4044),
    [sym_bracketed_argument_list] = STATE(3189),
    [sym_preproc_region] = STATE(4538),
    [sym_preproc_endregion] = STATE(4538),
    [sym_preproc_line] = STATE(4538),
    [sym_preproc_pragma] = STATE(4538),
    [sym_preproc_nullable] = STATE(4538),
    [sym_preproc_error] = STATE(4538),
    [sym_preproc_warning] = STATE(4538),
    [sym_preproc_define] = STATE(4538),
    [sym_preproc_undef] = STATE(4538),
    [anon_sym_SEMI] = ACTIONS(6324),
    [anon_sym_LBRACK] = ACTIONS(5778),
    [anon_sym_COMMA] = ACTIONS(6324),
    [anon_sym_RBRACK] = ACTIONS(6324),
    [anon_sym_LPAREN] = ACTIONS(5759),
    [anon_sym_RPAREN] = ACTIONS(6324),
    [anon_sym_RBRACE] = ACTIONS(6324),
    [anon_sym_LT] = ACTIONS(6410),
    [anon_sym_GT] = ACTIONS(6410),
    [anon_sym_in] = ACTIONS(6326),
    [anon_sym_QMARK] = ACTIONS(6412),
    [anon_sym_BANG] = ACTIONS(5780),
    [anon_sym_PLUS_PLUS] = ACTIONS(5782),
    [anon_sym_DASH_DASH] = ACTIONS(5782),
    [anon_sym_PLUS] = ACTIONS(6414),
    [anon_sym_DASH] = ACTIONS(6414),
    [anon_sym_STAR] = ACTIONS(6416),
    [anon_sym_SLASH] = ACTIONS(6418),
    [anon_sym_PERCENT] = ACTIONS(6416),
    [anon_sym_CARET] = ACTIONS(6420),
    [anon_sym_PIPE] = ACTIONS(6422),
    [anon_sym_AMP] = ACTIONS(6424),
    [anon_sym_LT_LT] = ACTIONS(6426),
    [anon_sym_GT_GT] = ACTIONS(6428),
    [anon_sym_GT_GT_GT] = ACTIONS(6426),
    [anon_sym_EQ_EQ] = ACTIONS(6430),
    [anon_sym_BANG_EQ] = ACTIONS(6430),
    [anon_sym_GT_EQ] = ACTIONS(6432),
    [anon_sym_LT_EQ] = ACTIONS(6432),
    [anon_sym_DOT] = ACTIONS(4634),
    [anon_sym_switch] = ACTIONS(6434),
    [anon_sym_DOT_DOT] = ACTIONS(6436),
    [anon_sym_and] = ACTIONS(6324),
    [anon_sym_or] = ACTIONS(6324),
    [anon_sym_AMP_AMP] = ACTIONS(6438),
    [anon_sym_PIPE_PIPE] = ACTIONS(6440),
    [anon_sym_QMARK_QMARK] = ACTIONS(6442),
    [anon_sym_into] = ACTIONS(6324),
    [anon_sym_as] = ACTIONS(6444),
    [anon_sym_is] = ACTIONS(6446),
    [anon_sym_DASH_GT] = ACTIONS(4636),
    [anon_sym_with] = ACTIONS(6448),
    [aux_sym_preproc_if_token3] = ACTIONS(6324),
    [aux_sym_preproc_else_token1] = ACTIONS(6324),
    [aux_sym_preproc_elif_token1] = ACTIONS(6324),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4539] = {
    [sym_argument_list] = STATE(4044),
    [sym_bracketed_argument_list] = STATE(3189),
    [sym_preproc_region] = STATE(4539),
    [sym_preproc_endregion] = STATE(4539),
    [sym_preproc_line] = STATE(4539),
    [sym_preproc_pragma] = STATE(4539),
    [sym_preproc_nullable] = STATE(4539),
    [sym_preproc_error] = STATE(4539),
    [sym_preproc_warning] = STATE(4539),
    [sym_preproc_define] = STATE(4539),
    [sym_preproc_undef] = STATE(4539),
    [anon_sym_SEMI] = ACTIONS(5644),
    [anon_sym_LBRACK] = ACTIONS(5778),
    [anon_sym_COMMA] = ACTIONS(5644),
    [anon_sym_RBRACK] = ACTIONS(5644),
    [anon_sym_LPAREN] = ACTIONS(5759),
    [anon_sym_RPAREN] = ACTIONS(5644),
    [anon_sym_RBRACE] = ACTIONS(5644),
    [anon_sym_LT] = ACTIONS(6410),
    [anon_sym_GT] = ACTIONS(6410),
    [anon_sym_in] = ACTIONS(5646),
    [anon_sym_QMARK] = ACTIONS(6412),
    [anon_sym_BANG] = ACTIONS(5780),
    [anon_sym_PLUS_PLUS] = ACTIONS(5782),
    [anon_sym_DASH_DASH] = ACTIONS(5782),
    [anon_sym_PLUS] = ACTIONS(6414),
    [anon_sym_DASH] = ACTIONS(6414),
    [anon_sym_STAR] = ACTIONS(6416),
    [anon_sym_SLASH] = ACTIONS(6418),
    [anon_sym_PERCENT] = ACTIONS(6416),
    [anon_sym_CARET] = ACTIONS(6420),
    [anon_sym_PIPE] = ACTIONS(6422),
    [anon_sym_AMP] = ACTIONS(6424),
    [anon_sym_LT_LT] = ACTIONS(6426),
    [anon_sym_GT_GT] = ACTIONS(6428),
    [anon_sym_GT_GT_GT] = ACTIONS(6426),
    [anon_sym_EQ_EQ] = ACTIONS(6430),
    [anon_sym_BANG_EQ] = ACTIONS(6430),
    [anon_sym_GT_EQ] = ACTIONS(6432),
    [anon_sym_LT_EQ] = ACTIONS(6432),
    [anon_sym_DOT] = ACTIONS(4634),
    [anon_sym_switch] = ACTIONS(6434),
    [anon_sym_DOT_DOT] = ACTIONS(6436),
    [anon_sym_and] = ACTIONS(5644),
    [anon_sym_or] = ACTIONS(5644),
    [anon_sym_AMP_AMP] = ACTIONS(6438),
    [anon_sym_PIPE_PIPE] = ACTIONS(6440),
    [anon_sym_QMARK_QMARK] = ACTIONS(6442),
    [anon_sym_into] = ACTIONS(5644),
    [anon_sym_as] = ACTIONS(6444),
    [anon_sym_is] = ACTIONS(6446),
    [anon_sym_DASH_GT] = ACTIONS(4636),
    [anon_sym_with] = ACTIONS(6448),
    [aux_sym_preproc_if_token3] = ACTIONS(5644),
    [aux_sym_preproc_else_token1] = ACTIONS(5644),
    [aux_sym_preproc_elif_token1] = ACTIONS(5644),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4540] = {
    [sym__name] = STATE(8163),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_implicit_type] = STATE(9513),
    [sym_array_type] = STATE(8610),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(8611),
    [sym_pointer_type] = STATE(8611),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(8611),
    [sym_function_pointer_parameter] = STATE(9589),
    [sym__ref_base_type] = STATE(9629),
    [sym_tuple_type] = STATE(8341),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4540),
    [sym_preproc_endregion] = STATE(4540),
    [sym_preproc_line] = STATE(4540),
    [sym_preproc_pragma] = STATE(4540),
    [sym_preproc_nullable] = STATE(4540),
    [sym_preproc_error] = STATE(4540),
    [sym_preproc_warning] = STATE(4540),
    [sym_preproc_define] = STATE(4540),
    [sym_preproc_undef] = STATE(4540),
    [aux_sym_function_pointer_type_repeat1] = STATE(4540),
    [sym__identifier_token] = ACTIONS(6519),
    [anon_sym_alias] = ACTIONS(6522),
    [anon_sym_global] = ACTIONS(6522),
    [anon_sym_LPAREN] = ACTIONS(6525),
    [anon_sym_ref] = ACTIONS(6528),
    [anon_sym_delegate] = ACTIONS(6531),
    [anon_sym_file] = ACTIONS(6522),
    [anon_sym_in] = ACTIONS(6528),
    [anon_sym_out] = ACTIONS(6528),
    [anon_sym_where] = ACTIONS(6522),
    [anon_sym_notnull] = ACTIONS(6522),
    [anon_sym_unmanaged] = ACTIONS(6522),
    [anon_sym_scoped] = ACTIONS(6522),
    [anon_sym_var] = ACTIONS(6534),
    [sym_predefined_type] = ACTIONS(6537),
    [anon_sym_yield] = ACTIONS(6522),
    [anon_sym_when] = ACTIONS(6522),
    [anon_sym_from] = ACTIONS(6522),
    [anon_sym_into] = ACTIONS(6522),
    [anon_sym_join] = ACTIONS(6522),
    [anon_sym_on] = ACTIONS(6522),
    [anon_sym_equals] = ACTIONS(6522),
    [anon_sym_let] = ACTIONS(6522),
    [anon_sym_orderby] = ACTIONS(6522),
    [anon_sym_ascending] = ACTIONS(6522),
    [anon_sym_descending] = ACTIONS(6522),
    [anon_sym_group] = ACTIONS(6522),
    [anon_sym_by] = ACTIONS(6522),
    [anon_sym_select] = ACTIONS(6522),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4541] = {
    [sym_preproc_region] = STATE(4541),
    [sym_preproc_endregion] = STATE(4541),
    [sym_preproc_line] = STATE(4541),
    [sym_preproc_pragma] = STATE(4541),
    [sym_preproc_nullable] = STATE(4541),
    [sym_preproc_error] = STATE(4541),
    [sym_preproc_warning] = STATE(4541),
    [sym_preproc_define] = STATE(4541),
    [sym_preproc_undef] = STATE(4541),
    [anon_sym_EQ] = ACTIONS(6540),
    [anon_sym_LBRACK] = ACTIONS(5286),
    [anon_sym_LPAREN] = ACTIONS(5286),
    [anon_sym_LT] = ACTIONS(5288),
    [anon_sym_GT] = ACTIONS(5288),
    [anon_sym_QMARK] = ACTIONS(5288),
    [anon_sym_BANG] = ACTIONS(5288),
    [anon_sym_PLUS_PLUS] = ACTIONS(5286),
    [anon_sym_DASH_DASH] = ACTIONS(5286),
    [anon_sym_PLUS] = ACTIONS(5288),
    [anon_sym_DASH] = ACTIONS(5288),
    [anon_sym_STAR] = ACTIONS(5288),
    [anon_sym_SLASH] = ACTIONS(5288),
    [anon_sym_PERCENT] = ACTIONS(5288),
    [anon_sym_CARET] = ACTIONS(5288),
    [anon_sym_PIPE] = ACTIONS(5288),
    [anon_sym_AMP] = ACTIONS(5288),
    [anon_sym_LT_LT] = ACTIONS(5288),
    [anon_sym_GT_GT] = ACTIONS(5288),
    [anon_sym_GT_GT_GT] = ACTIONS(5288),
    [anon_sym_EQ_EQ] = ACTIONS(5286),
    [anon_sym_BANG_EQ] = ACTIONS(5286),
    [anon_sym_GT_EQ] = ACTIONS(5286),
    [anon_sym_LT_EQ] = ACTIONS(5286),
    [anon_sym_DOT] = ACTIONS(5288),
    [anon_sym_switch] = ACTIONS(5286),
    [anon_sym_DOT_DOT] = ACTIONS(5286),
    [anon_sym_PLUS_EQ] = ACTIONS(6542),
    [anon_sym_DASH_EQ] = ACTIONS(6542),
    [anon_sym_STAR_EQ] = ACTIONS(6542),
    [anon_sym_SLASH_EQ] = ACTIONS(6542),
    [anon_sym_PERCENT_EQ] = ACTIONS(6542),
    [anon_sym_AMP_EQ] = ACTIONS(6542),
    [anon_sym_CARET_EQ] = ACTIONS(6542),
    [anon_sym_PIPE_EQ] = ACTIONS(6542),
    [anon_sym_LT_LT_EQ] = ACTIONS(6542),
    [anon_sym_GT_GT_EQ] = ACTIONS(6542),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(6542),
    [anon_sym_QMARK_QMARK_EQ] = ACTIONS(6542),
    [anon_sym_AMP_AMP] = ACTIONS(5286),
    [anon_sym_PIPE_PIPE] = ACTIONS(5286),
    [anon_sym_QMARK_QMARK] = ACTIONS(5288),
    [anon_sym_on] = ACTIONS(5286),
    [anon_sym_as] = ACTIONS(5286),
    [anon_sym_is] = ACTIONS(5286),
    [anon_sym_DASH_GT] = ACTIONS(5286),
    [anon_sym_with] = ACTIONS(5286),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4542] = {
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(6020),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4542),
    [sym_preproc_endregion] = STATE(4542),
    [sym_preproc_line] = STATE(4542),
    [sym_preproc_pragma] = STATE(4542),
    [sym_preproc_nullable] = STATE(4542),
    [sym_preproc_error] = STATE(4542),
    [sym_preproc_warning] = STATE(4542),
    [sym_preproc_define] = STATE(4542),
    [sym_preproc_undef] = STATE(4542),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_struct] = ACTIONS(6544),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_readonly] = ACTIONS(2767),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4543] = {
    [sym_argument_list] = STATE(4044),
    [sym_bracketed_argument_list] = STATE(3189),
    [sym_preproc_region] = STATE(4543),
    [sym_preproc_endregion] = STATE(4543),
    [sym_preproc_line] = STATE(4543),
    [sym_preproc_pragma] = STATE(4543),
    [sym_preproc_nullable] = STATE(4543),
    [sym_preproc_error] = STATE(4543),
    [sym_preproc_warning] = STATE(4543),
    [sym_preproc_define] = STATE(4543),
    [sym_preproc_undef] = STATE(4543),
    [anon_sym_SEMI] = ACTIONS(6342),
    [anon_sym_LBRACK] = ACTIONS(5778),
    [anon_sym_COMMA] = ACTIONS(6342),
    [anon_sym_RBRACK] = ACTIONS(6342),
    [anon_sym_LPAREN] = ACTIONS(5759),
    [anon_sym_RPAREN] = ACTIONS(6342),
    [anon_sym_RBRACE] = ACTIONS(6342),
    [anon_sym_LT] = ACTIONS(6410),
    [anon_sym_GT] = ACTIONS(6410),
    [anon_sym_in] = ACTIONS(6344),
    [anon_sym_QMARK] = ACTIONS(6344),
    [anon_sym_BANG] = ACTIONS(5780),
    [anon_sym_PLUS_PLUS] = ACTIONS(5782),
    [anon_sym_DASH_DASH] = ACTIONS(5782),
    [anon_sym_PLUS] = ACTIONS(6414),
    [anon_sym_DASH] = ACTIONS(6414),
    [anon_sym_STAR] = ACTIONS(6416),
    [anon_sym_SLASH] = ACTIONS(6418),
    [anon_sym_PERCENT] = ACTIONS(6416),
    [anon_sym_CARET] = ACTIONS(6342),
    [anon_sym_PIPE] = ACTIONS(6344),
    [anon_sym_AMP] = ACTIONS(6344),
    [anon_sym_LT_LT] = ACTIONS(6426),
    [anon_sym_GT_GT] = ACTIONS(6428),
    [anon_sym_GT_GT_GT] = ACTIONS(6426),
    [anon_sym_EQ_EQ] = ACTIONS(6342),
    [anon_sym_BANG_EQ] = ACTIONS(6342),
    [anon_sym_GT_EQ] = ACTIONS(6432),
    [anon_sym_LT_EQ] = ACTIONS(6432),
    [anon_sym_DOT] = ACTIONS(4634),
    [anon_sym_switch] = ACTIONS(6434),
    [anon_sym_DOT_DOT] = ACTIONS(6436),
    [anon_sym_and] = ACTIONS(6342),
    [anon_sym_or] = ACTIONS(6342),
    [anon_sym_AMP_AMP] = ACTIONS(6342),
    [anon_sym_PIPE_PIPE] = ACTIONS(6342),
    [anon_sym_QMARK_QMARK] = ACTIONS(6342),
    [anon_sym_into] = ACTIONS(6342),
    [anon_sym_as] = ACTIONS(6444),
    [anon_sym_is] = ACTIONS(6446),
    [anon_sym_DASH_GT] = ACTIONS(4636),
    [anon_sym_with] = ACTIONS(6448),
    [aux_sym_preproc_if_token3] = ACTIONS(6342),
    [aux_sym_preproc_else_token1] = ACTIONS(6342),
    [aux_sym_preproc_elif_token1] = ACTIONS(6342),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4544] = {
    [sym_argument_list] = STATE(4044),
    [sym_bracketed_argument_list] = STATE(3189),
    [sym_preproc_region] = STATE(4544),
    [sym_preproc_endregion] = STATE(4544),
    [sym_preproc_line] = STATE(4544),
    [sym_preproc_pragma] = STATE(4544),
    [sym_preproc_nullable] = STATE(4544),
    [sym_preproc_error] = STATE(4544),
    [sym_preproc_warning] = STATE(4544),
    [sym_preproc_define] = STATE(4544),
    [sym_preproc_undef] = STATE(4544),
    [anon_sym_SEMI] = ACTIONS(5416),
    [anon_sym_LBRACK] = ACTIONS(5778),
    [anon_sym_COMMA] = ACTIONS(5416),
    [anon_sym_RBRACK] = ACTIONS(5416),
    [anon_sym_LPAREN] = ACTIONS(5759),
    [anon_sym_RPAREN] = ACTIONS(5416),
    [anon_sym_RBRACE] = ACTIONS(5416),
    [anon_sym_LT] = ACTIONS(6410),
    [anon_sym_GT] = ACTIONS(6410),
    [anon_sym_in] = ACTIONS(5418),
    [anon_sym_QMARK] = ACTIONS(6412),
    [anon_sym_BANG] = ACTIONS(5780),
    [anon_sym_PLUS_PLUS] = ACTIONS(5782),
    [anon_sym_DASH_DASH] = ACTIONS(5782),
    [anon_sym_PLUS] = ACTIONS(6414),
    [anon_sym_DASH] = ACTIONS(6414),
    [anon_sym_STAR] = ACTIONS(6416),
    [anon_sym_SLASH] = ACTIONS(6418),
    [anon_sym_PERCENT] = ACTIONS(6416),
    [anon_sym_CARET] = ACTIONS(6420),
    [anon_sym_PIPE] = ACTIONS(6422),
    [anon_sym_AMP] = ACTIONS(6424),
    [anon_sym_LT_LT] = ACTIONS(6426),
    [anon_sym_GT_GT] = ACTIONS(6428),
    [anon_sym_GT_GT_GT] = ACTIONS(6426),
    [anon_sym_EQ_EQ] = ACTIONS(6430),
    [anon_sym_BANG_EQ] = ACTIONS(6430),
    [anon_sym_GT_EQ] = ACTIONS(6432),
    [anon_sym_LT_EQ] = ACTIONS(6432),
    [anon_sym_DOT] = ACTIONS(4634),
    [anon_sym_switch] = ACTIONS(6434),
    [anon_sym_DOT_DOT] = ACTIONS(6436),
    [anon_sym_and] = ACTIONS(5416),
    [anon_sym_or] = ACTIONS(5416),
    [anon_sym_AMP_AMP] = ACTIONS(6438),
    [anon_sym_PIPE_PIPE] = ACTIONS(6440),
    [anon_sym_QMARK_QMARK] = ACTIONS(6442),
    [anon_sym_into] = ACTIONS(5416),
    [anon_sym_as] = ACTIONS(6444),
    [anon_sym_is] = ACTIONS(6446),
    [anon_sym_DASH_GT] = ACTIONS(4636),
    [anon_sym_with] = ACTIONS(6448),
    [aux_sym_preproc_if_token3] = ACTIONS(5416),
    [aux_sym_preproc_else_token1] = ACTIONS(5416),
    [aux_sym_preproc_elif_token1] = ACTIONS(5416),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4545] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4545),
    [sym_preproc_endregion] = STATE(4545),
    [sym_preproc_line] = STATE(4545),
    [sym_preproc_pragma] = STATE(4545),
    [sym_preproc_nullable] = STATE(4545),
    [sym_preproc_error] = STATE(4545),
    [sym_preproc_warning] = STATE(4545),
    [sym_preproc_define] = STATE(4545),
    [sym_preproc_undef] = STATE(4545),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(6342),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(6388),
    [anon_sym_GT] = ACTIONS(6388),
    [anon_sym_where] = ACTIONS(6342),
    [anon_sym_QMARK] = ACTIONS(6344),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(6390),
    [anon_sym_DASH] = ACTIONS(6390),
    [anon_sym_STAR] = ACTIONS(6392),
    [anon_sym_SLASH] = ACTIONS(6394),
    [anon_sym_PERCENT] = ACTIONS(6392),
    [anon_sym_CARET] = ACTIONS(6342),
    [anon_sym_PIPE] = ACTIONS(6344),
    [anon_sym_AMP] = ACTIONS(6344),
    [anon_sym_LT_LT] = ACTIONS(6396),
    [anon_sym_GT_GT] = ACTIONS(6398),
    [anon_sym_GT_GT_GT] = ACTIONS(6396),
    [anon_sym_EQ_EQ] = ACTIONS(6342),
    [anon_sym_BANG_EQ] = ACTIONS(6342),
    [anon_sym_GT_EQ] = ACTIONS(6402),
    [anon_sym_LT_EQ] = ACTIONS(6402),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(6216),
    [anon_sym_DOT_DOT] = ACTIONS(6404),
    [anon_sym_and] = ACTIONS(6342),
    [anon_sym_or] = ACTIONS(6344),
    [anon_sym_AMP_AMP] = ACTIONS(6342),
    [anon_sym_PIPE_PIPE] = ACTIONS(6342),
    [anon_sym_QMARK_QMARK] = ACTIONS(6342),
    [anon_sym_from] = ACTIONS(6342),
    [anon_sym_join] = ACTIONS(6342),
    [anon_sym_let] = ACTIONS(6342),
    [anon_sym_orderby] = ACTIONS(6342),
    [anon_sym_ascending] = ACTIONS(6342),
    [anon_sym_descending] = ACTIONS(6342),
    [anon_sym_group] = ACTIONS(6342),
    [anon_sym_select] = ACTIONS(6342),
    [anon_sym_as] = ACTIONS(6406),
    [anon_sym_is] = ACTIONS(6408),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(6232),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4546] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4546),
    [sym_preproc_endregion] = STATE(4546),
    [sym_preproc_line] = STATE(4546),
    [sym_preproc_pragma] = STATE(4546),
    [sym_preproc_nullable] = STATE(4546),
    [sym_preproc_error] = STATE(4546),
    [sym_preproc_warning] = STATE(4546),
    [sym_preproc_define] = STATE(4546),
    [sym_preproc_undef] = STATE(4546),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(5584),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(6546),
    [anon_sym_GT] = ACTIONS(6546),
    [anon_sym_where] = ACTIONS(5584),
    [anon_sym_QMARK] = ACTIONS(6548),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(6550),
    [anon_sym_DASH] = ACTIONS(6550),
    [anon_sym_STAR] = ACTIONS(6552),
    [anon_sym_SLASH] = ACTIONS(6554),
    [anon_sym_PERCENT] = ACTIONS(6552),
    [anon_sym_CARET] = ACTIONS(6556),
    [anon_sym_PIPE] = ACTIONS(6558),
    [anon_sym_AMP] = ACTIONS(6560),
    [anon_sym_LT_LT] = ACTIONS(6562),
    [anon_sym_GT_GT] = ACTIONS(6564),
    [anon_sym_GT_GT_GT] = ACTIONS(6562),
    [anon_sym_EQ_EQ] = ACTIONS(6566),
    [anon_sym_BANG_EQ] = ACTIONS(6566),
    [anon_sym_GT_EQ] = ACTIONS(6568),
    [anon_sym_LT_EQ] = ACTIONS(6568),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(6216),
    [anon_sym_DOT_DOT] = ACTIONS(6570),
    [anon_sym_AMP_AMP] = ACTIONS(6572),
    [anon_sym_PIPE_PIPE] = ACTIONS(6574),
    [anon_sym_QMARK_QMARK] = ACTIONS(6576),
    [anon_sym_from] = ACTIONS(5584),
    [anon_sym_into] = ACTIONS(5584),
    [anon_sym_join] = ACTIONS(5584),
    [anon_sym_let] = ACTIONS(5584),
    [anon_sym_orderby] = ACTIONS(5584),
    [anon_sym_ascending] = ACTIONS(5584),
    [anon_sym_descending] = ACTIONS(5584),
    [anon_sym_group] = ACTIONS(5584),
    [anon_sym_select] = ACTIONS(5584),
    [anon_sym_as] = ACTIONS(6228),
    [anon_sym_is] = ACTIONS(6578),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(6232),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4547] = {
    [sym_preproc_region] = STATE(4547),
    [sym_preproc_endregion] = STATE(4547),
    [sym_preproc_line] = STATE(4547),
    [sym_preproc_pragma] = STATE(4547),
    [sym_preproc_nullable] = STATE(4547),
    [sym_preproc_error] = STATE(4547),
    [sym_preproc_warning] = STATE(4547),
    [sym_preproc_define] = STATE(4547),
    [sym_preproc_undef] = STATE(4547),
    [anon_sym_LBRACK] = ACTIONS(5865),
    [anon_sym_COMMA] = ACTIONS(5865),
    [anon_sym_LPAREN] = ACTIONS(5865),
    [anon_sym_LT] = ACTIONS(5867),
    [anon_sym_GT] = ACTIONS(5867),
    [anon_sym_where] = ACTIONS(5865),
    [anon_sym_QMARK] = ACTIONS(5867),
    [anon_sym_BANG] = ACTIONS(5867),
    [anon_sym_PLUS_PLUS] = ACTIONS(5865),
    [anon_sym_DASH_DASH] = ACTIONS(5865),
    [anon_sym_PLUS] = ACTIONS(5867),
    [anon_sym_DASH] = ACTIONS(5867),
    [anon_sym_STAR] = ACTIONS(5865),
    [anon_sym_SLASH] = ACTIONS(5867),
    [anon_sym_PERCENT] = ACTIONS(5865),
    [anon_sym_CARET] = ACTIONS(5865),
    [anon_sym_PIPE] = ACTIONS(5867),
    [anon_sym_AMP] = ACTIONS(5867),
    [anon_sym_LT_LT] = ACTIONS(5865),
    [anon_sym_GT_GT] = ACTIONS(5867),
    [anon_sym_GT_GT_GT] = ACTIONS(5865),
    [anon_sym_EQ_EQ] = ACTIONS(5865),
    [anon_sym_BANG_EQ] = ACTIONS(5865),
    [anon_sym_GT_EQ] = ACTIONS(5865),
    [anon_sym_LT_EQ] = ACTIONS(5865),
    [anon_sym_DOT] = ACTIONS(5867),
    [anon_sym_switch] = ACTIONS(5865),
    [anon_sym_DOT_DOT] = ACTIONS(5865),
    [anon_sym_and] = ACTIONS(5865),
    [anon_sym_or] = ACTIONS(5867),
    [anon_sym_AMP_AMP] = ACTIONS(5865),
    [anon_sym_PIPE_PIPE] = ACTIONS(5865),
    [anon_sym_QMARK_QMARK] = ACTIONS(5865),
    [anon_sym_from] = ACTIONS(5865),
    [anon_sym_into] = ACTIONS(5865),
    [anon_sym_join] = ACTIONS(5865),
    [anon_sym_let] = ACTIONS(5865),
    [anon_sym_orderby] = ACTIONS(5865),
    [anon_sym_ascending] = ACTIONS(5865),
    [anon_sym_descending] = ACTIONS(5865),
    [anon_sym_group] = ACTIONS(5865),
    [anon_sym_select] = ACTIONS(5865),
    [anon_sym_as] = ACTIONS(5867),
    [anon_sym_is] = ACTIONS(5865),
    [anon_sym_DASH_GT] = ACTIONS(5865),
    [anon_sym_with] = ACTIONS(5865),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4548] = {
    [sym_preproc_region] = STATE(4548),
    [sym_preproc_endregion] = STATE(4548),
    [sym_preproc_line] = STATE(4548),
    [sym_preproc_pragma] = STATE(4548),
    [sym_preproc_nullable] = STATE(4548),
    [sym_preproc_error] = STATE(4548),
    [sym_preproc_warning] = STATE(4548),
    [sym_preproc_define] = STATE(4548),
    [sym_preproc_undef] = STATE(4548),
    [anon_sym_LBRACK] = ACTIONS(4310),
    [anon_sym_COMMA] = ACTIONS(4310),
    [anon_sym_LPAREN] = ACTIONS(4310),
    [anon_sym_LT] = ACTIONS(5873),
    [anon_sym_GT] = ACTIONS(5873),
    [anon_sym_where] = ACTIONS(4310),
    [anon_sym_QMARK] = ACTIONS(5873),
    [anon_sym_BANG] = ACTIONS(5873),
    [anon_sym_PLUS_PLUS] = ACTIONS(4310),
    [anon_sym_DASH_DASH] = ACTIONS(4310),
    [anon_sym_PLUS] = ACTIONS(5873),
    [anon_sym_DASH] = ACTIONS(5873),
    [anon_sym_STAR] = ACTIONS(4310),
    [anon_sym_SLASH] = ACTIONS(5873),
    [anon_sym_PERCENT] = ACTIONS(4310),
    [anon_sym_CARET] = ACTIONS(4310),
    [anon_sym_PIPE] = ACTIONS(5873),
    [anon_sym_AMP] = ACTIONS(5873),
    [anon_sym_LT_LT] = ACTIONS(4310),
    [anon_sym_GT_GT] = ACTIONS(5873),
    [anon_sym_GT_GT_GT] = ACTIONS(4310),
    [anon_sym_EQ_EQ] = ACTIONS(4310),
    [anon_sym_BANG_EQ] = ACTIONS(4310),
    [anon_sym_GT_EQ] = ACTIONS(4310),
    [anon_sym_LT_EQ] = ACTIONS(4310),
    [anon_sym_DOT] = ACTIONS(5873),
    [anon_sym_switch] = ACTIONS(4310),
    [anon_sym_DOT_DOT] = ACTIONS(4310),
    [anon_sym_and] = ACTIONS(4310),
    [anon_sym_or] = ACTIONS(5873),
    [anon_sym_AMP_AMP] = ACTIONS(4310),
    [anon_sym_PIPE_PIPE] = ACTIONS(4310),
    [anon_sym_QMARK_QMARK] = ACTIONS(4310),
    [anon_sym_from] = ACTIONS(4310),
    [anon_sym_into] = ACTIONS(4310),
    [anon_sym_join] = ACTIONS(4310),
    [anon_sym_let] = ACTIONS(4310),
    [anon_sym_orderby] = ACTIONS(4310),
    [anon_sym_ascending] = ACTIONS(4310),
    [anon_sym_descending] = ACTIONS(4310),
    [anon_sym_group] = ACTIONS(4310),
    [anon_sym_select] = ACTIONS(4310),
    [anon_sym_as] = ACTIONS(5873),
    [anon_sym_is] = ACTIONS(4310),
    [anon_sym_DASH_GT] = ACTIONS(4310),
    [anon_sym_with] = ACTIONS(4310),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4549] = {
    [sym_preproc_region] = STATE(4549),
    [sym_preproc_endregion] = STATE(4549),
    [sym_preproc_line] = STATE(4549),
    [sym_preproc_pragma] = STATE(4549),
    [sym_preproc_nullable] = STATE(4549),
    [sym_preproc_error] = STATE(4549),
    [sym_preproc_warning] = STATE(4549),
    [sym_preproc_define] = STATE(4549),
    [sym_preproc_undef] = STATE(4549),
    [anon_sym_LBRACK] = ACTIONS(5420),
    [anon_sym_COMMA] = ACTIONS(5420),
    [anon_sym_LPAREN] = ACTIONS(5420),
    [anon_sym_LT] = ACTIONS(5422),
    [anon_sym_GT] = ACTIONS(5422),
    [anon_sym_where] = ACTIONS(5420),
    [anon_sym_QMARK] = ACTIONS(5422),
    [anon_sym_BANG] = ACTIONS(5422),
    [anon_sym_PLUS_PLUS] = ACTIONS(5420),
    [anon_sym_DASH_DASH] = ACTIONS(5420),
    [anon_sym_PLUS] = ACTIONS(5422),
    [anon_sym_DASH] = ACTIONS(5422),
    [anon_sym_STAR] = ACTIONS(5420),
    [anon_sym_SLASH] = ACTIONS(5422),
    [anon_sym_PERCENT] = ACTIONS(5420),
    [anon_sym_CARET] = ACTIONS(5420),
    [anon_sym_PIPE] = ACTIONS(5422),
    [anon_sym_AMP] = ACTIONS(5422),
    [anon_sym_LT_LT] = ACTIONS(5420),
    [anon_sym_GT_GT] = ACTIONS(5422),
    [anon_sym_GT_GT_GT] = ACTIONS(5420),
    [anon_sym_EQ_EQ] = ACTIONS(5420),
    [anon_sym_BANG_EQ] = ACTIONS(5420),
    [anon_sym_GT_EQ] = ACTIONS(5420),
    [anon_sym_LT_EQ] = ACTIONS(5420),
    [anon_sym_DOT] = ACTIONS(5422),
    [anon_sym_switch] = ACTIONS(5420),
    [anon_sym_DOT_DOT] = ACTIONS(5420),
    [anon_sym_and] = ACTIONS(5420),
    [anon_sym_or] = ACTIONS(5422),
    [anon_sym_AMP_AMP] = ACTIONS(5420),
    [anon_sym_PIPE_PIPE] = ACTIONS(5420),
    [anon_sym_QMARK_QMARK] = ACTIONS(5420),
    [anon_sym_from] = ACTIONS(5420),
    [anon_sym_into] = ACTIONS(5420),
    [anon_sym_join] = ACTIONS(5420),
    [anon_sym_let] = ACTIONS(5420),
    [anon_sym_orderby] = ACTIONS(5420),
    [anon_sym_ascending] = ACTIONS(5420),
    [anon_sym_descending] = ACTIONS(5420),
    [anon_sym_group] = ACTIONS(5420),
    [anon_sym_select] = ACTIONS(5420),
    [anon_sym_as] = ACTIONS(5422),
    [anon_sym_is] = ACTIONS(5420),
    [anon_sym_DASH_GT] = ACTIONS(5420),
    [anon_sym_with] = ACTIONS(5420),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4550] = {
    [sym_preproc_region] = STATE(4550),
    [sym_preproc_endregion] = STATE(4550),
    [sym_preproc_line] = STATE(4550),
    [sym_preproc_pragma] = STATE(4550),
    [sym_preproc_nullable] = STATE(4550),
    [sym_preproc_error] = STATE(4550),
    [sym_preproc_warning] = STATE(4550),
    [sym_preproc_define] = STATE(4550),
    [sym_preproc_undef] = STATE(4550),
    [sym__identifier_token] = ACTIONS(4042),
    [anon_sym_extern] = ACTIONS(4042),
    [anon_sym_alias] = ACTIONS(4042),
    [anon_sym_global] = ACTIONS(4042),
    [anon_sym_unsafe] = ACTIONS(4042),
    [anon_sym_static] = ACTIONS(4042),
    [anon_sym_LPAREN] = ACTIONS(5901),
    [anon_sym_ref] = ACTIONS(4042),
    [anon_sym_delegate] = ACTIONS(4042),
    [anon_sym_abstract] = ACTIONS(4042),
    [anon_sym_async] = ACTIONS(4042),
    [anon_sym_const] = ACTIONS(4042),
    [anon_sym_file] = ACTIONS(4042),
    [anon_sym_fixed] = ACTIONS(4042),
    [anon_sym_internal] = ACTIONS(4042),
    [anon_sym_new] = ACTIONS(4042),
    [anon_sym_override] = ACTIONS(4042),
    [anon_sym_partial] = ACTIONS(4042),
    [anon_sym_private] = ACTIONS(4042),
    [anon_sym_protected] = ACTIONS(4042),
    [anon_sym_public] = ACTIONS(4042),
    [anon_sym_readonly] = ACTIONS(4042),
    [anon_sym_required] = ACTIONS(4042),
    [anon_sym_sealed] = ACTIONS(4042),
    [anon_sym_virtual] = ACTIONS(4042),
    [anon_sym_volatile] = ACTIONS(4042),
    [anon_sym_where] = ACTIONS(4042),
    [anon_sym_notnull] = ACTIONS(4042),
    [anon_sym_unmanaged] = ACTIONS(4042),
    [anon_sym_scoped] = ACTIONS(4042),
    [anon_sym_var] = ACTIONS(4042),
    [sym_predefined_type] = ACTIONS(4042),
    [anon_sym_yield] = ACTIONS(4042),
    [anon_sym_when] = ACTIONS(4042),
    [anon_sym_from] = ACTIONS(4042),
    [anon_sym_into] = ACTIONS(4042),
    [anon_sym_join] = ACTIONS(4042),
    [anon_sym_on] = ACTIONS(4042),
    [anon_sym_equals] = ACTIONS(4042),
    [anon_sym_let] = ACTIONS(4042),
    [anon_sym_orderby] = ACTIONS(4042),
    [anon_sym_ascending] = ACTIONS(4042),
    [anon_sym_descending] = ACTIONS(4042),
    [anon_sym_group] = ACTIONS(4042),
    [anon_sym_by] = ACTIONS(4042),
    [anon_sym_select] = ACTIONS(4042),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4551] = {
    [sym_preproc_region] = STATE(4551),
    [sym_preproc_endregion] = STATE(4551),
    [sym_preproc_line] = STATE(4551),
    [sym_preproc_pragma] = STATE(4551),
    [sym_preproc_nullable] = STATE(4551),
    [sym_preproc_error] = STATE(4551),
    [sym_preproc_warning] = STATE(4551),
    [sym_preproc_define] = STATE(4551),
    [sym_preproc_undef] = STATE(4551),
    [anon_sym_LBRACK] = ACTIONS(5970),
    [anon_sym_COMMA] = ACTIONS(5970),
    [anon_sym_LPAREN] = ACTIONS(5970),
    [anon_sym_LT] = ACTIONS(5972),
    [anon_sym_GT] = ACTIONS(5972),
    [anon_sym_where] = ACTIONS(5970),
    [anon_sym_QMARK] = ACTIONS(5972),
    [anon_sym_BANG] = ACTIONS(5972),
    [anon_sym_PLUS_PLUS] = ACTIONS(5970),
    [anon_sym_DASH_DASH] = ACTIONS(5970),
    [anon_sym_PLUS] = ACTIONS(5972),
    [anon_sym_DASH] = ACTIONS(5972),
    [anon_sym_STAR] = ACTIONS(5970),
    [anon_sym_SLASH] = ACTIONS(5972),
    [anon_sym_PERCENT] = ACTIONS(5970),
    [anon_sym_CARET] = ACTIONS(5970),
    [anon_sym_PIPE] = ACTIONS(5972),
    [anon_sym_AMP] = ACTIONS(5972),
    [anon_sym_LT_LT] = ACTIONS(5970),
    [anon_sym_GT_GT] = ACTIONS(5972),
    [anon_sym_GT_GT_GT] = ACTIONS(5970),
    [anon_sym_EQ_EQ] = ACTIONS(5970),
    [anon_sym_BANG_EQ] = ACTIONS(5970),
    [anon_sym_GT_EQ] = ACTIONS(5970),
    [anon_sym_LT_EQ] = ACTIONS(5970),
    [anon_sym_DOT] = ACTIONS(5972),
    [anon_sym_switch] = ACTIONS(5970),
    [anon_sym_DOT_DOT] = ACTIONS(5970),
    [anon_sym_and] = ACTIONS(5970),
    [anon_sym_or] = ACTIONS(5972),
    [anon_sym_AMP_AMP] = ACTIONS(5970),
    [anon_sym_PIPE_PIPE] = ACTIONS(5970),
    [anon_sym_QMARK_QMARK] = ACTIONS(5970),
    [anon_sym_from] = ACTIONS(5970),
    [anon_sym_into] = ACTIONS(5970),
    [anon_sym_join] = ACTIONS(5970),
    [anon_sym_let] = ACTIONS(5970),
    [anon_sym_orderby] = ACTIONS(5970),
    [anon_sym_ascending] = ACTIONS(5970),
    [anon_sym_descending] = ACTIONS(5970),
    [anon_sym_group] = ACTIONS(5970),
    [anon_sym_select] = ACTIONS(5970),
    [anon_sym_as] = ACTIONS(5972),
    [anon_sym_is] = ACTIONS(5970),
    [anon_sym_DASH_GT] = ACTIONS(5970),
    [anon_sym_with] = ACTIONS(5970),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4552] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4552),
    [sym_preproc_endregion] = STATE(4552),
    [sym_preproc_line] = STATE(4552),
    [sym_preproc_pragma] = STATE(4552),
    [sym_preproc_nullable] = STATE(4552),
    [sym_preproc_error] = STATE(4552),
    [sym_preproc_warning] = STATE(4552),
    [sym_preproc_define] = STATE(4552),
    [sym_preproc_undef] = STATE(4552),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(6190),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(6546),
    [anon_sym_GT] = ACTIONS(6546),
    [anon_sym_where] = ACTIONS(6190),
    [anon_sym_QMARK] = ACTIONS(6548),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(6550),
    [anon_sym_DASH] = ACTIONS(6550),
    [anon_sym_STAR] = ACTIONS(6552),
    [anon_sym_SLASH] = ACTIONS(6554),
    [anon_sym_PERCENT] = ACTIONS(6552),
    [anon_sym_CARET] = ACTIONS(6556),
    [anon_sym_PIPE] = ACTIONS(6558),
    [anon_sym_AMP] = ACTIONS(6560),
    [anon_sym_LT_LT] = ACTIONS(6562),
    [anon_sym_GT_GT] = ACTIONS(6564),
    [anon_sym_GT_GT_GT] = ACTIONS(6562),
    [anon_sym_EQ_EQ] = ACTIONS(6566),
    [anon_sym_BANG_EQ] = ACTIONS(6566),
    [anon_sym_GT_EQ] = ACTIONS(6568),
    [anon_sym_LT_EQ] = ACTIONS(6568),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(6216),
    [anon_sym_DOT_DOT] = ACTIONS(6570),
    [anon_sym_AMP_AMP] = ACTIONS(6572),
    [anon_sym_PIPE_PIPE] = ACTIONS(6574),
    [anon_sym_QMARK_QMARK] = ACTIONS(6576),
    [anon_sym_from] = ACTIONS(6190),
    [anon_sym_into] = ACTIONS(6190),
    [anon_sym_join] = ACTIONS(6190),
    [anon_sym_let] = ACTIONS(6190),
    [anon_sym_orderby] = ACTIONS(6190),
    [anon_sym_ascending] = ACTIONS(6190),
    [anon_sym_descending] = ACTIONS(6190),
    [anon_sym_group] = ACTIONS(6190),
    [anon_sym_select] = ACTIONS(6190),
    [anon_sym_as] = ACTIONS(6228),
    [anon_sym_is] = ACTIONS(6578),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(6232),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4553] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4553),
    [sym_preproc_endregion] = STATE(4553),
    [sym_preproc_line] = STATE(4553),
    [sym_preproc_pragma] = STATE(4553),
    [sym_preproc_nullable] = STATE(4553),
    [sym_preproc_error] = STATE(4553),
    [sym_preproc_warning] = STATE(4553),
    [sym_preproc_define] = STATE(4553),
    [sym_preproc_undef] = STATE(4553),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(1227),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(1229),
    [anon_sym_GT] = ACTIONS(1229),
    [anon_sym_where] = ACTIONS(1227),
    [anon_sym_QMARK] = ACTIONS(1229),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(1229),
    [anon_sym_DASH] = ACTIONS(1229),
    [anon_sym_STAR] = ACTIONS(1227),
    [anon_sym_SLASH] = ACTIONS(1229),
    [anon_sym_PERCENT] = ACTIONS(1227),
    [anon_sym_CARET] = ACTIONS(1227),
    [anon_sym_PIPE] = ACTIONS(1229),
    [anon_sym_AMP] = ACTIONS(1229),
    [anon_sym_LT_LT] = ACTIONS(1227),
    [anon_sym_GT_GT] = ACTIONS(1229),
    [anon_sym_GT_GT_GT] = ACTIONS(1227),
    [anon_sym_EQ_EQ] = ACTIONS(1227),
    [anon_sym_BANG_EQ] = ACTIONS(1227),
    [anon_sym_GT_EQ] = ACTIONS(1227),
    [anon_sym_LT_EQ] = ACTIONS(1227),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(1227),
    [anon_sym_DOT_DOT] = ACTIONS(6570),
    [anon_sym_AMP_AMP] = ACTIONS(1227),
    [anon_sym_PIPE_PIPE] = ACTIONS(1227),
    [anon_sym_QMARK_QMARK] = ACTIONS(1227),
    [anon_sym_from] = ACTIONS(1227),
    [anon_sym_into] = ACTIONS(1227),
    [anon_sym_join] = ACTIONS(1227),
    [anon_sym_let] = ACTIONS(1227),
    [anon_sym_orderby] = ACTIONS(1227),
    [anon_sym_ascending] = ACTIONS(1227),
    [anon_sym_descending] = ACTIONS(1227),
    [anon_sym_group] = ACTIONS(1227),
    [anon_sym_select] = ACTIONS(1227),
    [anon_sym_as] = ACTIONS(1229),
    [anon_sym_is] = ACTIONS(1227),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(1227),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4554] = {
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7206),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8837),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4554),
    [sym_preproc_endregion] = STATE(4554),
    [sym_preproc_line] = STATE(4554),
    [sym_preproc_pragma] = STATE(4554),
    [sym_preproc_nullable] = STATE(4554),
    [sym_preproc_error] = STATE(4554),
    [sym_preproc_warning] = STATE(4554),
    [sym_preproc_define] = STATE(4554),
    [sym_preproc_undef] = STATE(4554),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(4112),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(6580),
    [anon_sym_var] = ACTIONS(6582),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4555] = {
    [sym_preproc_region] = STATE(4555),
    [sym_preproc_endregion] = STATE(4555),
    [sym_preproc_line] = STATE(4555),
    [sym_preproc_pragma] = STATE(4555),
    [sym_preproc_nullable] = STATE(4555),
    [sym_preproc_error] = STATE(4555),
    [sym_preproc_warning] = STATE(4555),
    [sym_preproc_define] = STATE(4555),
    [sym_preproc_undef] = STATE(4555),
    [anon_sym_LBRACK] = ACTIONS(5913),
    [anon_sym_COMMA] = ACTIONS(5913),
    [anon_sym_LPAREN] = ACTIONS(5913),
    [anon_sym_LT] = ACTIONS(5915),
    [anon_sym_GT] = ACTIONS(5915),
    [anon_sym_where] = ACTIONS(5913),
    [anon_sym_QMARK] = ACTIONS(5915),
    [anon_sym_BANG] = ACTIONS(5915),
    [anon_sym_PLUS_PLUS] = ACTIONS(5913),
    [anon_sym_DASH_DASH] = ACTIONS(5913),
    [anon_sym_PLUS] = ACTIONS(5915),
    [anon_sym_DASH] = ACTIONS(5915),
    [anon_sym_STAR] = ACTIONS(5913),
    [anon_sym_SLASH] = ACTIONS(5915),
    [anon_sym_PERCENT] = ACTIONS(5913),
    [anon_sym_CARET] = ACTIONS(5913),
    [anon_sym_PIPE] = ACTIONS(5915),
    [anon_sym_AMP] = ACTIONS(5915),
    [anon_sym_LT_LT] = ACTIONS(5913),
    [anon_sym_GT_GT] = ACTIONS(5915),
    [anon_sym_GT_GT_GT] = ACTIONS(5913),
    [anon_sym_EQ_EQ] = ACTIONS(5913),
    [anon_sym_BANG_EQ] = ACTIONS(5913),
    [anon_sym_GT_EQ] = ACTIONS(5913),
    [anon_sym_LT_EQ] = ACTIONS(5913),
    [anon_sym_DOT] = ACTIONS(5915),
    [anon_sym_switch] = ACTIONS(5913),
    [anon_sym_DOT_DOT] = ACTIONS(5913),
    [anon_sym_and] = ACTIONS(5913),
    [anon_sym_or] = ACTIONS(5915),
    [anon_sym_AMP_AMP] = ACTIONS(5913),
    [anon_sym_PIPE_PIPE] = ACTIONS(5913),
    [anon_sym_QMARK_QMARK] = ACTIONS(5913),
    [anon_sym_from] = ACTIONS(5913),
    [anon_sym_into] = ACTIONS(5913),
    [anon_sym_join] = ACTIONS(5913),
    [anon_sym_let] = ACTIONS(5913),
    [anon_sym_orderby] = ACTIONS(5913),
    [anon_sym_ascending] = ACTIONS(5913),
    [anon_sym_descending] = ACTIONS(5913),
    [anon_sym_group] = ACTIONS(5913),
    [anon_sym_select] = ACTIONS(5913),
    [anon_sym_as] = ACTIONS(5915),
    [anon_sym_is] = ACTIONS(5913),
    [anon_sym_DASH_GT] = ACTIONS(5913),
    [anon_sym_with] = ACTIONS(5913),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4556] = {
    [sym_preproc_region] = STATE(4556),
    [sym_preproc_endregion] = STATE(4556),
    [sym_preproc_line] = STATE(4556),
    [sym_preproc_pragma] = STATE(4556),
    [sym_preproc_nullable] = STATE(4556),
    [sym_preproc_error] = STATE(4556),
    [sym_preproc_warning] = STATE(4556),
    [sym_preproc_define] = STATE(4556),
    [sym_preproc_undef] = STATE(4556),
    [anon_sym_LBRACK] = ACTIONS(5913),
    [anon_sym_COMMA] = ACTIONS(5913),
    [anon_sym_LPAREN] = ACTIONS(5913),
    [anon_sym_LT] = ACTIONS(5915),
    [anon_sym_GT] = ACTIONS(5915),
    [anon_sym_where] = ACTIONS(5913),
    [anon_sym_QMARK] = ACTIONS(5915),
    [anon_sym_BANG] = ACTIONS(5915),
    [anon_sym_PLUS_PLUS] = ACTIONS(5913),
    [anon_sym_DASH_DASH] = ACTIONS(5913),
    [anon_sym_PLUS] = ACTIONS(5915),
    [anon_sym_DASH] = ACTIONS(5915),
    [anon_sym_STAR] = ACTIONS(5913),
    [anon_sym_SLASH] = ACTIONS(5915),
    [anon_sym_PERCENT] = ACTIONS(5913),
    [anon_sym_CARET] = ACTIONS(5913),
    [anon_sym_PIPE] = ACTIONS(5915),
    [anon_sym_AMP] = ACTIONS(5915),
    [anon_sym_LT_LT] = ACTIONS(5913),
    [anon_sym_GT_GT] = ACTIONS(5915),
    [anon_sym_GT_GT_GT] = ACTIONS(5913),
    [anon_sym_EQ_EQ] = ACTIONS(5913),
    [anon_sym_BANG_EQ] = ACTIONS(5913),
    [anon_sym_GT_EQ] = ACTIONS(5913),
    [anon_sym_LT_EQ] = ACTIONS(5913),
    [anon_sym_DOT] = ACTIONS(5915),
    [anon_sym_switch] = ACTIONS(5913),
    [anon_sym_DOT_DOT] = ACTIONS(5913),
    [anon_sym_and] = ACTIONS(5913),
    [anon_sym_or] = ACTIONS(5915),
    [anon_sym_AMP_AMP] = ACTIONS(5913),
    [anon_sym_PIPE_PIPE] = ACTIONS(5913),
    [anon_sym_QMARK_QMARK] = ACTIONS(5913),
    [anon_sym_from] = ACTIONS(5913),
    [anon_sym_into] = ACTIONS(5913),
    [anon_sym_join] = ACTIONS(5913),
    [anon_sym_let] = ACTIONS(5913),
    [anon_sym_orderby] = ACTIONS(5913),
    [anon_sym_ascending] = ACTIONS(5913),
    [anon_sym_descending] = ACTIONS(5913),
    [anon_sym_group] = ACTIONS(5913),
    [anon_sym_select] = ACTIONS(5913),
    [anon_sym_as] = ACTIONS(5915),
    [anon_sym_is] = ACTIONS(5913),
    [anon_sym_DASH_GT] = ACTIONS(5913),
    [anon_sym_with] = ACTIONS(5913),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4557] = {
    [sym_preproc_region] = STATE(4557),
    [sym_preproc_endregion] = STATE(4557),
    [sym_preproc_line] = STATE(4557),
    [sym_preproc_pragma] = STATE(4557),
    [sym_preproc_nullable] = STATE(4557),
    [sym_preproc_error] = STATE(4557),
    [sym_preproc_warning] = STATE(4557),
    [sym_preproc_define] = STATE(4557),
    [sym_preproc_undef] = STATE(4557),
    [anon_sym_LBRACK] = ACTIONS(5964),
    [anon_sym_COMMA] = ACTIONS(5964),
    [anon_sym_LPAREN] = ACTIONS(5964),
    [anon_sym_LT] = ACTIONS(5966),
    [anon_sym_GT] = ACTIONS(5966),
    [anon_sym_where] = ACTIONS(5964),
    [anon_sym_QMARK] = ACTIONS(5966),
    [anon_sym_BANG] = ACTIONS(5966),
    [anon_sym_PLUS_PLUS] = ACTIONS(5964),
    [anon_sym_DASH_DASH] = ACTIONS(5964),
    [anon_sym_PLUS] = ACTIONS(5966),
    [anon_sym_DASH] = ACTIONS(5966),
    [anon_sym_STAR] = ACTIONS(5964),
    [anon_sym_SLASH] = ACTIONS(5966),
    [anon_sym_PERCENT] = ACTIONS(5964),
    [anon_sym_CARET] = ACTIONS(5964),
    [anon_sym_PIPE] = ACTIONS(5966),
    [anon_sym_AMP] = ACTIONS(5966),
    [anon_sym_LT_LT] = ACTIONS(5964),
    [anon_sym_GT_GT] = ACTIONS(5966),
    [anon_sym_GT_GT_GT] = ACTIONS(5964),
    [anon_sym_EQ_EQ] = ACTIONS(5964),
    [anon_sym_BANG_EQ] = ACTIONS(5964),
    [anon_sym_GT_EQ] = ACTIONS(5964),
    [anon_sym_LT_EQ] = ACTIONS(5964),
    [anon_sym_DOT] = ACTIONS(5966),
    [anon_sym_switch] = ACTIONS(5964),
    [anon_sym_DOT_DOT] = ACTIONS(5964),
    [anon_sym_and] = ACTIONS(5964),
    [anon_sym_or] = ACTIONS(5966),
    [anon_sym_AMP_AMP] = ACTIONS(5964),
    [anon_sym_PIPE_PIPE] = ACTIONS(5964),
    [anon_sym_QMARK_QMARK] = ACTIONS(5964),
    [anon_sym_from] = ACTIONS(5964),
    [anon_sym_into] = ACTIONS(5964),
    [anon_sym_join] = ACTIONS(5964),
    [anon_sym_let] = ACTIONS(5964),
    [anon_sym_orderby] = ACTIONS(5964),
    [anon_sym_ascending] = ACTIONS(5964),
    [anon_sym_descending] = ACTIONS(5964),
    [anon_sym_group] = ACTIONS(5964),
    [anon_sym_select] = ACTIONS(5964),
    [anon_sym_as] = ACTIONS(5966),
    [anon_sym_is] = ACTIONS(5964),
    [anon_sym_DASH_GT] = ACTIONS(5964),
    [anon_sym_with] = ACTIONS(5964),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4558] = {
    [sym__name] = STATE(3744),
    [sym_alias_qualified_name] = STATE(3680),
    [sym__simple_name] = STATE(3680),
    [sym_qualified_name] = STATE(3680),
    [sym_generic_name] = STATE(3648),
    [sym_type] = STATE(3731),
    [sym_implicit_type] = STATE(3707),
    [sym_array_type] = STATE(3725),
    [sym__array_base_type] = STATE(8829),
    [sym_nullable_type] = STATE(3681),
    [sym_pointer_type] = STATE(3681),
    [sym__pointer_base_type] = STATE(9538),
    [sym_function_pointer_type] = STATE(3681),
    [sym_ref_type] = STATE(3707),
    [sym_scoped_type] = STATE(3707),
    [sym_tuple_type] = STATE(3631),
    [sym_identifier] = STATE(3590),
    [sym__reserved_identifier] = STATE(3625),
    [sym_preproc_region] = STATE(4558),
    [sym_preproc_endregion] = STATE(4558),
    [sym_preproc_line] = STATE(4558),
    [sym_preproc_pragma] = STATE(4558),
    [sym_preproc_nullable] = STATE(4558),
    [sym_preproc_error] = STATE(4558),
    [sym_preproc_warning] = STATE(4558),
    [sym_preproc_define] = STATE(4558),
    [sym_preproc_undef] = STATE(4558),
    [sym__identifier_token] = ACTIONS(4349),
    [anon_sym_alias] = ACTIONS(4351),
    [anon_sym_global] = ACTIONS(4351),
    [anon_sym_LPAREN] = ACTIONS(6584),
    [anon_sym_ref] = ACTIONS(4678),
    [anon_sym_delegate] = ACTIONS(4512),
    [anon_sym_file] = ACTIONS(4351),
    [anon_sym_readonly] = ACTIONS(6586),
    [anon_sym_where] = ACTIONS(4351),
    [anon_sym_notnull] = ACTIONS(4351),
    [anon_sym_unmanaged] = ACTIONS(4351),
    [anon_sym_scoped] = ACTIONS(6360),
    [anon_sym_var] = ACTIONS(4516),
    [sym_predefined_type] = ACTIONS(4518),
    [anon_sym_yield] = ACTIONS(4351),
    [anon_sym_when] = ACTIONS(4351),
    [anon_sym_from] = ACTIONS(4351),
    [anon_sym_into] = ACTIONS(4351),
    [anon_sym_join] = ACTIONS(4351),
    [anon_sym_on] = ACTIONS(4351),
    [anon_sym_equals] = ACTIONS(4351),
    [anon_sym_let] = ACTIONS(4351),
    [anon_sym_orderby] = ACTIONS(4351),
    [anon_sym_ascending] = ACTIONS(4351),
    [anon_sym_descending] = ACTIONS(4351),
    [anon_sym_group] = ACTIONS(4351),
    [anon_sym_by] = ACTIONS(4351),
    [anon_sym_select] = ACTIONS(4351),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4559] = {
    [sym_preproc_region] = STATE(4559),
    [sym_preproc_endregion] = STATE(4559),
    [sym_preproc_line] = STATE(4559),
    [sym_preproc_pragma] = STATE(4559),
    [sym_preproc_nullable] = STATE(4559),
    [sym_preproc_error] = STATE(4559),
    [sym_preproc_warning] = STATE(4559),
    [sym_preproc_define] = STATE(4559),
    [sym_preproc_undef] = STATE(4559),
    [anon_sym_LBRACK] = ACTIONS(5883),
    [anon_sym_COMMA] = ACTIONS(4806),
    [anon_sym_LPAREN] = ACTIONS(5883),
    [anon_sym_LT] = ACTIONS(5886),
    [anon_sym_GT] = ACTIONS(5886),
    [anon_sym_where] = ACTIONS(4806),
    [anon_sym_QMARK] = ACTIONS(5886),
    [anon_sym_BANG] = ACTIONS(5886),
    [anon_sym_PLUS_PLUS] = ACTIONS(5883),
    [anon_sym_DASH_DASH] = ACTIONS(5883),
    [anon_sym_PLUS] = ACTIONS(5886),
    [anon_sym_DASH] = ACTIONS(5886),
    [anon_sym_STAR] = ACTIONS(5883),
    [anon_sym_SLASH] = ACTIONS(5886),
    [anon_sym_PERCENT] = ACTIONS(5883),
    [anon_sym_CARET] = ACTIONS(5883),
    [anon_sym_PIPE] = ACTIONS(5886),
    [anon_sym_AMP] = ACTIONS(5886),
    [anon_sym_LT_LT] = ACTIONS(5883),
    [anon_sym_GT_GT] = ACTIONS(5886),
    [anon_sym_GT_GT_GT] = ACTIONS(5883),
    [anon_sym_EQ_EQ] = ACTIONS(5883),
    [anon_sym_BANG_EQ] = ACTIONS(5883),
    [anon_sym_GT_EQ] = ACTIONS(5883),
    [anon_sym_LT_EQ] = ACTIONS(5883),
    [anon_sym_DOT] = ACTIONS(5886),
    [anon_sym_switch] = ACTIONS(5883),
    [anon_sym_DOT_DOT] = ACTIONS(5883),
    [anon_sym_and] = ACTIONS(4806),
    [anon_sym_or] = ACTIONS(4814),
    [anon_sym_AMP_AMP] = ACTIONS(5883),
    [anon_sym_PIPE_PIPE] = ACTIONS(5883),
    [anon_sym_QMARK_QMARK] = ACTIONS(5883),
    [anon_sym_from] = ACTIONS(4806),
    [anon_sym_into] = ACTIONS(4806),
    [anon_sym_join] = ACTIONS(4806),
    [anon_sym_let] = ACTIONS(4806),
    [anon_sym_orderby] = ACTIONS(4806),
    [anon_sym_ascending] = ACTIONS(4806),
    [anon_sym_descending] = ACTIONS(4806),
    [anon_sym_group] = ACTIONS(4806),
    [anon_sym_select] = ACTIONS(4806),
    [anon_sym_as] = ACTIONS(5886),
    [anon_sym_is] = ACTIONS(5883),
    [anon_sym_DASH_GT] = ACTIONS(5883),
    [anon_sym_with] = ACTIONS(5883),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4560] = {
    [sym_preproc_region] = STATE(4560),
    [sym_preproc_endregion] = STATE(4560),
    [sym_preproc_line] = STATE(4560),
    [sym_preproc_pragma] = STATE(4560),
    [sym_preproc_nullable] = STATE(4560),
    [sym_preproc_error] = STATE(4560),
    [sym_preproc_warning] = STATE(4560),
    [sym_preproc_define] = STATE(4560),
    [sym_preproc_undef] = STATE(4560),
    [anon_sym_LBRACK] = ACTIONS(5889),
    [anon_sym_COMMA] = ACTIONS(4806),
    [anon_sym_LPAREN] = ACTIONS(5889),
    [anon_sym_LT] = ACTIONS(5892),
    [anon_sym_GT] = ACTIONS(5892),
    [anon_sym_where] = ACTIONS(4806),
    [anon_sym_QMARK] = ACTIONS(5892),
    [anon_sym_BANG] = ACTIONS(5892),
    [anon_sym_PLUS_PLUS] = ACTIONS(5889),
    [anon_sym_DASH_DASH] = ACTIONS(5889),
    [anon_sym_PLUS] = ACTIONS(5892),
    [anon_sym_DASH] = ACTIONS(5892),
    [anon_sym_STAR] = ACTIONS(5889),
    [anon_sym_SLASH] = ACTIONS(5892),
    [anon_sym_PERCENT] = ACTIONS(5889),
    [anon_sym_CARET] = ACTIONS(5889),
    [anon_sym_PIPE] = ACTIONS(5892),
    [anon_sym_AMP] = ACTIONS(5892),
    [anon_sym_LT_LT] = ACTIONS(5889),
    [anon_sym_GT_GT] = ACTIONS(5892),
    [anon_sym_GT_GT_GT] = ACTIONS(5889),
    [anon_sym_EQ_EQ] = ACTIONS(5889),
    [anon_sym_BANG_EQ] = ACTIONS(5889),
    [anon_sym_GT_EQ] = ACTIONS(5889),
    [anon_sym_LT_EQ] = ACTIONS(5889),
    [anon_sym_DOT] = ACTIONS(5892),
    [anon_sym_switch] = ACTIONS(5889),
    [anon_sym_DOT_DOT] = ACTIONS(5889),
    [anon_sym_and] = ACTIONS(4806),
    [anon_sym_or] = ACTIONS(4814),
    [anon_sym_AMP_AMP] = ACTIONS(5889),
    [anon_sym_PIPE_PIPE] = ACTIONS(5889),
    [anon_sym_QMARK_QMARK] = ACTIONS(5889),
    [anon_sym_from] = ACTIONS(4806),
    [anon_sym_into] = ACTIONS(4806),
    [anon_sym_join] = ACTIONS(4806),
    [anon_sym_let] = ACTIONS(4806),
    [anon_sym_orderby] = ACTIONS(4806),
    [anon_sym_ascending] = ACTIONS(4806),
    [anon_sym_descending] = ACTIONS(4806),
    [anon_sym_group] = ACTIONS(4806),
    [anon_sym_select] = ACTIONS(4806),
    [anon_sym_as] = ACTIONS(5892),
    [anon_sym_is] = ACTIONS(5889),
    [anon_sym_DASH_GT] = ACTIONS(5889),
    [anon_sym_with] = ACTIONS(5889),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4561] = {
    [sym_preproc_region] = STATE(4561),
    [sym_preproc_endregion] = STATE(4561),
    [sym_preproc_line] = STATE(4561),
    [sym_preproc_pragma] = STATE(4561),
    [sym_preproc_nullable] = STATE(4561),
    [sym_preproc_error] = STATE(4561),
    [sym_preproc_warning] = STATE(4561),
    [sym_preproc_define] = STATE(4561),
    [sym_preproc_undef] = STATE(4561),
    [anon_sym_LBRACK] = ACTIONS(5548),
    [anon_sym_COMMA] = ACTIONS(5548),
    [anon_sym_LPAREN] = ACTIONS(5548),
    [anon_sym_LT] = ACTIONS(5550),
    [anon_sym_GT] = ACTIONS(5550),
    [anon_sym_where] = ACTIONS(5548),
    [anon_sym_QMARK] = ACTIONS(5550),
    [anon_sym_BANG] = ACTIONS(5550),
    [anon_sym_PLUS_PLUS] = ACTIONS(5548),
    [anon_sym_DASH_DASH] = ACTIONS(5548),
    [anon_sym_PLUS] = ACTIONS(5550),
    [anon_sym_DASH] = ACTIONS(5550),
    [anon_sym_STAR] = ACTIONS(5548),
    [anon_sym_SLASH] = ACTIONS(5550),
    [anon_sym_PERCENT] = ACTIONS(5548),
    [anon_sym_CARET] = ACTIONS(5548),
    [anon_sym_PIPE] = ACTIONS(5550),
    [anon_sym_AMP] = ACTIONS(5550),
    [anon_sym_LT_LT] = ACTIONS(5548),
    [anon_sym_GT_GT] = ACTIONS(5550),
    [anon_sym_GT_GT_GT] = ACTIONS(5548),
    [anon_sym_EQ_EQ] = ACTIONS(5548),
    [anon_sym_BANG_EQ] = ACTIONS(5548),
    [anon_sym_GT_EQ] = ACTIONS(5548),
    [anon_sym_LT_EQ] = ACTIONS(5548),
    [anon_sym_DOT] = ACTIONS(5550),
    [anon_sym_switch] = ACTIONS(5548),
    [anon_sym_DOT_DOT] = ACTIONS(5548),
    [anon_sym_and] = ACTIONS(5548),
    [anon_sym_or] = ACTIONS(5550),
    [anon_sym_AMP_AMP] = ACTIONS(5548),
    [anon_sym_PIPE_PIPE] = ACTIONS(5548),
    [anon_sym_QMARK_QMARK] = ACTIONS(5548),
    [anon_sym_from] = ACTIONS(5548),
    [anon_sym_into] = ACTIONS(5548),
    [anon_sym_join] = ACTIONS(5548),
    [anon_sym_let] = ACTIONS(5548),
    [anon_sym_orderby] = ACTIONS(5548),
    [anon_sym_ascending] = ACTIONS(5548),
    [anon_sym_descending] = ACTIONS(5548),
    [anon_sym_group] = ACTIONS(5548),
    [anon_sym_select] = ACTIONS(5548),
    [anon_sym_as] = ACTIONS(5550),
    [anon_sym_is] = ACTIONS(5548),
    [anon_sym_DASH_GT] = ACTIONS(5548),
    [anon_sym_with] = ACTIONS(5548),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4562] = {
    [sym_preproc_region] = STATE(4562),
    [sym_preproc_endregion] = STATE(4562),
    [sym_preproc_line] = STATE(4562),
    [sym_preproc_pragma] = STATE(4562),
    [sym_preproc_nullable] = STATE(4562),
    [sym_preproc_error] = STATE(4562),
    [sym_preproc_warning] = STATE(4562),
    [sym_preproc_define] = STATE(4562),
    [sym_preproc_undef] = STATE(4562),
    [anon_sym_LBRACK] = ACTIONS(5879),
    [anon_sym_COMMA] = ACTIONS(5879),
    [anon_sym_LPAREN] = ACTIONS(5879),
    [anon_sym_LT] = ACTIONS(5881),
    [anon_sym_GT] = ACTIONS(5881),
    [anon_sym_where] = ACTIONS(5879),
    [anon_sym_QMARK] = ACTIONS(5881),
    [anon_sym_BANG] = ACTIONS(5881),
    [anon_sym_PLUS_PLUS] = ACTIONS(5879),
    [anon_sym_DASH_DASH] = ACTIONS(5879),
    [anon_sym_PLUS] = ACTIONS(5881),
    [anon_sym_DASH] = ACTIONS(5881),
    [anon_sym_STAR] = ACTIONS(5879),
    [anon_sym_SLASH] = ACTIONS(5881),
    [anon_sym_PERCENT] = ACTIONS(5879),
    [anon_sym_CARET] = ACTIONS(5879),
    [anon_sym_PIPE] = ACTIONS(5881),
    [anon_sym_AMP] = ACTIONS(5881),
    [anon_sym_LT_LT] = ACTIONS(5879),
    [anon_sym_GT_GT] = ACTIONS(5881),
    [anon_sym_GT_GT_GT] = ACTIONS(5879),
    [anon_sym_EQ_EQ] = ACTIONS(5879),
    [anon_sym_BANG_EQ] = ACTIONS(5879),
    [anon_sym_GT_EQ] = ACTIONS(5879),
    [anon_sym_LT_EQ] = ACTIONS(5879),
    [anon_sym_DOT] = ACTIONS(5881),
    [anon_sym_switch] = ACTIONS(5879),
    [anon_sym_DOT_DOT] = ACTIONS(5879),
    [anon_sym_and] = ACTIONS(6588),
    [anon_sym_or] = ACTIONS(6590),
    [anon_sym_AMP_AMP] = ACTIONS(5879),
    [anon_sym_PIPE_PIPE] = ACTIONS(5879),
    [anon_sym_QMARK_QMARK] = ACTIONS(5879),
    [anon_sym_from] = ACTIONS(5879),
    [anon_sym_into] = ACTIONS(5879),
    [anon_sym_join] = ACTIONS(5879),
    [anon_sym_let] = ACTIONS(5879),
    [anon_sym_orderby] = ACTIONS(5879),
    [anon_sym_ascending] = ACTIONS(5879),
    [anon_sym_descending] = ACTIONS(5879),
    [anon_sym_group] = ACTIONS(5879),
    [anon_sym_select] = ACTIONS(5879),
    [anon_sym_as] = ACTIONS(5881),
    [anon_sym_is] = ACTIONS(5879),
    [anon_sym_DASH_GT] = ACTIONS(5879),
    [anon_sym_with] = ACTIONS(5879),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4563] = {
    [sym_preproc_region] = STATE(4563),
    [sym_preproc_endregion] = STATE(4563),
    [sym_preproc_line] = STATE(4563),
    [sym_preproc_pragma] = STATE(4563),
    [sym_preproc_nullable] = STATE(4563),
    [sym_preproc_error] = STATE(4563),
    [sym_preproc_warning] = STATE(4563),
    [sym_preproc_define] = STATE(4563),
    [sym_preproc_undef] = STATE(4563),
    [anon_sym_LBRACK] = ACTIONS(6592),
    [anon_sym_COMMA] = ACTIONS(6592),
    [anon_sym_LPAREN] = ACTIONS(6592),
    [anon_sym_LT] = ACTIONS(6594),
    [anon_sym_GT] = ACTIONS(6594),
    [anon_sym_where] = ACTIONS(6592),
    [anon_sym_QMARK] = ACTIONS(6594),
    [anon_sym_BANG] = ACTIONS(6594),
    [anon_sym_PLUS_PLUS] = ACTIONS(6592),
    [anon_sym_DASH_DASH] = ACTIONS(6592),
    [anon_sym_PLUS] = ACTIONS(6594),
    [anon_sym_DASH] = ACTIONS(6594),
    [anon_sym_STAR] = ACTIONS(6592),
    [anon_sym_SLASH] = ACTIONS(6594),
    [anon_sym_PERCENT] = ACTIONS(6592),
    [anon_sym_CARET] = ACTIONS(6592),
    [anon_sym_PIPE] = ACTIONS(6594),
    [anon_sym_AMP] = ACTIONS(6594),
    [anon_sym_LT_LT] = ACTIONS(6592),
    [anon_sym_GT_GT] = ACTIONS(6594),
    [anon_sym_GT_GT_GT] = ACTIONS(6592),
    [anon_sym_EQ_EQ] = ACTIONS(6592),
    [anon_sym_BANG_EQ] = ACTIONS(6592),
    [anon_sym_GT_EQ] = ACTIONS(6592),
    [anon_sym_LT_EQ] = ACTIONS(6592),
    [anon_sym_DOT] = ACTIONS(6594),
    [anon_sym_switch] = ACTIONS(6592),
    [anon_sym_DOT_DOT] = ACTIONS(6592),
    [anon_sym_and] = ACTIONS(6588),
    [anon_sym_or] = ACTIONS(6590),
    [anon_sym_AMP_AMP] = ACTIONS(6592),
    [anon_sym_PIPE_PIPE] = ACTIONS(6592),
    [anon_sym_QMARK_QMARK] = ACTIONS(6592),
    [anon_sym_from] = ACTIONS(6592),
    [anon_sym_into] = ACTIONS(6592),
    [anon_sym_join] = ACTIONS(6592),
    [anon_sym_let] = ACTIONS(6592),
    [anon_sym_orderby] = ACTIONS(6592),
    [anon_sym_ascending] = ACTIONS(6592),
    [anon_sym_descending] = ACTIONS(6592),
    [anon_sym_group] = ACTIONS(6592),
    [anon_sym_select] = ACTIONS(6592),
    [anon_sym_as] = ACTIONS(6594),
    [anon_sym_is] = ACTIONS(6592),
    [anon_sym_DASH_GT] = ACTIONS(6592),
    [anon_sym_with] = ACTIONS(6592),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4564] = {
    [sym_preproc_region] = STATE(4564),
    [sym_preproc_endregion] = STATE(4564),
    [sym_preproc_line] = STATE(4564),
    [sym_preproc_pragma] = STATE(4564),
    [sym_preproc_nullable] = STATE(4564),
    [sym_preproc_error] = STATE(4564),
    [sym_preproc_warning] = STATE(4564),
    [sym_preproc_define] = STATE(4564),
    [sym_preproc_undef] = STATE(4564),
    [anon_sym_LBRACK] = ACTIONS(5592),
    [anon_sym_COMMA] = ACTIONS(5592),
    [anon_sym_LPAREN] = ACTIONS(5592),
    [anon_sym_LT] = ACTIONS(5594),
    [anon_sym_GT] = ACTIONS(5594),
    [anon_sym_where] = ACTIONS(5592),
    [anon_sym_QMARK] = ACTIONS(5594),
    [anon_sym_BANG] = ACTIONS(5594),
    [anon_sym_PLUS_PLUS] = ACTIONS(5592),
    [anon_sym_DASH_DASH] = ACTIONS(5592),
    [anon_sym_PLUS] = ACTIONS(5594),
    [anon_sym_DASH] = ACTIONS(5594),
    [anon_sym_STAR] = ACTIONS(5592),
    [anon_sym_SLASH] = ACTIONS(5594),
    [anon_sym_PERCENT] = ACTIONS(5592),
    [anon_sym_CARET] = ACTIONS(5592),
    [anon_sym_PIPE] = ACTIONS(5594),
    [anon_sym_AMP] = ACTIONS(5594),
    [anon_sym_LT_LT] = ACTIONS(5592),
    [anon_sym_GT_GT] = ACTIONS(5594),
    [anon_sym_GT_GT_GT] = ACTIONS(5592),
    [anon_sym_EQ_EQ] = ACTIONS(5592),
    [anon_sym_BANG_EQ] = ACTIONS(5592),
    [anon_sym_GT_EQ] = ACTIONS(5592),
    [anon_sym_LT_EQ] = ACTIONS(5592),
    [anon_sym_DOT] = ACTIONS(5594),
    [anon_sym_switch] = ACTIONS(5592),
    [anon_sym_DOT_DOT] = ACTIONS(5592),
    [anon_sym_and] = ACTIONS(5592),
    [anon_sym_or] = ACTIONS(5594),
    [anon_sym_AMP_AMP] = ACTIONS(5592),
    [anon_sym_PIPE_PIPE] = ACTIONS(5592),
    [anon_sym_QMARK_QMARK] = ACTIONS(5592),
    [anon_sym_from] = ACTIONS(5592),
    [anon_sym_into] = ACTIONS(5592),
    [anon_sym_join] = ACTIONS(5592),
    [anon_sym_let] = ACTIONS(5592),
    [anon_sym_orderby] = ACTIONS(5592),
    [anon_sym_ascending] = ACTIONS(5592),
    [anon_sym_descending] = ACTIONS(5592),
    [anon_sym_group] = ACTIONS(5592),
    [anon_sym_select] = ACTIONS(5592),
    [anon_sym_as] = ACTIONS(5594),
    [anon_sym_is] = ACTIONS(5592),
    [anon_sym_DASH_GT] = ACTIONS(5592),
    [anon_sym_with] = ACTIONS(5592),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4565] = {
    [sym_preproc_region] = STATE(4565),
    [sym_preproc_endregion] = STATE(4565),
    [sym_preproc_line] = STATE(4565),
    [sym_preproc_pragma] = STATE(4565),
    [sym_preproc_nullable] = STATE(4565),
    [sym_preproc_error] = STATE(4565),
    [sym_preproc_warning] = STATE(4565),
    [sym_preproc_define] = STATE(4565),
    [sym_preproc_undef] = STATE(4565),
    [anon_sym_LBRACK] = ACTIONS(5506),
    [anon_sym_COMMA] = ACTIONS(5506),
    [anon_sym_LPAREN] = ACTIONS(5506),
    [anon_sym_LT] = ACTIONS(5508),
    [anon_sym_GT] = ACTIONS(5508),
    [anon_sym_where] = ACTIONS(5506),
    [anon_sym_QMARK] = ACTIONS(5508),
    [anon_sym_BANG] = ACTIONS(5508),
    [anon_sym_PLUS_PLUS] = ACTIONS(5506),
    [anon_sym_DASH_DASH] = ACTIONS(5506),
    [anon_sym_PLUS] = ACTIONS(5508),
    [anon_sym_DASH] = ACTIONS(5508),
    [anon_sym_STAR] = ACTIONS(5506),
    [anon_sym_SLASH] = ACTIONS(5508),
    [anon_sym_PERCENT] = ACTIONS(5506),
    [anon_sym_CARET] = ACTIONS(5506),
    [anon_sym_PIPE] = ACTIONS(5508),
    [anon_sym_AMP] = ACTIONS(5508),
    [anon_sym_LT_LT] = ACTIONS(5506),
    [anon_sym_GT_GT] = ACTIONS(5508),
    [anon_sym_GT_GT_GT] = ACTIONS(5506),
    [anon_sym_EQ_EQ] = ACTIONS(5506),
    [anon_sym_BANG_EQ] = ACTIONS(5506),
    [anon_sym_GT_EQ] = ACTIONS(5506),
    [anon_sym_LT_EQ] = ACTIONS(5506),
    [anon_sym_DOT] = ACTIONS(5508),
    [anon_sym_switch] = ACTIONS(5506),
    [anon_sym_DOT_DOT] = ACTIONS(5506),
    [anon_sym_and] = ACTIONS(5506),
    [anon_sym_or] = ACTIONS(5508),
    [anon_sym_AMP_AMP] = ACTIONS(5506),
    [anon_sym_PIPE_PIPE] = ACTIONS(5506),
    [anon_sym_QMARK_QMARK] = ACTIONS(5506),
    [anon_sym_from] = ACTIONS(5506),
    [anon_sym_into] = ACTIONS(5506),
    [anon_sym_join] = ACTIONS(5506),
    [anon_sym_let] = ACTIONS(5506),
    [anon_sym_orderby] = ACTIONS(5506),
    [anon_sym_ascending] = ACTIONS(5506),
    [anon_sym_descending] = ACTIONS(5506),
    [anon_sym_group] = ACTIONS(5506),
    [anon_sym_select] = ACTIONS(5506),
    [anon_sym_as] = ACTIONS(5508),
    [anon_sym_is] = ACTIONS(5506),
    [anon_sym_DASH_GT] = ACTIONS(5506),
    [anon_sym_with] = ACTIONS(5506),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4566] = {
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(6020),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4566),
    [sym_preproc_endregion] = STATE(4566),
    [sym_preproc_line] = STATE(4566),
    [sym_preproc_pragma] = STATE(4566),
    [sym_preproc_nullable] = STATE(4566),
    [sym_preproc_error] = STATE(4566),
    [sym_preproc_warning] = STATE(4566),
    [sym_preproc_define] = STATE(4566),
    [sym_preproc_undef] = STATE(4566),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(6596),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_readonly] = ACTIONS(6598),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(6600),
    [anon_sym_var] = ACTIONS(6582),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4567] = {
    [sym__name] = STATE(7943),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(6020),
    [sym_implicit_type] = STATE(8787),
    [sym_array_type] = STATE(8347),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9367),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(8787),
    [sym_scoped_type] = STATE(8787),
    [sym_tuple_type] = STATE(8173),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4567),
    [sym_preproc_endregion] = STATE(4567),
    [sym_preproc_line] = STATE(4567),
    [sym_preproc_pragma] = STATE(4567),
    [sym_preproc_nullable] = STATE(4567),
    [sym_preproc_error] = STATE(4567),
    [sym_preproc_warning] = STATE(4567),
    [sym_preproc_define] = STATE(4567),
    [sym_preproc_undef] = STATE(4567),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(6507),
    [anon_sym_delegate] = ACTIONS(5747),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_readonly] = ACTIONS(6509),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(5980),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(5755),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4568] = {
    [sym_preproc_region] = STATE(4568),
    [sym_preproc_endregion] = STATE(4568),
    [sym_preproc_line] = STATE(4568),
    [sym_preproc_pragma] = STATE(4568),
    [sym_preproc_nullable] = STATE(4568),
    [sym_preproc_error] = STATE(4568),
    [sym_preproc_warning] = STATE(4568),
    [sym_preproc_define] = STATE(4568),
    [sym_preproc_undef] = STATE(4568),
    [anon_sym_LBRACK] = ACTIONS(5664),
    [anon_sym_COMMA] = ACTIONS(5664),
    [anon_sym_LPAREN] = ACTIONS(5664),
    [anon_sym_LT] = ACTIONS(5666),
    [anon_sym_GT] = ACTIONS(5666),
    [anon_sym_where] = ACTIONS(5664),
    [anon_sym_QMARK] = ACTIONS(5666),
    [anon_sym_BANG] = ACTIONS(5666),
    [anon_sym_PLUS_PLUS] = ACTIONS(5664),
    [anon_sym_DASH_DASH] = ACTIONS(5664),
    [anon_sym_PLUS] = ACTIONS(5666),
    [anon_sym_DASH] = ACTIONS(5666),
    [anon_sym_STAR] = ACTIONS(5664),
    [anon_sym_SLASH] = ACTIONS(5666),
    [anon_sym_PERCENT] = ACTIONS(5664),
    [anon_sym_CARET] = ACTIONS(5664),
    [anon_sym_PIPE] = ACTIONS(5666),
    [anon_sym_AMP] = ACTIONS(5666),
    [anon_sym_LT_LT] = ACTIONS(5664),
    [anon_sym_GT_GT] = ACTIONS(5666),
    [anon_sym_GT_GT_GT] = ACTIONS(5664),
    [anon_sym_EQ_EQ] = ACTIONS(5664),
    [anon_sym_BANG_EQ] = ACTIONS(5664),
    [anon_sym_GT_EQ] = ACTIONS(5664),
    [anon_sym_LT_EQ] = ACTIONS(5664),
    [anon_sym_DOT] = ACTIONS(5666),
    [anon_sym_switch] = ACTIONS(5664),
    [anon_sym_DOT_DOT] = ACTIONS(5664),
    [anon_sym_and] = ACTIONS(5664),
    [anon_sym_or] = ACTIONS(5666),
    [anon_sym_AMP_AMP] = ACTIONS(5664),
    [anon_sym_PIPE_PIPE] = ACTIONS(5664),
    [anon_sym_QMARK_QMARK] = ACTIONS(5664),
    [anon_sym_from] = ACTIONS(5664),
    [anon_sym_into] = ACTIONS(5664),
    [anon_sym_join] = ACTIONS(5664),
    [anon_sym_let] = ACTIONS(5664),
    [anon_sym_orderby] = ACTIONS(5664),
    [anon_sym_ascending] = ACTIONS(5664),
    [anon_sym_descending] = ACTIONS(5664),
    [anon_sym_group] = ACTIONS(5664),
    [anon_sym_select] = ACTIONS(5664),
    [anon_sym_as] = ACTIONS(5666),
    [anon_sym_is] = ACTIONS(5664),
    [anon_sym_DASH_GT] = ACTIONS(5664),
    [anon_sym_with] = ACTIONS(5664),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4569] = {
    [sym_preproc_region] = STATE(4569),
    [sym_preproc_endregion] = STATE(4569),
    [sym_preproc_line] = STATE(4569),
    [sym_preproc_pragma] = STATE(4569),
    [sym_preproc_nullable] = STATE(4569),
    [sym_preproc_error] = STATE(4569),
    [sym_preproc_warning] = STATE(4569),
    [sym_preproc_define] = STATE(4569),
    [sym_preproc_undef] = STATE(4569),
    [anon_sym_LBRACK] = ACTIONS(5678),
    [anon_sym_COMMA] = ACTIONS(5678),
    [anon_sym_LPAREN] = ACTIONS(5678),
    [anon_sym_LT] = ACTIONS(5680),
    [anon_sym_GT] = ACTIONS(5680),
    [anon_sym_where] = ACTIONS(5678),
    [anon_sym_QMARK] = ACTIONS(5680),
    [anon_sym_BANG] = ACTIONS(5680),
    [anon_sym_PLUS_PLUS] = ACTIONS(5678),
    [anon_sym_DASH_DASH] = ACTIONS(5678),
    [anon_sym_PLUS] = ACTIONS(5680),
    [anon_sym_DASH] = ACTIONS(5680),
    [anon_sym_STAR] = ACTIONS(5678),
    [anon_sym_SLASH] = ACTIONS(5680),
    [anon_sym_PERCENT] = ACTIONS(5678),
    [anon_sym_CARET] = ACTIONS(5678),
    [anon_sym_PIPE] = ACTIONS(5680),
    [anon_sym_AMP] = ACTIONS(5680),
    [anon_sym_LT_LT] = ACTIONS(5678),
    [anon_sym_GT_GT] = ACTIONS(5680),
    [anon_sym_GT_GT_GT] = ACTIONS(5678),
    [anon_sym_EQ_EQ] = ACTIONS(5678),
    [anon_sym_BANG_EQ] = ACTIONS(5678),
    [anon_sym_GT_EQ] = ACTIONS(5678),
    [anon_sym_LT_EQ] = ACTIONS(5678),
    [anon_sym_DOT] = ACTIONS(5680),
    [anon_sym_switch] = ACTIONS(5678),
    [anon_sym_DOT_DOT] = ACTIONS(5678),
    [anon_sym_and] = ACTIONS(5678),
    [anon_sym_or] = ACTIONS(5680),
    [anon_sym_AMP_AMP] = ACTIONS(5678),
    [anon_sym_PIPE_PIPE] = ACTIONS(5678),
    [anon_sym_QMARK_QMARK] = ACTIONS(5678),
    [anon_sym_from] = ACTIONS(5678),
    [anon_sym_into] = ACTIONS(5678),
    [anon_sym_join] = ACTIONS(5678),
    [anon_sym_let] = ACTIONS(5678),
    [anon_sym_orderby] = ACTIONS(5678),
    [anon_sym_ascending] = ACTIONS(5678),
    [anon_sym_descending] = ACTIONS(5678),
    [anon_sym_group] = ACTIONS(5678),
    [anon_sym_select] = ACTIONS(5678),
    [anon_sym_as] = ACTIONS(5680),
    [anon_sym_is] = ACTIONS(5678),
    [anon_sym_DASH_GT] = ACTIONS(5678),
    [anon_sym_with] = ACTIONS(5678),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4570] = {
    [sym__name] = STATE(2992),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2956),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2944),
    [sym_type] = STATE(2978),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_identifier] = STATE(2920),
    [sym__reserved_identifier] = STATE(2928),
    [sym_preproc_region] = STATE(4570),
    [sym_preproc_endregion] = STATE(4570),
    [sym_preproc_line] = STATE(4570),
    [sym_preproc_pragma] = STATE(4570),
    [sym_preproc_nullable] = STATE(4570),
    [sym_preproc_error] = STATE(4570),
    [sym_preproc_warning] = STATE(4570),
    [sym_preproc_define] = STATE(4570),
    [sym_preproc_undef] = STATE(4570),
    [sym__identifier_token] = ACTIONS(4536),
    [anon_sym_alias] = ACTIONS(4538),
    [anon_sym_global] = ACTIONS(4538),
    [anon_sym_LPAREN] = ACTIONS(6602),
    [anon_sym_ref] = ACTIONS(4632),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_file] = ACTIONS(4538),
    [anon_sym_readonly] = ACTIONS(6604),
    [anon_sym_where] = ACTIONS(4538),
    [anon_sym_notnull] = ACTIONS(4538),
    [anon_sym_unmanaged] = ACTIONS(4538),
    [anon_sym_scoped] = ACTIONS(6244),
    [anon_sym_var] = ACTIONS(6246),
    [sym_predefined_type] = ACTIONS(6248),
    [anon_sym_yield] = ACTIONS(4538),
    [anon_sym_when] = ACTIONS(4538),
    [anon_sym_from] = ACTIONS(4538),
    [anon_sym_into] = ACTIONS(4538),
    [anon_sym_join] = ACTIONS(4538),
    [anon_sym_on] = ACTIONS(4538),
    [anon_sym_equals] = ACTIONS(4538),
    [anon_sym_let] = ACTIONS(4538),
    [anon_sym_orderby] = ACTIONS(4538),
    [anon_sym_ascending] = ACTIONS(4538),
    [anon_sym_descending] = ACTIONS(4538),
    [anon_sym_group] = ACTIONS(4538),
    [anon_sym_by] = ACTIONS(4538),
    [anon_sym_select] = ACTIONS(4538),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4571] = {
    [sym_preproc_region] = STATE(4571),
    [sym_preproc_endregion] = STATE(4571),
    [sym_preproc_line] = STATE(4571),
    [sym_preproc_pragma] = STATE(4571),
    [sym_preproc_nullable] = STATE(4571),
    [sym_preproc_error] = STATE(4571),
    [sym_preproc_warning] = STATE(4571),
    [sym_preproc_define] = STATE(4571),
    [sym_preproc_undef] = STATE(4571),
    [aux_sym__query_body_repeat2] = STATE(4577),
    [anon_sym_SEMI] = ACTIONS(6474),
    [anon_sym_LBRACK] = ACTIONS(6474),
    [anon_sym_COMMA] = ACTIONS(6474),
    [anon_sym_RBRACK] = ACTIONS(6474),
    [anon_sym_LPAREN] = ACTIONS(6474),
    [anon_sym_RPAREN] = ACTIONS(6474),
    [anon_sym_RBRACE] = ACTIONS(6474),
    [anon_sym_LT] = ACTIONS(6476),
    [anon_sym_GT] = ACTIONS(6476),
    [anon_sym_in] = ACTIONS(6476),
    [anon_sym_QMARK] = ACTIONS(6476),
    [anon_sym_BANG] = ACTIONS(6476),
    [anon_sym_PLUS_PLUS] = ACTIONS(6474),
    [anon_sym_DASH_DASH] = ACTIONS(6474),
    [anon_sym_PLUS] = ACTIONS(6476),
    [anon_sym_DASH] = ACTIONS(6476),
    [anon_sym_STAR] = ACTIONS(6474),
    [anon_sym_SLASH] = ACTIONS(6476),
    [anon_sym_PERCENT] = ACTIONS(6474),
    [anon_sym_CARET] = ACTIONS(6474),
    [anon_sym_PIPE] = ACTIONS(6476),
    [anon_sym_AMP] = ACTIONS(6476),
    [anon_sym_LT_LT] = ACTIONS(6474),
    [anon_sym_GT_GT] = ACTIONS(6476),
    [anon_sym_GT_GT_GT] = ACTIONS(6474),
    [anon_sym_EQ_EQ] = ACTIONS(6474),
    [anon_sym_BANG_EQ] = ACTIONS(6474),
    [anon_sym_GT_EQ] = ACTIONS(6474),
    [anon_sym_LT_EQ] = ACTIONS(6474),
    [anon_sym_DOT] = ACTIONS(6476),
    [anon_sym_switch] = ACTIONS(6474),
    [anon_sym_DOT_DOT] = ACTIONS(6474),
    [anon_sym_and] = ACTIONS(6474),
    [anon_sym_or] = ACTIONS(6474),
    [anon_sym_AMP_AMP] = ACTIONS(6474),
    [anon_sym_PIPE_PIPE] = ACTIONS(6474),
    [anon_sym_QMARK_QMARK] = ACTIONS(6474),
    [anon_sym_into] = ACTIONS(6606),
    [anon_sym_as] = ACTIONS(6474),
    [anon_sym_is] = ACTIONS(6474),
    [anon_sym_DASH_GT] = ACTIONS(6474),
    [anon_sym_with] = ACTIONS(6474),
    [aux_sym_preproc_if_token3] = ACTIONS(6474),
    [aux_sym_preproc_else_token1] = ACTIONS(6474),
    [aux_sym_preproc_elif_token1] = ACTIONS(6474),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4572] = {
    [sym_preproc_region] = STATE(4572),
    [sym_preproc_endregion] = STATE(4572),
    [sym_preproc_line] = STATE(4572),
    [sym_preproc_pragma] = STATE(4572),
    [sym_preproc_nullable] = STATE(4572),
    [sym_preproc_error] = STATE(4572),
    [sym_preproc_warning] = STATE(4572),
    [sym_preproc_define] = STATE(4572),
    [sym_preproc_undef] = STATE(4572),
    [sym__identifier_token] = ACTIONS(4042),
    [anon_sym_extern] = ACTIONS(4042),
    [anon_sym_alias] = ACTIONS(4042),
    [anon_sym_global] = ACTIONS(4042),
    [anon_sym_unsafe] = ACTIONS(4042),
    [anon_sym_static] = ACTIONS(4042),
    [anon_sym_LPAREN] = ACTIONS(5474),
    [anon_sym_ref] = ACTIONS(4042),
    [anon_sym_delegate] = ACTIONS(4042),
    [anon_sym_abstract] = ACTIONS(4042),
    [anon_sym_async] = ACTIONS(4042),
    [anon_sym_const] = ACTIONS(4042),
    [anon_sym_file] = ACTIONS(4042),
    [anon_sym_fixed] = ACTIONS(4042),
    [anon_sym_internal] = ACTIONS(4042),
    [anon_sym_new] = ACTIONS(4042),
    [anon_sym_override] = ACTIONS(4042),
    [anon_sym_partial] = ACTIONS(4042),
    [anon_sym_private] = ACTIONS(4042),
    [anon_sym_protected] = ACTIONS(4042),
    [anon_sym_public] = ACTIONS(4042),
    [anon_sym_readonly] = ACTIONS(4042),
    [anon_sym_required] = ACTIONS(4042),
    [anon_sym_sealed] = ACTIONS(4042),
    [anon_sym_virtual] = ACTIONS(4042),
    [anon_sym_volatile] = ACTIONS(4042),
    [anon_sym_where] = ACTIONS(4042),
    [anon_sym_notnull] = ACTIONS(4042),
    [anon_sym_unmanaged] = ACTIONS(4042),
    [anon_sym_scoped] = ACTIONS(4042),
    [anon_sym_var] = ACTIONS(4042),
    [sym_predefined_type] = ACTIONS(4042),
    [anon_sym_yield] = ACTIONS(4042),
    [anon_sym_when] = ACTIONS(4042),
    [anon_sym_from] = ACTIONS(4042),
    [anon_sym_into] = ACTIONS(4042),
    [anon_sym_join] = ACTIONS(4042),
    [anon_sym_on] = ACTIONS(4042),
    [anon_sym_equals] = ACTIONS(4042),
    [anon_sym_let] = ACTIONS(4042),
    [anon_sym_orderby] = ACTIONS(4042),
    [anon_sym_ascending] = ACTIONS(4042),
    [anon_sym_descending] = ACTIONS(4042),
    [anon_sym_group] = ACTIONS(4042),
    [anon_sym_by] = ACTIONS(4042),
    [anon_sym_select] = ACTIONS(4042),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4573] = {
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(8877),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4573),
    [sym_preproc_endregion] = STATE(4573),
    [sym_preproc_line] = STATE(4573),
    [sym_preproc_pragma] = STATE(4573),
    [sym_preproc_nullable] = STATE(4573),
    [sym_preproc_error] = STATE(4573),
    [sym_preproc_warning] = STATE(4573),
    [sym_preproc_define] = STATE(4573),
    [sym_preproc_undef] = STATE(4573),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(6608),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_checked] = ACTIONS(6610),
    [anon_sym_scoped] = ACTIONS(6612),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4574] = {
    [sym_type_argument_list] = STATE(3607),
    [sym_preproc_region] = STATE(4574),
    [sym_preproc_endregion] = STATE(4574),
    [sym_preproc_line] = STATE(4574),
    [sym_preproc_pragma] = STATE(4574),
    [sym_preproc_nullable] = STATE(4574),
    [sym_preproc_error] = STATE(4574),
    [sym_preproc_warning] = STATE(4574),
    [sym_preproc_define] = STATE(4574),
    [sym_preproc_undef] = STATE(4574),
    [anon_sym_LBRACK] = ACTIONS(4140),
    [anon_sym_LPAREN] = ACTIONS(4140),
    [anon_sym_LBRACE] = ACTIONS(4140),
    [anon_sym_LT] = ACTIONS(5281),
    [anon_sym_GT] = ACTIONS(4138),
    [anon_sym_where] = ACTIONS(4140),
    [anon_sym_QMARK] = ACTIONS(4138),
    [anon_sym_BANG] = ACTIONS(4138),
    [anon_sym_PLUS_PLUS] = ACTIONS(4140),
    [anon_sym_DASH_DASH] = ACTIONS(4140),
    [anon_sym_PLUS] = ACTIONS(4138),
    [anon_sym_DASH] = ACTIONS(4138),
    [anon_sym_STAR] = ACTIONS(4140),
    [anon_sym_SLASH] = ACTIONS(4138),
    [anon_sym_PERCENT] = ACTIONS(4140),
    [anon_sym_CARET] = ACTIONS(4140),
    [anon_sym_PIPE] = ACTIONS(4138),
    [anon_sym_AMP] = ACTIONS(4138),
    [anon_sym_LT_LT] = ACTIONS(4140),
    [anon_sym_GT_GT] = ACTIONS(4138),
    [anon_sym_GT_GT_GT] = ACTIONS(4140),
    [anon_sym_EQ_EQ] = ACTIONS(4140),
    [anon_sym_BANG_EQ] = ACTIONS(4140),
    [anon_sym_GT_EQ] = ACTIONS(4140),
    [anon_sym_LT_EQ] = ACTIONS(4140),
    [anon_sym_DOT] = ACTIONS(4138),
    [anon_sym_COLON_COLON] = ACTIONS(6614),
    [anon_sym_switch] = ACTIONS(4140),
    [anon_sym_DOT_DOT] = ACTIONS(4140),
    [anon_sym_and] = ACTIONS(4140),
    [anon_sym_or] = ACTIONS(4138),
    [anon_sym_AMP_AMP] = ACTIONS(4140),
    [anon_sym_PIPE_PIPE] = ACTIONS(4140),
    [anon_sym_QMARK_QMARK] = ACTIONS(4140),
    [anon_sym_from] = ACTIONS(4140),
    [anon_sym_into] = ACTIONS(4140),
    [anon_sym_join] = ACTIONS(4140),
    [anon_sym_let] = ACTIONS(4140),
    [anon_sym_orderby] = ACTIONS(4140),
    [anon_sym_group] = ACTIONS(4140),
    [anon_sym_select] = ACTIONS(4140),
    [anon_sym_as] = ACTIONS(4140),
    [anon_sym_is] = ACTIONS(4140),
    [anon_sym_DASH_GT] = ACTIONS(4140),
    [anon_sym_with] = ACTIONS(4140),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4575] = {
    [sym_preproc_region] = STATE(4575),
    [sym_preproc_endregion] = STATE(4575),
    [sym_preproc_line] = STATE(4575),
    [sym_preproc_pragma] = STATE(4575),
    [sym_preproc_nullable] = STATE(4575),
    [sym_preproc_error] = STATE(4575),
    [sym_preproc_warning] = STATE(4575),
    [sym_preproc_define] = STATE(4575),
    [sym_preproc_undef] = STATE(4575),
    [anon_sym_LBRACK] = ACTIONS(5560),
    [anon_sym_COMMA] = ACTIONS(5560),
    [anon_sym_LPAREN] = ACTIONS(5560),
    [anon_sym_LT] = ACTIONS(5562),
    [anon_sym_GT] = ACTIONS(5562),
    [anon_sym_where] = ACTIONS(5560),
    [anon_sym_QMARK] = ACTIONS(5562),
    [anon_sym_BANG] = ACTIONS(5562),
    [anon_sym_PLUS_PLUS] = ACTIONS(5560),
    [anon_sym_DASH_DASH] = ACTIONS(5560),
    [anon_sym_PLUS] = ACTIONS(5562),
    [anon_sym_DASH] = ACTIONS(5562),
    [anon_sym_STAR] = ACTIONS(5560),
    [anon_sym_SLASH] = ACTIONS(5562),
    [anon_sym_PERCENT] = ACTIONS(5560),
    [anon_sym_CARET] = ACTIONS(5560),
    [anon_sym_PIPE] = ACTIONS(5562),
    [anon_sym_AMP] = ACTIONS(5562),
    [anon_sym_LT_LT] = ACTIONS(5560),
    [anon_sym_GT_GT] = ACTIONS(5562),
    [anon_sym_GT_GT_GT] = ACTIONS(5560),
    [anon_sym_EQ_EQ] = ACTIONS(5560),
    [anon_sym_BANG_EQ] = ACTIONS(5560),
    [anon_sym_GT_EQ] = ACTIONS(5560),
    [anon_sym_LT_EQ] = ACTIONS(5560),
    [anon_sym_DOT] = ACTIONS(5562),
    [anon_sym_switch] = ACTIONS(5560),
    [anon_sym_DOT_DOT] = ACTIONS(5560),
    [anon_sym_and] = ACTIONS(5560),
    [anon_sym_or] = ACTIONS(5562),
    [anon_sym_AMP_AMP] = ACTIONS(5560),
    [anon_sym_PIPE_PIPE] = ACTIONS(5560),
    [anon_sym_QMARK_QMARK] = ACTIONS(5560),
    [anon_sym_from] = ACTIONS(5560),
    [anon_sym_into] = ACTIONS(5560),
    [anon_sym_join] = ACTIONS(5560),
    [anon_sym_let] = ACTIONS(5560),
    [anon_sym_orderby] = ACTIONS(5560),
    [anon_sym_ascending] = ACTIONS(5560),
    [anon_sym_descending] = ACTIONS(5560),
    [anon_sym_group] = ACTIONS(5560),
    [anon_sym_select] = ACTIONS(5560),
    [anon_sym_as] = ACTIONS(5562),
    [anon_sym_is] = ACTIONS(5560),
    [anon_sym_DASH_GT] = ACTIONS(5560),
    [anon_sym_with] = ACTIONS(5560),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4576] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4576),
    [sym_preproc_endregion] = STATE(4576),
    [sym_preproc_line] = STATE(4576),
    [sym_preproc_pragma] = STATE(4576),
    [sym_preproc_nullable] = STATE(4576),
    [sym_preproc_error] = STATE(4576),
    [sym_preproc_warning] = STATE(4576),
    [sym_preproc_define] = STATE(4576),
    [sym_preproc_undef] = STATE(4576),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(6320),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(6546),
    [anon_sym_GT] = ACTIONS(6546),
    [anon_sym_where] = ACTIONS(6320),
    [anon_sym_QMARK] = ACTIONS(6548),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(6550),
    [anon_sym_DASH] = ACTIONS(6550),
    [anon_sym_STAR] = ACTIONS(6552),
    [anon_sym_SLASH] = ACTIONS(6554),
    [anon_sym_PERCENT] = ACTIONS(6552),
    [anon_sym_CARET] = ACTIONS(6556),
    [anon_sym_PIPE] = ACTIONS(6558),
    [anon_sym_AMP] = ACTIONS(6560),
    [anon_sym_LT_LT] = ACTIONS(6562),
    [anon_sym_GT_GT] = ACTIONS(6564),
    [anon_sym_GT_GT_GT] = ACTIONS(6562),
    [anon_sym_EQ_EQ] = ACTIONS(6566),
    [anon_sym_BANG_EQ] = ACTIONS(6566),
    [anon_sym_GT_EQ] = ACTIONS(6568),
    [anon_sym_LT_EQ] = ACTIONS(6568),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(6216),
    [anon_sym_DOT_DOT] = ACTIONS(6570),
    [anon_sym_AMP_AMP] = ACTIONS(6572),
    [anon_sym_PIPE_PIPE] = ACTIONS(6574),
    [anon_sym_QMARK_QMARK] = ACTIONS(6576),
    [anon_sym_from] = ACTIONS(6320),
    [anon_sym_into] = ACTIONS(6320),
    [anon_sym_join] = ACTIONS(6320),
    [anon_sym_let] = ACTIONS(6320),
    [anon_sym_orderby] = ACTIONS(6320),
    [anon_sym_ascending] = ACTIONS(6320),
    [anon_sym_descending] = ACTIONS(6320),
    [anon_sym_group] = ACTIONS(6320),
    [anon_sym_select] = ACTIONS(6320),
    [anon_sym_as] = ACTIONS(6228),
    [anon_sym_is] = ACTIONS(6578),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(6232),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4577] = {
    [sym_preproc_region] = STATE(4577),
    [sym_preproc_endregion] = STATE(4577),
    [sym_preproc_line] = STATE(4577),
    [sym_preproc_pragma] = STATE(4577),
    [sym_preproc_nullable] = STATE(4577),
    [sym_preproc_error] = STATE(4577),
    [sym_preproc_warning] = STATE(4577),
    [sym_preproc_define] = STATE(4577),
    [sym_preproc_undef] = STATE(4577),
    [aux_sym__query_body_repeat2] = STATE(4669),
    [anon_sym_SEMI] = ACTIONS(6480),
    [anon_sym_LBRACK] = ACTIONS(6480),
    [anon_sym_COMMA] = ACTIONS(6480),
    [anon_sym_RBRACK] = ACTIONS(6480),
    [anon_sym_LPAREN] = ACTIONS(6480),
    [anon_sym_RPAREN] = ACTIONS(6480),
    [anon_sym_RBRACE] = ACTIONS(6480),
    [anon_sym_LT] = ACTIONS(6482),
    [anon_sym_GT] = ACTIONS(6482),
    [anon_sym_in] = ACTIONS(6482),
    [anon_sym_QMARK] = ACTIONS(6482),
    [anon_sym_BANG] = ACTIONS(6482),
    [anon_sym_PLUS_PLUS] = ACTIONS(6480),
    [anon_sym_DASH_DASH] = ACTIONS(6480),
    [anon_sym_PLUS] = ACTIONS(6482),
    [anon_sym_DASH] = ACTIONS(6482),
    [anon_sym_STAR] = ACTIONS(6480),
    [anon_sym_SLASH] = ACTIONS(6482),
    [anon_sym_PERCENT] = ACTIONS(6480),
    [anon_sym_CARET] = ACTIONS(6480),
    [anon_sym_PIPE] = ACTIONS(6482),
    [anon_sym_AMP] = ACTIONS(6482),
    [anon_sym_LT_LT] = ACTIONS(6480),
    [anon_sym_GT_GT] = ACTIONS(6482),
    [anon_sym_GT_GT_GT] = ACTIONS(6480),
    [anon_sym_EQ_EQ] = ACTIONS(6480),
    [anon_sym_BANG_EQ] = ACTIONS(6480),
    [anon_sym_GT_EQ] = ACTIONS(6480),
    [anon_sym_LT_EQ] = ACTIONS(6480),
    [anon_sym_DOT] = ACTIONS(6482),
    [anon_sym_switch] = ACTIONS(6480),
    [anon_sym_DOT_DOT] = ACTIONS(6480),
    [anon_sym_and] = ACTIONS(6480),
    [anon_sym_or] = ACTIONS(6480),
    [anon_sym_AMP_AMP] = ACTIONS(6480),
    [anon_sym_PIPE_PIPE] = ACTIONS(6480),
    [anon_sym_QMARK_QMARK] = ACTIONS(6480),
    [anon_sym_into] = ACTIONS(6606),
    [anon_sym_as] = ACTIONS(6480),
    [anon_sym_is] = ACTIONS(6480),
    [anon_sym_DASH_GT] = ACTIONS(6480),
    [anon_sym_with] = ACTIONS(6480),
    [aux_sym_preproc_if_token3] = ACTIONS(6480),
    [aux_sym_preproc_else_token1] = ACTIONS(6480),
    [aux_sym_preproc_elif_token1] = ACTIONS(6480),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4578] = {
    [sym_preproc_region] = STATE(4578),
    [sym_preproc_endregion] = STATE(4578),
    [sym_preproc_line] = STATE(4578),
    [sym_preproc_pragma] = STATE(4578),
    [sym_preproc_nullable] = STATE(4578),
    [sym_preproc_error] = STATE(4578),
    [sym_preproc_warning] = STATE(4578),
    [sym_preproc_define] = STATE(4578),
    [sym_preproc_undef] = STATE(4578),
    [anon_sym_LBRACK] = ACTIONS(3001),
    [anon_sym_COMMA] = ACTIONS(3001),
    [anon_sym_LPAREN] = ACTIONS(3001),
    [anon_sym_LT] = ACTIONS(2999),
    [anon_sym_GT] = ACTIONS(2999),
    [anon_sym_where] = ACTIONS(3001),
    [anon_sym_QMARK] = ACTIONS(2999),
    [anon_sym_BANG] = ACTIONS(2999),
    [anon_sym_PLUS_PLUS] = ACTIONS(3001),
    [anon_sym_DASH_DASH] = ACTIONS(3001),
    [anon_sym_PLUS] = ACTIONS(2999),
    [anon_sym_DASH] = ACTIONS(2999),
    [anon_sym_STAR] = ACTIONS(3001),
    [anon_sym_SLASH] = ACTIONS(2999),
    [anon_sym_PERCENT] = ACTIONS(3001),
    [anon_sym_CARET] = ACTIONS(3001),
    [anon_sym_PIPE] = ACTIONS(2999),
    [anon_sym_AMP] = ACTIONS(2999),
    [anon_sym_LT_LT] = ACTIONS(3001),
    [anon_sym_GT_GT] = ACTIONS(2999),
    [anon_sym_GT_GT_GT] = ACTIONS(3001),
    [anon_sym_EQ_EQ] = ACTIONS(3001),
    [anon_sym_BANG_EQ] = ACTIONS(3001),
    [anon_sym_GT_EQ] = ACTIONS(3001),
    [anon_sym_LT_EQ] = ACTIONS(3001),
    [anon_sym_DOT] = ACTIONS(2999),
    [anon_sym_switch] = ACTIONS(3001),
    [anon_sym_DOT_DOT] = ACTIONS(3001),
    [anon_sym_and] = ACTIONS(3001),
    [anon_sym_or] = ACTIONS(2999),
    [anon_sym_AMP_AMP] = ACTIONS(3001),
    [anon_sym_PIPE_PIPE] = ACTIONS(3001),
    [anon_sym_QMARK_QMARK] = ACTIONS(3001),
    [anon_sym_from] = ACTIONS(3001),
    [anon_sym_into] = ACTIONS(3001),
    [anon_sym_join] = ACTIONS(3001),
    [anon_sym_let] = ACTIONS(3001),
    [anon_sym_orderby] = ACTIONS(3001),
    [anon_sym_ascending] = ACTIONS(3001),
    [anon_sym_descending] = ACTIONS(3001),
    [anon_sym_group] = ACTIONS(3001),
    [anon_sym_select] = ACTIONS(3001),
    [anon_sym_as] = ACTIONS(2999),
    [anon_sym_is] = ACTIONS(3001),
    [anon_sym_DASH_GT] = ACTIONS(3001),
    [anon_sym_with] = ACTIONS(3001),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4579] = {
    [sym__name] = STATE(2992),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2956),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2944),
    [sym_type] = STATE(2978),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_identifier] = STATE(2920),
    [sym__reserved_identifier] = STATE(2928),
    [sym_preproc_region] = STATE(4579),
    [sym_preproc_endregion] = STATE(4579),
    [sym_preproc_line] = STATE(4579),
    [sym_preproc_pragma] = STATE(4579),
    [sym_preproc_nullable] = STATE(4579),
    [sym_preproc_error] = STATE(4579),
    [sym_preproc_warning] = STATE(4579),
    [sym_preproc_define] = STATE(4579),
    [sym_preproc_undef] = STATE(4579),
    [sym__identifier_token] = ACTIONS(4536),
    [anon_sym_alias] = ACTIONS(4538),
    [anon_sym_global] = ACTIONS(4538),
    [anon_sym_LPAREN] = ACTIONS(6602),
    [anon_sym_ref] = ACTIONS(4540),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_file] = ACTIONS(4538),
    [anon_sym_readonly] = ACTIONS(6616),
    [anon_sym_where] = ACTIONS(4538),
    [anon_sym_notnull] = ACTIONS(4538),
    [anon_sym_unmanaged] = ACTIONS(4538),
    [anon_sym_scoped] = ACTIONS(6362),
    [anon_sym_var] = ACTIONS(6246),
    [sym_predefined_type] = ACTIONS(6248),
    [anon_sym_yield] = ACTIONS(4538),
    [anon_sym_when] = ACTIONS(4538),
    [anon_sym_from] = ACTIONS(4538),
    [anon_sym_into] = ACTIONS(4538),
    [anon_sym_join] = ACTIONS(4538),
    [anon_sym_on] = ACTIONS(4538),
    [anon_sym_equals] = ACTIONS(4538),
    [anon_sym_let] = ACTIONS(4538),
    [anon_sym_orderby] = ACTIONS(4538),
    [anon_sym_ascending] = ACTIONS(4538),
    [anon_sym_descending] = ACTIONS(4538),
    [anon_sym_group] = ACTIONS(4538),
    [anon_sym_by] = ACTIONS(4538),
    [anon_sym_select] = ACTIONS(4538),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4580] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4580),
    [sym_preproc_endregion] = STATE(4580),
    [sym_preproc_line] = STATE(4580),
    [sym_preproc_pragma] = STATE(4580),
    [sym_preproc_nullable] = STATE(4580),
    [sym_preproc_error] = STATE(4580),
    [sym_preproc_warning] = STATE(4580),
    [sym_preproc_define] = STATE(4580),
    [sym_preproc_undef] = STATE(4580),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(6328),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(6330),
    [anon_sym_GT] = ACTIONS(6330),
    [anon_sym_where] = ACTIONS(6328),
    [anon_sym_QMARK] = ACTIONS(6330),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(6330),
    [anon_sym_DASH] = ACTIONS(6330),
    [anon_sym_STAR] = ACTIONS(6328),
    [anon_sym_SLASH] = ACTIONS(6330),
    [anon_sym_PERCENT] = ACTIONS(6328),
    [anon_sym_CARET] = ACTIONS(6328),
    [anon_sym_PIPE] = ACTIONS(6330),
    [anon_sym_AMP] = ACTIONS(6330),
    [anon_sym_LT_LT] = ACTIONS(6328),
    [anon_sym_GT_GT] = ACTIONS(6330),
    [anon_sym_GT_GT_GT] = ACTIONS(6328),
    [anon_sym_EQ_EQ] = ACTIONS(6328),
    [anon_sym_BANG_EQ] = ACTIONS(6328),
    [anon_sym_GT_EQ] = ACTIONS(6328),
    [anon_sym_LT_EQ] = ACTIONS(6328),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(6328),
    [anon_sym_DOT_DOT] = ACTIONS(6570),
    [anon_sym_AMP_AMP] = ACTIONS(6328),
    [anon_sym_PIPE_PIPE] = ACTIONS(6328),
    [anon_sym_QMARK_QMARK] = ACTIONS(6328),
    [anon_sym_from] = ACTIONS(6328),
    [anon_sym_into] = ACTIONS(6328),
    [anon_sym_join] = ACTIONS(6328),
    [anon_sym_let] = ACTIONS(6328),
    [anon_sym_orderby] = ACTIONS(6328),
    [anon_sym_ascending] = ACTIONS(6328),
    [anon_sym_descending] = ACTIONS(6328),
    [anon_sym_group] = ACTIONS(6328),
    [anon_sym_select] = ACTIONS(6328),
    [anon_sym_as] = ACTIONS(6330),
    [anon_sym_is] = ACTIONS(6328),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(6328),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4581] = {
    [sym_preproc_region] = STATE(4581),
    [sym_preproc_endregion] = STATE(4581),
    [sym_preproc_line] = STATE(4581),
    [sym_preproc_pragma] = STATE(4581),
    [sym_preproc_nullable] = STATE(4581),
    [sym_preproc_error] = STATE(4581),
    [sym_preproc_warning] = STATE(4581),
    [sym_preproc_define] = STATE(4581),
    [sym_preproc_undef] = STATE(4581),
    [anon_sym_LBRACK] = ACTIONS(5470),
    [anon_sym_COMMA] = ACTIONS(5470),
    [anon_sym_LPAREN] = ACTIONS(5470),
    [anon_sym_LT] = ACTIONS(5472),
    [anon_sym_GT] = ACTIONS(5472),
    [anon_sym_where] = ACTIONS(5470),
    [anon_sym_QMARK] = ACTIONS(5472),
    [anon_sym_BANG] = ACTIONS(5472),
    [anon_sym_PLUS_PLUS] = ACTIONS(5470),
    [anon_sym_DASH_DASH] = ACTIONS(5470),
    [anon_sym_PLUS] = ACTIONS(5472),
    [anon_sym_DASH] = ACTIONS(5472),
    [anon_sym_STAR] = ACTIONS(5470),
    [anon_sym_SLASH] = ACTIONS(5472),
    [anon_sym_PERCENT] = ACTIONS(5470),
    [anon_sym_CARET] = ACTIONS(5470),
    [anon_sym_PIPE] = ACTIONS(5472),
    [anon_sym_AMP] = ACTIONS(5472),
    [anon_sym_LT_LT] = ACTIONS(5470),
    [anon_sym_GT_GT] = ACTIONS(5472),
    [anon_sym_GT_GT_GT] = ACTIONS(5470),
    [anon_sym_EQ_EQ] = ACTIONS(5470),
    [anon_sym_BANG_EQ] = ACTIONS(5470),
    [anon_sym_GT_EQ] = ACTIONS(5470),
    [anon_sym_LT_EQ] = ACTIONS(5470),
    [anon_sym_DOT] = ACTIONS(5472),
    [anon_sym_switch] = ACTIONS(5470),
    [anon_sym_DOT_DOT] = ACTIONS(5470),
    [anon_sym_and] = ACTIONS(5470),
    [anon_sym_or] = ACTIONS(5472),
    [anon_sym_AMP_AMP] = ACTIONS(5470),
    [anon_sym_PIPE_PIPE] = ACTIONS(5470),
    [anon_sym_QMARK_QMARK] = ACTIONS(5470),
    [anon_sym_from] = ACTIONS(5470),
    [anon_sym_into] = ACTIONS(5470),
    [anon_sym_join] = ACTIONS(5470),
    [anon_sym_let] = ACTIONS(5470),
    [anon_sym_orderby] = ACTIONS(5470),
    [anon_sym_ascending] = ACTIONS(5470),
    [anon_sym_descending] = ACTIONS(5470),
    [anon_sym_group] = ACTIONS(5470),
    [anon_sym_select] = ACTIONS(5470),
    [anon_sym_as] = ACTIONS(5472),
    [anon_sym_is] = ACTIONS(5470),
    [anon_sym_DASH_GT] = ACTIONS(5470),
    [anon_sym_with] = ACTIONS(5470),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4582] = {
    [sym_preproc_region] = STATE(4582),
    [sym_preproc_endregion] = STATE(4582),
    [sym_preproc_line] = STATE(4582),
    [sym_preproc_pragma] = STATE(4582),
    [sym_preproc_nullable] = STATE(4582),
    [sym_preproc_error] = STATE(4582),
    [sym_preproc_warning] = STATE(4582),
    [sym_preproc_define] = STATE(4582),
    [sym_preproc_undef] = STATE(4582),
    [anon_sym_LBRACK] = ACTIONS(5869),
    [anon_sym_COMMA] = ACTIONS(5869),
    [anon_sym_LPAREN] = ACTIONS(5869),
    [anon_sym_LT] = ACTIONS(5871),
    [anon_sym_GT] = ACTIONS(5871),
    [anon_sym_where] = ACTIONS(5869),
    [anon_sym_QMARK] = ACTIONS(5871),
    [anon_sym_BANG] = ACTIONS(5871),
    [anon_sym_PLUS_PLUS] = ACTIONS(5869),
    [anon_sym_DASH_DASH] = ACTIONS(5869),
    [anon_sym_PLUS] = ACTIONS(5871),
    [anon_sym_DASH] = ACTIONS(5871),
    [anon_sym_STAR] = ACTIONS(5869),
    [anon_sym_SLASH] = ACTIONS(5871),
    [anon_sym_PERCENT] = ACTIONS(5869),
    [anon_sym_CARET] = ACTIONS(5869),
    [anon_sym_PIPE] = ACTIONS(5871),
    [anon_sym_AMP] = ACTIONS(5871),
    [anon_sym_LT_LT] = ACTIONS(5869),
    [anon_sym_GT_GT] = ACTIONS(5871),
    [anon_sym_GT_GT_GT] = ACTIONS(5869),
    [anon_sym_EQ_EQ] = ACTIONS(5869),
    [anon_sym_BANG_EQ] = ACTIONS(5869),
    [anon_sym_GT_EQ] = ACTIONS(5869),
    [anon_sym_LT_EQ] = ACTIONS(5869),
    [anon_sym_DOT] = ACTIONS(5871),
    [anon_sym_switch] = ACTIONS(5869),
    [anon_sym_DOT_DOT] = ACTIONS(5869),
    [anon_sym_and] = ACTIONS(5869),
    [anon_sym_or] = ACTIONS(5871),
    [anon_sym_AMP_AMP] = ACTIONS(5869),
    [anon_sym_PIPE_PIPE] = ACTIONS(5869),
    [anon_sym_QMARK_QMARK] = ACTIONS(5869),
    [anon_sym_from] = ACTIONS(5869),
    [anon_sym_into] = ACTIONS(5869),
    [anon_sym_join] = ACTIONS(5869),
    [anon_sym_let] = ACTIONS(5869),
    [anon_sym_orderby] = ACTIONS(5869),
    [anon_sym_ascending] = ACTIONS(5869),
    [anon_sym_descending] = ACTIONS(5869),
    [anon_sym_group] = ACTIONS(5869),
    [anon_sym_select] = ACTIONS(5869),
    [anon_sym_as] = ACTIONS(5871),
    [anon_sym_is] = ACTIONS(5869),
    [anon_sym_DASH_GT] = ACTIONS(5869),
    [anon_sym_with] = ACTIONS(5869),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4583] = {
    [sym_variable_declaration] = STATE(9069),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(6754),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4583),
    [sym_preproc_endregion] = STATE(4583),
    [sym_preproc_line] = STATE(4583),
    [sym_preproc_pragma] = STATE(4583),
    [sym_preproc_nullable] = STATE(4583),
    [sym_preproc_error] = STATE(4583),
    [sym_preproc_warning] = STATE(4583),
    [sym_preproc_define] = STATE(4583),
    [sym_preproc_undef] = STATE(4583),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4584] = {
    [sym_preproc_region] = STATE(4584),
    [sym_preproc_endregion] = STATE(4584),
    [sym_preproc_line] = STATE(4584),
    [sym_preproc_pragma] = STATE(4584),
    [sym_preproc_nullable] = STATE(4584),
    [sym_preproc_error] = STATE(4584),
    [sym_preproc_warning] = STATE(4584),
    [sym_preproc_define] = STATE(4584),
    [sym_preproc_undef] = STATE(4584),
    [aux_sym__query_body_repeat2] = STATE(4670),
    [anon_sym_SEMI] = ACTIONS(6480),
    [anon_sym_LBRACK] = ACTIONS(6480),
    [anon_sym_COMMA] = ACTIONS(6480),
    [anon_sym_RBRACK] = ACTIONS(6480),
    [anon_sym_LPAREN] = ACTIONS(6480),
    [anon_sym_RPAREN] = ACTIONS(6480),
    [anon_sym_RBRACE] = ACTIONS(6480),
    [anon_sym_LT] = ACTIONS(6482),
    [anon_sym_GT] = ACTIONS(6482),
    [anon_sym_in] = ACTIONS(6482),
    [anon_sym_QMARK] = ACTIONS(6482),
    [anon_sym_BANG] = ACTIONS(6482),
    [anon_sym_PLUS_PLUS] = ACTIONS(6480),
    [anon_sym_DASH_DASH] = ACTIONS(6480),
    [anon_sym_PLUS] = ACTIONS(6482),
    [anon_sym_DASH] = ACTIONS(6482),
    [anon_sym_STAR] = ACTIONS(6480),
    [anon_sym_SLASH] = ACTIONS(6482),
    [anon_sym_PERCENT] = ACTIONS(6480),
    [anon_sym_CARET] = ACTIONS(6480),
    [anon_sym_PIPE] = ACTIONS(6482),
    [anon_sym_AMP] = ACTIONS(6482),
    [anon_sym_LT_LT] = ACTIONS(6480),
    [anon_sym_GT_GT] = ACTIONS(6482),
    [anon_sym_GT_GT_GT] = ACTIONS(6480),
    [anon_sym_EQ_EQ] = ACTIONS(6480),
    [anon_sym_BANG_EQ] = ACTIONS(6480),
    [anon_sym_GT_EQ] = ACTIONS(6480),
    [anon_sym_LT_EQ] = ACTIONS(6480),
    [anon_sym_DOT] = ACTIONS(6482),
    [anon_sym_switch] = ACTIONS(6480),
    [anon_sym_DOT_DOT] = ACTIONS(6480),
    [anon_sym_and] = ACTIONS(6480),
    [anon_sym_or] = ACTIONS(6480),
    [anon_sym_AMP_AMP] = ACTIONS(6480),
    [anon_sym_PIPE_PIPE] = ACTIONS(6480),
    [anon_sym_QMARK_QMARK] = ACTIONS(6480),
    [anon_sym_into] = ACTIONS(6606),
    [anon_sym_as] = ACTIONS(6480),
    [anon_sym_is] = ACTIONS(6480),
    [anon_sym_DASH_GT] = ACTIONS(6480),
    [anon_sym_with] = ACTIONS(6480),
    [aux_sym_preproc_if_token3] = ACTIONS(6480),
    [aux_sym_preproc_else_token1] = ACTIONS(6480),
    [aux_sym_preproc_elif_token1] = ACTIONS(6480),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4585] = {
    [sym_preproc_region] = STATE(4585),
    [sym_preproc_endregion] = STATE(4585),
    [sym_preproc_line] = STATE(4585),
    [sym_preproc_pragma] = STATE(4585),
    [sym_preproc_nullable] = STATE(4585),
    [sym_preproc_error] = STATE(4585),
    [sym_preproc_warning] = STATE(4585),
    [sym_preproc_define] = STATE(4585),
    [sym_preproc_undef] = STATE(4585),
    [anon_sym_LBRACK] = ACTIONS(5875),
    [anon_sym_COMMA] = ACTIONS(5875),
    [anon_sym_LPAREN] = ACTIONS(5875),
    [anon_sym_LT] = ACTIONS(5877),
    [anon_sym_GT] = ACTIONS(5877),
    [anon_sym_where] = ACTIONS(5875),
    [anon_sym_QMARK] = ACTIONS(5877),
    [anon_sym_BANG] = ACTIONS(5877),
    [anon_sym_PLUS_PLUS] = ACTIONS(5875),
    [anon_sym_DASH_DASH] = ACTIONS(5875),
    [anon_sym_PLUS] = ACTIONS(5877),
    [anon_sym_DASH] = ACTIONS(5877),
    [anon_sym_STAR] = ACTIONS(5875),
    [anon_sym_SLASH] = ACTIONS(5877),
    [anon_sym_PERCENT] = ACTIONS(5875),
    [anon_sym_CARET] = ACTIONS(5875),
    [anon_sym_PIPE] = ACTIONS(5877),
    [anon_sym_AMP] = ACTIONS(5877),
    [anon_sym_LT_LT] = ACTIONS(5875),
    [anon_sym_GT_GT] = ACTIONS(5877),
    [anon_sym_GT_GT_GT] = ACTIONS(5875),
    [anon_sym_EQ_EQ] = ACTIONS(5875),
    [anon_sym_BANG_EQ] = ACTIONS(5875),
    [anon_sym_GT_EQ] = ACTIONS(5875),
    [anon_sym_LT_EQ] = ACTIONS(5875),
    [anon_sym_DOT] = ACTIONS(5877),
    [anon_sym_switch] = ACTIONS(5875),
    [anon_sym_DOT_DOT] = ACTIONS(5875),
    [anon_sym_and] = ACTIONS(5875),
    [anon_sym_or] = ACTIONS(5877),
    [anon_sym_AMP_AMP] = ACTIONS(5875),
    [anon_sym_PIPE_PIPE] = ACTIONS(5875),
    [anon_sym_QMARK_QMARK] = ACTIONS(5875),
    [anon_sym_from] = ACTIONS(5875),
    [anon_sym_into] = ACTIONS(5875),
    [anon_sym_join] = ACTIONS(5875),
    [anon_sym_let] = ACTIONS(5875),
    [anon_sym_orderby] = ACTIONS(5875),
    [anon_sym_ascending] = ACTIONS(5875),
    [anon_sym_descending] = ACTIONS(5875),
    [anon_sym_group] = ACTIONS(5875),
    [anon_sym_select] = ACTIONS(5875),
    [anon_sym_as] = ACTIONS(5877),
    [anon_sym_is] = ACTIONS(5875),
    [anon_sym_DASH_GT] = ACTIONS(5875),
    [anon_sym_with] = ACTIONS(5875),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4586] = {
    [sym_preproc_region] = STATE(4586),
    [sym_preproc_endregion] = STATE(4586),
    [sym_preproc_line] = STATE(4586),
    [sym_preproc_pragma] = STATE(4586),
    [sym_preproc_nullable] = STATE(4586),
    [sym_preproc_error] = STATE(4586),
    [sym_preproc_warning] = STATE(4586),
    [sym_preproc_define] = STATE(4586),
    [sym_preproc_undef] = STATE(4586),
    [anon_sym_LBRACK] = ACTIONS(4765),
    [anon_sym_COMMA] = ACTIONS(4765),
    [anon_sym_LPAREN] = ACTIONS(4765),
    [anon_sym_LT] = ACTIONS(4767),
    [anon_sym_GT] = ACTIONS(4767),
    [anon_sym_where] = ACTIONS(4765),
    [anon_sym_QMARK] = ACTIONS(4767),
    [anon_sym_BANG] = ACTIONS(4767),
    [anon_sym_PLUS_PLUS] = ACTIONS(4765),
    [anon_sym_DASH_DASH] = ACTIONS(4765),
    [anon_sym_PLUS] = ACTIONS(4767),
    [anon_sym_DASH] = ACTIONS(4767),
    [anon_sym_STAR] = ACTIONS(4765),
    [anon_sym_SLASH] = ACTIONS(4767),
    [anon_sym_PERCENT] = ACTIONS(4765),
    [anon_sym_CARET] = ACTIONS(4765),
    [anon_sym_PIPE] = ACTIONS(4767),
    [anon_sym_AMP] = ACTIONS(4767),
    [anon_sym_LT_LT] = ACTIONS(4765),
    [anon_sym_GT_GT] = ACTIONS(4767),
    [anon_sym_GT_GT_GT] = ACTIONS(4765),
    [anon_sym_EQ_EQ] = ACTIONS(4765),
    [anon_sym_BANG_EQ] = ACTIONS(4765),
    [anon_sym_GT_EQ] = ACTIONS(4765),
    [anon_sym_LT_EQ] = ACTIONS(4765),
    [anon_sym_DOT] = ACTIONS(4767),
    [anon_sym_switch] = ACTIONS(4765),
    [anon_sym_DOT_DOT] = ACTIONS(4765),
    [anon_sym_and] = ACTIONS(4765),
    [anon_sym_or] = ACTIONS(4767),
    [anon_sym_AMP_AMP] = ACTIONS(4765),
    [anon_sym_PIPE_PIPE] = ACTIONS(4765),
    [anon_sym_QMARK_QMARK] = ACTIONS(4765),
    [anon_sym_from] = ACTIONS(4765),
    [anon_sym_into] = ACTIONS(4765),
    [anon_sym_join] = ACTIONS(4765),
    [anon_sym_let] = ACTIONS(4765),
    [anon_sym_orderby] = ACTIONS(4765),
    [anon_sym_ascending] = ACTIONS(4765),
    [anon_sym_descending] = ACTIONS(4765),
    [anon_sym_group] = ACTIONS(4765),
    [anon_sym_select] = ACTIONS(4765),
    [anon_sym_as] = ACTIONS(4767),
    [anon_sym_is] = ACTIONS(4765),
    [anon_sym_DASH_GT] = ACTIONS(4765),
    [anon_sym_with] = ACTIONS(4765),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4587] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4587),
    [sym_preproc_endregion] = STATE(4587),
    [sym_preproc_line] = STATE(4587),
    [sym_preproc_pragma] = STATE(4587),
    [sym_preproc_nullable] = STATE(4587),
    [sym_preproc_error] = STATE(4587),
    [sym_preproc_warning] = STATE(4587),
    [sym_preproc_define] = STATE(4587),
    [sym_preproc_undef] = STATE(4587),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(6324),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(6546),
    [anon_sym_GT] = ACTIONS(6546),
    [anon_sym_where] = ACTIONS(6324),
    [anon_sym_QMARK] = ACTIONS(6548),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(6550),
    [anon_sym_DASH] = ACTIONS(6550),
    [anon_sym_STAR] = ACTIONS(6552),
    [anon_sym_SLASH] = ACTIONS(6554),
    [anon_sym_PERCENT] = ACTIONS(6552),
    [anon_sym_CARET] = ACTIONS(6556),
    [anon_sym_PIPE] = ACTIONS(6558),
    [anon_sym_AMP] = ACTIONS(6560),
    [anon_sym_LT_LT] = ACTIONS(6562),
    [anon_sym_GT_GT] = ACTIONS(6564),
    [anon_sym_GT_GT_GT] = ACTIONS(6562),
    [anon_sym_EQ_EQ] = ACTIONS(6566),
    [anon_sym_BANG_EQ] = ACTIONS(6566),
    [anon_sym_GT_EQ] = ACTIONS(6568),
    [anon_sym_LT_EQ] = ACTIONS(6568),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(6216),
    [anon_sym_DOT_DOT] = ACTIONS(6570),
    [anon_sym_AMP_AMP] = ACTIONS(6572),
    [anon_sym_PIPE_PIPE] = ACTIONS(6574),
    [anon_sym_QMARK_QMARK] = ACTIONS(6576),
    [anon_sym_from] = ACTIONS(6324),
    [anon_sym_into] = ACTIONS(6324),
    [anon_sym_join] = ACTIONS(6324),
    [anon_sym_let] = ACTIONS(6324),
    [anon_sym_orderby] = ACTIONS(6324),
    [anon_sym_ascending] = ACTIONS(6324),
    [anon_sym_descending] = ACTIONS(6324),
    [anon_sym_group] = ACTIONS(6324),
    [anon_sym_select] = ACTIONS(6324),
    [anon_sym_as] = ACTIONS(6228),
    [anon_sym_is] = ACTIONS(6578),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(6232),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4588] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4588),
    [sym_preproc_endregion] = STATE(4588),
    [sym_preproc_line] = STATE(4588),
    [sym_preproc_pragma] = STATE(4588),
    [sym_preproc_nullable] = STATE(4588),
    [sym_preproc_error] = STATE(4588),
    [sym_preproc_warning] = STATE(4588),
    [sym_preproc_define] = STATE(4588),
    [sym_preproc_undef] = STATE(4588),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(5416),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(6546),
    [anon_sym_GT] = ACTIONS(6546),
    [anon_sym_where] = ACTIONS(5416),
    [anon_sym_QMARK] = ACTIONS(6548),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(6550),
    [anon_sym_DASH] = ACTIONS(6550),
    [anon_sym_STAR] = ACTIONS(6552),
    [anon_sym_SLASH] = ACTIONS(6554),
    [anon_sym_PERCENT] = ACTIONS(6552),
    [anon_sym_CARET] = ACTIONS(6556),
    [anon_sym_PIPE] = ACTIONS(6558),
    [anon_sym_AMP] = ACTIONS(6560),
    [anon_sym_LT_LT] = ACTIONS(6562),
    [anon_sym_GT_GT] = ACTIONS(6564),
    [anon_sym_GT_GT_GT] = ACTIONS(6562),
    [anon_sym_EQ_EQ] = ACTIONS(6566),
    [anon_sym_BANG_EQ] = ACTIONS(6566),
    [anon_sym_GT_EQ] = ACTIONS(6568),
    [anon_sym_LT_EQ] = ACTIONS(6568),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(6216),
    [anon_sym_DOT_DOT] = ACTIONS(6570),
    [anon_sym_AMP_AMP] = ACTIONS(6572),
    [anon_sym_PIPE_PIPE] = ACTIONS(6574),
    [anon_sym_QMARK_QMARK] = ACTIONS(6576),
    [anon_sym_from] = ACTIONS(5416),
    [anon_sym_into] = ACTIONS(5416),
    [anon_sym_join] = ACTIONS(5416),
    [anon_sym_let] = ACTIONS(5416),
    [anon_sym_orderby] = ACTIONS(5416),
    [anon_sym_ascending] = ACTIONS(5416),
    [anon_sym_descending] = ACTIONS(5416),
    [anon_sym_group] = ACTIONS(5416),
    [anon_sym_select] = ACTIONS(5416),
    [anon_sym_as] = ACTIONS(6228),
    [anon_sym_is] = ACTIONS(6578),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(6232),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4589] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4589),
    [sym_preproc_endregion] = STATE(4589),
    [sym_preproc_line] = STATE(4589),
    [sym_preproc_pragma] = STATE(4589),
    [sym_preproc_nullable] = STATE(4589),
    [sym_preproc_error] = STATE(4589),
    [sym_preproc_warning] = STATE(4589),
    [sym_preproc_define] = STATE(4589),
    [sym_preproc_undef] = STATE(4589),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(5644),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(6546),
    [anon_sym_GT] = ACTIONS(6546),
    [anon_sym_where] = ACTIONS(5644),
    [anon_sym_QMARK] = ACTIONS(6548),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(6550),
    [anon_sym_DASH] = ACTIONS(6550),
    [anon_sym_STAR] = ACTIONS(6552),
    [anon_sym_SLASH] = ACTIONS(6554),
    [anon_sym_PERCENT] = ACTIONS(6552),
    [anon_sym_CARET] = ACTIONS(6556),
    [anon_sym_PIPE] = ACTIONS(6558),
    [anon_sym_AMP] = ACTIONS(6560),
    [anon_sym_LT_LT] = ACTIONS(6562),
    [anon_sym_GT_GT] = ACTIONS(6564),
    [anon_sym_GT_GT_GT] = ACTIONS(6562),
    [anon_sym_EQ_EQ] = ACTIONS(6566),
    [anon_sym_BANG_EQ] = ACTIONS(6566),
    [anon_sym_GT_EQ] = ACTIONS(6568),
    [anon_sym_LT_EQ] = ACTIONS(6568),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(6216),
    [anon_sym_DOT_DOT] = ACTIONS(6570),
    [anon_sym_AMP_AMP] = ACTIONS(6572),
    [anon_sym_PIPE_PIPE] = ACTIONS(6574),
    [anon_sym_QMARK_QMARK] = ACTIONS(6576),
    [anon_sym_from] = ACTIONS(5644),
    [anon_sym_into] = ACTIONS(5644),
    [anon_sym_join] = ACTIONS(5644),
    [anon_sym_let] = ACTIONS(5644),
    [anon_sym_orderby] = ACTIONS(5644),
    [anon_sym_ascending] = ACTIONS(5644),
    [anon_sym_descending] = ACTIONS(5644),
    [anon_sym_group] = ACTIONS(5644),
    [anon_sym_select] = ACTIONS(5644),
    [anon_sym_as] = ACTIONS(6228),
    [anon_sym_is] = ACTIONS(6578),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(6232),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4590] = {
    [sym_preproc_region] = STATE(4590),
    [sym_preproc_endregion] = STATE(4590),
    [sym_preproc_line] = STATE(4590),
    [sym_preproc_pragma] = STATE(4590),
    [sym_preproc_nullable] = STATE(4590),
    [sym_preproc_error] = STATE(4590),
    [sym_preproc_warning] = STATE(4590),
    [sym_preproc_define] = STATE(4590),
    [sym_preproc_undef] = STATE(4590),
    [anon_sym_LBRACK] = ACTIONS(5518),
    [anon_sym_COMMA] = ACTIONS(5518),
    [anon_sym_LPAREN] = ACTIONS(5518),
    [anon_sym_LT] = ACTIONS(5520),
    [anon_sym_GT] = ACTIONS(5520),
    [anon_sym_where] = ACTIONS(5518),
    [anon_sym_QMARK] = ACTIONS(5520),
    [anon_sym_BANG] = ACTIONS(5520),
    [anon_sym_PLUS_PLUS] = ACTIONS(5518),
    [anon_sym_DASH_DASH] = ACTIONS(5518),
    [anon_sym_PLUS] = ACTIONS(5520),
    [anon_sym_DASH] = ACTIONS(5520),
    [anon_sym_STAR] = ACTIONS(5518),
    [anon_sym_SLASH] = ACTIONS(5520),
    [anon_sym_PERCENT] = ACTIONS(5518),
    [anon_sym_CARET] = ACTIONS(5518),
    [anon_sym_PIPE] = ACTIONS(5520),
    [anon_sym_AMP] = ACTIONS(5520),
    [anon_sym_LT_LT] = ACTIONS(5518),
    [anon_sym_GT_GT] = ACTIONS(5520),
    [anon_sym_GT_GT_GT] = ACTIONS(5518),
    [anon_sym_EQ_EQ] = ACTIONS(5518),
    [anon_sym_BANG_EQ] = ACTIONS(5518),
    [anon_sym_GT_EQ] = ACTIONS(5518),
    [anon_sym_LT_EQ] = ACTIONS(5518),
    [anon_sym_DOT] = ACTIONS(5520),
    [anon_sym_switch] = ACTIONS(5518),
    [anon_sym_DOT_DOT] = ACTIONS(5518),
    [anon_sym_and] = ACTIONS(5518),
    [anon_sym_or] = ACTIONS(5520),
    [anon_sym_AMP_AMP] = ACTIONS(5518),
    [anon_sym_PIPE_PIPE] = ACTIONS(5518),
    [anon_sym_QMARK_QMARK] = ACTIONS(5518),
    [anon_sym_from] = ACTIONS(5518),
    [anon_sym_into] = ACTIONS(5518),
    [anon_sym_join] = ACTIONS(5518),
    [anon_sym_let] = ACTIONS(5518),
    [anon_sym_orderby] = ACTIONS(5518),
    [anon_sym_ascending] = ACTIONS(5518),
    [anon_sym_descending] = ACTIONS(5518),
    [anon_sym_group] = ACTIONS(5518),
    [anon_sym_select] = ACTIONS(5518),
    [anon_sym_as] = ACTIONS(5520),
    [anon_sym_is] = ACTIONS(5518),
    [anon_sym_DASH_GT] = ACTIONS(5518),
    [anon_sym_with] = ACTIONS(5518),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4591] = {
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(8783),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4591),
    [sym_preproc_endregion] = STATE(4591),
    [sym_preproc_line] = STATE(4591),
    [sym_preproc_pragma] = STATE(4591),
    [sym_preproc_nullable] = STATE(4591),
    [sym_preproc_error] = STATE(4591),
    [sym_preproc_warning] = STATE(4591),
    [sym_preproc_define] = STATE(4591),
    [sym_preproc_undef] = STATE(4591),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(6608),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_checked] = ACTIONS(6618),
    [anon_sym_scoped] = ACTIONS(6612),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4592] = {
    [sym_preproc_region] = STATE(4592),
    [sym_preproc_endregion] = STATE(4592),
    [sym_preproc_line] = STATE(4592),
    [sym_preproc_pragma] = STATE(4592),
    [sym_preproc_nullable] = STATE(4592),
    [sym_preproc_error] = STATE(4592),
    [sym_preproc_warning] = STATE(4592),
    [sym_preproc_define] = STATE(4592),
    [sym_preproc_undef] = STATE(4592),
    [anon_sym_LBRACK] = ACTIONS(5552),
    [anon_sym_COMMA] = ACTIONS(5552),
    [anon_sym_LPAREN] = ACTIONS(5552),
    [anon_sym_LT] = ACTIONS(5554),
    [anon_sym_GT] = ACTIONS(5554),
    [anon_sym_where] = ACTIONS(5552),
    [anon_sym_QMARK] = ACTIONS(5554),
    [anon_sym_BANG] = ACTIONS(5554),
    [anon_sym_PLUS_PLUS] = ACTIONS(5552),
    [anon_sym_DASH_DASH] = ACTIONS(5552),
    [anon_sym_PLUS] = ACTIONS(5554),
    [anon_sym_DASH] = ACTIONS(5554),
    [anon_sym_STAR] = ACTIONS(5552),
    [anon_sym_SLASH] = ACTIONS(5554),
    [anon_sym_PERCENT] = ACTIONS(5552),
    [anon_sym_CARET] = ACTIONS(5552),
    [anon_sym_PIPE] = ACTIONS(5554),
    [anon_sym_AMP] = ACTIONS(5554),
    [anon_sym_LT_LT] = ACTIONS(5552),
    [anon_sym_GT_GT] = ACTIONS(5554),
    [anon_sym_GT_GT_GT] = ACTIONS(5552),
    [anon_sym_EQ_EQ] = ACTIONS(5552),
    [anon_sym_BANG_EQ] = ACTIONS(5552),
    [anon_sym_GT_EQ] = ACTIONS(5552),
    [anon_sym_LT_EQ] = ACTIONS(5552),
    [anon_sym_DOT] = ACTIONS(5554),
    [anon_sym_switch] = ACTIONS(5552),
    [anon_sym_DOT_DOT] = ACTIONS(5552),
    [anon_sym_and] = ACTIONS(5552),
    [anon_sym_or] = ACTIONS(5554),
    [anon_sym_AMP_AMP] = ACTIONS(5552),
    [anon_sym_PIPE_PIPE] = ACTIONS(5552),
    [anon_sym_QMARK_QMARK] = ACTIONS(5552),
    [anon_sym_from] = ACTIONS(5552),
    [anon_sym_into] = ACTIONS(5552),
    [anon_sym_join] = ACTIONS(5552),
    [anon_sym_let] = ACTIONS(5552),
    [anon_sym_orderby] = ACTIONS(5552),
    [anon_sym_ascending] = ACTIONS(5552),
    [anon_sym_descending] = ACTIONS(5552),
    [anon_sym_group] = ACTIONS(5552),
    [anon_sym_select] = ACTIONS(5552),
    [anon_sym_as] = ACTIONS(5554),
    [anon_sym_is] = ACTIONS(5552),
    [anon_sym_DASH_GT] = ACTIONS(5552),
    [anon_sym_with] = ACTIONS(5552),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4593] = {
    [sym_preproc_region] = STATE(4593),
    [sym_preproc_endregion] = STATE(4593),
    [sym_preproc_line] = STATE(4593),
    [sym_preproc_pragma] = STATE(4593),
    [sym_preproc_nullable] = STATE(4593),
    [sym_preproc_error] = STATE(4593),
    [sym_preproc_warning] = STATE(4593),
    [sym_preproc_define] = STATE(4593),
    [sym_preproc_undef] = STATE(4593),
    [anon_sym_LBRACK] = ACTIONS(5556),
    [anon_sym_COMMA] = ACTIONS(5556),
    [anon_sym_LPAREN] = ACTIONS(5556),
    [anon_sym_LT] = ACTIONS(5558),
    [anon_sym_GT] = ACTIONS(5558),
    [anon_sym_where] = ACTIONS(5556),
    [anon_sym_QMARK] = ACTIONS(5558),
    [anon_sym_BANG] = ACTIONS(5558),
    [anon_sym_PLUS_PLUS] = ACTIONS(5556),
    [anon_sym_DASH_DASH] = ACTIONS(5556),
    [anon_sym_PLUS] = ACTIONS(5558),
    [anon_sym_DASH] = ACTIONS(5558),
    [anon_sym_STAR] = ACTIONS(5556),
    [anon_sym_SLASH] = ACTIONS(5558),
    [anon_sym_PERCENT] = ACTIONS(5556),
    [anon_sym_CARET] = ACTIONS(5556),
    [anon_sym_PIPE] = ACTIONS(5558),
    [anon_sym_AMP] = ACTIONS(5558),
    [anon_sym_LT_LT] = ACTIONS(5556),
    [anon_sym_GT_GT] = ACTIONS(5558),
    [anon_sym_GT_GT_GT] = ACTIONS(5556),
    [anon_sym_EQ_EQ] = ACTIONS(5556),
    [anon_sym_BANG_EQ] = ACTIONS(5556),
    [anon_sym_GT_EQ] = ACTIONS(5556),
    [anon_sym_LT_EQ] = ACTIONS(5556),
    [anon_sym_DOT] = ACTIONS(5558),
    [anon_sym_switch] = ACTIONS(5556),
    [anon_sym_DOT_DOT] = ACTIONS(5556),
    [anon_sym_and] = ACTIONS(5556),
    [anon_sym_or] = ACTIONS(5558),
    [anon_sym_AMP_AMP] = ACTIONS(5556),
    [anon_sym_PIPE_PIPE] = ACTIONS(5556),
    [anon_sym_QMARK_QMARK] = ACTIONS(5556),
    [anon_sym_from] = ACTIONS(5556),
    [anon_sym_into] = ACTIONS(5556),
    [anon_sym_join] = ACTIONS(5556),
    [anon_sym_let] = ACTIONS(5556),
    [anon_sym_orderby] = ACTIONS(5556),
    [anon_sym_ascending] = ACTIONS(5556),
    [anon_sym_descending] = ACTIONS(5556),
    [anon_sym_group] = ACTIONS(5556),
    [anon_sym_select] = ACTIONS(5556),
    [anon_sym_as] = ACTIONS(5558),
    [anon_sym_is] = ACTIONS(5556),
    [anon_sym_DASH_GT] = ACTIONS(5556),
    [anon_sym_with] = ACTIONS(5556),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4594] = {
    [sym_preproc_region] = STATE(4594),
    [sym_preproc_endregion] = STATE(4594),
    [sym_preproc_line] = STATE(4594),
    [sym_preproc_pragma] = STATE(4594),
    [sym_preproc_nullable] = STATE(4594),
    [sym_preproc_error] = STATE(4594),
    [sym_preproc_warning] = STATE(4594),
    [sym_preproc_define] = STATE(4594),
    [sym_preproc_undef] = STATE(4594),
    [sym__identifier_token] = ACTIONS(4042),
    [anon_sym_extern] = ACTIONS(4042),
    [anon_sym_alias] = ACTIONS(4042),
    [anon_sym_global] = ACTIONS(4042),
    [anon_sym_unsafe] = ACTIONS(4042),
    [anon_sym_static] = ACTIONS(4042),
    [anon_sym_LPAREN] = ACTIONS(5474),
    [anon_sym_ref] = ACTIONS(4042),
    [anon_sym_delegate] = ACTIONS(4042),
    [anon_sym_abstract] = ACTIONS(4042),
    [anon_sym_async] = ACTIONS(4042),
    [anon_sym_const] = ACTIONS(4042),
    [anon_sym_file] = ACTIONS(4042),
    [anon_sym_fixed] = ACTIONS(4042),
    [anon_sym_internal] = ACTIONS(4042),
    [anon_sym_new] = ACTIONS(4042),
    [anon_sym_override] = ACTIONS(4042),
    [anon_sym_partial] = ACTIONS(4042),
    [anon_sym_private] = ACTIONS(4042),
    [anon_sym_protected] = ACTIONS(4042),
    [anon_sym_public] = ACTIONS(4042),
    [anon_sym_readonly] = ACTIONS(4042),
    [anon_sym_required] = ACTIONS(4042),
    [anon_sym_sealed] = ACTIONS(4042),
    [anon_sym_virtual] = ACTIONS(4042),
    [anon_sym_volatile] = ACTIONS(4042),
    [anon_sym_where] = ACTIONS(4042),
    [anon_sym_notnull] = ACTIONS(4042),
    [anon_sym_unmanaged] = ACTIONS(4042),
    [anon_sym_scoped] = ACTIONS(4042),
    [anon_sym_var] = ACTIONS(4042),
    [sym_predefined_type] = ACTIONS(4042),
    [anon_sym_yield] = ACTIONS(4042),
    [anon_sym_when] = ACTIONS(4042),
    [anon_sym_from] = ACTIONS(4042),
    [anon_sym_into] = ACTIONS(4042),
    [anon_sym_join] = ACTIONS(4042),
    [anon_sym_on] = ACTIONS(4042),
    [anon_sym_equals] = ACTIONS(4042),
    [anon_sym_let] = ACTIONS(4042),
    [anon_sym_orderby] = ACTIONS(4042),
    [anon_sym_ascending] = ACTIONS(4042),
    [anon_sym_descending] = ACTIONS(4042),
    [anon_sym_group] = ACTIONS(4042),
    [anon_sym_by] = ACTIONS(4042),
    [anon_sym_select] = ACTIONS(4042),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4595] = {
    [sym_preproc_region] = STATE(4595),
    [sym_preproc_endregion] = STATE(4595),
    [sym_preproc_line] = STATE(4595),
    [sym_preproc_pragma] = STATE(4595),
    [sym_preproc_nullable] = STATE(4595),
    [sym_preproc_error] = STATE(4595),
    [sym_preproc_warning] = STATE(4595),
    [sym_preproc_define] = STATE(4595),
    [sym_preproc_undef] = STATE(4595),
    [anon_sym_LBRACK] = ACTIONS(5564),
    [anon_sym_COMMA] = ACTIONS(5564),
    [anon_sym_LPAREN] = ACTIONS(5564),
    [anon_sym_LT] = ACTIONS(5566),
    [anon_sym_GT] = ACTIONS(5566),
    [anon_sym_where] = ACTIONS(5564),
    [anon_sym_QMARK] = ACTIONS(5566),
    [anon_sym_BANG] = ACTIONS(5566),
    [anon_sym_PLUS_PLUS] = ACTIONS(5564),
    [anon_sym_DASH_DASH] = ACTIONS(5564),
    [anon_sym_PLUS] = ACTIONS(5566),
    [anon_sym_DASH] = ACTIONS(5566),
    [anon_sym_STAR] = ACTIONS(5564),
    [anon_sym_SLASH] = ACTIONS(5566),
    [anon_sym_PERCENT] = ACTIONS(5564),
    [anon_sym_CARET] = ACTIONS(5564),
    [anon_sym_PIPE] = ACTIONS(5566),
    [anon_sym_AMP] = ACTIONS(5566),
    [anon_sym_LT_LT] = ACTIONS(5564),
    [anon_sym_GT_GT] = ACTIONS(5566),
    [anon_sym_GT_GT_GT] = ACTIONS(5564),
    [anon_sym_EQ_EQ] = ACTIONS(5564),
    [anon_sym_BANG_EQ] = ACTIONS(5564),
    [anon_sym_GT_EQ] = ACTIONS(5564),
    [anon_sym_LT_EQ] = ACTIONS(5564),
    [anon_sym_DOT] = ACTIONS(5566),
    [anon_sym_switch] = ACTIONS(5564),
    [anon_sym_DOT_DOT] = ACTIONS(5564),
    [anon_sym_and] = ACTIONS(5564),
    [anon_sym_or] = ACTIONS(5566),
    [anon_sym_AMP_AMP] = ACTIONS(5564),
    [anon_sym_PIPE_PIPE] = ACTIONS(5564),
    [anon_sym_QMARK_QMARK] = ACTIONS(5564),
    [anon_sym_from] = ACTIONS(5564),
    [anon_sym_into] = ACTIONS(5564),
    [anon_sym_join] = ACTIONS(5564),
    [anon_sym_let] = ACTIONS(5564),
    [anon_sym_orderby] = ACTIONS(5564),
    [anon_sym_ascending] = ACTIONS(5564),
    [anon_sym_descending] = ACTIONS(5564),
    [anon_sym_group] = ACTIONS(5564),
    [anon_sym_select] = ACTIONS(5564),
    [anon_sym_as] = ACTIONS(5566),
    [anon_sym_is] = ACTIONS(5564),
    [anon_sym_DASH_GT] = ACTIONS(5564),
    [anon_sym_with] = ACTIONS(5564),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4596] = {
    [sym__name] = STATE(6204),
    [sym_alias_qualified_name] = STATE(4085),
    [sym__simple_name] = STATE(4085),
    [sym_qualified_name] = STATE(4085),
    [sym_generic_name] = STATE(3959),
    [sym_type] = STATE(4032),
    [sym_implicit_type] = STATE(4031),
    [sym_array_type] = STATE(3958),
    [sym__array_base_type] = STATE(8941),
    [sym_nullable_type] = STATE(3961),
    [sym_pointer_type] = STATE(3961),
    [sym__pointer_base_type] = STATE(9806),
    [sym_function_pointer_type] = STATE(3961),
    [sym_ref_type] = STATE(4031),
    [sym_scoped_type] = STATE(4031),
    [sym_tuple_type] = STATE(3962),
    [sym_identifier] = STATE(5502),
    [sym__reserved_identifier] = STATE(3911),
    [sym_preproc_region] = STATE(4596),
    [sym_preproc_endregion] = STATE(4596),
    [sym_preproc_line] = STATE(4596),
    [sym_preproc_pragma] = STATE(4596),
    [sym_preproc_nullable] = STATE(4596),
    [sym_preproc_error] = STATE(4596),
    [sym_preproc_warning] = STATE(4596),
    [sym_preproc_define] = STATE(4596),
    [sym_preproc_undef] = STATE(4596),
    [sym__identifier_token] = ACTIONS(4248),
    [anon_sym_alias] = ACTIONS(4250),
    [anon_sym_global] = ACTIONS(4250),
    [anon_sym_LPAREN] = ACTIONS(6620),
    [anon_sym_ref] = ACTIONS(4542),
    [anon_sym_delegate] = ACTIONS(6168),
    [anon_sym_file] = ACTIONS(4250),
    [anon_sym_readonly] = ACTIONS(6622),
    [anon_sym_where] = ACTIONS(4250),
    [anon_sym_notnull] = ACTIONS(4250),
    [anon_sym_unmanaged] = ACTIONS(4250),
    [anon_sym_scoped] = ACTIONS(6170),
    [anon_sym_var] = ACTIONS(6172),
    [sym_predefined_type] = ACTIONS(6174),
    [anon_sym_yield] = ACTIONS(4250),
    [anon_sym_when] = ACTIONS(4250),
    [anon_sym_from] = ACTIONS(4250),
    [anon_sym_into] = ACTIONS(4250),
    [anon_sym_join] = ACTIONS(4250),
    [anon_sym_on] = ACTIONS(4250),
    [anon_sym_equals] = ACTIONS(4250),
    [anon_sym_let] = ACTIONS(4250),
    [anon_sym_orderby] = ACTIONS(4250),
    [anon_sym_ascending] = ACTIONS(4250),
    [anon_sym_descending] = ACTIONS(4250),
    [anon_sym_group] = ACTIONS(4250),
    [anon_sym_by] = ACTIONS(4250),
    [anon_sym_select] = ACTIONS(4250),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4597] = {
    [sym__name] = STATE(3904),
    [sym_alias_qualified_name] = STATE(3924),
    [sym__simple_name] = STATE(3924),
    [sym_qualified_name] = STATE(3924),
    [sym_generic_name] = STATE(3900),
    [sym_type] = STATE(3929),
    [sym_implicit_type] = STATE(3943),
    [sym_array_type] = STATE(3945),
    [sym__array_base_type] = STATE(8893),
    [sym_nullable_type] = STATE(3885),
    [sym_pointer_type] = STATE(3885),
    [sym__pointer_base_type] = STATE(9659),
    [sym_function_pointer_type] = STATE(3885),
    [sym_ref_type] = STATE(3943),
    [sym_scoped_type] = STATE(3943),
    [sym_tuple_type] = STATE(3880),
    [sym_identifier] = STATE(3808),
    [sym__reserved_identifier] = STATE(3871),
    [sym_preproc_region] = STATE(4597),
    [sym_preproc_endregion] = STATE(4597),
    [sym_preproc_line] = STATE(4597),
    [sym_preproc_pragma] = STATE(4597),
    [sym_preproc_nullable] = STATE(4597),
    [sym_preproc_error] = STATE(4597),
    [sym_preproc_warning] = STATE(4597),
    [sym_preproc_define] = STATE(4597),
    [sym_preproc_undef] = STATE(4597),
    [sym__identifier_token] = ACTIONS(4223),
    [anon_sym_alias] = ACTIONS(4225),
    [anon_sym_global] = ACTIONS(4225),
    [anon_sym_LPAREN] = ACTIONS(6624),
    [anon_sym_ref] = ACTIONS(4530),
    [anon_sym_delegate] = ACTIONS(6182),
    [anon_sym_file] = ACTIONS(4225),
    [anon_sym_readonly] = ACTIONS(6626),
    [anon_sym_where] = ACTIONS(4225),
    [anon_sym_notnull] = ACTIONS(4225),
    [anon_sym_unmanaged] = ACTIONS(4225),
    [anon_sym_scoped] = ACTIONS(6262),
    [anon_sym_var] = ACTIONS(6186),
    [sym_predefined_type] = ACTIONS(6188),
    [anon_sym_yield] = ACTIONS(4225),
    [anon_sym_when] = ACTIONS(4225),
    [anon_sym_from] = ACTIONS(4225),
    [anon_sym_into] = ACTIONS(4225),
    [anon_sym_join] = ACTIONS(4225),
    [anon_sym_on] = ACTIONS(4225),
    [anon_sym_equals] = ACTIONS(4225),
    [anon_sym_let] = ACTIONS(4225),
    [anon_sym_orderby] = ACTIONS(4225),
    [anon_sym_ascending] = ACTIONS(4225),
    [anon_sym_descending] = ACTIONS(4225),
    [anon_sym_group] = ACTIONS(4225),
    [anon_sym_by] = ACTIONS(4225),
    [anon_sym_select] = ACTIONS(4225),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4598] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4598),
    [sym_preproc_endregion] = STATE(4598),
    [sym_preproc_line] = STATE(4598),
    [sym_preproc_pragma] = STATE(4598),
    [sym_preproc_nullable] = STATE(4598),
    [sym_preproc_error] = STATE(4598),
    [sym_preproc_warning] = STATE(4598),
    [sym_preproc_define] = STATE(4598),
    [sym_preproc_undef] = STATE(4598),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(5424),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(6546),
    [anon_sym_GT] = ACTIONS(6546),
    [anon_sym_where] = ACTIONS(5424),
    [anon_sym_QMARK] = ACTIONS(6548),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(6550),
    [anon_sym_DASH] = ACTIONS(6550),
    [anon_sym_STAR] = ACTIONS(6552),
    [anon_sym_SLASH] = ACTIONS(6554),
    [anon_sym_PERCENT] = ACTIONS(6552),
    [anon_sym_CARET] = ACTIONS(6556),
    [anon_sym_PIPE] = ACTIONS(6558),
    [anon_sym_AMP] = ACTIONS(6560),
    [anon_sym_LT_LT] = ACTIONS(6562),
    [anon_sym_GT_GT] = ACTIONS(6564),
    [anon_sym_GT_GT_GT] = ACTIONS(6562),
    [anon_sym_EQ_EQ] = ACTIONS(6566),
    [anon_sym_BANG_EQ] = ACTIONS(6566),
    [anon_sym_GT_EQ] = ACTIONS(6568),
    [anon_sym_LT_EQ] = ACTIONS(6568),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(6216),
    [anon_sym_DOT_DOT] = ACTIONS(6570),
    [anon_sym_AMP_AMP] = ACTIONS(6572),
    [anon_sym_PIPE_PIPE] = ACTIONS(6574),
    [anon_sym_QMARK_QMARK] = ACTIONS(6576),
    [anon_sym_from] = ACTIONS(5424),
    [anon_sym_into] = ACTIONS(5424),
    [anon_sym_join] = ACTIONS(5424),
    [anon_sym_let] = ACTIONS(5424),
    [anon_sym_orderby] = ACTIONS(5424),
    [anon_sym_ascending] = ACTIONS(5424),
    [anon_sym_descending] = ACTIONS(5424),
    [anon_sym_group] = ACTIONS(5424),
    [anon_sym_select] = ACTIONS(5424),
    [anon_sym_as] = ACTIONS(6228),
    [anon_sym_is] = ACTIONS(6578),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(6232),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4599] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4599),
    [sym_preproc_endregion] = STATE(4599),
    [sym_preproc_line] = STATE(4599),
    [sym_preproc_pragma] = STATE(4599),
    [sym_preproc_nullable] = STATE(4599),
    [sym_preproc_error] = STATE(4599),
    [sym_preproc_warning] = STATE(4599),
    [sym_preproc_define] = STATE(4599),
    [sym_preproc_undef] = STATE(4599),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(6336),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(6546),
    [anon_sym_GT] = ACTIONS(6546),
    [anon_sym_where] = ACTIONS(6336),
    [anon_sym_QMARK] = ACTIONS(6548),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(6550),
    [anon_sym_DASH] = ACTIONS(6550),
    [anon_sym_STAR] = ACTIONS(6552),
    [anon_sym_SLASH] = ACTIONS(6554),
    [anon_sym_PERCENT] = ACTIONS(6552),
    [anon_sym_CARET] = ACTIONS(6556),
    [anon_sym_PIPE] = ACTIONS(6558),
    [anon_sym_AMP] = ACTIONS(6560),
    [anon_sym_LT_LT] = ACTIONS(6562),
    [anon_sym_GT_GT] = ACTIONS(6564),
    [anon_sym_GT_GT_GT] = ACTIONS(6562),
    [anon_sym_EQ_EQ] = ACTIONS(6566),
    [anon_sym_BANG_EQ] = ACTIONS(6566),
    [anon_sym_GT_EQ] = ACTIONS(6568),
    [anon_sym_LT_EQ] = ACTIONS(6568),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(6216),
    [anon_sym_DOT_DOT] = ACTIONS(6570),
    [anon_sym_AMP_AMP] = ACTIONS(6572),
    [anon_sym_PIPE_PIPE] = ACTIONS(6574),
    [anon_sym_QMARK_QMARK] = ACTIONS(6576),
    [anon_sym_from] = ACTIONS(6336),
    [anon_sym_into] = ACTIONS(6336),
    [anon_sym_join] = ACTIONS(6336),
    [anon_sym_let] = ACTIONS(6336),
    [anon_sym_orderby] = ACTIONS(6336),
    [anon_sym_ascending] = ACTIONS(6336),
    [anon_sym_descending] = ACTIONS(6336),
    [anon_sym_group] = ACTIONS(6336),
    [anon_sym_select] = ACTIONS(6336),
    [anon_sym_as] = ACTIONS(6228),
    [anon_sym_is] = ACTIONS(6578),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(6232),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4600] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4600),
    [sym_preproc_endregion] = STATE(4600),
    [sym_preproc_line] = STATE(4600),
    [sym_preproc_pragma] = STATE(4600),
    [sym_preproc_nullable] = STATE(4600),
    [sym_preproc_error] = STATE(4600),
    [sym_preproc_warning] = STATE(4600),
    [sym_preproc_define] = STATE(4600),
    [sym_preproc_undef] = STATE(4600),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(5572),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(6546),
    [anon_sym_GT] = ACTIONS(6546),
    [anon_sym_where] = ACTIONS(5572),
    [anon_sym_QMARK] = ACTIONS(6548),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(6550),
    [anon_sym_DASH] = ACTIONS(6550),
    [anon_sym_STAR] = ACTIONS(6552),
    [anon_sym_SLASH] = ACTIONS(6554),
    [anon_sym_PERCENT] = ACTIONS(6552),
    [anon_sym_CARET] = ACTIONS(6556),
    [anon_sym_PIPE] = ACTIONS(6558),
    [anon_sym_AMP] = ACTIONS(6560),
    [anon_sym_LT_LT] = ACTIONS(6562),
    [anon_sym_GT_GT] = ACTIONS(6564),
    [anon_sym_GT_GT_GT] = ACTIONS(6562),
    [anon_sym_EQ_EQ] = ACTIONS(6566),
    [anon_sym_BANG_EQ] = ACTIONS(6566),
    [anon_sym_GT_EQ] = ACTIONS(6568),
    [anon_sym_LT_EQ] = ACTIONS(6568),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(6216),
    [anon_sym_DOT_DOT] = ACTIONS(6570),
    [anon_sym_AMP_AMP] = ACTIONS(6572),
    [anon_sym_PIPE_PIPE] = ACTIONS(6574),
    [anon_sym_QMARK_QMARK] = ACTIONS(6576),
    [anon_sym_from] = ACTIONS(5572),
    [anon_sym_into] = ACTIONS(5572),
    [anon_sym_join] = ACTIONS(5572),
    [anon_sym_let] = ACTIONS(5572),
    [anon_sym_orderby] = ACTIONS(5572),
    [anon_sym_ascending] = ACTIONS(5572),
    [anon_sym_descending] = ACTIONS(5572),
    [anon_sym_group] = ACTIONS(5572),
    [anon_sym_select] = ACTIONS(5572),
    [anon_sym_as] = ACTIONS(6228),
    [anon_sym_is] = ACTIONS(6578),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(6232),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4601] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4601),
    [sym_preproc_endregion] = STATE(4601),
    [sym_preproc_line] = STATE(4601),
    [sym_preproc_pragma] = STATE(4601),
    [sym_preproc_nullable] = STATE(4601),
    [sym_preproc_error] = STATE(4601),
    [sym_preproc_warning] = STATE(4601),
    [sym_preproc_define] = STATE(4601),
    [sym_preproc_undef] = STATE(4601),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(5624),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(6546),
    [anon_sym_GT] = ACTIONS(6546),
    [anon_sym_where] = ACTIONS(5624),
    [anon_sym_QMARK] = ACTIONS(6548),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(6550),
    [anon_sym_DASH] = ACTIONS(6550),
    [anon_sym_STAR] = ACTIONS(6552),
    [anon_sym_SLASH] = ACTIONS(6554),
    [anon_sym_PERCENT] = ACTIONS(6552),
    [anon_sym_CARET] = ACTIONS(6556),
    [anon_sym_PIPE] = ACTIONS(6558),
    [anon_sym_AMP] = ACTIONS(6560),
    [anon_sym_LT_LT] = ACTIONS(6562),
    [anon_sym_GT_GT] = ACTIONS(6564),
    [anon_sym_GT_GT_GT] = ACTIONS(6562),
    [anon_sym_EQ_EQ] = ACTIONS(6566),
    [anon_sym_BANG_EQ] = ACTIONS(6566),
    [anon_sym_GT_EQ] = ACTIONS(6568),
    [anon_sym_LT_EQ] = ACTIONS(6568),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(6216),
    [anon_sym_DOT_DOT] = ACTIONS(6570),
    [anon_sym_AMP_AMP] = ACTIONS(6572),
    [anon_sym_PIPE_PIPE] = ACTIONS(6574),
    [anon_sym_QMARK_QMARK] = ACTIONS(6576),
    [anon_sym_from] = ACTIONS(5624),
    [anon_sym_into] = ACTIONS(5624),
    [anon_sym_join] = ACTIONS(5624),
    [anon_sym_let] = ACTIONS(5624),
    [anon_sym_orderby] = ACTIONS(5624),
    [anon_sym_ascending] = ACTIONS(5624),
    [anon_sym_descending] = ACTIONS(5624),
    [anon_sym_group] = ACTIONS(5624),
    [anon_sym_select] = ACTIONS(5624),
    [anon_sym_as] = ACTIONS(6228),
    [anon_sym_is] = ACTIONS(6578),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(6232),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4602] = {
    [sym_preproc_region] = STATE(4602),
    [sym_preproc_endregion] = STATE(4602),
    [sym_preproc_line] = STATE(4602),
    [sym_preproc_pragma] = STATE(4602),
    [sym_preproc_nullable] = STATE(4602),
    [sym_preproc_error] = STATE(4602),
    [sym_preproc_warning] = STATE(4602),
    [sym_preproc_define] = STATE(4602),
    [sym_preproc_undef] = STATE(4602),
    [anon_sym_LBRACK] = ACTIONS(5620),
    [anon_sym_COMMA] = ACTIONS(5620),
    [anon_sym_LPAREN] = ACTIONS(5620),
    [anon_sym_LT] = ACTIONS(5622),
    [anon_sym_GT] = ACTIONS(5622),
    [anon_sym_where] = ACTIONS(5620),
    [anon_sym_QMARK] = ACTIONS(5622),
    [anon_sym_BANG] = ACTIONS(5622),
    [anon_sym_PLUS_PLUS] = ACTIONS(5620),
    [anon_sym_DASH_DASH] = ACTIONS(5620),
    [anon_sym_PLUS] = ACTIONS(5622),
    [anon_sym_DASH] = ACTIONS(5622),
    [anon_sym_STAR] = ACTIONS(5620),
    [anon_sym_SLASH] = ACTIONS(5622),
    [anon_sym_PERCENT] = ACTIONS(5620),
    [anon_sym_CARET] = ACTIONS(5620),
    [anon_sym_PIPE] = ACTIONS(5622),
    [anon_sym_AMP] = ACTIONS(5622),
    [anon_sym_LT_LT] = ACTIONS(5620),
    [anon_sym_GT_GT] = ACTIONS(5622),
    [anon_sym_GT_GT_GT] = ACTIONS(5620),
    [anon_sym_EQ_EQ] = ACTIONS(5620),
    [anon_sym_BANG_EQ] = ACTIONS(5620),
    [anon_sym_GT_EQ] = ACTIONS(5620),
    [anon_sym_LT_EQ] = ACTIONS(5620),
    [anon_sym_DOT] = ACTIONS(5622),
    [anon_sym_switch] = ACTIONS(5620),
    [anon_sym_DOT_DOT] = ACTIONS(5620),
    [anon_sym_and] = ACTIONS(5620),
    [anon_sym_or] = ACTIONS(5622),
    [anon_sym_AMP_AMP] = ACTIONS(5620),
    [anon_sym_PIPE_PIPE] = ACTIONS(5620),
    [anon_sym_QMARK_QMARK] = ACTIONS(5620),
    [anon_sym_from] = ACTIONS(5620),
    [anon_sym_into] = ACTIONS(5620),
    [anon_sym_join] = ACTIONS(5620),
    [anon_sym_let] = ACTIONS(5620),
    [anon_sym_orderby] = ACTIONS(5620),
    [anon_sym_ascending] = ACTIONS(5620),
    [anon_sym_descending] = ACTIONS(5620),
    [anon_sym_group] = ACTIONS(5620),
    [anon_sym_select] = ACTIONS(5620),
    [anon_sym_as] = ACTIONS(5622),
    [anon_sym_is] = ACTIONS(5620),
    [anon_sym_DASH_GT] = ACTIONS(5620),
    [anon_sym_with] = ACTIONS(5620),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4603] = {
    [sym_preproc_region] = STATE(4603),
    [sym_preproc_endregion] = STATE(4603),
    [sym_preproc_line] = STATE(4603),
    [sym_preproc_pragma] = STATE(4603),
    [sym_preproc_nullable] = STATE(4603),
    [sym_preproc_error] = STATE(4603),
    [sym_preproc_warning] = STATE(4603),
    [sym_preproc_define] = STATE(4603),
    [sym_preproc_undef] = STATE(4603),
    [sym__identifier_token] = ACTIONS(4042),
    [anon_sym_extern] = ACTIONS(4042),
    [anon_sym_alias] = ACTIONS(4042),
    [anon_sym_global] = ACTIONS(4042),
    [anon_sym_unsafe] = ACTIONS(4042),
    [anon_sym_static] = ACTIONS(4042),
    [anon_sym_LPAREN] = ACTIONS(6628),
    [anon_sym_ref] = ACTIONS(4042),
    [anon_sym_delegate] = ACTIONS(4042),
    [anon_sym_abstract] = ACTIONS(4042),
    [anon_sym_async] = ACTIONS(4042),
    [anon_sym_const] = ACTIONS(4042),
    [anon_sym_file] = ACTIONS(4042),
    [anon_sym_fixed] = ACTIONS(4042),
    [anon_sym_internal] = ACTIONS(4042),
    [anon_sym_new] = ACTIONS(4042),
    [anon_sym_override] = ACTIONS(4042),
    [anon_sym_partial] = ACTIONS(4042),
    [anon_sym_private] = ACTIONS(4042),
    [anon_sym_protected] = ACTIONS(4042),
    [anon_sym_public] = ACTIONS(4042),
    [anon_sym_readonly] = ACTIONS(4042),
    [anon_sym_required] = ACTIONS(4042),
    [anon_sym_sealed] = ACTIONS(4042),
    [anon_sym_virtual] = ACTIONS(4042),
    [anon_sym_volatile] = ACTIONS(4042),
    [anon_sym_where] = ACTIONS(4042),
    [anon_sym_notnull] = ACTIONS(4042),
    [anon_sym_unmanaged] = ACTIONS(4042),
    [anon_sym_scoped] = ACTIONS(4042),
    [anon_sym_var] = ACTIONS(4042),
    [sym_predefined_type] = ACTIONS(4042),
    [anon_sym_yield] = ACTIONS(4042),
    [anon_sym_when] = ACTIONS(4042),
    [anon_sym_from] = ACTIONS(4042),
    [anon_sym_into] = ACTIONS(4042),
    [anon_sym_join] = ACTIONS(4042),
    [anon_sym_on] = ACTIONS(4042),
    [anon_sym_equals] = ACTIONS(4042),
    [anon_sym_let] = ACTIONS(4042),
    [anon_sym_orderby] = ACTIONS(4042),
    [anon_sym_ascending] = ACTIONS(4042),
    [anon_sym_descending] = ACTIONS(4042),
    [anon_sym_group] = ACTIONS(4042),
    [anon_sym_by] = ACTIONS(4042),
    [anon_sym_select] = ACTIONS(4042),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4604] = {
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7206),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8977),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4604),
    [sym_preproc_endregion] = STATE(4604),
    [sym_preproc_line] = STATE(4604),
    [sym_preproc_pragma] = STATE(4604),
    [sym_preproc_nullable] = STATE(4604),
    [sym_preproc_error] = STATE(4604),
    [sym_preproc_warning] = STATE(4604),
    [sym_preproc_define] = STATE(4604),
    [sym_preproc_undef] = STATE(4604),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(4078),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(6140),
    [anon_sym_var] = ACTIONS(5369),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4605] = {
    [sym__name] = STATE(4158),
    [sym_alias_qualified_name] = STATE(4085),
    [sym__simple_name] = STATE(4085),
    [sym_qualified_name] = STATE(4085),
    [sym_generic_name] = STATE(3959),
    [sym_type] = STATE(4032),
    [sym_implicit_type] = STATE(4031),
    [sym_array_type] = STATE(3958),
    [sym__array_base_type] = STATE(8941),
    [sym_nullable_type] = STATE(3961),
    [sym_pointer_type] = STATE(3961),
    [sym__pointer_base_type] = STATE(9806),
    [sym_function_pointer_type] = STATE(3961),
    [sym_ref_type] = STATE(4031),
    [sym_scoped_type] = STATE(4031),
    [sym_tuple_type] = STATE(3962),
    [sym_identifier] = STATE(3889),
    [sym__reserved_identifier] = STATE(3911),
    [sym_preproc_region] = STATE(4605),
    [sym_preproc_endregion] = STATE(4605),
    [sym_preproc_line] = STATE(4605),
    [sym_preproc_pragma] = STATE(4605),
    [sym_preproc_nullable] = STATE(4605),
    [sym_preproc_error] = STATE(4605),
    [sym_preproc_warning] = STATE(4605),
    [sym_preproc_define] = STATE(4605),
    [sym_preproc_undef] = STATE(4605),
    [sym__identifier_token] = ACTIONS(4248),
    [anon_sym_alias] = ACTIONS(4250),
    [anon_sym_global] = ACTIONS(4250),
    [anon_sym_LPAREN] = ACTIONS(6620),
    [anon_sym_ref] = ACTIONS(4252),
    [anon_sym_delegate] = ACTIONS(6168),
    [anon_sym_file] = ACTIONS(4250),
    [anon_sym_readonly] = ACTIONS(6630),
    [anon_sym_where] = ACTIONS(4250),
    [anon_sym_notnull] = ACTIONS(4250),
    [anon_sym_unmanaged] = ACTIONS(4250),
    [anon_sym_scoped] = ACTIONS(6350),
    [anon_sym_var] = ACTIONS(6172),
    [sym_predefined_type] = ACTIONS(6174),
    [anon_sym_yield] = ACTIONS(4250),
    [anon_sym_when] = ACTIONS(4250),
    [anon_sym_from] = ACTIONS(4250),
    [anon_sym_into] = ACTIONS(4250),
    [anon_sym_join] = ACTIONS(4250),
    [anon_sym_on] = ACTIONS(4250),
    [anon_sym_equals] = ACTIONS(4250),
    [anon_sym_let] = ACTIONS(4250),
    [anon_sym_orderby] = ACTIONS(4250),
    [anon_sym_ascending] = ACTIONS(4250),
    [anon_sym_descending] = ACTIONS(4250),
    [anon_sym_group] = ACTIONS(4250),
    [anon_sym_by] = ACTIONS(4250),
    [anon_sym_select] = ACTIONS(4250),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4606] = {
    [sym_preproc_region] = STATE(4606),
    [sym_preproc_endregion] = STATE(4606),
    [sym_preproc_line] = STATE(4606),
    [sym_preproc_pragma] = STATE(4606),
    [sym_preproc_nullable] = STATE(4606),
    [sym_preproc_error] = STATE(4606),
    [sym_preproc_warning] = STATE(4606),
    [sym_preproc_define] = STATE(4606),
    [sym_preproc_undef] = STATE(4606),
    [anon_sym_LBRACK] = ACTIONS(5568),
    [anon_sym_COMMA] = ACTIONS(5568),
    [anon_sym_LPAREN] = ACTIONS(5568),
    [anon_sym_LT] = ACTIONS(5570),
    [anon_sym_GT] = ACTIONS(5570),
    [anon_sym_where] = ACTIONS(5568),
    [anon_sym_QMARK] = ACTIONS(5570),
    [anon_sym_BANG] = ACTIONS(5570),
    [anon_sym_PLUS_PLUS] = ACTIONS(5568),
    [anon_sym_DASH_DASH] = ACTIONS(5568),
    [anon_sym_PLUS] = ACTIONS(5570),
    [anon_sym_DASH] = ACTIONS(5570),
    [anon_sym_STAR] = ACTIONS(5568),
    [anon_sym_SLASH] = ACTIONS(5570),
    [anon_sym_PERCENT] = ACTIONS(5568),
    [anon_sym_CARET] = ACTIONS(5568),
    [anon_sym_PIPE] = ACTIONS(5570),
    [anon_sym_AMP] = ACTIONS(5570),
    [anon_sym_LT_LT] = ACTIONS(5568),
    [anon_sym_GT_GT] = ACTIONS(5570),
    [anon_sym_GT_GT_GT] = ACTIONS(5568),
    [anon_sym_EQ_EQ] = ACTIONS(5568),
    [anon_sym_BANG_EQ] = ACTIONS(5568),
    [anon_sym_GT_EQ] = ACTIONS(5568),
    [anon_sym_LT_EQ] = ACTIONS(5568),
    [anon_sym_DOT] = ACTIONS(5570),
    [anon_sym_switch] = ACTIONS(5568),
    [anon_sym_DOT_DOT] = ACTIONS(5568),
    [anon_sym_and] = ACTIONS(5568),
    [anon_sym_or] = ACTIONS(5570),
    [anon_sym_AMP_AMP] = ACTIONS(5568),
    [anon_sym_PIPE_PIPE] = ACTIONS(5568),
    [anon_sym_QMARK_QMARK] = ACTIONS(5568),
    [anon_sym_from] = ACTIONS(5568),
    [anon_sym_into] = ACTIONS(5568),
    [anon_sym_join] = ACTIONS(5568),
    [anon_sym_let] = ACTIONS(5568),
    [anon_sym_orderby] = ACTIONS(5568),
    [anon_sym_ascending] = ACTIONS(5568),
    [anon_sym_descending] = ACTIONS(5568),
    [anon_sym_group] = ACTIONS(5568),
    [anon_sym_select] = ACTIONS(5568),
    [anon_sym_as] = ACTIONS(5570),
    [anon_sym_is] = ACTIONS(5568),
    [anon_sym_DASH_GT] = ACTIONS(5568),
    [anon_sym_with] = ACTIONS(5568),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4607] = {
    [sym_preproc_region] = STATE(4607),
    [sym_preproc_endregion] = STATE(4607),
    [sym_preproc_line] = STATE(4607),
    [sym_preproc_pragma] = STATE(4607),
    [sym_preproc_nullable] = STATE(4607),
    [sym_preproc_error] = STATE(4607),
    [sym_preproc_warning] = STATE(4607),
    [sym_preproc_define] = STATE(4607),
    [sym_preproc_undef] = STATE(4607),
    [anon_sym_LBRACK] = ACTIONS(5616),
    [anon_sym_COMMA] = ACTIONS(5616),
    [anon_sym_LPAREN] = ACTIONS(5616),
    [anon_sym_LT] = ACTIONS(5618),
    [anon_sym_GT] = ACTIONS(5618),
    [anon_sym_where] = ACTIONS(5616),
    [anon_sym_QMARK] = ACTIONS(5618),
    [anon_sym_BANG] = ACTIONS(5618),
    [anon_sym_PLUS_PLUS] = ACTIONS(5616),
    [anon_sym_DASH_DASH] = ACTIONS(5616),
    [anon_sym_PLUS] = ACTIONS(5618),
    [anon_sym_DASH] = ACTIONS(5618),
    [anon_sym_STAR] = ACTIONS(5616),
    [anon_sym_SLASH] = ACTIONS(5618),
    [anon_sym_PERCENT] = ACTIONS(5616),
    [anon_sym_CARET] = ACTIONS(5616),
    [anon_sym_PIPE] = ACTIONS(5618),
    [anon_sym_AMP] = ACTIONS(5618),
    [anon_sym_LT_LT] = ACTIONS(5616),
    [anon_sym_GT_GT] = ACTIONS(5618),
    [anon_sym_GT_GT_GT] = ACTIONS(5616),
    [anon_sym_EQ_EQ] = ACTIONS(5616),
    [anon_sym_BANG_EQ] = ACTIONS(5616),
    [anon_sym_GT_EQ] = ACTIONS(5616),
    [anon_sym_LT_EQ] = ACTIONS(5616),
    [anon_sym_DOT] = ACTIONS(5618),
    [anon_sym_switch] = ACTIONS(5616),
    [anon_sym_DOT_DOT] = ACTIONS(5616),
    [anon_sym_and] = ACTIONS(5616),
    [anon_sym_or] = ACTIONS(5618),
    [anon_sym_AMP_AMP] = ACTIONS(5616),
    [anon_sym_PIPE_PIPE] = ACTIONS(5616),
    [anon_sym_QMARK_QMARK] = ACTIONS(5616),
    [anon_sym_from] = ACTIONS(5616),
    [anon_sym_into] = ACTIONS(5616),
    [anon_sym_join] = ACTIONS(5616),
    [anon_sym_let] = ACTIONS(5616),
    [anon_sym_orderby] = ACTIONS(5616),
    [anon_sym_ascending] = ACTIONS(5616),
    [anon_sym_descending] = ACTIONS(5616),
    [anon_sym_group] = ACTIONS(5616),
    [anon_sym_select] = ACTIONS(5616),
    [anon_sym_as] = ACTIONS(5618),
    [anon_sym_is] = ACTIONS(5616),
    [anon_sym_DASH_GT] = ACTIONS(5616),
    [anon_sym_with] = ACTIONS(5616),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4608] = {
    [sym_preproc_region] = STATE(4608),
    [sym_preproc_endregion] = STATE(4608),
    [sym_preproc_line] = STATE(4608),
    [sym_preproc_pragma] = STATE(4608),
    [sym_preproc_nullable] = STATE(4608),
    [sym_preproc_error] = STATE(4608),
    [sym_preproc_warning] = STATE(4608),
    [sym_preproc_define] = STATE(4608),
    [sym_preproc_undef] = STATE(4608),
    [anon_sym_LBRACK] = ACTIONS(5942),
    [anon_sym_COMMA] = ACTIONS(5942),
    [anon_sym_LPAREN] = ACTIONS(5942),
    [anon_sym_LT] = ACTIONS(5944),
    [anon_sym_GT] = ACTIONS(5944),
    [anon_sym_where] = ACTIONS(5942),
    [anon_sym_QMARK] = ACTIONS(5944),
    [anon_sym_BANG] = ACTIONS(5944),
    [anon_sym_PLUS_PLUS] = ACTIONS(5942),
    [anon_sym_DASH_DASH] = ACTIONS(5942),
    [anon_sym_PLUS] = ACTIONS(5944),
    [anon_sym_DASH] = ACTIONS(5944),
    [anon_sym_STAR] = ACTIONS(5942),
    [anon_sym_SLASH] = ACTIONS(5944),
    [anon_sym_PERCENT] = ACTIONS(5942),
    [anon_sym_CARET] = ACTIONS(5942),
    [anon_sym_PIPE] = ACTIONS(5944),
    [anon_sym_AMP] = ACTIONS(5944),
    [anon_sym_LT_LT] = ACTIONS(5942),
    [anon_sym_GT_GT] = ACTIONS(5944),
    [anon_sym_GT_GT_GT] = ACTIONS(5942),
    [anon_sym_EQ_EQ] = ACTIONS(5942),
    [anon_sym_BANG_EQ] = ACTIONS(5942),
    [anon_sym_GT_EQ] = ACTIONS(5942),
    [anon_sym_LT_EQ] = ACTIONS(5942),
    [anon_sym_DOT] = ACTIONS(5944),
    [anon_sym_switch] = ACTIONS(5942),
    [anon_sym_DOT_DOT] = ACTIONS(5942),
    [anon_sym_and] = ACTIONS(5942),
    [anon_sym_or] = ACTIONS(5944),
    [anon_sym_AMP_AMP] = ACTIONS(5942),
    [anon_sym_PIPE_PIPE] = ACTIONS(5942),
    [anon_sym_QMARK_QMARK] = ACTIONS(5942),
    [anon_sym_from] = ACTIONS(5942),
    [anon_sym_into] = ACTIONS(5942),
    [anon_sym_join] = ACTIONS(5942),
    [anon_sym_let] = ACTIONS(5942),
    [anon_sym_orderby] = ACTIONS(5942),
    [anon_sym_ascending] = ACTIONS(5942),
    [anon_sym_descending] = ACTIONS(5942),
    [anon_sym_group] = ACTIONS(5942),
    [anon_sym_select] = ACTIONS(5942),
    [anon_sym_as] = ACTIONS(5944),
    [anon_sym_is] = ACTIONS(5942),
    [anon_sym_DASH_GT] = ACTIONS(5942),
    [anon_sym_with] = ACTIONS(5942),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4609] = {
    [sym_preproc_region] = STATE(4609),
    [sym_preproc_endregion] = STATE(4609),
    [sym_preproc_line] = STATE(4609),
    [sym_preproc_pragma] = STATE(4609),
    [sym_preproc_nullable] = STATE(4609),
    [sym_preproc_error] = STATE(4609),
    [sym_preproc_warning] = STATE(4609),
    [sym_preproc_define] = STATE(4609),
    [sym_preproc_undef] = STATE(4609),
    [anon_sym_LBRACK] = ACTIONS(5946),
    [anon_sym_COMMA] = ACTIONS(5946),
    [anon_sym_LPAREN] = ACTIONS(5946),
    [anon_sym_LT] = ACTIONS(5948),
    [anon_sym_GT] = ACTIONS(5948),
    [anon_sym_where] = ACTIONS(5946),
    [anon_sym_QMARK] = ACTIONS(5948),
    [anon_sym_BANG] = ACTIONS(5948),
    [anon_sym_PLUS_PLUS] = ACTIONS(5946),
    [anon_sym_DASH_DASH] = ACTIONS(5946),
    [anon_sym_PLUS] = ACTIONS(5948),
    [anon_sym_DASH] = ACTIONS(5948),
    [anon_sym_STAR] = ACTIONS(5946),
    [anon_sym_SLASH] = ACTIONS(5948),
    [anon_sym_PERCENT] = ACTIONS(5946),
    [anon_sym_CARET] = ACTIONS(5946),
    [anon_sym_PIPE] = ACTIONS(5948),
    [anon_sym_AMP] = ACTIONS(5948),
    [anon_sym_LT_LT] = ACTIONS(5946),
    [anon_sym_GT_GT] = ACTIONS(5948),
    [anon_sym_GT_GT_GT] = ACTIONS(5946),
    [anon_sym_EQ_EQ] = ACTIONS(5946),
    [anon_sym_BANG_EQ] = ACTIONS(5946),
    [anon_sym_GT_EQ] = ACTIONS(5946),
    [anon_sym_LT_EQ] = ACTIONS(5946),
    [anon_sym_DOT] = ACTIONS(5948),
    [anon_sym_switch] = ACTIONS(5946),
    [anon_sym_DOT_DOT] = ACTIONS(5946),
    [anon_sym_and] = ACTIONS(5946),
    [anon_sym_or] = ACTIONS(5948),
    [anon_sym_AMP_AMP] = ACTIONS(5946),
    [anon_sym_PIPE_PIPE] = ACTIONS(5946),
    [anon_sym_QMARK_QMARK] = ACTIONS(5946),
    [anon_sym_from] = ACTIONS(5946),
    [anon_sym_into] = ACTIONS(5946),
    [anon_sym_join] = ACTIONS(5946),
    [anon_sym_let] = ACTIONS(5946),
    [anon_sym_orderby] = ACTIONS(5946),
    [anon_sym_ascending] = ACTIONS(5946),
    [anon_sym_descending] = ACTIONS(5946),
    [anon_sym_group] = ACTIONS(5946),
    [anon_sym_select] = ACTIONS(5946),
    [anon_sym_as] = ACTIONS(5948),
    [anon_sym_is] = ACTIONS(5946),
    [anon_sym_DASH_GT] = ACTIONS(5946),
    [anon_sym_with] = ACTIONS(5946),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4610] = {
    [sym_preproc_region] = STATE(4610),
    [sym_preproc_endregion] = STATE(4610),
    [sym_preproc_line] = STATE(4610),
    [sym_preproc_pragma] = STATE(4610),
    [sym_preproc_nullable] = STATE(4610),
    [sym_preproc_error] = STATE(4610),
    [sym_preproc_warning] = STATE(4610),
    [sym_preproc_define] = STATE(4610),
    [sym_preproc_undef] = STATE(4610),
    [anon_sym_LBRACK] = ACTIONS(5956),
    [anon_sym_COMMA] = ACTIONS(5956),
    [anon_sym_LPAREN] = ACTIONS(5956),
    [anon_sym_LT] = ACTIONS(5958),
    [anon_sym_GT] = ACTIONS(5958),
    [anon_sym_where] = ACTIONS(5956),
    [anon_sym_QMARK] = ACTIONS(5958),
    [anon_sym_BANG] = ACTIONS(5958),
    [anon_sym_PLUS_PLUS] = ACTIONS(5956),
    [anon_sym_DASH_DASH] = ACTIONS(5956),
    [anon_sym_PLUS] = ACTIONS(5958),
    [anon_sym_DASH] = ACTIONS(5958),
    [anon_sym_STAR] = ACTIONS(5956),
    [anon_sym_SLASH] = ACTIONS(5958),
    [anon_sym_PERCENT] = ACTIONS(5956),
    [anon_sym_CARET] = ACTIONS(5956),
    [anon_sym_PIPE] = ACTIONS(5958),
    [anon_sym_AMP] = ACTIONS(5958),
    [anon_sym_LT_LT] = ACTIONS(5956),
    [anon_sym_GT_GT] = ACTIONS(5958),
    [anon_sym_GT_GT_GT] = ACTIONS(5956),
    [anon_sym_EQ_EQ] = ACTIONS(5956),
    [anon_sym_BANG_EQ] = ACTIONS(5956),
    [anon_sym_GT_EQ] = ACTIONS(5956),
    [anon_sym_LT_EQ] = ACTIONS(5956),
    [anon_sym_DOT] = ACTIONS(5958),
    [anon_sym_switch] = ACTIONS(5956),
    [anon_sym_DOT_DOT] = ACTIONS(5956),
    [anon_sym_and] = ACTIONS(5956),
    [anon_sym_or] = ACTIONS(5958),
    [anon_sym_AMP_AMP] = ACTIONS(5956),
    [anon_sym_PIPE_PIPE] = ACTIONS(5956),
    [anon_sym_QMARK_QMARK] = ACTIONS(5956),
    [anon_sym_from] = ACTIONS(5956),
    [anon_sym_into] = ACTIONS(5956),
    [anon_sym_join] = ACTIONS(5956),
    [anon_sym_let] = ACTIONS(5956),
    [anon_sym_orderby] = ACTIONS(5956),
    [anon_sym_ascending] = ACTIONS(5956),
    [anon_sym_descending] = ACTIONS(5956),
    [anon_sym_group] = ACTIONS(5956),
    [anon_sym_select] = ACTIONS(5956),
    [anon_sym_as] = ACTIONS(5958),
    [anon_sym_is] = ACTIONS(5956),
    [anon_sym_DASH_GT] = ACTIONS(5956),
    [anon_sym_with] = ACTIONS(5956),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4611] = {
    [sym_preproc_region] = STATE(4611),
    [sym_preproc_endregion] = STATE(4611),
    [sym_preproc_line] = STATE(4611),
    [sym_preproc_pragma] = STATE(4611),
    [sym_preproc_nullable] = STATE(4611),
    [sym_preproc_error] = STATE(4611),
    [sym_preproc_warning] = STATE(4611),
    [sym_preproc_define] = STATE(4611),
    [sym_preproc_undef] = STATE(4611),
    [anon_sym_LBRACK] = ACTIONS(5928),
    [anon_sym_COMMA] = ACTIONS(5928),
    [anon_sym_LPAREN] = ACTIONS(5928),
    [anon_sym_LT] = ACTIONS(5930),
    [anon_sym_GT] = ACTIONS(5930),
    [anon_sym_where] = ACTIONS(5928),
    [anon_sym_QMARK] = ACTIONS(5930),
    [anon_sym_BANG] = ACTIONS(5930),
    [anon_sym_PLUS_PLUS] = ACTIONS(5928),
    [anon_sym_DASH_DASH] = ACTIONS(5928),
    [anon_sym_PLUS] = ACTIONS(5930),
    [anon_sym_DASH] = ACTIONS(5930),
    [anon_sym_STAR] = ACTIONS(5928),
    [anon_sym_SLASH] = ACTIONS(5930),
    [anon_sym_PERCENT] = ACTIONS(5928),
    [anon_sym_CARET] = ACTIONS(5928),
    [anon_sym_PIPE] = ACTIONS(5930),
    [anon_sym_AMP] = ACTIONS(5930),
    [anon_sym_LT_LT] = ACTIONS(5928),
    [anon_sym_GT_GT] = ACTIONS(5930),
    [anon_sym_GT_GT_GT] = ACTIONS(5928),
    [anon_sym_EQ_EQ] = ACTIONS(5928),
    [anon_sym_BANG_EQ] = ACTIONS(5928),
    [anon_sym_GT_EQ] = ACTIONS(5928),
    [anon_sym_LT_EQ] = ACTIONS(5928),
    [anon_sym_DOT] = ACTIONS(5930),
    [anon_sym_switch] = ACTIONS(5928),
    [anon_sym_DOT_DOT] = ACTIONS(5928),
    [anon_sym_and] = ACTIONS(5928),
    [anon_sym_or] = ACTIONS(5930),
    [anon_sym_AMP_AMP] = ACTIONS(5928),
    [anon_sym_PIPE_PIPE] = ACTIONS(5928),
    [anon_sym_QMARK_QMARK] = ACTIONS(5928),
    [anon_sym_from] = ACTIONS(5928),
    [anon_sym_into] = ACTIONS(5928),
    [anon_sym_join] = ACTIONS(5928),
    [anon_sym_let] = ACTIONS(5928),
    [anon_sym_orderby] = ACTIONS(5928),
    [anon_sym_ascending] = ACTIONS(5928),
    [anon_sym_descending] = ACTIONS(5928),
    [anon_sym_group] = ACTIONS(5928),
    [anon_sym_select] = ACTIONS(5928),
    [anon_sym_as] = ACTIONS(5930),
    [anon_sym_is] = ACTIONS(5928),
    [anon_sym_DASH_GT] = ACTIONS(5928),
    [anon_sym_with] = ACTIONS(5928),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4612] = {
    [sym_preproc_region] = STATE(4612),
    [sym_preproc_endregion] = STATE(4612),
    [sym_preproc_line] = STATE(4612),
    [sym_preproc_pragma] = STATE(4612),
    [sym_preproc_nullable] = STATE(4612),
    [sym_preproc_error] = STATE(4612),
    [sym_preproc_warning] = STATE(4612),
    [sym_preproc_define] = STATE(4612),
    [sym_preproc_undef] = STATE(4612),
    [anon_sym_LBRACK] = ACTIONS(5928),
    [anon_sym_COMMA] = ACTIONS(5928),
    [anon_sym_LPAREN] = ACTIONS(5928),
    [anon_sym_LT] = ACTIONS(5930),
    [anon_sym_GT] = ACTIONS(5930),
    [anon_sym_where] = ACTIONS(5928),
    [anon_sym_QMARK] = ACTIONS(5930),
    [anon_sym_BANG] = ACTIONS(5930),
    [anon_sym_PLUS_PLUS] = ACTIONS(5928),
    [anon_sym_DASH_DASH] = ACTIONS(5928),
    [anon_sym_PLUS] = ACTIONS(5930),
    [anon_sym_DASH] = ACTIONS(5930),
    [anon_sym_STAR] = ACTIONS(5928),
    [anon_sym_SLASH] = ACTIONS(5930),
    [anon_sym_PERCENT] = ACTIONS(5928),
    [anon_sym_CARET] = ACTIONS(5928),
    [anon_sym_PIPE] = ACTIONS(5930),
    [anon_sym_AMP] = ACTIONS(5930),
    [anon_sym_LT_LT] = ACTIONS(5928),
    [anon_sym_GT_GT] = ACTIONS(5930),
    [anon_sym_GT_GT_GT] = ACTIONS(5928),
    [anon_sym_EQ_EQ] = ACTIONS(5928),
    [anon_sym_BANG_EQ] = ACTIONS(5928),
    [anon_sym_GT_EQ] = ACTIONS(5928),
    [anon_sym_LT_EQ] = ACTIONS(5928),
    [anon_sym_DOT] = ACTIONS(5930),
    [anon_sym_switch] = ACTIONS(5928),
    [anon_sym_DOT_DOT] = ACTIONS(5928),
    [anon_sym_and] = ACTIONS(5928),
    [anon_sym_or] = ACTIONS(5930),
    [anon_sym_AMP_AMP] = ACTIONS(5928),
    [anon_sym_PIPE_PIPE] = ACTIONS(5928),
    [anon_sym_QMARK_QMARK] = ACTIONS(5928),
    [anon_sym_from] = ACTIONS(5928),
    [anon_sym_into] = ACTIONS(5928),
    [anon_sym_join] = ACTIONS(5928),
    [anon_sym_let] = ACTIONS(5928),
    [anon_sym_orderby] = ACTIONS(5928),
    [anon_sym_ascending] = ACTIONS(5928),
    [anon_sym_descending] = ACTIONS(5928),
    [anon_sym_group] = ACTIONS(5928),
    [anon_sym_select] = ACTIONS(5928),
    [anon_sym_as] = ACTIONS(5930),
    [anon_sym_is] = ACTIONS(5928),
    [anon_sym_DASH_GT] = ACTIONS(5928),
    [anon_sym_with] = ACTIONS(5928),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4613] = {
    [sym_preproc_region] = STATE(4613),
    [sym_preproc_endregion] = STATE(4613),
    [sym_preproc_line] = STATE(4613),
    [sym_preproc_pragma] = STATE(4613),
    [sym_preproc_nullable] = STATE(4613),
    [sym_preproc_error] = STATE(4613),
    [sym_preproc_warning] = STATE(4613),
    [sym_preproc_define] = STATE(4613),
    [sym_preproc_undef] = STATE(4613),
    [anon_sym_LBRACK] = ACTIONS(5909),
    [anon_sym_COMMA] = ACTIONS(5909),
    [anon_sym_LPAREN] = ACTIONS(5909),
    [anon_sym_LT] = ACTIONS(5911),
    [anon_sym_GT] = ACTIONS(5911),
    [anon_sym_where] = ACTIONS(5909),
    [anon_sym_QMARK] = ACTIONS(5911),
    [anon_sym_BANG] = ACTIONS(5911),
    [anon_sym_PLUS_PLUS] = ACTIONS(5909),
    [anon_sym_DASH_DASH] = ACTIONS(5909),
    [anon_sym_PLUS] = ACTIONS(5911),
    [anon_sym_DASH] = ACTIONS(5911),
    [anon_sym_STAR] = ACTIONS(5909),
    [anon_sym_SLASH] = ACTIONS(5911),
    [anon_sym_PERCENT] = ACTIONS(5909),
    [anon_sym_CARET] = ACTIONS(5909),
    [anon_sym_PIPE] = ACTIONS(5911),
    [anon_sym_AMP] = ACTIONS(5911),
    [anon_sym_LT_LT] = ACTIONS(5909),
    [anon_sym_GT_GT] = ACTIONS(5911),
    [anon_sym_GT_GT_GT] = ACTIONS(5909),
    [anon_sym_EQ_EQ] = ACTIONS(5909),
    [anon_sym_BANG_EQ] = ACTIONS(5909),
    [anon_sym_GT_EQ] = ACTIONS(5909),
    [anon_sym_LT_EQ] = ACTIONS(5909),
    [anon_sym_DOT] = ACTIONS(5911),
    [anon_sym_switch] = ACTIONS(5909),
    [anon_sym_DOT_DOT] = ACTIONS(5909),
    [anon_sym_and] = ACTIONS(5909),
    [anon_sym_or] = ACTIONS(5911),
    [anon_sym_AMP_AMP] = ACTIONS(5909),
    [anon_sym_PIPE_PIPE] = ACTIONS(5909),
    [anon_sym_QMARK_QMARK] = ACTIONS(5909),
    [anon_sym_from] = ACTIONS(5909),
    [anon_sym_into] = ACTIONS(5909),
    [anon_sym_join] = ACTIONS(5909),
    [anon_sym_let] = ACTIONS(5909),
    [anon_sym_orderby] = ACTIONS(5909),
    [anon_sym_ascending] = ACTIONS(5909),
    [anon_sym_descending] = ACTIONS(5909),
    [anon_sym_group] = ACTIONS(5909),
    [anon_sym_select] = ACTIONS(5909),
    [anon_sym_as] = ACTIONS(5911),
    [anon_sym_is] = ACTIONS(5909),
    [anon_sym_DASH_GT] = ACTIONS(5909),
    [anon_sym_with] = ACTIONS(5909),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4614] = {
    [sym_preproc_region] = STATE(4614),
    [sym_preproc_endregion] = STATE(4614),
    [sym_preproc_line] = STATE(4614),
    [sym_preproc_pragma] = STATE(4614),
    [sym_preproc_nullable] = STATE(4614),
    [sym_preproc_error] = STATE(4614),
    [sym_preproc_warning] = STATE(4614),
    [sym_preproc_define] = STATE(4614),
    [sym_preproc_undef] = STATE(4614),
    [anon_sym_LBRACK] = ACTIONS(5938),
    [anon_sym_COMMA] = ACTIONS(5938),
    [anon_sym_LPAREN] = ACTIONS(5938),
    [anon_sym_LT] = ACTIONS(5940),
    [anon_sym_GT] = ACTIONS(5940),
    [anon_sym_where] = ACTIONS(5938),
    [anon_sym_QMARK] = ACTIONS(5940),
    [anon_sym_BANG] = ACTIONS(5940),
    [anon_sym_PLUS_PLUS] = ACTIONS(5938),
    [anon_sym_DASH_DASH] = ACTIONS(5938),
    [anon_sym_PLUS] = ACTIONS(5940),
    [anon_sym_DASH] = ACTIONS(5940),
    [anon_sym_STAR] = ACTIONS(5938),
    [anon_sym_SLASH] = ACTIONS(5940),
    [anon_sym_PERCENT] = ACTIONS(5938),
    [anon_sym_CARET] = ACTIONS(5938),
    [anon_sym_PIPE] = ACTIONS(5940),
    [anon_sym_AMP] = ACTIONS(5940),
    [anon_sym_LT_LT] = ACTIONS(5938),
    [anon_sym_GT_GT] = ACTIONS(5940),
    [anon_sym_GT_GT_GT] = ACTIONS(5938),
    [anon_sym_EQ_EQ] = ACTIONS(5938),
    [anon_sym_BANG_EQ] = ACTIONS(5938),
    [anon_sym_GT_EQ] = ACTIONS(5938),
    [anon_sym_LT_EQ] = ACTIONS(5938),
    [anon_sym_DOT] = ACTIONS(5940),
    [anon_sym_switch] = ACTIONS(5938),
    [anon_sym_DOT_DOT] = ACTIONS(5938),
    [anon_sym_and] = ACTIONS(5938),
    [anon_sym_or] = ACTIONS(5940),
    [anon_sym_AMP_AMP] = ACTIONS(5938),
    [anon_sym_PIPE_PIPE] = ACTIONS(5938),
    [anon_sym_QMARK_QMARK] = ACTIONS(5938),
    [anon_sym_from] = ACTIONS(5938),
    [anon_sym_into] = ACTIONS(5938),
    [anon_sym_join] = ACTIONS(5938),
    [anon_sym_let] = ACTIONS(5938),
    [anon_sym_orderby] = ACTIONS(5938),
    [anon_sym_ascending] = ACTIONS(5938),
    [anon_sym_descending] = ACTIONS(5938),
    [anon_sym_group] = ACTIONS(5938),
    [anon_sym_select] = ACTIONS(5938),
    [anon_sym_as] = ACTIONS(5940),
    [anon_sym_is] = ACTIONS(5938),
    [anon_sym_DASH_GT] = ACTIONS(5938),
    [anon_sym_with] = ACTIONS(5938),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4615] = {
    [sym__name] = STATE(6202),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_ref_type] = STATE(2883),
    [sym__scoped_base_type] = STATE(2885),
    [sym_identifier] = STATE(5346),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_region] = STATE(4615),
    [sym_preproc_endregion] = STATE(4615),
    [sym_preproc_line] = STATE(4615),
    [sym_preproc_pragma] = STATE(4615),
    [sym_preproc_nullable] = STATE(4615),
    [sym_preproc_error] = STATE(4615),
    [sym_preproc_warning] = STATE(4615),
    [sym_preproc_define] = STATE(4615),
    [sym_preproc_undef] = STATE(4615),
    [sym__identifier_token] = ACTIONS(4072),
    [anon_sym_alias] = ACTIONS(4075),
    [anon_sym_SEMI] = ACTIONS(3993),
    [anon_sym_global] = ACTIONS(4075),
    [anon_sym_EQ] = ACTIONS(3995),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_LPAREN] = ACTIONS(3993),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_file] = ACTIONS(4075),
    [anon_sym_LT] = ACTIONS(3993),
    [anon_sym_in] = ACTIONS(3995),
    [anon_sym_where] = ACTIONS(4075),
    [anon_sym_QMARK] = ACTIONS(3993),
    [anon_sym_notnull] = ACTIONS(4075),
    [anon_sym_unmanaged] = ACTIONS(4075),
    [anon_sym_operator] = ACTIONS(3995),
    [anon_sym_STAR] = ACTIONS(3993),
    [anon_sym_this] = ACTIONS(3995),
    [anon_sym_DOT] = ACTIONS(3993),
    [anon_sym_scoped] = ACTIONS(4075),
    [anon_sym_EQ_GT] = ACTIONS(3993),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(4075),
    [anon_sym_yield] = ACTIONS(4075),
    [anon_sym_when] = ACTIONS(4075),
    [anon_sym_from] = ACTIONS(4075),
    [anon_sym_into] = ACTIONS(4075),
    [anon_sym_join] = ACTIONS(4075),
    [anon_sym_on] = ACTIONS(4075),
    [anon_sym_equals] = ACTIONS(4075),
    [anon_sym_let] = ACTIONS(4075),
    [anon_sym_orderby] = ACTIONS(4075),
    [anon_sym_ascending] = ACTIONS(4075),
    [anon_sym_descending] = ACTIONS(4075),
    [anon_sym_group] = ACTIONS(4075),
    [anon_sym_by] = ACTIONS(4075),
    [anon_sym_select] = ACTIONS(4075),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4616] = {
    [sym_preproc_region] = STATE(4616),
    [sym_preproc_endregion] = STATE(4616),
    [sym_preproc_line] = STATE(4616),
    [sym_preproc_pragma] = STATE(4616),
    [sym_preproc_nullable] = STATE(4616),
    [sym_preproc_error] = STATE(4616),
    [sym_preproc_warning] = STATE(4616),
    [sym_preproc_define] = STATE(4616),
    [sym_preproc_undef] = STATE(4616),
    [anon_sym_LBRACK] = ACTIONS(5652),
    [anon_sym_COMMA] = ACTIONS(5652),
    [anon_sym_LPAREN] = ACTIONS(5652),
    [anon_sym_LT] = ACTIONS(5654),
    [anon_sym_GT] = ACTIONS(5654),
    [anon_sym_where] = ACTIONS(5652),
    [anon_sym_QMARK] = ACTIONS(5654),
    [anon_sym_BANG] = ACTIONS(5654),
    [anon_sym_PLUS_PLUS] = ACTIONS(5652),
    [anon_sym_DASH_DASH] = ACTIONS(5652),
    [anon_sym_PLUS] = ACTIONS(5654),
    [anon_sym_DASH] = ACTIONS(5654),
    [anon_sym_STAR] = ACTIONS(5652),
    [anon_sym_SLASH] = ACTIONS(5654),
    [anon_sym_PERCENT] = ACTIONS(5652),
    [anon_sym_CARET] = ACTIONS(5652),
    [anon_sym_PIPE] = ACTIONS(5654),
    [anon_sym_AMP] = ACTIONS(5654),
    [anon_sym_LT_LT] = ACTIONS(5652),
    [anon_sym_GT_GT] = ACTIONS(5654),
    [anon_sym_GT_GT_GT] = ACTIONS(5652),
    [anon_sym_EQ_EQ] = ACTIONS(5652),
    [anon_sym_BANG_EQ] = ACTIONS(5652),
    [anon_sym_GT_EQ] = ACTIONS(5652),
    [anon_sym_LT_EQ] = ACTIONS(5652),
    [anon_sym_DOT] = ACTIONS(5654),
    [anon_sym_switch] = ACTIONS(5652),
    [anon_sym_DOT_DOT] = ACTIONS(5652),
    [anon_sym_and] = ACTIONS(5652),
    [anon_sym_or] = ACTIONS(5654),
    [anon_sym_AMP_AMP] = ACTIONS(5652),
    [anon_sym_PIPE_PIPE] = ACTIONS(5652),
    [anon_sym_QMARK_QMARK] = ACTIONS(5652),
    [anon_sym_from] = ACTIONS(5652),
    [anon_sym_into] = ACTIONS(5652),
    [anon_sym_join] = ACTIONS(5652),
    [anon_sym_let] = ACTIONS(5652),
    [anon_sym_orderby] = ACTIONS(5652),
    [anon_sym_ascending] = ACTIONS(5652),
    [anon_sym_descending] = ACTIONS(5652),
    [anon_sym_group] = ACTIONS(5652),
    [anon_sym_select] = ACTIONS(5652),
    [anon_sym_as] = ACTIONS(5654),
    [anon_sym_is] = ACTIONS(5652),
    [anon_sym_DASH_GT] = ACTIONS(5652),
    [anon_sym_with] = ACTIONS(5652),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4617] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4617),
    [sym_preproc_endregion] = STATE(4617),
    [sym_preproc_line] = STATE(4617),
    [sym_preproc_pragma] = STATE(4617),
    [sym_preproc_nullable] = STATE(4617),
    [sym_preproc_error] = STATE(4617),
    [sym_preproc_warning] = STATE(4617),
    [sym_preproc_define] = STATE(4617),
    [sym_preproc_undef] = STATE(4617),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(6342),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(6344),
    [anon_sym_GT] = ACTIONS(6344),
    [anon_sym_where] = ACTIONS(6342),
    [anon_sym_QMARK] = ACTIONS(6344),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(6550),
    [anon_sym_DASH] = ACTIONS(6550),
    [anon_sym_STAR] = ACTIONS(6552),
    [anon_sym_SLASH] = ACTIONS(6554),
    [anon_sym_PERCENT] = ACTIONS(6552),
    [anon_sym_CARET] = ACTIONS(6342),
    [anon_sym_PIPE] = ACTIONS(6344),
    [anon_sym_AMP] = ACTIONS(6344),
    [anon_sym_LT_LT] = ACTIONS(6562),
    [anon_sym_GT_GT] = ACTIONS(6564),
    [anon_sym_GT_GT_GT] = ACTIONS(6562),
    [anon_sym_EQ_EQ] = ACTIONS(6342),
    [anon_sym_BANG_EQ] = ACTIONS(6342),
    [anon_sym_GT_EQ] = ACTIONS(6342),
    [anon_sym_LT_EQ] = ACTIONS(6342),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(6216),
    [anon_sym_DOT_DOT] = ACTIONS(6570),
    [anon_sym_AMP_AMP] = ACTIONS(6342),
    [anon_sym_PIPE_PIPE] = ACTIONS(6342),
    [anon_sym_QMARK_QMARK] = ACTIONS(6342),
    [anon_sym_from] = ACTIONS(6342),
    [anon_sym_into] = ACTIONS(6342),
    [anon_sym_join] = ACTIONS(6342),
    [anon_sym_let] = ACTIONS(6342),
    [anon_sym_orderby] = ACTIONS(6342),
    [anon_sym_ascending] = ACTIONS(6342),
    [anon_sym_descending] = ACTIONS(6342),
    [anon_sym_group] = ACTIONS(6342),
    [anon_sym_select] = ACTIONS(6342),
    [anon_sym_as] = ACTIONS(6344),
    [anon_sym_is] = ACTIONS(6342),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(6232),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4618] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4618),
    [sym_preproc_endregion] = STATE(4618),
    [sym_preproc_line] = STATE(4618),
    [sym_preproc_pragma] = STATE(4618),
    [sym_preproc_nullable] = STATE(4618),
    [sym_preproc_error] = STATE(4618),
    [sym_preproc_warning] = STATE(4618),
    [sym_preproc_define] = STATE(4618),
    [sym_preproc_undef] = STATE(4618),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(6342),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(6344),
    [anon_sym_GT] = ACTIONS(6344),
    [anon_sym_where] = ACTIONS(6342),
    [anon_sym_QMARK] = ACTIONS(6344),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(6344),
    [anon_sym_DASH] = ACTIONS(6344),
    [anon_sym_STAR] = ACTIONS(6552),
    [anon_sym_SLASH] = ACTIONS(6554),
    [anon_sym_PERCENT] = ACTIONS(6552),
    [anon_sym_CARET] = ACTIONS(6342),
    [anon_sym_PIPE] = ACTIONS(6344),
    [anon_sym_AMP] = ACTIONS(6344),
    [anon_sym_LT_LT] = ACTIONS(6342),
    [anon_sym_GT_GT] = ACTIONS(6344),
    [anon_sym_GT_GT_GT] = ACTIONS(6342),
    [anon_sym_EQ_EQ] = ACTIONS(6342),
    [anon_sym_BANG_EQ] = ACTIONS(6342),
    [anon_sym_GT_EQ] = ACTIONS(6342),
    [anon_sym_LT_EQ] = ACTIONS(6342),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(6216),
    [anon_sym_DOT_DOT] = ACTIONS(6570),
    [anon_sym_AMP_AMP] = ACTIONS(6342),
    [anon_sym_PIPE_PIPE] = ACTIONS(6342),
    [anon_sym_QMARK_QMARK] = ACTIONS(6342),
    [anon_sym_from] = ACTIONS(6342),
    [anon_sym_into] = ACTIONS(6342),
    [anon_sym_join] = ACTIONS(6342),
    [anon_sym_let] = ACTIONS(6342),
    [anon_sym_orderby] = ACTIONS(6342),
    [anon_sym_ascending] = ACTIONS(6342),
    [anon_sym_descending] = ACTIONS(6342),
    [anon_sym_group] = ACTIONS(6342),
    [anon_sym_select] = ACTIONS(6342),
    [anon_sym_as] = ACTIONS(6344),
    [anon_sym_is] = ACTIONS(6342),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(6232),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4619] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4619),
    [sym_preproc_endregion] = STATE(4619),
    [sym_preproc_line] = STATE(4619),
    [sym_preproc_pragma] = STATE(4619),
    [sym_preproc_nullable] = STATE(4619),
    [sym_preproc_error] = STATE(4619),
    [sym_preproc_warning] = STATE(4619),
    [sym_preproc_define] = STATE(4619),
    [sym_preproc_undef] = STATE(4619),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(6342),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(6344),
    [anon_sym_GT] = ACTIONS(6344),
    [anon_sym_where] = ACTIONS(6342),
    [anon_sym_QMARK] = ACTIONS(6344),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(6344),
    [anon_sym_DASH] = ACTIONS(6344),
    [anon_sym_STAR] = ACTIONS(6342),
    [anon_sym_SLASH] = ACTIONS(6344),
    [anon_sym_PERCENT] = ACTIONS(6342),
    [anon_sym_CARET] = ACTIONS(6342),
    [anon_sym_PIPE] = ACTIONS(6344),
    [anon_sym_AMP] = ACTIONS(6344),
    [anon_sym_LT_LT] = ACTIONS(6342),
    [anon_sym_GT_GT] = ACTIONS(6344),
    [anon_sym_GT_GT_GT] = ACTIONS(6342),
    [anon_sym_EQ_EQ] = ACTIONS(6342),
    [anon_sym_BANG_EQ] = ACTIONS(6342),
    [anon_sym_GT_EQ] = ACTIONS(6342),
    [anon_sym_LT_EQ] = ACTIONS(6342),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(6216),
    [anon_sym_DOT_DOT] = ACTIONS(6570),
    [anon_sym_AMP_AMP] = ACTIONS(6342),
    [anon_sym_PIPE_PIPE] = ACTIONS(6342),
    [anon_sym_QMARK_QMARK] = ACTIONS(6342),
    [anon_sym_from] = ACTIONS(6342),
    [anon_sym_into] = ACTIONS(6342),
    [anon_sym_join] = ACTIONS(6342),
    [anon_sym_let] = ACTIONS(6342),
    [anon_sym_orderby] = ACTIONS(6342),
    [anon_sym_ascending] = ACTIONS(6342),
    [anon_sym_descending] = ACTIONS(6342),
    [anon_sym_group] = ACTIONS(6342),
    [anon_sym_select] = ACTIONS(6342),
    [anon_sym_as] = ACTIONS(6344),
    [anon_sym_is] = ACTIONS(6342),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(6232),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4620] = {
    [sym_preproc_region] = STATE(4620),
    [sym_preproc_endregion] = STATE(4620),
    [sym_preproc_line] = STATE(4620),
    [sym_preproc_pragma] = STATE(4620),
    [sym_preproc_nullable] = STATE(4620),
    [sym_preproc_error] = STATE(4620),
    [sym_preproc_warning] = STATE(4620),
    [sym_preproc_define] = STATE(4620),
    [sym_preproc_undef] = STATE(4620),
    [anon_sym_LBRACK] = ACTIONS(2031),
    [anon_sym_COMMA] = ACTIONS(2031),
    [anon_sym_LPAREN] = ACTIONS(6632),
    [anon_sym_LT] = ACTIONS(2029),
    [anon_sym_GT] = ACTIONS(2029),
    [anon_sym_where] = ACTIONS(2031),
    [anon_sym_QMARK] = ACTIONS(2029),
    [anon_sym_BANG] = ACTIONS(2029),
    [anon_sym_PLUS_PLUS] = ACTIONS(2031),
    [anon_sym_DASH_DASH] = ACTIONS(2031),
    [anon_sym_PLUS] = ACTIONS(2029),
    [anon_sym_DASH] = ACTIONS(2029),
    [anon_sym_STAR] = ACTIONS(2031),
    [anon_sym_SLASH] = ACTIONS(2029),
    [anon_sym_PERCENT] = ACTIONS(2031),
    [anon_sym_CARET] = ACTIONS(2031),
    [anon_sym_PIPE] = ACTIONS(2029),
    [anon_sym_AMP] = ACTIONS(2029),
    [anon_sym_LT_LT] = ACTIONS(2031),
    [anon_sym_GT_GT] = ACTIONS(2029),
    [anon_sym_GT_GT_GT] = ACTIONS(2031),
    [anon_sym_EQ_EQ] = ACTIONS(2031),
    [anon_sym_BANG_EQ] = ACTIONS(2031),
    [anon_sym_GT_EQ] = ACTIONS(2031),
    [anon_sym_LT_EQ] = ACTIONS(2031),
    [anon_sym_DOT] = ACTIONS(2029),
    [anon_sym_switch] = ACTIONS(2031),
    [anon_sym_DOT_DOT] = ACTIONS(2031),
    [anon_sym_and] = ACTIONS(2031),
    [anon_sym_or] = ACTIONS(2029),
    [anon_sym_AMP_AMP] = ACTIONS(2031),
    [anon_sym_PIPE_PIPE] = ACTIONS(2031),
    [anon_sym_QMARK_QMARK] = ACTIONS(2031),
    [anon_sym_from] = ACTIONS(2031),
    [anon_sym_into] = ACTIONS(2031),
    [anon_sym_join] = ACTIONS(2031),
    [anon_sym_let] = ACTIONS(2031),
    [anon_sym_orderby] = ACTIONS(2031),
    [anon_sym_ascending] = ACTIONS(2031),
    [anon_sym_descending] = ACTIONS(2031),
    [anon_sym_group] = ACTIONS(2031),
    [anon_sym_select] = ACTIONS(2031),
    [anon_sym_as] = ACTIONS(2029),
    [anon_sym_is] = ACTIONS(2031),
    [anon_sym_DASH_GT] = ACTIONS(2031),
    [anon_sym_with] = ACTIONS(2031),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4621] = {
    [sym_preproc_region] = STATE(4621),
    [sym_preproc_endregion] = STATE(4621),
    [sym_preproc_line] = STATE(4621),
    [sym_preproc_pragma] = STATE(4621),
    [sym_preproc_nullable] = STATE(4621),
    [sym_preproc_error] = STATE(4621),
    [sym_preproc_warning] = STATE(4621),
    [sym_preproc_define] = STATE(4621),
    [sym_preproc_undef] = STATE(4621),
    [anon_sym_LBRACK] = ACTIONS(5576),
    [anon_sym_COMMA] = ACTIONS(5576),
    [anon_sym_LPAREN] = ACTIONS(5576),
    [anon_sym_LT] = ACTIONS(5578),
    [anon_sym_GT] = ACTIONS(5578),
    [anon_sym_where] = ACTIONS(5576),
    [anon_sym_QMARK] = ACTIONS(5578),
    [anon_sym_BANG] = ACTIONS(5578),
    [anon_sym_PLUS_PLUS] = ACTIONS(5576),
    [anon_sym_DASH_DASH] = ACTIONS(5576),
    [anon_sym_PLUS] = ACTIONS(5578),
    [anon_sym_DASH] = ACTIONS(5578),
    [anon_sym_STAR] = ACTIONS(5576),
    [anon_sym_SLASH] = ACTIONS(5578),
    [anon_sym_PERCENT] = ACTIONS(5576),
    [anon_sym_CARET] = ACTIONS(5576),
    [anon_sym_PIPE] = ACTIONS(5578),
    [anon_sym_AMP] = ACTIONS(5578),
    [anon_sym_LT_LT] = ACTIONS(5576),
    [anon_sym_GT_GT] = ACTIONS(5578),
    [anon_sym_GT_GT_GT] = ACTIONS(5576),
    [anon_sym_EQ_EQ] = ACTIONS(5576),
    [anon_sym_BANG_EQ] = ACTIONS(5576),
    [anon_sym_GT_EQ] = ACTIONS(5576),
    [anon_sym_LT_EQ] = ACTIONS(5576),
    [anon_sym_DOT] = ACTIONS(5578),
    [anon_sym_switch] = ACTIONS(5576),
    [anon_sym_DOT_DOT] = ACTIONS(5576),
    [anon_sym_and] = ACTIONS(5576),
    [anon_sym_or] = ACTIONS(5578),
    [anon_sym_AMP_AMP] = ACTIONS(5576),
    [anon_sym_PIPE_PIPE] = ACTIONS(5576),
    [anon_sym_QMARK_QMARK] = ACTIONS(5576),
    [anon_sym_from] = ACTIONS(5576),
    [anon_sym_into] = ACTIONS(5576),
    [anon_sym_join] = ACTIONS(5576),
    [anon_sym_let] = ACTIONS(5576),
    [anon_sym_orderby] = ACTIONS(5576),
    [anon_sym_ascending] = ACTIONS(5576),
    [anon_sym_descending] = ACTIONS(5576),
    [anon_sym_group] = ACTIONS(5576),
    [anon_sym_select] = ACTIONS(5576),
    [anon_sym_as] = ACTIONS(5578),
    [anon_sym_is] = ACTIONS(5576),
    [anon_sym_DASH_GT] = ACTIONS(5576),
    [anon_sym_with] = ACTIONS(5576),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4622] = {
    [sym__name] = STATE(3744),
    [sym_alias_qualified_name] = STATE(3680),
    [sym__simple_name] = STATE(3680),
    [sym_qualified_name] = STATE(3680),
    [sym_generic_name] = STATE(3648),
    [sym_type] = STATE(3731),
    [sym_implicit_type] = STATE(3707),
    [sym_array_type] = STATE(3725),
    [sym__array_base_type] = STATE(8829),
    [sym_nullable_type] = STATE(3681),
    [sym_pointer_type] = STATE(3681),
    [sym__pointer_base_type] = STATE(9538),
    [sym_function_pointer_type] = STATE(3681),
    [sym_ref_type] = STATE(3707),
    [sym_scoped_type] = STATE(3707),
    [sym_tuple_type] = STATE(3631),
    [sym_identifier] = STATE(3590),
    [sym__reserved_identifier] = STATE(3625),
    [sym_preproc_region] = STATE(4622),
    [sym_preproc_endregion] = STATE(4622),
    [sym_preproc_line] = STATE(4622),
    [sym_preproc_pragma] = STATE(4622),
    [sym_preproc_nullable] = STATE(4622),
    [sym_preproc_error] = STATE(4622),
    [sym_preproc_warning] = STATE(4622),
    [sym_preproc_define] = STATE(4622),
    [sym_preproc_undef] = STATE(4622),
    [sym__identifier_token] = ACTIONS(4349),
    [anon_sym_alias] = ACTIONS(4351),
    [anon_sym_global] = ACTIONS(4351),
    [anon_sym_LPAREN] = ACTIONS(6584),
    [anon_sym_ref] = ACTIONS(4723),
    [anon_sym_delegate] = ACTIONS(4512),
    [anon_sym_file] = ACTIONS(4351),
    [anon_sym_readonly] = ACTIONS(6634),
    [anon_sym_where] = ACTIONS(4351),
    [anon_sym_notnull] = ACTIONS(4351),
    [anon_sym_unmanaged] = ACTIONS(4351),
    [anon_sym_scoped] = ACTIONS(6352),
    [anon_sym_var] = ACTIONS(4516),
    [sym_predefined_type] = ACTIONS(4518),
    [anon_sym_yield] = ACTIONS(4351),
    [anon_sym_when] = ACTIONS(4351),
    [anon_sym_from] = ACTIONS(4351),
    [anon_sym_into] = ACTIONS(4351),
    [anon_sym_join] = ACTIONS(4351),
    [anon_sym_on] = ACTIONS(4351),
    [anon_sym_equals] = ACTIONS(4351),
    [anon_sym_let] = ACTIONS(4351),
    [anon_sym_orderby] = ACTIONS(4351),
    [anon_sym_ascending] = ACTIONS(4351),
    [anon_sym_descending] = ACTIONS(4351),
    [anon_sym_group] = ACTIONS(4351),
    [anon_sym_by] = ACTIONS(4351),
    [anon_sym_select] = ACTIONS(4351),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4623] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4623),
    [sym_preproc_endregion] = STATE(4623),
    [sym_preproc_line] = STATE(4623),
    [sym_preproc_pragma] = STATE(4623),
    [sym_preproc_nullable] = STATE(4623),
    [sym_preproc_error] = STATE(4623),
    [sym_preproc_warning] = STATE(4623),
    [sym_preproc_define] = STATE(4623),
    [sym_preproc_undef] = STATE(4623),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(6342),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(6344),
    [anon_sym_GT] = ACTIONS(6344),
    [anon_sym_where] = ACTIONS(6342),
    [anon_sym_QMARK] = ACTIONS(6344),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(6550),
    [anon_sym_DASH] = ACTIONS(6550),
    [anon_sym_STAR] = ACTIONS(6552),
    [anon_sym_SLASH] = ACTIONS(6554),
    [anon_sym_PERCENT] = ACTIONS(6552),
    [anon_sym_CARET] = ACTIONS(6342),
    [anon_sym_PIPE] = ACTIONS(6344),
    [anon_sym_AMP] = ACTIONS(6344),
    [anon_sym_LT_LT] = ACTIONS(6342),
    [anon_sym_GT_GT] = ACTIONS(6344),
    [anon_sym_GT_GT_GT] = ACTIONS(6342),
    [anon_sym_EQ_EQ] = ACTIONS(6342),
    [anon_sym_BANG_EQ] = ACTIONS(6342),
    [anon_sym_GT_EQ] = ACTIONS(6342),
    [anon_sym_LT_EQ] = ACTIONS(6342),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(6216),
    [anon_sym_DOT_DOT] = ACTIONS(6570),
    [anon_sym_AMP_AMP] = ACTIONS(6342),
    [anon_sym_PIPE_PIPE] = ACTIONS(6342),
    [anon_sym_QMARK_QMARK] = ACTIONS(6342),
    [anon_sym_from] = ACTIONS(6342),
    [anon_sym_into] = ACTIONS(6342),
    [anon_sym_join] = ACTIONS(6342),
    [anon_sym_let] = ACTIONS(6342),
    [anon_sym_orderby] = ACTIONS(6342),
    [anon_sym_ascending] = ACTIONS(6342),
    [anon_sym_descending] = ACTIONS(6342),
    [anon_sym_group] = ACTIONS(6342),
    [anon_sym_select] = ACTIONS(6342),
    [anon_sym_as] = ACTIONS(6344),
    [anon_sym_is] = ACTIONS(6342),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(6232),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4624] = {
    [sym_preproc_region] = STATE(4624),
    [sym_preproc_endregion] = STATE(4624),
    [sym_preproc_line] = STATE(4624),
    [sym_preproc_pragma] = STATE(4624),
    [sym_preproc_nullable] = STATE(4624),
    [sym_preproc_error] = STATE(4624),
    [sym_preproc_warning] = STATE(4624),
    [sym_preproc_define] = STATE(4624),
    [sym_preproc_undef] = STATE(4624),
    [anon_sym_LBRACK] = ACTIONS(5588),
    [anon_sym_COMMA] = ACTIONS(5588),
    [anon_sym_LPAREN] = ACTIONS(5588),
    [anon_sym_LT] = ACTIONS(5590),
    [anon_sym_GT] = ACTIONS(5590),
    [anon_sym_where] = ACTIONS(5588),
    [anon_sym_QMARK] = ACTIONS(5590),
    [anon_sym_BANG] = ACTIONS(5590),
    [anon_sym_PLUS_PLUS] = ACTIONS(5588),
    [anon_sym_DASH_DASH] = ACTIONS(5588),
    [anon_sym_PLUS] = ACTIONS(5590),
    [anon_sym_DASH] = ACTIONS(5590),
    [anon_sym_STAR] = ACTIONS(5588),
    [anon_sym_SLASH] = ACTIONS(5590),
    [anon_sym_PERCENT] = ACTIONS(5588),
    [anon_sym_CARET] = ACTIONS(5588),
    [anon_sym_PIPE] = ACTIONS(5590),
    [anon_sym_AMP] = ACTIONS(5590),
    [anon_sym_LT_LT] = ACTIONS(5588),
    [anon_sym_GT_GT] = ACTIONS(5590),
    [anon_sym_GT_GT_GT] = ACTIONS(5588),
    [anon_sym_EQ_EQ] = ACTIONS(5588),
    [anon_sym_BANG_EQ] = ACTIONS(5588),
    [anon_sym_GT_EQ] = ACTIONS(5588),
    [anon_sym_LT_EQ] = ACTIONS(5588),
    [anon_sym_DOT] = ACTIONS(5590),
    [anon_sym_switch] = ACTIONS(5588),
    [anon_sym_DOT_DOT] = ACTIONS(5588),
    [anon_sym_and] = ACTIONS(5588),
    [anon_sym_or] = ACTIONS(5590),
    [anon_sym_AMP_AMP] = ACTIONS(5588),
    [anon_sym_PIPE_PIPE] = ACTIONS(5588),
    [anon_sym_QMARK_QMARK] = ACTIONS(5588),
    [anon_sym_from] = ACTIONS(5588),
    [anon_sym_into] = ACTIONS(5588),
    [anon_sym_join] = ACTIONS(5588),
    [anon_sym_let] = ACTIONS(5588),
    [anon_sym_orderby] = ACTIONS(5588),
    [anon_sym_ascending] = ACTIONS(5588),
    [anon_sym_descending] = ACTIONS(5588),
    [anon_sym_group] = ACTIONS(5588),
    [anon_sym_select] = ACTIONS(5588),
    [anon_sym_as] = ACTIONS(5590),
    [anon_sym_is] = ACTIONS(5588),
    [anon_sym_DASH_GT] = ACTIONS(5588),
    [anon_sym_with] = ACTIONS(5588),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4625] = {
    [sym__name] = STATE(3499),
    [sym_alias_qualified_name] = STATE(3486),
    [sym__simple_name] = STATE(3486),
    [sym_qualified_name] = STATE(3486),
    [sym_generic_name] = STATE(3326),
    [sym_type] = STATE(3395),
    [sym_implicit_type] = STATE(3330),
    [sym_array_type] = STATE(3488),
    [sym__array_base_type] = STATE(8756),
    [sym_nullable_type] = STATE(3489),
    [sym_pointer_type] = STATE(3489),
    [sym__pointer_base_type] = STATE(9221),
    [sym_function_pointer_type] = STATE(3489),
    [sym_ref_type] = STATE(3330),
    [sym_scoped_type] = STATE(3330),
    [sym_tuple_type] = STATE(3490),
    [sym_identifier] = STATE(3158),
    [sym__reserved_identifier] = STATE(3178),
    [sym_preproc_region] = STATE(4625),
    [sym_preproc_endregion] = STATE(4625),
    [sym_preproc_line] = STATE(4625),
    [sym_preproc_pragma] = STATE(4625),
    [sym_preproc_nullable] = STATE(4625),
    [sym_preproc_error] = STATE(4625),
    [sym_preproc_warning] = STATE(4625),
    [sym_preproc_define] = STATE(4625),
    [sym_preproc_undef] = STATE(4625),
    [sym__identifier_token] = ACTIONS(6636),
    [anon_sym_alias] = ACTIONS(6638),
    [anon_sym_global] = ACTIONS(6638),
    [anon_sym_LPAREN] = ACTIONS(6640),
    [anon_sym_ref] = ACTIONS(4110),
    [anon_sym_delegate] = ACTIONS(6642),
    [anon_sym_file] = ACTIONS(6638),
    [anon_sym_readonly] = ACTIONS(2897),
    [anon_sym_where] = ACTIONS(6638),
    [anon_sym_notnull] = ACTIONS(6638),
    [anon_sym_unmanaged] = ACTIONS(6638),
    [anon_sym_scoped] = ACTIONS(6644),
    [anon_sym_var] = ACTIONS(6646),
    [sym_predefined_type] = ACTIONS(6648),
    [anon_sym_yield] = ACTIONS(6638),
    [anon_sym_when] = ACTIONS(6638),
    [anon_sym_from] = ACTIONS(6638),
    [anon_sym_into] = ACTIONS(6638),
    [anon_sym_join] = ACTIONS(6638),
    [anon_sym_on] = ACTIONS(6638),
    [anon_sym_equals] = ACTIONS(6638),
    [anon_sym_let] = ACTIONS(6638),
    [anon_sym_orderby] = ACTIONS(6638),
    [anon_sym_ascending] = ACTIONS(6638),
    [anon_sym_descending] = ACTIONS(6638),
    [anon_sym_group] = ACTIONS(6638),
    [anon_sym_by] = ACTIONS(6638),
    [anon_sym_select] = ACTIONS(6638),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4626] = {
    [sym_preproc_region] = STATE(4626),
    [sym_preproc_endregion] = STATE(4626),
    [sym_preproc_line] = STATE(4626),
    [sym_preproc_pragma] = STATE(4626),
    [sym_preproc_nullable] = STATE(4626),
    [sym_preproc_error] = STATE(4626),
    [sym_preproc_warning] = STATE(4626),
    [sym_preproc_define] = STATE(4626),
    [sym_preproc_undef] = STATE(4626),
    [anon_sym_LBRACK] = ACTIONS(5674),
    [anon_sym_COMMA] = ACTIONS(5674),
    [anon_sym_LPAREN] = ACTIONS(5674),
    [anon_sym_LT] = ACTIONS(5676),
    [anon_sym_GT] = ACTIONS(5676),
    [anon_sym_where] = ACTIONS(5674),
    [anon_sym_QMARK] = ACTIONS(5676),
    [anon_sym_BANG] = ACTIONS(5676),
    [anon_sym_PLUS_PLUS] = ACTIONS(5674),
    [anon_sym_DASH_DASH] = ACTIONS(5674),
    [anon_sym_PLUS] = ACTIONS(5676),
    [anon_sym_DASH] = ACTIONS(5676),
    [anon_sym_STAR] = ACTIONS(5674),
    [anon_sym_SLASH] = ACTIONS(5676),
    [anon_sym_PERCENT] = ACTIONS(5674),
    [anon_sym_CARET] = ACTIONS(5674),
    [anon_sym_PIPE] = ACTIONS(5676),
    [anon_sym_AMP] = ACTIONS(5676),
    [anon_sym_LT_LT] = ACTIONS(5674),
    [anon_sym_GT_GT] = ACTIONS(5676),
    [anon_sym_GT_GT_GT] = ACTIONS(5674),
    [anon_sym_EQ_EQ] = ACTIONS(5674),
    [anon_sym_BANG_EQ] = ACTIONS(5674),
    [anon_sym_GT_EQ] = ACTIONS(5674),
    [anon_sym_LT_EQ] = ACTIONS(5674),
    [anon_sym_DOT] = ACTIONS(5676),
    [anon_sym_switch] = ACTIONS(5674),
    [anon_sym_DOT_DOT] = ACTIONS(5674),
    [anon_sym_and] = ACTIONS(5674),
    [anon_sym_or] = ACTIONS(5676),
    [anon_sym_AMP_AMP] = ACTIONS(5674),
    [anon_sym_PIPE_PIPE] = ACTIONS(5674),
    [anon_sym_QMARK_QMARK] = ACTIONS(5674),
    [anon_sym_from] = ACTIONS(5674),
    [anon_sym_into] = ACTIONS(5674),
    [anon_sym_join] = ACTIONS(5674),
    [anon_sym_let] = ACTIONS(5674),
    [anon_sym_orderby] = ACTIONS(5674),
    [anon_sym_ascending] = ACTIONS(5674),
    [anon_sym_descending] = ACTIONS(5674),
    [anon_sym_group] = ACTIONS(5674),
    [anon_sym_select] = ACTIONS(5674),
    [anon_sym_as] = ACTIONS(5676),
    [anon_sym_is] = ACTIONS(5674),
    [anon_sym_DASH_GT] = ACTIONS(5674),
    [anon_sym_with] = ACTIONS(5674),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4627] = {
    [sym_variable_declaration] = STATE(9568),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7104),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4627),
    [sym_preproc_endregion] = STATE(4627),
    [sym_preproc_line] = STATE(4627),
    [sym_preproc_pragma] = STATE(4627),
    [sym_preproc_nullable] = STATE(4627),
    [sym_preproc_error] = STATE(4627),
    [sym_preproc_warning] = STATE(4627),
    [sym_preproc_define] = STATE(4627),
    [sym_preproc_undef] = STATE(4627),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4628] = {
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7206),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8759),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4628),
    [sym_preproc_endregion] = STATE(4628),
    [sym_preproc_line] = STATE(4628),
    [sym_preproc_pragma] = STATE(4628),
    [sym_preproc_nullable] = STATE(4628),
    [sym_preproc_error] = STATE(4628),
    [sym_preproc_warning] = STATE(4628),
    [sym_preproc_define] = STATE(4628),
    [sym_preproc_undef] = STATE(4628),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(4078),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(6140),
    [anon_sym_var] = ACTIONS(5369),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4629] = {
    [sym_preproc_region] = STATE(4629),
    [sym_preproc_endregion] = STATE(4629),
    [sym_preproc_line] = STATE(4629),
    [sym_preproc_pragma] = STATE(4629),
    [sym_preproc_nullable] = STATE(4629),
    [sym_preproc_error] = STATE(4629),
    [sym_preproc_warning] = STATE(4629),
    [sym_preproc_define] = STATE(4629),
    [sym_preproc_undef] = STATE(4629),
    [anon_sym_LBRACK] = ACTIONS(5510),
    [anon_sym_COMMA] = ACTIONS(5510),
    [anon_sym_LPAREN] = ACTIONS(5510),
    [anon_sym_LT] = ACTIONS(5512),
    [anon_sym_GT] = ACTIONS(5512),
    [anon_sym_where] = ACTIONS(5510),
    [anon_sym_QMARK] = ACTIONS(5512),
    [anon_sym_BANG] = ACTIONS(5512),
    [anon_sym_PLUS_PLUS] = ACTIONS(5510),
    [anon_sym_DASH_DASH] = ACTIONS(5510),
    [anon_sym_PLUS] = ACTIONS(5512),
    [anon_sym_DASH] = ACTIONS(5512),
    [anon_sym_STAR] = ACTIONS(5510),
    [anon_sym_SLASH] = ACTIONS(5512),
    [anon_sym_PERCENT] = ACTIONS(5510),
    [anon_sym_CARET] = ACTIONS(5510),
    [anon_sym_PIPE] = ACTIONS(5512),
    [anon_sym_AMP] = ACTIONS(5512),
    [anon_sym_LT_LT] = ACTIONS(5510),
    [anon_sym_GT_GT] = ACTIONS(5512),
    [anon_sym_GT_GT_GT] = ACTIONS(5510),
    [anon_sym_EQ_EQ] = ACTIONS(5510),
    [anon_sym_BANG_EQ] = ACTIONS(5510),
    [anon_sym_GT_EQ] = ACTIONS(5510),
    [anon_sym_LT_EQ] = ACTIONS(5510),
    [anon_sym_DOT] = ACTIONS(5512),
    [anon_sym_switch] = ACTIONS(5510),
    [anon_sym_DOT_DOT] = ACTIONS(5510),
    [anon_sym_and] = ACTIONS(5510),
    [anon_sym_or] = ACTIONS(5512),
    [anon_sym_AMP_AMP] = ACTIONS(5510),
    [anon_sym_PIPE_PIPE] = ACTIONS(5510),
    [anon_sym_QMARK_QMARK] = ACTIONS(5510),
    [anon_sym_from] = ACTIONS(5510),
    [anon_sym_into] = ACTIONS(5510),
    [anon_sym_join] = ACTIONS(5510),
    [anon_sym_let] = ACTIONS(5510),
    [anon_sym_orderby] = ACTIONS(5510),
    [anon_sym_ascending] = ACTIONS(5510),
    [anon_sym_descending] = ACTIONS(5510),
    [anon_sym_group] = ACTIONS(5510),
    [anon_sym_select] = ACTIONS(5510),
    [anon_sym_as] = ACTIONS(5512),
    [anon_sym_is] = ACTIONS(5510),
    [anon_sym_DASH_GT] = ACTIONS(5510),
    [anon_sym_with] = ACTIONS(5510),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4630] = {
    [sym_preproc_region] = STATE(4630),
    [sym_preproc_endregion] = STATE(4630),
    [sym_preproc_line] = STATE(4630),
    [sym_preproc_pragma] = STATE(4630),
    [sym_preproc_nullable] = STATE(4630),
    [sym_preproc_error] = STATE(4630),
    [sym_preproc_warning] = STATE(4630),
    [sym_preproc_define] = STATE(4630),
    [sym_preproc_undef] = STATE(4630),
    [anon_sym_LBRACK] = ACTIONS(5895),
    [anon_sym_COMMA] = ACTIONS(5895),
    [anon_sym_LPAREN] = ACTIONS(5895),
    [anon_sym_LT] = ACTIONS(5897),
    [anon_sym_GT] = ACTIONS(5897),
    [anon_sym_where] = ACTIONS(5895),
    [anon_sym_QMARK] = ACTIONS(5897),
    [anon_sym_BANG] = ACTIONS(5897),
    [anon_sym_PLUS_PLUS] = ACTIONS(5895),
    [anon_sym_DASH_DASH] = ACTIONS(5895),
    [anon_sym_PLUS] = ACTIONS(5897),
    [anon_sym_DASH] = ACTIONS(5897),
    [anon_sym_STAR] = ACTIONS(5895),
    [anon_sym_SLASH] = ACTIONS(5897),
    [anon_sym_PERCENT] = ACTIONS(5895),
    [anon_sym_CARET] = ACTIONS(5895),
    [anon_sym_PIPE] = ACTIONS(5897),
    [anon_sym_AMP] = ACTIONS(5897),
    [anon_sym_LT_LT] = ACTIONS(5895),
    [anon_sym_GT_GT] = ACTIONS(5897),
    [anon_sym_GT_GT_GT] = ACTIONS(5895),
    [anon_sym_EQ_EQ] = ACTIONS(5895),
    [anon_sym_BANG_EQ] = ACTIONS(5895),
    [anon_sym_GT_EQ] = ACTIONS(5895),
    [anon_sym_LT_EQ] = ACTIONS(5895),
    [anon_sym_DOT] = ACTIONS(5897),
    [anon_sym_switch] = ACTIONS(5895),
    [anon_sym_DOT_DOT] = ACTIONS(5895),
    [anon_sym_and] = ACTIONS(5895),
    [anon_sym_or] = ACTIONS(5897),
    [anon_sym_AMP_AMP] = ACTIONS(5895),
    [anon_sym_PIPE_PIPE] = ACTIONS(5895),
    [anon_sym_QMARK_QMARK] = ACTIONS(5895),
    [anon_sym_from] = ACTIONS(5895),
    [anon_sym_into] = ACTIONS(5895),
    [anon_sym_join] = ACTIONS(5895),
    [anon_sym_let] = ACTIONS(5895),
    [anon_sym_orderby] = ACTIONS(5895),
    [anon_sym_ascending] = ACTIONS(5895),
    [anon_sym_descending] = ACTIONS(5895),
    [anon_sym_group] = ACTIONS(5895),
    [anon_sym_select] = ACTIONS(5895),
    [anon_sym_as] = ACTIONS(5897),
    [anon_sym_is] = ACTIONS(5895),
    [anon_sym_DASH_GT] = ACTIONS(5895),
    [anon_sym_with] = ACTIONS(5895),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4631] = {
    [sym_preproc_region] = STATE(4631),
    [sym_preproc_endregion] = STATE(4631),
    [sym_preproc_line] = STATE(4631),
    [sym_preproc_pragma] = STATE(4631),
    [sym_preproc_nullable] = STATE(4631),
    [sym_preproc_error] = STATE(4631),
    [sym_preproc_warning] = STATE(4631),
    [sym_preproc_define] = STATE(4631),
    [sym_preproc_undef] = STATE(4631),
    [anon_sym_LBRACK] = ACTIONS(5636),
    [anon_sym_COMMA] = ACTIONS(5636),
    [anon_sym_LPAREN] = ACTIONS(5636),
    [anon_sym_LT] = ACTIONS(5638),
    [anon_sym_GT] = ACTIONS(5638),
    [anon_sym_where] = ACTIONS(5636),
    [anon_sym_QMARK] = ACTIONS(5638),
    [anon_sym_BANG] = ACTIONS(5638),
    [anon_sym_PLUS_PLUS] = ACTIONS(5636),
    [anon_sym_DASH_DASH] = ACTIONS(5636),
    [anon_sym_PLUS] = ACTIONS(5638),
    [anon_sym_DASH] = ACTIONS(5638),
    [anon_sym_STAR] = ACTIONS(5636),
    [anon_sym_SLASH] = ACTIONS(5638),
    [anon_sym_PERCENT] = ACTIONS(5636),
    [anon_sym_CARET] = ACTIONS(5636),
    [anon_sym_PIPE] = ACTIONS(5638),
    [anon_sym_AMP] = ACTIONS(5638),
    [anon_sym_LT_LT] = ACTIONS(5636),
    [anon_sym_GT_GT] = ACTIONS(5638),
    [anon_sym_GT_GT_GT] = ACTIONS(5636),
    [anon_sym_EQ_EQ] = ACTIONS(5636),
    [anon_sym_BANG_EQ] = ACTIONS(5636),
    [anon_sym_GT_EQ] = ACTIONS(5636),
    [anon_sym_LT_EQ] = ACTIONS(5636),
    [anon_sym_DOT] = ACTIONS(5638),
    [anon_sym_switch] = ACTIONS(5636),
    [anon_sym_DOT_DOT] = ACTIONS(5636),
    [anon_sym_and] = ACTIONS(5636),
    [anon_sym_or] = ACTIONS(5638),
    [anon_sym_AMP_AMP] = ACTIONS(5636),
    [anon_sym_PIPE_PIPE] = ACTIONS(5636),
    [anon_sym_QMARK_QMARK] = ACTIONS(5636),
    [anon_sym_from] = ACTIONS(5636),
    [anon_sym_into] = ACTIONS(5636),
    [anon_sym_join] = ACTIONS(5636),
    [anon_sym_let] = ACTIONS(5636),
    [anon_sym_orderby] = ACTIONS(5636),
    [anon_sym_ascending] = ACTIONS(5636),
    [anon_sym_descending] = ACTIONS(5636),
    [anon_sym_group] = ACTIONS(5636),
    [anon_sym_select] = ACTIONS(5636),
    [anon_sym_as] = ACTIONS(5638),
    [anon_sym_is] = ACTIONS(5636),
    [anon_sym_DASH_GT] = ACTIONS(5636),
    [anon_sym_with] = ACTIONS(5636),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4632] = {
    [sym__name] = STATE(5270),
    [sym_alias_qualified_name] = STATE(5341),
    [sym__simple_name] = STATE(5341),
    [sym_qualified_name] = STATE(5341),
    [sym_generic_name] = STATE(5408),
    [sym_type] = STATE(5360),
    [sym_implicit_type] = STATE(5336),
    [sym_array_type] = STATE(5251),
    [sym__array_base_type] = STATE(8724),
    [sym_nullable_type] = STATE(5262),
    [sym_pointer_type] = STATE(5262),
    [sym__pointer_base_type] = STATE(9858),
    [sym_function_pointer_type] = STATE(5262),
    [sym_ref_type] = STATE(5336),
    [sym_scoped_type] = STATE(5336),
    [sym_tuple_type] = STATE(5321),
    [sym_identifier] = STATE(5076),
    [sym__reserved_identifier] = STATE(5173),
    [sym_preproc_region] = STATE(4632),
    [sym_preproc_endregion] = STATE(4632),
    [sym_preproc_line] = STATE(4632),
    [sym_preproc_pragma] = STATE(4632),
    [sym_preproc_nullable] = STATE(4632),
    [sym_preproc_error] = STATE(4632),
    [sym_preproc_warning] = STATE(4632),
    [sym_preproc_define] = STATE(4632),
    [sym_preproc_undef] = STATE(4632),
    [sym__identifier_token] = ACTIONS(4457),
    [anon_sym_alias] = ACTIONS(4459),
    [anon_sym_global] = ACTIONS(4459),
    [anon_sym_LPAREN] = ACTIONS(6650),
    [anon_sym_ref] = ACTIONS(4461),
    [anon_sym_delegate] = ACTIONS(6297),
    [anon_sym_file] = ACTIONS(4459),
    [anon_sym_readonly] = ACTIONS(6652),
    [anon_sym_where] = ACTIONS(4459),
    [anon_sym_notnull] = ACTIONS(4459),
    [anon_sym_unmanaged] = ACTIONS(4459),
    [anon_sym_scoped] = ACTIONS(6386),
    [anon_sym_var] = ACTIONS(6301),
    [sym_predefined_type] = ACTIONS(6303),
    [anon_sym_yield] = ACTIONS(4459),
    [anon_sym_when] = ACTIONS(4459),
    [anon_sym_from] = ACTIONS(4459),
    [anon_sym_into] = ACTIONS(4459),
    [anon_sym_join] = ACTIONS(4459),
    [anon_sym_on] = ACTIONS(4459),
    [anon_sym_equals] = ACTIONS(4459),
    [anon_sym_let] = ACTIONS(4459),
    [anon_sym_orderby] = ACTIONS(4459),
    [anon_sym_ascending] = ACTIONS(4459),
    [anon_sym_descending] = ACTIONS(4459),
    [anon_sym_group] = ACTIONS(4459),
    [anon_sym_by] = ACTIONS(4459),
    [anon_sym_select] = ACTIONS(4459),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4633] = {
    [sym_preproc_region] = STATE(4633),
    [sym_preproc_endregion] = STATE(4633),
    [sym_preproc_line] = STATE(4633),
    [sym_preproc_pragma] = STATE(4633),
    [sym_preproc_nullable] = STATE(4633),
    [sym_preproc_error] = STATE(4633),
    [sym_preproc_warning] = STATE(4633),
    [sym_preproc_define] = STATE(4633),
    [sym_preproc_undef] = STATE(4633),
    [anon_sym_LBRACK] = ACTIONS(5932),
    [anon_sym_COMMA] = ACTIONS(5932),
    [anon_sym_LPAREN] = ACTIONS(5932),
    [anon_sym_LT] = ACTIONS(5934),
    [anon_sym_GT] = ACTIONS(5934),
    [anon_sym_where] = ACTIONS(5932),
    [anon_sym_QMARK] = ACTIONS(5934),
    [anon_sym_BANG] = ACTIONS(5934),
    [anon_sym_PLUS_PLUS] = ACTIONS(5932),
    [anon_sym_DASH_DASH] = ACTIONS(5932),
    [anon_sym_PLUS] = ACTIONS(5934),
    [anon_sym_DASH] = ACTIONS(5934),
    [anon_sym_STAR] = ACTIONS(5932),
    [anon_sym_SLASH] = ACTIONS(5934),
    [anon_sym_PERCENT] = ACTIONS(5932),
    [anon_sym_CARET] = ACTIONS(5932),
    [anon_sym_PIPE] = ACTIONS(5934),
    [anon_sym_AMP] = ACTIONS(5934),
    [anon_sym_LT_LT] = ACTIONS(5932),
    [anon_sym_GT_GT] = ACTIONS(5934),
    [anon_sym_GT_GT_GT] = ACTIONS(5932),
    [anon_sym_EQ_EQ] = ACTIONS(5932),
    [anon_sym_BANG_EQ] = ACTIONS(5932),
    [anon_sym_GT_EQ] = ACTIONS(5932),
    [anon_sym_LT_EQ] = ACTIONS(5932),
    [anon_sym_DOT] = ACTIONS(5934),
    [anon_sym_switch] = ACTIONS(5932),
    [anon_sym_DOT_DOT] = ACTIONS(5932),
    [anon_sym_and] = ACTIONS(5932),
    [anon_sym_or] = ACTIONS(5934),
    [anon_sym_AMP_AMP] = ACTIONS(5932),
    [anon_sym_PIPE_PIPE] = ACTIONS(5932),
    [anon_sym_QMARK_QMARK] = ACTIONS(5932),
    [anon_sym_from] = ACTIONS(5932),
    [anon_sym_into] = ACTIONS(5932),
    [anon_sym_join] = ACTIONS(5932),
    [anon_sym_let] = ACTIONS(5932),
    [anon_sym_orderby] = ACTIONS(5932),
    [anon_sym_ascending] = ACTIONS(5932),
    [anon_sym_descending] = ACTIONS(5932),
    [anon_sym_group] = ACTIONS(5932),
    [anon_sym_select] = ACTIONS(5932),
    [anon_sym_as] = ACTIONS(5934),
    [anon_sym_is] = ACTIONS(5932),
    [anon_sym_DASH_GT] = ACTIONS(5932),
    [anon_sym_with] = ACTIONS(5932),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4634] = {
    [sym_preproc_region] = STATE(4634),
    [sym_preproc_endregion] = STATE(4634),
    [sym_preproc_line] = STATE(4634),
    [sym_preproc_pragma] = STATE(4634),
    [sym_preproc_nullable] = STATE(4634),
    [sym_preproc_error] = STATE(4634),
    [sym_preproc_warning] = STATE(4634),
    [sym_preproc_define] = STATE(4634),
    [sym_preproc_undef] = STATE(4634),
    [sym__identifier_token] = ACTIONS(5761),
    [anon_sym_extern] = ACTIONS(5761),
    [anon_sym_alias] = ACTIONS(5761),
    [anon_sym_global] = ACTIONS(5761),
    [anon_sym_unsafe] = ACTIONS(5761),
    [anon_sym_static] = ACTIONS(5761),
    [anon_sym_LPAREN] = ACTIONS(5763),
    [anon_sym_ref] = ACTIONS(5761),
    [anon_sym_delegate] = ACTIONS(5761),
    [anon_sym_abstract] = ACTIONS(5761),
    [anon_sym_async] = ACTIONS(5761),
    [anon_sym_const] = ACTIONS(5761),
    [anon_sym_file] = ACTIONS(5761),
    [anon_sym_fixed] = ACTIONS(5761),
    [anon_sym_internal] = ACTIONS(5761),
    [anon_sym_new] = ACTIONS(5761),
    [anon_sym_override] = ACTIONS(5761),
    [anon_sym_partial] = ACTIONS(5761),
    [anon_sym_private] = ACTIONS(5761),
    [anon_sym_protected] = ACTIONS(5761),
    [anon_sym_public] = ACTIONS(5761),
    [anon_sym_readonly] = ACTIONS(5761),
    [anon_sym_required] = ACTIONS(5761),
    [anon_sym_sealed] = ACTIONS(5761),
    [anon_sym_virtual] = ACTIONS(5761),
    [anon_sym_volatile] = ACTIONS(5761),
    [anon_sym_where] = ACTIONS(5761),
    [anon_sym_notnull] = ACTIONS(5761),
    [anon_sym_unmanaged] = ACTIONS(5761),
    [anon_sym_scoped] = ACTIONS(5761),
    [anon_sym_var] = ACTIONS(5761),
    [sym_predefined_type] = ACTIONS(5761),
    [anon_sym_yield] = ACTIONS(5761),
    [anon_sym_when] = ACTIONS(5761),
    [anon_sym_from] = ACTIONS(5761),
    [anon_sym_into] = ACTIONS(5761),
    [anon_sym_join] = ACTIONS(5761),
    [anon_sym_on] = ACTIONS(5761),
    [anon_sym_equals] = ACTIONS(5761),
    [anon_sym_let] = ACTIONS(5761),
    [anon_sym_orderby] = ACTIONS(5761),
    [anon_sym_ascending] = ACTIONS(5761),
    [anon_sym_descending] = ACTIONS(5761),
    [anon_sym_group] = ACTIONS(5761),
    [anon_sym_by] = ACTIONS(5761),
    [anon_sym_select] = ACTIONS(5761),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4635] = {
    [sym_preproc_region] = STATE(4635),
    [sym_preproc_endregion] = STATE(4635),
    [sym_preproc_line] = STATE(4635),
    [sym_preproc_pragma] = STATE(4635),
    [sym_preproc_nullable] = STATE(4635),
    [sym_preproc_error] = STATE(4635),
    [sym_preproc_warning] = STATE(4635),
    [sym_preproc_define] = STATE(4635),
    [sym_preproc_undef] = STATE(4635),
    [anon_sym_LBRACK] = ACTIONS(5682),
    [anon_sym_COMMA] = ACTIONS(5682),
    [anon_sym_LPAREN] = ACTIONS(5682),
    [anon_sym_LT] = ACTIONS(5684),
    [anon_sym_GT] = ACTIONS(5684),
    [anon_sym_where] = ACTIONS(5682),
    [anon_sym_QMARK] = ACTIONS(5684),
    [anon_sym_BANG] = ACTIONS(5684),
    [anon_sym_PLUS_PLUS] = ACTIONS(5682),
    [anon_sym_DASH_DASH] = ACTIONS(5682),
    [anon_sym_PLUS] = ACTIONS(5684),
    [anon_sym_DASH] = ACTIONS(5684),
    [anon_sym_STAR] = ACTIONS(5682),
    [anon_sym_SLASH] = ACTIONS(5684),
    [anon_sym_PERCENT] = ACTIONS(5682),
    [anon_sym_CARET] = ACTIONS(5682),
    [anon_sym_PIPE] = ACTIONS(5684),
    [anon_sym_AMP] = ACTIONS(5684),
    [anon_sym_LT_LT] = ACTIONS(5682),
    [anon_sym_GT_GT] = ACTIONS(5684),
    [anon_sym_GT_GT_GT] = ACTIONS(5682),
    [anon_sym_EQ_EQ] = ACTIONS(5682),
    [anon_sym_BANG_EQ] = ACTIONS(5682),
    [anon_sym_GT_EQ] = ACTIONS(5682),
    [anon_sym_LT_EQ] = ACTIONS(5682),
    [anon_sym_DOT] = ACTIONS(5684),
    [anon_sym_switch] = ACTIONS(5682),
    [anon_sym_DOT_DOT] = ACTIONS(5682),
    [anon_sym_and] = ACTIONS(5682),
    [anon_sym_or] = ACTIONS(5684),
    [anon_sym_AMP_AMP] = ACTIONS(5682),
    [anon_sym_PIPE_PIPE] = ACTIONS(5682),
    [anon_sym_QMARK_QMARK] = ACTIONS(5682),
    [anon_sym_from] = ACTIONS(5682),
    [anon_sym_into] = ACTIONS(5682),
    [anon_sym_join] = ACTIONS(5682),
    [anon_sym_let] = ACTIONS(5682),
    [anon_sym_orderby] = ACTIONS(5682),
    [anon_sym_ascending] = ACTIONS(5682),
    [anon_sym_descending] = ACTIONS(5682),
    [anon_sym_group] = ACTIONS(5682),
    [anon_sym_select] = ACTIONS(5682),
    [anon_sym_as] = ACTIONS(5684),
    [anon_sym_is] = ACTIONS(5682),
    [anon_sym_DASH_GT] = ACTIONS(5682),
    [anon_sym_with] = ACTIONS(5682),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4636] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4636),
    [sym_preproc_endregion] = STATE(4636),
    [sym_preproc_line] = STATE(4636),
    [sym_preproc_pragma] = STATE(4636),
    [sym_preproc_nullable] = STATE(4636),
    [sym_preproc_error] = STATE(4636),
    [sym_preproc_warning] = STATE(4636),
    [sym_preproc_define] = STATE(4636),
    [sym_preproc_undef] = STATE(4636),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(6266),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(6546),
    [anon_sym_GT] = ACTIONS(6546),
    [anon_sym_where] = ACTIONS(6266),
    [anon_sym_QMARK] = ACTIONS(6548),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(6550),
    [anon_sym_DASH] = ACTIONS(6550),
    [anon_sym_STAR] = ACTIONS(6552),
    [anon_sym_SLASH] = ACTIONS(6554),
    [anon_sym_PERCENT] = ACTIONS(6552),
    [anon_sym_CARET] = ACTIONS(6556),
    [anon_sym_PIPE] = ACTIONS(6558),
    [anon_sym_AMP] = ACTIONS(6560),
    [anon_sym_LT_LT] = ACTIONS(6562),
    [anon_sym_GT_GT] = ACTIONS(6564),
    [anon_sym_GT_GT_GT] = ACTIONS(6562),
    [anon_sym_EQ_EQ] = ACTIONS(6566),
    [anon_sym_BANG_EQ] = ACTIONS(6566),
    [anon_sym_GT_EQ] = ACTIONS(6568),
    [anon_sym_LT_EQ] = ACTIONS(6568),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(6216),
    [anon_sym_DOT_DOT] = ACTIONS(6570),
    [anon_sym_AMP_AMP] = ACTIONS(6572),
    [anon_sym_PIPE_PIPE] = ACTIONS(6574),
    [anon_sym_QMARK_QMARK] = ACTIONS(6576),
    [anon_sym_from] = ACTIONS(6266),
    [anon_sym_into] = ACTIONS(6266),
    [anon_sym_join] = ACTIONS(6266),
    [anon_sym_let] = ACTIONS(6266),
    [anon_sym_orderby] = ACTIONS(6266),
    [anon_sym_ascending] = ACTIONS(6266),
    [anon_sym_descending] = ACTIONS(6266),
    [anon_sym_group] = ACTIONS(6266),
    [anon_sym_select] = ACTIONS(6266),
    [anon_sym_as] = ACTIONS(6228),
    [anon_sym_is] = ACTIONS(6578),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(6232),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4637] = {
    [sym_preproc_region] = STATE(4637),
    [sym_preproc_endregion] = STATE(4637),
    [sym_preproc_line] = STATE(4637),
    [sym_preproc_pragma] = STATE(4637),
    [sym_preproc_nullable] = STATE(4637),
    [sym_preproc_error] = STATE(4637),
    [sym_preproc_warning] = STATE(4637),
    [sym_preproc_define] = STATE(4637),
    [sym_preproc_undef] = STATE(4637),
    [anon_sym_LBRACK] = ACTIONS(5382),
    [anon_sym_COMMA] = ACTIONS(5382),
    [anon_sym_LPAREN] = ACTIONS(5382),
    [anon_sym_LT] = ACTIONS(5384),
    [anon_sym_GT] = ACTIONS(5384),
    [anon_sym_where] = ACTIONS(5382),
    [anon_sym_QMARK] = ACTIONS(5384),
    [anon_sym_BANG] = ACTIONS(5384),
    [anon_sym_PLUS_PLUS] = ACTIONS(5382),
    [anon_sym_DASH_DASH] = ACTIONS(5382),
    [anon_sym_PLUS] = ACTIONS(5384),
    [anon_sym_DASH] = ACTIONS(5384),
    [anon_sym_STAR] = ACTIONS(5382),
    [anon_sym_SLASH] = ACTIONS(5384),
    [anon_sym_PERCENT] = ACTIONS(5382),
    [anon_sym_CARET] = ACTIONS(5382),
    [anon_sym_PIPE] = ACTIONS(5384),
    [anon_sym_AMP] = ACTIONS(5384),
    [anon_sym_LT_LT] = ACTIONS(5382),
    [anon_sym_GT_GT] = ACTIONS(5384),
    [anon_sym_GT_GT_GT] = ACTIONS(5382),
    [anon_sym_EQ_EQ] = ACTIONS(5382),
    [anon_sym_BANG_EQ] = ACTIONS(5382),
    [anon_sym_GT_EQ] = ACTIONS(5382),
    [anon_sym_LT_EQ] = ACTIONS(5382),
    [anon_sym_DOT] = ACTIONS(5384),
    [anon_sym_switch] = ACTIONS(5382),
    [anon_sym_DOT_DOT] = ACTIONS(5382),
    [anon_sym_and] = ACTIONS(5382),
    [anon_sym_or] = ACTIONS(5384),
    [anon_sym_AMP_AMP] = ACTIONS(5382),
    [anon_sym_PIPE_PIPE] = ACTIONS(5382),
    [anon_sym_QMARK_QMARK] = ACTIONS(5382),
    [anon_sym_from] = ACTIONS(5382),
    [anon_sym_into] = ACTIONS(5382),
    [anon_sym_join] = ACTIONS(5382),
    [anon_sym_let] = ACTIONS(5382),
    [anon_sym_orderby] = ACTIONS(5382),
    [anon_sym_ascending] = ACTIONS(5382),
    [anon_sym_descending] = ACTIONS(5382),
    [anon_sym_group] = ACTIONS(5382),
    [anon_sym_select] = ACTIONS(5382),
    [anon_sym_as] = ACTIONS(5384),
    [anon_sym_is] = ACTIONS(5382),
    [anon_sym_DASH_GT] = ACTIONS(5382),
    [anon_sym_with] = ACTIONS(5382),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4638] = {
    [sym_variable_declaration] = STATE(9467),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7104),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4638),
    [sym_preproc_endregion] = STATE(4638),
    [sym_preproc_line] = STATE(4638),
    [sym_preproc_pragma] = STATE(4638),
    [sym_preproc_nullable] = STATE(4638),
    [sym_preproc_error] = STATE(4638),
    [sym_preproc_warning] = STATE(4638),
    [sym_preproc_define] = STATE(4638),
    [sym_preproc_undef] = STATE(4638),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4639] = {
    [sym__name] = STATE(4343),
    [sym_alias_qualified_name] = STATE(3588),
    [sym__simple_name] = STATE(3588),
    [sym_qualified_name] = STATE(3588),
    [sym_generic_name] = STATE(3597),
    [sym_type] = STATE(3611),
    [sym_implicit_type] = STATE(3596),
    [sym_array_type] = STATE(3608),
    [sym__array_base_type] = STATE(8805),
    [sym_nullable_type] = STATE(3612),
    [sym_pointer_type] = STATE(3612),
    [sym__pointer_base_type] = STATE(9071),
    [sym_function_pointer_type] = STATE(3612),
    [sym_ref_type] = STATE(3596),
    [sym_scoped_type] = STATE(3596),
    [sym_tuple_type] = STATE(3621),
    [sym_identifier] = STATE(4004),
    [sym__reserved_identifier] = STATE(3572),
    [sym_preproc_region] = STATE(4639),
    [sym_preproc_endregion] = STATE(4639),
    [sym_preproc_line] = STATE(4639),
    [sym_preproc_pragma] = STATE(4639),
    [sym_preproc_nullable] = STATE(4639),
    [sym_preproc_error] = STATE(4639),
    [sym_preproc_warning] = STATE(4639),
    [sym_preproc_define] = STATE(4639),
    [sym_preproc_undef] = STATE(4639),
    [sym__identifier_token] = ACTIONS(4328),
    [anon_sym_alias] = ACTIONS(4330),
    [anon_sym_global] = ACTIONS(4330),
    [anon_sym_LPAREN] = ACTIONS(6654),
    [anon_sym_ref] = ACTIONS(4725),
    [anon_sym_delegate] = ACTIONS(6148),
    [anon_sym_file] = ACTIONS(4330),
    [anon_sym_readonly] = ACTIONS(6656),
    [anon_sym_where] = ACTIONS(4330),
    [anon_sym_notnull] = ACTIONS(4330),
    [anon_sym_unmanaged] = ACTIONS(4330),
    [anon_sym_scoped] = ACTIONS(6372),
    [anon_sym_var] = ACTIONS(6152),
    [sym_predefined_type] = ACTIONS(6154),
    [anon_sym_yield] = ACTIONS(4330),
    [anon_sym_when] = ACTIONS(4330),
    [anon_sym_from] = ACTIONS(4330),
    [anon_sym_into] = ACTIONS(4330),
    [anon_sym_join] = ACTIONS(4330),
    [anon_sym_on] = ACTIONS(4330),
    [anon_sym_equals] = ACTIONS(4330),
    [anon_sym_let] = ACTIONS(4330),
    [anon_sym_orderby] = ACTIONS(4330),
    [anon_sym_ascending] = ACTIONS(4330),
    [anon_sym_descending] = ACTIONS(4330),
    [anon_sym_group] = ACTIONS(4330),
    [anon_sym_by] = ACTIONS(4330),
    [anon_sym_select] = ACTIONS(4330),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4640] = {
    [sym__name] = STATE(5270),
    [sym_alias_qualified_name] = STATE(5341),
    [sym__simple_name] = STATE(5341),
    [sym_qualified_name] = STATE(5341),
    [sym_generic_name] = STATE(5408),
    [sym_type] = STATE(5360),
    [sym_implicit_type] = STATE(5336),
    [sym_array_type] = STATE(5251),
    [sym__array_base_type] = STATE(8724),
    [sym_nullable_type] = STATE(5262),
    [sym_pointer_type] = STATE(5262),
    [sym__pointer_base_type] = STATE(9858),
    [sym_function_pointer_type] = STATE(5262),
    [sym_ref_type] = STATE(5336),
    [sym_scoped_type] = STATE(5336),
    [sym_tuple_type] = STATE(5321),
    [sym_identifier] = STATE(5076),
    [sym__reserved_identifier] = STATE(5173),
    [sym_preproc_region] = STATE(4640),
    [sym_preproc_endregion] = STATE(4640),
    [sym_preproc_line] = STATE(4640),
    [sym_preproc_pragma] = STATE(4640),
    [sym_preproc_nullable] = STATE(4640),
    [sym_preproc_error] = STATE(4640),
    [sym_preproc_warning] = STATE(4640),
    [sym_preproc_define] = STATE(4640),
    [sym_preproc_undef] = STATE(4640),
    [sym__identifier_token] = ACTIONS(4457),
    [anon_sym_alias] = ACTIONS(4459),
    [anon_sym_global] = ACTIONS(4459),
    [anon_sym_LPAREN] = ACTIONS(6650),
    [anon_sym_ref] = ACTIONS(4474),
    [anon_sym_delegate] = ACTIONS(6297),
    [anon_sym_file] = ACTIONS(4459),
    [anon_sym_readonly] = ACTIONS(6658),
    [anon_sym_where] = ACTIONS(4459),
    [anon_sym_notnull] = ACTIONS(4459),
    [anon_sym_unmanaged] = ACTIONS(4459),
    [anon_sym_scoped] = ACTIONS(6299),
    [anon_sym_var] = ACTIONS(6301),
    [sym_predefined_type] = ACTIONS(6303),
    [anon_sym_yield] = ACTIONS(4459),
    [anon_sym_when] = ACTIONS(4459),
    [anon_sym_from] = ACTIONS(4459),
    [anon_sym_into] = ACTIONS(4459),
    [anon_sym_join] = ACTIONS(4459),
    [anon_sym_on] = ACTIONS(4459),
    [anon_sym_equals] = ACTIONS(4459),
    [anon_sym_let] = ACTIONS(4459),
    [anon_sym_orderby] = ACTIONS(4459),
    [anon_sym_ascending] = ACTIONS(4459),
    [anon_sym_descending] = ACTIONS(4459),
    [anon_sym_group] = ACTIONS(4459),
    [anon_sym_by] = ACTIONS(4459),
    [anon_sym_select] = ACTIONS(4459),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4641] = {
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7206),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8778),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4641),
    [sym_preproc_endregion] = STATE(4641),
    [sym_preproc_line] = STATE(4641),
    [sym_preproc_pragma] = STATE(4641),
    [sym_preproc_nullable] = STATE(4641),
    [sym_preproc_error] = STATE(4641),
    [sym_preproc_warning] = STATE(4641),
    [sym_preproc_define] = STATE(4641),
    [sym_preproc_undef] = STATE(4641),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(4078),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(6140),
    [anon_sym_var] = ACTIONS(5369),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4642] = {
    [sym__name] = STATE(2992),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2956),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2944),
    [sym_type] = STATE(2978),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_identifier] = STATE(2920),
    [sym__reserved_identifier] = STATE(2928),
    [sym_preproc_region] = STATE(4642),
    [sym_preproc_endregion] = STATE(4642),
    [sym_preproc_line] = STATE(4642),
    [sym_preproc_pragma] = STATE(4642),
    [sym_preproc_nullable] = STATE(4642),
    [sym_preproc_error] = STATE(4642),
    [sym_preproc_warning] = STATE(4642),
    [sym_preproc_define] = STATE(4642),
    [sym_preproc_undef] = STATE(4642),
    [sym__identifier_token] = ACTIONS(4536),
    [anon_sym_alias] = ACTIONS(4538),
    [anon_sym_global] = ACTIONS(4538),
    [anon_sym_LPAREN] = ACTIONS(6602),
    [anon_sym_ref] = ACTIONS(4059),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_file] = ACTIONS(4538),
    [anon_sym_readonly] = ACTIONS(2865),
    [anon_sym_where] = ACTIONS(4538),
    [anon_sym_notnull] = ACTIONS(4538),
    [anon_sym_unmanaged] = ACTIONS(4538),
    [anon_sym_scoped] = ACTIONS(6660),
    [anon_sym_var] = ACTIONS(6246),
    [sym_predefined_type] = ACTIONS(6248),
    [anon_sym_yield] = ACTIONS(4538),
    [anon_sym_when] = ACTIONS(4538),
    [anon_sym_from] = ACTIONS(4538),
    [anon_sym_into] = ACTIONS(4538),
    [anon_sym_join] = ACTIONS(4538),
    [anon_sym_on] = ACTIONS(4538),
    [anon_sym_equals] = ACTIONS(4538),
    [anon_sym_let] = ACTIONS(4538),
    [anon_sym_orderby] = ACTIONS(4538),
    [anon_sym_ascending] = ACTIONS(4538),
    [anon_sym_descending] = ACTIONS(4538),
    [anon_sym_group] = ACTIONS(4538),
    [anon_sym_by] = ACTIONS(4538),
    [anon_sym_select] = ACTIONS(4538),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4643] = {
    [sym_preproc_region] = STATE(4643),
    [sym_preproc_endregion] = STATE(4643),
    [sym_preproc_line] = STATE(4643),
    [sym_preproc_pragma] = STATE(4643),
    [sym_preproc_nullable] = STATE(4643),
    [sym_preproc_error] = STATE(4643),
    [sym_preproc_warning] = STATE(4643),
    [sym_preproc_define] = STATE(4643),
    [sym_preproc_undef] = STATE(4643),
    [anon_sym_LBRACK] = ACTIONS(5416),
    [anon_sym_COMMA] = ACTIONS(5416),
    [anon_sym_LPAREN] = ACTIONS(5416),
    [anon_sym_LT] = ACTIONS(5418),
    [anon_sym_GT] = ACTIONS(5418),
    [anon_sym_where] = ACTIONS(5416),
    [anon_sym_QMARK] = ACTIONS(5418),
    [anon_sym_BANG] = ACTIONS(5418),
    [anon_sym_PLUS_PLUS] = ACTIONS(5416),
    [anon_sym_DASH_DASH] = ACTIONS(5416),
    [anon_sym_PLUS] = ACTIONS(5418),
    [anon_sym_DASH] = ACTIONS(5418),
    [anon_sym_STAR] = ACTIONS(5416),
    [anon_sym_SLASH] = ACTIONS(5418),
    [anon_sym_PERCENT] = ACTIONS(5416),
    [anon_sym_CARET] = ACTIONS(5416),
    [anon_sym_PIPE] = ACTIONS(5418),
    [anon_sym_AMP] = ACTIONS(5418),
    [anon_sym_LT_LT] = ACTIONS(5416),
    [anon_sym_GT_GT] = ACTIONS(5418),
    [anon_sym_GT_GT_GT] = ACTIONS(5416),
    [anon_sym_EQ_EQ] = ACTIONS(5416),
    [anon_sym_BANG_EQ] = ACTIONS(5416),
    [anon_sym_GT_EQ] = ACTIONS(5416),
    [anon_sym_LT_EQ] = ACTIONS(5416),
    [anon_sym_DOT] = ACTIONS(5418),
    [anon_sym_switch] = ACTIONS(5416),
    [anon_sym_DOT_DOT] = ACTIONS(5416),
    [anon_sym_and] = ACTIONS(5416),
    [anon_sym_or] = ACTIONS(5418),
    [anon_sym_AMP_AMP] = ACTIONS(5416),
    [anon_sym_PIPE_PIPE] = ACTIONS(5416),
    [anon_sym_QMARK_QMARK] = ACTIONS(5416),
    [anon_sym_from] = ACTIONS(5416),
    [anon_sym_into] = ACTIONS(5416),
    [anon_sym_join] = ACTIONS(5416),
    [anon_sym_let] = ACTIONS(5416),
    [anon_sym_orderby] = ACTIONS(5416),
    [anon_sym_ascending] = ACTIONS(5416),
    [anon_sym_descending] = ACTIONS(5416),
    [anon_sym_group] = ACTIONS(5416),
    [anon_sym_select] = ACTIONS(5416),
    [anon_sym_as] = ACTIONS(5418),
    [anon_sym_is] = ACTIONS(5416),
    [anon_sym_DASH_GT] = ACTIONS(5416),
    [anon_sym_with] = ACTIONS(5416),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4644] = {
    [sym_variable_declaration] = STATE(9378),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(6761),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4644),
    [sym_preproc_endregion] = STATE(4644),
    [sym_preproc_line] = STATE(4644),
    [sym_preproc_pragma] = STATE(4644),
    [sym_preproc_nullable] = STATE(4644),
    [sym_preproc_error] = STATE(4644),
    [sym_preproc_warning] = STATE(4644),
    [sym_preproc_define] = STATE(4644),
    [sym_preproc_undef] = STATE(4644),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4645] = {
    [sym__name] = STATE(4158),
    [sym_alias_qualified_name] = STATE(4085),
    [sym__simple_name] = STATE(4085),
    [sym_qualified_name] = STATE(4085),
    [sym_generic_name] = STATE(3959),
    [sym_type] = STATE(4032),
    [sym_implicit_type] = STATE(4031),
    [sym_array_type] = STATE(3958),
    [sym__array_base_type] = STATE(8941),
    [sym_nullable_type] = STATE(3961),
    [sym_pointer_type] = STATE(3961),
    [sym__pointer_base_type] = STATE(9806),
    [sym_function_pointer_type] = STATE(3961),
    [sym_ref_type] = STATE(4031),
    [sym_scoped_type] = STATE(4031),
    [sym_tuple_type] = STATE(3962),
    [sym_identifier] = STATE(3889),
    [sym__reserved_identifier] = STATE(3911),
    [sym_preproc_region] = STATE(4645),
    [sym_preproc_endregion] = STATE(4645),
    [sym_preproc_line] = STATE(4645),
    [sym_preproc_pragma] = STATE(4645),
    [sym_preproc_nullable] = STATE(4645),
    [sym_preproc_error] = STATE(4645),
    [sym_preproc_warning] = STATE(4645),
    [sym_preproc_define] = STATE(4645),
    [sym_preproc_undef] = STATE(4645),
    [sym__identifier_token] = ACTIONS(4248),
    [anon_sym_alias] = ACTIONS(4250),
    [anon_sym_global] = ACTIONS(4250),
    [anon_sym_LPAREN] = ACTIONS(6620),
    [anon_sym_ref] = ACTIONS(4523),
    [anon_sym_delegate] = ACTIONS(6168),
    [anon_sym_file] = ACTIONS(4250),
    [anon_sym_readonly] = ACTIONS(6662),
    [anon_sym_where] = ACTIONS(4250),
    [anon_sym_notnull] = ACTIONS(4250),
    [anon_sym_unmanaged] = ACTIONS(4250),
    [anon_sym_scoped] = ACTIONS(6278),
    [anon_sym_var] = ACTIONS(6172),
    [sym_predefined_type] = ACTIONS(6174),
    [anon_sym_yield] = ACTIONS(4250),
    [anon_sym_when] = ACTIONS(4250),
    [anon_sym_from] = ACTIONS(4250),
    [anon_sym_into] = ACTIONS(4250),
    [anon_sym_join] = ACTIONS(4250),
    [anon_sym_on] = ACTIONS(4250),
    [anon_sym_equals] = ACTIONS(4250),
    [anon_sym_let] = ACTIONS(4250),
    [anon_sym_orderby] = ACTIONS(4250),
    [anon_sym_ascending] = ACTIONS(4250),
    [anon_sym_descending] = ACTIONS(4250),
    [anon_sym_group] = ACTIONS(4250),
    [anon_sym_by] = ACTIONS(4250),
    [anon_sym_select] = ACTIONS(4250),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4646] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4646),
    [sym_preproc_endregion] = STATE(4646),
    [sym_preproc_line] = STATE(4646),
    [sym_preproc_pragma] = STATE(4646),
    [sym_preproc_nullable] = STATE(4646),
    [sym_preproc_error] = STATE(4646),
    [sym_preproc_warning] = STATE(4646),
    [sym_preproc_define] = STATE(4646),
    [sym_preproc_undef] = STATE(4646),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(6270),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(6546),
    [anon_sym_GT] = ACTIONS(6546),
    [anon_sym_where] = ACTIONS(6270),
    [anon_sym_QMARK] = ACTIONS(6548),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(6550),
    [anon_sym_DASH] = ACTIONS(6550),
    [anon_sym_STAR] = ACTIONS(6552),
    [anon_sym_SLASH] = ACTIONS(6554),
    [anon_sym_PERCENT] = ACTIONS(6552),
    [anon_sym_CARET] = ACTIONS(6556),
    [anon_sym_PIPE] = ACTIONS(6558),
    [anon_sym_AMP] = ACTIONS(6560),
    [anon_sym_LT_LT] = ACTIONS(6562),
    [anon_sym_GT_GT] = ACTIONS(6564),
    [anon_sym_GT_GT_GT] = ACTIONS(6562),
    [anon_sym_EQ_EQ] = ACTIONS(6566),
    [anon_sym_BANG_EQ] = ACTIONS(6566),
    [anon_sym_GT_EQ] = ACTIONS(6568),
    [anon_sym_LT_EQ] = ACTIONS(6568),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(6216),
    [anon_sym_DOT_DOT] = ACTIONS(6570),
    [anon_sym_AMP_AMP] = ACTIONS(6572),
    [anon_sym_PIPE_PIPE] = ACTIONS(6574),
    [anon_sym_QMARK_QMARK] = ACTIONS(6576),
    [anon_sym_from] = ACTIONS(6270),
    [anon_sym_into] = ACTIONS(6270),
    [anon_sym_join] = ACTIONS(6270),
    [anon_sym_let] = ACTIONS(6270),
    [anon_sym_orderby] = ACTIONS(6270),
    [anon_sym_ascending] = ACTIONS(6270),
    [anon_sym_descending] = ACTIONS(6270),
    [anon_sym_group] = ACTIONS(6270),
    [anon_sym_select] = ACTIONS(6270),
    [anon_sym_as] = ACTIONS(6228),
    [anon_sym_is] = ACTIONS(6578),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(6232),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4647] = {
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7304),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4647),
    [sym_preproc_endregion] = STATE(4647),
    [sym_preproc_line] = STATE(4647),
    [sym_preproc_pragma] = STATE(4647),
    [sym_preproc_nullable] = STATE(4647),
    [sym_preproc_error] = STATE(4647),
    [sym_preproc_warning] = STATE(4647),
    [sym_preproc_define] = STATE(4647),
    [sym_preproc_undef] = STATE(4647),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_STAR] = ACTIONS(6110),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4648] = {
    [sym_preproc_region] = STATE(4648),
    [sym_preproc_endregion] = STATE(4648),
    [sym_preproc_line] = STATE(4648),
    [sym_preproc_pragma] = STATE(4648),
    [sym_preproc_nullable] = STATE(4648),
    [sym_preproc_error] = STATE(4648),
    [sym_preproc_warning] = STATE(4648),
    [sym_preproc_define] = STATE(4648),
    [sym_preproc_undef] = STATE(4648),
    [anon_sym_LBRACK] = ACTIONS(5526),
    [anon_sym_COMMA] = ACTIONS(5526),
    [anon_sym_LPAREN] = ACTIONS(5526),
    [anon_sym_LT] = ACTIONS(5528),
    [anon_sym_GT] = ACTIONS(5528),
    [anon_sym_where] = ACTIONS(5526),
    [anon_sym_QMARK] = ACTIONS(5528),
    [anon_sym_BANG] = ACTIONS(5528),
    [anon_sym_PLUS_PLUS] = ACTIONS(5526),
    [anon_sym_DASH_DASH] = ACTIONS(5526),
    [anon_sym_PLUS] = ACTIONS(5528),
    [anon_sym_DASH] = ACTIONS(5528),
    [anon_sym_STAR] = ACTIONS(5526),
    [anon_sym_SLASH] = ACTIONS(5528),
    [anon_sym_PERCENT] = ACTIONS(5526),
    [anon_sym_CARET] = ACTIONS(5526),
    [anon_sym_PIPE] = ACTIONS(5528),
    [anon_sym_AMP] = ACTIONS(5528),
    [anon_sym_LT_LT] = ACTIONS(5526),
    [anon_sym_GT_GT] = ACTIONS(5528),
    [anon_sym_GT_GT_GT] = ACTIONS(5526),
    [anon_sym_EQ_EQ] = ACTIONS(5526),
    [anon_sym_BANG_EQ] = ACTIONS(5526),
    [anon_sym_GT_EQ] = ACTIONS(5526),
    [anon_sym_LT_EQ] = ACTIONS(5526),
    [anon_sym_DOT] = ACTIONS(5528),
    [anon_sym_switch] = ACTIONS(5526),
    [anon_sym_DOT_DOT] = ACTIONS(5526),
    [anon_sym_and] = ACTIONS(5526),
    [anon_sym_or] = ACTIONS(5528),
    [anon_sym_AMP_AMP] = ACTIONS(5526),
    [anon_sym_PIPE_PIPE] = ACTIONS(5526),
    [anon_sym_QMARK_QMARK] = ACTIONS(5526),
    [anon_sym_from] = ACTIONS(5526),
    [anon_sym_into] = ACTIONS(5526),
    [anon_sym_join] = ACTIONS(5526),
    [anon_sym_let] = ACTIONS(5526),
    [anon_sym_orderby] = ACTIONS(5526),
    [anon_sym_ascending] = ACTIONS(5526),
    [anon_sym_descending] = ACTIONS(5526),
    [anon_sym_group] = ACTIONS(5526),
    [anon_sym_select] = ACTIONS(5526),
    [anon_sym_as] = ACTIONS(5528),
    [anon_sym_is] = ACTIONS(5526),
    [anon_sym_DASH_GT] = ACTIONS(5526),
    [anon_sym_with] = ACTIONS(5526),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4649] = {
    [sym_preproc_region] = STATE(4649),
    [sym_preproc_endregion] = STATE(4649),
    [sym_preproc_line] = STATE(4649),
    [sym_preproc_pragma] = STATE(4649),
    [sym_preproc_nullable] = STATE(4649),
    [sym_preproc_error] = STATE(4649),
    [sym_preproc_warning] = STATE(4649),
    [sym_preproc_define] = STATE(4649),
    [sym_preproc_undef] = STATE(4649),
    [anon_sym_LBRACK] = ACTIONS(5648),
    [anon_sym_COMMA] = ACTIONS(5648),
    [anon_sym_LPAREN] = ACTIONS(5648),
    [anon_sym_LT] = ACTIONS(5650),
    [anon_sym_GT] = ACTIONS(5650),
    [anon_sym_where] = ACTIONS(5648),
    [anon_sym_QMARK] = ACTIONS(5650),
    [anon_sym_BANG] = ACTIONS(5650),
    [anon_sym_PLUS_PLUS] = ACTIONS(5648),
    [anon_sym_DASH_DASH] = ACTIONS(5648),
    [anon_sym_PLUS] = ACTIONS(5650),
    [anon_sym_DASH] = ACTIONS(5650),
    [anon_sym_STAR] = ACTIONS(5648),
    [anon_sym_SLASH] = ACTIONS(5650),
    [anon_sym_PERCENT] = ACTIONS(5648),
    [anon_sym_CARET] = ACTIONS(5648),
    [anon_sym_PIPE] = ACTIONS(5650),
    [anon_sym_AMP] = ACTIONS(5650),
    [anon_sym_LT_LT] = ACTIONS(5648),
    [anon_sym_GT_GT] = ACTIONS(5650),
    [anon_sym_GT_GT_GT] = ACTIONS(5648),
    [anon_sym_EQ_EQ] = ACTIONS(5648),
    [anon_sym_BANG_EQ] = ACTIONS(5648),
    [anon_sym_GT_EQ] = ACTIONS(5648),
    [anon_sym_LT_EQ] = ACTIONS(5648),
    [anon_sym_DOT] = ACTIONS(5650),
    [anon_sym_switch] = ACTIONS(5648),
    [anon_sym_DOT_DOT] = ACTIONS(5648),
    [anon_sym_and] = ACTIONS(5648),
    [anon_sym_or] = ACTIONS(5650),
    [anon_sym_AMP_AMP] = ACTIONS(5648),
    [anon_sym_PIPE_PIPE] = ACTIONS(5648),
    [anon_sym_QMARK_QMARK] = ACTIONS(5648),
    [anon_sym_from] = ACTIONS(5648),
    [anon_sym_into] = ACTIONS(5648),
    [anon_sym_join] = ACTIONS(5648),
    [anon_sym_let] = ACTIONS(5648),
    [anon_sym_orderby] = ACTIONS(5648),
    [anon_sym_ascending] = ACTIONS(5648),
    [anon_sym_descending] = ACTIONS(5648),
    [anon_sym_group] = ACTIONS(5648),
    [anon_sym_select] = ACTIONS(5648),
    [anon_sym_as] = ACTIONS(5650),
    [anon_sym_is] = ACTIONS(5648),
    [anon_sym_DASH_GT] = ACTIONS(5648),
    [anon_sym_with] = ACTIONS(5648),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4650] = {
    [sym_preproc_region] = STATE(4650),
    [sym_preproc_endregion] = STATE(4650),
    [sym_preproc_line] = STATE(4650),
    [sym_preproc_pragma] = STATE(4650),
    [sym_preproc_nullable] = STATE(4650),
    [sym_preproc_error] = STATE(4650),
    [sym_preproc_warning] = STATE(4650),
    [sym_preproc_define] = STATE(4650),
    [sym_preproc_undef] = STATE(4650),
    [anon_sym_LBRACK] = ACTIONS(5401),
    [anon_sym_COMMA] = ACTIONS(5401),
    [anon_sym_LPAREN] = ACTIONS(5401),
    [anon_sym_LT] = ACTIONS(5403),
    [anon_sym_GT] = ACTIONS(5403),
    [anon_sym_where] = ACTIONS(5401),
    [anon_sym_QMARK] = ACTIONS(5403),
    [anon_sym_BANG] = ACTIONS(5403),
    [anon_sym_PLUS_PLUS] = ACTIONS(5401),
    [anon_sym_DASH_DASH] = ACTIONS(5401),
    [anon_sym_PLUS] = ACTIONS(5403),
    [anon_sym_DASH] = ACTIONS(5403),
    [anon_sym_STAR] = ACTIONS(5401),
    [anon_sym_SLASH] = ACTIONS(5403),
    [anon_sym_PERCENT] = ACTIONS(5401),
    [anon_sym_CARET] = ACTIONS(5401),
    [anon_sym_PIPE] = ACTIONS(5403),
    [anon_sym_AMP] = ACTIONS(5403),
    [anon_sym_LT_LT] = ACTIONS(5401),
    [anon_sym_GT_GT] = ACTIONS(5403),
    [anon_sym_GT_GT_GT] = ACTIONS(5401),
    [anon_sym_EQ_EQ] = ACTIONS(5401),
    [anon_sym_BANG_EQ] = ACTIONS(5401),
    [anon_sym_GT_EQ] = ACTIONS(5401),
    [anon_sym_LT_EQ] = ACTIONS(5401),
    [anon_sym_DOT] = ACTIONS(5403),
    [anon_sym_switch] = ACTIONS(5401),
    [anon_sym_DOT_DOT] = ACTIONS(5401),
    [anon_sym_and] = ACTIONS(5401),
    [anon_sym_or] = ACTIONS(5403),
    [anon_sym_AMP_AMP] = ACTIONS(5401),
    [anon_sym_PIPE_PIPE] = ACTIONS(5401),
    [anon_sym_QMARK_QMARK] = ACTIONS(5401),
    [anon_sym_from] = ACTIONS(5401),
    [anon_sym_into] = ACTIONS(5401),
    [anon_sym_join] = ACTIONS(5401),
    [anon_sym_let] = ACTIONS(5401),
    [anon_sym_orderby] = ACTIONS(5401),
    [anon_sym_ascending] = ACTIONS(5401),
    [anon_sym_descending] = ACTIONS(5401),
    [anon_sym_group] = ACTIONS(5401),
    [anon_sym_select] = ACTIONS(5401),
    [anon_sym_as] = ACTIONS(5403),
    [anon_sym_is] = ACTIONS(5401),
    [anon_sym_DASH_GT] = ACTIONS(5401),
    [anon_sym_with] = ACTIONS(5401),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4651] = {
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7206),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8986),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4651),
    [sym_preproc_endregion] = STATE(4651),
    [sym_preproc_line] = STATE(4651),
    [sym_preproc_pragma] = STATE(4651),
    [sym_preproc_nullable] = STATE(4651),
    [sym_preproc_error] = STATE(4651),
    [sym_preproc_warning] = STATE(4651),
    [sym_preproc_define] = STATE(4651),
    [sym_preproc_undef] = STATE(4651),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(4078),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(6140),
    [anon_sym_var] = ACTIONS(5369),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4652] = {
    [sym__name] = STATE(4343),
    [sym_alias_qualified_name] = STATE(3588),
    [sym__simple_name] = STATE(3588),
    [sym_qualified_name] = STATE(3588),
    [sym_generic_name] = STATE(3597),
    [sym_type] = STATE(3611),
    [sym_implicit_type] = STATE(3596),
    [sym_array_type] = STATE(3608),
    [sym__array_base_type] = STATE(8805),
    [sym_nullable_type] = STATE(3612),
    [sym_pointer_type] = STATE(3612),
    [sym__pointer_base_type] = STATE(9071),
    [sym_function_pointer_type] = STATE(3612),
    [sym_ref_type] = STATE(3596),
    [sym_scoped_type] = STATE(3596),
    [sym_tuple_type] = STATE(3621),
    [sym_identifier] = STATE(4004),
    [sym__reserved_identifier] = STATE(3572),
    [sym_preproc_region] = STATE(4652),
    [sym_preproc_endregion] = STATE(4652),
    [sym_preproc_line] = STATE(4652),
    [sym_preproc_pragma] = STATE(4652),
    [sym_preproc_nullable] = STATE(4652),
    [sym_preproc_error] = STATE(4652),
    [sym_preproc_warning] = STATE(4652),
    [sym_preproc_define] = STATE(4652),
    [sym_preproc_undef] = STATE(4652),
    [sym__identifier_token] = ACTIONS(4328),
    [anon_sym_alias] = ACTIONS(4330),
    [anon_sym_global] = ACTIONS(4330),
    [anon_sym_LPAREN] = ACTIONS(6654),
    [anon_sym_ref] = ACTIONS(4731),
    [anon_sym_delegate] = ACTIONS(6148),
    [anon_sym_file] = ACTIONS(4330),
    [anon_sym_readonly] = ACTIONS(6664),
    [anon_sym_where] = ACTIONS(4330),
    [anon_sym_notnull] = ACTIONS(4330),
    [anon_sym_unmanaged] = ACTIONS(4330),
    [anon_sym_scoped] = ACTIONS(6264),
    [anon_sym_var] = ACTIONS(6152),
    [sym_predefined_type] = ACTIONS(6154),
    [anon_sym_yield] = ACTIONS(4330),
    [anon_sym_when] = ACTIONS(4330),
    [anon_sym_from] = ACTIONS(4330),
    [anon_sym_into] = ACTIONS(4330),
    [anon_sym_join] = ACTIONS(4330),
    [anon_sym_on] = ACTIONS(4330),
    [anon_sym_equals] = ACTIONS(4330),
    [anon_sym_let] = ACTIONS(4330),
    [anon_sym_orderby] = ACTIONS(4330),
    [anon_sym_ascending] = ACTIONS(4330),
    [anon_sym_descending] = ACTIONS(4330),
    [anon_sym_group] = ACTIONS(4330),
    [anon_sym_by] = ACTIONS(4330),
    [anon_sym_select] = ACTIONS(4330),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4653] = {
    [sym_preproc_region] = STATE(4653),
    [sym_preproc_endregion] = STATE(4653),
    [sym_preproc_line] = STATE(4653),
    [sym_preproc_pragma] = STATE(4653),
    [sym_preproc_nullable] = STATE(4653),
    [sym_preproc_error] = STATE(4653),
    [sym_preproc_warning] = STATE(4653),
    [sym_preproc_define] = STATE(4653),
    [sym_preproc_undef] = STATE(4653),
    [anon_sym_LBRACK] = ACTIONS(5408),
    [anon_sym_COMMA] = ACTIONS(5408),
    [anon_sym_LPAREN] = ACTIONS(5408),
    [anon_sym_LT] = ACTIONS(5410),
    [anon_sym_GT] = ACTIONS(5410),
    [anon_sym_where] = ACTIONS(5408),
    [anon_sym_QMARK] = ACTIONS(5410),
    [anon_sym_BANG] = ACTIONS(5410),
    [anon_sym_PLUS_PLUS] = ACTIONS(5408),
    [anon_sym_DASH_DASH] = ACTIONS(5408),
    [anon_sym_PLUS] = ACTIONS(5410),
    [anon_sym_DASH] = ACTIONS(5410),
    [anon_sym_STAR] = ACTIONS(5408),
    [anon_sym_SLASH] = ACTIONS(5410),
    [anon_sym_PERCENT] = ACTIONS(5408),
    [anon_sym_CARET] = ACTIONS(5408),
    [anon_sym_PIPE] = ACTIONS(5410),
    [anon_sym_AMP] = ACTIONS(5410),
    [anon_sym_LT_LT] = ACTIONS(5408),
    [anon_sym_GT_GT] = ACTIONS(5410),
    [anon_sym_GT_GT_GT] = ACTIONS(5408),
    [anon_sym_EQ_EQ] = ACTIONS(5408),
    [anon_sym_BANG_EQ] = ACTIONS(5408),
    [anon_sym_GT_EQ] = ACTIONS(5408),
    [anon_sym_LT_EQ] = ACTIONS(5408),
    [anon_sym_DOT] = ACTIONS(5410),
    [anon_sym_switch] = ACTIONS(5408),
    [anon_sym_DOT_DOT] = ACTIONS(5408),
    [anon_sym_and] = ACTIONS(5408),
    [anon_sym_or] = ACTIONS(5410),
    [anon_sym_AMP_AMP] = ACTIONS(5408),
    [anon_sym_PIPE_PIPE] = ACTIONS(5408),
    [anon_sym_QMARK_QMARK] = ACTIONS(5408),
    [anon_sym_from] = ACTIONS(5408),
    [anon_sym_into] = ACTIONS(5408),
    [anon_sym_join] = ACTIONS(5408),
    [anon_sym_let] = ACTIONS(5408),
    [anon_sym_orderby] = ACTIONS(5408),
    [anon_sym_ascending] = ACTIONS(5408),
    [anon_sym_descending] = ACTIONS(5408),
    [anon_sym_group] = ACTIONS(5408),
    [anon_sym_select] = ACTIONS(5408),
    [anon_sym_as] = ACTIONS(5410),
    [anon_sym_is] = ACTIONS(5408),
    [anon_sym_DASH_GT] = ACTIONS(5408),
    [anon_sym_with] = ACTIONS(5408),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4654] = {
    [sym_preproc_region] = STATE(4654),
    [sym_preproc_endregion] = STATE(4654),
    [sym_preproc_line] = STATE(4654),
    [sym_preproc_pragma] = STATE(4654),
    [sym_preproc_nullable] = STATE(4654),
    [sym_preproc_error] = STATE(4654),
    [sym_preproc_warning] = STATE(4654),
    [sym_preproc_define] = STATE(4654),
    [sym_preproc_undef] = STATE(4654),
    [anon_sym_LBRACK] = ACTIONS(5600),
    [anon_sym_COMMA] = ACTIONS(5600),
    [anon_sym_LPAREN] = ACTIONS(5600),
    [anon_sym_LT] = ACTIONS(5602),
    [anon_sym_GT] = ACTIONS(5602),
    [anon_sym_where] = ACTIONS(5600),
    [anon_sym_QMARK] = ACTIONS(5602),
    [anon_sym_BANG] = ACTIONS(5602),
    [anon_sym_PLUS_PLUS] = ACTIONS(5600),
    [anon_sym_DASH_DASH] = ACTIONS(5600),
    [anon_sym_PLUS] = ACTIONS(5602),
    [anon_sym_DASH] = ACTIONS(5602),
    [anon_sym_STAR] = ACTIONS(5600),
    [anon_sym_SLASH] = ACTIONS(5602),
    [anon_sym_PERCENT] = ACTIONS(5600),
    [anon_sym_CARET] = ACTIONS(5600),
    [anon_sym_PIPE] = ACTIONS(5602),
    [anon_sym_AMP] = ACTIONS(5602),
    [anon_sym_LT_LT] = ACTIONS(5600),
    [anon_sym_GT_GT] = ACTIONS(5602),
    [anon_sym_GT_GT_GT] = ACTIONS(5600),
    [anon_sym_EQ_EQ] = ACTIONS(5600),
    [anon_sym_BANG_EQ] = ACTIONS(5600),
    [anon_sym_GT_EQ] = ACTIONS(5600),
    [anon_sym_LT_EQ] = ACTIONS(5600),
    [anon_sym_DOT] = ACTIONS(5602),
    [anon_sym_switch] = ACTIONS(5600),
    [anon_sym_DOT_DOT] = ACTIONS(5600),
    [anon_sym_and] = ACTIONS(5600),
    [anon_sym_or] = ACTIONS(5602),
    [anon_sym_AMP_AMP] = ACTIONS(5600),
    [anon_sym_PIPE_PIPE] = ACTIONS(5600),
    [anon_sym_QMARK_QMARK] = ACTIONS(5600),
    [anon_sym_from] = ACTIONS(5600),
    [anon_sym_into] = ACTIONS(5600),
    [anon_sym_join] = ACTIONS(5600),
    [anon_sym_let] = ACTIONS(5600),
    [anon_sym_orderby] = ACTIONS(5600),
    [anon_sym_ascending] = ACTIONS(5600),
    [anon_sym_descending] = ACTIONS(5600),
    [anon_sym_group] = ACTIONS(5600),
    [anon_sym_select] = ACTIONS(5600),
    [anon_sym_as] = ACTIONS(5602),
    [anon_sym_is] = ACTIONS(5600),
    [anon_sym_DASH_GT] = ACTIONS(5600),
    [anon_sym_with] = ACTIONS(5600),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4655] = {
    [sym_preproc_region] = STATE(4655),
    [sym_preproc_endregion] = STATE(4655),
    [sym_preproc_line] = STATE(4655),
    [sym_preproc_pragma] = STATE(4655),
    [sym_preproc_nullable] = STATE(4655),
    [sym_preproc_error] = STATE(4655),
    [sym_preproc_warning] = STATE(4655),
    [sym_preproc_define] = STATE(4655),
    [sym_preproc_undef] = STATE(4655),
    [anon_sym_LBRACK] = ACTIONS(5656),
    [anon_sym_COMMA] = ACTIONS(5656),
    [anon_sym_LPAREN] = ACTIONS(5656),
    [anon_sym_LT] = ACTIONS(5658),
    [anon_sym_GT] = ACTIONS(5658),
    [anon_sym_where] = ACTIONS(5656),
    [anon_sym_QMARK] = ACTIONS(5658),
    [anon_sym_BANG] = ACTIONS(5658),
    [anon_sym_PLUS_PLUS] = ACTIONS(5656),
    [anon_sym_DASH_DASH] = ACTIONS(5656),
    [anon_sym_PLUS] = ACTIONS(5658),
    [anon_sym_DASH] = ACTIONS(5658),
    [anon_sym_STAR] = ACTIONS(5656),
    [anon_sym_SLASH] = ACTIONS(5658),
    [anon_sym_PERCENT] = ACTIONS(5656),
    [anon_sym_CARET] = ACTIONS(5656),
    [anon_sym_PIPE] = ACTIONS(5658),
    [anon_sym_AMP] = ACTIONS(5658),
    [anon_sym_LT_LT] = ACTIONS(5656),
    [anon_sym_GT_GT] = ACTIONS(5658),
    [anon_sym_GT_GT_GT] = ACTIONS(5656),
    [anon_sym_EQ_EQ] = ACTIONS(5656),
    [anon_sym_BANG_EQ] = ACTIONS(5656),
    [anon_sym_GT_EQ] = ACTIONS(5656),
    [anon_sym_LT_EQ] = ACTIONS(5656),
    [anon_sym_DOT] = ACTIONS(5658),
    [anon_sym_switch] = ACTIONS(5656),
    [anon_sym_DOT_DOT] = ACTIONS(5656),
    [anon_sym_and] = ACTIONS(5656),
    [anon_sym_or] = ACTIONS(5658),
    [anon_sym_AMP_AMP] = ACTIONS(5656),
    [anon_sym_PIPE_PIPE] = ACTIONS(5656),
    [anon_sym_QMARK_QMARK] = ACTIONS(5656),
    [anon_sym_from] = ACTIONS(5656),
    [anon_sym_into] = ACTIONS(5656),
    [anon_sym_join] = ACTIONS(5656),
    [anon_sym_let] = ACTIONS(5656),
    [anon_sym_orderby] = ACTIONS(5656),
    [anon_sym_ascending] = ACTIONS(5656),
    [anon_sym_descending] = ACTIONS(5656),
    [anon_sym_group] = ACTIONS(5656),
    [anon_sym_select] = ACTIONS(5656),
    [anon_sym_as] = ACTIONS(5658),
    [anon_sym_is] = ACTIONS(5656),
    [anon_sym_DASH_GT] = ACTIONS(5656),
    [anon_sym_with] = ACTIONS(5656),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4656] = {
    [sym_preproc_region] = STATE(4656),
    [sym_preproc_endregion] = STATE(4656),
    [sym_preproc_line] = STATE(4656),
    [sym_preproc_pragma] = STATE(4656),
    [sym_preproc_nullable] = STATE(4656),
    [sym_preproc_error] = STATE(4656),
    [sym_preproc_warning] = STATE(4656),
    [sym_preproc_define] = STATE(4656),
    [sym_preproc_undef] = STATE(4656),
    [anon_sym_LBRACK] = ACTIONS(5604),
    [anon_sym_COMMA] = ACTIONS(5604),
    [anon_sym_LPAREN] = ACTIONS(5604),
    [anon_sym_LT] = ACTIONS(5606),
    [anon_sym_GT] = ACTIONS(5606),
    [anon_sym_where] = ACTIONS(5604),
    [anon_sym_QMARK] = ACTIONS(5606),
    [anon_sym_BANG] = ACTIONS(5606),
    [anon_sym_PLUS_PLUS] = ACTIONS(5604),
    [anon_sym_DASH_DASH] = ACTIONS(5604),
    [anon_sym_PLUS] = ACTIONS(5606),
    [anon_sym_DASH] = ACTIONS(5606),
    [anon_sym_STAR] = ACTIONS(5604),
    [anon_sym_SLASH] = ACTIONS(5606),
    [anon_sym_PERCENT] = ACTIONS(5604),
    [anon_sym_CARET] = ACTIONS(5604),
    [anon_sym_PIPE] = ACTIONS(5606),
    [anon_sym_AMP] = ACTIONS(5606),
    [anon_sym_LT_LT] = ACTIONS(5604),
    [anon_sym_GT_GT] = ACTIONS(5606),
    [anon_sym_GT_GT_GT] = ACTIONS(5604),
    [anon_sym_EQ_EQ] = ACTIONS(5604),
    [anon_sym_BANG_EQ] = ACTIONS(5604),
    [anon_sym_GT_EQ] = ACTIONS(5604),
    [anon_sym_LT_EQ] = ACTIONS(5604),
    [anon_sym_DOT] = ACTIONS(5606),
    [anon_sym_switch] = ACTIONS(5604),
    [anon_sym_DOT_DOT] = ACTIONS(5604),
    [anon_sym_and] = ACTIONS(5604),
    [anon_sym_or] = ACTIONS(5606),
    [anon_sym_AMP_AMP] = ACTIONS(5604),
    [anon_sym_PIPE_PIPE] = ACTIONS(5604),
    [anon_sym_QMARK_QMARK] = ACTIONS(5604),
    [anon_sym_from] = ACTIONS(5604),
    [anon_sym_into] = ACTIONS(5604),
    [anon_sym_join] = ACTIONS(5604),
    [anon_sym_let] = ACTIONS(5604),
    [anon_sym_orderby] = ACTIONS(5604),
    [anon_sym_ascending] = ACTIONS(5604),
    [anon_sym_descending] = ACTIONS(5604),
    [anon_sym_group] = ACTIONS(5604),
    [anon_sym_select] = ACTIONS(5604),
    [anon_sym_as] = ACTIONS(5606),
    [anon_sym_is] = ACTIONS(5604),
    [anon_sym_DASH_GT] = ACTIONS(5604),
    [anon_sym_with] = ACTIONS(5604),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4657] = {
    [sym_preproc_region] = STATE(4657),
    [sym_preproc_endregion] = STATE(4657),
    [sym_preproc_line] = STATE(4657),
    [sym_preproc_pragma] = STATE(4657),
    [sym_preproc_nullable] = STATE(4657),
    [sym_preproc_error] = STATE(4657),
    [sym_preproc_warning] = STATE(4657),
    [sym_preproc_define] = STATE(4657),
    [sym_preproc_undef] = STATE(4657),
    [anon_sym_LBRACK] = ACTIONS(5286),
    [anon_sym_COMMA] = ACTIONS(5286),
    [anon_sym_LPAREN] = ACTIONS(5286),
    [anon_sym_LT] = ACTIONS(5288),
    [anon_sym_GT] = ACTIONS(5288),
    [anon_sym_where] = ACTIONS(5286),
    [anon_sym_QMARK] = ACTIONS(5288),
    [anon_sym_BANG] = ACTIONS(5288),
    [anon_sym_PLUS_PLUS] = ACTIONS(5286),
    [anon_sym_DASH_DASH] = ACTIONS(5286),
    [anon_sym_PLUS] = ACTIONS(5288),
    [anon_sym_DASH] = ACTIONS(5288),
    [anon_sym_STAR] = ACTIONS(5286),
    [anon_sym_SLASH] = ACTIONS(5288),
    [anon_sym_PERCENT] = ACTIONS(5286),
    [anon_sym_CARET] = ACTIONS(5286),
    [anon_sym_PIPE] = ACTIONS(5288),
    [anon_sym_AMP] = ACTIONS(5288),
    [anon_sym_LT_LT] = ACTIONS(5286),
    [anon_sym_GT_GT] = ACTIONS(5288),
    [anon_sym_GT_GT_GT] = ACTIONS(5286),
    [anon_sym_EQ_EQ] = ACTIONS(5286),
    [anon_sym_BANG_EQ] = ACTIONS(5286),
    [anon_sym_GT_EQ] = ACTIONS(5286),
    [anon_sym_LT_EQ] = ACTIONS(5286),
    [anon_sym_DOT] = ACTIONS(5288),
    [anon_sym_switch] = ACTIONS(5286),
    [anon_sym_DOT_DOT] = ACTIONS(5286),
    [anon_sym_and] = ACTIONS(5286),
    [anon_sym_or] = ACTIONS(5288),
    [anon_sym_AMP_AMP] = ACTIONS(5286),
    [anon_sym_PIPE_PIPE] = ACTIONS(5286),
    [anon_sym_QMARK_QMARK] = ACTIONS(5286),
    [anon_sym_from] = ACTIONS(5286),
    [anon_sym_into] = ACTIONS(5286),
    [anon_sym_join] = ACTIONS(5286),
    [anon_sym_let] = ACTIONS(5286),
    [anon_sym_orderby] = ACTIONS(5286),
    [anon_sym_ascending] = ACTIONS(5286),
    [anon_sym_descending] = ACTIONS(5286),
    [anon_sym_group] = ACTIONS(5286),
    [anon_sym_select] = ACTIONS(5286),
    [anon_sym_as] = ACTIONS(5288),
    [anon_sym_is] = ACTIONS(5286),
    [anon_sym_DASH_GT] = ACTIONS(5286),
    [anon_sym_with] = ACTIONS(5286),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4658] = {
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(6020),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4658),
    [sym_preproc_endregion] = STATE(4658),
    [sym_preproc_line] = STATE(4658),
    [sym_preproc_pragma] = STATE(4658),
    [sym_preproc_nullable] = STATE(4658),
    [sym_preproc_error] = STATE(4658),
    [sym_preproc_warning] = STATE(4658),
    [sym_preproc_define] = STATE(4658),
    [sym_preproc_undef] = STATE(4658),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(6608),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_readonly] = ACTIONS(6666),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(6612),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4659] = {
    [sym__name] = STATE(3744),
    [sym_alias_qualified_name] = STATE(3680),
    [sym__simple_name] = STATE(3680),
    [sym_qualified_name] = STATE(3680),
    [sym_generic_name] = STATE(3648),
    [sym_type] = STATE(3731),
    [sym_implicit_type] = STATE(3707),
    [sym_array_type] = STATE(3725),
    [sym__array_base_type] = STATE(8829),
    [sym_nullable_type] = STATE(3681),
    [sym_pointer_type] = STATE(3681),
    [sym__pointer_base_type] = STATE(9538),
    [sym_function_pointer_type] = STATE(3681),
    [sym_ref_type] = STATE(3707),
    [sym_scoped_type] = STATE(3707),
    [sym_tuple_type] = STATE(3631),
    [sym_identifier] = STATE(3590),
    [sym__reserved_identifier] = STATE(3625),
    [sym_preproc_region] = STATE(4659),
    [sym_preproc_endregion] = STATE(4659),
    [sym_preproc_line] = STATE(4659),
    [sym_preproc_pragma] = STATE(4659),
    [sym_preproc_nullable] = STATE(4659),
    [sym_preproc_error] = STATE(4659),
    [sym_preproc_warning] = STATE(4659),
    [sym_preproc_define] = STATE(4659),
    [sym_preproc_undef] = STATE(4659),
    [sym__identifier_token] = ACTIONS(4349),
    [anon_sym_alias] = ACTIONS(4351),
    [anon_sym_global] = ACTIONS(4351),
    [anon_sym_LPAREN] = ACTIONS(6584),
    [anon_sym_ref] = ACTIONS(4721),
    [anon_sym_delegate] = ACTIONS(4512),
    [anon_sym_file] = ACTIONS(4351),
    [anon_sym_readonly] = ACTIONS(6668),
    [anon_sym_where] = ACTIONS(4351),
    [anon_sym_notnull] = ACTIONS(4351),
    [anon_sym_unmanaged] = ACTIONS(4351),
    [anon_sym_scoped] = ACTIONS(6307),
    [anon_sym_var] = ACTIONS(4516),
    [sym_predefined_type] = ACTIONS(4518),
    [anon_sym_yield] = ACTIONS(4351),
    [anon_sym_when] = ACTIONS(4351),
    [anon_sym_from] = ACTIONS(4351),
    [anon_sym_into] = ACTIONS(4351),
    [anon_sym_join] = ACTIONS(4351),
    [anon_sym_on] = ACTIONS(4351),
    [anon_sym_equals] = ACTIONS(4351),
    [anon_sym_let] = ACTIONS(4351),
    [anon_sym_orderby] = ACTIONS(4351),
    [anon_sym_ascending] = ACTIONS(4351),
    [anon_sym_descending] = ACTIONS(4351),
    [anon_sym_group] = ACTIONS(4351),
    [anon_sym_by] = ACTIONS(4351),
    [anon_sym_select] = ACTIONS(4351),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4660] = {
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7206),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8770),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4660),
    [sym_preproc_endregion] = STATE(4660),
    [sym_preproc_line] = STATE(4660),
    [sym_preproc_pragma] = STATE(4660),
    [sym_preproc_nullable] = STATE(4660),
    [sym_preproc_error] = STATE(4660),
    [sym_preproc_warning] = STATE(4660),
    [sym_preproc_define] = STATE(4660),
    [sym_preproc_undef] = STATE(4660),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(4078),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(6140),
    [anon_sym_var] = ACTIONS(5369),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4661] = {
    [sym__name] = STATE(3744),
    [sym_alias_qualified_name] = STATE(3680),
    [sym__simple_name] = STATE(3680),
    [sym_qualified_name] = STATE(3680),
    [sym_generic_name] = STATE(3648),
    [sym_type] = STATE(3731),
    [sym_implicit_type] = STATE(3707),
    [sym_array_type] = STATE(3725),
    [sym__array_base_type] = STATE(8829),
    [sym_nullable_type] = STATE(3681),
    [sym_pointer_type] = STATE(3681),
    [sym__pointer_base_type] = STATE(9538),
    [sym_function_pointer_type] = STATE(3681),
    [sym_ref_type] = STATE(3707),
    [sym_scoped_type] = STATE(3707),
    [sym_tuple_type] = STATE(3631),
    [sym_identifier] = STATE(3590),
    [sym__reserved_identifier] = STATE(3625),
    [sym_preproc_region] = STATE(4661),
    [sym_preproc_endregion] = STATE(4661),
    [sym_preproc_line] = STATE(4661),
    [sym_preproc_pragma] = STATE(4661),
    [sym_preproc_nullable] = STATE(4661),
    [sym_preproc_error] = STATE(4661),
    [sym_preproc_warning] = STATE(4661),
    [sym_preproc_define] = STATE(4661),
    [sym_preproc_undef] = STATE(4661),
    [sym__identifier_token] = ACTIONS(4349),
    [anon_sym_alias] = ACTIONS(4351),
    [anon_sym_global] = ACTIONS(4351),
    [anon_sym_LPAREN] = ACTIONS(6584),
    [anon_sym_ref] = ACTIONS(4353),
    [anon_sym_delegate] = ACTIONS(4512),
    [anon_sym_file] = ACTIONS(4351),
    [anon_sym_readonly] = ACTIONS(6670),
    [anon_sym_where] = ACTIONS(4351),
    [anon_sym_notnull] = ACTIONS(4351),
    [anon_sym_unmanaged] = ACTIONS(4351),
    [anon_sym_scoped] = ACTIONS(4514),
    [anon_sym_var] = ACTIONS(4516),
    [sym_predefined_type] = ACTIONS(4518),
    [anon_sym_yield] = ACTIONS(4351),
    [anon_sym_when] = ACTIONS(4351),
    [anon_sym_from] = ACTIONS(4351),
    [anon_sym_into] = ACTIONS(4351),
    [anon_sym_join] = ACTIONS(4351),
    [anon_sym_on] = ACTIONS(4351),
    [anon_sym_equals] = ACTIONS(4351),
    [anon_sym_let] = ACTIONS(4351),
    [anon_sym_orderby] = ACTIONS(4351),
    [anon_sym_ascending] = ACTIONS(4351),
    [anon_sym_descending] = ACTIONS(4351),
    [anon_sym_group] = ACTIONS(4351),
    [anon_sym_by] = ACTIONS(4351),
    [anon_sym_select] = ACTIONS(4351),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4662] = {
    [sym_preproc_region] = STATE(4662),
    [sym_preproc_endregion] = STATE(4662),
    [sym_preproc_line] = STATE(4662),
    [sym_preproc_pragma] = STATE(4662),
    [sym_preproc_nullable] = STATE(4662),
    [sym_preproc_error] = STATE(4662),
    [sym_preproc_warning] = STATE(4662),
    [sym_preproc_define] = STATE(4662),
    [sym_preproc_undef] = STATE(4662),
    [anon_sym_LBRACK] = ACTIONS(2997),
    [anon_sym_COMMA] = ACTIONS(2997),
    [anon_sym_LPAREN] = ACTIONS(2997),
    [anon_sym_LT] = ACTIONS(2995),
    [anon_sym_GT] = ACTIONS(2995),
    [anon_sym_where] = ACTIONS(2997),
    [anon_sym_QMARK] = ACTIONS(2995),
    [anon_sym_BANG] = ACTIONS(2995),
    [anon_sym_PLUS_PLUS] = ACTIONS(2997),
    [anon_sym_DASH_DASH] = ACTIONS(2997),
    [anon_sym_PLUS] = ACTIONS(2995),
    [anon_sym_DASH] = ACTIONS(2995),
    [anon_sym_STAR] = ACTIONS(2997),
    [anon_sym_SLASH] = ACTIONS(2995),
    [anon_sym_PERCENT] = ACTIONS(2997),
    [anon_sym_CARET] = ACTIONS(2997),
    [anon_sym_PIPE] = ACTIONS(2995),
    [anon_sym_AMP] = ACTIONS(2995),
    [anon_sym_LT_LT] = ACTIONS(2997),
    [anon_sym_GT_GT] = ACTIONS(2995),
    [anon_sym_GT_GT_GT] = ACTIONS(2997),
    [anon_sym_EQ_EQ] = ACTIONS(2997),
    [anon_sym_BANG_EQ] = ACTIONS(2997),
    [anon_sym_GT_EQ] = ACTIONS(2997),
    [anon_sym_LT_EQ] = ACTIONS(2997),
    [anon_sym_DOT] = ACTIONS(2995),
    [anon_sym_switch] = ACTIONS(2997),
    [anon_sym_DOT_DOT] = ACTIONS(2997),
    [anon_sym_and] = ACTIONS(2997),
    [anon_sym_or] = ACTIONS(2995),
    [anon_sym_AMP_AMP] = ACTIONS(2997),
    [anon_sym_PIPE_PIPE] = ACTIONS(2997),
    [anon_sym_QMARK_QMARK] = ACTIONS(2997),
    [anon_sym_from] = ACTIONS(2997),
    [anon_sym_into] = ACTIONS(2997),
    [anon_sym_join] = ACTIONS(2997),
    [anon_sym_let] = ACTIONS(2997),
    [anon_sym_orderby] = ACTIONS(2997),
    [anon_sym_ascending] = ACTIONS(2997),
    [anon_sym_descending] = ACTIONS(2997),
    [anon_sym_group] = ACTIONS(2997),
    [anon_sym_select] = ACTIONS(2997),
    [anon_sym_as] = ACTIONS(2995),
    [anon_sym_is] = ACTIONS(2997),
    [anon_sym_DASH_GT] = ACTIONS(2997),
    [anon_sym_with] = ACTIONS(2997),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4663] = {
    [sym_preproc_region] = STATE(4663),
    [sym_preproc_endregion] = STATE(4663),
    [sym_preproc_line] = STATE(4663),
    [sym_preproc_pragma] = STATE(4663),
    [sym_preproc_nullable] = STATE(4663),
    [sym_preproc_error] = STATE(4663),
    [sym_preproc_warning] = STATE(4663),
    [sym_preproc_define] = STATE(4663),
    [sym_preproc_undef] = STATE(4663),
    [anon_sym_LBRACK] = ACTIONS(5846),
    [anon_sym_COMMA] = ACTIONS(5846),
    [anon_sym_LPAREN] = ACTIONS(5846),
    [anon_sym_LT] = ACTIONS(5848),
    [anon_sym_GT] = ACTIONS(5848),
    [anon_sym_where] = ACTIONS(5846),
    [anon_sym_QMARK] = ACTIONS(5848),
    [anon_sym_BANG] = ACTIONS(5848),
    [anon_sym_PLUS_PLUS] = ACTIONS(5846),
    [anon_sym_DASH_DASH] = ACTIONS(5846),
    [anon_sym_PLUS] = ACTIONS(5848),
    [anon_sym_DASH] = ACTIONS(5848),
    [anon_sym_STAR] = ACTIONS(5846),
    [anon_sym_SLASH] = ACTIONS(5848),
    [anon_sym_PERCENT] = ACTIONS(5846),
    [anon_sym_CARET] = ACTIONS(5846),
    [anon_sym_PIPE] = ACTIONS(5848),
    [anon_sym_AMP] = ACTIONS(5848),
    [anon_sym_LT_LT] = ACTIONS(5846),
    [anon_sym_GT_GT] = ACTIONS(5848),
    [anon_sym_GT_GT_GT] = ACTIONS(5846),
    [anon_sym_EQ_EQ] = ACTIONS(5846),
    [anon_sym_BANG_EQ] = ACTIONS(5846),
    [anon_sym_GT_EQ] = ACTIONS(5846),
    [anon_sym_LT_EQ] = ACTIONS(5846),
    [anon_sym_DOT] = ACTIONS(5848),
    [anon_sym_switch] = ACTIONS(5846),
    [anon_sym_DOT_DOT] = ACTIONS(5846),
    [anon_sym_and] = ACTIONS(5846),
    [anon_sym_or] = ACTIONS(5848),
    [anon_sym_AMP_AMP] = ACTIONS(5846),
    [anon_sym_PIPE_PIPE] = ACTIONS(5846),
    [anon_sym_QMARK_QMARK] = ACTIONS(5846),
    [anon_sym_from] = ACTIONS(5846),
    [anon_sym_into] = ACTIONS(5846),
    [anon_sym_join] = ACTIONS(5846),
    [anon_sym_let] = ACTIONS(5846),
    [anon_sym_orderby] = ACTIONS(5846),
    [anon_sym_ascending] = ACTIONS(5846),
    [anon_sym_descending] = ACTIONS(5846),
    [anon_sym_group] = ACTIONS(5846),
    [anon_sym_select] = ACTIONS(5846),
    [anon_sym_as] = ACTIONS(5848),
    [anon_sym_is] = ACTIONS(5846),
    [anon_sym_DASH_GT] = ACTIONS(5846),
    [anon_sym_with] = ACTIONS(5846),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4664] = {
    [sym_preproc_region] = STATE(4664),
    [sym_preproc_endregion] = STATE(4664),
    [sym_preproc_line] = STATE(4664),
    [sym_preproc_pragma] = STATE(4664),
    [sym_preproc_nullable] = STATE(4664),
    [sym_preproc_error] = STATE(4664),
    [sym_preproc_warning] = STATE(4664),
    [sym_preproc_define] = STATE(4664),
    [sym_preproc_undef] = STATE(4664),
    [anon_sym_LBRACK] = ACTIONS(5608),
    [anon_sym_COMMA] = ACTIONS(5608),
    [anon_sym_LPAREN] = ACTIONS(5608),
    [anon_sym_LT] = ACTIONS(5610),
    [anon_sym_GT] = ACTIONS(5610),
    [anon_sym_where] = ACTIONS(5608),
    [anon_sym_QMARK] = ACTIONS(5610),
    [anon_sym_BANG] = ACTIONS(5610),
    [anon_sym_PLUS_PLUS] = ACTIONS(5608),
    [anon_sym_DASH_DASH] = ACTIONS(5608),
    [anon_sym_PLUS] = ACTIONS(5610),
    [anon_sym_DASH] = ACTIONS(5610),
    [anon_sym_STAR] = ACTIONS(5608),
    [anon_sym_SLASH] = ACTIONS(5610),
    [anon_sym_PERCENT] = ACTIONS(5608),
    [anon_sym_CARET] = ACTIONS(5608),
    [anon_sym_PIPE] = ACTIONS(5610),
    [anon_sym_AMP] = ACTIONS(5610),
    [anon_sym_LT_LT] = ACTIONS(5608),
    [anon_sym_GT_GT] = ACTIONS(5610),
    [anon_sym_GT_GT_GT] = ACTIONS(5608),
    [anon_sym_EQ_EQ] = ACTIONS(5608),
    [anon_sym_BANG_EQ] = ACTIONS(5608),
    [anon_sym_GT_EQ] = ACTIONS(5608),
    [anon_sym_LT_EQ] = ACTIONS(5608),
    [anon_sym_DOT] = ACTIONS(5610),
    [anon_sym_switch] = ACTIONS(5608),
    [anon_sym_DOT_DOT] = ACTIONS(5608),
    [anon_sym_and] = ACTIONS(5608),
    [anon_sym_or] = ACTIONS(5610),
    [anon_sym_AMP_AMP] = ACTIONS(5608),
    [anon_sym_PIPE_PIPE] = ACTIONS(5608),
    [anon_sym_QMARK_QMARK] = ACTIONS(5608),
    [anon_sym_from] = ACTIONS(5608),
    [anon_sym_into] = ACTIONS(5608),
    [anon_sym_join] = ACTIONS(5608),
    [anon_sym_let] = ACTIONS(5608),
    [anon_sym_orderby] = ACTIONS(5608),
    [anon_sym_ascending] = ACTIONS(5608),
    [anon_sym_descending] = ACTIONS(5608),
    [anon_sym_group] = ACTIONS(5608),
    [anon_sym_select] = ACTIONS(5608),
    [anon_sym_as] = ACTIONS(5610),
    [anon_sym_is] = ACTIONS(5608),
    [anon_sym_DASH_GT] = ACTIONS(5608),
    [anon_sym_with] = ACTIONS(5608),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4665] = {
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7206),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8812),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4665),
    [sym_preproc_endregion] = STATE(4665),
    [sym_preproc_line] = STATE(4665),
    [sym_preproc_pragma] = STATE(4665),
    [sym_preproc_nullable] = STATE(4665),
    [sym_preproc_error] = STATE(4665),
    [sym_preproc_warning] = STATE(4665),
    [sym_preproc_define] = STATE(4665),
    [sym_preproc_undef] = STATE(4665),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(4078),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(6140),
    [anon_sym_var] = ACTIONS(5369),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4666] = {
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(6020),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4666),
    [sym_preproc_endregion] = STATE(4666),
    [sym_preproc_line] = STATE(4666),
    [sym_preproc_pragma] = STATE(4666),
    [sym_preproc_nullable] = STATE(4666),
    [sym_preproc_error] = STATE(4666),
    [sym_preproc_warning] = STATE(4666),
    [sym_preproc_define] = STATE(4666),
    [sym_preproc_undef] = STATE(4666),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(4078),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_readonly] = ACTIONS(2739),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(6140),
    [anon_sym_var] = ACTIONS(5369),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4667] = {
    [sym__name] = STATE(4343),
    [sym_alias_qualified_name] = STATE(3588),
    [sym__simple_name] = STATE(3588),
    [sym_qualified_name] = STATE(3588),
    [sym_generic_name] = STATE(3597),
    [sym_type] = STATE(3611),
    [sym_implicit_type] = STATE(3596),
    [sym_array_type] = STATE(3608),
    [sym__array_base_type] = STATE(8805),
    [sym_nullable_type] = STATE(3612),
    [sym_pointer_type] = STATE(3612),
    [sym__pointer_base_type] = STATE(9071),
    [sym_function_pointer_type] = STATE(3612),
    [sym_ref_type] = STATE(3596),
    [sym_scoped_type] = STATE(3596),
    [sym_tuple_type] = STATE(3621),
    [sym_identifier] = STATE(4004),
    [sym__reserved_identifier] = STATE(3572),
    [sym_preproc_region] = STATE(4667),
    [sym_preproc_endregion] = STATE(4667),
    [sym_preproc_line] = STATE(4667),
    [sym_preproc_pragma] = STATE(4667),
    [sym_preproc_nullable] = STATE(4667),
    [sym_preproc_error] = STATE(4667),
    [sym_preproc_warning] = STATE(4667),
    [sym_preproc_define] = STATE(4667),
    [sym_preproc_undef] = STATE(4667),
    [sym__identifier_token] = ACTIONS(4328),
    [anon_sym_alias] = ACTIONS(4330),
    [anon_sym_global] = ACTIONS(4330),
    [anon_sym_LPAREN] = ACTIONS(6654),
    [anon_sym_ref] = ACTIONS(4727),
    [anon_sym_delegate] = ACTIONS(6148),
    [anon_sym_file] = ACTIONS(4330),
    [anon_sym_readonly] = ACTIONS(6672),
    [anon_sym_where] = ACTIONS(4330),
    [anon_sym_notnull] = ACTIONS(4330),
    [anon_sym_unmanaged] = ACTIONS(4330),
    [anon_sym_scoped] = ACTIONS(6274),
    [anon_sym_var] = ACTIONS(6152),
    [sym_predefined_type] = ACTIONS(6154),
    [anon_sym_yield] = ACTIONS(4330),
    [anon_sym_when] = ACTIONS(4330),
    [anon_sym_from] = ACTIONS(4330),
    [anon_sym_into] = ACTIONS(4330),
    [anon_sym_join] = ACTIONS(4330),
    [anon_sym_on] = ACTIONS(4330),
    [anon_sym_equals] = ACTIONS(4330),
    [anon_sym_let] = ACTIONS(4330),
    [anon_sym_orderby] = ACTIONS(4330),
    [anon_sym_ascending] = ACTIONS(4330),
    [anon_sym_descending] = ACTIONS(4330),
    [anon_sym_group] = ACTIONS(4330),
    [anon_sym_by] = ACTIONS(4330),
    [anon_sym_select] = ACTIONS(4330),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4668] = {
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7206),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8848),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4668),
    [sym_preproc_endregion] = STATE(4668),
    [sym_preproc_line] = STATE(4668),
    [sym_preproc_pragma] = STATE(4668),
    [sym_preproc_nullable] = STATE(4668),
    [sym_preproc_error] = STATE(4668),
    [sym_preproc_warning] = STATE(4668),
    [sym_preproc_define] = STATE(4668),
    [sym_preproc_undef] = STATE(4668),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(4078),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(6140),
    [anon_sym_var] = ACTIONS(5369),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4669] = {
    [sym_preproc_region] = STATE(4669),
    [sym_preproc_endregion] = STATE(4669),
    [sym_preproc_line] = STATE(4669),
    [sym_preproc_pragma] = STATE(4669),
    [sym_preproc_nullable] = STATE(4669),
    [sym_preproc_error] = STATE(4669),
    [sym_preproc_warning] = STATE(4669),
    [sym_preproc_define] = STATE(4669),
    [sym_preproc_undef] = STATE(4669),
    [aux_sym__query_body_repeat2] = STATE(4669),
    [anon_sym_SEMI] = ACTIONS(6484),
    [anon_sym_LBRACK] = ACTIONS(6484),
    [anon_sym_COMMA] = ACTIONS(6484),
    [anon_sym_RBRACK] = ACTIONS(6484),
    [anon_sym_LPAREN] = ACTIONS(6484),
    [anon_sym_RPAREN] = ACTIONS(6484),
    [anon_sym_RBRACE] = ACTIONS(6484),
    [anon_sym_LT] = ACTIONS(6486),
    [anon_sym_GT] = ACTIONS(6486),
    [anon_sym_in] = ACTIONS(6486),
    [anon_sym_QMARK] = ACTIONS(6486),
    [anon_sym_BANG] = ACTIONS(6486),
    [anon_sym_PLUS_PLUS] = ACTIONS(6484),
    [anon_sym_DASH_DASH] = ACTIONS(6484),
    [anon_sym_PLUS] = ACTIONS(6486),
    [anon_sym_DASH] = ACTIONS(6486),
    [anon_sym_STAR] = ACTIONS(6484),
    [anon_sym_SLASH] = ACTIONS(6486),
    [anon_sym_PERCENT] = ACTIONS(6484),
    [anon_sym_CARET] = ACTIONS(6484),
    [anon_sym_PIPE] = ACTIONS(6486),
    [anon_sym_AMP] = ACTIONS(6486),
    [anon_sym_LT_LT] = ACTIONS(6484),
    [anon_sym_GT_GT] = ACTIONS(6486),
    [anon_sym_GT_GT_GT] = ACTIONS(6484),
    [anon_sym_EQ_EQ] = ACTIONS(6484),
    [anon_sym_BANG_EQ] = ACTIONS(6484),
    [anon_sym_GT_EQ] = ACTIONS(6484),
    [anon_sym_LT_EQ] = ACTIONS(6484),
    [anon_sym_DOT] = ACTIONS(6486),
    [anon_sym_switch] = ACTIONS(6484),
    [anon_sym_DOT_DOT] = ACTIONS(6484),
    [anon_sym_and] = ACTIONS(6484),
    [anon_sym_or] = ACTIONS(6484),
    [anon_sym_AMP_AMP] = ACTIONS(6484),
    [anon_sym_PIPE_PIPE] = ACTIONS(6484),
    [anon_sym_QMARK_QMARK] = ACTIONS(6484),
    [anon_sym_into] = ACTIONS(6674),
    [anon_sym_as] = ACTIONS(6484),
    [anon_sym_is] = ACTIONS(6484),
    [anon_sym_DASH_GT] = ACTIONS(6484),
    [anon_sym_with] = ACTIONS(6484),
    [aux_sym_preproc_if_token3] = ACTIONS(6484),
    [aux_sym_preproc_else_token1] = ACTIONS(6484),
    [aux_sym_preproc_elif_token1] = ACTIONS(6484),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4670] = {
    [sym_preproc_region] = STATE(4670),
    [sym_preproc_endregion] = STATE(4670),
    [sym_preproc_line] = STATE(4670),
    [sym_preproc_pragma] = STATE(4670),
    [sym_preproc_nullable] = STATE(4670),
    [sym_preproc_error] = STATE(4670),
    [sym_preproc_warning] = STATE(4670),
    [sym_preproc_define] = STATE(4670),
    [sym_preproc_undef] = STATE(4670),
    [aux_sym__query_body_repeat2] = STATE(4669),
    [anon_sym_SEMI] = ACTIONS(6491),
    [anon_sym_LBRACK] = ACTIONS(6491),
    [anon_sym_COMMA] = ACTIONS(6491),
    [anon_sym_RBRACK] = ACTIONS(6491),
    [anon_sym_LPAREN] = ACTIONS(6491),
    [anon_sym_RPAREN] = ACTIONS(6491),
    [anon_sym_RBRACE] = ACTIONS(6491),
    [anon_sym_LT] = ACTIONS(6493),
    [anon_sym_GT] = ACTIONS(6493),
    [anon_sym_in] = ACTIONS(6493),
    [anon_sym_QMARK] = ACTIONS(6493),
    [anon_sym_BANG] = ACTIONS(6493),
    [anon_sym_PLUS_PLUS] = ACTIONS(6491),
    [anon_sym_DASH_DASH] = ACTIONS(6491),
    [anon_sym_PLUS] = ACTIONS(6493),
    [anon_sym_DASH] = ACTIONS(6493),
    [anon_sym_STAR] = ACTIONS(6491),
    [anon_sym_SLASH] = ACTIONS(6493),
    [anon_sym_PERCENT] = ACTIONS(6491),
    [anon_sym_CARET] = ACTIONS(6491),
    [anon_sym_PIPE] = ACTIONS(6493),
    [anon_sym_AMP] = ACTIONS(6493),
    [anon_sym_LT_LT] = ACTIONS(6491),
    [anon_sym_GT_GT] = ACTIONS(6493),
    [anon_sym_GT_GT_GT] = ACTIONS(6491),
    [anon_sym_EQ_EQ] = ACTIONS(6491),
    [anon_sym_BANG_EQ] = ACTIONS(6491),
    [anon_sym_GT_EQ] = ACTIONS(6491),
    [anon_sym_LT_EQ] = ACTIONS(6491),
    [anon_sym_DOT] = ACTIONS(6493),
    [anon_sym_switch] = ACTIONS(6491),
    [anon_sym_DOT_DOT] = ACTIONS(6491),
    [anon_sym_and] = ACTIONS(6491),
    [anon_sym_or] = ACTIONS(6491),
    [anon_sym_AMP_AMP] = ACTIONS(6491),
    [anon_sym_PIPE_PIPE] = ACTIONS(6491),
    [anon_sym_QMARK_QMARK] = ACTIONS(6491),
    [anon_sym_into] = ACTIONS(6606),
    [anon_sym_as] = ACTIONS(6491),
    [anon_sym_is] = ACTIONS(6491),
    [anon_sym_DASH_GT] = ACTIONS(6491),
    [anon_sym_with] = ACTIONS(6491),
    [aux_sym_preproc_if_token3] = ACTIONS(6491),
    [aux_sym_preproc_else_token1] = ACTIONS(6491),
    [aux_sym_preproc_elif_token1] = ACTIONS(6491),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4671] = {
    [sym_preproc_region] = STATE(4671),
    [sym_preproc_endregion] = STATE(4671),
    [sym_preproc_line] = STATE(4671),
    [sym_preproc_pragma] = STATE(4671),
    [sym_preproc_nullable] = STATE(4671),
    [sym_preproc_error] = STATE(4671),
    [sym_preproc_warning] = STATE(4671),
    [sym_preproc_define] = STATE(4671),
    [sym_preproc_undef] = STATE(4671),
    [anon_sym_LBRACK] = ACTIONS(5584),
    [anon_sym_COMMA] = ACTIONS(5584),
    [anon_sym_LPAREN] = ACTIONS(5584),
    [anon_sym_LT] = ACTIONS(5586),
    [anon_sym_GT] = ACTIONS(5586),
    [anon_sym_where] = ACTIONS(5584),
    [anon_sym_QMARK] = ACTIONS(5586),
    [anon_sym_BANG] = ACTIONS(5586),
    [anon_sym_PLUS_PLUS] = ACTIONS(5584),
    [anon_sym_DASH_DASH] = ACTIONS(5584),
    [anon_sym_PLUS] = ACTIONS(5586),
    [anon_sym_DASH] = ACTIONS(5586),
    [anon_sym_STAR] = ACTIONS(5584),
    [anon_sym_SLASH] = ACTIONS(5586),
    [anon_sym_PERCENT] = ACTIONS(5584),
    [anon_sym_CARET] = ACTIONS(5584),
    [anon_sym_PIPE] = ACTIONS(5586),
    [anon_sym_AMP] = ACTIONS(5586),
    [anon_sym_LT_LT] = ACTIONS(5584),
    [anon_sym_GT_GT] = ACTIONS(5586),
    [anon_sym_GT_GT_GT] = ACTIONS(5584),
    [anon_sym_EQ_EQ] = ACTIONS(5584),
    [anon_sym_BANG_EQ] = ACTIONS(5584),
    [anon_sym_GT_EQ] = ACTIONS(5584),
    [anon_sym_LT_EQ] = ACTIONS(5584),
    [anon_sym_DOT] = ACTIONS(5586),
    [anon_sym_switch] = ACTIONS(5584),
    [anon_sym_DOT_DOT] = ACTIONS(5584),
    [anon_sym_and] = ACTIONS(5584),
    [anon_sym_or] = ACTIONS(5586),
    [anon_sym_AMP_AMP] = ACTIONS(5584),
    [anon_sym_PIPE_PIPE] = ACTIONS(5584),
    [anon_sym_QMARK_QMARK] = ACTIONS(5584),
    [anon_sym_from] = ACTIONS(5584),
    [anon_sym_into] = ACTIONS(5584),
    [anon_sym_join] = ACTIONS(5584),
    [anon_sym_let] = ACTIONS(5584),
    [anon_sym_orderby] = ACTIONS(5584),
    [anon_sym_ascending] = ACTIONS(5584),
    [anon_sym_descending] = ACTIONS(5584),
    [anon_sym_group] = ACTIONS(5584),
    [anon_sym_select] = ACTIONS(5584),
    [anon_sym_as] = ACTIONS(5586),
    [anon_sym_is] = ACTIONS(5584),
    [anon_sym_DASH_GT] = ACTIONS(5584),
    [anon_sym_with] = ACTIONS(5584),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4672] = {
    [sym_preproc_region] = STATE(4672),
    [sym_preproc_endregion] = STATE(4672),
    [sym_preproc_line] = STATE(4672),
    [sym_preproc_pragma] = STATE(4672),
    [sym_preproc_nullable] = STATE(4672),
    [sym_preproc_error] = STATE(4672),
    [sym_preproc_warning] = STATE(4672),
    [sym_preproc_define] = STATE(4672),
    [sym_preproc_undef] = STATE(4672),
    [anon_sym_LBRACK] = ACTIONS(5428),
    [anon_sym_COMMA] = ACTIONS(5428),
    [anon_sym_LPAREN] = ACTIONS(5428),
    [anon_sym_LT] = ACTIONS(5430),
    [anon_sym_GT] = ACTIONS(5430),
    [anon_sym_where] = ACTIONS(5428),
    [anon_sym_QMARK] = ACTIONS(5430),
    [anon_sym_BANG] = ACTIONS(5430),
    [anon_sym_PLUS_PLUS] = ACTIONS(5428),
    [anon_sym_DASH_DASH] = ACTIONS(5428),
    [anon_sym_PLUS] = ACTIONS(5430),
    [anon_sym_DASH] = ACTIONS(5430),
    [anon_sym_STAR] = ACTIONS(5428),
    [anon_sym_SLASH] = ACTIONS(5430),
    [anon_sym_PERCENT] = ACTIONS(5428),
    [anon_sym_CARET] = ACTIONS(5428),
    [anon_sym_PIPE] = ACTIONS(5430),
    [anon_sym_AMP] = ACTIONS(5430),
    [anon_sym_LT_LT] = ACTIONS(5428),
    [anon_sym_GT_GT] = ACTIONS(5430),
    [anon_sym_GT_GT_GT] = ACTIONS(5428),
    [anon_sym_EQ_EQ] = ACTIONS(5428),
    [anon_sym_BANG_EQ] = ACTIONS(5428),
    [anon_sym_GT_EQ] = ACTIONS(5428),
    [anon_sym_LT_EQ] = ACTIONS(5428),
    [anon_sym_DOT] = ACTIONS(5430),
    [anon_sym_switch] = ACTIONS(5428),
    [anon_sym_DOT_DOT] = ACTIONS(5428),
    [anon_sym_and] = ACTIONS(5428),
    [anon_sym_or] = ACTIONS(5430),
    [anon_sym_AMP_AMP] = ACTIONS(5428),
    [anon_sym_PIPE_PIPE] = ACTIONS(5428),
    [anon_sym_QMARK_QMARK] = ACTIONS(5428),
    [anon_sym_from] = ACTIONS(5428),
    [anon_sym_into] = ACTIONS(5428),
    [anon_sym_join] = ACTIONS(5428),
    [anon_sym_let] = ACTIONS(5428),
    [anon_sym_orderby] = ACTIONS(5428),
    [anon_sym_ascending] = ACTIONS(5428),
    [anon_sym_descending] = ACTIONS(5428),
    [anon_sym_group] = ACTIONS(5428),
    [anon_sym_select] = ACTIONS(5428),
    [anon_sym_as] = ACTIONS(5430),
    [anon_sym_is] = ACTIONS(5428),
    [anon_sym_DASH_GT] = ACTIONS(5428),
    [anon_sym_with] = ACTIONS(5428),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4673] = {
    [sym_preproc_region] = STATE(4673),
    [sym_preproc_endregion] = STATE(4673),
    [sym_preproc_line] = STATE(4673),
    [sym_preproc_pragma] = STATE(4673),
    [sym_preproc_nullable] = STATE(4673),
    [sym_preproc_error] = STATE(4673),
    [sym_preproc_warning] = STATE(4673),
    [sym_preproc_define] = STATE(4673),
    [sym_preproc_undef] = STATE(4673),
    [anon_sym_LBRACK] = ACTIONS(5514),
    [anon_sym_COMMA] = ACTIONS(5514),
    [anon_sym_LPAREN] = ACTIONS(5514),
    [anon_sym_LT] = ACTIONS(5516),
    [anon_sym_GT] = ACTIONS(5516),
    [anon_sym_where] = ACTIONS(5514),
    [anon_sym_QMARK] = ACTIONS(5516),
    [anon_sym_BANG] = ACTIONS(5516),
    [anon_sym_PLUS_PLUS] = ACTIONS(5514),
    [anon_sym_DASH_DASH] = ACTIONS(5514),
    [anon_sym_PLUS] = ACTIONS(5516),
    [anon_sym_DASH] = ACTIONS(5516),
    [anon_sym_STAR] = ACTIONS(5514),
    [anon_sym_SLASH] = ACTIONS(5516),
    [anon_sym_PERCENT] = ACTIONS(5514),
    [anon_sym_CARET] = ACTIONS(5514),
    [anon_sym_PIPE] = ACTIONS(5516),
    [anon_sym_AMP] = ACTIONS(5516),
    [anon_sym_LT_LT] = ACTIONS(5514),
    [anon_sym_GT_GT] = ACTIONS(5516),
    [anon_sym_GT_GT_GT] = ACTIONS(5514),
    [anon_sym_EQ_EQ] = ACTIONS(5514),
    [anon_sym_BANG_EQ] = ACTIONS(5514),
    [anon_sym_GT_EQ] = ACTIONS(5514),
    [anon_sym_LT_EQ] = ACTIONS(5514),
    [anon_sym_DOT] = ACTIONS(5516),
    [anon_sym_switch] = ACTIONS(5514),
    [anon_sym_DOT_DOT] = ACTIONS(5514),
    [anon_sym_and] = ACTIONS(5514),
    [anon_sym_or] = ACTIONS(5516),
    [anon_sym_AMP_AMP] = ACTIONS(5514),
    [anon_sym_PIPE_PIPE] = ACTIONS(5514),
    [anon_sym_QMARK_QMARK] = ACTIONS(5514),
    [anon_sym_from] = ACTIONS(5514),
    [anon_sym_into] = ACTIONS(5514),
    [anon_sym_join] = ACTIONS(5514),
    [anon_sym_let] = ACTIONS(5514),
    [anon_sym_orderby] = ACTIONS(5514),
    [anon_sym_ascending] = ACTIONS(5514),
    [anon_sym_descending] = ACTIONS(5514),
    [anon_sym_group] = ACTIONS(5514),
    [anon_sym_select] = ACTIONS(5514),
    [anon_sym_as] = ACTIONS(5516),
    [anon_sym_is] = ACTIONS(5514),
    [anon_sym_DASH_GT] = ACTIONS(5514),
    [anon_sym_with] = ACTIONS(5514),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4674] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4674),
    [sym_preproc_endregion] = STATE(4674),
    [sym_preproc_line] = STATE(4674),
    [sym_preproc_pragma] = STATE(4674),
    [sym_preproc_nullable] = STATE(4674),
    [sym_preproc_error] = STATE(4674),
    [sym_preproc_warning] = STATE(4674),
    [sym_preproc_define] = STATE(4674),
    [sym_preproc_undef] = STATE(4674),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(6342),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(6546),
    [anon_sym_GT] = ACTIONS(6546),
    [anon_sym_where] = ACTIONS(6342),
    [anon_sym_QMARK] = ACTIONS(6344),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(6550),
    [anon_sym_DASH] = ACTIONS(6550),
    [anon_sym_STAR] = ACTIONS(6552),
    [anon_sym_SLASH] = ACTIONS(6554),
    [anon_sym_PERCENT] = ACTIONS(6552),
    [anon_sym_CARET] = ACTIONS(6342),
    [anon_sym_PIPE] = ACTIONS(6344),
    [anon_sym_AMP] = ACTIONS(6560),
    [anon_sym_LT_LT] = ACTIONS(6562),
    [anon_sym_GT_GT] = ACTIONS(6564),
    [anon_sym_GT_GT_GT] = ACTIONS(6562),
    [anon_sym_EQ_EQ] = ACTIONS(6566),
    [anon_sym_BANG_EQ] = ACTIONS(6566),
    [anon_sym_GT_EQ] = ACTIONS(6568),
    [anon_sym_LT_EQ] = ACTIONS(6568),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(6216),
    [anon_sym_DOT_DOT] = ACTIONS(6570),
    [anon_sym_AMP_AMP] = ACTIONS(6342),
    [anon_sym_PIPE_PIPE] = ACTIONS(6342),
    [anon_sym_QMARK_QMARK] = ACTIONS(6342),
    [anon_sym_from] = ACTIONS(6342),
    [anon_sym_into] = ACTIONS(6342),
    [anon_sym_join] = ACTIONS(6342),
    [anon_sym_let] = ACTIONS(6342),
    [anon_sym_orderby] = ACTIONS(6342),
    [anon_sym_ascending] = ACTIONS(6342),
    [anon_sym_descending] = ACTIONS(6342),
    [anon_sym_group] = ACTIONS(6342),
    [anon_sym_select] = ACTIONS(6342),
    [anon_sym_as] = ACTIONS(6228),
    [anon_sym_is] = ACTIONS(6578),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(6232),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4675] = {
    [sym__name] = STATE(4158),
    [sym_alias_qualified_name] = STATE(4085),
    [sym__simple_name] = STATE(4085),
    [sym_qualified_name] = STATE(4085),
    [sym_generic_name] = STATE(3959),
    [sym_type] = STATE(4032),
    [sym_implicit_type] = STATE(4031),
    [sym_array_type] = STATE(3958),
    [sym__array_base_type] = STATE(8941),
    [sym_nullable_type] = STATE(3961),
    [sym_pointer_type] = STATE(3961),
    [sym__pointer_base_type] = STATE(9806),
    [sym_function_pointer_type] = STATE(3961),
    [sym_ref_type] = STATE(4031),
    [sym_scoped_type] = STATE(4031),
    [sym_tuple_type] = STATE(3962),
    [sym_identifier] = STATE(3889),
    [sym__reserved_identifier] = STATE(3911),
    [sym_preproc_region] = STATE(4675),
    [sym_preproc_endregion] = STATE(4675),
    [sym_preproc_line] = STATE(4675),
    [sym_preproc_pragma] = STATE(4675),
    [sym_preproc_nullable] = STATE(4675),
    [sym_preproc_error] = STATE(4675),
    [sym_preproc_warning] = STATE(4675),
    [sym_preproc_define] = STATE(4675),
    [sym_preproc_undef] = STATE(4675),
    [sym__identifier_token] = ACTIONS(4248),
    [anon_sym_alias] = ACTIONS(4250),
    [anon_sym_global] = ACTIONS(4250),
    [anon_sym_LPAREN] = ACTIONS(6620),
    [anon_sym_ref] = ACTIONS(4648),
    [anon_sym_delegate] = ACTIONS(6168),
    [anon_sym_file] = ACTIONS(4250),
    [anon_sym_readonly] = ACTIONS(6677),
    [anon_sym_where] = ACTIONS(4250),
    [anon_sym_notnull] = ACTIONS(4250),
    [anon_sym_unmanaged] = ACTIONS(4250),
    [anon_sym_scoped] = ACTIONS(6289),
    [anon_sym_var] = ACTIONS(6172),
    [sym_predefined_type] = ACTIONS(6174),
    [anon_sym_yield] = ACTIONS(4250),
    [anon_sym_when] = ACTIONS(4250),
    [anon_sym_from] = ACTIONS(4250),
    [anon_sym_into] = ACTIONS(4250),
    [anon_sym_join] = ACTIONS(4250),
    [anon_sym_on] = ACTIONS(4250),
    [anon_sym_equals] = ACTIONS(4250),
    [anon_sym_let] = ACTIONS(4250),
    [anon_sym_orderby] = ACTIONS(4250),
    [anon_sym_ascending] = ACTIONS(4250),
    [anon_sym_descending] = ACTIONS(4250),
    [anon_sym_group] = ACTIONS(4250),
    [anon_sym_by] = ACTIONS(4250),
    [anon_sym_select] = ACTIONS(4250),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4676] = {
    [sym_preproc_region] = STATE(4676),
    [sym_preproc_endregion] = STATE(4676),
    [sym_preproc_line] = STATE(4676),
    [sym_preproc_pragma] = STATE(4676),
    [sym_preproc_nullable] = STATE(4676),
    [sym_preproc_error] = STATE(4676),
    [sym_preproc_warning] = STATE(4676),
    [sym_preproc_define] = STATE(4676),
    [sym_preproc_undef] = STATE(4676),
    [anon_sym_LBRACK] = ACTIONS(5624),
    [anon_sym_COMMA] = ACTIONS(5624),
    [anon_sym_LPAREN] = ACTIONS(5624),
    [anon_sym_LT] = ACTIONS(5626),
    [anon_sym_GT] = ACTIONS(5626),
    [anon_sym_where] = ACTIONS(5624),
    [anon_sym_QMARK] = ACTIONS(5626),
    [anon_sym_BANG] = ACTIONS(5626),
    [anon_sym_PLUS_PLUS] = ACTIONS(5624),
    [anon_sym_DASH_DASH] = ACTIONS(5624),
    [anon_sym_PLUS] = ACTIONS(5626),
    [anon_sym_DASH] = ACTIONS(5626),
    [anon_sym_STAR] = ACTIONS(5624),
    [anon_sym_SLASH] = ACTIONS(5626),
    [anon_sym_PERCENT] = ACTIONS(5624),
    [anon_sym_CARET] = ACTIONS(5624),
    [anon_sym_PIPE] = ACTIONS(5626),
    [anon_sym_AMP] = ACTIONS(5626),
    [anon_sym_LT_LT] = ACTIONS(5624),
    [anon_sym_GT_GT] = ACTIONS(5626),
    [anon_sym_GT_GT_GT] = ACTIONS(5624),
    [anon_sym_EQ_EQ] = ACTIONS(5624),
    [anon_sym_BANG_EQ] = ACTIONS(5624),
    [anon_sym_GT_EQ] = ACTIONS(5624),
    [anon_sym_LT_EQ] = ACTIONS(5624),
    [anon_sym_DOT] = ACTIONS(5626),
    [anon_sym_switch] = ACTIONS(5624),
    [anon_sym_DOT_DOT] = ACTIONS(5624),
    [anon_sym_and] = ACTIONS(5624),
    [anon_sym_or] = ACTIONS(5626),
    [anon_sym_AMP_AMP] = ACTIONS(5624),
    [anon_sym_PIPE_PIPE] = ACTIONS(5624),
    [anon_sym_QMARK_QMARK] = ACTIONS(5624),
    [anon_sym_from] = ACTIONS(5624),
    [anon_sym_into] = ACTIONS(5624),
    [anon_sym_join] = ACTIONS(5624),
    [anon_sym_let] = ACTIONS(5624),
    [anon_sym_orderby] = ACTIONS(5624),
    [anon_sym_ascending] = ACTIONS(5624),
    [anon_sym_descending] = ACTIONS(5624),
    [anon_sym_group] = ACTIONS(5624),
    [anon_sym_select] = ACTIONS(5624),
    [anon_sym_as] = ACTIONS(5626),
    [anon_sym_is] = ACTIONS(5624),
    [anon_sym_DASH_GT] = ACTIONS(5624),
    [anon_sym_with] = ACTIONS(5624),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4677] = {
    [sym_preproc_region] = STATE(4677),
    [sym_preproc_endregion] = STATE(4677),
    [sym_preproc_line] = STATE(4677),
    [sym_preproc_pragma] = STATE(4677),
    [sym_preproc_nullable] = STATE(4677),
    [sym_preproc_error] = STATE(4677),
    [sym_preproc_warning] = STATE(4677),
    [sym_preproc_define] = STATE(4677),
    [sym_preproc_undef] = STATE(4677),
    [anon_sym_LBRACK] = ACTIONS(5572),
    [anon_sym_COMMA] = ACTIONS(5572),
    [anon_sym_LPAREN] = ACTIONS(5572),
    [anon_sym_LT] = ACTIONS(5574),
    [anon_sym_GT] = ACTIONS(5574),
    [anon_sym_where] = ACTIONS(5572),
    [anon_sym_QMARK] = ACTIONS(5574),
    [anon_sym_BANG] = ACTIONS(5574),
    [anon_sym_PLUS_PLUS] = ACTIONS(5572),
    [anon_sym_DASH_DASH] = ACTIONS(5572),
    [anon_sym_PLUS] = ACTIONS(5574),
    [anon_sym_DASH] = ACTIONS(5574),
    [anon_sym_STAR] = ACTIONS(5572),
    [anon_sym_SLASH] = ACTIONS(5574),
    [anon_sym_PERCENT] = ACTIONS(5572),
    [anon_sym_CARET] = ACTIONS(5572),
    [anon_sym_PIPE] = ACTIONS(5574),
    [anon_sym_AMP] = ACTIONS(5574),
    [anon_sym_LT_LT] = ACTIONS(5572),
    [anon_sym_GT_GT] = ACTIONS(5574),
    [anon_sym_GT_GT_GT] = ACTIONS(5572),
    [anon_sym_EQ_EQ] = ACTIONS(5572),
    [anon_sym_BANG_EQ] = ACTIONS(5572),
    [anon_sym_GT_EQ] = ACTIONS(5572),
    [anon_sym_LT_EQ] = ACTIONS(5572),
    [anon_sym_DOT] = ACTIONS(5574),
    [anon_sym_switch] = ACTIONS(5572),
    [anon_sym_DOT_DOT] = ACTIONS(5572),
    [anon_sym_and] = ACTIONS(5572),
    [anon_sym_or] = ACTIONS(5574),
    [anon_sym_AMP_AMP] = ACTIONS(5572),
    [anon_sym_PIPE_PIPE] = ACTIONS(5572),
    [anon_sym_QMARK_QMARK] = ACTIONS(5572),
    [anon_sym_from] = ACTIONS(5572),
    [anon_sym_into] = ACTIONS(5572),
    [anon_sym_join] = ACTIONS(5572),
    [anon_sym_let] = ACTIONS(5572),
    [anon_sym_orderby] = ACTIONS(5572),
    [anon_sym_ascending] = ACTIONS(5572),
    [anon_sym_descending] = ACTIONS(5572),
    [anon_sym_group] = ACTIONS(5572),
    [anon_sym_select] = ACTIONS(5572),
    [anon_sym_as] = ACTIONS(5574),
    [anon_sym_is] = ACTIONS(5572),
    [anon_sym_DASH_GT] = ACTIONS(5572),
    [anon_sym_with] = ACTIONS(5572),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4678] = {
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(6020),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4678),
    [sym_preproc_endregion] = STATE(4678),
    [sym_preproc_line] = STATE(4678),
    [sym_preproc_pragma] = STATE(4678),
    [sym_preproc_nullable] = STATE(4678),
    [sym_preproc_error] = STATE(4678),
    [sym_preproc_warning] = STATE(4678),
    [sym_preproc_define] = STATE(4678),
    [sym_preproc_undef] = STATE(4678),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(4112),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_readonly] = ACTIONS(2833),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(6580),
    [anon_sym_var] = ACTIONS(6582),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4679] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4679),
    [sym_preproc_endregion] = STATE(4679),
    [sym_preproc_line] = STATE(4679),
    [sym_preproc_pragma] = STATE(4679),
    [sym_preproc_nullable] = STATE(4679),
    [sym_preproc_error] = STATE(4679),
    [sym_preproc_warning] = STATE(4679),
    [sym_preproc_define] = STATE(4679),
    [sym_preproc_undef] = STATE(4679),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(6342),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(6546),
    [anon_sym_GT] = ACTIONS(6546),
    [anon_sym_where] = ACTIONS(6342),
    [anon_sym_QMARK] = ACTIONS(6344),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(6550),
    [anon_sym_DASH] = ACTIONS(6550),
    [anon_sym_STAR] = ACTIONS(6552),
    [anon_sym_SLASH] = ACTIONS(6554),
    [anon_sym_PERCENT] = ACTIONS(6552),
    [anon_sym_CARET] = ACTIONS(6556),
    [anon_sym_PIPE] = ACTIONS(6344),
    [anon_sym_AMP] = ACTIONS(6560),
    [anon_sym_LT_LT] = ACTIONS(6562),
    [anon_sym_GT_GT] = ACTIONS(6564),
    [anon_sym_GT_GT_GT] = ACTIONS(6562),
    [anon_sym_EQ_EQ] = ACTIONS(6566),
    [anon_sym_BANG_EQ] = ACTIONS(6566),
    [anon_sym_GT_EQ] = ACTIONS(6568),
    [anon_sym_LT_EQ] = ACTIONS(6568),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(6216),
    [anon_sym_DOT_DOT] = ACTIONS(6570),
    [anon_sym_AMP_AMP] = ACTIONS(6342),
    [anon_sym_PIPE_PIPE] = ACTIONS(6342),
    [anon_sym_QMARK_QMARK] = ACTIONS(6342),
    [anon_sym_from] = ACTIONS(6342),
    [anon_sym_into] = ACTIONS(6342),
    [anon_sym_join] = ACTIONS(6342),
    [anon_sym_let] = ACTIONS(6342),
    [anon_sym_orderby] = ACTIONS(6342),
    [anon_sym_ascending] = ACTIONS(6342),
    [anon_sym_descending] = ACTIONS(6342),
    [anon_sym_group] = ACTIONS(6342),
    [anon_sym_select] = ACTIONS(6342),
    [anon_sym_as] = ACTIONS(6228),
    [anon_sym_is] = ACTIONS(6578),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(6232),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4680] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4680),
    [sym_preproc_endregion] = STATE(4680),
    [sym_preproc_line] = STATE(4680),
    [sym_preproc_pragma] = STATE(4680),
    [sym_preproc_nullable] = STATE(4680),
    [sym_preproc_error] = STATE(4680),
    [sym_preproc_warning] = STATE(4680),
    [sym_preproc_define] = STATE(4680),
    [sym_preproc_undef] = STATE(4680),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(6342),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(6546),
    [anon_sym_GT] = ACTIONS(6546),
    [anon_sym_where] = ACTIONS(6342),
    [anon_sym_QMARK] = ACTIONS(6344),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(6550),
    [anon_sym_DASH] = ACTIONS(6550),
    [anon_sym_STAR] = ACTIONS(6552),
    [anon_sym_SLASH] = ACTIONS(6554),
    [anon_sym_PERCENT] = ACTIONS(6552),
    [anon_sym_CARET] = ACTIONS(6342),
    [anon_sym_PIPE] = ACTIONS(6344),
    [anon_sym_AMP] = ACTIONS(6344),
    [anon_sym_LT_LT] = ACTIONS(6562),
    [anon_sym_GT_GT] = ACTIONS(6564),
    [anon_sym_GT_GT_GT] = ACTIONS(6562),
    [anon_sym_EQ_EQ] = ACTIONS(6566),
    [anon_sym_BANG_EQ] = ACTIONS(6566),
    [anon_sym_GT_EQ] = ACTIONS(6568),
    [anon_sym_LT_EQ] = ACTIONS(6568),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(6216),
    [anon_sym_DOT_DOT] = ACTIONS(6570),
    [anon_sym_AMP_AMP] = ACTIONS(6342),
    [anon_sym_PIPE_PIPE] = ACTIONS(6342),
    [anon_sym_QMARK_QMARK] = ACTIONS(6342),
    [anon_sym_from] = ACTIONS(6342),
    [anon_sym_into] = ACTIONS(6342),
    [anon_sym_join] = ACTIONS(6342),
    [anon_sym_let] = ACTIONS(6342),
    [anon_sym_orderby] = ACTIONS(6342),
    [anon_sym_ascending] = ACTIONS(6342),
    [anon_sym_descending] = ACTIONS(6342),
    [anon_sym_group] = ACTIONS(6342),
    [anon_sym_select] = ACTIONS(6342),
    [anon_sym_as] = ACTIONS(6228),
    [anon_sym_is] = ACTIONS(6578),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(6232),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4681] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4681),
    [sym_preproc_endregion] = STATE(4681),
    [sym_preproc_line] = STATE(4681),
    [sym_preproc_pragma] = STATE(4681),
    [sym_preproc_nullable] = STATE(4681),
    [sym_preproc_error] = STATE(4681),
    [sym_preproc_warning] = STATE(4681),
    [sym_preproc_define] = STATE(4681),
    [sym_preproc_undef] = STATE(4681),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(6342),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(6546),
    [anon_sym_GT] = ACTIONS(6546),
    [anon_sym_where] = ACTIONS(6342),
    [anon_sym_QMARK] = ACTIONS(6344),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(6550),
    [anon_sym_DASH] = ACTIONS(6550),
    [anon_sym_STAR] = ACTIONS(6552),
    [anon_sym_SLASH] = ACTIONS(6554),
    [anon_sym_PERCENT] = ACTIONS(6552),
    [anon_sym_CARET] = ACTIONS(6342),
    [anon_sym_PIPE] = ACTIONS(6344),
    [anon_sym_AMP] = ACTIONS(6344),
    [anon_sym_LT_LT] = ACTIONS(6562),
    [anon_sym_GT_GT] = ACTIONS(6564),
    [anon_sym_GT_GT_GT] = ACTIONS(6562),
    [anon_sym_EQ_EQ] = ACTIONS(6342),
    [anon_sym_BANG_EQ] = ACTIONS(6342),
    [anon_sym_GT_EQ] = ACTIONS(6568),
    [anon_sym_LT_EQ] = ACTIONS(6568),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(6216),
    [anon_sym_DOT_DOT] = ACTIONS(6570),
    [anon_sym_AMP_AMP] = ACTIONS(6342),
    [anon_sym_PIPE_PIPE] = ACTIONS(6342),
    [anon_sym_QMARK_QMARK] = ACTIONS(6342),
    [anon_sym_from] = ACTIONS(6342),
    [anon_sym_into] = ACTIONS(6342),
    [anon_sym_join] = ACTIONS(6342),
    [anon_sym_let] = ACTIONS(6342),
    [anon_sym_orderby] = ACTIONS(6342),
    [anon_sym_ascending] = ACTIONS(6342),
    [anon_sym_descending] = ACTIONS(6342),
    [anon_sym_group] = ACTIONS(6342),
    [anon_sym_select] = ACTIONS(6342),
    [anon_sym_as] = ACTIONS(6228),
    [anon_sym_is] = ACTIONS(6578),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(6232),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4682] = {
    [sym__name] = STATE(4158),
    [sym_alias_qualified_name] = STATE(4085),
    [sym__simple_name] = STATE(4085),
    [sym_qualified_name] = STATE(4085),
    [sym_generic_name] = STATE(3959),
    [sym_type] = STATE(4032),
    [sym_implicit_type] = STATE(4031),
    [sym_array_type] = STATE(3958),
    [sym__array_base_type] = STATE(8941),
    [sym_nullable_type] = STATE(3961),
    [sym_pointer_type] = STATE(3961),
    [sym__pointer_base_type] = STATE(9806),
    [sym_function_pointer_type] = STATE(3961),
    [sym_ref_type] = STATE(4031),
    [sym_scoped_type] = STATE(4031),
    [sym_tuple_type] = STATE(3962),
    [sym_identifier] = STATE(3889),
    [sym__reserved_identifier] = STATE(3911),
    [sym_preproc_region] = STATE(4682),
    [sym_preproc_endregion] = STATE(4682),
    [sym_preproc_line] = STATE(4682),
    [sym_preproc_pragma] = STATE(4682),
    [sym_preproc_nullable] = STATE(4682),
    [sym_preproc_error] = STATE(4682),
    [sym_preproc_warning] = STATE(4682),
    [sym_preproc_define] = STATE(4682),
    [sym_preproc_undef] = STATE(4682),
    [sym__identifier_token] = ACTIONS(4248),
    [anon_sym_alias] = ACTIONS(4250),
    [anon_sym_global] = ACTIONS(4250),
    [anon_sym_LPAREN] = ACTIONS(6620),
    [anon_sym_ref] = ACTIONS(4691),
    [anon_sym_delegate] = ACTIONS(6168),
    [anon_sym_file] = ACTIONS(4250),
    [anon_sym_readonly] = ACTIONS(6679),
    [anon_sym_where] = ACTIONS(4250),
    [anon_sym_notnull] = ACTIONS(4250),
    [anon_sym_unmanaged] = ACTIONS(4250),
    [anon_sym_scoped] = ACTIONS(6348),
    [anon_sym_var] = ACTIONS(6172),
    [sym_predefined_type] = ACTIONS(6174),
    [anon_sym_yield] = ACTIONS(4250),
    [anon_sym_when] = ACTIONS(4250),
    [anon_sym_from] = ACTIONS(4250),
    [anon_sym_into] = ACTIONS(4250),
    [anon_sym_join] = ACTIONS(4250),
    [anon_sym_on] = ACTIONS(4250),
    [anon_sym_equals] = ACTIONS(4250),
    [anon_sym_let] = ACTIONS(4250),
    [anon_sym_orderby] = ACTIONS(4250),
    [anon_sym_ascending] = ACTIONS(4250),
    [anon_sym_descending] = ACTIONS(4250),
    [anon_sym_group] = ACTIONS(4250),
    [anon_sym_by] = ACTIONS(4250),
    [anon_sym_select] = ACTIONS(4250),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4683] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4683),
    [sym_preproc_endregion] = STATE(4683),
    [sym_preproc_line] = STATE(4683),
    [sym_preproc_pragma] = STATE(4683),
    [sym_preproc_nullable] = STATE(4683),
    [sym_preproc_error] = STATE(4683),
    [sym_preproc_warning] = STATE(4683),
    [sym_preproc_define] = STATE(4683),
    [sym_preproc_undef] = STATE(4683),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(6342),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(6546),
    [anon_sym_GT] = ACTIONS(6546),
    [anon_sym_where] = ACTIONS(6342),
    [anon_sym_QMARK] = ACTIONS(6344),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(6550),
    [anon_sym_DASH] = ACTIONS(6550),
    [anon_sym_STAR] = ACTIONS(6552),
    [anon_sym_SLASH] = ACTIONS(6554),
    [anon_sym_PERCENT] = ACTIONS(6552),
    [anon_sym_CARET] = ACTIONS(6556),
    [anon_sym_PIPE] = ACTIONS(6558),
    [anon_sym_AMP] = ACTIONS(6560),
    [anon_sym_LT_LT] = ACTIONS(6562),
    [anon_sym_GT_GT] = ACTIONS(6564),
    [anon_sym_GT_GT_GT] = ACTIONS(6562),
    [anon_sym_EQ_EQ] = ACTIONS(6566),
    [anon_sym_BANG_EQ] = ACTIONS(6566),
    [anon_sym_GT_EQ] = ACTIONS(6568),
    [anon_sym_LT_EQ] = ACTIONS(6568),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(6216),
    [anon_sym_DOT_DOT] = ACTIONS(6570),
    [anon_sym_AMP_AMP] = ACTIONS(6342),
    [anon_sym_PIPE_PIPE] = ACTIONS(6342),
    [anon_sym_QMARK_QMARK] = ACTIONS(6342),
    [anon_sym_from] = ACTIONS(6342),
    [anon_sym_into] = ACTIONS(6342),
    [anon_sym_join] = ACTIONS(6342),
    [anon_sym_let] = ACTIONS(6342),
    [anon_sym_orderby] = ACTIONS(6342),
    [anon_sym_ascending] = ACTIONS(6342),
    [anon_sym_descending] = ACTIONS(6342),
    [anon_sym_group] = ACTIONS(6342),
    [anon_sym_select] = ACTIONS(6342),
    [anon_sym_as] = ACTIONS(6228),
    [anon_sym_is] = ACTIONS(6578),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(6232),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4684] = {
    [sym_preproc_region] = STATE(4684),
    [sym_preproc_endregion] = STATE(4684),
    [sym_preproc_line] = STATE(4684),
    [sym_preproc_pragma] = STATE(4684),
    [sym_preproc_nullable] = STATE(4684),
    [sym_preproc_error] = STATE(4684),
    [sym_preproc_warning] = STATE(4684),
    [sym_preproc_define] = STATE(4684),
    [sym_preproc_undef] = STATE(4684),
    [anon_sym_LBRACK] = ACTIONS(5466),
    [anon_sym_COMMA] = ACTIONS(5466),
    [anon_sym_LPAREN] = ACTIONS(5466),
    [anon_sym_LT] = ACTIONS(5468),
    [anon_sym_GT] = ACTIONS(5468),
    [anon_sym_where] = ACTIONS(5466),
    [anon_sym_QMARK] = ACTIONS(5468),
    [anon_sym_BANG] = ACTIONS(5468),
    [anon_sym_PLUS_PLUS] = ACTIONS(5466),
    [anon_sym_DASH_DASH] = ACTIONS(5466),
    [anon_sym_PLUS] = ACTIONS(5468),
    [anon_sym_DASH] = ACTIONS(5468),
    [anon_sym_STAR] = ACTIONS(5466),
    [anon_sym_SLASH] = ACTIONS(5468),
    [anon_sym_PERCENT] = ACTIONS(5466),
    [anon_sym_CARET] = ACTIONS(5466),
    [anon_sym_PIPE] = ACTIONS(5468),
    [anon_sym_AMP] = ACTIONS(5468),
    [anon_sym_LT_LT] = ACTIONS(5466),
    [anon_sym_GT_GT] = ACTIONS(5468),
    [anon_sym_GT_GT_GT] = ACTIONS(5466),
    [anon_sym_EQ_EQ] = ACTIONS(5466),
    [anon_sym_BANG_EQ] = ACTIONS(5466),
    [anon_sym_GT_EQ] = ACTIONS(5466),
    [anon_sym_LT_EQ] = ACTIONS(5466),
    [anon_sym_DOT] = ACTIONS(5468),
    [anon_sym_switch] = ACTIONS(5466),
    [anon_sym_DOT_DOT] = ACTIONS(5466),
    [anon_sym_and] = ACTIONS(5466),
    [anon_sym_or] = ACTIONS(5468),
    [anon_sym_AMP_AMP] = ACTIONS(5466),
    [anon_sym_PIPE_PIPE] = ACTIONS(5466),
    [anon_sym_QMARK_QMARK] = ACTIONS(5466),
    [anon_sym_from] = ACTIONS(5466),
    [anon_sym_into] = ACTIONS(5466),
    [anon_sym_join] = ACTIONS(5466),
    [anon_sym_let] = ACTIONS(5466),
    [anon_sym_orderby] = ACTIONS(5466),
    [anon_sym_ascending] = ACTIONS(5466),
    [anon_sym_descending] = ACTIONS(5466),
    [anon_sym_group] = ACTIONS(5466),
    [anon_sym_select] = ACTIONS(5466),
    [anon_sym_as] = ACTIONS(5468),
    [anon_sym_is] = ACTIONS(5466),
    [anon_sym_DASH_GT] = ACTIONS(5466),
    [anon_sym_with] = ACTIONS(5466),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4685] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4685),
    [sym_preproc_endregion] = STATE(4685),
    [sym_preproc_line] = STATE(4685),
    [sym_preproc_pragma] = STATE(4685),
    [sym_preproc_nullable] = STATE(4685),
    [sym_preproc_error] = STATE(4685),
    [sym_preproc_warning] = STATE(4685),
    [sym_preproc_define] = STATE(4685),
    [sym_preproc_undef] = STATE(4685),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(6342),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(6546),
    [anon_sym_GT] = ACTIONS(6546),
    [anon_sym_where] = ACTIONS(6342),
    [anon_sym_QMARK] = ACTIONS(6344),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(6550),
    [anon_sym_DASH] = ACTIONS(6550),
    [anon_sym_STAR] = ACTIONS(6552),
    [anon_sym_SLASH] = ACTIONS(6554),
    [anon_sym_PERCENT] = ACTIONS(6552),
    [anon_sym_CARET] = ACTIONS(6556),
    [anon_sym_PIPE] = ACTIONS(6558),
    [anon_sym_AMP] = ACTIONS(6560),
    [anon_sym_LT_LT] = ACTIONS(6562),
    [anon_sym_GT_GT] = ACTIONS(6564),
    [anon_sym_GT_GT_GT] = ACTIONS(6562),
    [anon_sym_EQ_EQ] = ACTIONS(6566),
    [anon_sym_BANG_EQ] = ACTIONS(6566),
    [anon_sym_GT_EQ] = ACTIONS(6568),
    [anon_sym_LT_EQ] = ACTIONS(6568),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(6216),
    [anon_sym_DOT_DOT] = ACTIONS(6570),
    [anon_sym_AMP_AMP] = ACTIONS(6572),
    [anon_sym_PIPE_PIPE] = ACTIONS(6342),
    [anon_sym_QMARK_QMARK] = ACTIONS(6342),
    [anon_sym_from] = ACTIONS(6342),
    [anon_sym_into] = ACTIONS(6342),
    [anon_sym_join] = ACTIONS(6342),
    [anon_sym_let] = ACTIONS(6342),
    [anon_sym_orderby] = ACTIONS(6342),
    [anon_sym_ascending] = ACTIONS(6342),
    [anon_sym_descending] = ACTIONS(6342),
    [anon_sym_group] = ACTIONS(6342),
    [anon_sym_select] = ACTIONS(6342),
    [anon_sym_as] = ACTIONS(6228),
    [anon_sym_is] = ACTIONS(6578),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(6232),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4686] = {
    [sym_preproc_region] = STATE(4686),
    [sym_preproc_endregion] = STATE(4686),
    [sym_preproc_line] = STATE(4686),
    [sym_preproc_pragma] = STATE(4686),
    [sym_preproc_nullable] = STATE(4686),
    [sym_preproc_error] = STATE(4686),
    [sym_preproc_warning] = STATE(4686),
    [sym_preproc_define] = STATE(4686),
    [sym_preproc_undef] = STATE(4686),
    [anon_sym_LBRACK] = ACTIONS(5486),
    [anon_sym_COMMA] = ACTIONS(5486),
    [anon_sym_LPAREN] = ACTIONS(5486),
    [anon_sym_LT] = ACTIONS(5488),
    [anon_sym_GT] = ACTIONS(5488),
    [anon_sym_where] = ACTIONS(5486),
    [anon_sym_QMARK] = ACTIONS(5488),
    [anon_sym_BANG] = ACTIONS(5488),
    [anon_sym_PLUS_PLUS] = ACTIONS(5486),
    [anon_sym_DASH_DASH] = ACTIONS(5486),
    [anon_sym_PLUS] = ACTIONS(5488),
    [anon_sym_DASH] = ACTIONS(5488),
    [anon_sym_STAR] = ACTIONS(5486),
    [anon_sym_SLASH] = ACTIONS(5488),
    [anon_sym_PERCENT] = ACTIONS(5486),
    [anon_sym_CARET] = ACTIONS(5486),
    [anon_sym_PIPE] = ACTIONS(5488),
    [anon_sym_AMP] = ACTIONS(5488),
    [anon_sym_LT_LT] = ACTIONS(5486),
    [anon_sym_GT_GT] = ACTIONS(5488),
    [anon_sym_GT_GT_GT] = ACTIONS(5486),
    [anon_sym_EQ_EQ] = ACTIONS(5486),
    [anon_sym_BANG_EQ] = ACTIONS(5486),
    [anon_sym_GT_EQ] = ACTIONS(5486),
    [anon_sym_LT_EQ] = ACTIONS(5486),
    [anon_sym_DOT] = ACTIONS(5488),
    [anon_sym_switch] = ACTIONS(5486),
    [anon_sym_DOT_DOT] = ACTIONS(5486),
    [anon_sym_and] = ACTIONS(5486),
    [anon_sym_or] = ACTIONS(5488),
    [anon_sym_AMP_AMP] = ACTIONS(5486),
    [anon_sym_PIPE_PIPE] = ACTIONS(5486),
    [anon_sym_QMARK_QMARK] = ACTIONS(5486),
    [anon_sym_from] = ACTIONS(5486),
    [anon_sym_into] = ACTIONS(5486),
    [anon_sym_join] = ACTIONS(5486),
    [anon_sym_let] = ACTIONS(5486),
    [anon_sym_orderby] = ACTIONS(5486),
    [anon_sym_ascending] = ACTIONS(5486),
    [anon_sym_descending] = ACTIONS(5486),
    [anon_sym_group] = ACTIONS(5486),
    [anon_sym_select] = ACTIONS(5486),
    [anon_sym_as] = ACTIONS(5488),
    [anon_sym_is] = ACTIONS(5486),
    [anon_sym_DASH_GT] = ACTIONS(5486),
    [anon_sym_with] = ACTIONS(5486),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4687] = {
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(8791),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4687),
    [sym_preproc_endregion] = STATE(4687),
    [sym_preproc_line] = STATE(4687),
    [sym_preproc_pragma] = STATE(4687),
    [sym_preproc_nullable] = STATE(4687),
    [sym_preproc_error] = STATE(4687),
    [sym_preproc_warning] = STATE(4687),
    [sym_preproc_define] = STATE(4687),
    [sym_preproc_undef] = STATE(4687),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(6608),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_checked] = ACTIONS(6681),
    [anon_sym_scoped] = ACTIONS(6612),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4688] = {
    [sym_preproc_region] = STATE(4688),
    [sym_preproc_endregion] = STATE(4688),
    [sym_preproc_line] = STATE(4688),
    [sym_preproc_pragma] = STATE(4688),
    [sym_preproc_nullable] = STATE(4688),
    [sym_preproc_error] = STATE(4688),
    [sym_preproc_warning] = STATE(4688),
    [sym_preproc_define] = STATE(4688),
    [sym_preproc_undef] = STATE(4688),
    [anon_sym_LBRACK] = ACTIONS(5494),
    [anon_sym_COMMA] = ACTIONS(5494),
    [anon_sym_LPAREN] = ACTIONS(5494),
    [anon_sym_LT] = ACTIONS(5496),
    [anon_sym_GT] = ACTIONS(5496),
    [anon_sym_where] = ACTIONS(5494),
    [anon_sym_QMARK] = ACTIONS(5496),
    [anon_sym_BANG] = ACTIONS(5496),
    [anon_sym_PLUS_PLUS] = ACTIONS(5494),
    [anon_sym_DASH_DASH] = ACTIONS(5494),
    [anon_sym_PLUS] = ACTIONS(5496),
    [anon_sym_DASH] = ACTIONS(5496),
    [anon_sym_STAR] = ACTIONS(5494),
    [anon_sym_SLASH] = ACTIONS(5496),
    [anon_sym_PERCENT] = ACTIONS(5494),
    [anon_sym_CARET] = ACTIONS(5494),
    [anon_sym_PIPE] = ACTIONS(5496),
    [anon_sym_AMP] = ACTIONS(5496),
    [anon_sym_LT_LT] = ACTIONS(5494),
    [anon_sym_GT_GT] = ACTIONS(5496),
    [anon_sym_GT_GT_GT] = ACTIONS(5494),
    [anon_sym_EQ_EQ] = ACTIONS(5494),
    [anon_sym_BANG_EQ] = ACTIONS(5494),
    [anon_sym_GT_EQ] = ACTIONS(5494),
    [anon_sym_LT_EQ] = ACTIONS(5494),
    [anon_sym_DOT] = ACTIONS(5496),
    [anon_sym_switch] = ACTIONS(5494),
    [anon_sym_DOT_DOT] = ACTIONS(5494),
    [anon_sym_and] = ACTIONS(5494),
    [anon_sym_or] = ACTIONS(5496),
    [anon_sym_AMP_AMP] = ACTIONS(5494),
    [anon_sym_PIPE_PIPE] = ACTIONS(5494),
    [anon_sym_QMARK_QMARK] = ACTIONS(5494),
    [anon_sym_from] = ACTIONS(5494),
    [anon_sym_into] = ACTIONS(5494),
    [anon_sym_join] = ACTIONS(5494),
    [anon_sym_let] = ACTIONS(5494),
    [anon_sym_orderby] = ACTIONS(5494),
    [anon_sym_ascending] = ACTIONS(5494),
    [anon_sym_descending] = ACTIONS(5494),
    [anon_sym_group] = ACTIONS(5494),
    [anon_sym_select] = ACTIONS(5494),
    [anon_sym_as] = ACTIONS(5496),
    [anon_sym_is] = ACTIONS(5494),
    [anon_sym_DASH_GT] = ACTIONS(5494),
    [anon_sym_with] = ACTIONS(5494),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4689] = {
    [sym_argument_list] = STATE(4561),
    [sym_bracketed_argument_list] = STATE(3577),
    [sym_preproc_region] = STATE(4689),
    [sym_preproc_endregion] = STATE(4689),
    [sym_preproc_line] = STATE(4689),
    [sym_preproc_pragma] = STATE(4689),
    [sym_preproc_nullable] = STATE(4689),
    [sym_preproc_error] = STATE(4689),
    [sym_preproc_warning] = STATE(4689),
    [sym_preproc_define] = STATE(4689),
    [sym_preproc_undef] = STATE(4689),
    [anon_sym_LBRACK] = ACTIONS(6156),
    [anon_sym_COMMA] = ACTIONS(6342),
    [anon_sym_LPAREN] = ACTIONS(6124),
    [anon_sym_LT] = ACTIONS(6546),
    [anon_sym_GT] = ACTIONS(6546),
    [anon_sym_where] = ACTIONS(6342),
    [anon_sym_QMARK] = ACTIONS(6344),
    [anon_sym_BANG] = ACTIONS(6158),
    [anon_sym_PLUS_PLUS] = ACTIONS(6160),
    [anon_sym_DASH_DASH] = ACTIONS(6160),
    [anon_sym_PLUS] = ACTIONS(6550),
    [anon_sym_DASH] = ACTIONS(6550),
    [anon_sym_STAR] = ACTIONS(6552),
    [anon_sym_SLASH] = ACTIONS(6554),
    [anon_sym_PERCENT] = ACTIONS(6552),
    [anon_sym_CARET] = ACTIONS(6556),
    [anon_sym_PIPE] = ACTIONS(6558),
    [anon_sym_AMP] = ACTIONS(6560),
    [anon_sym_LT_LT] = ACTIONS(6562),
    [anon_sym_GT_GT] = ACTIONS(6564),
    [anon_sym_GT_GT_GT] = ACTIONS(6562),
    [anon_sym_EQ_EQ] = ACTIONS(6566),
    [anon_sym_BANG_EQ] = ACTIONS(6566),
    [anon_sym_GT_EQ] = ACTIONS(6568),
    [anon_sym_LT_EQ] = ACTIONS(6568),
    [anon_sym_DOT] = ACTIONS(5239),
    [anon_sym_switch] = ACTIONS(6216),
    [anon_sym_DOT_DOT] = ACTIONS(6570),
    [anon_sym_AMP_AMP] = ACTIONS(6572),
    [anon_sym_PIPE_PIPE] = ACTIONS(6574),
    [anon_sym_QMARK_QMARK] = ACTIONS(6576),
    [anon_sym_from] = ACTIONS(6342),
    [anon_sym_into] = ACTIONS(6342),
    [anon_sym_join] = ACTIONS(6342),
    [anon_sym_let] = ACTIONS(6342),
    [anon_sym_orderby] = ACTIONS(6342),
    [anon_sym_ascending] = ACTIONS(6342),
    [anon_sym_descending] = ACTIONS(6342),
    [anon_sym_group] = ACTIONS(6342),
    [anon_sym_select] = ACTIONS(6342),
    [anon_sym_as] = ACTIONS(6228),
    [anon_sym_is] = ACTIONS(6578),
    [anon_sym_DASH_GT] = ACTIONS(5233),
    [anon_sym_with] = ACTIONS(6232),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4690] = {
    [sym_preproc_region] = STATE(4690),
    [sym_preproc_endregion] = STATE(4690),
    [sym_preproc_line] = STATE(4690),
    [sym_preproc_pragma] = STATE(4690),
    [sym_preproc_nullable] = STATE(4690),
    [sym_preproc_error] = STATE(4690),
    [sym_preproc_warning] = STATE(4690),
    [sym_preproc_define] = STATE(4690),
    [sym_preproc_undef] = STATE(4690),
    [anon_sym_LBRACK] = ACTIONS(5502),
    [anon_sym_COMMA] = ACTIONS(5502),
    [anon_sym_LPAREN] = ACTIONS(5502),
    [anon_sym_LT] = ACTIONS(5504),
    [anon_sym_GT] = ACTIONS(5504),
    [anon_sym_where] = ACTIONS(5502),
    [anon_sym_QMARK] = ACTIONS(5504),
    [anon_sym_BANG] = ACTIONS(5504),
    [anon_sym_PLUS_PLUS] = ACTIONS(5502),
    [anon_sym_DASH_DASH] = ACTIONS(5502),
    [anon_sym_PLUS] = ACTIONS(5504),
    [anon_sym_DASH] = ACTIONS(5504),
    [anon_sym_STAR] = ACTIONS(5502),
    [anon_sym_SLASH] = ACTIONS(5504),
    [anon_sym_PERCENT] = ACTIONS(5502),
    [anon_sym_CARET] = ACTIONS(5502),
    [anon_sym_PIPE] = ACTIONS(5504),
    [anon_sym_AMP] = ACTIONS(5504),
    [anon_sym_LT_LT] = ACTIONS(5502),
    [anon_sym_GT_GT] = ACTIONS(5504),
    [anon_sym_GT_GT_GT] = ACTIONS(5502),
    [anon_sym_EQ_EQ] = ACTIONS(5502),
    [anon_sym_BANG_EQ] = ACTIONS(5502),
    [anon_sym_GT_EQ] = ACTIONS(5502),
    [anon_sym_LT_EQ] = ACTIONS(5502),
    [anon_sym_DOT] = ACTIONS(5504),
    [anon_sym_switch] = ACTIONS(5502),
    [anon_sym_DOT_DOT] = ACTIONS(5502),
    [anon_sym_and] = ACTIONS(5502),
    [anon_sym_or] = ACTIONS(5504),
    [anon_sym_AMP_AMP] = ACTIONS(5502),
    [anon_sym_PIPE_PIPE] = ACTIONS(5502),
    [anon_sym_QMARK_QMARK] = ACTIONS(5502),
    [anon_sym_from] = ACTIONS(5502),
    [anon_sym_into] = ACTIONS(5502),
    [anon_sym_join] = ACTIONS(5502),
    [anon_sym_let] = ACTIONS(5502),
    [anon_sym_orderby] = ACTIONS(5502),
    [anon_sym_ascending] = ACTIONS(5502),
    [anon_sym_descending] = ACTIONS(5502),
    [anon_sym_group] = ACTIONS(5502),
    [anon_sym_select] = ACTIONS(5502),
    [anon_sym_as] = ACTIONS(5504),
    [anon_sym_is] = ACTIONS(5502),
    [anon_sym_DASH_GT] = ACTIONS(5502),
    [anon_sym_with] = ACTIONS(5502),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4691] = {
    [sym__name] = STATE(7943),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(6020),
    [sym_implicit_type] = STATE(8787),
    [sym_array_type] = STATE(8347),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9367),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(8787),
    [sym_scoped_type] = STATE(8787),
    [sym_tuple_type] = STATE(8173),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4691),
    [sym_preproc_endregion] = STATE(4691),
    [sym_preproc_line] = STATE(4691),
    [sym_preproc_pragma] = STATE(4691),
    [sym_preproc_nullable] = STATE(4691),
    [sym_preproc_error] = STATE(4691),
    [sym_preproc_warning] = STATE(4691),
    [sym_preproc_define] = STATE(4691),
    [sym_preproc_undef] = STATE(4691),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(5745),
    [anon_sym_delegate] = ACTIONS(5747),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_readonly] = ACTIONS(6683),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(5753),
    [anon_sym_var] = ACTIONS(5369),
    [sym_predefined_type] = ACTIONS(5755),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4692] = {
    [sym__name] = STATE(3904),
    [sym_alias_qualified_name] = STATE(3924),
    [sym__simple_name] = STATE(3924),
    [sym_qualified_name] = STATE(3924),
    [sym_generic_name] = STATE(3900),
    [sym_type] = STATE(3929),
    [sym_implicit_type] = STATE(3943),
    [sym_array_type] = STATE(3945),
    [sym__array_base_type] = STATE(8893),
    [sym_nullable_type] = STATE(3885),
    [sym_pointer_type] = STATE(3885),
    [sym__pointer_base_type] = STATE(9659),
    [sym_function_pointer_type] = STATE(3885),
    [sym_ref_type] = STATE(3943),
    [sym_scoped_type] = STATE(3943),
    [sym_tuple_type] = STATE(3880),
    [sym_identifier] = STATE(3808),
    [sym__reserved_identifier] = STATE(3871),
    [sym_preproc_region] = STATE(4692),
    [sym_preproc_endregion] = STATE(4692),
    [sym_preproc_line] = STATE(4692),
    [sym_preproc_pragma] = STATE(4692),
    [sym_preproc_nullable] = STATE(4692),
    [sym_preproc_error] = STATE(4692),
    [sym_preproc_warning] = STATE(4692),
    [sym_preproc_define] = STATE(4692),
    [sym_preproc_undef] = STATE(4692),
    [sym__identifier_token] = ACTIONS(4223),
    [anon_sym_alias] = ACTIONS(4225),
    [anon_sym_global] = ACTIONS(4225),
    [anon_sym_LPAREN] = ACTIONS(6624),
    [anon_sym_ref] = ACTIONS(4638),
    [anon_sym_delegate] = ACTIONS(6182),
    [anon_sym_file] = ACTIONS(4225),
    [anon_sym_readonly] = ACTIONS(6685),
    [anon_sym_where] = ACTIONS(4225),
    [anon_sym_notnull] = ACTIONS(4225),
    [anon_sym_unmanaged] = ACTIONS(4225),
    [anon_sym_scoped] = ACTIONS(6366),
    [anon_sym_var] = ACTIONS(6186),
    [sym_predefined_type] = ACTIONS(6188),
    [anon_sym_yield] = ACTIONS(4225),
    [anon_sym_when] = ACTIONS(4225),
    [anon_sym_from] = ACTIONS(4225),
    [anon_sym_into] = ACTIONS(4225),
    [anon_sym_join] = ACTIONS(4225),
    [anon_sym_on] = ACTIONS(4225),
    [anon_sym_equals] = ACTIONS(4225),
    [anon_sym_let] = ACTIONS(4225),
    [anon_sym_orderby] = ACTIONS(4225),
    [anon_sym_ascending] = ACTIONS(4225),
    [anon_sym_descending] = ACTIONS(4225),
    [anon_sym_group] = ACTIONS(4225),
    [anon_sym_by] = ACTIONS(4225),
    [anon_sym_select] = ACTIONS(4225),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4693] = {
    [sym__name] = STATE(4158),
    [sym_alias_qualified_name] = STATE(4085),
    [sym__simple_name] = STATE(4085),
    [sym_qualified_name] = STATE(4085),
    [sym_generic_name] = STATE(3959),
    [sym_type] = STATE(4032),
    [sym_implicit_type] = STATE(4031),
    [sym_array_type] = STATE(3958),
    [sym__array_base_type] = STATE(8941),
    [sym_nullable_type] = STATE(3961),
    [sym_pointer_type] = STATE(3961),
    [sym__pointer_base_type] = STATE(9806),
    [sym_function_pointer_type] = STATE(3961),
    [sym_ref_type] = STATE(4031),
    [sym_scoped_type] = STATE(4031),
    [sym_tuple_type] = STATE(3962),
    [sym_identifier] = STATE(3889),
    [sym__reserved_identifier] = STATE(3911),
    [sym_preproc_region] = STATE(4693),
    [sym_preproc_endregion] = STATE(4693),
    [sym_preproc_line] = STATE(4693),
    [sym_preproc_pragma] = STATE(4693),
    [sym_preproc_nullable] = STATE(4693),
    [sym_preproc_error] = STATE(4693),
    [sym_preproc_warning] = STATE(4693),
    [sym_preproc_define] = STATE(4693),
    [sym_preproc_undef] = STATE(4693),
    [sym__identifier_token] = ACTIONS(4248),
    [anon_sym_alias] = ACTIONS(4250),
    [anon_sym_global] = ACTIONS(4250),
    [anon_sym_LPAREN] = ACTIONS(6620),
    [anon_sym_ref] = ACTIONS(4658),
    [anon_sym_delegate] = ACTIONS(6168),
    [anon_sym_file] = ACTIONS(4250),
    [anon_sym_readonly] = ACTIONS(6687),
    [anon_sym_where] = ACTIONS(4250),
    [anon_sym_notnull] = ACTIONS(4250),
    [anon_sym_unmanaged] = ACTIONS(4250),
    [anon_sym_scoped] = ACTIONS(6258),
    [anon_sym_var] = ACTIONS(6172),
    [sym_predefined_type] = ACTIONS(6174),
    [anon_sym_yield] = ACTIONS(4250),
    [anon_sym_when] = ACTIONS(4250),
    [anon_sym_from] = ACTIONS(4250),
    [anon_sym_into] = ACTIONS(4250),
    [anon_sym_join] = ACTIONS(4250),
    [anon_sym_on] = ACTIONS(4250),
    [anon_sym_equals] = ACTIONS(4250),
    [anon_sym_let] = ACTIONS(4250),
    [anon_sym_orderby] = ACTIONS(4250),
    [anon_sym_ascending] = ACTIONS(4250),
    [anon_sym_descending] = ACTIONS(4250),
    [anon_sym_group] = ACTIONS(4250),
    [anon_sym_by] = ACTIONS(4250),
    [anon_sym_select] = ACTIONS(4250),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4694] = {
    [sym__name] = STATE(3904),
    [sym_alias_qualified_name] = STATE(3924),
    [sym__simple_name] = STATE(3924),
    [sym_qualified_name] = STATE(3924),
    [sym_generic_name] = STATE(3900),
    [sym_type] = STATE(3929),
    [sym_implicit_type] = STATE(3943),
    [sym_array_type] = STATE(3945),
    [sym__array_base_type] = STATE(8893),
    [sym_nullable_type] = STATE(3885),
    [sym_pointer_type] = STATE(3885),
    [sym__pointer_base_type] = STATE(9659),
    [sym_function_pointer_type] = STATE(3885),
    [sym_ref_type] = STATE(3943),
    [sym_scoped_type] = STATE(3943),
    [sym_tuple_type] = STATE(3880),
    [sym_identifier] = STATE(3808),
    [sym__reserved_identifier] = STATE(3871),
    [sym_preproc_region] = STATE(4694),
    [sym_preproc_endregion] = STATE(4694),
    [sym_preproc_line] = STATE(4694),
    [sym_preproc_pragma] = STATE(4694),
    [sym_preproc_nullable] = STATE(4694),
    [sym_preproc_error] = STATE(4694),
    [sym_preproc_warning] = STATE(4694),
    [sym_preproc_define] = STATE(4694),
    [sym_preproc_undef] = STATE(4694),
    [sym__identifier_token] = ACTIONS(4223),
    [anon_sym_alias] = ACTIONS(4225),
    [anon_sym_global] = ACTIONS(4225),
    [anon_sym_LPAREN] = ACTIONS(6624),
    [anon_sym_ref] = ACTIONS(4644),
    [anon_sym_delegate] = ACTIONS(6182),
    [anon_sym_file] = ACTIONS(4225),
    [anon_sym_readonly] = ACTIONS(6689),
    [anon_sym_where] = ACTIONS(4225),
    [anon_sym_notnull] = ACTIONS(4225),
    [anon_sym_unmanaged] = ACTIONS(4225),
    [anon_sym_scoped] = ACTIONS(6376),
    [anon_sym_var] = ACTIONS(6186),
    [sym_predefined_type] = ACTIONS(6188),
    [anon_sym_yield] = ACTIONS(4225),
    [anon_sym_when] = ACTIONS(4225),
    [anon_sym_from] = ACTIONS(4225),
    [anon_sym_into] = ACTIONS(4225),
    [anon_sym_join] = ACTIONS(4225),
    [anon_sym_on] = ACTIONS(4225),
    [anon_sym_equals] = ACTIONS(4225),
    [anon_sym_let] = ACTIONS(4225),
    [anon_sym_orderby] = ACTIONS(4225),
    [anon_sym_ascending] = ACTIONS(4225),
    [anon_sym_descending] = ACTIONS(4225),
    [anon_sym_group] = ACTIONS(4225),
    [anon_sym_by] = ACTIONS(4225),
    [anon_sym_select] = ACTIONS(4225),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4695] = {
    [sym_preproc_region] = STATE(4695),
    [sym_preproc_endregion] = STATE(4695),
    [sym_preproc_line] = STATE(4695),
    [sym_preproc_pragma] = STATE(4695),
    [sym_preproc_nullable] = STATE(4695),
    [sym_preproc_error] = STATE(4695),
    [sym_preproc_warning] = STATE(4695),
    [sym_preproc_define] = STATE(4695),
    [sym_preproc_undef] = STATE(4695),
    [anon_sym_LBRACK] = ACTIONS(2035),
    [anon_sym_COMMA] = ACTIONS(2035),
    [anon_sym_LPAREN] = ACTIONS(2035),
    [anon_sym_LT] = ACTIONS(2037),
    [anon_sym_GT] = ACTIONS(2037),
    [anon_sym_where] = ACTIONS(2035),
    [anon_sym_QMARK] = ACTIONS(2037),
    [anon_sym_BANG] = ACTIONS(2037),
    [anon_sym_PLUS_PLUS] = ACTIONS(2035),
    [anon_sym_DASH_DASH] = ACTIONS(2035),
    [anon_sym_PLUS] = ACTIONS(2037),
    [anon_sym_DASH] = ACTIONS(2037),
    [anon_sym_STAR] = ACTIONS(2035),
    [anon_sym_SLASH] = ACTIONS(2037),
    [anon_sym_PERCENT] = ACTIONS(2035),
    [anon_sym_CARET] = ACTIONS(2035),
    [anon_sym_PIPE] = ACTIONS(2037),
    [anon_sym_AMP] = ACTIONS(2037),
    [anon_sym_LT_LT] = ACTIONS(2035),
    [anon_sym_GT_GT] = ACTIONS(2037),
    [anon_sym_GT_GT_GT] = ACTIONS(2035),
    [anon_sym_EQ_EQ] = ACTIONS(2035),
    [anon_sym_BANG_EQ] = ACTIONS(2035),
    [anon_sym_GT_EQ] = ACTIONS(2035),
    [anon_sym_LT_EQ] = ACTIONS(2035),
    [anon_sym_DOT] = ACTIONS(2037),
    [anon_sym_switch] = ACTIONS(2035),
    [anon_sym_DOT_DOT] = ACTIONS(2035),
    [anon_sym_and] = ACTIONS(2035),
    [anon_sym_or] = ACTIONS(2037),
    [anon_sym_AMP_AMP] = ACTIONS(2035),
    [anon_sym_PIPE_PIPE] = ACTIONS(2035),
    [anon_sym_QMARK_QMARK] = ACTIONS(2035),
    [anon_sym_from] = ACTIONS(2035),
    [anon_sym_into] = ACTIONS(2035),
    [anon_sym_join] = ACTIONS(2035),
    [anon_sym_let] = ACTIONS(2035),
    [anon_sym_orderby] = ACTIONS(2035),
    [anon_sym_ascending] = ACTIONS(2035),
    [anon_sym_descending] = ACTIONS(2035),
    [anon_sym_group] = ACTIONS(2035),
    [anon_sym_select] = ACTIONS(2035),
    [anon_sym_as] = ACTIONS(2037),
    [anon_sym_is] = ACTIONS(2035),
    [anon_sym_DASH_GT] = ACTIONS(2035),
    [anon_sym_with] = ACTIONS(2035),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4696] = {
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(6020),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4696),
    [sym_preproc_endregion] = STATE(4696),
    [sym_preproc_line] = STATE(4696),
    [sym_preproc_pragma] = STATE(4696),
    [sym_preproc_nullable] = STATE(4696),
    [sym_preproc_error] = STATE(4696),
    [sym_preproc_warning] = STATE(4696),
    [sym_preproc_define] = STATE(4696),
    [sym_preproc_undef] = STATE(4696),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_readonly] = ACTIONS(2767),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4697] = {
    [sym__name] = STATE(3904),
    [sym_alias_qualified_name] = STATE(3924),
    [sym__simple_name] = STATE(3924),
    [sym_qualified_name] = STATE(3924),
    [sym_generic_name] = STATE(3900),
    [sym_type] = STATE(3929),
    [sym_implicit_type] = STATE(3943),
    [sym_array_type] = STATE(3945),
    [sym__array_base_type] = STATE(8893),
    [sym_nullable_type] = STATE(3885),
    [sym_pointer_type] = STATE(3885),
    [sym__pointer_base_type] = STATE(9659),
    [sym_function_pointer_type] = STATE(3885),
    [sym_ref_type] = STATE(3943),
    [sym_scoped_type] = STATE(3943),
    [sym_tuple_type] = STATE(3880),
    [sym_identifier] = STATE(3808),
    [sym__reserved_identifier] = STATE(3871),
    [sym_preproc_region] = STATE(4697),
    [sym_preproc_endregion] = STATE(4697),
    [sym_preproc_line] = STATE(4697),
    [sym_preproc_pragma] = STATE(4697),
    [sym_preproc_nullable] = STATE(4697),
    [sym_preproc_error] = STATE(4697),
    [sym_preproc_warning] = STATE(4697),
    [sym_preproc_define] = STATE(4697),
    [sym_preproc_undef] = STATE(4697),
    [sym__identifier_token] = ACTIONS(4223),
    [anon_sym_alias] = ACTIONS(4225),
    [anon_sym_global] = ACTIONS(4225),
    [anon_sym_LPAREN] = ACTIONS(6624),
    [anon_sym_ref] = ACTIONS(4660),
    [anon_sym_delegate] = ACTIONS(6182),
    [anon_sym_file] = ACTIONS(4225),
    [anon_sym_readonly] = ACTIONS(6691),
    [anon_sym_where] = ACTIONS(4225),
    [anon_sym_notnull] = ACTIONS(4225),
    [anon_sym_unmanaged] = ACTIONS(4225),
    [anon_sym_scoped] = ACTIONS(6378),
    [anon_sym_var] = ACTIONS(6186),
    [sym_predefined_type] = ACTIONS(6188),
    [anon_sym_yield] = ACTIONS(4225),
    [anon_sym_when] = ACTIONS(4225),
    [anon_sym_from] = ACTIONS(4225),
    [anon_sym_into] = ACTIONS(4225),
    [anon_sym_join] = ACTIONS(4225),
    [anon_sym_on] = ACTIONS(4225),
    [anon_sym_equals] = ACTIONS(4225),
    [anon_sym_let] = ACTIONS(4225),
    [anon_sym_orderby] = ACTIONS(4225),
    [anon_sym_ascending] = ACTIONS(4225),
    [anon_sym_descending] = ACTIONS(4225),
    [anon_sym_group] = ACTIONS(4225),
    [anon_sym_by] = ACTIONS(4225),
    [anon_sym_select] = ACTIONS(4225),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4698] = {
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(6020),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4698),
    [sym_preproc_endregion] = STATE(4698),
    [sym_preproc_line] = STATE(4698),
    [sym_preproc_pragma] = STATE(4698),
    [sym_preproc_nullable] = STATE(4698),
    [sym_preproc_error] = STATE(4698),
    [sym_preproc_warning] = STATE(4698),
    [sym_preproc_define] = STATE(4698),
    [sym_preproc_undef] = STATE(4698),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(5988),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_readonly] = ACTIONS(6693),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(5996),
    [anon_sym_var] = ACTIONS(5369),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4699] = {
    [sym_preproc_region] = STATE(4699),
    [sym_preproc_endregion] = STATE(4699),
    [sym_preproc_line] = STATE(4699),
    [sym_preproc_pragma] = STATE(4699),
    [sym_preproc_nullable] = STATE(4699),
    [sym_preproc_error] = STATE(4699),
    [sym_preproc_warning] = STATE(4699),
    [sym_preproc_define] = STATE(4699),
    [sym_preproc_undef] = STATE(4699),
    [anon_sym_LBRACK] = ACTIONS(5879),
    [anon_sym_COMMA] = ACTIONS(5879),
    [anon_sym_LPAREN] = ACTIONS(5879),
    [anon_sym_LT] = ACTIONS(5881),
    [anon_sym_GT] = ACTIONS(5881),
    [anon_sym_where] = ACTIONS(5879),
    [anon_sym_QMARK] = ACTIONS(5881),
    [anon_sym_BANG] = ACTIONS(5881),
    [anon_sym_PLUS_PLUS] = ACTIONS(5879),
    [anon_sym_DASH_DASH] = ACTIONS(5879),
    [anon_sym_PLUS] = ACTIONS(5881),
    [anon_sym_DASH] = ACTIONS(5881),
    [anon_sym_STAR] = ACTIONS(5879),
    [anon_sym_SLASH] = ACTIONS(5881),
    [anon_sym_PERCENT] = ACTIONS(5879),
    [anon_sym_CARET] = ACTIONS(5879),
    [anon_sym_PIPE] = ACTIONS(5881),
    [anon_sym_AMP] = ACTIONS(5881),
    [anon_sym_LT_LT] = ACTIONS(5879),
    [anon_sym_GT_GT] = ACTIONS(5881),
    [anon_sym_GT_GT_GT] = ACTIONS(5879),
    [anon_sym_EQ_EQ] = ACTIONS(5879),
    [anon_sym_BANG_EQ] = ACTIONS(5879),
    [anon_sym_GT_EQ] = ACTIONS(5879),
    [anon_sym_LT_EQ] = ACTIONS(5879),
    [anon_sym_DOT] = ACTIONS(5881),
    [anon_sym_switch] = ACTIONS(5879),
    [anon_sym_DOT_DOT] = ACTIONS(5879),
    [anon_sym_and] = ACTIONS(5879),
    [anon_sym_or] = ACTIONS(5881),
    [anon_sym_AMP_AMP] = ACTIONS(5879),
    [anon_sym_PIPE_PIPE] = ACTIONS(5879),
    [anon_sym_QMARK_QMARK] = ACTIONS(5879),
    [anon_sym_from] = ACTIONS(5879),
    [anon_sym_into] = ACTIONS(5879),
    [anon_sym_join] = ACTIONS(5879),
    [anon_sym_let] = ACTIONS(5879),
    [anon_sym_orderby] = ACTIONS(5879),
    [anon_sym_ascending] = ACTIONS(5879),
    [anon_sym_descending] = ACTIONS(5879),
    [anon_sym_group] = ACTIONS(5879),
    [anon_sym_select] = ACTIONS(5879),
    [anon_sym_as] = ACTIONS(5881),
    [anon_sym_is] = ACTIONS(5879),
    [anon_sym_DASH_GT] = ACTIONS(5879),
    [anon_sym_with] = ACTIONS(5879),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4700] = {
    [sym__name] = STATE(4343),
    [sym_alias_qualified_name] = STATE(3588),
    [sym__simple_name] = STATE(3588),
    [sym_qualified_name] = STATE(3588),
    [sym_generic_name] = STATE(3597),
    [sym_type] = STATE(3611),
    [sym_implicit_type] = STATE(3596),
    [sym_array_type] = STATE(3608),
    [sym__array_base_type] = STATE(8805),
    [sym_nullable_type] = STATE(3612),
    [sym_pointer_type] = STATE(3612),
    [sym__pointer_base_type] = STATE(9071),
    [sym_function_pointer_type] = STATE(3612),
    [sym_ref_type] = STATE(3596),
    [sym_scoped_type] = STATE(3596),
    [sym_tuple_type] = STATE(3621),
    [sym_identifier] = STATE(4004),
    [sym__reserved_identifier] = STATE(3572),
    [sym_preproc_region] = STATE(4700),
    [sym_preproc_endregion] = STATE(4700),
    [sym_preproc_line] = STATE(4700),
    [sym_preproc_pragma] = STATE(4700),
    [sym_preproc_nullable] = STATE(4700),
    [sym_preproc_error] = STATE(4700),
    [sym_preproc_warning] = STATE(4700),
    [sym_preproc_define] = STATE(4700),
    [sym_preproc_undef] = STATE(4700),
    [sym__identifier_token] = ACTIONS(4328),
    [anon_sym_alias] = ACTIONS(4330),
    [anon_sym_global] = ACTIONS(4330),
    [anon_sym_LPAREN] = ACTIONS(6654),
    [anon_sym_ref] = ACTIONS(4332),
    [anon_sym_delegate] = ACTIONS(6148),
    [anon_sym_file] = ACTIONS(4330),
    [anon_sym_readonly] = ACTIONS(6695),
    [anon_sym_where] = ACTIONS(4330),
    [anon_sym_notnull] = ACTIONS(4330),
    [anon_sym_unmanaged] = ACTIONS(4330),
    [anon_sym_scoped] = ACTIONS(6252),
    [anon_sym_var] = ACTIONS(6152),
    [sym_predefined_type] = ACTIONS(6154),
    [anon_sym_yield] = ACTIONS(4330),
    [anon_sym_when] = ACTIONS(4330),
    [anon_sym_from] = ACTIONS(4330),
    [anon_sym_into] = ACTIONS(4330),
    [anon_sym_join] = ACTIONS(4330),
    [anon_sym_on] = ACTIONS(4330),
    [anon_sym_equals] = ACTIONS(4330),
    [anon_sym_let] = ACTIONS(4330),
    [anon_sym_orderby] = ACTIONS(4330),
    [anon_sym_ascending] = ACTIONS(4330),
    [anon_sym_descending] = ACTIONS(4330),
    [anon_sym_group] = ACTIONS(4330),
    [anon_sym_by] = ACTIONS(4330),
    [anon_sym_select] = ACTIONS(4330),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4701] = {
    [sym_preproc_region] = STATE(4701),
    [sym_preproc_endregion] = STATE(4701),
    [sym_preproc_line] = STATE(4701),
    [sym_preproc_pragma] = STATE(4701),
    [sym_preproc_nullable] = STATE(4701),
    [sym_preproc_error] = STATE(4701),
    [sym_preproc_warning] = STATE(4701),
    [sym_preproc_define] = STATE(4701),
    [sym_preproc_undef] = STATE(4701),
    [anon_sym_LBRACK] = ACTIONS(5534),
    [anon_sym_COMMA] = ACTIONS(5534),
    [anon_sym_LPAREN] = ACTIONS(5534),
    [anon_sym_LT] = ACTIONS(5536),
    [anon_sym_GT] = ACTIONS(5536),
    [anon_sym_where] = ACTIONS(5534),
    [anon_sym_QMARK] = ACTIONS(5536),
    [anon_sym_BANG] = ACTIONS(5536),
    [anon_sym_PLUS_PLUS] = ACTIONS(5534),
    [anon_sym_DASH_DASH] = ACTIONS(5534),
    [anon_sym_PLUS] = ACTIONS(5536),
    [anon_sym_DASH] = ACTIONS(5536),
    [anon_sym_STAR] = ACTIONS(5534),
    [anon_sym_SLASH] = ACTIONS(5536),
    [anon_sym_PERCENT] = ACTIONS(5534),
    [anon_sym_CARET] = ACTIONS(5534),
    [anon_sym_PIPE] = ACTIONS(5536),
    [anon_sym_AMP] = ACTIONS(5536),
    [anon_sym_LT_LT] = ACTIONS(5534),
    [anon_sym_GT_GT] = ACTIONS(5536),
    [anon_sym_GT_GT_GT] = ACTIONS(5534),
    [anon_sym_EQ_EQ] = ACTIONS(5534),
    [anon_sym_BANG_EQ] = ACTIONS(5534),
    [anon_sym_GT_EQ] = ACTIONS(5534),
    [anon_sym_LT_EQ] = ACTIONS(5534),
    [anon_sym_DOT] = ACTIONS(5536),
    [anon_sym_switch] = ACTIONS(5534),
    [anon_sym_DOT_DOT] = ACTIONS(5534),
    [anon_sym_and] = ACTIONS(5534),
    [anon_sym_or] = ACTIONS(5536),
    [anon_sym_AMP_AMP] = ACTIONS(5534),
    [anon_sym_PIPE_PIPE] = ACTIONS(5534),
    [anon_sym_QMARK_QMARK] = ACTIONS(5534),
    [anon_sym_from] = ACTIONS(5534),
    [anon_sym_into] = ACTIONS(5534),
    [anon_sym_join] = ACTIONS(5534),
    [anon_sym_let] = ACTIONS(5534),
    [anon_sym_orderby] = ACTIONS(5534),
    [anon_sym_ascending] = ACTIONS(5534),
    [anon_sym_descending] = ACTIONS(5534),
    [anon_sym_group] = ACTIONS(5534),
    [anon_sym_select] = ACTIONS(5534),
    [anon_sym_as] = ACTIONS(5536),
    [anon_sym_is] = ACTIONS(5534),
    [anon_sym_DASH_GT] = ACTIONS(5534),
    [anon_sym_with] = ACTIONS(5534),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4702] = {
    [sym_preproc_region] = STATE(4702),
    [sym_preproc_endregion] = STATE(4702),
    [sym_preproc_line] = STATE(4702),
    [sym_preproc_pragma] = STATE(4702),
    [sym_preproc_nullable] = STATE(4702),
    [sym_preproc_error] = STATE(4702),
    [sym_preproc_warning] = STATE(4702),
    [sym_preproc_define] = STATE(4702),
    [sym_preproc_undef] = STATE(4702),
    [anon_sym_LBRACK] = ACTIONS(5538),
    [anon_sym_COMMA] = ACTIONS(5538),
    [anon_sym_LPAREN] = ACTIONS(5538),
    [anon_sym_LT] = ACTIONS(5540),
    [anon_sym_GT] = ACTIONS(5540),
    [anon_sym_where] = ACTIONS(5538),
    [anon_sym_QMARK] = ACTIONS(5540),
    [anon_sym_BANG] = ACTIONS(5540),
    [anon_sym_PLUS_PLUS] = ACTIONS(5538),
    [anon_sym_DASH_DASH] = ACTIONS(5538),
    [anon_sym_PLUS] = ACTIONS(5540),
    [anon_sym_DASH] = ACTIONS(5540),
    [anon_sym_STAR] = ACTIONS(5538),
    [anon_sym_SLASH] = ACTIONS(5540),
    [anon_sym_PERCENT] = ACTIONS(5538),
    [anon_sym_CARET] = ACTIONS(5538),
    [anon_sym_PIPE] = ACTIONS(5540),
    [anon_sym_AMP] = ACTIONS(5540),
    [anon_sym_LT_LT] = ACTIONS(5538),
    [anon_sym_GT_GT] = ACTIONS(5540),
    [anon_sym_GT_GT_GT] = ACTIONS(5538),
    [anon_sym_EQ_EQ] = ACTIONS(5538),
    [anon_sym_BANG_EQ] = ACTIONS(5538),
    [anon_sym_GT_EQ] = ACTIONS(5538),
    [anon_sym_LT_EQ] = ACTIONS(5538),
    [anon_sym_DOT] = ACTIONS(5540),
    [anon_sym_switch] = ACTIONS(5538),
    [anon_sym_DOT_DOT] = ACTIONS(5538),
    [anon_sym_and] = ACTIONS(5538),
    [anon_sym_or] = ACTIONS(5540),
    [anon_sym_AMP_AMP] = ACTIONS(5538),
    [anon_sym_PIPE_PIPE] = ACTIONS(5538),
    [anon_sym_QMARK_QMARK] = ACTIONS(5538),
    [anon_sym_from] = ACTIONS(5538),
    [anon_sym_into] = ACTIONS(5538),
    [anon_sym_join] = ACTIONS(5538),
    [anon_sym_let] = ACTIONS(5538),
    [anon_sym_orderby] = ACTIONS(5538),
    [anon_sym_ascending] = ACTIONS(5538),
    [anon_sym_descending] = ACTIONS(5538),
    [anon_sym_group] = ACTIONS(5538),
    [anon_sym_select] = ACTIONS(5538),
    [anon_sym_as] = ACTIONS(5540),
    [anon_sym_is] = ACTIONS(5538),
    [anon_sym_DASH_GT] = ACTIONS(5538),
    [anon_sym_with] = ACTIONS(5538),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4703] = {
    [sym_preproc_region] = STATE(4703),
    [sym_preproc_endregion] = STATE(4703),
    [sym_preproc_line] = STATE(4703),
    [sym_preproc_pragma] = STATE(4703),
    [sym_preproc_nullable] = STATE(4703),
    [sym_preproc_error] = STATE(4703),
    [sym_preproc_warning] = STATE(4703),
    [sym_preproc_define] = STATE(4703),
    [sym_preproc_undef] = STATE(4703),
    [anon_sym_LBRACK] = ACTIONS(5580),
    [anon_sym_COMMA] = ACTIONS(5580),
    [anon_sym_LPAREN] = ACTIONS(5580),
    [anon_sym_LT] = ACTIONS(5582),
    [anon_sym_GT] = ACTIONS(5582),
    [anon_sym_where] = ACTIONS(5580),
    [anon_sym_QMARK] = ACTIONS(5582),
    [anon_sym_BANG] = ACTIONS(5582),
    [anon_sym_PLUS_PLUS] = ACTIONS(5580),
    [anon_sym_DASH_DASH] = ACTIONS(5580),
    [anon_sym_PLUS] = ACTIONS(5582),
    [anon_sym_DASH] = ACTIONS(5582),
    [anon_sym_STAR] = ACTIONS(5580),
    [anon_sym_SLASH] = ACTIONS(5582),
    [anon_sym_PERCENT] = ACTIONS(5580),
    [anon_sym_CARET] = ACTIONS(5580),
    [anon_sym_PIPE] = ACTIONS(5582),
    [anon_sym_AMP] = ACTIONS(5582),
    [anon_sym_LT_LT] = ACTIONS(5580),
    [anon_sym_GT_GT] = ACTIONS(5582),
    [anon_sym_GT_GT_GT] = ACTIONS(5580),
    [anon_sym_EQ_EQ] = ACTIONS(5580),
    [anon_sym_BANG_EQ] = ACTIONS(5580),
    [anon_sym_GT_EQ] = ACTIONS(5580),
    [anon_sym_LT_EQ] = ACTIONS(5580),
    [anon_sym_DOT] = ACTIONS(5582),
    [anon_sym_switch] = ACTIONS(5580),
    [anon_sym_DOT_DOT] = ACTIONS(5580),
    [anon_sym_and] = ACTIONS(5580),
    [anon_sym_or] = ACTIONS(5582),
    [anon_sym_AMP_AMP] = ACTIONS(5580),
    [anon_sym_PIPE_PIPE] = ACTIONS(5580),
    [anon_sym_QMARK_QMARK] = ACTIONS(5580),
    [anon_sym_from] = ACTIONS(5580),
    [anon_sym_into] = ACTIONS(5580),
    [anon_sym_join] = ACTIONS(5580),
    [anon_sym_let] = ACTIONS(5580),
    [anon_sym_orderby] = ACTIONS(5580),
    [anon_sym_ascending] = ACTIONS(5580),
    [anon_sym_descending] = ACTIONS(5580),
    [anon_sym_group] = ACTIONS(5580),
    [anon_sym_select] = ACTIONS(5580),
    [anon_sym_as] = ACTIONS(5582),
    [anon_sym_is] = ACTIONS(5580),
    [anon_sym_DASH_GT] = ACTIONS(5580),
    [anon_sym_with] = ACTIONS(5580),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4704] = {
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7377),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4704),
    [sym_preproc_endregion] = STATE(4704),
    [sym_preproc_line] = STATE(4704),
    [sym_preproc_pragma] = STATE(4704),
    [sym_preproc_nullable] = STATE(4704),
    [sym_preproc_error] = STATE(4704),
    [sym_preproc_warning] = STATE(4704),
    [sym_preproc_define] = STATE(4704),
    [sym_preproc_undef] = STATE(4704),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_STAR] = ACTIONS(6110),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4705] = {
    [sym_preproc_region] = STATE(4705),
    [sym_preproc_endregion] = STATE(4705),
    [sym_preproc_line] = STATE(4705),
    [sym_preproc_pragma] = STATE(4705),
    [sym_preproc_nullable] = STATE(4705),
    [sym_preproc_error] = STATE(4705),
    [sym_preproc_warning] = STATE(4705),
    [sym_preproc_define] = STATE(4705),
    [sym_preproc_undef] = STATE(4705),
    [anon_sym_LBRACK] = ACTIONS(5632),
    [anon_sym_COMMA] = ACTIONS(5632),
    [anon_sym_LPAREN] = ACTIONS(5632),
    [anon_sym_LT] = ACTIONS(5634),
    [anon_sym_GT] = ACTIONS(5634),
    [anon_sym_where] = ACTIONS(5632),
    [anon_sym_QMARK] = ACTIONS(5634),
    [anon_sym_BANG] = ACTIONS(5634),
    [anon_sym_PLUS_PLUS] = ACTIONS(5632),
    [anon_sym_DASH_DASH] = ACTIONS(5632),
    [anon_sym_PLUS] = ACTIONS(5634),
    [anon_sym_DASH] = ACTIONS(5634),
    [anon_sym_STAR] = ACTIONS(5632),
    [anon_sym_SLASH] = ACTIONS(5634),
    [anon_sym_PERCENT] = ACTIONS(5632),
    [anon_sym_CARET] = ACTIONS(5632),
    [anon_sym_PIPE] = ACTIONS(5634),
    [anon_sym_AMP] = ACTIONS(5634),
    [anon_sym_LT_LT] = ACTIONS(5632),
    [anon_sym_GT_GT] = ACTIONS(5634),
    [anon_sym_GT_GT_GT] = ACTIONS(5632),
    [anon_sym_EQ_EQ] = ACTIONS(5632),
    [anon_sym_BANG_EQ] = ACTIONS(5632),
    [anon_sym_GT_EQ] = ACTIONS(5632),
    [anon_sym_LT_EQ] = ACTIONS(5632),
    [anon_sym_DOT] = ACTIONS(5634),
    [anon_sym_switch] = ACTIONS(5632),
    [anon_sym_DOT_DOT] = ACTIONS(5632),
    [anon_sym_and] = ACTIONS(5632),
    [anon_sym_or] = ACTIONS(5634),
    [anon_sym_AMP_AMP] = ACTIONS(5632),
    [anon_sym_PIPE_PIPE] = ACTIONS(5632),
    [anon_sym_QMARK_QMARK] = ACTIONS(5632),
    [anon_sym_from] = ACTIONS(5632),
    [anon_sym_into] = ACTIONS(5632),
    [anon_sym_join] = ACTIONS(5632),
    [anon_sym_let] = ACTIONS(5632),
    [anon_sym_orderby] = ACTIONS(5632),
    [anon_sym_ascending] = ACTIONS(5632),
    [anon_sym_descending] = ACTIONS(5632),
    [anon_sym_group] = ACTIONS(5632),
    [anon_sym_select] = ACTIONS(5632),
    [anon_sym_as] = ACTIONS(5634),
    [anon_sym_is] = ACTIONS(5632),
    [anon_sym_DASH_GT] = ACTIONS(5632),
    [anon_sym_with] = ACTIONS(5632),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4706] = {
    [sym_variable_declaration] = STATE(9186),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7104),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4706),
    [sym_preproc_endregion] = STATE(4706),
    [sym_preproc_line] = STATE(4706),
    [sym_preproc_pragma] = STATE(4706),
    [sym_preproc_nullable] = STATE(4706),
    [sym_preproc_error] = STATE(4706),
    [sym_preproc_warning] = STATE(4706),
    [sym_preproc_define] = STATE(4706),
    [sym_preproc_undef] = STATE(4706),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4707] = {
    [sym_preproc_region] = STATE(4707),
    [sym_preproc_endregion] = STATE(4707),
    [sym_preproc_line] = STATE(4707),
    [sym_preproc_pragma] = STATE(4707),
    [sym_preproc_nullable] = STATE(4707),
    [sym_preproc_error] = STATE(4707),
    [sym_preproc_warning] = STATE(4707),
    [sym_preproc_define] = STATE(4707),
    [sym_preproc_undef] = STATE(4707),
    [anon_sym_LBRACK] = ACTIONS(5640),
    [anon_sym_COMMA] = ACTIONS(5640),
    [anon_sym_LPAREN] = ACTIONS(5640),
    [anon_sym_LT] = ACTIONS(5642),
    [anon_sym_GT] = ACTIONS(5642),
    [anon_sym_where] = ACTIONS(5640),
    [anon_sym_QMARK] = ACTIONS(5642),
    [anon_sym_BANG] = ACTIONS(5642),
    [anon_sym_PLUS_PLUS] = ACTIONS(5640),
    [anon_sym_DASH_DASH] = ACTIONS(5640),
    [anon_sym_PLUS] = ACTIONS(5642),
    [anon_sym_DASH] = ACTIONS(5642),
    [anon_sym_STAR] = ACTIONS(5640),
    [anon_sym_SLASH] = ACTIONS(5642),
    [anon_sym_PERCENT] = ACTIONS(5640),
    [anon_sym_CARET] = ACTIONS(5640),
    [anon_sym_PIPE] = ACTIONS(5642),
    [anon_sym_AMP] = ACTIONS(5642),
    [anon_sym_LT_LT] = ACTIONS(5640),
    [anon_sym_GT_GT] = ACTIONS(5642),
    [anon_sym_GT_GT_GT] = ACTIONS(5640),
    [anon_sym_EQ_EQ] = ACTIONS(5640),
    [anon_sym_BANG_EQ] = ACTIONS(5640),
    [anon_sym_GT_EQ] = ACTIONS(5640),
    [anon_sym_LT_EQ] = ACTIONS(5640),
    [anon_sym_DOT] = ACTIONS(5642),
    [anon_sym_switch] = ACTIONS(5640),
    [anon_sym_DOT_DOT] = ACTIONS(5640),
    [anon_sym_and] = ACTIONS(5640),
    [anon_sym_or] = ACTIONS(5642),
    [anon_sym_AMP_AMP] = ACTIONS(5640),
    [anon_sym_PIPE_PIPE] = ACTIONS(5640),
    [anon_sym_QMARK_QMARK] = ACTIONS(5640),
    [anon_sym_from] = ACTIONS(5640),
    [anon_sym_into] = ACTIONS(5640),
    [anon_sym_join] = ACTIONS(5640),
    [anon_sym_let] = ACTIONS(5640),
    [anon_sym_orderby] = ACTIONS(5640),
    [anon_sym_ascending] = ACTIONS(5640),
    [anon_sym_descending] = ACTIONS(5640),
    [anon_sym_group] = ACTIONS(5640),
    [anon_sym_select] = ACTIONS(5640),
    [anon_sym_as] = ACTIONS(5642),
    [anon_sym_is] = ACTIONS(5640),
    [anon_sym_DASH_GT] = ACTIONS(5640),
    [anon_sym_with] = ACTIONS(5640),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4708] = {
    [sym_preproc_region] = STATE(4708),
    [sym_preproc_endregion] = STATE(4708),
    [sym_preproc_line] = STATE(4708),
    [sym_preproc_pragma] = STATE(4708),
    [sym_preproc_nullable] = STATE(4708),
    [sym_preproc_error] = STATE(4708),
    [sym_preproc_warning] = STATE(4708),
    [sym_preproc_define] = STATE(4708),
    [sym_preproc_undef] = STATE(4708),
    [anon_sym_LBRACK] = ACTIONS(5644),
    [anon_sym_COMMA] = ACTIONS(5644),
    [anon_sym_LPAREN] = ACTIONS(5644),
    [anon_sym_LT] = ACTIONS(5646),
    [anon_sym_GT] = ACTIONS(5646),
    [anon_sym_where] = ACTIONS(5644),
    [anon_sym_QMARK] = ACTIONS(5646),
    [anon_sym_BANG] = ACTIONS(5646),
    [anon_sym_PLUS_PLUS] = ACTIONS(5644),
    [anon_sym_DASH_DASH] = ACTIONS(5644),
    [anon_sym_PLUS] = ACTIONS(5646),
    [anon_sym_DASH] = ACTIONS(5646),
    [anon_sym_STAR] = ACTIONS(5644),
    [anon_sym_SLASH] = ACTIONS(5646),
    [anon_sym_PERCENT] = ACTIONS(5644),
    [anon_sym_CARET] = ACTIONS(5644),
    [anon_sym_PIPE] = ACTIONS(5646),
    [anon_sym_AMP] = ACTIONS(5646),
    [anon_sym_LT_LT] = ACTIONS(5644),
    [anon_sym_GT_GT] = ACTIONS(5646),
    [anon_sym_GT_GT_GT] = ACTIONS(5644),
    [anon_sym_EQ_EQ] = ACTIONS(5644),
    [anon_sym_BANG_EQ] = ACTIONS(5644),
    [anon_sym_GT_EQ] = ACTIONS(5644),
    [anon_sym_LT_EQ] = ACTIONS(5644),
    [anon_sym_DOT] = ACTIONS(5646),
    [anon_sym_switch] = ACTIONS(5644),
    [anon_sym_DOT_DOT] = ACTIONS(5644),
    [anon_sym_and] = ACTIONS(5644),
    [anon_sym_or] = ACTIONS(5646),
    [anon_sym_AMP_AMP] = ACTIONS(5644),
    [anon_sym_PIPE_PIPE] = ACTIONS(5644),
    [anon_sym_QMARK_QMARK] = ACTIONS(5644),
    [anon_sym_from] = ACTIONS(5644),
    [anon_sym_into] = ACTIONS(5644),
    [anon_sym_join] = ACTIONS(5644),
    [anon_sym_let] = ACTIONS(5644),
    [anon_sym_orderby] = ACTIONS(5644),
    [anon_sym_ascending] = ACTIONS(5644),
    [anon_sym_descending] = ACTIONS(5644),
    [anon_sym_group] = ACTIONS(5644),
    [anon_sym_select] = ACTIONS(5644),
    [anon_sym_as] = ACTIONS(5646),
    [anon_sym_is] = ACTIONS(5644),
    [anon_sym_DASH_GT] = ACTIONS(5644),
    [anon_sym_with] = ACTIONS(5644),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4709] = {
    [sym_preproc_region] = STATE(4709),
    [sym_preproc_endregion] = STATE(4709),
    [sym_preproc_line] = STATE(4709),
    [sym_preproc_pragma] = STATE(4709),
    [sym_preproc_nullable] = STATE(4709),
    [sym_preproc_error] = STATE(4709),
    [sym_preproc_warning] = STATE(4709),
    [sym_preproc_define] = STATE(4709),
    [sym_preproc_undef] = STATE(4709),
    [anon_sym_LBRACK] = ACTIONS(5670),
    [anon_sym_COMMA] = ACTIONS(5670),
    [anon_sym_LPAREN] = ACTIONS(5670),
    [anon_sym_LT] = ACTIONS(5672),
    [anon_sym_GT] = ACTIONS(5672),
    [anon_sym_where] = ACTIONS(5670),
    [anon_sym_QMARK] = ACTIONS(5672),
    [anon_sym_BANG] = ACTIONS(5672),
    [anon_sym_PLUS_PLUS] = ACTIONS(5670),
    [anon_sym_DASH_DASH] = ACTIONS(5670),
    [anon_sym_PLUS] = ACTIONS(5672),
    [anon_sym_DASH] = ACTIONS(5672),
    [anon_sym_STAR] = ACTIONS(5670),
    [anon_sym_SLASH] = ACTIONS(5672),
    [anon_sym_PERCENT] = ACTIONS(5670),
    [anon_sym_CARET] = ACTIONS(5670),
    [anon_sym_PIPE] = ACTIONS(5672),
    [anon_sym_AMP] = ACTIONS(5672),
    [anon_sym_LT_LT] = ACTIONS(5670),
    [anon_sym_GT_GT] = ACTIONS(5672),
    [anon_sym_GT_GT_GT] = ACTIONS(5670),
    [anon_sym_EQ_EQ] = ACTIONS(5670),
    [anon_sym_BANG_EQ] = ACTIONS(5670),
    [anon_sym_GT_EQ] = ACTIONS(5670),
    [anon_sym_LT_EQ] = ACTIONS(5670),
    [anon_sym_DOT] = ACTIONS(5672),
    [anon_sym_switch] = ACTIONS(5670),
    [anon_sym_DOT_DOT] = ACTIONS(5670),
    [anon_sym_and] = ACTIONS(5670),
    [anon_sym_or] = ACTIONS(5672),
    [anon_sym_AMP_AMP] = ACTIONS(5670),
    [anon_sym_PIPE_PIPE] = ACTIONS(5670),
    [anon_sym_QMARK_QMARK] = ACTIONS(5670),
    [anon_sym_from] = ACTIONS(5670),
    [anon_sym_into] = ACTIONS(5670),
    [anon_sym_join] = ACTIONS(5670),
    [anon_sym_let] = ACTIONS(5670),
    [anon_sym_orderby] = ACTIONS(5670),
    [anon_sym_ascending] = ACTIONS(5670),
    [anon_sym_descending] = ACTIONS(5670),
    [anon_sym_group] = ACTIONS(5670),
    [anon_sym_select] = ACTIONS(5670),
    [anon_sym_as] = ACTIONS(5672),
    [anon_sym_is] = ACTIONS(5670),
    [anon_sym_DASH_GT] = ACTIONS(5670),
    [anon_sym_with] = ACTIONS(5670),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4710] = {
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7322),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4710),
    [sym_preproc_endregion] = STATE(4710),
    [sym_preproc_line] = STATE(4710),
    [sym_preproc_pragma] = STATE(4710),
    [sym_preproc_nullable] = STATE(4710),
    [sym_preproc_error] = STATE(4710),
    [sym_preproc_warning] = STATE(4710),
    [sym_preproc_define] = STATE(4710),
    [sym_preproc_undef] = STATE(4710),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_STAR] = ACTIONS(6110),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4711] = {
    [sym__name] = STATE(4958),
    [sym_alias_qualified_name] = STATE(3588),
    [sym__simple_name] = STATE(3588),
    [sym_qualified_name] = STATE(3588),
    [sym_generic_name] = STATE(3597),
    [sym_type] = STATE(3611),
    [sym_implicit_type] = STATE(3596),
    [sym_array_type] = STATE(3608),
    [sym__array_base_type] = STATE(8805),
    [sym_nullable_type] = STATE(3612),
    [sym_pointer_type] = STATE(3612),
    [sym__pointer_base_type] = STATE(9071),
    [sym_function_pointer_type] = STATE(3612),
    [sym_ref_type] = STATE(3596),
    [sym_scoped_type] = STATE(3596),
    [sym_tuple_type] = STATE(3621),
    [sym_identifier] = STATE(4574),
    [sym__reserved_identifier] = STATE(3572),
    [sym_preproc_region] = STATE(4711),
    [sym_preproc_endregion] = STATE(4711),
    [sym_preproc_line] = STATE(4711),
    [sym_preproc_pragma] = STATE(4711),
    [sym_preproc_nullable] = STATE(4711),
    [sym_preproc_error] = STATE(4711),
    [sym_preproc_warning] = STATE(4711),
    [sym_preproc_define] = STATE(4711),
    [sym_preproc_undef] = STATE(4711),
    [sym__identifier_token] = ACTIONS(4328),
    [anon_sym_alias] = ACTIONS(4330),
    [anon_sym_global] = ACTIONS(4330),
    [anon_sym_LPAREN] = ACTIONS(6654),
    [anon_sym_ref] = ACTIONS(4693),
    [anon_sym_delegate] = ACTIONS(6148),
    [anon_sym_file] = ACTIONS(4330),
    [anon_sym_readonly] = ACTIONS(6697),
    [anon_sym_where] = ACTIONS(4330),
    [anon_sym_notnull] = ACTIONS(4330),
    [anon_sym_unmanaged] = ACTIONS(4330),
    [anon_sym_scoped] = ACTIONS(6150),
    [anon_sym_var] = ACTIONS(6152),
    [sym_predefined_type] = ACTIONS(6154),
    [anon_sym_yield] = ACTIONS(4330),
    [anon_sym_when] = ACTIONS(4330),
    [anon_sym_from] = ACTIONS(4330),
    [anon_sym_into] = ACTIONS(4330),
    [anon_sym_join] = ACTIONS(4330),
    [anon_sym_on] = ACTIONS(4330),
    [anon_sym_equals] = ACTIONS(4330),
    [anon_sym_let] = ACTIONS(4330),
    [anon_sym_orderby] = ACTIONS(4330),
    [anon_sym_ascending] = ACTIONS(4330),
    [anon_sym_descending] = ACTIONS(4330),
    [anon_sym_group] = ACTIONS(4330),
    [anon_sym_by] = ACTIONS(4330),
    [anon_sym_select] = ACTIONS(4330),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4712] = {
    [sym_preproc_region] = STATE(4712),
    [sym_preproc_endregion] = STATE(4712),
    [sym_preproc_line] = STATE(4712),
    [sym_preproc_pragma] = STATE(4712),
    [sym_preproc_nullable] = STATE(4712),
    [sym_preproc_error] = STATE(4712),
    [sym_preproc_warning] = STATE(4712),
    [sym_preproc_define] = STATE(4712),
    [sym_preproc_undef] = STATE(4712),
    [anon_sym_LBRACK] = ACTIONS(5686),
    [anon_sym_COMMA] = ACTIONS(5686),
    [anon_sym_LPAREN] = ACTIONS(5686),
    [anon_sym_LT] = ACTIONS(5688),
    [anon_sym_GT] = ACTIONS(5688),
    [anon_sym_where] = ACTIONS(5686),
    [anon_sym_QMARK] = ACTIONS(5688),
    [anon_sym_BANG] = ACTIONS(5688),
    [anon_sym_PLUS_PLUS] = ACTIONS(5686),
    [anon_sym_DASH_DASH] = ACTIONS(5686),
    [anon_sym_PLUS] = ACTIONS(5688),
    [anon_sym_DASH] = ACTIONS(5688),
    [anon_sym_STAR] = ACTIONS(5686),
    [anon_sym_SLASH] = ACTIONS(5688),
    [anon_sym_PERCENT] = ACTIONS(5686),
    [anon_sym_CARET] = ACTIONS(5686),
    [anon_sym_PIPE] = ACTIONS(5688),
    [anon_sym_AMP] = ACTIONS(5688),
    [anon_sym_LT_LT] = ACTIONS(5686),
    [anon_sym_GT_GT] = ACTIONS(5688),
    [anon_sym_GT_GT_GT] = ACTIONS(5686),
    [anon_sym_EQ_EQ] = ACTIONS(5686),
    [anon_sym_BANG_EQ] = ACTIONS(5686),
    [anon_sym_GT_EQ] = ACTIONS(5686),
    [anon_sym_LT_EQ] = ACTIONS(5686),
    [anon_sym_DOT] = ACTIONS(5688),
    [anon_sym_switch] = ACTIONS(5686),
    [anon_sym_DOT_DOT] = ACTIONS(5686),
    [anon_sym_and] = ACTIONS(5686),
    [anon_sym_or] = ACTIONS(5688),
    [anon_sym_AMP_AMP] = ACTIONS(5686),
    [anon_sym_PIPE_PIPE] = ACTIONS(5686),
    [anon_sym_QMARK_QMARK] = ACTIONS(5686),
    [anon_sym_from] = ACTIONS(5686),
    [anon_sym_into] = ACTIONS(5686),
    [anon_sym_join] = ACTIONS(5686),
    [anon_sym_let] = ACTIONS(5686),
    [anon_sym_orderby] = ACTIONS(5686),
    [anon_sym_ascending] = ACTIONS(5686),
    [anon_sym_descending] = ACTIONS(5686),
    [anon_sym_group] = ACTIONS(5686),
    [anon_sym_select] = ACTIONS(5686),
    [anon_sym_as] = ACTIONS(5688),
    [anon_sym_is] = ACTIONS(5686),
    [anon_sym_DASH_GT] = ACTIONS(5686),
    [anon_sym_with] = ACTIONS(5686),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4713] = {
    [sym_preproc_region] = STATE(4713),
    [sym_preproc_endregion] = STATE(4713),
    [sym_preproc_line] = STATE(4713),
    [sym_preproc_pragma] = STATE(4713),
    [sym_preproc_nullable] = STATE(4713),
    [sym_preproc_error] = STATE(4713),
    [sym_preproc_warning] = STATE(4713),
    [sym_preproc_define] = STATE(4713),
    [sym_preproc_undef] = STATE(4713),
    [anon_sym_LBRACK] = ACTIONS(5596),
    [anon_sym_COMMA] = ACTIONS(5596),
    [anon_sym_LPAREN] = ACTIONS(5596),
    [anon_sym_LT] = ACTIONS(5598),
    [anon_sym_GT] = ACTIONS(5598),
    [anon_sym_where] = ACTIONS(5596),
    [anon_sym_QMARK] = ACTIONS(5598),
    [anon_sym_BANG] = ACTIONS(5598),
    [anon_sym_PLUS_PLUS] = ACTIONS(5596),
    [anon_sym_DASH_DASH] = ACTIONS(5596),
    [anon_sym_PLUS] = ACTIONS(5598),
    [anon_sym_DASH] = ACTIONS(5598),
    [anon_sym_STAR] = ACTIONS(5596),
    [anon_sym_SLASH] = ACTIONS(5598),
    [anon_sym_PERCENT] = ACTIONS(5596),
    [anon_sym_CARET] = ACTIONS(5596),
    [anon_sym_PIPE] = ACTIONS(5598),
    [anon_sym_AMP] = ACTIONS(5598),
    [anon_sym_LT_LT] = ACTIONS(5596),
    [anon_sym_GT_GT] = ACTIONS(5598),
    [anon_sym_GT_GT_GT] = ACTIONS(5596),
    [anon_sym_EQ_EQ] = ACTIONS(5596),
    [anon_sym_BANG_EQ] = ACTIONS(5596),
    [anon_sym_GT_EQ] = ACTIONS(5596),
    [anon_sym_LT_EQ] = ACTIONS(5596),
    [anon_sym_DOT] = ACTIONS(5598),
    [anon_sym_switch] = ACTIONS(5596),
    [anon_sym_DOT_DOT] = ACTIONS(5596),
    [anon_sym_and] = ACTIONS(5596),
    [anon_sym_or] = ACTIONS(5598),
    [anon_sym_AMP_AMP] = ACTIONS(5596),
    [anon_sym_PIPE_PIPE] = ACTIONS(5596),
    [anon_sym_QMARK_QMARK] = ACTIONS(5596),
    [anon_sym_from] = ACTIONS(5596),
    [anon_sym_into] = ACTIONS(5596),
    [anon_sym_join] = ACTIONS(5596),
    [anon_sym_let] = ACTIONS(5596),
    [anon_sym_orderby] = ACTIONS(5596),
    [anon_sym_ascending] = ACTIONS(5596),
    [anon_sym_descending] = ACTIONS(5596),
    [anon_sym_group] = ACTIONS(5596),
    [anon_sym_select] = ACTIONS(5596),
    [anon_sym_as] = ACTIONS(5598),
    [anon_sym_is] = ACTIONS(5596),
    [anon_sym_DASH_GT] = ACTIONS(5596),
    [anon_sym_with] = ACTIONS(5596),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4714] = {
    [sym_preproc_region] = STATE(4714),
    [sym_preproc_endregion] = STATE(4714),
    [sym_preproc_line] = STATE(4714),
    [sym_preproc_pragma] = STATE(4714),
    [sym_preproc_nullable] = STATE(4714),
    [sym_preproc_error] = STATE(4714),
    [sym_preproc_warning] = STATE(4714),
    [sym_preproc_define] = STATE(4714),
    [sym_preproc_undef] = STATE(4714),
    [anon_sym_LBRACK] = ACTIONS(5660),
    [anon_sym_COMMA] = ACTIONS(5660),
    [anon_sym_LPAREN] = ACTIONS(5660),
    [anon_sym_LT] = ACTIONS(5662),
    [anon_sym_GT] = ACTIONS(5662),
    [anon_sym_where] = ACTIONS(5660),
    [anon_sym_QMARK] = ACTIONS(5662),
    [anon_sym_BANG] = ACTIONS(5662),
    [anon_sym_PLUS_PLUS] = ACTIONS(5660),
    [anon_sym_DASH_DASH] = ACTIONS(5660),
    [anon_sym_PLUS] = ACTIONS(5662),
    [anon_sym_DASH] = ACTIONS(5662),
    [anon_sym_STAR] = ACTIONS(5660),
    [anon_sym_SLASH] = ACTIONS(5662),
    [anon_sym_PERCENT] = ACTIONS(5660),
    [anon_sym_CARET] = ACTIONS(5660),
    [anon_sym_PIPE] = ACTIONS(5662),
    [anon_sym_AMP] = ACTIONS(5662),
    [anon_sym_LT_LT] = ACTIONS(5660),
    [anon_sym_GT_GT] = ACTIONS(5662),
    [anon_sym_GT_GT_GT] = ACTIONS(5660),
    [anon_sym_EQ_EQ] = ACTIONS(5660),
    [anon_sym_BANG_EQ] = ACTIONS(5660),
    [anon_sym_GT_EQ] = ACTIONS(5660),
    [anon_sym_LT_EQ] = ACTIONS(5660),
    [anon_sym_DOT] = ACTIONS(5662),
    [anon_sym_switch] = ACTIONS(5660),
    [anon_sym_DOT_DOT] = ACTIONS(5660),
    [anon_sym_and] = ACTIONS(5660),
    [anon_sym_or] = ACTIONS(5662),
    [anon_sym_AMP_AMP] = ACTIONS(5660),
    [anon_sym_PIPE_PIPE] = ACTIONS(5660),
    [anon_sym_QMARK_QMARK] = ACTIONS(5660),
    [anon_sym_from] = ACTIONS(5660),
    [anon_sym_into] = ACTIONS(5660),
    [anon_sym_join] = ACTIONS(5660),
    [anon_sym_let] = ACTIONS(5660),
    [anon_sym_orderby] = ACTIONS(5660),
    [anon_sym_ascending] = ACTIONS(5660),
    [anon_sym_descending] = ACTIONS(5660),
    [anon_sym_group] = ACTIONS(5660),
    [anon_sym_select] = ACTIONS(5660),
    [anon_sym_as] = ACTIONS(5662),
    [anon_sym_is] = ACTIONS(5660),
    [anon_sym_DASH_GT] = ACTIONS(5660),
    [anon_sym_with] = ACTIONS(5660),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4715] = {
    [sym_preproc_region] = STATE(4715),
    [sym_preproc_endregion] = STATE(4715),
    [sym_preproc_line] = STATE(4715),
    [sym_preproc_pragma] = STATE(4715),
    [sym_preproc_nullable] = STATE(4715),
    [sym_preproc_error] = STATE(4715),
    [sym_preproc_warning] = STATE(4715),
    [sym_preproc_define] = STATE(4715),
    [sym_preproc_undef] = STATE(4715),
    [sym__identifier_token] = ACTIONS(4042),
    [anon_sym_extern] = ACTIONS(4042),
    [anon_sym_alias] = ACTIONS(4042),
    [anon_sym_global] = ACTIONS(4042),
    [anon_sym_unsafe] = ACTIONS(4042),
    [anon_sym_static] = ACTIONS(4042),
    [anon_sym_LPAREN] = ACTIONS(6699),
    [anon_sym_ref] = ACTIONS(4042),
    [anon_sym_delegate] = ACTIONS(4042),
    [anon_sym_abstract] = ACTIONS(4042),
    [anon_sym_async] = ACTIONS(4042),
    [anon_sym_const] = ACTIONS(4042),
    [anon_sym_file] = ACTIONS(4042),
    [anon_sym_fixed] = ACTIONS(4042),
    [anon_sym_internal] = ACTIONS(4042),
    [anon_sym_new] = ACTIONS(4042),
    [anon_sym_override] = ACTIONS(4042),
    [anon_sym_partial] = ACTIONS(4042),
    [anon_sym_private] = ACTIONS(4042),
    [anon_sym_protected] = ACTIONS(4042),
    [anon_sym_public] = ACTIONS(4042),
    [anon_sym_readonly] = ACTIONS(4042),
    [anon_sym_required] = ACTIONS(4042),
    [anon_sym_sealed] = ACTIONS(4042),
    [anon_sym_virtual] = ACTIONS(4042),
    [anon_sym_volatile] = ACTIONS(4042),
    [anon_sym_where] = ACTIONS(4042),
    [anon_sym_notnull] = ACTIONS(4042),
    [anon_sym_unmanaged] = ACTIONS(4042),
    [anon_sym_scoped] = ACTIONS(4042),
    [anon_sym_var] = ACTIONS(4042),
    [sym_predefined_type] = ACTIONS(4042),
    [anon_sym_yield] = ACTIONS(4042),
    [anon_sym_when] = ACTIONS(4042),
    [anon_sym_from] = ACTIONS(4042),
    [anon_sym_into] = ACTIONS(4042),
    [anon_sym_join] = ACTIONS(4042),
    [anon_sym_on] = ACTIONS(4042),
    [anon_sym_equals] = ACTIONS(4042),
    [anon_sym_let] = ACTIONS(4042),
    [anon_sym_orderby] = ACTIONS(4042),
    [anon_sym_ascending] = ACTIONS(4042),
    [anon_sym_descending] = ACTIONS(4042),
    [anon_sym_group] = ACTIONS(4042),
    [anon_sym_by] = ACTIONS(4042),
    [anon_sym_select] = ACTIONS(4042),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4716] = {
    [sym__name] = STATE(5936),
    [sym_alias_qualified_name] = STATE(3680),
    [sym__simple_name] = STATE(3680),
    [sym_qualified_name] = STATE(3680),
    [sym_generic_name] = STATE(3648),
    [sym_type] = STATE(3731),
    [sym_implicit_type] = STATE(3707),
    [sym_array_type] = STATE(3725),
    [sym__array_base_type] = STATE(8829),
    [sym_nullable_type] = STATE(3681),
    [sym_pointer_type] = STATE(3681),
    [sym__pointer_base_type] = STATE(9538),
    [sym_function_pointer_type] = STATE(3681),
    [sym_ref_type] = STATE(3707),
    [sym_scoped_type] = STATE(3707),
    [sym_tuple_type] = STATE(3631),
    [sym_identifier] = STATE(5255),
    [sym__reserved_identifier] = STATE(3625),
    [sym_preproc_region] = STATE(4716),
    [sym_preproc_endregion] = STATE(4716),
    [sym_preproc_line] = STATE(4716),
    [sym_preproc_pragma] = STATE(4716),
    [sym_preproc_nullable] = STATE(4716),
    [sym_preproc_error] = STATE(4716),
    [sym_preproc_warning] = STATE(4716),
    [sym_preproc_define] = STATE(4716),
    [sym_preproc_undef] = STATE(4716),
    [sym__identifier_token] = ACTIONS(4349),
    [anon_sym_alias] = ACTIONS(4351),
    [anon_sym_global] = ACTIONS(4351),
    [anon_sym_LPAREN] = ACTIONS(6584),
    [anon_sym_ref] = ACTIONS(4528),
    [anon_sym_delegate] = ACTIONS(4512),
    [anon_sym_file] = ACTIONS(4351),
    [anon_sym_readonly] = ACTIONS(6701),
    [anon_sym_where] = ACTIONS(4351),
    [anon_sym_notnull] = ACTIONS(4351),
    [anon_sym_unmanaged] = ACTIONS(4351),
    [anon_sym_scoped] = ACTIONS(6340),
    [anon_sym_var] = ACTIONS(4516),
    [sym_predefined_type] = ACTIONS(4518),
    [anon_sym_yield] = ACTIONS(4351),
    [anon_sym_when] = ACTIONS(4351),
    [anon_sym_from] = ACTIONS(4351),
    [anon_sym_into] = ACTIONS(4351),
    [anon_sym_join] = ACTIONS(4351),
    [anon_sym_on] = ACTIONS(4351),
    [anon_sym_equals] = ACTIONS(4351),
    [anon_sym_let] = ACTIONS(4351),
    [anon_sym_orderby] = ACTIONS(4351),
    [anon_sym_ascending] = ACTIONS(4351),
    [anon_sym_descending] = ACTIONS(4351),
    [anon_sym_group] = ACTIONS(4351),
    [anon_sym_by] = ACTIONS(4351),
    [anon_sym_select] = ACTIONS(4351),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4717] = {
    [sym_preproc_region] = STATE(4717),
    [sym_preproc_endregion] = STATE(4717),
    [sym_preproc_line] = STATE(4717),
    [sym_preproc_pragma] = STATE(4717),
    [sym_preproc_nullable] = STATE(4717),
    [sym_preproc_error] = STATE(4717),
    [sym_preproc_warning] = STATE(4717),
    [sym_preproc_define] = STATE(4717),
    [sym_preproc_undef] = STATE(4717),
    [anon_sym_LBRACK] = ACTIONS(5412),
    [anon_sym_COMMA] = ACTIONS(5412),
    [anon_sym_LPAREN] = ACTIONS(5412),
    [anon_sym_LT] = ACTIONS(5414),
    [anon_sym_GT] = ACTIONS(5414),
    [anon_sym_where] = ACTIONS(5412),
    [anon_sym_QMARK] = ACTIONS(5414),
    [anon_sym_BANG] = ACTIONS(5414),
    [anon_sym_PLUS_PLUS] = ACTIONS(5412),
    [anon_sym_DASH_DASH] = ACTIONS(5412),
    [anon_sym_PLUS] = ACTIONS(5414),
    [anon_sym_DASH] = ACTIONS(5414),
    [anon_sym_STAR] = ACTIONS(5412),
    [anon_sym_SLASH] = ACTIONS(5414),
    [anon_sym_PERCENT] = ACTIONS(5412),
    [anon_sym_CARET] = ACTIONS(5412),
    [anon_sym_PIPE] = ACTIONS(5414),
    [anon_sym_AMP] = ACTIONS(5414),
    [anon_sym_LT_LT] = ACTIONS(5412),
    [anon_sym_GT_GT] = ACTIONS(5414),
    [anon_sym_GT_GT_GT] = ACTIONS(5412),
    [anon_sym_EQ_EQ] = ACTIONS(5412),
    [anon_sym_BANG_EQ] = ACTIONS(5412),
    [anon_sym_GT_EQ] = ACTIONS(5412),
    [anon_sym_LT_EQ] = ACTIONS(5412),
    [anon_sym_DOT] = ACTIONS(5414),
    [anon_sym_switch] = ACTIONS(5412),
    [anon_sym_DOT_DOT] = ACTIONS(5412),
    [anon_sym_and] = ACTIONS(5412),
    [anon_sym_or] = ACTIONS(5414),
    [anon_sym_AMP_AMP] = ACTIONS(5412),
    [anon_sym_PIPE_PIPE] = ACTIONS(5412),
    [anon_sym_QMARK_QMARK] = ACTIONS(5412),
    [anon_sym_from] = ACTIONS(5412),
    [anon_sym_into] = ACTIONS(5412),
    [anon_sym_join] = ACTIONS(5412),
    [anon_sym_let] = ACTIONS(5412),
    [anon_sym_orderby] = ACTIONS(5412),
    [anon_sym_ascending] = ACTIONS(5412),
    [anon_sym_descending] = ACTIONS(5412),
    [anon_sym_group] = ACTIONS(5412),
    [anon_sym_select] = ACTIONS(5412),
    [anon_sym_as] = ACTIONS(5414),
    [anon_sym_is] = ACTIONS(5412),
    [anon_sym_DASH_GT] = ACTIONS(5412),
    [anon_sym_with] = ACTIONS(5412),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4718] = {
    [sym__name] = STATE(3217),
    [sym_alias_qualified_name] = STATE(2956),
    [sym__simple_name] = STATE(2956),
    [sym_qualified_name] = STATE(2956),
    [sym_generic_name] = STATE(2944),
    [sym_type] = STATE(2978),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(2966),
    [sym__array_base_type] = STATE(8753),
    [sym_nullable_type] = STATE(2970),
    [sym_pointer_type] = STATE(2970),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(2970),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(2971),
    [sym_identifier] = STATE(3123),
    [sym__reserved_identifier] = STATE(2928),
    [sym_preproc_region] = STATE(4718),
    [sym_preproc_endregion] = STATE(4718),
    [sym_preproc_line] = STATE(4718),
    [sym_preproc_pragma] = STATE(4718),
    [sym_preproc_nullable] = STATE(4718),
    [sym_preproc_error] = STATE(4718),
    [sym_preproc_warning] = STATE(4718),
    [sym_preproc_define] = STATE(4718),
    [sym_preproc_undef] = STATE(4718),
    [sym__identifier_token] = ACTIONS(4536),
    [anon_sym_alias] = ACTIONS(4538),
    [anon_sym_global] = ACTIONS(4538),
    [anon_sym_LPAREN] = ACTIONS(6602),
    [anon_sym_ref] = ACTIONS(4102),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_file] = ACTIONS(4538),
    [anon_sym_readonly] = ACTIONS(2841),
    [anon_sym_where] = ACTIONS(4538),
    [anon_sym_notnull] = ACTIONS(4538),
    [anon_sym_unmanaged] = ACTIONS(4538),
    [anon_sym_scoped] = ACTIONS(6703),
    [anon_sym_var] = ACTIONS(6246),
    [sym_predefined_type] = ACTIONS(6248),
    [anon_sym_yield] = ACTIONS(4538),
    [anon_sym_when] = ACTIONS(4538),
    [anon_sym_from] = ACTIONS(4538),
    [anon_sym_into] = ACTIONS(4538),
    [anon_sym_join] = ACTIONS(4538),
    [anon_sym_on] = ACTIONS(4538),
    [anon_sym_equals] = ACTIONS(4538),
    [anon_sym_let] = ACTIONS(4538),
    [anon_sym_orderby] = ACTIONS(4538),
    [anon_sym_ascending] = ACTIONS(4538),
    [anon_sym_descending] = ACTIONS(4538),
    [anon_sym_group] = ACTIONS(4538),
    [anon_sym_by] = ACTIONS(4538),
    [anon_sym_select] = ACTIONS(4538),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4719] = {
    [sym_preproc_region] = STATE(4719),
    [sym_preproc_endregion] = STATE(4719),
    [sym_preproc_line] = STATE(4719),
    [sym_preproc_pragma] = STATE(4719),
    [sym_preproc_nullable] = STATE(4719),
    [sym_preproc_error] = STATE(4719),
    [sym_preproc_warning] = STATE(4719),
    [sym_preproc_define] = STATE(4719),
    [sym_preproc_undef] = STATE(4719),
    [anon_sym_LBRACK] = ACTIONS(5424),
    [anon_sym_COMMA] = ACTIONS(5424),
    [anon_sym_LPAREN] = ACTIONS(5424),
    [anon_sym_LT] = ACTIONS(5426),
    [anon_sym_GT] = ACTIONS(5426),
    [anon_sym_where] = ACTIONS(5424),
    [anon_sym_QMARK] = ACTIONS(5426),
    [anon_sym_BANG] = ACTIONS(5426),
    [anon_sym_PLUS_PLUS] = ACTIONS(5424),
    [anon_sym_DASH_DASH] = ACTIONS(5424),
    [anon_sym_PLUS] = ACTIONS(5426),
    [anon_sym_DASH] = ACTIONS(5426),
    [anon_sym_STAR] = ACTIONS(5424),
    [anon_sym_SLASH] = ACTIONS(5426),
    [anon_sym_PERCENT] = ACTIONS(5424),
    [anon_sym_CARET] = ACTIONS(5424),
    [anon_sym_PIPE] = ACTIONS(5426),
    [anon_sym_AMP] = ACTIONS(5426),
    [anon_sym_LT_LT] = ACTIONS(5424),
    [anon_sym_GT_GT] = ACTIONS(5426),
    [anon_sym_GT_GT_GT] = ACTIONS(5424),
    [anon_sym_EQ_EQ] = ACTIONS(5424),
    [anon_sym_BANG_EQ] = ACTIONS(5424),
    [anon_sym_GT_EQ] = ACTIONS(5424),
    [anon_sym_LT_EQ] = ACTIONS(5424),
    [anon_sym_DOT] = ACTIONS(5426),
    [anon_sym_switch] = ACTIONS(5424),
    [anon_sym_DOT_DOT] = ACTIONS(5424),
    [anon_sym_and] = ACTIONS(5424),
    [anon_sym_or] = ACTIONS(5426),
    [anon_sym_AMP_AMP] = ACTIONS(5424),
    [anon_sym_PIPE_PIPE] = ACTIONS(5424),
    [anon_sym_QMARK_QMARK] = ACTIONS(5424),
    [anon_sym_from] = ACTIONS(5424),
    [anon_sym_into] = ACTIONS(5424),
    [anon_sym_join] = ACTIONS(5424),
    [anon_sym_let] = ACTIONS(5424),
    [anon_sym_orderby] = ACTIONS(5424),
    [anon_sym_ascending] = ACTIONS(5424),
    [anon_sym_descending] = ACTIONS(5424),
    [anon_sym_group] = ACTIONS(5424),
    [anon_sym_select] = ACTIONS(5424),
    [anon_sym_as] = ACTIONS(5426),
    [anon_sym_is] = ACTIONS(5424),
    [anon_sym_DASH_GT] = ACTIONS(5424),
    [anon_sym_with] = ACTIONS(5424),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4720] = {
    [sym_preproc_region] = STATE(4720),
    [sym_preproc_endregion] = STATE(4720),
    [sym_preproc_line] = STATE(4720),
    [sym_preproc_pragma] = STATE(4720),
    [sym_preproc_nullable] = STATE(4720),
    [sym_preproc_error] = STATE(4720),
    [sym_preproc_warning] = STATE(4720),
    [sym_preproc_define] = STATE(4720),
    [sym_preproc_undef] = STATE(4720),
    [anon_sym_LBRACK] = ACTIONS(6705),
    [anon_sym_COMMA] = ACTIONS(6705),
    [anon_sym_LPAREN] = ACTIONS(6705),
    [anon_sym_LT] = ACTIONS(6707),
    [anon_sym_GT] = ACTIONS(6707),
    [anon_sym_where] = ACTIONS(6705),
    [anon_sym_QMARK] = ACTIONS(6707),
    [anon_sym_BANG] = ACTIONS(6707),
    [anon_sym_PLUS_PLUS] = ACTIONS(6705),
    [anon_sym_DASH_DASH] = ACTIONS(6705),
    [anon_sym_PLUS] = ACTIONS(6707),
    [anon_sym_DASH] = ACTIONS(6707),
    [anon_sym_STAR] = ACTIONS(6705),
    [anon_sym_SLASH] = ACTIONS(6707),
    [anon_sym_PERCENT] = ACTIONS(6705),
    [anon_sym_CARET] = ACTIONS(6705),
    [anon_sym_PIPE] = ACTIONS(6707),
    [anon_sym_AMP] = ACTIONS(6707),
    [anon_sym_LT_LT] = ACTIONS(6705),
    [anon_sym_GT_GT] = ACTIONS(6707),
    [anon_sym_GT_GT_GT] = ACTIONS(6705),
    [anon_sym_EQ_EQ] = ACTIONS(6705),
    [anon_sym_BANG_EQ] = ACTIONS(6705),
    [anon_sym_GT_EQ] = ACTIONS(6705),
    [anon_sym_LT_EQ] = ACTIONS(6705),
    [anon_sym_DOT] = ACTIONS(6707),
    [anon_sym_switch] = ACTIONS(6705),
    [anon_sym_DOT_DOT] = ACTIONS(6705),
    [anon_sym_and] = ACTIONS(6588),
    [anon_sym_or] = ACTIONS(6707),
    [anon_sym_AMP_AMP] = ACTIONS(6705),
    [anon_sym_PIPE_PIPE] = ACTIONS(6705),
    [anon_sym_QMARK_QMARK] = ACTIONS(6705),
    [anon_sym_from] = ACTIONS(6705),
    [anon_sym_into] = ACTIONS(6705),
    [anon_sym_join] = ACTIONS(6705),
    [anon_sym_let] = ACTIONS(6705),
    [anon_sym_orderby] = ACTIONS(6705),
    [anon_sym_ascending] = ACTIONS(6705),
    [anon_sym_descending] = ACTIONS(6705),
    [anon_sym_group] = ACTIONS(6705),
    [anon_sym_select] = ACTIONS(6705),
    [anon_sym_as] = ACTIONS(6707),
    [anon_sym_is] = ACTIONS(6705),
    [anon_sym_DASH_GT] = ACTIONS(6705),
    [anon_sym_with] = ACTIONS(6705),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4721] = {
    [sym_preproc_region] = STATE(4721),
    [sym_preproc_endregion] = STATE(4721),
    [sym_preproc_line] = STATE(4721),
    [sym_preproc_pragma] = STATE(4721),
    [sym_preproc_nullable] = STATE(4721),
    [sym_preproc_error] = STATE(4721),
    [sym_preproc_warning] = STATE(4721),
    [sym_preproc_define] = STATE(4721),
    [sym_preproc_undef] = STATE(4721),
    [anon_sym_LBRACK] = ACTIONS(5452),
    [anon_sym_COMMA] = ACTIONS(5452),
    [anon_sym_LPAREN] = ACTIONS(5452),
    [anon_sym_LT] = ACTIONS(5454),
    [anon_sym_GT] = ACTIONS(5454),
    [anon_sym_where] = ACTIONS(5452),
    [anon_sym_QMARK] = ACTIONS(5454),
    [anon_sym_BANG] = ACTIONS(5454),
    [anon_sym_PLUS_PLUS] = ACTIONS(5452),
    [anon_sym_DASH_DASH] = ACTIONS(5452),
    [anon_sym_PLUS] = ACTIONS(5454),
    [anon_sym_DASH] = ACTIONS(5454),
    [anon_sym_STAR] = ACTIONS(5452),
    [anon_sym_SLASH] = ACTIONS(5454),
    [anon_sym_PERCENT] = ACTIONS(5452),
    [anon_sym_CARET] = ACTIONS(5452),
    [anon_sym_PIPE] = ACTIONS(5454),
    [anon_sym_AMP] = ACTIONS(5454),
    [anon_sym_LT_LT] = ACTIONS(5452),
    [anon_sym_GT_GT] = ACTIONS(5454),
    [anon_sym_GT_GT_GT] = ACTIONS(5452),
    [anon_sym_EQ_EQ] = ACTIONS(5452),
    [anon_sym_BANG_EQ] = ACTIONS(5452),
    [anon_sym_GT_EQ] = ACTIONS(5452),
    [anon_sym_LT_EQ] = ACTIONS(5452),
    [anon_sym_DOT] = ACTIONS(5454),
    [anon_sym_switch] = ACTIONS(5452),
    [anon_sym_DOT_DOT] = ACTIONS(5452),
    [anon_sym_and] = ACTIONS(5452),
    [anon_sym_or] = ACTIONS(5454),
    [anon_sym_AMP_AMP] = ACTIONS(5452),
    [anon_sym_PIPE_PIPE] = ACTIONS(5452),
    [anon_sym_QMARK_QMARK] = ACTIONS(5452),
    [anon_sym_from] = ACTIONS(5452),
    [anon_sym_into] = ACTIONS(5452),
    [anon_sym_join] = ACTIONS(5452),
    [anon_sym_let] = ACTIONS(5452),
    [anon_sym_orderby] = ACTIONS(5452),
    [anon_sym_ascending] = ACTIONS(5452),
    [anon_sym_descending] = ACTIONS(5452),
    [anon_sym_group] = ACTIONS(5452),
    [anon_sym_select] = ACTIONS(5452),
    [anon_sym_as] = ACTIONS(5454),
    [anon_sym_is] = ACTIONS(5452),
    [anon_sym_DASH_GT] = ACTIONS(5452),
    [anon_sym_with] = ACTIONS(5452),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4722] = {
    [sym_preproc_region] = STATE(4722),
    [sym_preproc_endregion] = STATE(4722),
    [sym_preproc_line] = STATE(4722),
    [sym_preproc_pragma] = STATE(4722),
    [sym_preproc_nullable] = STATE(4722),
    [sym_preproc_error] = STATE(4722),
    [sym_preproc_warning] = STATE(4722),
    [sym_preproc_define] = STATE(4722),
    [sym_preproc_undef] = STATE(4722),
    [anon_sym_LBRACK] = ACTIONS(2993),
    [anon_sym_COMMA] = ACTIONS(2993),
    [anon_sym_LPAREN] = ACTIONS(2993),
    [anon_sym_LT] = ACTIONS(2991),
    [anon_sym_GT] = ACTIONS(2991),
    [anon_sym_where] = ACTIONS(2993),
    [anon_sym_QMARK] = ACTIONS(2991),
    [anon_sym_BANG] = ACTIONS(2991),
    [anon_sym_PLUS_PLUS] = ACTIONS(2993),
    [anon_sym_DASH_DASH] = ACTIONS(2993),
    [anon_sym_PLUS] = ACTIONS(2991),
    [anon_sym_DASH] = ACTIONS(2991),
    [anon_sym_STAR] = ACTIONS(2993),
    [anon_sym_SLASH] = ACTIONS(2991),
    [anon_sym_PERCENT] = ACTIONS(2993),
    [anon_sym_CARET] = ACTIONS(2993),
    [anon_sym_PIPE] = ACTIONS(2991),
    [anon_sym_AMP] = ACTIONS(2991),
    [anon_sym_LT_LT] = ACTIONS(2993),
    [anon_sym_GT_GT] = ACTIONS(2991),
    [anon_sym_GT_GT_GT] = ACTIONS(2993),
    [anon_sym_EQ_EQ] = ACTIONS(2993),
    [anon_sym_BANG_EQ] = ACTIONS(2993),
    [anon_sym_GT_EQ] = ACTIONS(2993),
    [anon_sym_LT_EQ] = ACTIONS(2993),
    [anon_sym_DOT] = ACTIONS(2991),
    [anon_sym_switch] = ACTIONS(2993),
    [anon_sym_DOT_DOT] = ACTIONS(2993),
    [anon_sym_and] = ACTIONS(2993),
    [anon_sym_or] = ACTIONS(2991),
    [anon_sym_AMP_AMP] = ACTIONS(2993),
    [anon_sym_PIPE_PIPE] = ACTIONS(2993),
    [anon_sym_QMARK_QMARK] = ACTIONS(2993),
    [anon_sym_from] = ACTIONS(2993),
    [anon_sym_into] = ACTIONS(2993),
    [anon_sym_join] = ACTIONS(2993),
    [anon_sym_let] = ACTIONS(2993),
    [anon_sym_orderby] = ACTIONS(2993),
    [anon_sym_ascending] = ACTIONS(2993),
    [anon_sym_descending] = ACTIONS(2993),
    [anon_sym_group] = ACTIONS(2993),
    [anon_sym_select] = ACTIONS(2993),
    [anon_sym_as] = ACTIONS(2991),
    [anon_sym_is] = ACTIONS(2993),
    [anon_sym_DASH_GT] = ACTIONS(2993),
    [anon_sym_with] = ACTIONS(2993),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4723] = {
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(8951),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4723),
    [sym_preproc_endregion] = STATE(4723),
    [sym_preproc_line] = STATE(4723),
    [sym_preproc_pragma] = STATE(4723),
    [sym_preproc_nullable] = STATE(4723),
    [sym_preproc_error] = STATE(4723),
    [sym_preproc_warning] = STATE(4723),
    [sym_preproc_define] = STATE(4723),
    [sym_preproc_undef] = STATE(4723),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(6608),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_checked] = ACTIONS(6709),
    [anon_sym_scoped] = ACTIONS(6612),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4724] = {
    [sym_preproc_region] = STATE(4724),
    [sym_preproc_endregion] = STATE(4724),
    [sym_preproc_line] = STATE(4724),
    [sym_preproc_pragma] = STATE(4724),
    [sym_preproc_nullable] = STATE(4724),
    [sym_preproc_error] = STATE(4724),
    [sym_preproc_warning] = STATE(4724),
    [sym_preproc_define] = STATE(4724),
    [sym_preproc_undef] = STATE(4724),
    [anon_sym_LBRACK] = ACTIONS(5960),
    [anon_sym_COMMA] = ACTIONS(5960),
    [anon_sym_LPAREN] = ACTIONS(5960),
    [anon_sym_LT] = ACTIONS(5962),
    [anon_sym_GT] = ACTIONS(5962),
    [anon_sym_where] = ACTIONS(5960),
    [anon_sym_QMARK] = ACTIONS(5962),
    [anon_sym_BANG] = ACTIONS(5962),
    [anon_sym_PLUS_PLUS] = ACTIONS(5960),
    [anon_sym_DASH_DASH] = ACTIONS(5960),
    [anon_sym_PLUS] = ACTIONS(5962),
    [anon_sym_DASH] = ACTIONS(5962),
    [anon_sym_STAR] = ACTIONS(5960),
    [anon_sym_SLASH] = ACTIONS(5962),
    [anon_sym_PERCENT] = ACTIONS(5960),
    [anon_sym_CARET] = ACTIONS(5960),
    [anon_sym_PIPE] = ACTIONS(5962),
    [anon_sym_AMP] = ACTIONS(5962),
    [anon_sym_LT_LT] = ACTIONS(5960),
    [anon_sym_GT_GT] = ACTIONS(5962),
    [anon_sym_GT_GT_GT] = ACTIONS(5960),
    [anon_sym_EQ_EQ] = ACTIONS(5960),
    [anon_sym_BANG_EQ] = ACTIONS(5960),
    [anon_sym_GT_EQ] = ACTIONS(5960),
    [anon_sym_LT_EQ] = ACTIONS(5960),
    [anon_sym_DOT] = ACTIONS(5962),
    [anon_sym_switch] = ACTIONS(5960),
    [anon_sym_DOT_DOT] = ACTIONS(5960),
    [anon_sym_and] = ACTIONS(5960),
    [anon_sym_or] = ACTIONS(5962),
    [anon_sym_AMP_AMP] = ACTIONS(5960),
    [anon_sym_PIPE_PIPE] = ACTIONS(5960),
    [anon_sym_QMARK_QMARK] = ACTIONS(5960),
    [anon_sym_from] = ACTIONS(5960),
    [anon_sym_into] = ACTIONS(5960),
    [anon_sym_join] = ACTIONS(5960),
    [anon_sym_let] = ACTIONS(5960),
    [anon_sym_orderby] = ACTIONS(5960),
    [anon_sym_ascending] = ACTIONS(5960),
    [anon_sym_descending] = ACTIONS(5960),
    [anon_sym_group] = ACTIONS(5960),
    [anon_sym_select] = ACTIONS(5960),
    [anon_sym_as] = ACTIONS(5962),
    [anon_sym_is] = ACTIONS(5960),
    [anon_sym_DASH_GT] = ACTIONS(5960),
    [anon_sym_with] = ACTIONS(5960),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4725] = {
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7359),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym__join_header] = STATE(8758),
    [sym_identifier] = STATE(6813),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4725),
    [sym_preproc_endregion] = STATE(4725),
    [sym_preproc_line] = STATE(4725),
    [sym_preproc_pragma] = STATE(4725),
    [sym_preproc_nullable] = STATE(4725),
    [sym_preproc_error] = STATE(4725),
    [sym_preproc_warning] = STATE(4725),
    [sym_preproc_define] = STATE(4725),
    [sym_preproc_undef] = STATE(4725),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4726] = {
    [sym_preproc_region] = STATE(4726),
    [sym_preproc_endregion] = STATE(4726),
    [sym_preproc_line] = STATE(4726),
    [sym_preproc_pragma] = STATE(4726),
    [sym_preproc_nullable] = STATE(4726),
    [sym_preproc_error] = STATE(4726),
    [sym_preproc_warning] = STATE(4726),
    [sym_preproc_define] = STATE(4726),
    [sym_preproc_undef] = STATE(4726),
    [anon_sym_LBRACK] = ACTIONS(5480),
    [anon_sym_COMMA] = ACTIONS(5480),
    [anon_sym_LPAREN] = ACTIONS(5480),
    [anon_sym_LT] = ACTIONS(5482),
    [anon_sym_GT] = ACTIONS(5482),
    [anon_sym_where] = ACTIONS(5480),
    [anon_sym_QMARK] = ACTIONS(5482),
    [anon_sym_BANG] = ACTIONS(5482),
    [anon_sym_PLUS_PLUS] = ACTIONS(5480),
    [anon_sym_DASH_DASH] = ACTIONS(5480),
    [anon_sym_PLUS] = ACTIONS(5482),
    [anon_sym_DASH] = ACTIONS(5482),
    [anon_sym_STAR] = ACTIONS(5480),
    [anon_sym_SLASH] = ACTIONS(5482),
    [anon_sym_PERCENT] = ACTIONS(5480),
    [anon_sym_CARET] = ACTIONS(5480),
    [anon_sym_PIPE] = ACTIONS(5482),
    [anon_sym_AMP] = ACTIONS(5482),
    [anon_sym_LT_LT] = ACTIONS(5480),
    [anon_sym_GT_GT] = ACTIONS(5482),
    [anon_sym_GT_GT_GT] = ACTIONS(5480),
    [anon_sym_EQ_EQ] = ACTIONS(5480),
    [anon_sym_BANG_EQ] = ACTIONS(5480),
    [anon_sym_GT_EQ] = ACTIONS(5480),
    [anon_sym_LT_EQ] = ACTIONS(5480),
    [anon_sym_DOT] = ACTIONS(5482),
    [anon_sym_switch] = ACTIONS(5480),
    [anon_sym_DOT_DOT] = ACTIONS(5480),
    [anon_sym_and] = ACTIONS(5480),
    [anon_sym_or] = ACTIONS(5482),
    [anon_sym_AMP_AMP] = ACTIONS(5480),
    [anon_sym_PIPE_PIPE] = ACTIONS(5480),
    [anon_sym_QMARK_QMARK] = ACTIONS(5480),
    [anon_sym_from] = ACTIONS(5480),
    [anon_sym_into] = ACTIONS(5480),
    [anon_sym_join] = ACTIONS(5480),
    [anon_sym_let] = ACTIONS(5480),
    [anon_sym_orderby] = ACTIONS(5480),
    [anon_sym_ascending] = ACTIONS(5480),
    [anon_sym_descending] = ACTIONS(5480),
    [anon_sym_group] = ACTIONS(5480),
    [anon_sym_select] = ACTIONS(5480),
    [anon_sym_as] = ACTIONS(5482),
    [anon_sym_is] = ACTIONS(5480),
    [anon_sym_DASH_GT] = ACTIONS(5480),
    [anon_sym_with] = ACTIONS(5480),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4727] = {
    [sym__name] = STATE(6202),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(2749),
    [sym_ref_type] = STATE(2883),
    [sym__scoped_base_type] = STATE(2885),
    [sym_identifier] = STATE(5346),
    [sym__reserved_identifier] = STATE(2744),
    [sym_preproc_region] = STATE(4727),
    [sym_preproc_endregion] = STATE(4727),
    [sym_preproc_line] = STATE(4727),
    [sym_preproc_pragma] = STATE(4727),
    [sym_preproc_nullable] = STATE(4727),
    [sym_preproc_error] = STATE(4727),
    [sym_preproc_warning] = STATE(4727),
    [sym_preproc_define] = STATE(4727),
    [sym_preproc_undef] = STATE(4727),
    [sym__identifier_token] = ACTIONS(4072),
    [anon_sym_alias] = ACTIONS(4075),
    [anon_sym_global] = ACTIONS(4075),
    [anon_sym_LBRACK] = ACTIONS(3993),
    [anon_sym_COMMA] = ACTIONS(3993),
    [anon_sym_LPAREN] = ACTIONS(3993),
    [anon_sym_RPAREN] = ACTIONS(3993),
    [anon_sym_ref] = ACTIONS(4112),
    [anon_sym_LBRACE] = ACTIONS(3993),
    [anon_sym_file] = ACTIONS(4075),
    [anon_sym_LT] = ACTIONS(3993),
    [anon_sym_where] = ACTIONS(4075),
    [anon_sym_QMARK] = ACTIONS(3993),
    [anon_sym_notnull] = ACTIONS(4075),
    [anon_sym_unmanaged] = ACTIONS(4075),
    [anon_sym_STAR] = ACTIONS(3993),
    [anon_sym_DOT] = ACTIONS(3993),
    [anon_sym_scoped] = ACTIONS(4075),
    [anon_sym_COLON_COLON] = ACTIONS(3993),
    [anon_sym_var] = ACTIONS(4075),
    [anon_sym_yield] = ACTIONS(4075),
    [anon_sym_when] = ACTIONS(4075),
    [sym_discard] = ACTIONS(3995),
    [anon_sym_and] = ACTIONS(3995),
    [anon_sym_or] = ACTIONS(3995),
    [anon_sym_from] = ACTIONS(4075),
    [anon_sym_into] = ACTIONS(4075),
    [anon_sym_join] = ACTIONS(4075),
    [anon_sym_on] = ACTIONS(4075),
    [anon_sym_equals] = ACTIONS(4075),
    [anon_sym_let] = ACTIONS(4075),
    [anon_sym_orderby] = ACTIONS(4075),
    [anon_sym_ascending] = ACTIONS(4075),
    [anon_sym_descending] = ACTIONS(4075),
    [anon_sym_group] = ACTIONS(4075),
    [anon_sym_by] = ACTIONS(4075),
    [anon_sym_select] = ACTIONS(4075),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4728] = {
    [sym__name] = STATE(3904),
    [sym_alias_qualified_name] = STATE(3924),
    [sym__simple_name] = STATE(3924),
    [sym_qualified_name] = STATE(3924),
    [sym_generic_name] = STATE(3900),
    [sym_type] = STATE(3929),
    [sym_implicit_type] = STATE(3943),
    [sym_array_type] = STATE(3945),
    [sym__array_base_type] = STATE(8893),
    [sym_nullable_type] = STATE(3885),
    [sym_pointer_type] = STATE(3885),
    [sym__pointer_base_type] = STATE(9659),
    [sym_function_pointer_type] = STATE(3885),
    [sym_ref_type] = STATE(3943),
    [sym_scoped_type] = STATE(3943),
    [sym_tuple_type] = STATE(3880),
    [sym_identifier] = STATE(3808),
    [sym__reserved_identifier] = STATE(3871),
    [sym_preproc_region] = STATE(4728),
    [sym_preproc_endregion] = STATE(4728),
    [sym_preproc_line] = STATE(4728),
    [sym_preproc_pragma] = STATE(4728),
    [sym_preproc_nullable] = STATE(4728),
    [sym_preproc_error] = STATE(4728),
    [sym_preproc_warning] = STATE(4728),
    [sym_preproc_define] = STATE(4728),
    [sym_preproc_undef] = STATE(4728),
    [sym__identifier_token] = ACTIONS(4223),
    [anon_sym_alias] = ACTIONS(4225),
    [anon_sym_global] = ACTIONS(4225),
    [anon_sym_LPAREN] = ACTIONS(6624),
    [anon_sym_ref] = ACTIONS(4227),
    [anon_sym_delegate] = ACTIONS(6182),
    [anon_sym_file] = ACTIONS(4225),
    [anon_sym_readonly] = ACTIONS(6711),
    [anon_sym_where] = ACTIONS(4225),
    [anon_sym_notnull] = ACTIONS(4225),
    [anon_sym_unmanaged] = ACTIONS(4225),
    [anon_sym_scoped] = ACTIONS(6184),
    [anon_sym_var] = ACTIONS(6186),
    [sym_predefined_type] = ACTIONS(6188),
    [anon_sym_yield] = ACTIONS(4225),
    [anon_sym_when] = ACTIONS(4225),
    [anon_sym_from] = ACTIONS(4225),
    [anon_sym_into] = ACTIONS(4225),
    [anon_sym_join] = ACTIONS(4225),
    [anon_sym_on] = ACTIONS(4225),
    [anon_sym_equals] = ACTIONS(4225),
    [anon_sym_let] = ACTIONS(4225),
    [anon_sym_orderby] = ACTIONS(4225),
    [anon_sym_ascending] = ACTIONS(4225),
    [anon_sym_descending] = ACTIONS(4225),
    [anon_sym_group] = ACTIONS(4225),
    [anon_sym_by] = ACTIONS(4225),
    [anon_sym_select] = ACTIONS(4225),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4729] = {
    [sym_preproc_region] = STATE(4729),
    [sym_preproc_endregion] = STATE(4729),
    [sym_preproc_line] = STATE(4729),
    [sym_preproc_pragma] = STATE(4729),
    [sym_preproc_nullable] = STATE(4729),
    [sym_preproc_error] = STATE(4729),
    [sym_preproc_warning] = STATE(4729),
    [sym_preproc_define] = STATE(4729),
    [sym_preproc_undef] = STATE(4729),
    [sym__identifier_token] = ACTIONS(4042),
    [anon_sym_extern] = ACTIONS(4042),
    [anon_sym_alias] = ACTIONS(4042),
    [anon_sym_global] = ACTIONS(4042),
    [anon_sym_unsafe] = ACTIONS(4042),
    [anon_sym_static] = ACTIONS(4042),
    [anon_sym_LPAREN] = ACTIONS(5907),
    [anon_sym_ref] = ACTIONS(4042),
    [anon_sym_delegate] = ACTIONS(4042),
    [anon_sym_abstract] = ACTIONS(4042),
    [anon_sym_async] = ACTIONS(4042),
    [anon_sym_const] = ACTIONS(4042),
    [anon_sym_file] = ACTIONS(4042),
    [anon_sym_fixed] = ACTIONS(4042),
    [anon_sym_internal] = ACTIONS(4042),
    [anon_sym_new] = ACTIONS(4042),
    [anon_sym_override] = ACTIONS(4042),
    [anon_sym_partial] = ACTIONS(4042),
    [anon_sym_private] = ACTIONS(4042),
    [anon_sym_protected] = ACTIONS(4042),
    [anon_sym_public] = ACTIONS(4042),
    [anon_sym_readonly] = ACTIONS(4042),
    [anon_sym_required] = ACTIONS(4042),
    [anon_sym_sealed] = ACTIONS(4042),
    [anon_sym_virtual] = ACTIONS(4042),
    [anon_sym_volatile] = ACTIONS(4042),
    [anon_sym_where] = ACTIONS(4042),
    [anon_sym_notnull] = ACTIONS(4042),
    [anon_sym_unmanaged] = ACTIONS(4042),
    [anon_sym_scoped] = ACTIONS(4042),
    [anon_sym_var] = ACTIONS(4042),
    [sym_predefined_type] = ACTIONS(4042),
    [anon_sym_yield] = ACTIONS(4042),
    [anon_sym_when] = ACTIONS(4042),
    [anon_sym_from] = ACTIONS(4042),
    [anon_sym_into] = ACTIONS(4042),
    [anon_sym_join] = ACTIONS(4042),
    [anon_sym_on] = ACTIONS(4042),
    [anon_sym_equals] = ACTIONS(4042),
    [anon_sym_let] = ACTIONS(4042),
    [anon_sym_orderby] = ACTIONS(4042),
    [anon_sym_ascending] = ACTIONS(4042),
    [anon_sym_descending] = ACTIONS(4042),
    [anon_sym_group] = ACTIONS(4042),
    [anon_sym_by] = ACTIONS(4042),
    [anon_sym_select] = ACTIONS(4042),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4730] = {
    [sym_preproc_region] = STATE(4730),
    [sym_preproc_endregion] = STATE(4730),
    [sym_preproc_line] = STATE(4730),
    [sym_preproc_pragma] = STATE(4730),
    [sym_preproc_nullable] = STATE(4730),
    [sym_preproc_error] = STATE(4730),
    [sym_preproc_warning] = STATE(4730),
    [sym_preproc_define] = STATE(4730),
    [sym_preproc_undef] = STATE(4730),
    [anon_sym_LBRACK] = ACTIONS(5476),
    [anon_sym_COMMA] = ACTIONS(5476),
    [anon_sym_LPAREN] = ACTIONS(5476),
    [anon_sym_LT] = ACTIONS(5478),
    [anon_sym_GT] = ACTIONS(5478),
    [anon_sym_where] = ACTIONS(5476),
    [anon_sym_QMARK] = ACTIONS(5478),
    [anon_sym_BANG] = ACTIONS(5478),
    [anon_sym_PLUS_PLUS] = ACTIONS(5476),
    [anon_sym_DASH_DASH] = ACTIONS(5476),
    [anon_sym_PLUS] = ACTIONS(5478),
    [anon_sym_DASH] = ACTIONS(5478),
    [anon_sym_STAR] = ACTIONS(5476),
    [anon_sym_SLASH] = ACTIONS(5478),
    [anon_sym_PERCENT] = ACTIONS(5476),
    [anon_sym_CARET] = ACTIONS(5476),
    [anon_sym_PIPE] = ACTIONS(5478),
    [anon_sym_AMP] = ACTIONS(5478),
    [anon_sym_LT_LT] = ACTIONS(5476),
    [anon_sym_GT_GT] = ACTIONS(5478),
    [anon_sym_GT_GT_GT] = ACTIONS(5476),
    [anon_sym_EQ_EQ] = ACTIONS(5476),
    [anon_sym_BANG_EQ] = ACTIONS(5476),
    [anon_sym_GT_EQ] = ACTIONS(5476),
    [anon_sym_LT_EQ] = ACTIONS(5476),
    [anon_sym_DOT] = ACTIONS(5478),
    [anon_sym_switch] = ACTIONS(5476),
    [anon_sym_DOT_DOT] = ACTIONS(5476),
    [anon_sym_and] = ACTIONS(5476),
    [anon_sym_or] = ACTIONS(5478),
    [anon_sym_AMP_AMP] = ACTIONS(5476),
    [anon_sym_PIPE_PIPE] = ACTIONS(5476),
    [anon_sym_QMARK_QMARK] = ACTIONS(5476),
    [anon_sym_from] = ACTIONS(5476),
    [anon_sym_into] = ACTIONS(5476),
    [anon_sym_join] = ACTIONS(5476),
    [anon_sym_let] = ACTIONS(5476),
    [anon_sym_orderby] = ACTIONS(5476),
    [anon_sym_ascending] = ACTIONS(5476),
    [anon_sym_descending] = ACTIONS(5476),
    [anon_sym_group] = ACTIONS(5476),
    [anon_sym_select] = ACTIONS(5476),
    [anon_sym_as] = ACTIONS(5478),
    [anon_sym_is] = ACTIONS(5476),
    [anon_sym_DASH_GT] = ACTIONS(5476),
    [anon_sym_with] = ACTIONS(5476),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4731] = {
    [sym_variable_declaration] = STATE(9407),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(6751),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4731),
    [sym_preproc_endregion] = STATE(4731),
    [sym_preproc_line] = STATE(4731),
    [sym_preproc_pragma] = STATE(4731),
    [sym_preproc_nullable] = STATE(4731),
    [sym_preproc_error] = STATE(4731),
    [sym_preproc_warning] = STATE(4731),
    [sym_preproc_define] = STATE(4731),
    [sym_preproc_undef] = STATE(4731),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4732] = {
    [sym_preproc_region] = STATE(4732),
    [sym_preproc_endregion] = STATE(4732),
    [sym_preproc_line] = STATE(4732),
    [sym_preproc_pragma] = STATE(4732),
    [sym_preproc_nullable] = STATE(4732),
    [sym_preproc_error] = STATE(4732),
    [sym_preproc_warning] = STATE(4732),
    [sym_preproc_define] = STATE(4732),
    [sym_preproc_undef] = STATE(4732),
    [anon_sym_LBRACK] = ACTIONS(5490),
    [anon_sym_COMMA] = ACTIONS(5490),
    [anon_sym_LPAREN] = ACTIONS(5490),
    [anon_sym_LT] = ACTIONS(5492),
    [anon_sym_GT] = ACTIONS(5492),
    [anon_sym_where] = ACTIONS(5490),
    [anon_sym_QMARK] = ACTIONS(5492),
    [anon_sym_BANG] = ACTIONS(5492),
    [anon_sym_PLUS_PLUS] = ACTIONS(5490),
    [anon_sym_DASH_DASH] = ACTIONS(5490),
    [anon_sym_PLUS] = ACTIONS(5492),
    [anon_sym_DASH] = ACTIONS(5492),
    [anon_sym_STAR] = ACTIONS(5490),
    [anon_sym_SLASH] = ACTIONS(5492),
    [anon_sym_PERCENT] = ACTIONS(5490),
    [anon_sym_CARET] = ACTIONS(5490),
    [anon_sym_PIPE] = ACTIONS(5492),
    [anon_sym_AMP] = ACTIONS(5492),
    [anon_sym_LT_LT] = ACTIONS(5490),
    [anon_sym_GT_GT] = ACTIONS(5492),
    [anon_sym_GT_GT_GT] = ACTIONS(5490),
    [anon_sym_EQ_EQ] = ACTIONS(5490),
    [anon_sym_BANG_EQ] = ACTIONS(5490),
    [anon_sym_GT_EQ] = ACTIONS(5490),
    [anon_sym_LT_EQ] = ACTIONS(5490),
    [anon_sym_DOT] = ACTIONS(5492),
    [anon_sym_switch] = ACTIONS(5490),
    [anon_sym_DOT_DOT] = ACTIONS(5490),
    [anon_sym_and] = ACTIONS(5490),
    [anon_sym_or] = ACTIONS(5492),
    [anon_sym_AMP_AMP] = ACTIONS(5490),
    [anon_sym_PIPE_PIPE] = ACTIONS(5490),
    [anon_sym_QMARK_QMARK] = ACTIONS(5490),
    [anon_sym_from] = ACTIONS(5490),
    [anon_sym_into] = ACTIONS(5490),
    [anon_sym_join] = ACTIONS(5490),
    [anon_sym_let] = ACTIONS(5490),
    [anon_sym_orderby] = ACTIONS(5490),
    [anon_sym_ascending] = ACTIONS(5490),
    [anon_sym_descending] = ACTIONS(5490),
    [anon_sym_group] = ACTIONS(5490),
    [anon_sym_select] = ACTIONS(5490),
    [anon_sym_as] = ACTIONS(5492),
    [anon_sym_is] = ACTIONS(5490),
    [anon_sym_DASH_GT] = ACTIONS(5490),
    [anon_sym_with] = ACTIONS(5490),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4733] = {
    [sym_preproc_region] = STATE(4733),
    [sym_preproc_endregion] = STATE(4733),
    [sym_preproc_line] = STATE(4733),
    [sym_preproc_pragma] = STATE(4733),
    [sym_preproc_nullable] = STATE(4733),
    [sym_preproc_error] = STATE(4733),
    [sym_preproc_warning] = STATE(4733),
    [sym_preproc_define] = STATE(4733),
    [sym_preproc_undef] = STATE(4733),
    [anon_sym_LBRACK] = ACTIONS(5498),
    [anon_sym_COMMA] = ACTIONS(5498),
    [anon_sym_LPAREN] = ACTIONS(5498),
    [anon_sym_LT] = ACTIONS(5500),
    [anon_sym_GT] = ACTIONS(5500),
    [anon_sym_where] = ACTIONS(5498),
    [anon_sym_QMARK] = ACTIONS(5500),
    [anon_sym_BANG] = ACTIONS(5500),
    [anon_sym_PLUS_PLUS] = ACTIONS(5498),
    [anon_sym_DASH_DASH] = ACTIONS(5498),
    [anon_sym_PLUS] = ACTIONS(5500),
    [anon_sym_DASH] = ACTIONS(5500),
    [anon_sym_STAR] = ACTIONS(5498),
    [anon_sym_SLASH] = ACTIONS(5500),
    [anon_sym_PERCENT] = ACTIONS(5498),
    [anon_sym_CARET] = ACTIONS(5498),
    [anon_sym_PIPE] = ACTIONS(5500),
    [anon_sym_AMP] = ACTIONS(5500),
    [anon_sym_LT_LT] = ACTIONS(5498),
    [anon_sym_GT_GT] = ACTIONS(5500),
    [anon_sym_GT_GT_GT] = ACTIONS(5498),
    [anon_sym_EQ_EQ] = ACTIONS(5498),
    [anon_sym_BANG_EQ] = ACTIONS(5498),
    [anon_sym_GT_EQ] = ACTIONS(5498),
    [anon_sym_LT_EQ] = ACTIONS(5498),
    [anon_sym_DOT] = ACTIONS(5500),
    [anon_sym_switch] = ACTIONS(5498),
    [anon_sym_DOT_DOT] = ACTIONS(5498),
    [anon_sym_and] = ACTIONS(5498),
    [anon_sym_or] = ACTIONS(5500),
    [anon_sym_AMP_AMP] = ACTIONS(5498),
    [anon_sym_PIPE_PIPE] = ACTIONS(5498),
    [anon_sym_QMARK_QMARK] = ACTIONS(5498),
    [anon_sym_from] = ACTIONS(5498),
    [anon_sym_into] = ACTIONS(5498),
    [anon_sym_join] = ACTIONS(5498),
    [anon_sym_let] = ACTIONS(5498),
    [anon_sym_orderby] = ACTIONS(5498),
    [anon_sym_ascending] = ACTIONS(5498),
    [anon_sym_descending] = ACTIONS(5498),
    [anon_sym_group] = ACTIONS(5498),
    [anon_sym_select] = ACTIONS(5498),
    [anon_sym_as] = ACTIONS(5500),
    [anon_sym_is] = ACTIONS(5498),
    [anon_sym_DASH_GT] = ACTIONS(5498),
    [anon_sym_with] = ACTIONS(5498),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4734] = {
    [sym__name] = STATE(6771),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(6020),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(6517),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4734),
    [sym_preproc_endregion] = STATE(4734),
    [sym_preproc_line] = STATE(4734),
    [sym_preproc_pragma] = STATE(4734),
    [sym_preproc_nullable] = STATE(4734),
    [sym_preproc_error] = STATE(4734),
    [sym_preproc_warning] = STATE(4734),
    [sym_preproc_define] = STATE(4734),
    [sym_preproc_undef] = STATE(4734),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(4153),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_readonly] = ACTIONS(2867),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(6713),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4735] = {
    [sym__name] = STATE(3744),
    [sym_alias_qualified_name] = STATE(3680),
    [sym__simple_name] = STATE(3680),
    [sym_qualified_name] = STATE(3680),
    [sym_generic_name] = STATE(3648),
    [sym_type] = STATE(3731),
    [sym_implicit_type] = STATE(3707),
    [sym_array_type] = STATE(3725),
    [sym__array_base_type] = STATE(8829),
    [sym_nullable_type] = STATE(3681),
    [sym_pointer_type] = STATE(3681),
    [sym__pointer_base_type] = STATE(9538),
    [sym_function_pointer_type] = STATE(3681),
    [sym_ref_type] = STATE(3707),
    [sym_scoped_type] = STATE(3707),
    [sym_tuple_type] = STATE(3631),
    [sym_identifier] = STATE(3590),
    [sym__reserved_identifier] = STATE(3625),
    [sym_preproc_region] = STATE(4735),
    [sym_preproc_endregion] = STATE(4735),
    [sym_preproc_line] = STATE(4735),
    [sym_preproc_pragma] = STATE(4735),
    [sym_preproc_nullable] = STATE(4735),
    [sym_preproc_error] = STATE(4735),
    [sym_preproc_warning] = STATE(4735),
    [sym_preproc_define] = STATE(4735),
    [sym_preproc_undef] = STATE(4735),
    [sym__identifier_token] = ACTIONS(4349),
    [anon_sym_alias] = ACTIONS(4351),
    [anon_sym_global] = ACTIONS(4351),
    [anon_sym_LPAREN] = ACTIONS(6584),
    [anon_sym_ref] = ACTIONS(4729),
    [anon_sym_delegate] = ACTIONS(4512),
    [anon_sym_file] = ACTIONS(4351),
    [anon_sym_readonly] = ACTIONS(6715),
    [anon_sym_where] = ACTIONS(4351),
    [anon_sym_notnull] = ACTIONS(4351),
    [anon_sym_unmanaged] = ACTIONS(4351),
    [anon_sym_scoped] = ACTIONS(6254),
    [anon_sym_var] = ACTIONS(4516),
    [sym_predefined_type] = ACTIONS(4518),
    [anon_sym_yield] = ACTIONS(4351),
    [anon_sym_when] = ACTIONS(4351),
    [anon_sym_from] = ACTIONS(4351),
    [anon_sym_into] = ACTIONS(4351),
    [anon_sym_join] = ACTIONS(4351),
    [anon_sym_on] = ACTIONS(4351),
    [anon_sym_equals] = ACTIONS(4351),
    [anon_sym_let] = ACTIONS(4351),
    [anon_sym_orderby] = ACTIONS(4351),
    [anon_sym_ascending] = ACTIONS(4351),
    [anon_sym_descending] = ACTIONS(4351),
    [anon_sym_group] = ACTIONS(4351),
    [anon_sym_by] = ACTIONS(4351),
    [anon_sym_select] = ACTIONS(4351),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4736] = {
    [sym_preproc_region] = STATE(4736),
    [sym_preproc_endregion] = STATE(4736),
    [sym_preproc_line] = STATE(4736),
    [sym_preproc_pragma] = STATE(4736),
    [sym_preproc_nullable] = STATE(4736),
    [sym_preproc_error] = STATE(4736),
    [sym_preproc_warning] = STATE(4736),
    [sym_preproc_define] = STATE(4736),
    [sym_preproc_undef] = STATE(4736),
    [anon_sym_LBRACK] = ACTIONS(2997),
    [anon_sym_COMMA] = ACTIONS(2997),
    [anon_sym_LPAREN] = ACTIONS(2997),
    [anon_sym_LT] = ACTIONS(2995),
    [anon_sym_GT] = ACTIONS(2995),
    [anon_sym_where] = ACTIONS(2997),
    [anon_sym_QMARK] = ACTIONS(2995),
    [anon_sym_BANG] = ACTIONS(2995),
    [anon_sym_PLUS_PLUS] = ACTIONS(2997),
    [anon_sym_DASH_DASH] = ACTIONS(2997),
    [anon_sym_PLUS] = ACTIONS(2995),
    [anon_sym_DASH] = ACTIONS(2995),
    [anon_sym_STAR] = ACTIONS(2997),
    [anon_sym_SLASH] = ACTIONS(2995),
    [anon_sym_PERCENT] = ACTIONS(2997),
    [anon_sym_CARET] = ACTIONS(2997),
    [anon_sym_PIPE] = ACTIONS(2995),
    [anon_sym_AMP] = ACTIONS(2995),
    [anon_sym_LT_LT] = ACTIONS(2997),
    [anon_sym_GT_GT] = ACTIONS(2995),
    [anon_sym_GT_GT_GT] = ACTIONS(2997),
    [anon_sym_EQ_EQ] = ACTIONS(2997),
    [anon_sym_BANG_EQ] = ACTIONS(2997),
    [anon_sym_GT_EQ] = ACTIONS(2997),
    [anon_sym_LT_EQ] = ACTIONS(2997),
    [anon_sym_DOT] = ACTIONS(2995),
    [anon_sym_switch] = ACTIONS(2997),
    [anon_sym_DOT_DOT] = ACTIONS(2997),
    [anon_sym_and] = ACTIONS(2997),
    [anon_sym_or] = ACTIONS(2995),
    [anon_sym_AMP_AMP] = ACTIONS(2997),
    [anon_sym_PIPE_PIPE] = ACTIONS(2997),
    [anon_sym_QMARK_QMARK] = ACTIONS(2997),
    [anon_sym_from] = ACTIONS(2997),
    [anon_sym_into] = ACTIONS(2997),
    [anon_sym_join] = ACTIONS(2997),
    [anon_sym_let] = ACTIONS(2997),
    [anon_sym_orderby] = ACTIONS(2997),
    [anon_sym_ascending] = ACTIONS(2997),
    [anon_sym_descending] = ACTIONS(2997),
    [anon_sym_group] = ACTIONS(2997),
    [anon_sym_select] = ACTIONS(2997),
    [anon_sym_as] = ACTIONS(2995),
    [anon_sym_is] = ACTIONS(2997),
    [anon_sym_DASH_GT] = ACTIONS(2997),
    [anon_sym_with] = ACTIONS(2997),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4737] = {
    [sym_variable_declaration] = STATE(9754),
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7104),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4737),
    [sym_preproc_endregion] = STATE(4737),
    [sym_preproc_line] = STATE(4737),
    [sym_preproc_pragma] = STATE(4737),
    [sym_preproc_nullable] = STATE(4737),
    [sym_preproc_error] = STATE(4737),
    [sym_preproc_warning] = STATE(4737),
    [sym_preproc_define] = STATE(4737),
    [sym_preproc_undef] = STATE(4737),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4738] = {
    [sym_preproc_region] = STATE(4738),
    [sym_preproc_endregion] = STATE(4738),
    [sym_preproc_line] = STATE(4738),
    [sym_preproc_pragma] = STATE(4738),
    [sym_preproc_nullable] = STATE(4738),
    [sym_preproc_error] = STATE(4738),
    [sym_preproc_warning] = STATE(4738),
    [sym_preproc_define] = STATE(4738),
    [sym_preproc_undef] = STATE(4738),
    [anon_sym_LBRACK] = ACTIONS(5522),
    [anon_sym_COMMA] = ACTIONS(5522),
    [anon_sym_LPAREN] = ACTIONS(5522),
    [anon_sym_LT] = ACTIONS(5524),
    [anon_sym_GT] = ACTIONS(5524),
    [anon_sym_where] = ACTIONS(5522),
    [anon_sym_QMARK] = ACTIONS(5524),
    [anon_sym_BANG] = ACTIONS(5524),
    [anon_sym_PLUS_PLUS] = ACTIONS(5522),
    [anon_sym_DASH_DASH] = ACTIONS(5522),
    [anon_sym_PLUS] = ACTIONS(5524),
    [anon_sym_DASH] = ACTIONS(5524),
    [anon_sym_STAR] = ACTIONS(5522),
    [anon_sym_SLASH] = ACTIONS(5524),
    [anon_sym_PERCENT] = ACTIONS(5522),
    [anon_sym_CARET] = ACTIONS(5522),
    [anon_sym_PIPE] = ACTIONS(5524),
    [anon_sym_AMP] = ACTIONS(5524),
    [anon_sym_LT_LT] = ACTIONS(5522),
    [anon_sym_GT_GT] = ACTIONS(5524),
    [anon_sym_GT_GT_GT] = ACTIONS(5522),
    [anon_sym_EQ_EQ] = ACTIONS(5522),
    [anon_sym_BANG_EQ] = ACTIONS(5522),
    [anon_sym_GT_EQ] = ACTIONS(5522),
    [anon_sym_LT_EQ] = ACTIONS(5522),
    [anon_sym_DOT] = ACTIONS(5524),
    [anon_sym_switch] = ACTIONS(5522),
    [anon_sym_DOT_DOT] = ACTIONS(5522),
    [anon_sym_and] = ACTIONS(5522),
    [anon_sym_or] = ACTIONS(5524),
    [anon_sym_AMP_AMP] = ACTIONS(5522),
    [anon_sym_PIPE_PIPE] = ACTIONS(5522),
    [anon_sym_QMARK_QMARK] = ACTIONS(5522),
    [anon_sym_from] = ACTIONS(5522),
    [anon_sym_into] = ACTIONS(5522),
    [anon_sym_join] = ACTIONS(5522),
    [anon_sym_let] = ACTIONS(5522),
    [anon_sym_orderby] = ACTIONS(5522),
    [anon_sym_ascending] = ACTIONS(5522),
    [anon_sym_descending] = ACTIONS(5522),
    [anon_sym_group] = ACTIONS(5522),
    [anon_sym_select] = ACTIONS(5522),
    [anon_sym_as] = ACTIONS(5524),
    [anon_sym_is] = ACTIONS(5522),
    [anon_sym_DASH_GT] = ACTIONS(5522),
    [anon_sym_with] = ACTIONS(5522),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4739] = {
    [sym_preproc_region] = STATE(4739),
    [sym_preproc_endregion] = STATE(4739),
    [sym_preproc_line] = STATE(4739),
    [sym_preproc_pragma] = STATE(4739),
    [sym_preproc_nullable] = STATE(4739),
    [sym_preproc_error] = STATE(4739),
    [sym_preproc_warning] = STATE(4739),
    [sym_preproc_define] = STATE(4739),
    [sym_preproc_undef] = STATE(4739),
    [anon_sym_LBRACK] = ACTIONS(5530),
    [anon_sym_COMMA] = ACTIONS(5530),
    [anon_sym_LPAREN] = ACTIONS(5530),
    [anon_sym_LT] = ACTIONS(5532),
    [anon_sym_GT] = ACTIONS(5532),
    [anon_sym_where] = ACTIONS(5530),
    [anon_sym_QMARK] = ACTIONS(5532),
    [anon_sym_BANG] = ACTIONS(5532),
    [anon_sym_PLUS_PLUS] = ACTIONS(5530),
    [anon_sym_DASH_DASH] = ACTIONS(5530),
    [anon_sym_PLUS] = ACTIONS(5532),
    [anon_sym_DASH] = ACTIONS(5532),
    [anon_sym_STAR] = ACTIONS(5530),
    [anon_sym_SLASH] = ACTIONS(5532),
    [anon_sym_PERCENT] = ACTIONS(5530),
    [anon_sym_CARET] = ACTIONS(5530),
    [anon_sym_PIPE] = ACTIONS(5532),
    [anon_sym_AMP] = ACTIONS(5532),
    [anon_sym_LT_LT] = ACTIONS(5530),
    [anon_sym_GT_GT] = ACTIONS(5532),
    [anon_sym_GT_GT_GT] = ACTIONS(5530),
    [anon_sym_EQ_EQ] = ACTIONS(5530),
    [anon_sym_BANG_EQ] = ACTIONS(5530),
    [anon_sym_GT_EQ] = ACTIONS(5530),
    [anon_sym_LT_EQ] = ACTIONS(5530),
    [anon_sym_DOT] = ACTIONS(5532),
    [anon_sym_switch] = ACTIONS(5530),
    [anon_sym_DOT_DOT] = ACTIONS(5530),
    [anon_sym_and] = ACTIONS(5530),
    [anon_sym_or] = ACTIONS(5532),
    [anon_sym_AMP_AMP] = ACTIONS(5530),
    [anon_sym_PIPE_PIPE] = ACTIONS(5530),
    [anon_sym_QMARK_QMARK] = ACTIONS(5530),
    [anon_sym_from] = ACTIONS(5530),
    [anon_sym_into] = ACTIONS(5530),
    [anon_sym_join] = ACTIONS(5530),
    [anon_sym_let] = ACTIONS(5530),
    [anon_sym_orderby] = ACTIONS(5530),
    [anon_sym_ascending] = ACTIONS(5530),
    [anon_sym_descending] = ACTIONS(5530),
    [anon_sym_group] = ACTIONS(5530),
    [anon_sym_select] = ACTIONS(5530),
    [anon_sym_as] = ACTIONS(5532),
    [anon_sym_is] = ACTIONS(5530),
    [anon_sym_DASH_GT] = ACTIONS(5530),
    [anon_sym_with] = ACTIONS(5530),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4740] = {
    [sym_preproc_region] = STATE(4740),
    [sym_preproc_endregion] = STATE(4740),
    [sym_preproc_line] = STATE(4740),
    [sym_preproc_pragma] = STATE(4740),
    [sym_preproc_nullable] = STATE(4740),
    [sym_preproc_error] = STATE(4740),
    [sym_preproc_warning] = STATE(4740),
    [sym_preproc_define] = STATE(4740),
    [sym_preproc_undef] = STATE(4740),
    [anon_sym_LBRACK] = ACTIONS(3039),
    [anon_sym_COMMA] = ACTIONS(3039),
    [anon_sym_LPAREN] = ACTIONS(3039),
    [anon_sym_LT] = ACTIONS(3037),
    [anon_sym_GT] = ACTIONS(3037),
    [anon_sym_where] = ACTIONS(3039),
    [anon_sym_QMARK] = ACTIONS(3037),
    [anon_sym_BANG] = ACTIONS(3037),
    [anon_sym_PLUS_PLUS] = ACTIONS(3039),
    [anon_sym_DASH_DASH] = ACTIONS(3039),
    [anon_sym_PLUS] = ACTIONS(3037),
    [anon_sym_DASH] = ACTIONS(3037),
    [anon_sym_STAR] = ACTIONS(3039),
    [anon_sym_SLASH] = ACTIONS(3037),
    [anon_sym_PERCENT] = ACTIONS(3039),
    [anon_sym_CARET] = ACTIONS(3039),
    [anon_sym_PIPE] = ACTIONS(3037),
    [anon_sym_AMP] = ACTIONS(3037),
    [anon_sym_LT_LT] = ACTIONS(3039),
    [anon_sym_GT_GT] = ACTIONS(3037),
    [anon_sym_GT_GT_GT] = ACTIONS(3039),
    [anon_sym_EQ_EQ] = ACTIONS(3039),
    [anon_sym_BANG_EQ] = ACTIONS(3039),
    [anon_sym_GT_EQ] = ACTIONS(3039),
    [anon_sym_LT_EQ] = ACTIONS(3039),
    [anon_sym_DOT] = ACTIONS(3037),
    [anon_sym_switch] = ACTIONS(3039),
    [anon_sym_DOT_DOT] = ACTIONS(3039),
    [anon_sym_and] = ACTIONS(3039),
    [anon_sym_or] = ACTIONS(3037),
    [anon_sym_AMP_AMP] = ACTIONS(3039),
    [anon_sym_PIPE_PIPE] = ACTIONS(3039),
    [anon_sym_QMARK_QMARK] = ACTIONS(3039),
    [anon_sym_from] = ACTIONS(3039),
    [anon_sym_into] = ACTIONS(3039),
    [anon_sym_join] = ACTIONS(3039),
    [anon_sym_let] = ACTIONS(3039),
    [anon_sym_orderby] = ACTIONS(3039),
    [anon_sym_ascending] = ACTIONS(3039),
    [anon_sym_descending] = ACTIONS(3039),
    [anon_sym_group] = ACTIONS(3039),
    [anon_sym_select] = ACTIONS(3039),
    [anon_sym_as] = ACTIONS(3037),
    [anon_sym_is] = ACTIONS(3039),
    [anon_sym_DASH_GT] = ACTIONS(3039),
    [anon_sym_with] = ACTIONS(3039),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4741] = {
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7206),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_tuple_element] = STATE(8869),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4741),
    [sym_preproc_endregion] = STATE(4741),
    [sym_preproc_line] = STATE(4741),
    [sym_preproc_pragma] = STATE(4741),
    [sym_preproc_nullable] = STATE(4741),
    [sym_preproc_error] = STATE(4741),
    [sym_preproc_warning] = STATE(4741),
    [sym_preproc_define] = STATE(4741),
    [sym_preproc_undef] = STATE(4741),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(4078),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(6140),
    [anon_sym_var] = ACTIONS(5369),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4742] = {
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(6020),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4742),
    [sym_preproc_endregion] = STATE(4742),
    [sym_preproc_line] = STATE(4742),
    [sym_preproc_pragma] = STATE(4742),
    [sym_preproc_nullable] = STATE(4742),
    [sym_preproc_error] = STATE(4742),
    [sym_preproc_warning] = STATE(4742),
    [sym_preproc_define] = STATE(4742),
    [sym_preproc_undef] = STATE(4742),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(6717),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_readonly] = ACTIONS(6719),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_scoped] = ACTIONS(6721),
    [anon_sym_var] = ACTIONS(5369),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4743] = {
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7316),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4743),
    [sym_preproc_endregion] = STATE(4743),
    [sym_preproc_line] = STATE(4743),
    [sym_preproc_pragma] = STATE(4743),
    [sym_preproc_nullable] = STATE(4743),
    [sym_preproc_error] = STATE(4743),
    [sym_preproc_warning] = STATE(4743),
    [sym_preproc_define] = STATE(4743),
    [sym_preproc_undef] = STATE(4743),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_STAR] = ACTIONS(6110),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4744] = {
    [sym_preproc_region] = STATE(4744),
    [sym_preproc_endregion] = STATE(4744),
    [sym_preproc_line] = STATE(4744),
    [sym_preproc_pragma] = STATE(4744),
    [sym_preproc_nullable] = STATE(4744),
    [sym_preproc_error] = STATE(4744),
    [sym_preproc_warning] = STATE(4744),
    [sym_preproc_define] = STATE(4744),
    [sym_preproc_undef] = STATE(4744),
    [anon_sym_LBRACK] = ACTIONS(5544),
    [anon_sym_COMMA] = ACTIONS(5544),
    [anon_sym_LPAREN] = ACTIONS(5544),
    [anon_sym_LT] = ACTIONS(5546),
    [anon_sym_GT] = ACTIONS(5546),
    [anon_sym_where] = ACTIONS(5544),
    [anon_sym_QMARK] = ACTIONS(5546),
    [anon_sym_BANG] = ACTIONS(5546),
    [anon_sym_PLUS_PLUS] = ACTIONS(5544),
    [anon_sym_DASH_DASH] = ACTIONS(5544),
    [anon_sym_PLUS] = ACTIONS(5546),
    [anon_sym_DASH] = ACTIONS(5546),
    [anon_sym_STAR] = ACTIONS(5544),
    [anon_sym_SLASH] = ACTIONS(5546),
    [anon_sym_PERCENT] = ACTIONS(5544),
    [anon_sym_CARET] = ACTIONS(5544),
    [anon_sym_PIPE] = ACTIONS(5546),
    [anon_sym_AMP] = ACTIONS(5546),
    [anon_sym_LT_LT] = ACTIONS(5544),
    [anon_sym_GT_GT] = ACTIONS(5546),
    [anon_sym_GT_GT_GT] = ACTIONS(5544),
    [anon_sym_EQ_EQ] = ACTIONS(5544),
    [anon_sym_BANG_EQ] = ACTIONS(5544),
    [anon_sym_GT_EQ] = ACTIONS(5544),
    [anon_sym_LT_EQ] = ACTIONS(5544),
    [anon_sym_DOT] = ACTIONS(5546),
    [anon_sym_switch] = ACTIONS(5544),
    [anon_sym_DOT_DOT] = ACTIONS(5544),
    [anon_sym_and] = ACTIONS(5544),
    [anon_sym_or] = ACTIONS(5546),
    [anon_sym_AMP_AMP] = ACTIONS(5544),
    [anon_sym_PIPE_PIPE] = ACTIONS(5544),
    [anon_sym_QMARK_QMARK] = ACTIONS(5544),
    [anon_sym_from] = ACTIONS(5544),
    [anon_sym_into] = ACTIONS(5544),
    [anon_sym_join] = ACTIONS(5544),
    [anon_sym_let] = ACTIONS(5544),
    [anon_sym_orderby] = ACTIONS(5544),
    [anon_sym_ascending] = ACTIONS(5544),
    [anon_sym_descending] = ACTIONS(5544),
    [anon_sym_group] = ACTIONS(5544),
    [anon_sym_select] = ACTIONS(5544),
    [anon_sym_as] = ACTIONS(5546),
    [anon_sym_is] = ACTIONS(5544),
    [anon_sym_DASH_GT] = ACTIONS(5544),
    [anon_sym_with] = ACTIONS(5544),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4745] = {
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7326),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4745),
    [sym_preproc_endregion] = STATE(4745),
    [sym_preproc_line] = STATE(4745),
    [sym_preproc_pragma] = STATE(4745),
    [sym_preproc_nullable] = STATE(4745),
    [sym_preproc_error] = STATE(4745),
    [sym_preproc_warning] = STATE(4745),
    [sym_preproc_define] = STATE(4745),
    [sym_preproc_undef] = STATE(4745),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_STAR] = ACTIONS(6110),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4746] = {
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7363),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4746),
    [sym_preproc_endregion] = STATE(4746),
    [sym_preproc_line] = STATE(4746),
    [sym_preproc_pragma] = STATE(4746),
    [sym_preproc_nullable] = STATE(4746),
    [sym_preproc_error] = STATE(4746),
    [sym_preproc_warning] = STATE(4746),
    [sym_preproc_define] = STATE(4746),
    [sym_preproc_undef] = STATE(4746),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_STAR] = ACTIONS(6110),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4747] = {
    [sym__name] = STATE(5365),
    [sym_alias_qualified_name] = STATE(5007),
    [sym__simple_name] = STATE(5007),
    [sym_qualified_name] = STATE(5007),
    [sym_generic_name] = STATE(5019),
    [sym_type] = STATE(7370),
    [sym_implicit_type] = STATE(2906),
    [sym_array_type] = STATE(5473),
    [sym__array_base_type] = STATE(8852),
    [sym_nullable_type] = STATE(5385),
    [sym_pointer_type] = STATE(5385),
    [sym__pointer_base_type] = STATE(9443),
    [sym_function_pointer_type] = STATE(5385),
    [sym_ref_type] = STATE(2906),
    [sym_scoped_type] = STATE(2906),
    [sym_tuple_type] = STATE(5295),
    [sym_identifier] = STATE(4947),
    [sym__reserved_identifier] = STATE(4513),
    [sym_preproc_region] = STATE(4747),
    [sym_preproc_endregion] = STATE(4747),
    [sym_preproc_line] = STATE(4747),
    [sym_preproc_pragma] = STATE(4747),
    [sym_preproc_nullable] = STATE(4747),
    [sym_preproc_error] = STATE(4747),
    [sym_preproc_warning] = STATE(4747),
    [sym_preproc_define] = STATE(4747),
    [sym_preproc_undef] = STATE(4747),
    [sym__identifier_token] = ACTIONS(3193),
    [anon_sym_alias] = ACTIONS(3197),
    [anon_sym_global] = ACTIONS(3197),
    [anon_sym_LPAREN] = ACTIONS(3205),
    [anon_sym_ref] = ACTIONS(4000),
    [anon_sym_delegate] = ACTIONS(4002),
    [anon_sym_file] = ACTIONS(3197),
    [anon_sym_where] = ACTIONS(3197),
    [anon_sym_notnull] = ACTIONS(3197),
    [anon_sym_unmanaged] = ACTIONS(3197),
    [anon_sym_STAR] = ACTIONS(6110),
    [anon_sym_scoped] = ACTIONS(3231),
    [anon_sym_var] = ACTIONS(3233),
    [sym_predefined_type] = ACTIONS(3235),
    [anon_sym_yield] = ACTIONS(3197),
    [anon_sym_when] = ACTIONS(3197),
    [anon_sym_from] = ACTIONS(3197),
    [anon_sym_into] = ACTIONS(3197),
    [anon_sym_join] = ACTIONS(3197),
    [anon_sym_on] = ACTIONS(3197),
    [anon_sym_equals] = ACTIONS(3197),
    [anon_sym_let] = ACTIONS(3197),
    [anon_sym_orderby] = ACTIONS(3197),
    [anon_sym_ascending] = ACTIONS(3197),
    [anon_sym_descending] = ACTIONS(3197),
    [anon_sym_group] = ACTIONS(3197),
    [anon_sym_by] = ACTIONS(3197),
    [anon_sym_select] = ACTIONS(3197),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4748] = {
    [sym_preproc_region] = STATE(4748),
    [sym_preproc_endregion] = STATE(4748),
    [sym_preproc_line] = STATE(4748),
    [sym_preproc_pragma] = STATE(4748),
    [sym_preproc_nullable] = STATE(4748),
    [sym_preproc_error] = STATE(4748),
    [sym_preproc_warning] = STATE(4748),
    [sym_preproc_define] = STATE(4748),
    [sym_preproc_undef] = STATE(4748),
    [anon_sym_LBRACK] = ACTIONS(5861),
    [anon_sym_COMMA] = ACTIONS(5861),
    [anon_sym_LPAREN] = ACTIONS(5861),
    [anon_sym_LT] = ACTIONS(5863),
    [anon_sym_GT] = ACTIONS(5863),
    [anon_sym_where] = ACTIONS(5861),
    [anon_sym_QMARK] = ACTIONS(5863),
    [anon_sym_BANG] = ACTIONS(5863),
    [anon_sym_PLUS_PLUS] = ACTIONS(5861),
    [anon_sym_DASH_DASH] = ACTIONS(5861),
    [anon_sym_PLUS] = ACTIONS(5863),
    [anon_sym_DASH] = ACTIONS(5863),
    [anon_sym_STAR] = ACTIONS(5861),
    [anon_sym_SLASH] = ACTIONS(5863),
    [anon_sym_PERCENT] = ACTIONS(5861),
    [anon_sym_CARET] = ACTIONS(5861),
    [anon_sym_PIPE] = ACTIONS(5863),
    [anon_sym_AMP] = ACTIONS(5863),
    [anon_sym_LT_LT] = ACTIONS(5861),
    [anon_sym_GT_GT] = ACTIONS(5863),
    [anon_sym_GT_GT_GT] = ACTIONS(5861),
    [anon_sym_EQ_EQ] = ACTIONS(5861),
    [anon_sym_BANG_EQ] = ACTIONS(5861),
    [anon_sym_GT_EQ] = ACTIONS(5861),
    [anon_sym_LT_EQ] = ACTIONS(5861),
    [anon_sym_DOT] = ACTIONS(5863),
    [anon_sym_switch] = ACTIONS(5861),
    [anon_sym_DOT_DOT] = ACTIONS(5861),
    [anon_sym_and] = ACTIONS(5861),
    [anon_sym_or] = ACTIONS(5863),
    [anon_sym_AMP_AMP] = ACTIONS(5861),
    [anon_sym_PIPE_PIPE] = ACTIONS(5861),
    [anon_sym_QMARK_QMARK] = ACTIONS(5861),
    [anon_sym_from] = ACTIONS(5861),
    [anon_sym_into] = ACTIONS(5861),
    [anon_sym_join] = ACTIONS(5861),
    [anon_sym_let] = ACTIONS(5861),
    [anon_sym_orderby] = ACTIONS(5861),
    [anon_sym_ascending] = ACTIONS(5861),
    [anon_sym_descending] = ACTIONS(5861),
    [anon_sym_group] = ACTIONS(5861),
    [anon_sym_select] = ACTIONS(5861),
    [anon_sym_as] = ACTIONS(5863),
    [anon_sym_is] = ACTIONS(5861),
    [anon_sym_DASH_GT] = ACTIONS(5861),
    [anon_sym_with] = ACTIONS(5861),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
  [4749] = {
    [sym_preproc_region] = STATE(4749),
    [sym_preproc_endregion] = STATE(4749),
    [sym_preproc_line] = STATE(4749),
    [sym_preproc_pragma] = STATE(4749),
    [sym_preproc_nullable] = STATE(4749),
    [sym_preproc_error] = STATE(4749),
    [sym_preproc_warning] = STATE(4749),
    [sym_preproc_define] = STATE(4749),
    [sym_preproc_undef] = STATE(4749),
    [anon_sym_LBRACK] = ACTIONS(5628),
    [anon_sym_COMMA] = ACTIONS(5628),
    [anon_sym_LPAREN] = ACTIONS(5628),
    [anon_sym_LT] = ACTIONS(5630),
    [anon_sym_GT] = ACTIONS(5630),
    [anon_sym_where] = ACTIONS(5628),
    [anon_sym_QMARK] = ACTIONS(5630),
    [anon_sym_BANG] = ACTIONS(5630),
    [anon_sym_PLUS_PLUS] = ACTIONS(5628),
    [anon_sym_DASH_DASH] = ACTIONS(5628),
    [anon_sym_PLUS] = ACTIONS(5630),
    [anon_sym_DASH] = ACTIONS(5630),
    [anon_sym_STAR] = ACTIONS(5628),
    [anon_sym_SLASH] = ACTIONS(5630),
    [anon_sym_PERCENT] = ACTIONS(5628),
    [anon_sym_CARET] = ACTIONS(5628),
    [anon_sym_PIPE] = ACTIONS(5630),
    [anon_sym_AMP] = ACTIONS(5630),
    [anon_sym_LT_LT] = ACTIONS(5628),
    [anon_sym_GT_GT] = ACTIONS(5630),
    [anon_sym_GT_GT_GT] = ACTIONS(5628),
    [anon_sym_EQ_EQ] = ACTIONS(5628),
    [anon_sym_BANG_EQ] = ACTIONS(5628),
    [anon_sym_GT_EQ] = ACTIONS(5628),
    [anon_sym_LT_EQ] = ACTIONS(5628),
    [anon_sym_DOT] = ACTIONS(5630),
    [anon_sym_switch] = ACTIONS(5628),
    [anon_sym_DOT_DOT] = ACTIONS(5628),
    [anon_sym_and] = ACTIONS(5628),
    [anon_sym_or] = ACTIONS(5630),
    [anon_sym_AMP_AMP] = ACTIONS(5628),
    [anon_sym_PIPE_PIPE] = ACTIONS(5628),
    [anon_sym_QMARK_QMARK] = ACTIONS(5628),
    [anon_sym_from] = ACTIONS(5628),
    [anon_sym_into] = ACTIONS(5628),
    [anon_sym_join] = ACTIONS(5628),
    [anon_sym_let] = ACTIONS(5628),
    [anon_sym_orderby] = ACTIONS(5628),
    [anon_sym_ascending] = ACTIONS(5628),
    [anon_sym_descending] = ACTIONS(5628),
    [anon_sym_group] = ACTIONS(5628),
    [anon_sym_select] = ACTIONS(5628),
    [anon_sym_as] = ACTIONS(5630),
    [anon_sym_is] = ACTIONS(5628),
    [anon_sym_DASH_GT] = ACTIONS(5628),
    [anon_sym_with] = ACTIONS(5628),
    [aux_sym_preproc_region_token1] = ACTIONS(3),
    [aux_sym_preproc_endregion_token1] = ACTIONS(5),
    [aux_sym_preproc_line_token1] = ACTIONS(7),
    [aux_sym_preproc_pragma_token1] = ACTIONS(9),
    [aux_sym_preproc_nullable_token1] = ACTIONS(11),
    [aux_sym_preproc_error_token1] = ACTIONS(13),
    [aux_sym_preproc_warning_token1] = ACTIONS(15),
    [aux_sym_preproc_define_token1] = ACTIONS(17),
    [aux_sym_preproc_undef_token1] = ACTIONS(19),
    [sym_comment] = ACTIONS(21),
  },
};

static const uint16_t ts_small_parse_table[] = {
  [0] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3193), 1,
      sym__identifier_token,
    ACTIONS(3205), 1,
      anon_sym_LPAREN,
    ACTIONS(3235), 1,
      sym_predefined_type,
    ACTIONS(4002), 1,
      anon_sym_delegate,
    ACTIONS(5369), 1,
      anon_sym_var,
    ACTIONS(6717), 1,
      anon_sym_ref,
    ACTIONS(6721), 1,
      anon_sym_scoped,
    STATE(4513), 1,
      sym__reserved_identifier,
    STATE(4947), 1,
      sym_identifier,
    STATE(5019), 1,
      sym_generic_name,
    STATE(5295), 1,
      sym_tuple_type,
    STATE(5365), 1,
      sym__name,
    STATE(5473), 1,
      sym_array_type,
    STATE(8852), 1,
      sym__array_base_type,
    STATE(9443), 1,
      sym__pointer_base_type,
    STATE(9506), 1,
      sym_type,
    STATE(2906), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(5385), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4750), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3197), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [127] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6723), 1,
      anon_sym_DOT_DOT,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(4751), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(1229), 10,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    ACTIONS(1227), 25,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
  [236] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5233), 1,
      anon_sym_DASH_GT,
    ACTIONS(5239), 1,
      anon_sym_DOT,
    ACTIONS(6124), 1,
      anon_sym_LPAREN,
    ACTIONS(6156), 1,
      anon_sym_LBRACK,
    ACTIONS(6158), 1,
      anon_sym_BANG,
    ACTIONS(6216), 1,
      anon_sym_switch,
    ACTIONS(6232), 1,
      anon_sym_with,
    ACTIONS(6406), 1,
      anon_sym_as,
    ACTIONS(6727), 1,
      anon_sym_QMARK,
    ACTIONS(6733), 1,
      anon_sym_SLASH,
    ACTIONS(6735), 1,
      anon_sym_CARET,
    ACTIONS(6737), 1,
      anon_sym_PIPE,
    ACTIONS(6739), 1,
      anon_sym_AMP,
    ACTIONS(6743), 1,
      anon_sym_GT_GT,
    ACTIONS(6749), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6751), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6753), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6755), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(6757), 1,
      anon_sym_is,
    STATE(3577), 1,
      sym_bracketed_argument_list,
    STATE(4561), 1,
      sym_argument_list,
    ACTIONS(6160), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6725), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6729), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6731), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6741), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6745), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6747), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(4752), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5424), 10,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_select,
  [381] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4002), 1,
      anon_sym_delegate,
    ACTIONS(4102), 1,
      anon_sym_ref,
    ACTIONS(4536), 1,
      sym__identifier_token,
    ACTIONS(6246), 1,
      anon_sym_var,
    ACTIONS(6248), 1,
      sym_predefined_type,
    ACTIONS(6602), 1,
      anon_sym_LPAREN,
    ACTIONS(6703), 1,
      anon_sym_scoped,
    STATE(2887), 1,
      sym_type,
    STATE(2928), 1,
      sym__reserved_identifier,
    STATE(2944), 1,
      sym_generic_name,
    STATE(2966), 1,
      sym_array_type,
    STATE(2971), 1,
      sym_tuple_type,
    STATE(3123), 1,
      sym_identifier,
    STATE(3217), 1,
      sym__name,
    STATE(8753), 1,
      sym__array_base_type,
    STATE(9443), 1,
      sym__pointer_base_type,
    STATE(2906), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(2956), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(2970), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4753), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4538), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [508] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6759), 1,
      anon_sym_and,
    ACTIONS(6761), 1,
      anon_sym_or,
    STATE(4754), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5881), 12,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
      anon_sym_as,
    ACTIONS(5879), 31,
      anon_sym_LBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_where,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_select,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [603] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4349), 1,
      sym__identifier_token,
    ACTIONS(4512), 1,
      anon_sym_delegate,
    ACTIONS(4516), 1,
      anon_sym_var,
    ACTIONS(4518), 1,
      sym_predefined_type,
    ACTIONS(4678), 1,
      anon_sym_ref,
    ACTIONS(6360), 1,
      anon_sym_scoped,
    ACTIONS(6584), 1,
      anon_sym_LPAREN,
    STATE(3590), 1,
      sym_identifier,
    STATE(3625), 1,
      sym__reserved_identifier,
    STATE(3631), 1,
      sym_tuple_type,
    STATE(3639), 1,
      sym_type,
    STATE(3648), 1,
      sym_generic_name,
    STATE(3725), 1,
      sym_array_type,
    STATE(3744), 1,
      sym__name,
    STATE(8829), 1,
      sym__array_base_type,
    STATE(9538), 1,
      sym__pointer_base_type,
    STATE(3680), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(3681), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(3707), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(4755), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4351), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [730] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5233), 1,
      anon_sym_DASH_GT,
    ACTIONS(5239), 1,
      anon_sym_DOT,
    ACTIONS(6124), 1,
      anon_sym_LPAREN,
    ACTIONS(6156), 1,
      anon_sym_LBRACK,
    ACTIONS(6158), 1,
      anon_sym_BANG,
    ACTIONS(6216), 1,
      anon_sym_switch,
    ACTIONS(6232), 1,
      anon_sym_with,
    ACTIONS(6406), 1,
      anon_sym_as,
    ACTIONS(6727), 1,
      anon_sym_QMARK,
    ACTIONS(6733), 1,
      anon_sym_SLASH,
    ACTIONS(6735), 1,
      anon_sym_CARET,
    ACTIONS(6737), 1,
      anon_sym_PIPE,
    ACTIONS(6739), 1,
      anon_sym_AMP,
    ACTIONS(6743), 1,
      anon_sym_GT_GT,
    ACTIONS(6749), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6751), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6753), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6755), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(6757), 1,
      anon_sym_is,
    STATE(3577), 1,
      sym_bracketed_argument_list,
    STATE(4561), 1,
      sym_argument_list,
    ACTIONS(6160), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6725), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6729), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6731), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6741), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6745), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6747), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(4756), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6336), 10,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_select,
  [875] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4248), 1,
      sym__identifier_token,
    ACTIONS(4252), 1,
      anon_sym_ref,
    ACTIONS(6168), 1,
      anon_sym_delegate,
    ACTIONS(6172), 1,
      anon_sym_var,
    ACTIONS(6174), 1,
      sym_predefined_type,
    ACTIONS(6350), 1,
      anon_sym_scoped,
    ACTIONS(6620), 1,
      anon_sym_LPAREN,
    STATE(3889), 1,
      sym_identifier,
    STATE(3911), 1,
      sym__reserved_identifier,
    STATE(3958), 1,
      sym_array_type,
    STATE(3959), 1,
      sym_generic_name,
    STATE(3962), 1,
      sym_tuple_type,
    STATE(4036), 1,
      sym_type,
    STATE(4158), 1,
      sym__name,
    STATE(8941), 1,
      sym__array_base_type,
    STATE(9806), 1,
      sym__pointer_base_type,
    STATE(3961), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4031), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(4085), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(4757), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4250), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [1002] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3193), 1,
      sym__identifier_token,
    ACTIONS(3205), 1,
      anon_sym_LPAREN,
    ACTIONS(3235), 1,
      sym_predefined_type,
    ACTIONS(4002), 1,
      anon_sym_delegate,
    ACTIONS(6582), 1,
      anon_sym_var,
    ACTIONS(6596), 1,
      anon_sym_ref,
    ACTIONS(6600), 1,
      anon_sym_scoped,
    STATE(4513), 1,
      sym__reserved_identifier,
    STATE(4947), 1,
      sym_identifier,
    STATE(5019), 1,
      sym_generic_name,
    STATE(5295), 1,
      sym_tuple_type,
    STATE(5365), 1,
      sym__name,
    STATE(5473), 1,
      sym_array_type,
    STATE(8852), 1,
      sym__array_base_type,
    STATE(9443), 1,
      sym__pointer_base_type,
    STATE(9519), 1,
      sym_type,
    STATE(2906), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(5385), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4758), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3197), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [1129] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4328), 1,
      sym__identifier_token,
    ACTIONS(4693), 1,
      anon_sym_ref,
    ACTIONS(6148), 1,
      anon_sym_delegate,
    ACTIONS(6150), 1,
      anon_sym_scoped,
    ACTIONS(6152), 1,
      anon_sym_var,
    ACTIONS(6154), 1,
      sym_predefined_type,
    ACTIONS(6654), 1,
      anon_sym_LPAREN,
    STATE(3572), 1,
      sym__reserved_identifier,
    STATE(3597), 1,
      sym_generic_name,
    STATE(3608), 1,
      sym_array_type,
    STATE(3621), 1,
      sym_tuple_type,
    STATE(3712), 1,
      sym_type,
    STATE(4574), 1,
      sym_identifier,
    STATE(4958), 1,
      sym__name,
    STATE(8805), 1,
      sym__array_base_type,
    STATE(9071), 1,
      sym__pointer_base_type,
    STATE(3588), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(3596), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(3612), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4759), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4330), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [1256] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3193), 1,
      sym__identifier_token,
    ACTIONS(3205), 1,
      anon_sym_LPAREN,
    ACTIONS(3235), 1,
      sym_predefined_type,
    ACTIONS(4002), 1,
      anon_sym_delegate,
    ACTIONS(6582), 1,
      anon_sym_var,
    ACTIONS(6596), 1,
      anon_sym_ref,
    ACTIONS(6600), 1,
      anon_sym_scoped,
    STATE(4513), 1,
      sym__reserved_identifier,
    STATE(4947), 1,
      sym_identifier,
    STATE(5019), 1,
      sym_generic_name,
    STATE(5295), 1,
      sym_tuple_type,
    STATE(5365), 1,
      sym__name,
    STATE(5473), 1,
      sym_array_type,
    STATE(8852), 1,
      sym__array_base_type,
    STATE(9379), 1,
      sym_type,
    STATE(9443), 1,
      sym__pointer_base_type,
    STATE(2906), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(5385), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4760), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3197), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [1383] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4457), 1,
      sym__identifier_token,
    ACTIONS(4474), 1,
      anon_sym_ref,
    ACTIONS(6297), 1,
      anon_sym_delegate,
    ACTIONS(6299), 1,
      anon_sym_scoped,
    ACTIONS(6301), 1,
      anon_sym_var,
    ACTIONS(6303), 1,
      sym_predefined_type,
    ACTIONS(6650), 1,
      anon_sym_LPAREN,
    STATE(5076), 1,
      sym_identifier,
    STATE(5173), 1,
      sym__reserved_identifier,
    STATE(5251), 1,
      sym_array_type,
    STATE(5270), 1,
      sym__name,
    STATE(5321), 1,
      sym_tuple_type,
    STATE(5408), 1,
      sym_generic_name,
    STATE(5559), 1,
      sym_type,
    STATE(8724), 1,
      sym__array_base_type,
    STATE(9858), 1,
      sym__pointer_base_type,
    STATE(5262), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(5336), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(5341), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(4761), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4459), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [1510] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4349), 1,
      sym__identifier_token,
    ACTIONS(4512), 1,
      anon_sym_delegate,
    ACTIONS(4516), 1,
      anon_sym_var,
    ACTIONS(4518), 1,
      sym_predefined_type,
    ACTIONS(4729), 1,
      anon_sym_ref,
    ACTIONS(6254), 1,
      anon_sym_scoped,
    ACTIONS(6584), 1,
      anon_sym_LPAREN,
    STATE(3590), 1,
      sym_identifier,
    STATE(3625), 1,
      sym__reserved_identifier,
    STATE(3631), 1,
      sym_tuple_type,
    STATE(3648), 1,
      sym_generic_name,
    STATE(3725), 1,
      sym_array_type,
    STATE(3744), 1,
      sym__name,
    STATE(3772), 1,
      sym_type,
    STATE(8829), 1,
      sym__array_base_type,
    STATE(9538), 1,
      sym__pointer_base_type,
    STATE(3680), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(3681), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(3707), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(4762), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4351), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [1637] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3193), 1,
      sym__identifier_token,
    ACTIONS(3205), 1,
      anon_sym_LPAREN,
    ACTIONS(3235), 1,
      sym_predefined_type,
    ACTIONS(4002), 1,
      anon_sym_delegate,
    ACTIONS(5369), 1,
      anon_sym_var,
    ACTIONS(6717), 1,
      anon_sym_ref,
    ACTIONS(6721), 1,
      anon_sym_scoped,
    STATE(4513), 1,
      sym__reserved_identifier,
    STATE(4947), 1,
      sym_identifier,
    STATE(5019), 1,
      sym_generic_name,
    STATE(5295), 1,
      sym_tuple_type,
    STATE(5365), 1,
      sym__name,
    STATE(5473), 1,
      sym_array_type,
    STATE(8002), 1,
      sym_type,
    STATE(8852), 1,
      sym__array_base_type,
    STATE(9443), 1,
      sym__pointer_base_type,
    STATE(2906), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(5385), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4763), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3197), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [1764] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3193), 1,
      sym__identifier_token,
    ACTIONS(3205), 1,
      anon_sym_LPAREN,
    ACTIONS(3235), 1,
      sym_predefined_type,
    ACTIONS(4002), 1,
      anon_sym_delegate,
    ACTIONS(5369), 1,
      anon_sym_var,
    ACTIONS(5988), 1,
      anon_sym_ref,
    ACTIONS(5996), 1,
      anon_sym_scoped,
    STATE(4513), 1,
      sym__reserved_identifier,
    STATE(4947), 1,
      sym_identifier,
    STATE(5019), 1,
      sym_generic_name,
    STATE(5295), 1,
      sym_tuple_type,
    STATE(5365), 1,
      sym__name,
    STATE(5473), 1,
      sym_array_type,
    STATE(7894), 1,
      sym_type,
    STATE(8852), 1,
      sym__array_base_type,
    STATE(9443), 1,
      sym__pointer_base_type,
    STATE(2906), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(5385), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4764), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3197), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [1891] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3995), 2,
      anon_sym_EQ,
      anon_sym_in,
    ACTIONS(4088), 3,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_GT,
    STATE(4765), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3993), 11,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_STAR,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_COLON_COLON,
    ACTIONS(4091), 29,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_COLON,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_operator,
      anon_sym_this,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      sym_discard,
      anon_sym_and,
      anon_sym_or,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [1986] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3193), 1,
      sym__identifier_token,
    ACTIONS(3205), 1,
      anon_sym_LPAREN,
    ACTIONS(3233), 1,
      anon_sym_var,
    ACTIONS(3235), 1,
      sym_predefined_type,
    ACTIONS(4002), 1,
      anon_sym_delegate,
    ACTIONS(6608), 1,
      anon_sym_ref,
    ACTIONS(6612), 1,
      anon_sym_scoped,
    STATE(4513), 1,
      sym__reserved_identifier,
    STATE(4947), 1,
      sym_identifier,
    STATE(5019), 1,
      sym_generic_name,
    STATE(5295), 1,
      sym_tuple_type,
    STATE(5365), 1,
      sym__name,
    STATE(5473), 1,
      sym_array_type,
    STATE(8852), 1,
      sym__array_base_type,
    STATE(8877), 1,
      sym_type,
    STATE(9443), 1,
      sym__pointer_base_type,
    STATE(2906), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(5385), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4766), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3197), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [2113] = 41,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6322), 1,
      anon_sym_or,
    ACTIONS(6765), 1,
      anon_sym_QMARK,
    ACTIONS(6771), 1,
      anon_sym_SLASH,
    ACTIONS(6773), 1,
      anon_sym_CARET,
    ACTIONS(6775), 1,
      anon_sym_PIPE,
    ACTIONS(6777), 1,
      anon_sym_AMP,
    ACTIONS(6781), 1,
      anon_sym_GT_GT,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6789), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6791), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6793), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6795), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(6797), 1,
      anon_sym_as,
    ACTIONS(6799), 1,
      anon_sym_is,
    ACTIONS(6801), 1,
      anon_sym_with,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6763), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6767), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6769), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6779), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6783), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6785), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6320), 9,
      anon_sym_where,
      anon_sym_and,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
    STATE(4767), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [2260] = 41,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6326), 1,
      anon_sym_or,
    ACTIONS(6765), 1,
      anon_sym_QMARK,
    ACTIONS(6771), 1,
      anon_sym_SLASH,
    ACTIONS(6773), 1,
      anon_sym_CARET,
    ACTIONS(6775), 1,
      anon_sym_PIPE,
    ACTIONS(6777), 1,
      anon_sym_AMP,
    ACTIONS(6781), 1,
      anon_sym_GT_GT,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6789), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6791), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6793), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6795), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(6797), 1,
      anon_sym_as,
    ACTIONS(6799), 1,
      anon_sym_is,
    ACTIONS(6801), 1,
      anon_sym_with,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6763), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6767), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6769), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6779), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6783), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6785), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6324), 9,
      anon_sym_where,
      anon_sym_and,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
    STATE(4768), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [2407] = 41,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(5418), 1,
      anon_sym_or,
    ACTIONS(6765), 1,
      anon_sym_QMARK,
    ACTIONS(6771), 1,
      anon_sym_SLASH,
    ACTIONS(6773), 1,
      anon_sym_CARET,
    ACTIONS(6775), 1,
      anon_sym_PIPE,
    ACTIONS(6777), 1,
      anon_sym_AMP,
    ACTIONS(6781), 1,
      anon_sym_GT_GT,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6789), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6791), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6793), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6795), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(6797), 1,
      anon_sym_as,
    ACTIONS(6799), 1,
      anon_sym_is,
    ACTIONS(6801), 1,
      anon_sym_with,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6763), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6767), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6769), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6779), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6783), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6785), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5416), 9,
      anon_sym_where,
      anon_sym_and,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
    STATE(4769), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [2554] = 41,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(5646), 1,
      anon_sym_or,
    ACTIONS(6765), 1,
      anon_sym_QMARK,
    ACTIONS(6771), 1,
      anon_sym_SLASH,
    ACTIONS(6773), 1,
      anon_sym_CARET,
    ACTIONS(6775), 1,
      anon_sym_PIPE,
    ACTIONS(6777), 1,
      anon_sym_AMP,
    ACTIONS(6781), 1,
      anon_sym_GT_GT,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6789), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6791), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6793), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6795), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(6797), 1,
      anon_sym_as,
    ACTIONS(6799), 1,
      anon_sym_is,
    ACTIONS(6801), 1,
      anon_sym_with,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6763), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6767), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6769), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6779), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6783), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6785), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5644), 9,
      anon_sym_where,
      anon_sym_and,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
    STATE(4770), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [2701] = 41,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(5426), 1,
      anon_sym_or,
    ACTIONS(6765), 1,
      anon_sym_QMARK,
    ACTIONS(6771), 1,
      anon_sym_SLASH,
    ACTIONS(6773), 1,
      anon_sym_CARET,
    ACTIONS(6775), 1,
      anon_sym_PIPE,
    ACTIONS(6777), 1,
      anon_sym_AMP,
    ACTIONS(6781), 1,
      anon_sym_GT_GT,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6789), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6791), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6793), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6795), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(6797), 1,
      anon_sym_as,
    ACTIONS(6799), 1,
      anon_sym_is,
    ACTIONS(6801), 1,
      anon_sym_with,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6763), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6767), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6769), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6779), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6783), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6785), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5424), 9,
      anon_sym_where,
      anon_sym_and,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
    STATE(4771), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [2848] = 41,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6338), 1,
      anon_sym_or,
    ACTIONS(6765), 1,
      anon_sym_QMARK,
    ACTIONS(6771), 1,
      anon_sym_SLASH,
    ACTIONS(6773), 1,
      anon_sym_CARET,
    ACTIONS(6775), 1,
      anon_sym_PIPE,
    ACTIONS(6777), 1,
      anon_sym_AMP,
    ACTIONS(6781), 1,
      anon_sym_GT_GT,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6789), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6791), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6793), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6795), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(6797), 1,
      anon_sym_as,
    ACTIONS(6799), 1,
      anon_sym_is,
    ACTIONS(6801), 1,
      anon_sym_with,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6763), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6767), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6769), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6779), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6783), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6785), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6336), 9,
      anon_sym_where,
      anon_sym_and,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
    STATE(4772), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [2995] = 41,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(5574), 1,
      anon_sym_or,
    ACTIONS(6765), 1,
      anon_sym_QMARK,
    ACTIONS(6771), 1,
      anon_sym_SLASH,
    ACTIONS(6773), 1,
      anon_sym_CARET,
    ACTIONS(6775), 1,
      anon_sym_PIPE,
    ACTIONS(6777), 1,
      anon_sym_AMP,
    ACTIONS(6781), 1,
      anon_sym_GT_GT,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6789), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6791), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6793), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6795), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(6797), 1,
      anon_sym_as,
    ACTIONS(6799), 1,
      anon_sym_is,
    ACTIONS(6801), 1,
      anon_sym_with,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6763), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6767), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6769), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6779), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6783), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6785), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5572), 9,
      anon_sym_where,
      anon_sym_and,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
    STATE(4773), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [3142] = 41,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(5586), 1,
      anon_sym_or,
    ACTIONS(6765), 1,
      anon_sym_QMARK,
    ACTIONS(6771), 1,
      anon_sym_SLASH,
    ACTIONS(6773), 1,
      anon_sym_CARET,
    ACTIONS(6775), 1,
      anon_sym_PIPE,
    ACTIONS(6777), 1,
      anon_sym_AMP,
    ACTIONS(6781), 1,
      anon_sym_GT_GT,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6789), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6791), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6793), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6795), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(6797), 1,
      anon_sym_as,
    ACTIONS(6799), 1,
      anon_sym_is,
    ACTIONS(6801), 1,
      anon_sym_with,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6763), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6767), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6769), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6779), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6783), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6785), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5584), 9,
      anon_sym_where,
      anon_sym_and,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
    STATE(4774), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [3289] = 41,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(5626), 1,
      anon_sym_or,
    ACTIONS(6765), 1,
      anon_sym_QMARK,
    ACTIONS(6771), 1,
      anon_sym_SLASH,
    ACTIONS(6773), 1,
      anon_sym_CARET,
    ACTIONS(6775), 1,
      anon_sym_PIPE,
    ACTIONS(6777), 1,
      anon_sym_AMP,
    ACTIONS(6781), 1,
      anon_sym_GT_GT,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6789), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6791), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6793), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6795), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(6797), 1,
      anon_sym_as,
    ACTIONS(6799), 1,
      anon_sym_is,
    ACTIONS(6801), 1,
      anon_sym_with,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6763), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6767), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6769), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6779), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6783), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6785), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5624), 9,
      anon_sym_where,
      anon_sym_and,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
    STATE(4775), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [3436] = 35,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6771), 1,
      anon_sym_SLASH,
    ACTIONS(6777), 1,
      anon_sym_AMP,
    ACTIONS(6781), 1,
      anon_sym_GT_GT,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6789), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6797), 1,
      anon_sym_as,
    ACTIONS(6799), 1,
      anon_sym_is,
    ACTIONS(6801), 1,
      anon_sym_with,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6763), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6767), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6769), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6779), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6783), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6785), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_or,
    STATE(4776), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 13,
      anon_sym_where,
      anon_sym_CARET,
      anon_sym_and,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
  [3571] = 36,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6771), 1,
      anon_sym_SLASH,
    ACTIONS(6773), 1,
      anon_sym_CARET,
    ACTIONS(6777), 1,
      anon_sym_AMP,
    ACTIONS(6781), 1,
      anon_sym_GT_GT,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6789), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6797), 1,
      anon_sym_as,
    ACTIONS(6799), 1,
      anon_sym_is,
    ACTIONS(6801), 1,
      anon_sym_with,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6763), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6767), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6769), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6779), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6783), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6785), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_or,
    STATE(4777), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 12,
      anon_sym_where,
      anon_sym_and,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
  [3708] = 34,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6771), 1,
      anon_sym_SLASH,
    ACTIONS(6781), 1,
      anon_sym_GT_GT,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6789), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6797), 1,
      anon_sym_as,
    ACTIONS(6799), 1,
      anon_sym_is,
    ACTIONS(6801), 1,
      anon_sym_with,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6763), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6767), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6769), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6779), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6783), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6785), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 4,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_or,
    STATE(4778), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 13,
      anon_sym_where,
      anon_sym_CARET,
      anon_sym_and,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
  [3841] = 33,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6771), 1,
      anon_sym_SLASH,
    ACTIONS(6781), 1,
      anon_sym_GT_GT,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6789), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6797), 1,
      anon_sym_as,
    ACTIONS(6799), 1,
      anon_sym_is,
    ACTIONS(6801), 1,
      anon_sym_with,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6763), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6767), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6769), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6779), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6785), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 4,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_or,
    STATE(4779), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 15,
      anon_sym_where,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_and,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
  [3972] = 37,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6771), 1,
      anon_sym_SLASH,
    ACTIONS(6773), 1,
      anon_sym_CARET,
    ACTIONS(6775), 1,
      anon_sym_PIPE,
    ACTIONS(6777), 1,
      anon_sym_AMP,
    ACTIONS(6781), 1,
      anon_sym_GT_GT,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6789), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6797), 1,
      anon_sym_as,
    ACTIONS(6799), 1,
      anon_sym_is,
    ACTIONS(6801), 1,
      anon_sym_with,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_or,
    ACTIONS(6763), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6767), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6769), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6779), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6783), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6785), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(4780), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 12,
      anon_sym_where,
      anon_sym_and,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
  [4111] = 38,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6771), 1,
      anon_sym_SLASH,
    ACTIONS(6773), 1,
      anon_sym_CARET,
    ACTIONS(6775), 1,
      anon_sym_PIPE,
    ACTIONS(6777), 1,
      anon_sym_AMP,
    ACTIONS(6781), 1,
      anon_sym_GT_GT,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6789), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6791), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6797), 1,
      anon_sym_as,
    ACTIONS(6799), 1,
      anon_sym_is,
    ACTIONS(6801), 1,
      anon_sym_with,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_or,
    ACTIONS(6763), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6767), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6769), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6779), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6783), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6785), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(4781), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 11,
      anon_sym_where,
      anon_sym_and,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
  [4252] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6771), 1,
      anon_sym_SLASH,
    ACTIONS(6773), 1,
      anon_sym_CARET,
    ACTIONS(6775), 1,
      anon_sym_PIPE,
    ACTIONS(6777), 1,
      anon_sym_AMP,
    ACTIONS(6781), 1,
      anon_sym_GT_GT,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6789), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6791), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6793), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6795), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(6797), 1,
      anon_sym_as,
    ACTIONS(6799), 1,
      anon_sym_is,
    ACTIONS(6801), 1,
      anon_sym_with,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_or,
    ACTIONS(6763), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6767), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6769), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6779), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6783), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6785), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 9,
      anon_sym_where,
      anon_sym_and,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
    STATE(4782), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [4397] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3193), 1,
      sym__identifier_token,
    ACTIONS(3205), 1,
      anon_sym_LPAREN,
    ACTIONS(3233), 1,
      anon_sym_var,
    ACTIONS(5747), 1,
      anon_sym_delegate,
    ACTIONS(5755), 1,
      sym_predefined_type,
    ACTIONS(5980), 1,
      anon_sym_scoped,
    ACTIONS(6507), 1,
      anon_sym_ref,
    STATE(4513), 1,
      sym__reserved_identifier,
    STATE(4947), 1,
      sym_identifier,
    STATE(5019), 1,
      sym_generic_name,
    STATE(7943), 1,
      sym__name,
    STATE(8173), 1,
      sym_tuple_type,
    STATE(8347), 1,
      sym_array_type,
    STATE(8852), 1,
      sym__array_base_type,
    STATE(8870), 1,
      sym_type,
    STATE(9367), 1,
      sym__pointer_base_type,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(5385), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(8787), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(4783), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3197), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [4524] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4248), 1,
      sym__identifier_token,
    ACTIONS(4542), 1,
      anon_sym_ref,
    ACTIONS(6168), 1,
      anon_sym_delegate,
    ACTIONS(6170), 1,
      anon_sym_scoped,
    ACTIONS(6172), 1,
      anon_sym_var,
    ACTIONS(6174), 1,
      sym_predefined_type,
    ACTIONS(6620), 1,
      anon_sym_LPAREN,
    STATE(3911), 1,
      sym__reserved_identifier,
    STATE(3958), 1,
      sym_array_type,
    STATE(3959), 1,
      sym_generic_name,
    STATE(3962), 1,
      sym_tuple_type,
    STATE(4113), 1,
      sym_type,
    STATE(5502), 1,
      sym_identifier,
    STATE(6204), 1,
      sym__name,
    STATE(8941), 1,
      sym__array_base_type,
    STATE(9806), 1,
      sym__pointer_base_type,
    STATE(3961), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4031), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(4085), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(4784), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4250), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [4651] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3193), 1,
      sym__identifier_token,
    ACTIONS(3205), 1,
      anon_sym_LPAREN,
    ACTIONS(3235), 1,
      sym_predefined_type,
    ACTIONS(4002), 1,
      anon_sym_delegate,
    ACTIONS(6582), 1,
      anon_sym_var,
    ACTIONS(6596), 1,
      anon_sym_ref,
    ACTIONS(6600), 1,
      anon_sym_scoped,
    STATE(4513), 1,
      sym__reserved_identifier,
    STATE(4947), 1,
      sym_identifier,
    STATE(5019), 1,
      sym_generic_name,
    STATE(5295), 1,
      sym_tuple_type,
    STATE(5365), 1,
      sym__name,
    STATE(5473), 1,
      sym_array_type,
    STATE(8852), 1,
      sym__array_base_type,
    STATE(9393), 1,
      sym_type,
    STATE(9443), 1,
      sym__pointer_base_type,
    STATE(2906), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(5385), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4785), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3197), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [4778] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6803), 1,
      anon_sym_LT,
    STATE(5001), 1,
      sym_type_argument_list,
    STATE(4786), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4140), 15,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_STAR,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_DASH_GT,
    ACTIONS(4138), 28,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_operator,
      anon_sym_this,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      sym_discard,
      anon_sym_and,
      anon_sym_or,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [4873] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5233), 1,
      anon_sym_DASH_GT,
    ACTIONS(5239), 1,
      anon_sym_DOT,
    ACTIONS(6124), 1,
      anon_sym_LPAREN,
    ACTIONS(6156), 1,
      anon_sym_LBRACK,
    ACTIONS(6158), 1,
      anon_sym_BANG,
    ACTIONS(6216), 1,
      anon_sym_switch,
    ACTIONS(6232), 1,
      anon_sym_with,
    ACTIONS(6406), 1,
      anon_sym_as,
    ACTIONS(6727), 1,
      anon_sym_QMARK,
    ACTIONS(6733), 1,
      anon_sym_SLASH,
    ACTIONS(6735), 1,
      anon_sym_CARET,
    ACTIONS(6737), 1,
      anon_sym_PIPE,
    ACTIONS(6739), 1,
      anon_sym_AMP,
    ACTIONS(6743), 1,
      anon_sym_GT_GT,
    ACTIONS(6749), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6751), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6753), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6755), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(6757), 1,
      anon_sym_is,
    STATE(3577), 1,
      sym_bracketed_argument_list,
    STATE(4561), 1,
      sym_argument_list,
    ACTIONS(6160), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6725), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6729), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6731), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6741), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6745), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6747), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(4787), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6324), 10,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_select,
  [5018] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4349), 1,
      sym__identifier_token,
    ACTIONS(4512), 1,
      anon_sym_delegate,
    ACTIONS(4516), 1,
      anon_sym_var,
    ACTIONS(4518), 1,
      sym_predefined_type,
    ACTIONS(4723), 1,
      anon_sym_ref,
    ACTIONS(6352), 1,
      anon_sym_scoped,
    ACTIONS(6584), 1,
      anon_sym_LPAREN,
    STATE(3590), 1,
      sym_identifier,
    STATE(3625), 1,
      sym__reserved_identifier,
    STATE(3631), 1,
      sym_tuple_type,
    STATE(3639), 1,
      sym_type,
    STATE(3648), 1,
      sym_generic_name,
    STATE(3725), 1,
      sym_array_type,
    STATE(3744), 1,
      sym__name,
    STATE(8829), 1,
      sym__array_base_type,
    STATE(9538), 1,
      sym__pointer_base_type,
    STATE(3680), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(3681), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(3707), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(4788), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4351), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [5145] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4328), 1,
      sym__identifier_token,
    ACTIONS(4725), 1,
      anon_sym_ref,
    ACTIONS(6148), 1,
      anon_sym_delegate,
    ACTIONS(6152), 1,
      anon_sym_var,
    ACTIONS(6154), 1,
      sym_predefined_type,
    ACTIONS(6372), 1,
      anon_sym_scoped,
    ACTIONS(6654), 1,
      anon_sym_LPAREN,
    STATE(3572), 1,
      sym__reserved_identifier,
    STATE(3597), 1,
      sym_generic_name,
    STATE(3608), 1,
      sym_array_type,
    STATE(3621), 1,
      sym_tuple_type,
    STATE(3624), 1,
      sym_type,
    STATE(4004), 1,
      sym_identifier,
    STATE(4343), 1,
      sym__name,
    STATE(8805), 1,
      sym__array_base_type,
    STATE(9071), 1,
      sym__pointer_base_type,
    STATE(3588), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(3596), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(3612), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4789), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4330), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [5272] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3193), 1,
      sym__identifier_token,
    ACTIONS(3205), 1,
      anon_sym_LPAREN,
    ACTIONS(3235), 1,
      sym_predefined_type,
    ACTIONS(4002), 1,
      anon_sym_delegate,
    ACTIONS(6582), 1,
      anon_sym_var,
    ACTIONS(6596), 1,
      anon_sym_ref,
    ACTIONS(6600), 1,
      anon_sym_scoped,
    STATE(4513), 1,
      sym__reserved_identifier,
    STATE(4947), 1,
      sym_identifier,
    STATE(5019), 1,
      sym_generic_name,
    STATE(5295), 1,
      sym_tuple_type,
    STATE(5365), 1,
      sym__name,
    STATE(5473), 1,
      sym_array_type,
    STATE(8852), 1,
      sym__array_base_type,
    STATE(9443), 1,
      sym__pointer_base_type,
    STATE(9587), 1,
      sym_type,
    STATE(2906), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(5385), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4790), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3197), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [5399] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4328), 1,
      sym__identifier_token,
    ACTIONS(4332), 1,
      anon_sym_ref,
    ACTIONS(6148), 1,
      anon_sym_delegate,
    ACTIONS(6152), 1,
      anon_sym_var,
    ACTIONS(6154), 1,
      sym_predefined_type,
    ACTIONS(6252), 1,
      anon_sym_scoped,
    ACTIONS(6654), 1,
      anon_sym_LPAREN,
    STATE(3572), 1,
      sym__reserved_identifier,
    STATE(3597), 1,
      sym_generic_name,
    STATE(3608), 1,
      sym_array_type,
    STATE(3621), 1,
      sym_tuple_type,
    STATE(3712), 1,
      sym_type,
    STATE(4004), 1,
      sym_identifier,
    STATE(4343), 1,
      sym__name,
    STATE(8805), 1,
      sym__array_base_type,
    STATE(9071), 1,
      sym__pointer_base_type,
    STATE(3588), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(3596), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(3612), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4791), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4330), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [5526] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3193), 1,
      sym__identifier_token,
    ACTIONS(3205), 1,
      anon_sym_LPAREN,
    ACTIONS(3235), 1,
      sym_predefined_type,
    ACTIONS(4002), 1,
      anon_sym_delegate,
    ACTIONS(6582), 1,
      anon_sym_var,
    ACTIONS(6596), 1,
      anon_sym_ref,
    ACTIONS(6600), 1,
      anon_sym_scoped,
    STATE(4513), 1,
      sym__reserved_identifier,
    STATE(4947), 1,
      sym_identifier,
    STATE(5019), 1,
      sym_generic_name,
    STATE(5295), 1,
      sym_tuple_type,
    STATE(5365), 1,
      sym__name,
    STATE(5473), 1,
      sym_array_type,
    STATE(8852), 1,
      sym__array_base_type,
    STATE(9443), 1,
      sym__pointer_base_type,
    STATE(9596), 1,
      sym_type,
    STATE(2906), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(5385), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4792), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3197), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [5653] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3193), 1,
      sym__identifier_token,
    ACTIONS(3205), 1,
      anon_sym_LPAREN,
    ACTIONS(3235), 1,
      sym_predefined_type,
    ACTIONS(4002), 1,
      anon_sym_delegate,
    ACTIONS(6582), 1,
      anon_sym_var,
    ACTIONS(6596), 1,
      anon_sym_ref,
    ACTIONS(6600), 1,
      anon_sym_scoped,
    STATE(4513), 1,
      sym__reserved_identifier,
    STATE(4947), 1,
      sym_identifier,
    STATE(5019), 1,
      sym_generic_name,
    STATE(5295), 1,
      sym_tuple_type,
    STATE(5365), 1,
      sym__name,
    STATE(5473), 1,
      sym_array_type,
    STATE(8852), 1,
      sym__array_base_type,
    STATE(9443), 1,
      sym__pointer_base_type,
    STATE(9597), 1,
      sym_type,
    STATE(2906), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(5385), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4793), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3197), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [5780] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3193), 1,
      sym__identifier_token,
    ACTIONS(3205), 1,
      anon_sym_LPAREN,
    ACTIONS(3235), 1,
      sym_predefined_type,
    ACTIONS(4002), 1,
      anon_sym_delegate,
    ACTIONS(5369), 1,
      anon_sym_var,
    ACTIONS(6717), 1,
      anon_sym_ref,
    ACTIONS(6721), 1,
      anon_sym_scoped,
    STATE(4513), 1,
      sym__reserved_identifier,
    STATE(4947), 1,
      sym_identifier,
    STATE(5019), 1,
      sym_generic_name,
    STATE(5295), 1,
      sym_tuple_type,
    STATE(5365), 1,
      sym__name,
    STATE(5473), 1,
      sym_array_type,
    STATE(8852), 1,
      sym__array_base_type,
    STATE(9443), 1,
      sym__pointer_base_type,
    STATE(9674), 1,
      sym_type,
    STATE(2906), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(5385), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4794), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3197), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [5907] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3193), 1,
      sym__identifier_token,
    ACTIONS(3205), 1,
      anon_sym_LPAREN,
    ACTIONS(3235), 1,
      sym_predefined_type,
    ACTIONS(4002), 1,
      anon_sym_delegate,
    ACTIONS(5369), 1,
      anon_sym_var,
    ACTIONS(6717), 1,
      anon_sym_ref,
    ACTIONS(6721), 1,
      anon_sym_scoped,
    STATE(4513), 1,
      sym__reserved_identifier,
    STATE(4947), 1,
      sym_identifier,
    STATE(5019), 1,
      sym_generic_name,
    STATE(5295), 1,
      sym_tuple_type,
    STATE(5365), 1,
      sym__name,
    STATE(5473), 1,
      sym_array_type,
    STATE(8852), 1,
      sym__array_base_type,
    STATE(9443), 1,
      sym__pointer_base_type,
    STATE(9873), 1,
      sym_type,
    STATE(2906), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(5385), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4795), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3197), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [6034] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3193), 1,
      sym__identifier_token,
    ACTIONS(3205), 1,
      anon_sym_LPAREN,
    ACTIONS(3235), 1,
      sym_predefined_type,
    ACTIONS(4002), 1,
      anon_sym_delegate,
    ACTIONS(6582), 1,
      anon_sym_var,
    ACTIONS(6596), 1,
      anon_sym_ref,
    ACTIONS(6600), 1,
      anon_sym_scoped,
    STATE(4513), 1,
      sym__reserved_identifier,
    STATE(4947), 1,
      sym_identifier,
    STATE(5019), 1,
      sym_generic_name,
    STATE(5295), 1,
      sym_tuple_type,
    STATE(5365), 1,
      sym__name,
    STATE(5473), 1,
      sym_array_type,
    STATE(8852), 1,
      sym__array_base_type,
    STATE(9443), 1,
      sym__pointer_base_type,
    STATE(9901), 1,
      sym_type,
    STATE(2906), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(5385), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4796), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3197), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [6161] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3193), 1,
      sym__identifier_token,
    ACTIONS(3205), 1,
      anon_sym_LPAREN,
    ACTIONS(3235), 1,
      sym_predefined_type,
    ACTIONS(4002), 1,
      anon_sym_delegate,
    ACTIONS(6582), 1,
      anon_sym_var,
    ACTIONS(6596), 1,
      anon_sym_ref,
    ACTIONS(6600), 1,
      anon_sym_scoped,
    STATE(4513), 1,
      sym__reserved_identifier,
    STATE(4947), 1,
      sym_identifier,
    STATE(5019), 1,
      sym_generic_name,
    STATE(5295), 1,
      sym_tuple_type,
    STATE(5365), 1,
      sym__name,
    STATE(5473), 1,
      sym_array_type,
    STATE(8852), 1,
      sym__array_base_type,
    STATE(9443), 1,
      sym__pointer_base_type,
    STATE(9614), 1,
      sym_type,
    STATE(2906), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(5385), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4797), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3197), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [6288] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3193), 1,
      sym__identifier_token,
    ACTIONS(3205), 1,
      anon_sym_LPAREN,
    ACTIONS(3235), 1,
      sym_predefined_type,
    ACTIONS(4002), 1,
      anon_sym_delegate,
    ACTIONS(5369), 1,
      anon_sym_var,
    ACTIONS(6717), 1,
      anon_sym_ref,
    ACTIONS(6721), 1,
      anon_sym_scoped,
    STATE(4513), 1,
      sym__reserved_identifier,
    STATE(4947), 1,
      sym_identifier,
    STATE(5019), 1,
      sym_generic_name,
    STATE(5295), 1,
      sym_tuple_type,
    STATE(5365), 1,
      sym__name,
    STATE(5473), 1,
      sym_array_type,
    STATE(8852), 1,
      sym__array_base_type,
    STATE(9443), 1,
      sym__pointer_base_type,
    STATE(9951), 1,
      sym_type,
    STATE(2906), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(5385), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4798), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3197), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [6415] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5233), 1,
      anon_sym_DASH_GT,
    ACTIONS(5239), 1,
      anon_sym_DOT,
    ACTIONS(6124), 1,
      anon_sym_LPAREN,
    ACTIONS(6156), 1,
      anon_sym_LBRACK,
    ACTIONS(6158), 1,
      anon_sym_BANG,
    ACTIONS(6216), 1,
      anon_sym_switch,
    ACTIONS(6232), 1,
      anon_sym_with,
    ACTIONS(6406), 1,
      anon_sym_as,
    ACTIONS(6727), 1,
      anon_sym_QMARK,
    ACTIONS(6733), 1,
      anon_sym_SLASH,
    ACTIONS(6735), 1,
      anon_sym_CARET,
    ACTIONS(6737), 1,
      anon_sym_PIPE,
    ACTIONS(6739), 1,
      anon_sym_AMP,
    ACTIONS(6743), 1,
      anon_sym_GT_GT,
    ACTIONS(6749), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6751), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6753), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6755), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(6757), 1,
      anon_sym_is,
    STATE(3577), 1,
      sym_bracketed_argument_list,
    STATE(4561), 1,
      sym_argument_list,
    ACTIONS(6160), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6725), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6729), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6731), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6741), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6745), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6747), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(4799), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5416), 10,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_select,
  [6560] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4457), 1,
      sym__identifier_token,
    ACTIONS(4461), 1,
      anon_sym_ref,
    ACTIONS(6297), 1,
      anon_sym_delegate,
    ACTIONS(6301), 1,
      anon_sym_var,
    ACTIONS(6303), 1,
      sym_predefined_type,
    ACTIONS(6386), 1,
      anon_sym_scoped,
    ACTIONS(6650), 1,
      anon_sym_LPAREN,
    STATE(5076), 1,
      sym_identifier,
    STATE(5173), 1,
      sym__reserved_identifier,
    STATE(5251), 1,
      sym_array_type,
    STATE(5270), 1,
      sym__name,
    STATE(5321), 1,
      sym_tuple_type,
    STATE(5342), 1,
      sym_type,
    STATE(5408), 1,
      sym_generic_name,
    STATE(8724), 1,
      sym__array_base_type,
    STATE(9858), 1,
      sym__pointer_base_type,
    STATE(5262), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(5336), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(5341), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(4800), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4459), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [6687] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4349), 1,
      sym__identifier_token,
    ACTIONS(4512), 1,
      anon_sym_delegate,
    ACTIONS(4516), 1,
      anon_sym_var,
    ACTIONS(4518), 1,
      sym_predefined_type,
    ACTIONS(4721), 1,
      anon_sym_ref,
    ACTIONS(6307), 1,
      anon_sym_scoped,
    ACTIONS(6584), 1,
      anon_sym_LPAREN,
    STATE(3590), 1,
      sym_identifier,
    STATE(3625), 1,
      sym__reserved_identifier,
    STATE(3631), 1,
      sym_tuple_type,
    STATE(3648), 1,
      sym_generic_name,
    STATE(3725), 1,
      sym_array_type,
    STATE(3744), 1,
      sym__name,
    STATE(3772), 1,
      sym_type,
    STATE(8829), 1,
      sym__array_base_type,
    STATE(9538), 1,
      sym__pointer_base_type,
    STATE(3680), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(3681), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(3707), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(4801), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4351), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [6814] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3193), 1,
      sym__identifier_token,
    ACTIONS(3205), 1,
      anon_sym_LPAREN,
    ACTIONS(3233), 1,
      anon_sym_var,
    ACTIONS(3235), 1,
      sym_predefined_type,
    ACTIONS(4002), 1,
      anon_sym_delegate,
    ACTIONS(6608), 1,
      anon_sym_ref,
    ACTIONS(6612), 1,
      anon_sym_scoped,
    STATE(2887), 1,
      sym_type,
    STATE(4513), 1,
      sym__reserved_identifier,
    STATE(4947), 1,
      sym_identifier,
    STATE(5019), 1,
      sym_generic_name,
    STATE(5295), 1,
      sym_tuple_type,
    STATE(5365), 1,
      sym__name,
    STATE(5473), 1,
      sym_array_type,
    STATE(8852), 1,
      sym__array_base_type,
    STATE(9443), 1,
      sym__pointer_base_type,
    STATE(2906), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(5385), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4802), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3197), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [6941] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6805), 1,
      anon_sym_into,
    STATE(4804), 1,
      aux_sym__query_body_repeat2,
    STATE(4803), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6476), 12,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
      anon_sym_as,
    ACTIONS(6474), 31,
      anon_sym_LBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_where,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_select,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [7036] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6805), 1,
      anon_sym_into,
    STATE(4897), 1,
      aux_sym__query_body_repeat2,
    STATE(4804), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6482), 12,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
      anon_sym_as,
    ACTIONS(6480), 31,
      anon_sym_LBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_where,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_select,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [7131] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3193), 1,
      sym__identifier_token,
    ACTIONS(3205), 1,
      anon_sym_LPAREN,
    ACTIONS(3235), 1,
      sym_predefined_type,
    ACTIONS(4002), 1,
      anon_sym_delegate,
    ACTIONS(5369), 1,
      anon_sym_var,
    ACTIONS(6717), 1,
      anon_sym_ref,
    ACTIONS(6721), 1,
      anon_sym_scoped,
    STATE(2887), 1,
      sym_type,
    STATE(4513), 1,
      sym__reserved_identifier,
    STATE(4947), 1,
      sym_identifier,
    STATE(5019), 1,
      sym_generic_name,
    STATE(5295), 1,
      sym_tuple_type,
    STATE(5365), 1,
      sym__name,
    STATE(5473), 1,
      sym_array_type,
    STATE(8852), 1,
      sym__array_base_type,
    STATE(9443), 1,
      sym__pointer_base_type,
    STATE(2906), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(5385), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4805), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3197), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [7258] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3193), 1,
      sym__identifier_token,
    ACTIONS(3205), 1,
      anon_sym_LPAREN,
    ACTIONS(5369), 1,
      anon_sym_var,
    ACTIONS(5745), 1,
      anon_sym_ref,
    ACTIONS(5747), 1,
      anon_sym_delegate,
    ACTIONS(5753), 1,
      anon_sym_scoped,
    ACTIONS(5755), 1,
      sym_predefined_type,
    STATE(4513), 1,
      sym__reserved_identifier,
    STATE(4947), 1,
      sym_identifier,
    STATE(5019), 1,
      sym_generic_name,
    STATE(7943), 1,
      sym__name,
    STATE(8173), 1,
      sym_tuple_type,
    STATE(8347), 1,
      sym_array_type,
    STATE(8731), 1,
      sym_type,
    STATE(8852), 1,
      sym__array_base_type,
    STATE(9367), 1,
      sym__pointer_base_type,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(5385), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(8787), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(4806), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3197), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [7385] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3193), 1,
      sym__identifier_token,
    ACTIONS(3205), 1,
      anon_sym_LPAREN,
    ACTIONS(3235), 1,
      sym_predefined_type,
    ACTIONS(4002), 1,
      anon_sym_delegate,
    ACTIONS(6582), 1,
      anon_sym_var,
    ACTIONS(6596), 1,
      anon_sym_ref,
    ACTIONS(6600), 1,
      anon_sym_scoped,
    STATE(4513), 1,
      sym__reserved_identifier,
    STATE(4947), 1,
      sym_identifier,
    STATE(5019), 1,
      sym_generic_name,
    STATE(5295), 1,
      sym_tuple_type,
    STATE(5365), 1,
      sym__name,
    STATE(5473), 1,
      sym_array_type,
    STATE(8852), 1,
      sym__array_base_type,
    STATE(9443), 1,
      sym__pointer_base_type,
    STATE(9525), 1,
      sym_type,
    STATE(2906), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(5385), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4807), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3197), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [7512] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5233), 1,
      anon_sym_DASH_GT,
    ACTIONS(5239), 1,
      anon_sym_DOT,
    ACTIONS(6124), 1,
      anon_sym_LPAREN,
    ACTIONS(6156), 1,
      anon_sym_LBRACK,
    ACTIONS(6158), 1,
      anon_sym_BANG,
    ACTIONS(6216), 1,
      anon_sym_switch,
    ACTIONS(6232), 1,
      anon_sym_with,
    ACTIONS(6406), 1,
      anon_sym_as,
    ACTIONS(6727), 1,
      anon_sym_QMARK,
    ACTIONS(6733), 1,
      anon_sym_SLASH,
    ACTIONS(6735), 1,
      anon_sym_CARET,
    ACTIONS(6737), 1,
      anon_sym_PIPE,
    ACTIONS(6739), 1,
      anon_sym_AMP,
    ACTIONS(6743), 1,
      anon_sym_GT_GT,
    ACTIONS(6749), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6751), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6753), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6755), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(6757), 1,
      anon_sym_is,
    STATE(3577), 1,
      sym_bracketed_argument_list,
    STATE(4561), 1,
      sym_argument_list,
    ACTIONS(6160), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6725), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6729), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6731), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6741), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6745), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6747), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(4808), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5572), 10,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_select,
  [7657] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3193), 1,
      sym__identifier_token,
    ACTIONS(3205), 1,
      anon_sym_LPAREN,
    ACTIONS(3235), 1,
      sym_predefined_type,
    ACTIONS(4002), 1,
      anon_sym_delegate,
    ACTIONS(6582), 1,
      anon_sym_var,
    ACTIONS(6596), 1,
      anon_sym_ref,
    ACTIONS(6600), 1,
      anon_sym_scoped,
    STATE(4513), 1,
      sym__reserved_identifier,
    STATE(4947), 1,
      sym_identifier,
    STATE(5019), 1,
      sym_generic_name,
    STATE(5295), 1,
      sym_tuple_type,
    STATE(5365), 1,
      sym__name,
    STATE(5473), 1,
      sym_array_type,
    STATE(8852), 1,
      sym__array_base_type,
    STATE(9443), 1,
      sym__pointer_base_type,
    STATE(9542), 1,
      sym_type,
    STATE(2906), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(5385), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4809), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3197), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [7784] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3193), 1,
      sym__identifier_token,
    ACTIONS(3205), 1,
      anon_sym_LPAREN,
    ACTIONS(3235), 1,
      sym_predefined_type,
    ACTIONS(4002), 1,
      anon_sym_delegate,
    ACTIONS(6582), 1,
      anon_sym_var,
    ACTIONS(6596), 1,
      anon_sym_ref,
    ACTIONS(6600), 1,
      anon_sym_scoped,
    STATE(4513), 1,
      sym__reserved_identifier,
    STATE(4947), 1,
      sym_identifier,
    STATE(5019), 1,
      sym_generic_name,
    STATE(5295), 1,
      sym_tuple_type,
    STATE(5365), 1,
      sym__name,
    STATE(5473), 1,
      sym_array_type,
    STATE(8852), 1,
      sym__array_base_type,
    STATE(9443), 1,
      sym__pointer_base_type,
    STATE(9543), 1,
      sym_type,
    STATE(2906), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(5385), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4810), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3197), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [7911] = 41,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6334), 1,
      anon_sym_or,
    ACTIONS(6765), 1,
      anon_sym_QMARK,
    ACTIONS(6771), 1,
      anon_sym_SLASH,
    ACTIONS(6773), 1,
      anon_sym_CARET,
    ACTIONS(6775), 1,
      anon_sym_PIPE,
    ACTIONS(6777), 1,
      anon_sym_AMP,
    ACTIONS(6781), 1,
      anon_sym_GT_GT,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6789), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6791), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6793), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6795), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(6797), 1,
      anon_sym_as,
    ACTIONS(6799), 1,
      anon_sym_is,
    ACTIONS(6801), 1,
      anon_sym_with,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6763), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6767), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6769), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6779), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6783), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6785), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6332), 9,
      anon_sym_where,
      anon_sym_and,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
    STATE(4811), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [8058] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4328), 1,
      sym__identifier_token,
    ACTIONS(4693), 1,
      anon_sym_ref,
    ACTIONS(6148), 1,
      anon_sym_delegate,
    ACTIONS(6150), 1,
      anon_sym_scoped,
    ACTIONS(6152), 1,
      anon_sym_var,
    ACTIONS(6154), 1,
      sym_predefined_type,
    ACTIONS(6654), 1,
      anon_sym_LPAREN,
    STATE(3572), 1,
      sym__reserved_identifier,
    STATE(3597), 1,
      sym_generic_name,
    STATE(3608), 1,
      sym_array_type,
    STATE(3621), 1,
      sym_tuple_type,
    STATE(3624), 1,
      sym_type,
    STATE(4574), 1,
      sym_identifier,
    STATE(4958), 1,
      sym__name,
    STATE(8805), 1,
      sym__array_base_type,
    STATE(9071), 1,
      sym__pointer_base_type,
    STATE(3588), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(3596), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(3612), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4812), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4330), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [8185] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6805), 1,
      anon_sym_into,
    STATE(4898), 1,
      aux_sym__query_body_repeat2,
    STATE(4813), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6482), 12,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
      anon_sym_as,
    ACTIONS(6480), 31,
      anon_sym_LBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_where,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_select,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [8280] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3193), 1,
      sym__identifier_token,
    ACTIONS(3205), 1,
      anon_sym_LPAREN,
    ACTIONS(3235), 1,
      sym_predefined_type,
    ACTIONS(4002), 1,
      anon_sym_delegate,
    ACTIONS(6582), 1,
      anon_sym_var,
    ACTIONS(6596), 1,
      anon_sym_ref,
    ACTIONS(6600), 1,
      anon_sym_scoped,
    STATE(4513), 1,
      sym__reserved_identifier,
    STATE(4947), 1,
      sym_identifier,
    STATE(5019), 1,
      sym_generic_name,
    STATE(5295), 1,
      sym_tuple_type,
    STATE(5365), 1,
      sym__name,
    STATE(5473), 1,
      sym_array_type,
    STATE(8852), 1,
      sym__array_base_type,
    STATE(9008), 1,
      sym_type,
    STATE(9443), 1,
      sym__pointer_base_type,
    STATE(2906), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(5385), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4814), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3197), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [8407] = 41,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(5646), 1,
      anon_sym_in,
    ACTIONS(6723), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6809), 1,
      anon_sym_QMARK,
    ACTIONS(6815), 1,
      anon_sym_SLASH,
    ACTIONS(6817), 1,
      anon_sym_CARET,
    ACTIONS(6819), 1,
      anon_sym_PIPE,
    ACTIONS(6821), 1,
      anon_sym_AMP,
    ACTIONS(6825), 1,
      anon_sym_GT_GT,
    ACTIONS(6831), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6833), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6835), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(6837), 1,
      anon_sym_as,
    ACTIONS(6839), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6807), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6811), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6813), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6823), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6827), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6829), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5644), 9,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_into,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
    STATE(4815), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [8554] = 26,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6723), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6815), 1,
      anon_sym_SLASH,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6813), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(4816), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 21,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
  [8671] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4110), 1,
      anon_sym_ref,
    ACTIONS(6636), 1,
      sym__identifier_token,
    ACTIONS(6640), 1,
      anon_sym_LPAREN,
    ACTIONS(6642), 1,
      anon_sym_delegate,
    ACTIONS(6644), 1,
      anon_sym_scoped,
    ACTIONS(6646), 1,
      anon_sym_var,
    ACTIONS(6648), 1,
      sym_predefined_type,
    STATE(3158), 1,
      sym_identifier,
    STATE(3178), 1,
      sym__reserved_identifier,
    STATE(3326), 1,
      sym_generic_name,
    STATE(3408), 1,
      sym_type,
    STATE(3488), 1,
      sym_array_type,
    STATE(3490), 1,
      sym_tuple_type,
    STATE(3499), 1,
      sym__name,
    STATE(8756), 1,
      sym__array_base_type,
    STATE(9221), 1,
      sym__pointer_base_type,
    STATE(3330), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(3486), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(3489), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4817), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6638), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [8798] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3193), 1,
      sym__identifier_token,
    ACTIONS(3205), 1,
      anon_sym_LPAREN,
    ACTIONS(3235), 1,
      sym_predefined_type,
    ACTIONS(4002), 1,
      anon_sym_delegate,
    ACTIONS(6582), 1,
      anon_sym_var,
    ACTIONS(6596), 1,
      anon_sym_ref,
    ACTIONS(6600), 1,
      anon_sym_scoped,
    STATE(4513), 1,
      sym__reserved_identifier,
    STATE(4947), 1,
      sym_identifier,
    STATE(5019), 1,
      sym_generic_name,
    STATE(5295), 1,
      sym_tuple_type,
    STATE(5365), 1,
      sym__name,
    STATE(5473), 1,
      sym_array_type,
    STATE(8852), 1,
      sym__array_base_type,
    STATE(9181), 1,
      sym_type,
    STATE(9443), 1,
      sym__pointer_base_type,
    STATE(2906), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(5385), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4818), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3197), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [8925] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3193), 1,
      sym__identifier_token,
    ACTIONS(3205), 1,
      anon_sym_LPAREN,
    ACTIONS(3235), 1,
      sym_predefined_type,
    ACTIONS(4002), 1,
      anon_sym_delegate,
    ACTIONS(6582), 1,
      anon_sym_var,
    ACTIONS(6596), 1,
      anon_sym_ref,
    ACTIONS(6600), 1,
      anon_sym_scoped,
    STATE(4513), 1,
      sym__reserved_identifier,
    STATE(4947), 1,
      sym_identifier,
    STATE(5019), 1,
      sym_generic_name,
    STATE(5295), 1,
      sym_tuple_type,
    STATE(5365), 1,
      sym__name,
    STATE(5473), 1,
      sym_array_type,
    STATE(8852), 1,
      sym__array_base_type,
    STATE(9192), 1,
      sym_type,
    STATE(9443), 1,
      sym__pointer_base_type,
    STATE(2906), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(5385), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4819), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3197), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [9052] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3193), 1,
      sym__identifier_token,
    ACTIONS(3205), 1,
      anon_sym_LPAREN,
    ACTIONS(3235), 1,
      sym_predefined_type,
    ACTIONS(4002), 1,
      anon_sym_delegate,
    ACTIONS(6582), 1,
      anon_sym_var,
    ACTIONS(6596), 1,
      anon_sym_ref,
    ACTIONS(6600), 1,
      anon_sym_scoped,
    STATE(4513), 1,
      sym__reserved_identifier,
    STATE(4947), 1,
      sym_identifier,
    STATE(5019), 1,
      sym_generic_name,
    STATE(5295), 1,
      sym_tuple_type,
    STATE(5365), 1,
      sym__name,
    STATE(5473), 1,
      sym_array_type,
    STATE(8852), 1,
      sym__array_base_type,
    STATE(9194), 1,
      sym_type,
    STATE(9443), 1,
      sym__pointer_base_type,
    STATE(2906), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(5385), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4820), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3197), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [9179] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3193), 1,
      sym__identifier_token,
    ACTIONS(3205), 1,
      anon_sym_LPAREN,
    ACTIONS(3235), 1,
      sym_predefined_type,
    ACTIONS(4002), 1,
      anon_sym_delegate,
    ACTIONS(5369), 1,
      anon_sym_var,
    ACTIONS(6717), 1,
      anon_sym_ref,
    ACTIONS(6721), 1,
      anon_sym_scoped,
    STATE(4513), 1,
      sym__reserved_identifier,
    STATE(4947), 1,
      sym_identifier,
    STATE(5019), 1,
      sym_generic_name,
    STATE(5295), 1,
      sym_tuple_type,
    STATE(5365), 1,
      sym__name,
    STATE(5473), 1,
      sym_array_type,
    STATE(8852), 1,
      sym__array_base_type,
    STATE(9443), 1,
      sym__pointer_base_type,
    STATE(9579), 1,
      sym_type,
    STATE(2906), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(5385), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4821), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3197), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [9306] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4328), 1,
      sym__identifier_token,
    ACTIONS(4731), 1,
      anon_sym_ref,
    ACTIONS(6148), 1,
      anon_sym_delegate,
    ACTIONS(6152), 1,
      anon_sym_var,
    ACTIONS(6154), 1,
      sym_predefined_type,
    ACTIONS(6264), 1,
      anon_sym_scoped,
    ACTIONS(6654), 1,
      anon_sym_LPAREN,
    STATE(3572), 1,
      sym__reserved_identifier,
    STATE(3597), 1,
      sym_generic_name,
    STATE(3608), 1,
      sym_array_type,
    STATE(3621), 1,
      sym_tuple_type,
    STATE(3624), 1,
      sym_type,
    STATE(4004), 1,
      sym_identifier,
    STATE(4343), 1,
      sym__name,
    STATE(8805), 1,
      sym__array_base_type,
    STATE(9071), 1,
      sym__pointer_base_type,
    STATE(3588), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(3596), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(3612), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4822), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4330), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [9433] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3193), 1,
      sym__identifier_token,
    ACTIONS(3205), 1,
      anon_sym_LPAREN,
    ACTIONS(3235), 1,
      sym_predefined_type,
    ACTIONS(4002), 1,
      anon_sym_delegate,
    ACTIONS(6582), 1,
      anon_sym_var,
    ACTIONS(6596), 1,
      anon_sym_ref,
    ACTIONS(6600), 1,
      anon_sym_scoped,
    STATE(4513), 1,
      sym__reserved_identifier,
    STATE(4947), 1,
      sym_identifier,
    STATE(5019), 1,
      sym_generic_name,
    STATE(5295), 1,
      sym_tuple_type,
    STATE(5365), 1,
      sym__name,
    STATE(5473), 1,
      sym_array_type,
    STATE(8852), 1,
      sym__array_base_type,
    STATE(9305), 1,
      sym_type,
    STATE(9443), 1,
      sym__pointer_base_type,
    STATE(2906), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(5385), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4823), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3197), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [9560] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4072), 1,
      sym__identifier_token,
    ACTIONS(4153), 1,
      anon_sym_ref,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(2883), 1,
      sym_ref_type,
    STATE(2885), 1,
      sym__scoped_base_type,
    STATE(6769), 1,
      sym_identifier,
    STATE(6889), 1,
      sym__name,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    ACTIONS(3995), 4,
      anon_sym_COLON,
      sym_discard,
      anon_sym_and,
      anon_sym_or,
    ACTIONS(3993), 8,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_STAR,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
    STATE(4824), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4075), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [9671] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5233), 1,
      anon_sym_DASH_GT,
    ACTIONS(5239), 1,
      anon_sym_DOT,
    ACTIONS(6124), 1,
      anon_sym_LPAREN,
    ACTIONS(6156), 1,
      anon_sym_LBRACK,
    ACTIONS(6158), 1,
      anon_sym_BANG,
    ACTIONS(6216), 1,
      anon_sym_switch,
    ACTIONS(6232), 1,
      anon_sym_with,
    ACTIONS(6406), 1,
      anon_sym_as,
    ACTIONS(6727), 1,
      anon_sym_QMARK,
    ACTIONS(6733), 1,
      anon_sym_SLASH,
    ACTIONS(6735), 1,
      anon_sym_CARET,
    ACTIONS(6737), 1,
      anon_sym_PIPE,
    ACTIONS(6739), 1,
      anon_sym_AMP,
    ACTIONS(6743), 1,
      anon_sym_GT_GT,
    ACTIONS(6749), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6751), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6753), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6755), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(6757), 1,
      anon_sym_is,
    STATE(3577), 1,
      sym_bracketed_argument_list,
    STATE(4561), 1,
      sym_argument_list,
    ACTIONS(6160), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6725), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6729), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6731), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6741), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6745), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6747), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(4825), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5584), 10,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_select,
  [9816] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4457), 1,
      sym__identifier_token,
    ACTIONS(4474), 1,
      anon_sym_ref,
    ACTIONS(6297), 1,
      anon_sym_delegate,
    ACTIONS(6299), 1,
      anon_sym_scoped,
    ACTIONS(6301), 1,
      anon_sym_var,
    ACTIONS(6303), 1,
      sym_predefined_type,
    ACTIONS(6650), 1,
      anon_sym_LPAREN,
    STATE(5076), 1,
      sym_identifier,
    STATE(5173), 1,
      sym__reserved_identifier,
    STATE(5251), 1,
      sym_array_type,
    STATE(5270), 1,
      sym__name,
    STATE(5321), 1,
      sym_tuple_type,
    STATE(5342), 1,
      sym_type,
    STATE(5408), 1,
      sym_generic_name,
    STATE(8724), 1,
      sym__array_base_type,
    STATE(9858), 1,
      sym__pointer_base_type,
    STATE(5262), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(5336), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(5341), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(4826), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4459), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [9943] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4248), 1,
      sym__identifier_token,
    ACTIONS(4523), 1,
      anon_sym_ref,
    ACTIONS(6168), 1,
      anon_sym_delegate,
    ACTIONS(6172), 1,
      anon_sym_var,
    ACTIONS(6174), 1,
      sym_predefined_type,
    ACTIONS(6278), 1,
      anon_sym_scoped,
    ACTIONS(6620), 1,
      anon_sym_LPAREN,
    STATE(3889), 1,
      sym_identifier,
    STATE(3911), 1,
      sym__reserved_identifier,
    STATE(3958), 1,
      sym_array_type,
    STATE(3959), 1,
      sym_generic_name,
    STATE(3962), 1,
      sym_tuple_type,
    STATE(4113), 1,
      sym_type,
    STATE(4158), 1,
      sym__name,
    STATE(8941), 1,
      sym__array_base_type,
    STATE(9806), 1,
      sym__pointer_base_type,
    STATE(3961), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4031), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(4085), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(4827), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4250), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [10070] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3193), 1,
      sym__identifier_token,
    ACTIONS(3205), 1,
      anon_sym_LPAREN,
    ACTIONS(3235), 1,
      sym_predefined_type,
    ACTIONS(4002), 1,
      anon_sym_delegate,
    ACTIONS(6582), 1,
      anon_sym_var,
    ACTIONS(6596), 1,
      anon_sym_ref,
    ACTIONS(6600), 1,
      anon_sym_scoped,
    STATE(4513), 1,
      sym__reserved_identifier,
    STATE(4947), 1,
      sym_identifier,
    STATE(5019), 1,
      sym_generic_name,
    STATE(5295), 1,
      sym_tuple_type,
    STATE(5365), 1,
      sym__name,
    STATE(5473), 1,
      sym_array_type,
    STATE(8852), 1,
      sym__array_base_type,
    STATE(9072), 1,
      sym_type,
    STATE(9443), 1,
      sym__pointer_base_type,
    STATE(2906), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(5385), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4828), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3197), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [10197] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4349), 1,
      sym__identifier_token,
    ACTIONS(4512), 1,
      anon_sym_delegate,
    ACTIONS(4516), 1,
      anon_sym_var,
    ACTIONS(4518), 1,
      sym_predefined_type,
    ACTIONS(4721), 1,
      anon_sym_ref,
    ACTIONS(6307), 1,
      anon_sym_scoped,
    ACTIONS(6584), 1,
      anon_sym_LPAREN,
    STATE(3590), 1,
      sym_identifier,
    STATE(3625), 1,
      sym__reserved_identifier,
    STATE(3631), 1,
      sym_tuple_type,
    STATE(3639), 1,
      sym_type,
    STATE(3648), 1,
      sym_generic_name,
    STATE(3725), 1,
      sym_array_type,
    STATE(3744), 1,
      sym__name,
    STATE(8829), 1,
      sym__array_base_type,
    STATE(9538), 1,
      sym__pointer_base_type,
    STATE(3680), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(3681), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(3707), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(4829), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4351), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [10324] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4349), 1,
      sym__identifier_token,
    ACTIONS(4512), 1,
      anon_sym_delegate,
    ACTIONS(4516), 1,
      anon_sym_var,
    ACTIONS(4518), 1,
      sym_predefined_type,
    ACTIONS(4723), 1,
      anon_sym_ref,
    ACTIONS(6352), 1,
      anon_sym_scoped,
    ACTIONS(6584), 1,
      anon_sym_LPAREN,
    STATE(3590), 1,
      sym_identifier,
    STATE(3625), 1,
      sym__reserved_identifier,
    STATE(3631), 1,
      sym_tuple_type,
    STATE(3648), 1,
      sym_generic_name,
    STATE(3725), 1,
      sym_array_type,
    STATE(3744), 1,
      sym__name,
    STATE(3772), 1,
      sym_type,
    STATE(8829), 1,
      sym__array_base_type,
    STATE(9538), 1,
      sym__pointer_base_type,
    STATE(3680), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(3681), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(3707), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(4830), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4351), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [10451] = 36,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6723), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6815), 1,
      anon_sym_SLASH,
    ACTIONS(6817), 1,
      anon_sym_CARET,
    ACTIONS(6821), 1,
      anon_sym_AMP,
    ACTIONS(6825), 1,
      anon_sym_GT_GT,
    ACTIONS(6837), 1,
      anon_sym_as,
    ACTIONS(6839), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6807), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6811), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6813), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6823), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6827), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6829), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PIPE,
    STATE(4831), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 12,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
  [10588] = 41,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6268), 1,
      anon_sym_or,
    ACTIONS(6765), 1,
      anon_sym_QMARK,
    ACTIONS(6771), 1,
      anon_sym_SLASH,
    ACTIONS(6773), 1,
      anon_sym_CARET,
    ACTIONS(6775), 1,
      anon_sym_PIPE,
    ACTIONS(6777), 1,
      anon_sym_AMP,
    ACTIONS(6781), 1,
      anon_sym_GT_GT,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6789), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6791), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6793), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6795), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(6797), 1,
      anon_sym_as,
    ACTIONS(6799), 1,
      anon_sym_is,
    ACTIONS(6801), 1,
      anon_sym_with,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6763), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6767), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6769), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6779), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6783), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6785), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6266), 9,
      anon_sym_where,
      anon_sym_and,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
    STATE(4832), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [10735] = 41,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6322), 1,
      anon_sym_in,
    ACTIONS(6723), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6809), 1,
      anon_sym_QMARK,
    ACTIONS(6815), 1,
      anon_sym_SLASH,
    ACTIONS(6817), 1,
      anon_sym_CARET,
    ACTIONS(6819), 1,
      anon_sym_PIPE,
    ACTIONS(6821), 1,
      anon_sym_AMP,
    ACTIONS(6825), 1,
      anon_sym_GT_GT,
    ACTIONS(6831), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6833), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6835), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(6837), 1,
      anon_sym_as,
    ACTIONS(6839), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6807), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6811), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6813), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6823), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6827), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6829), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6320), 9,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_into,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
    STATE(4833), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [10882] = 41,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6272), 1,
      anon_sym_or,
    ACTIONS(6765), 1,
      anon_sym_QMARK,
    ACTIONS(6771), 1,
      anon_sym_SLASH,
    ACTIONS(6773), 1,
      anon_sym_CARET,
    ACTIONS(6775), 1,
      anon_sym_PIPE,
    ACTIONS(6777), 1,
      anon_sym_AMP,
    ACTIONS(6781), 1,
      anon_sym_GT_GT,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6789), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6791), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6793), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6795), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(6797), 1,
      anon_sym_as,
    ACTIONS(6799), 1,
      anon_sym_is,
    ACTIONS(6801), 1,
      anon_sym_with,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6763), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6767), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6769), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6779), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6783), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6785), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6270), 9,
      anon_sym_where,
      anon_sym_and,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
    STATE(4834), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [11029] = 41,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6220), 1,
      anon_sym_or,
    ACTIONS(6765), 1,
      anon_sym_QMARK,
    ACTIONS(6771), 1,
      anon_sym_SLASH,
    ACTIONS(6773), 1,
      anon_sym_CARET,
    ACTIONS(6775), 1,
      anon_sym_PIPE,
    ACTIONS(6777), 1,
      anon_sym_AMP,
    ACTIONS(6781), 1,
      anon_sym_GT_GT,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6789), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6791), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6793), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6795), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(6797), 1,
      anon_sym_as,
    ACTIONS(6799), 1,
      anon_sym_is,
    ACTIONS(6801), 1,
      anon_sym_with,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6763), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6767), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6769), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6779), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6783), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6785), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6190), 9,
      anon_sym_where,
      anon_sym_and,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
    STATE(4835), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [11176] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4349), 1,
      sym__identifier_token,
    ACTIONS(4353), 1,
      anon_sym_ref,
    ACTIONS(4512), 1,
      anon_sym_delegate,
    ACTIONS(4514), 1,
      anon_sym_scoped,
    ACTIONS(4516), 1,
      anon_sym_var,
    ACTIONS(4518), 1,
      sym_predefined_type,
    ACTIONS(6584), 1,
      anon_sym_LPAREN,
    STATE(3590), 1,
      sym_identifier,
    STATE(3625), 1,
      sym__reserved_identifier,
    STATE(3631), 1,
      sym_tuple_type,
    STATE(3639), 1,
      sym_type,
    STATE(3648), 1,
      sym_generic_name,
    STATE(3725), 1,
      sym_array_type,
    STATE(3744), 1,
      sym__name,
    STATE(8829), 1,
      sym__array_base_type,
    STATE(9538), 1,
      sym__pointer_base_type,
    STATE(3680), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(3681), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(3707), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(4836), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4351), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [11303] = 34,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6723), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6815), 1,
      anon_sym_SLASH,
    ACTIONS(6825), 1,
      anon_sym_GT_GT,
    ACTIONS(6837), 1,
      anon_sym_as,
    ACTIONS(6839), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6807), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6811), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6813), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6823), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6827), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6829), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 4,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    STATE(4837), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 13,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
  [11436] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4328), 1,
      sym__identifier_token,
    ACTIONS(4727), 1,
      anon_sym_ref,
    ACTIONS(6148), 1,
      anon_sym_delegate,
    ACTIONS(6152), 1,
      anon_sym_var,
    ACTIONS(6154), 1,
      sym_predefined_type,
    ACTIONS(6274), 1,
      anon_sym_scoped,
    ACTIONS(6654), 1,
      anon_sym_LPAREN,
    STATE(3572), 1,
      sym__reserved_identifier,
    STATE(3597), 1,
      sym_generic_name,
    STATE(3608), 1,
      sym_array_type,
    STATE(3621), 1,
      sym_tuple_type,
    STATE(3624), 1,
      sym_type,
    STATE(4004), 1,
      sym_identifier,
    STATE(4343), 1,
      sym__name,
    STATE(8805), 1,
      sym__array_base_type,
    STATE(9071), 1,
      sym__pointer_base_type,
    STATE(3588), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(3596), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(3612), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4838), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4330), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [11563] = 37,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6723), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6815), 1,
      anon_sym_SLASH,
    ACTIONS(6817), 1,
      anon_sym_CARET,
    ACTIONS(6819), 1,
      anon_sym_PIPE,
    ACTIONS(6821), 1,
      anon_sym_AMP,
    ACTIONS(6825), 1,
      anon_sym_GT_GT,
    ACTIONS(6837), 1,
      anon_sym_as,
    ACTIONS(6839), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_in,
      anon_sym_QMARK,
    ACTIONS(6807), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6811), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6813), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6823), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6827), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6829), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(4839), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 12,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
  [11702] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4002), 1,
      anon_sym_delegate,
    ACTIONS(4536), 1,
      sym__identifier_token,
    ACTIONS(4540), 1,
      anon_sym_ref,
    ACTIONS(6246), 1,
      anon_sym_var,
    ACTIONS(6248), 1,
      sym_predefined_type,
    ACTIONS(6362), 1,
      anon_sym_scoped,
    ACTIONS(6602), 1,
      anon_sym_LPAREN,
    STATE(2920), 1,
      sym_identifier,
    STATE(2928), 1,
      sym__reserved_identifier,
    STATE(2944), 1,
      sym_generic_name,
    STATE(2966), 1,
      sym_array_type,
    STATE(2971), 1,
      sym_tuple_type,
    STATE(2992), 1,
      sym__name,
    STATE(4631), 1,
      sym_type,
    STATE(8753), 1,
      sym__array_base_type,
    STATE(9443), 1,
      sym__pointer_base_type,
    STATE(2906), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(2956), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(2970), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4840), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4538), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [11829] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5233), 1,
      anon_sym_DASH_GT,
    ACTIONS(5239), 1,
      anon_sym_DOT,
    ACTIONS(6124), 1,
      anon_sym_LPAREN,
    ACTIONS(6156), 1,
      anon_sym_LBRACK,
    ACTIONS(6158), 1,
      anon_sym_BANG,
    ACTIONS(6216), 1,
      anon_sym_switch,
    ACTIONS(6232), 1,
      anon_sym_with,
    ACTIONS(6406), 1,
      anon_sym_as,
    ACTIONS(6727), 1,
      anon_sym_QMARK,
    ACTIONS(6733), 1,
      anon_sym_SLASH,
    ACTIONS(6735), 1,
      anon_sym_CARET,
    ACTIONS(6737), 1,
      anon_sym_PIPE,
    ACTIONS(6739), 1,
      anon_sym_AMP,
    ACTIONS(6743), 1,
      anon_sym_GT_GT,
    ACTIONS(6749), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6751), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6753), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6755), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(6757), 1,
      anon_sym_is,
    STATE(3577), 1,
      sym_bracketed_argument_list,
    STATE(4561), 1,
      sym_argument_list,
    ACTIONS(6160), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6725), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6729), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6731), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6741), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6745), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6747), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(4841), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6190), 10,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_select,
  [11974] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4349), 1,
      sym__identifier_token,
    ACTIONS(4512), 1,
      anon_sym_delegate,
    ACTIONS(4516), 1,
      anon_sym_var,
    ACTIONS(4518), 1,
      sym_predefined_type,
    ACTIONS(4729), 1,
      anon_sym_ref,
    ACTIONS(6254), 1,
      anon_sym_scoped,
    ACTIONS(6584), 1,
      anon_sym_LPAREN,
    STATE(3590), 1,
      sym_identifier,
    STATE(3625), 1,
      sym__reserved_identifier,
    STATE(3631), 1,
      sym_tuple_type,
    STATE(3639), 1,
      sym_type,
    STATE(3648), 1,
      sym_generic_name,
    STATE(3725), 1,
      sym_array_type,
    STATE(3744), 1,
      sym__name,
    STATE(8829), 1,
      sym__array_base_type,
    STATE(9538), 1,
      sym__pointer_base_type,
    STATE(3680), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(3681), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(3707), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(4842), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4351), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [12101] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3193), 1,
      sym__identifier_token,
    ACTIONS(3205), 1,
      anon_sym_LPAREN,
    ACTIONS(3235), 1,
      sym_predefined_type,
    ACTIONS(4002), 1,
      anon_sym_delegate,
    ACTIONS(4078), 1,
      anon_sym_ref,
    ACTIONS(5369), 1,
      anon_sym_var,
    ACTIONS(6140), 1,
      anon_sym_scoped,
    STATE(2887), 1,
      sym_type,
    STATE(4513), 1,
      sym__reserved_identifier,
    STATE(4947), 1,
      sym_identifier,
    STATE(5019), 1,
      sym_generic_name,
    STATE(5295), 1,
      sym_tuple_type,
    STATE(5365), 1,
      sym__name,
    STATE(5473), 1,
      sym_array_type,
    STATE(8852), 1,
      sym__array_base_type,
    STATE(9443), 1,
      sym__pointer_base_type,
    STATE(2906), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(5385), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4843), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3197), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [12228] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3193), 1,
      sym__identifier_token,
    ACTIONS(3205), 1,
      anon_sym_LPAREN,
    ACTIONS(3233), 1,
      anon_sym_var,
    ACTIONS(3235), 1,
      sym_predefined_type,
    ACTIONS(4002), 1,
      anon_sym_delegate,
    ACTIONS(6608), 1,
      anon_sym_ref,
    ACTIONS(6612), 1,
      anon_sym_scoped,
    STATE(4513), 1,
      sym__reserved_identifier,
    STATE(4947), 1,
      sym_identifier,
    STATE(5019), 1,
      sym_generic_name,
    STATE(5295), 1,
      sym_tuple_type,
    STATE(5365), 1,
      sym__name,
    STATE(5473), 1,
      sym_array_type,
    STATE(8783), 1,
      sym_type,
    STATE(8852), 1,
      sym__array_base_type,
    STATE(9443), 1,
      sym__pointer_base_type,
    STATE(2906), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(5385), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4844), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3197), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [12355] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4248), 1,
      sym__identifier_token,
    ACTIONS(4648), 1,
      anon_sym_ref,
    ACTIONS(6168), 1,
      anon_sym_delegate,
    ACTIONS(6172), 1,
      anon_sym_var,
    ACTIONS(6174), 1,
      sym_predefined_type,
    ACTIONS(6289), 1,
      anon_sym_scoped,
    ACTIONS(6620), 1,
      anon_sym_LPAREN,
    STATE(3889), 1,
      sym_identifier,
    STATE(3911), 1,
      sym__reserved_identifier,
    STATE(3958), 1,
      sym_array_type,
    STATE(3959), 1,
      sym_generic_name,
    STATE(3962), 1,
      sym_tuple_type,
    STATE(4036), 1,
      sym_type,
    STATE(4158), 1,
      sym__name,
    STATE(8941), 1,
      sym__array_base_type,
    STATE(9806), 1,
      sym__pointer_base_type,
    STATE(3961), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4031), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(4085), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(4845), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4250), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [12482] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4349), 1,
      sym__identifier_token,
    ACTIONS(4512), 1,
      anon_sym_delegate,
    ACTIONS(4516), 1,
      anon_sym_var,
    ACTIONS(4518), 1,
      sym_predefined_type,
    ACTIONS(4528), 1,
      anon_sym_ref,
    ACTIONS(6340), 1,
      anon_sym_scoped,
    ACTIONS(6584), 1,
      anon_sym_LPAREN,
    STATE(3625), 1,
      sym__reserved_identifier,
    STATE(3631), 1,
      sym_tuple_type,
    STATE(3639), 1,
      sym_type,
    STATE(3648), 1,
      sym_generic_name,
    STATE(3725), 1,
      sym_array_type,
    STATE(5255), 1,
      sym_identifier,
    STATE(5936), 1,
      sym__name,
    STATE(8829), 1,
      sym__array_base_type,
    STATE(9538), 1,
      sym__pointer_base_type,
    STATE(3680), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(3681), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(3707), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(4846), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4351), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [12609] = 41,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6326), 1,
      anon_sym_in,
    ACTIONS(6723), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6809), 1,
      anon_sym_QMARK,
    ACTIONS(6815), 1,
      anon_sym_SLASH,
    ACTIONS(6817), 1,
      anon_sym_CARET,
    ACTIONS(6819), 1,
      anon_sym_PIPE,
    ACTIONS(6821), 1,
      anon_sym_AMP,
    ACTIONS(6825), 1,
      anon_sym_GT_GT,
    ACTIONS(6831), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6833), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6835), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(6837), 1,
      anon_sym_as,
    ACTIONS(6839), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6807), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6811), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6813), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6823), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6827), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6829), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6324), 9,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_into,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
    STATE(4847), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [12756] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4328), 1,
      sym__identifier_token,
    ACTIONS(4725), 1,
      anon_sym_ref,
    ACTIONS(6148), 1,
      anon_sym_delegate,
    ACTIONS(6152), 1,
      anon_sym_var,
    ACTIONS(6154), 1,
      sym_predefined_type,
    ACTIONS(6372), 1,
      anon_sym_scoped,
    ACTIONS(6654), 1,
      anon_sym_LPAREN,
    STATE(3572), 1,
      sym__reserved_identifier,
    STATE(3597), 1,
      sym_generic_name,
    STATE(3608), 1,
      sym_array_type,
    STATE(3621), 1,
      sym_tuple_type,
    STATE(3712), 1,
      sym_type,
    STATE(4004), 1,
      sym_identifier,
    STATE(4343), 1,
      sym__name,
    STATE(8805), 1,
      sym__array_base_type,
    STATE(9071), 1,
      sym__pointer_base_type,
    STATE(3588), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(3596), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(3612), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4848), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4330), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [12883] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4248), 1,
      sym__identifier_token,
    ACTIONS(4691), 1,
      anon_sym_ref,
    ACTIONS(6168), 1,
      anon_sym_delegate,
    ACTIONS(6172), 1,
      anon_sym_var,
    ACTIONS(6174), 1,
      sym_predefined_type,
    ACTIONS(6348), 1,
      anon_sym_scoped,
    ACTIONS(6620), 1,
      anon_sym_LPAREN,
    STATE(3889), 1,
      sym_identifier,
    STATE(3911), 1,
      sym__reserved_identifier,
    STATE(3958), 1,
      sym_array_type,
    STATE(3959), 1,
      sym_generic_name,
    STATE(3962), 1,
      sym_tuple_type,
    STATE(4036), 1,
      sym_type,
    STATE(4158), 1,
      sym__name,
    STATE(8941), 1,
      sym__array_base_type,
    STATE(9806), 1,
      sym__pointer_base_type,
    STATE(3961), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4031), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(4085), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(4849), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4250), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [13010] = 38,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6723), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6815), 1,
      anon_sym_SLASH,
    ACTIONS(6817), 1,
      anon_sym_CARET,
    ACTIONS(6819), 1,
      anon_sym_PIPE,
    ACTIONS(6821), 1,
      anon_sym_AMP,
    ACTIONS(6825), 1,
      anon_sym_GT_GT,
    ACTIONS(6831), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6837), 1,
      anon_sym_as,
    ACTIONS(6839), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_in,
      anon_sym_QMARK,
    ACTIONS(6807), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6811), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6813), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6823), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6827), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6829), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(4850), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 11,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
  [13151] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4457), 1,
      sym__identifier_token,
    ACTIONS(4461), 1,
      anon_sym_ref,
    ACTIONS(6297), 1,
      anon_sym_delegate,
    ACTIONS(6301), 1,
      anon_sym_var,
    ACTIONS(6303), 1,
      sym_predefined_type,
    ACTIONS(6386), 1,
      anon_sym_scoped,
    ACTIONS(6650), 1,
      anon_sym_LPAREN,
    STATE(5076), 1,
      sym_identifier,
    STATE(5173), 1,
      sym__reserved_identifier,
    STATE(5251), 1,
      sym_array_type,
    STATE(5270), 1,
      sym__name,
    STATE(5321), 1,
      sym_tuple_type,
    STATE(5408), 1,
      sym_generic_name,
    STATE(5559), 1,
      sym_type,
    STATE(8724), 1,
      sym__array_base_type,
    STATE(9858), 1,
      sym__pointer_base_type,
    STATE(5262), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(5336), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(5341), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(4851), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4459), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [13278] = 41,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(5426), 1,
      anon_sym_in,
    ACTIONS(6723), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6809), 1,
      anon_sym_QMARK,
    ACTIONS(6815), 1,
      anon_sym_SLASH,
    ACTIONS(6817), 1,
      anon_sym_CARET,
    ACTIONS(6819), 1,
      anon_sym_PIPE,
    ACTIONS(6821), 1,
      anon_sym_AMP,
    ACTIONS(6825), 1,
      anon_sym_GT_GT,
    ACTIONS(6831), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6833), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6835), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(6837), 1,
      anon_sym_as,
    ACTIONS(6839), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6807), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6811), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6813), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6823), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6827), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6829), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5424), 9,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_into,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
    STATE(4852), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [13425] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5336), 1,
      anon_sym_LBRACK,
    ACTIONS(6010), 1,
      anon_sym_LBRACE,
    ACTIONS(6013), 1,
      anon_sym_QMARK,
    STATE(3687), 1,
      sym_initializer_expression,
    STATE(4853), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5346), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
      anon_sym_or,
    ACTIONS(5340), 30,
      anon_sym_LPAREN,
      anon_sym_where,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [13524] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4223), 1,
      sym__identifier_token,
    ACTIONS(4638), 1,
      anon_sym_ref,
    ACTIONS(6182), 1,
      anon_sym_delegate,
    ACTIONS(6186), 1,
      anon_sym_var,
    ACTIONS(6188), 1,
      sym_predefined_type,
    ACTIONS(6366), 1,
      anon_sym_scoped,
    ACTIONS(6624), 1,
      anon_sym_LPAREN,
    STATE(3808), 1,
      sym_identifier,
    STATE(3871), 1,
      sym__reserved_identifier,
    STATE(3880), 1,
      sym_tuple_type,
    STATE(3900), 1,
      sym_generic_name,
    STATE(3904), 1,
      sym__name,
    STATE(3930), 1,
      sym_type,
    STATE(3945), 1,
      sym_array_type,
    STATE(8893), 1,
      sym__array_base_type,
    STATE(9659), 1,
      sym__pointer_base_type,
    STATE(3885), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(3924), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(3943), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(4854), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4225), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [13651] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6841), 1,
      anon_sym_and,
    ACTIONS(6843), 1,
      anon_sym_or,
    STATE(4855), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5881), 12,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5879), 31,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
  [13746] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6723), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6815), 1,
      anon_sym_SLASH,
    ACTIONS(6817), 1,
      anon_sym_CARET,
    ACTIONS(6819), 1,
      anon_sym_PIPE,
    ACTIONS(6821), 1,
      anon_sym_AMP,
    ACTIONS(6825), 1,
      anon_sym_GT_GT,
    ACTIONS(6831), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6833), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6835), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(6837), 1,
      anon_sym_as,
    ACTIONS(6839), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_in,
      anon_sym_QMARK,
    ACTIONS(6807), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6811), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6813), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6823), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6827), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6829), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 9,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_into,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
    STATE(4856), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [13891] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4223), 1,
      sym__identifier_token,
    ACTIONS(4227), 1,
      anon_sym_ref,
    ACTIONS(6182), 1,
      anon_sym_delegate,
    ACTIONS(6184), 1,
      anon_sym_scoped,
    ACTIONS(6186), 1,
      anon_sym_var,
    ACTIONS(6188), 1,
      sym_predefined_type,
    ACTIONS(6624), 1,
      anon_sym_LPAREN,
    STATE(3808), 1,
      sym_identifier,
    STATE(3871), 1,
      sym__reserved_identifier,
    STATE(3880), 1,
      sym_tuple_type,
    STATE(3900), 1,
      sym_generic_name,
    STATE(3904), 1,
      sym__name,
    STATE(3945), 1,
      sym_array_type,
    STATE(4080), 1,
      sym_type,
    STATE(8893), 1,
      sym__array_base_type,
    STATE(9659), 1,
      sym__pointer_base_type,
    STATE(3885), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(3924), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(3943), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(4857), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4225), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [14018] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3193), 1,
      sym__identifier_token,
    ACTIONS(3205), 1,
      anon_sym_LPAREN,
    ACTIONS(3235), 1,
      sym_predefined_type,
    ACTIONS(4002), 1,
      anon_sym_delegate,
    ACTIONS(4112), 1,
      anon_sym_ref,
    ACTIONS(6580), 1,
      anon_sym_scoped,
    ACTIONS(6582), 1,
      anon_sym_var,
    STATE(2887), 1,
      sym_type,
    STATE(4513), 1,
      sym__reserved_identifier,
    STATE(4947), 1,
      sym_identifier,
    STATE(5019), 1,
      sym_generic_name,
    STATE(5295), 1,
      sym_tuple_type,
    STATE(5365), 1,
      sym__name,
    STATE(5473), 1,
      sym_array_type,
    STATE(8852), 1,
      sym__array_base_type,
    STATE(9443), 1,
      sym__pointer_base_type,
    STATE(2906), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(5385), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4858), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3197), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [14145] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4002), 1,
      anon_sym_delegate,
    ACTIONS(4536), 1,
      sym__identifier_token,
    ACTIONS(4632), 1,
      anon_sym_ref,
    ACTIONS(6244), 1,
      anon_sym_scoped,
    ACTIONS(6246), 1,
      anon_sym_var,
    ACTIONS(6248), 1,
      sym_predefined_type,
    ACTIONS(6602), 1,
      anon_sym_LPAREN,
    STATE(2887), 1,
      sym_type,
    STATE(2920), 1,
      sym_identifier,
    STATE(2928), 1,
      sym__reserved_identifier,
    STATE(2944), 1,
      sym_generic_name,
    STATE(2966), 1,
      sym_array_type,
    STATE(2971), 1,
      sym_tuple_type,
    STATE(2992), 1,
      sym__name,
    STATE(8753), 1,
      sym__array_base_type,
    STATE(9443), 1,
      sym__pointer_base_type,
    STATE(2906), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(2956), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(2970), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4859), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4538), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [14272] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4223), 1,
      sym__identifier_token,
    ACTIONS(4644), 1,
      anon_sym_ref,
    ACTIONS(6182), 1,
      anon_sym_delegate,
    ACTIONS(6186), 1,
      anon_sym_var,
    ACTIONS(6188), 1,
      sym_predefined_type,
    ACTIONS(6376), 1,
      anon_sym_scoped,
    ACTIONS(6624), 1,
      anon_sym_LPAREN,
    STATE(3808), 1,
      sym_identifier,
    STATE(3871), 1,
      sym__reserved_identifier,
    STATE(3880), 1,
      sym_tuple_type,
    STATE(3900), 1,
      sym_generic_name,
    STATE(3904), 1,
      sym__name,
    STATE(3930), 1,
      sym_type,
    STATE(3945), 1,
      sym_array_type,
    STATE(8893), 1,
      sym__array_base_type,
    STATE(9659), 1,
      sym__pointer_base_type,
    STATE(3885), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(3924), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(3943), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(4860), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4225), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [14399] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4248), 1,
      sym__identifier_token,
    ACTIONS(4658), 1,
      anon_sym_ref,
    ACTIONS(6168), 1,
      anon_sym_delegate,
    ACTIONS(6172), 1,
      anon_sym_var,
    ACTIONS(6174), 1,
      sym_predefined_type,
    ACTIONS(6258), 1,
      anon_sym_scoped,
    ACTIONS(6620), 1,
      anon_sym_LPAREN,
    STATE(3889), 1,
      sym_identifier,
    STATE(3911), 1,
      sym__reserved_identifier,
    STATE(3958), 1,
      sym_array_type,
    STATE(3959), 1,
      sym_generic_name,
    STATE(3962), 1,
      sym_tuple_type,
    STATE(4036), 1,
      sym_type,
    STATE(4158), 1,
      sym__name,
    STATE(8941), 1,
      sym__array_base_type,
    STATE(9806), 1,
      sym__pointer_base_type,
    STATE(3961), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4031), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(4085), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(4861), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4250), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [14526] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4248), 1,
      sym__identifier_token,
    ACTIONS(4658), 1,
      anon_sym_ref,
    ACTIONS(6168), 1,
      anon_sym_delegate,
    ACTIONS(6172), 1,
      anon_sym_var,
    ACTIONS(6174), 1,
      sym_predefined_type,
    ACTIONS(6258), 1,
      anon_sym_scoped,
    ACTIONS(6620), 1,
      anon_sym_LPAREN,
    STATE(3889), 1,
      sym_identifier,
    STATE(3911), 1,
      sym__reserved_identifier,
    STATE(3958), 1,
      sym_array_type,
    STATE(3959), 1,
      sym_generic_name,
    STATE(3962), 1,
      sym_tuple_type,
    STATE(4113), 1,
      sym_type,
    STATE(4158), 1,
      sym__name,
    STATE(8941), 1,
      sym__array_base_type,
    STATE(9806), 1,
      sym__pointer_base_type,
    STATE(3961), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4031), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(4085), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(4862), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4250), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [14653] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3193), 1,
      sym__identifier_token,
    ACTIONS(3205), 1,
      anon_sym_LPAREN,
    ACTIONS(3235), 1,
      sym_predefined_type,
    ACTIONS(4002), 1,
      anon_sym_delegate,
    ACTIONS(5369), 1,
      anon_sym_var,
    ACTIONS(6717), 1,
      anon_sym_ref,
    ACTIONS(6721), 1,
      anon_sym_scoped,
    STATE(4513), 1,
      sym__reserved_identifier,
    STATE(4947), 1,
      sym_identifier,
    STATE(5019), 1,
      sym_generic_name,
    STATE(5295), 1,
      sym_tuple_type,
    STATE(5365), 1,
      sym__name,
    STATE(5473), 1,
      sym_array_type,
    STATE(8852), 1,
      sym__array_base_type,
    STATE(9030), 1,
      sym_type,
    STATE(9443), 1,
      sym__pointer_base_type,
    STATE(2906), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(5385), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4863), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3197), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [14780] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4002), 1,
      anon_sym_delegate,
    ACTIONS(4059), 1,
      anon_sym_ref,
    ACTIONS(4536), 1,
      sym__identifier_token,
    ACTIONS(6246), 1,
      anon_sym_var,
    ACTIONS(6248), 1,
      sym_predefined_type,
    ACTIONS(6602), 1,
      anon_sym_LPAREN,
    ACTIONS(6660), 1,
      anon_sym_scoped,
    STATE(2887), 1,
      sym_type,
    STATE(2920), 1,
      sym_identifier,
    STATE(2928), 1,
      sym__reserved_identifier,
    STATE(2944), 1,
      sym_generic_name,
    STATE(2966), 1,
      sym_array_type,
    STATE(2971), 1,
      sym_tuple_type,
    STATE(2992), 1,
      sym__name,
    STATE(8753), 1,
      sym__array_base_type,
    STATE(9443), 1,
      sym__pointer_base_type,
    STATE(2906), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(2956), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(2970), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4864), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4538), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [14907] = 29,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6723), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6815), 1,
      anon_sym_SLASH,
    ACTIONS(6825), 1,
      anon_sym_GT_GT,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6811), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6813), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6823), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6344), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    STATE(4865), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 19,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
  [15030] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4223), 1,
      sym__identifier_token,
    ACTIONS(4660), 1,
      anon_sym_ref,
    ACTIONS(6182), 1,
      anon_sym_delegate,
    ACTIONS(6186), 1,
      anon_sym_var,
    ACTIONS(6188), 1,
      sym_predefined_type,
    ACTIONS(6378), 1,
      anon_sym_scoped,
    ACTIONS(6624), 1,
      anon_sym_LPAREN,
    STATE(3808), 1,
      sym_identifier,
    STATE(3871), 1,
      sym__reserved_identifier,
    STATE(3880), 1,
      sym_tuple_type,
    STATE(3900), 1,
      sym_generic_name,
    STATE(3904), 1,
      sym__name,
    STATE(3930), 1,
      sym_type,
    STATE(3945), 1,
      sym_array_type,
    STATE(8893), 1,
      sym__array_base_type,
    STATE(9659), 1,
      sym__pointer_base_type,
    STATE(3885), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(3924), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(3943), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(4866), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4225), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [15157] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5233), 1,
      anon_sym_DASH_GT,
    ACTIONS(5239), 1,
      anon_sym_DOT,
    ACTIONS(6124), 1,
      anon_sym_LPAREN,
    ACTIONS(6156), 1,
      anon_sym_LBRACK,
    ACTIONS(6158), 1,
      anon_sym_BANG,
    ACTIONS(6216), 1,
      anon_sym_switch,
    ACTIONS(6232), 1,
      anon_sym_with,
    ACTIONS(6406), 1,
      anon_sym_as,
    ACTIONS(6727), 1,
      anon_sym_QMARK,
    ACTIONS(6733), 1,
      anon_sym_SLASH,
    ACTIONS(6735), 1,
      anon_sym_CARET,
    ACTIONS(6737), 1,
      anon_sym_PIPE,
    ACTIONS(6739), 1,
      anon_sym_AMP,
    ACTIONS(6743), 1,
      anon_sym_GT_GT,
    ACTIONS(6749), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6751), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6753), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6755), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(6757), 1,
      anon_sym_is,
    STATE(3577), 1,
      sym_bracketed_argument_list,
    STATE(4561), 1,
      sym_argument_list,
    ACTIONS(6160), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6725), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6729), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6731), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6741), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6745), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6747), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(4867), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5624), 10,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_select,
  [15302] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5233), 1,
      anon_sym_DASH_GT,
    ACTIONS(5239), 1,
      anon_sym_DOT,
    ACTIONS(6124), 1,
      anon_sym_LPAREN,
    ACTIONS(6156), 1,
      anon_sym_LBRACK,
    ACTIONS(6158), 1,
      anon_sym_BANG,
    ACTIONS(6216), 1,
      anon_sym_switch,
    ACTIONS(6232), 1,
      anon_sym_with,
    ACTIONS(6406), 1,
      anon_sym_as,
    ACTIONS(6727), 1,
      anon_sym_QMARK,
    ACTIONS(6733), 1,
      anon_sym_SLASH,
    ACTIONS(6735), 1,
      anon_sym_CARET,
    ACTIONS(6737), 1,
      anon_sym_PIPE,
    ACTIONS(6739), 1,
      anon_sym_AMP,
    ACTIONS(6743), 1,
      anon_sym_GT_GT,
    ACTIONS(6749), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6751), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6753), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6755), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(6757), 1,
      anon_sym_is,
    STATE(3577), 1,
      sym_bracketed_argument_list,
    STATE(4561), 1,
      sym_argument_list,
    ACTIONS(6160), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6725), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6729), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6731), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6741), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6745), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6747), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(4868), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6320), 10,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_select,
  [15447] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4223), 1,
      sym__identifier_token,
    ACTIONS(4530), 1,
      anon_sym_ref,
    ACTIONS(6182), 1,
      anon_sym_delegate,
    ACTIONS(6186), 1,
      anon_sym_var,
    ACTIONS(6188), 1,
      sym_predefined_type,
    ACTIONS(6262), 1,
      anon_sym_scoped,
    ACTIONS(6624), 1,
      anon_sym_LPAREN,
    STATE(3808), 1,
      sym_identifier,
    STATE(3871), 1,
      sym__reserved_identifier,
    STATE(3880), 1,
      sym_tuple_type,
    STATE(3900), 1,
      sym_generic_name,
    STATE(3904), 1,
      sym__name,
    STATE(3945), 1,
      sym_array_type,
    STATE(4080), 1,
      sym_type,
    STATE(8893), 1,
      sym__array_base_type,
    STATE(9659), 1,
      sym__pointer_base_type,
    STATE(3885), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(3924), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(3943), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(4869), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4225), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [15574] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3193), 1,
      sym__identifier_token,
    ACTIONS(3205), 1,
      anon_sym_LPAREN,
    ACTIONS(5369), 1,
      anon_sym_var,
    ACTIONS(5745), 1,
      anon_sym_ref,
    ACTIONS(5747), 1,
      anon_sym_delegate,
    ACTIONS(5753), 1,
      anon_sym_scoped,
    ACTIONS(5755), 1,
      sym_predefined_type,
    STATE(4513), 1,
      sym__reserved_identifier,
    STATE(4947), 1,
      sym_identifier,
    STATE(5019), 1,
      sym_generic_name,
    STATE(7943), 1,
      sym__name,
    STATE(8173), 1,
      sym_tuple_type,
    STATE(8347), 1,
      sym_array_type,
    STATE(8852), 1,
      sym__array_base_type,
    STATE(8870), 1,
      sym_type,
    STATE(9367), 1,
      sym__pointer_base_type,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(5385), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(8787), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(4870), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3197), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [15701] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3193), 1,
      sym__identifier_token,
    ACTIONS(3205), 1,
      anon_sym_LPAREN,
    ACTIONS(3235), 1,
      sym_predefined_type,
    ACTIONS(4002), 1,
      anon_sym_delegate,
    ACTIONS(5369), 1,
      anon_sym_var,
    ACTIONS(6717), 1,
      anon_sym_ref,
    ACTIONS(6721), 1,
      anon_sym_scoped,
    STATE(4513), 1,
      sym__reserved_identifier,
    STATE(4947), 1,
      sym_identifier,
    STATE(5019), 1,
      sym_generic_name,
    STATE(5295), 1,
      sym_tuple_type,
    STATE(5365), 1,
      sym__name,
    STATE(5473), 1,
      sym_array_type,
    STATE(8852), 1,
      sym__array_base_type,
    STATE(9443), 1,
      sym__pointer_base_type,
    STATE(9779), 1,
      sym_type,
    STATE(2906), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(5385), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4871), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3197), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [15828] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4328), 1,
      sym__identifier_token,
    ACTIONS(4731), 1,
      anon_sym_ref,
    ACTIONS(6148), 1,
      anon_sym_delegate,
    ACTIONS(6152), 1,
      anon_sym_var,
    ACTIONS(6154), 1,
      sym_predefined_type,
    ACTIONS(6264), 1,
      anon_sym_scoped,
    ACTIONS(6654), 1,
      anon_sym_LPAREN,
    STATE(3572), 1,
      sym__reserved_identifier,
    STATE(3597), 1,
      sym_generic_name,
    STATE(3608), 1,
      sym_array_type,
    STATE(3621), 1,
      sym_tuple_type,
    STATE(3712), 1,
      sym_type,
    STATE(4004), 1,
      sym_identifier,
    STATE(4343), 1,
      sym__name,
    STATE(8805), 1,
      sym__array_base_type,
    STATE(9071), 1,
      sym__pointer_base_type,
    STATE(3588), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(3596), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(3612), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4872), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4330), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [15955] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3193), 1,
      sym__identifier_token,
    ACTIONS(3205), 1,
      anon_sym_LPAREN,
    ACTIONS(3235), 1,
      sym_predefined_type,
    ACTIONS(4002), 1,
      anon_sym_delegate,
    ACTIONS(5369), 1,
      anon_sym_var,
    ACTIONS(5988), 1,
      anon_sym_ref,
    ACTIONS(5996), 1,
      anon_sym_scoped,
    STATE(2887), 1,
      sym_type,
    STATE(4513), 1,
      sym__reserved_identifier,
    STATE(4947), 1,
      sym_identifier,
    STATE(5019), 1,
      sym_generic_name,
    STATE(5295), 1,
      sym_tuple_type,
    STATE(5365), 1,
      sym__name,
    STATE(5473), 1,
      sym_array_type,
    STATE(8852), 1,
      sym__array_base_type,
    STATE(9443), 1,
      sym__pointer_base_type,
    STATE(2906), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(5385), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4873), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3197), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [16082] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4328), 1,
      sym__identifier_token,
    ACTIONS(4727), 1,
      anon_sym_ref,
    ACTIONS(6148), 1,
      anon_sym_delegate,
    ACTIONS(6152), 1,
      anon_sym_var,
    ACTIONS(6154), 1,
      sym_predefined_type,
    ACTIONS(6274), 1,
      anon_sym_scoped,
    ACTIONS(6654), 1,
      anon_sym_LPAREN,
    STATE(3572), 1,
      sym__reserved_identifier,
    STATE(3597), 1,
      sym_generic_name,
    STATE(3608), 1,
      sym_array_type,
    STATE(3621), 1,
      sym_tuple_type,
    STATE(3712), 1,
      sym_type,
    STATE(4004), 1,
      sym_identifier,
    STATE(4343), 1,
      sym__name,
    STATE(8805), 1,
      sym__array_base_type,
    STATE(9071), 1,
      sym__pointer_base_type,
    STATE(3588), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(3596), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(3612), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4874), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4330), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [16209] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4248), 1,
      sym__identifier_token,
    ACTIONS(4648), 1,
      anon_sym_ref,
    ACTIONS(6168), 1,
      anon_sym_delegate,
    ACTIONS(6172), 1,
      anon_sym_var,
    ACTIONS(6174), 1,
      sym_predefined_type,
    ACTIONS(6289), 1,
      anon_sym_scoped,
    ACTIONS(6620), 1,
      anon_sym_LPAREN,
    STATE(3889), 1,
      sym_identifier,
    STATE(3911), 1,
      sym__reserved_identifier,
    STATE(3958), 1,
      sym_array_type,
    STATE(3959), 1,
      sym_generic_name,
    STATE(3962), 1,
      sym_tuple_type,
    STATE(4113), 1,
      sym_type,
    STATE(4158), 1,
      sym__name,
    STATE(8941), 1,
      sym__array_base_type,
    STATE(9806), 1,
      sym__pointer_base_type,
    STATE(3961), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4031), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(4085), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(4875), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4250), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [16336] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4248), 1,
      sym__identifier_token,
    ACTIONS(4691), 1,
      anon_sym_ref,
    ACTIONS(6168), 1,
      anon_sym_delegate,
    ACTIONS(6172), 1,
      anon_sym_var,
    ACTIONS(6174), 1,
      sym_predefined_type,
    ACTIONS(6348), 1,
      anon_sym_scoped,
    ACTIONS(6620), 1,
      anon_sym_LPAREN,
    STATE(3889), 1,
      sym_identifier,
    STATE(3911), 1,
      sym__reserved_identifier,
    STATE(3958), 1,
      sym_array_type,
    STATE(3959), 1,
      sym_generic_name,
    STATE(3962), 1,
      sym_tuple_type,
    STATE(4113), 1,
      sym_type,
    STATE(4158), 1,
      sym__name,
    STATE(8941), 1,
      sym__array_base_type,
    STATE(9806), 1,
      sym__pointer_base_type,
    STATE(3961), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4031), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(4085), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(4876), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4250), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [16463] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4223), 1,
      sym__identifier_token,
    ACTIONS(4638), 1,
      anon_sym_ref,
    ACTIONS(6182), 1,
      anon_sym_delegate,
    ACTIONS(6186), 1,
      anon_sym_var,
    ACTIONS(6188), 1,
      sym_predefined_type,
    ACTIONS(6366), 1,
      anon_sym_scoped,
    ACTIONS(6624), 1,
      anon_sym_LPAREN,
    STATE(3808), 1,
      sym_identifier,
    STATE(3871), 1,
      sym__reserved_identifier,
    STATE(3880), 1,
      sym_tuple_type,
    STATE(3900), 1,
      sym_generic_name,
    STATE(3904), 1,
      sym__name,
    STATE(3945), 1,
      sym_array_type,
    STATE(4080), 1,
      sym_type,
    STATE(8893), 1,
      sym__array_base_type,
    STATE(9659), 1,
      sym__pointer_base_type,
    STATE(3885), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(3924), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(3943), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(4877), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4225), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [16590] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6723), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(4878), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6344), 10,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    ACTIONS(6342), 23,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
  [16703] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4223), 1,
      sym__identifier_token,
    ACTIONS(4644), 1,
      anon_sym_ref,
    ACTIONS(6182), 1,
      anon_sym_delegate,
    ACTIONS(6186), 1,
      anon_sym_var,
    ACTIONS(6188), 1,
      sym_predefined_type,
    ACTIONS(6376), 1,
      anon_sym_scoped,
    ACTIONS(6624), 1,
      anon_sym_LPAREN,
    STATE(3808), 1,
      sym_identifier,
    STATE(3871), 1,
      sym__reserved_identifier,
    STATE(3880), 1,
      sym_tuple_type,
    STATE(3900), 1,
      sym_generic_name,
    STATE(3904), 1,
      sym__name,
    STATE(3945), 1,
      sym_array_type,
    STATE(4080), 1,
      sym_type,
    STATE(8893), 1,
      sym__array_base_type,
    STATE(9659), 1,
      sym__pointer_base_type,
    STATE(3885), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(3924), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(3943), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(4879), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4225), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [16830] = 38,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5233), 1,
      anon_sym_DASH_GT,
    ACTIONS(5239), 1,
      anon_sym_DOT,
    ACTIONS(6124), 1,
      anon_sym_LPAREN,
    ACTIONS(6156), 1,
      anon_sym_LBRACK,
    ACTIONS(6158), 1,
      anon_sym_BANG,
    ACTIONS(6216), 1,
      anon_sym_switch,
    ACTIONS(6232), 1,
      anon_sym_with,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6406), 1,
      anon_sym_as,
    ACTIONS(6733), 1,
      anon_sym_SLASH,
    ACTIONS(6735), 1,
      anon_sym_CARET,
    ACTIONS(6737), 1,
      anon_sym_PIPE,
    ACTIONS(6739), 1,
      anon_sym_AMP,
    ACTIONS(6743), 1,
      anon_sym_GT_GT,
    ACTIONS(6749), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6751), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6757), 1,
      anon_sym_is,
    STATE(3577), 1,
      sym_bracketed_argument_list,
    STATE(4561), 1,
      sym_argument_list,
    ACTIONS(6160), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6725), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6729), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6731), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6741), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6745), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6747), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(4880), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 12,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_select,
  [16971] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4223), 1,
      sym__identifier_token,
    ACTIONS(4660), 1,
      anon_sym_ref,
    ACTIONS(6182), 1,
      anon_sym_delegate,
    ACTIONS(6186), 1,
      anon_sym_var,
    ACTIONS(6188), 1,
      sym_predefined_type,
    ACTIONS(6378), 1,
      anon_sym_scoped,
    ACTIONS(6624), 1,
      anon_sym_LPAREN,
    STATE(3808), 1,
      sym_identifier,
    STATE(3871), 1,
      sym__reserved_identifier,
    STATE(3880), 1,
      sym_tuple_type,
    STATE(3900), 1,
      sym_generic_name,
    STATE(3904), 1,
      sym__name,
    STATE(3945), 1,
      sym_array_type,
    STATE(4080), 1,
      sym_type,
    STATE(8893), 1,
      sym__array_base_type,
    STATE(9659), 1,
      sym__pointer_base_type,
    STATE(3885), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(3924), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(3943), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(4881), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4225), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [17098] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4328), 1,
      sym__identifier_token,
    ACTIONS(4332), 1,
      anon_sym_ref,
    ACTIONS(6148), 1,
      anon_sym_delegate,
    ACTIONS(6152), 1,
      anon_sym_var,
    ACTIONS(6154), 1,
      sym_predefined_type,
    ACTIONS(6252), 1,
      anon_sym_scoped,
    ACTIONS(6654), 1,
      anon_sym_LPAREN,
    STATE(3572), 1,
      sym__reserved_identifier,
    STATE(3597), 1,
      sym_generic_name,
    STATE(3608), 1,
      sym_array_type,
    STATE(3621), 1,
      sym_tuple_type,
    STATE(3624), 1,
      sym_type,
    STATE(4004), 1,
      sym_identifier,
    STATE(4343), 1,
      sym__name,
    STATE(8805), 1,
      sym__array_base_type,
    STATE(9071), 1,
      sym__pointer_base_type,
    STATE(3588), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(3596), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(3612), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4882), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4330), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [17225] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4248), 1,
      sym__identifier_token,
    ACTIONS(4252), 1,
      anon_sym_ref,
    ACTIONS(6168), 1,
      anon_sym_delegate,
    ACTIONS(6172), 1,
      anon_sym_var,
    ACTIONS(6174), 1,
      sym_predefined_type,
    ACTIONS(6350), 1,
      anon_sym_scoped,
    ACTIONS(6620), 1,
      anon_sym_LPAREN,
    STATE(3889), 1,
      sym_identifier,
    STATE(3911), 1,
      sym__reserved_identifier,
    STATE(3958), 1,
      sym_array_type,
    STATE(3959), 1,
      sym_generic_name,
    STATE(3962), 1,
      sym_tuple_type,
    STATE(4113), 1,
      sym_type,
    STATE(4158), 1,
      sym__name,
    STATE(8941), 1,
      sym__array_base_type,
    STATE(9806), 1,
      sym__pointer_base_type,
    STATE(3961), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4031), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(4085), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(4883), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4250), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [17352] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5233), 1,
      anon_sym_DASH_GT,
    ACTIONS(5239), 1,
      anon_sym_DOT,
    ACTIONS(6124), 1,
      anon_sym_LPAREN,
    ACTIONS(6156), 1,
      anon_sym_LBRACK,
    ACTIONS(6158), 1,
      anon_sym_BANG,
    ACTIONS(6749), 1,
      anon_sym_DOT_DOT,
    STATE(3577), 1,
      sym_bracketed_argument_list,
    STATE(4561), 1,
      sym_argument_list,
    ACTIONS(6160), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(4884), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6330), 10,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_as,
    ACTIONS(6328), 25,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_select,
      anon_sym_is,
      anon_sym_with,
  [17461] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4248), 1,
      sym__identifier_token,
    ACTIONS(4523), 1,
      anon_sym_ref,
    ACTIONS(6168), 1,
      anon_sym_delegate,
    ACTIONS(6172), 1,
      anon_sym_var,
    ACTIONS(6174), 1,
      sym_predefined_type,
    ACTIONS(6278), 1,
      anon_sym_scoped,
    ACTIONS(6620), 1,
      anon_sym_LPAREN,
    STATE(3889), 1,
      sym_identifier,
    STATE(3911), 1,
      sym__reserved_identifier,
    STATE(3958), 1,
      sym_array_type,
    STATE(3959), 1,
      sym_generic_name,
    STATE(3962), 1,
      sym_tuple_type,
    STATE(4036), 1,
      sym_type,
    STATE(4158), 1,
      sym__name,
    STATE(8941), 1,
      sym__array_base_type,
    STATE(9806), 1,
      sym__pointer_base_type,
    STATE(3961), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4031), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(4085), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(4885), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4250), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [17588] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5233), 1,
      anon_sym_DASH_GT,
    ACTIONS(5239), 1,
      anon_sym_DOT,
    ACTIONS(6124), 1,
      anon_sym_LPAREN,
    ACTIONS(6156), 1,
      anon_sym_LBRACK,
    ACTIONS(6158), 1,
      anon_sym_BANG,
    ACTIONS(6216), 1,
      anon_sym_switch,
    ACTIONS(6232), 1,
      anon_sym_with,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6406), 1,
      anon_sym_as,
    ACTIONS(6733), 1,
      anon_sym_SLASH,
    ACTIONS(6735), 1,
      anon_sym_CARET,
    ACTIONS(6737), 1,
      anon_sym_PIPE,
    ACTIONS(6739), 1,
      anon_sym_AMP,
    ACTIONS(6743), 1,
      anon_sym_GT_GT,
    ACTIONS(6749), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6751), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6753), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6755), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(6757), 1,
      anon_sym_is,
    STATE(3577), 1,
      sym_bracketed_argument_list,
    STATE(4561), 1,
      sym_argument_list,
    ACTIONS(6160), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6725), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6729), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6731), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6741), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6745), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6747), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(4886), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 10,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_select,
  [17733] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4349), 1,
      sym__identifier_token,
    ACTIONS(4512), 1,
      anon_sym_delegate,
    ACTIONS(4516), 1,
      anon_sym_var,
    ACTIONS(4518), 1,
      sym_predefined_type,
    ACTIONS(4528), 1,
      anon_sym_ref,
    ACTIONS(6340), 1,
      anon_sym_scoped,
    ACTIONS(6584), 1,
      anon_sym_LPAREN,
    STATE(3625), 1,
      sym__reserved_identifier,
    STATE(3631), 1,
      sym_tuple_type,
    STATE(3648), 1,
      sym_generic_name,
    STATE(3725), 1,
      sym_array_type,
    STATE(3772), 1,
      sym_type,
    STATE(5255), 1,
      sym_identifier,
    STATE(5936), 1,
      sym__name,
    STATE(8829), 1,
      sym__array_base_type,
    STATE(9538), 1,
      sym__pointer_base_type,
    STATE(3680), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(3681), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(3707), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(4887), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4351), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [17860] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4349), 1,
      sym__identifier_token,
    ACTIONS(4353), 1,
      anon_sym_ref,
    ACTIONS(4512), 1,
      anon_sym_delegate,
    ACTIONS(4514), 1,
      anon_sym_scoped,
    ACTIONS(4516), 1,
      anon_sym_var,
    ACTIONS(4518), 1,
      sym_predefined_type,
    ACTIONS(6584), 1,
      anon_sym_LPAREN,
    STATE(3590), 1,
      sym_identifier,
    STATE(3625), 1,
      sym__reserved_identifier,
    STATE(3631), 1,
      sym_tuple_type,
    STATE(3648), 1,
      sym_generic_name,
    STATE(3725), 1,
      sym_array_type,
    STATE(3744), 1,
      sym__name,
    STATE(3772), 1,
      sym_type,
    STATE(8829), 1,
      sym__array_base_type,
    STATE(9538), 1,
      sym__pointer_base_type,
    STATE(3680), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(3681), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(3707), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(4888), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4351), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [17987] = 41,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5233), 1,
      anon_sym_DASH_GT,
    ACTIONS(5239), 1,
      anon_sym_DOT,
    ACTIONS(6124), 1,
      anon_sym_LPAREN,
    ACTIONS(6156), 1,
      anon_sym_LBRACK,
    ACTIONS(6158), 1,
      anon_sym_BANG,
    ACTIONS(6216), 1,
      anon_sym_switch,
    ACTIONS(6232), 1,
      anon_sym_with,
    ACTIONS(6406), 1,
      anon_sym_as,
    ACTIONS(6727), 1,
      anon_sym_QMARK,
    ACTIONS(6733), 1,
      anon_sym_SLASH,
    ACTIONS(6735), 1,
      anon_sym_CARET,
    ACTIONS(6737), 1,
      anon_sym_PIPE,
    ACTIONS(6739), 1,
      anon_sym_AMP,
    ACTIONS(6743), 1,
      anon_sym_GT_GT,
    ACTIONS(6749), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6751), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6753), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6755), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(6757), 1,
      anon_sym_is,
    STATE(3577), 1,
      sym_bracketed_argument_list,
    STATE(4561), 1,
      sym_argument_list,
    ACTIONS(6160), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6725), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6729), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6731), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6741), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6745), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6747), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6847), 2,
      anon_sym_ascending,
      anon_sym_descending,
    ACTIONS(6845), 8,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
    STATE(4889), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [18134] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5233), 1,
      anon_sym_DASH_GT,
    ACTIONS(5239), 1,
      anon_sym_DOT,
    ACTIONS(6124), 1,
      anon_sym_LPAREN,
    ACTIONS(6156), 1,
      anon_sym_LBRACK,
    ACTIONS(6158), 1,
      anon_sym_BANG,
    ACTIONS(6216), 1,
      anon_sym_switch,
    ACTIONS(6232), 1,
      anon_sym_with,
    ACTIONS(6406), 1,
      anon_sym_as,
    ACTIONS(6727), 1,
      anon_sym_QMARK,
    ACTIONS(6733), 1,
      anon_sym_SLASH,
    ACTIONS(6735), 1,
      anon_sym_CARET,
    ACTIONS(6737), 1,
      anon_sym_PIPE,
    ACTIONS(6739), 1,
      anon_sym_AMP,
    ACTIONS(6743), 1,
      anon_sym_GT_GT,
    ACTIONS(6749), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6751), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6753), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6755), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(6757), 1,
      anon_sym_is,
    STATE(3577), 1,
      sym_bracketed_argument_list,
    STATE(4561), 1,
      sym_argument_list,
    ACTIONS(6160), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6725), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6729), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6731), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6741), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6745), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6747), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(4890), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5644), 10,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_select,
  [18279] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3193), 1,
      sym__identifier_token,
    ACTIONS(3205), 1,
      anon_sym_LPAREN,
    ACTIONS(3235), 1,
      sym_predefined_type,
    ACTIONS(4002), 1,
      anon_sym_delegate,
    ACTIONS(6582), 1,
      anon_sym_var,
    ACTIONS(6596), 1,
      anon_sym_ref,
    ACTIONS(6600), 1,
      anon_sym_scoped,
    STATE(2887), 1,
      sym_type,
    STATE(4513), 1,
      sym__reserved_identifier,
    STATE(4947), 1,
      sym_identifier,
    STATE(5019), 1,
      sym_generic_name,
    STATE(5295), 1,
      sym_tuple_type,
    STATE(5365), 1,
      sym__name,
    STATE(5473), 1,
      sym_array_type,
    STATE(8852), 1,
      sym__array_base_type,
    STATE(9443), 1,
      sym__pointer_base_type,
    STATE(2906), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(5385), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4891), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3197), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [18406] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4349), 1,
      sym__identifier_token,
    ACTIONS(4512), 1,
      anon_sym_delegate,
    ACTIONS(4516), 1,
      anon_sym_var,
    ACTIONS(4518), 1,
      sym_predefined_type,
    ACTIONS(4678), 1,
      anon_sym_ref,
    ACTIONS(6360), 1,
      anon_sym_scoped,
    ACTIONS(6584), 1,
      anon_sym_LPAREN,
    STATE(3590), 1,
      sym_identifier,
    STATE(3625), 1,
      sym__reserved_identifier,
    STATE(3631), 1,
      sym_tuple_type,
    STATE(3648), 1,
      sym_generic_name,
    STATE(3725), 1,
      sym_array_type,
    STATE(3744), 1,
      sym__name,
    STATE(3772), 1,
      sym_type,
    STATE(8829), 1,
      sym__array_base_type,
    STATE(9538), 1,
      sym__pointer_base_type,
    STATE(3680), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(3681), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(3707), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(4892), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4351), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [18533] = 41,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(5626), 1,
      anon_sym_in,
    ACTIONS(6723), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6809), 1,
      anon_sym_QMARK,
    ACTIONS(6815), 1,
      anon_sym_SLASH,
    ACTIONS(6817), 1,
      anon_sym_CARET,
    ACTIONS(6819), 1,
      anon_sym_PIPE,
    ACTIONS(6821), 1,
      anon_sym_AMP,
    ACTIONS(6825), 1,
      anon_sym_GT_GT,
    ACTIONS(6831), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6833), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6835), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(6837), 1,
      anon_sym_as,
    ACTIONS(6839), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6807), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6811), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6813), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6823), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6827), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6829), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5624), 9,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_into,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
    STATE(4893), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [18680] = 41,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6220), 1,
      anon_sym_in,
    ACTIONS(6723), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6809), 1,
      anon_sym_QMARK,
    ACTIONS(6815), 1,
      anon_sym_SLASH,
    ACTIONS(6817), 1,
      anon_sym_CARET,
    ACTIONS(6819), 1,
      anon_sym_PIPE,
    ACTIONS(6821), 1,
      anon_sym_AMP,
    ACTIONS(6825), 1,
      anon_sym_GT_GT,
    ACTIONS(6831), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6833), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6835), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(6837), 1,
      anon_sym_as,
    ACTIONS(6839), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6807), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6811), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6813), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6823), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6827), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6829), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6190), 9,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_into,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
    STATE(4894), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [18827] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3193), 1,
      sym__identifier_token,
    ACTIONS(3205), 1,
      anon_sym_LPAREN,
    ACTIONS(3231), 1,
      anon_sym_scoped,
    ACTIONS(3233), 1,
      anon_sym_var,
    ACTIONS(3235), 1,
      sym_predefined_type,
    ACTIONS(4000), 1,
      anon_sym_ref,
    ACTIONS(4002), 1,
      anon_sym_delegate,
    STATE(2887), 1,
      sym_type,
    STATE(4513), 1,
      sym__reserved_identifier,
    STATE(4947), 1,
      sym_identifier,
    STATE(5019), 1,
      sym_generic_name,
    STATE(5295), 1,
      sym_tuple_type,
    STATE(5365), 1,
      sym__name,
    STATE(5473), 1,
      sym_array_type,
    STATE(8852), 1,
      sym__array_base_type,
    STATE(9443), 1,
      sym__pointer_base_type,
    STATE(2906), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(5385), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4895), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3197), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [18954] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3193), 1,
      sym__identifier_token,
    ACTIONS(3205), 1,
      anon_sym_LPAREN,
    ACTIONS(3231), 1,
      anon_sym_scoped,
    ACTIONS(3233), 1,
      anon_sym_var,
    ACTIONS(3235), 1,
      sym_predefined_type,
    ACTIONS(4000), 1,
      anon_sym_ref,
    ACTIONS(4002), 1,
      anon_sym_delegate,
    STATE(4513), 1,
      sym__reserved_identifier,
    STATE(5019), 1,
      sym_generic_name,
    STATE(5295), 1,
      sym_tuple_type,
    STATE(5365), 1,
      sym__name,
    STATE(5473), 1,
      sym_array_type,
    STATE(6820), 1,
      sym_identifier,
    STATE(7339), 1,
      sym_type,
    STATE(8852), 1,
      sym__array_base_type,
    STATE(9443), 1,
      sym__pointer_base_type,
    STATE(2906), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(5385), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4896), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3197), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [19081] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6849), 1,
      anon_sym_into,
    STATE(4897), 10,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
      aux_sym__query_body_repeat2,
    ACTIONS(6486), 12,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
      anon_sym_as,
    ACTIONS(6484), 31,
      anon_sym_LBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_where,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_select,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [19174] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6805), 1,
      anon_sym_into,
    STATE(4897), 1,
      aux_sym__query_body_repeat2,
    STATE(4898), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6493), 12,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
      anon_sym_as,
    ACTIONS(6491), 31,
      anon_sym_LBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_where,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_select,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [19269] = 29,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5233), 1,
      anon_sym_DASH_GT,
    ACTIONS(5239), 1,
      anon_sym_DOT,
    ACTIONS(6124), 1,
      anon_sym_LPAREN,
    ACTIONS(6156), 1,
      anon_sym_LBRACK,
    ACTIONS(6158), 1,
      anon_sym_BANG,
    ACTIONS(6216), 1,
      anon_sym_switch,
    ACTIONS(6232), 1,
      anon_sym_with,
    ACTIONS(6733), 1,
      anon_sym_SLASH,
    ACTIONS(6743), 1,
      anon_sym_GT_GT,
    ACTIONS(6749), 1,
      anon_sym_DOT_DOT,
    STATE(3577), 1,
      sym_bracketed_argument_list,
    STATE(4561), 1,
      sym_argument_list,
    ACTIONS(6160), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6729), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6731), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6741), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6344), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_as,
    STATE(4899), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 19,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_select,
      anon_sym_is,
  [19392] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6789), 1,
      anon_sym_DOT_DOT,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(4900), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6330), 10,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_or,
    ACTIONS(6328), 25,
      anon_sym_where,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_and,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [19501] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3193), 1,
      sym__identifier_token,
    ACTIONS(3205), 1,
      anon_sym_LPAREN,
    ACTIONS(3235), 1,
      sym_predefined_type,
    ACTIONS(4002), 1,
      anon_sym_delegate,
    ACTIONS(4112), 1,
      anon_sym_ref,
    ACTIONS(6580), 1,
      anon_sym_scoped,
    ACTIONS(6582), 1,
      anon_sym_var,
    STATE(4513), 1,
      sym__reserved_identifier,
    STATE(4947), 1,
      sym_identifier,
    STATE(5019), 1,
      sym_generic_name,
    STATE(5295), 1,
      sym_tuple_type,
    STATE(5365), 1,
      sym__name,
    STATE(5473), 1,
      sym_array_type,
    STATE(7296), 1,
      sym_type,
    STATE(8852), 1,
      sym__array_base_type,
    STATE(9443), 1,
      sym__pointer_base_type,
    STATE(2906), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(5385), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4901), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3197), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [19628] = 41,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6268), 1,
      anon_sym_in,
    ACTIONS(6723), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6809), 1,
      anon_sym_QMARK,
    ACTIONS(6815), 1,
      anon_sym_SLASH,
    ACTIONS(6817), 1,
      anon_sym_CARET,
    ACTIONS(6819), 1,
      anon_sym_PIPE,
    ACTIONS(6821), 1,
      anon_sym_AMP,
    ACTIONS(6825), 1,
      anon_sym_GT_GT,
    ACTIONS(6831), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6833), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6835), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(6837), 1,
      anon_sym_as,
    ACTIONS(6839), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6807), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6811), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6813), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6823), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6827), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6829), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6266), 9,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_into,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
    STATE(4902), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [19775] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3193), 1,
      sym__identifier_token,
    ACTIONS(3205), 1,
      anon_sym_LPAREN,
    ACTIONS(3235), 1,
      sym_predefined_type,
    ACTIONS(4002), 1,
      anon_sym_delegate,
    ACTIONS(5369), 1,
      anon_sym_var,
    ACTIONS(6717), 1,
      anon_sym_ref,
    ACTIONS(6721), 1,
      anon_sym_scoped,
    STATE(4513), 1,
      sym__reserved_identifier,
    STATE(4947), 1,
      sym_identifier,
    STATE(5019), 1,
      sym_generic_name,
    STATE(5295), 1,
      sym_tuple_type,
    STATE(5365), 1,
      sym__name,
    STATE(5473), 1,
      sym_array_type,
    STATE(8246), 1,
      sym_type,
    STATE(8852), 1,
      sym__array_base_type,
    STATE(9443), 1,
      sym__pointer_base_type,
    STATE(2906), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(5385), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4903), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3197), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [19902] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3193), 1,
      sym__identifier_token,
    ACTIONS(3205), 1,
      anon_sym_LPAREN,
    ACTIONS(3233), 1,
      anon_sym_var,
    ACTIONS(3235), 1,
      sym_predefined_type,
    ACTIONS(4002), 1,
      anon_sym_delegate,
    ACTIONS(6608), 1,
      anon_sym_ref,
    ACTIONS(6612), 1,
      anon_sym_scoped,
    STATE(4513), 1,
      sym__reserved_identifier,
    STATE(4947), 1,
      sym_identifier,
    STATE(5019), 1,
      sym_generic_name,
    STATE(5295), 1,
      sym_tuple_type,
    STATE(5365), 1,
      sym__name,
    STATE(5473), 1,
      sym_array_type,
    STATE(8852), 1,
      sym__array_base_type,
    STATE(8927), 1,
      sym_type,
    STATE(9443), 1,
      sym__pointer_base_type,
    STATE(2906), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(5385), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4904), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3197), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [20029] = 41,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6338), 1,
      anon_sym_in,
    ACTIONS(6723), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6809), 1,
      anon_sym_QMARK,
    ACTIONS(6815), 1,
      anon_sym_SLASH,
    ACTIONS(6817), 1,
      anon_sym_CARET,
    ACTIONS(6819), 1,
      anon_sym_PIPE,
    ACTIONS(6821), 1,
      anon_sym_AMP,
    ACTIONS(6825), 1,
      anon_sym_GT_GT,
    ACTIONS(6831), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6833), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6835), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(6837), 1,
      anon_sym_as,
    ACTIONS(6839), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6807), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6811), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6813), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6823), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6827), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6829), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6336), 9,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_into,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
    STATE(4905), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [20176] = 29,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6771), 1,
      anon_sym_SLASH,
    ACTIONS(6781), 1,
      anon_sym_GT_GT,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6789), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6801), 1,
      anon_sym_with,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6767), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6769), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6779), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6344), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_or,
    STATE(4906), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 19,
      anon_sym_where,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_and,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
      anon_sym_as,
      anon_sym_is,
  [20299] = 26,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6771), 1,
      anon_sym_SLASH,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6789), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6801), 1,
      anon_sym_with,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6769), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_or,
    STATE(4907), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 21,
      anon_sym_where,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_and,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
      anon_sym_as,
      anon_sym_is,
  [20416] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6789), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6801), 1,
      anon_sym_with,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(4908), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6344), 10,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_or,
    ACTIONS(6342), 23,
      anon_sym_where,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_and,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
      anon_sym_as,
      anon_sym_is,
  [20529] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6771), 1,
      anon_sym_SLASH,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6789), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6801), 1,
      anon_sym_with,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6767), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6769), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_or,
    STATE(4909), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 21,
      anon_sym_where,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_and,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
      anon_sym_as,
      anon_sym_is,
  [20648] = 41,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6272), 1,
      anon_sym_in,
    ACTIONS(6723), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6809), 1,
      anon_sym_QMARK,
    ACTIONS(6815), 1,
      anon_sym_SLASH,
    ACTIONS(6817), 1,
      anon_sym_CARET,
    ACTIONS(6819), 1,
      anon_sym_PIPE,
    ACTIONS(6821), 1,
      anon_sym_AMP,
    ACTIONS(6825), 1,
      anon_sym_GT_GT,
    ACTIONS(6831), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6833), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6835), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(6837), 1,
      anon_sym_as,
    ACTIONS(6839), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6807), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6811), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6813), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6823), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6827), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6829), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6270), 9,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_into,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
    STATE(4910), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [20795] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4002), 1,
      anon_sym_delegate,
    ACTIONS(4536), 1,
      sym__identifier_token,
    ACTIONS(4632), 1,
      anon_sym_ref,
    ACTIONS(6244), 1,
      anon_sym_scoped,
    ACTIONS(6246), 1,
      anon_sym_var,
    ACTIONS(6248), 1,
      sym_predefined_type,
    ACTIONS(6602), 1,
      anon_sym_LPAREN,
    STATE(2920), 1,
      sym_identifier,
    STATE(2928), 1,
      sym__reserved_identifier,
    STATE(2944), 1,
      sym_generic_name,
    STATE(2966), 1,
      sym_array_type,
    STATE(2971), 1,
      sym_tuple_type,
    STATE(2992), 1,
      sym__name,
    STATE(4631), 1,
      sym_type,
    STATE(8753), 1,
      sym__array_base_type,
    STATE(9443), 1,
      sym__pointer_base_type,
    STATE(2906), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(2956), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(2970), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4911), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4538), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [20922] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3193), 1,
      sym__identifier_token,
    ACTIONS(3205), 1,
      anon_sym_LPAREN,
    ACTIONS(3235), 1,
      sym_predefined_type,
    ACTIONS(4002), 1,
      anon_sym_delegate,
    ACTIONS(5369), 1,
      anon_sym_var,
    ACTIONS(6717), 1,
      anon_sym_ref,
    ACTIONS(6721), 1,
      anon_sym_scoped,
    STATE(4513), 1,
      sym__reserved_identifier,
    STATE(4947), 1,
      sym_identifier,
    STATE(5019), 1,
      sym_generic_name,
    STATE(5295), 1,
      sym_tuple_type,
    STATE(5365), 1,
      sym__name,
    STATE(5473), 1,
      sym_array_type,
    STATE(8852), 1,
      sym__array_base_type,
    STATE(9443), 1,
      sym__pointer_base_type,
    STATE(9610), 1,
      sym_type,
    STATE(2906), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(5385), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4912), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3197), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [21049] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6789), 1,
      anon_sym_DOT_DOT,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(4913), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(1229), 10,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_or,
    ACTIONS(1227), 25,
      anon_sym_where,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_and,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [21158] = 26,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5233), 1,
      anon_sym_DASH_GT,
    ACTIONS(5239), 1,
      anon_sym_DOT,
    ACTIONS(6124), 1,
      anon_sym_LPAREN,
    ACTIONS(6156), 1,
      anon_sym_LBRACK,
    ACTIONS(6158), 1,
      anon_sym_BANG,
    ACTIONS(6216), 1,
      anon_sym_switch,
    ACTIONS(6232), 1,
      anon_sym_with,
    ACTIONS(6733), 1,
      anon_sym_SLASH,
    ACTIONS(6749), 1,
      anon_sym_DOT_DOT,
    STATE(3577), 1,
      sym_bracketed_argument_list,
    STATE(4561), 1,
      sym_argument_list,
    ACTIONS(6160), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6731), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_as,
    STATE(4914), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 21,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_select,
      anon_sym_is,
  [21275] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4002), 1,
      anon_sym_delegate,
    ACTIONS(4536), 1,
      sym__identifier_token,
    ACTIONS(4540), 1,
      anon_sym_ref,
    ACTIONS(6246), 1,
      anon_sym_var,
    ACTIONS(6248), 1,
      sym_predefined_type,
    ACTIONS(6362), 1,
      anon_sym_scoped,
    ACTIONS(6602), 1,
      anon_sym_LPAREN,
    STATE(2887), 1,
      sym_type,
    STATE(2920), 1,
      sym_identifier,
    STATE(2928), 1,
      sym__reserved_identifier,
    STATE(2944), 1,
      sym_generic_name,
    STATE(2966), 1,
      sym_array_type,
    STATE(2971), 1,
      sym_tuple_type,
    STATE(2992), 1,
      sym__name,
    STATE(8753), 1,
      sym__array_base_type,
    STATE(9443), 1,
      sym__pointer_base_type,
    STATE(2906), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(2956), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(2970), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4915), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4538), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [21402] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5233), 1,
      anon_sym_DASH_GT,
    ACTIONS(5239), 1,
      anon_sym_DOT,
    ACTIONS(6124), 1,
      anon_sym_LPAREN,
    ACTIONS(6156), 1,
      anon_sym_LBRACK,
    ACTIONS(6158), 1,
      anon_sym_BANG,
    ACTIONS(6216), 1,
      anon_sym_switch,
    ACTIONS(6232), 1,
      anon_sym_with,
    ACTIONS(6749), 1,
      anon_sym_DOT_DOT,
    STATE(3577), 1,
      sym_bracketed_argument_list,
    STATE(4561), 1,
      sym_argument_list,
    ACTIONS(6160), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(4916), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6344), 10,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_as,
    ACTIONS(6342), 23,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_select,
      anon_sym_is,
  [21515] = 41,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(5418), 1,
      anon_sym_in,
    ACTIONS(6723), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6809), 1,
      anon_sym_QMARK,
    ACTIONS(6815), 1,
      anon_sym_SLASH,
    ACTIONS(6817), 1,
      anon_sym_CARET,
    ACTIONS(6819), 1,
      anon_sym_PIPE,
    ACTIONS(6821), 1,
      anon_sym_AMP,
    ACTIONS(6825), 1,
      anon_sym_GT_GT,
    ACTIONS(6831), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6833), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6835), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(6837), 1,
      anon_sym_as,
    ACTIONS(6839), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6807), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6811), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6813), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6823), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6827), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6829), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5416), 9,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_into,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
    STATE(4917), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [21662] = 35,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5233), 1,
      anon_sym_DASH_GT,
    ACTIONS(5239), 1,
      anon_sym_DOT,
    ACTIONS(6124), 1,
      anon_sym_LPAREN,
    ACTIONS(6156), 1,
      anon_sym_LBRACK,
    ACTIONS(6158), 1,
      anon_sym_BANG,
    ACTIONS(6216), 1,
      anon_sym_switch,
    ACTIONS(6232), 1,
      anon_sym_with,
    ACTIONS(6406), 1,
      anon_sym_as,
    ACTIONS(6733), 1,
      anon_sym_SLASH,
    ACTIONS(6739), 1,
      anon_sym_AMP,
    ACTIONS(6743), 1,
      anon_sym_GT_GT,
    ACTIONS(6749), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6757), 1,
      anon_sym_is,
    STATE(3577), 1,
      sym_bracketed_argument_list,
    STATE(4561), 1,
      sym_argument_list,
    ACTIONS(6160), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(6725), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6729), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6731), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6741), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6745), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6747), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(4918), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 14,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_select,
  [21797] = 41,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(5574), 1,
      anon_sym_in,
    ACTIONS(6723), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6809), 1,
      anon_sym_QMARK,
    ACTIONS(6815), 1,
      anon_sym_SLASH,
    ACTIONS(6817), 1,
      anon_sym_CARET,
    ACTIONS(6819), 1,
      anon_sym_PIPE,
    ACTIONS(6821), 1,
      anon_sym_AMP,
    ACTIONS(6825), 1,
      anon_sym_GT_GT,
    ACTIONS(6831), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6833), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6835), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(6837), 1,
      anon_sym_as,
    ACTIONS(6839), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6807), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6811), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6813), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6823), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6827), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6829), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5572), 9,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_into,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
    STATE(4919), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [21944] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4223), 1,
      sym__identifier_token,
    ACTIONS(4227), 1,
      anon_sym_ref,
    ACTIONS(6182), 1,
      anon_sym_delegate,
    ACTIONS(6184), 1,
      anon_sym_scoped,
    ACTIONS(6186), 1,
      anon_sym_var,
    ACTIONS(6188), 1,
      sym_predefined_type,
    ACTIONS(6624), 1,
      anon_sym_LPAREN,
    STATE(3808), 1,
      sym_identifier,
    STATE(3871), 1,
      sym__reserved_identifier,
    STATE(3880), 1,
      sym_tuple_type,
    STATE(3900), 1,
      sym_generic_name,
    STATE(3904), 1,
      sym__name,
    STATE(3930), 1,
      sym_type,
    STATE(3945), 1,
      sym_array_type,
    STATE(8893), 1,
      sym__array_base_type,
    STATE(9659), 1,
      sym__pointer_base_type,
    STATE(3885), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(3924), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(3943), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(4920), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4225), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [22071] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6723), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6815), 1,
      anon_sym_SLASH,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6811), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6813), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(4921), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 21,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
  [22190] = 36,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5233), 1,
      anon_sym_DASH_GT,
    ACTIONS(5239), 1,
      anon_sym_DOT,
    ACTIONS(6124), 1,
      anon_sym_LPAREN,
    ACTIONS(6156), 1,
      anon_sym_LBRACK,
    ACTIONS(6158), 1,
      anon_sym_BANG,
    ACTIONS(6216), 1,
      anon_sym_switch,
    ACTIONS(6232), 1,
      anon_sym_with,
    ACTIONS(6406), 1,
      anon_sym_as,
    ACTIONS(6733), 1,
      anon_sym_SLASH,
    ACTIONS(6735), 1,
      anon_sym_CARET,
    ACTIONS(6739), 1,
      anon_sym_AMP,
    ACTIONS(6743), 1,
      anon_sym_GT_GT,
    ACTIONS(6749), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6757), 1,
      anon_sym_is,
    STATE(3577), 1,
      sym_bracketed_argument_list,
    STATE(4561), 1,
      sym_argument_list,
    ACTIONS(6160), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(6725), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6729), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6731), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6741), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6745), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6747), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(4922), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 13,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_select,
  [22327] = 34,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5233), 1,
      anon_sym_DASH_GT,
    ACTIONS(5239), 1,
      anon_sym_DOT,
    ACTIONS(6124), 1,
      anon_sym_LPAREN,
    ACTIONS(6156), 1,
      anon_sym_LBRACK,
    ACTIONS(6158), 1,
      anon_sym_BANG,
    ACTIONS(6216), 1,
      anon_sym_switch,
    ACTIONS(6232), 1,
      anon_sym_with,
    ACTIONS(6406), 1,
      anon_sym_as,
    ACTIONS(6733), 1,
      anon_sym_SLASH,
    ACTIONS(6743), 1,
      anon_sym_GT_GT,
    ACTIONS(6749), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6757), 1,
      anon_sym_is,
    STATE(3577), 1,
      sym_bracketed_argument_list,
    STATE(4561), 1,
      sym_argument_list,
    ACTIONS(6160), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6725), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6729), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6731), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6741), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6745), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6747), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    STATE(4923), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 14,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_select,
  [22460] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5233), 1,
      anon_sym_DASH_GT,
    ACTIONS(5239), 1,
      anon_sym_DOT,
    ACTIONS(6124), 1,
      anon_sym_LPAREN,
    ACTIONS(6156), 1,
      anon_sym_LBRACK,
    ACTIONS(6158), 1,
      anon_sym_BANG,
    ACTIONS(6216), 1,
      anon_sym_switch,
    ACTIONS(6232), 1,
      anon_sym_with,
    ACTIONS(6733), 1,
      anon_sym_SLASH,
    ACTIONS(6749), 1,
      anon_sym_DOT_DOT,
    STATE(3577), 1,
      sym_bracketed_argument_list,
    STATE(4561), 1,
      sym_argument_list,
    ACTIONS(6160), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6729), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6731), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_as,
    STATE(4924), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 21,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_select,
      anon_sym_is,
  [22579] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6759), 1,
      anon_sym_and,
    STATE(4925), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6707), 13,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
      anon_sym_or,
      anon_sym_as,
    ACTIONS(6705), 31,
      anon_sym_LBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_where,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_select,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [22672] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6841), 1,
      anon_sym_and,
    STATE(4926), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6707), 12,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6705), 32,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
  [22765] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6759), 1,
      anon_sym_and,
    ACTIONS(6761), 1,
      anon_sym_or,
    STATE(4927), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6594), 12,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
      anon_sym_as,
    ACTIONS(6592), 31,
      anon_sym_LBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_where,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_select,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [22860] = 33,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5233), 1,
      anon_sym_DASH_GT,
    ACTIONS(5239), 1,
      anon_sym_DOT,
    ACTIONS(6124), 1,
      anon_sym_LPAREN,
    ACTIONS(6156), 1,
      anon_sym_LBRACK,
    ACTIONS(6158), 1,
      anon_sym_BANG,
    ACTIONS(6216), 1,
      anon_sym_switch,
    ACTIONS(6232), 1,
      anon_sym_with,
    ACTIONS(6406), 1,
      anon_sym_as,
    ACTIONS(6733), 1,
      anon_sym_SLASH,
    ACTIONS(6743), 1,
      anon_sym_GT_GT,
    ACTIONS(6749), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6757), 1,
      anon_sym_is,
    STATE(3577), 1,
      sym_bracketed_argument_list,
    STATE(4561), 1,
      sym_argument_list,
    ACTIONS(6160), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6725), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6729), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6731), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6741), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6747), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    STATE(4928), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 16,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_select,
  [22991] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3193), 1,
      sym__identifier_token,
    ACTIONS(3205), 1,
      anon_sym_LPAREN,
    ACTIONS(3233), 1,
      anon_sym_var,
    ACTIONS(3235), 1,
      sym_predefined_type,
    ACTIONS(4002), 1,
      anon_sym_delegate,
    ACTIONS(4153), 1,
      anon_sym_ref,
    ACTIONS(6713), 1,
      anon_sym_scoped,
    STATE(2887), 1,
      sym_type,
    STATE(4513), 1,
      sym__reserved_identifier,
    STATE(5019), 1,
      sym_generic_name,
    STATE(5295), 1,
      sym_tuple_type,
    STATE(5473), 1,
      sym_array_type,
    STATE(6517), 1,
      sym_identifier,
    STATE(6771), 1,
      sym__name,
    STATE(8852), 1,
      sym__array_base_type,
    STATE(9443), 1,
      sym__pointer_base_type,
    STATE(2906), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(5385), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4929), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3197), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [23118] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(1501), 1,
      anon_sym_LBRACE,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    STATE(3592), 1,
      sym_argument_list,
    STATE(3783), 1,
      sym_initializer_expression,
    STATE(4930), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5267), 12,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
      anon_sym_or,
    ACTIONS(5263), 29,
      anon_sym_LBRACK,
      anon_sym_where,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [23217] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3193), 1,
      sym__identifier_token,
    ACTIONS(3205), 1,
      anon_sym_LPAREN,
    ACTIONS(3235), 1,
      sym_predefined_type,
    ACTIONS(4002), 1,
      anon_sym_delegate,
    ACTIONS(5369), 1,
      anon_sym_var,
    ACTIONS(5988), 1,
      anon_sym_ref,
    ACTIONS(5996), 1,
      anon_sym_scoped,
    STATE(4513), 1,
      sym__reserved_identifier,
    STATE(4947), 1,
      sym_identifier,
    STATE(5019), 1,
      sym_generic_name,
    STATE(5295), 1,
      sym_tuple_type,
    STATE(5365), 1,
      sym__name,
    STATE(5473), 1,
      sym_array_type,
    STATE(8002), 1,
      sym_type,
    STATE(8852), 1,
      sym__array_base_type,
    STATE(9443), 1,
      sym__pointer_base_type,
    STATE(2906), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(5385), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4931), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3197), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [23344] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3193), 1,
      sym__identifier_token,
    ACTIONS(3205), 1,
      anon_sym_LPAREN,
    ACTIONS(3235), 1,
      sym_predefined_type,
    ACTIONS(4002), 1,
      anon_sym_delegate,
    ACTIONS(6582), 1,
      anon_sym_var,
    ACTIONS(6596), 1,
      anon_sym_ref,
    ACTIONS(6600), 1,
      anon_sym_scoped,
    STATE(4513), 1,
      sym__reserved_identifier,
    STATE(4947), 1,
      sym_identifier,
    STATE(5019), 1,
      sym_generic_name,
    STATE(5295), 1,
      sym_tuple_type,
    STATE(5365), 1,
      sym__name,
    STATE(5473), 1,
      sym_array_type,
    STATE(8852), 1,
      sym__array_base_type,
    STATE(9240), 1,
      sym_type,
    STATE(9443), 1,
      sym__pointer_base_type,
    STATE(2906), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(5385), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4932), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3197), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [23471] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3193), 1,
      sym__identifier_token,
    ACTIONS(3205), 1,
      anon_sym_LPAREN,
    ACTIONS(3235), 1,
      sym_predefined_type,
    ACTIONS(4002), 1,
      anon_sym_delegate,
    ACTIONS(6582), 1,
      anon_sym_var,
    ACTIONS(6596), 1,
      anon_sym_ref,
    ACTIONS(6600), 1,
      anon_sym_scoped,
    STATE(4513), 1,
      sym__reserved_identifier,
    STATE(4947), 1,
      sym_identifier,
    STATE(5019), 1,
      sym_generic_name,
    STATE(5295), 1,
      sym_tuple_type,
    STATE(5365), 1,
      sym__name,
    STATE(5473), 1,
      sym_array_type,
    STATE(8852), 1,
      sym__array_base_type,
    STATE(9329), 1,
      sym_type,
    STATE(9443), 1,
      sym__pointer_base_type,
    STATE(2906), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(5385), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4933), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3197), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [23598] = 41,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(5586), 1,
      anon_sym_in,
    ACTIONS(6723), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6809), 1,
      anon_sym_QMARK,
    ACTIONS(6815), 1,
      anon_sym_SLASH,
    ACTIONS(6817), 1,
      anon_sym_CARET,
    ACTIONS(6819), 1,
      anon_sym_PIPE,
    ACTIONS(6821), 1,
      anon_sym_AMP,
    ACTIONS(6825), 1,
      anon_sym_GT_GT,
    ACTIONS(6831), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6833), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6835), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(6837), 1,
      anon_sym_as,
    ACTIONS(6839), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6807), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6811), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6813), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6823), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6827), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6829), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5584), 9,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_into,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
    STATE(4934), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [23745] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3193), 1,
      sym__identifier_token,
    ACTIONS(3205), 1,
      anon_sym_LPAREN,
    ACTIONS(3235), 1,
      sym_predefined_type,
    ACTIONS(4002), 1,
      anon_sym_delegate,
    ACTIONS(6582), 1,
      anon_sym_var,
    ACTIONS(6596), 1,
      anon_sym_ref,
    ACTIONS(6600), 1,
      anon_sym_scoped,
    STATE(4513), 1,
      sym__reserved_identifier,
    STATE(4947), 1,
      sym_identifier,
    STATE(5019), 1,
      sym_generic_name,
    STATE(5295), 1,
      sym_tuple_type,
    STATE(5365), 1,
      sym__name,
    STATE(5473), 1,
      sym_array_type,
    STATE(8852), 1,
      sym__array_base_type,
    STATE(9354), 1,
      sym_type,
    STATE(9443), 1,
      sym__pointer_base_type,
    STATE(2906), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(5385), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4935), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3197), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [23872] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3193), 1,
      sym__identifier_token,
    ACTIONS(3205), 1,
      anon_sym_LPAREN,
    ACTIONS(3235), 1,
      sym_predefined_type,
    ACTIONS(4002), 1,
      anon_sym_delegate,
    ACTIONS(6582), 1,
      anon_sym_var,
    ACTIONS(6596), 1,
      anon_sym_ref,
    ACTIONS(6600), 1,
      anon_sym_scoped,
    STATE(4513), 1,
      sym__reserved_identifier,
    STATE(4947), 1,
      sym_identifier,
    STATE(5019), 1,
      sym_generic_name,
    STATE(5295), 1,
      sym_tuple_type,
    STATE(5365), 1,
      sym__name,
    STATE(5473), 1,
      sym_array_type,
    STATE(8852), 1,
      sym__array_base_type,
    STATE(9361), 1,
      sym_type,
    STATE(9443), 1,
      sym__pointer_base_type,
    STATE(2906), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(5385), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4936), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3197), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [23999] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4248), 1,
      sym__identifier_token,
    ACTIONS(4542), 1,
      anon_sym_ref,
    ACTIONS(6168), 1,
      anon_sym_delegate,
    ACTIONS(6170), 1,
      anon_sym_scoped,
    ACTIONS(6172), 1,
      anon_sym_var,
    ACTIONS(6174), 1,
      sym_predefined_type,
    ACTIONS(6620), 1,
      anon_sym_LPAREN,
    STATE(3911), 1,
      sym__reserved_identifier,
    STATE(3958), 1,
      sym_array_type,
    STATE(3959), 1,
      sym_generic_name,
    STATE(3962), 1,
      sym_tuple_type,
    STATE(4036), 1,
      sym_type,
    STATE(5502), 1,
      sym_identifier,
    STATE(6204), 1,
      sym__name,
    STATE(8941), 1,
      sym__array_base_type,
    STATE(9806), 1,
      sym__pointer_base_type,
    STATE(3961), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4031), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(4085), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(4937), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4250), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [24126] = 35,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6723), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6815), 1,
      anon_sym_SLASH,
    ACTIONS(6821), 1,
      anon_sym_AMP,
    ACTIONS(6825), 1,
      anon_sym_GT_GT,
    ACTIONS(6837), 1,
      anon_sym_as,
    ACTIONS(6839), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6807), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6811), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6813), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6823), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6827), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6829), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PIPE,
    STATE(4938), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 13,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
  [24261] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5233), 1,
      anon_sym_DASH_GT,
    ACTIONS(5239), 1,
      anon_sym_DOT,
    ACTIONS(6124), 1,
      anon_sym_LPAREN,
    ACTIONS(6156), 1,
      anon_sym_LBRACK,
    ACTIONS(6158), 1,
      anon_sym_BANG,
    ACTIONS(6749), 1,
      anon_sym_DOT_DOT,
    STATE(3577), 1,
      sym_bracketed_argument_list,
    STATE(4561), 1,
      sym_argument_list,
    ACTIONS(6160), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(4939), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(1229), 10,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_as,
    ACTIONS(1227), 25,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_select,
      anon_sym_is,
      anon_sym_with,
  [24370] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3193), 1,
      sym__identifier_token,
    ACTIONS(3205), 1,
      anon_sym_LPAREN,
    ACTIONS(3233), 1,
      anon_sym_var,
    ACTIONS(3235), 1,
      sym_predefined_type,
    ACTIONS(4002), 1,
      anon_sym_delegate,
    ACTIONS(6608), 1,
      anon_sym_ref,
    ACTIONS(6612), 1,
      anon_sym_scoped,
    STATE(4513), 1,
      sym__reserved_identifier,
    STATE(4947), 1,
      sym_identifier,
    STATE(5019), 1,
      sym_generic_name,
    STATE(5295), 1,
      sym_tuple_type,
    STATE(5365), 1,
      sym__name,
    STATE(5473), 1,
      sym_array_type,
    STATE(8791), 1,
      sym_type,
    STATE(8852), 1,
      sym__array_base_type,
    STATE(9443), 1,
      sym__pointer_base_type,
    STATE(2906), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(5385), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4940), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3197), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [24497] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3193), 1,
      sym__identifier_token,
    ACTIONS(3205), 1,
      anon_sym_LPAREN,
    ACTIONS(3235), 1,
      sym_predefined_type,
    ACTIONS(4002), 1,
      anon_sym_delegate,
    ACTIONS(5369), 1,
      anon_sym_var,
    ACTIONS(6717), 1,
      anon_sym_ref,
    ACTIONS(6721), 1,
      anon_sym_scoped,
    STATE(4513), 1,
      sym__reserved_identifier,
    STATE(4947), 1,
      sym_identifier,
    STATE(5019), 1,
      sym_generic_name,
    STATE(5295), 1,
      sym_tuple_type,
    STATE(5365), 1,
      sym__name,
    STATE(5473), 1,
      sym_array_type,
    STATE(8852), 1,
      sym__array_base_type,
    STATE(9180), 1,
      sym_type,
    STATE(9443), 1,
      sym__pointer_base_type,
    STATE(2906), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(5385), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(4941), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3197), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [24624] = 31,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4223), 1,
      sym__identifier_token,
    ACTIONS(4530), 1,
      anon_sym_ref,
    ACTIONS(6182), 1,
      anon_sym_delegate,
    ACTIONS(6186), 1,
      anon_sym_var,
    ACTIONS(6188), 1,
      sym_predefined_type,
    ACTIONS(6262), 1,
      anon_sym_scoped,
    ACTIONS(6624), 1,
      anon_sym_LPAREN,
    STATE(3808), 1,
      sym_identifier,
    STATE(3871), 1,
      sym__reserved_identifier,
    STATE(3880), 1,
      sym_tuple_type,
    STATE(3900), 1,
      sym_generic_name,
    STATE(3904), 1,
      sym__name,
    STATE(3930), 1,
      sym_type,
    STATE(3945), 1,
      sym_array_type,
    STATE(8893), 1,
      sym__array_base_type,
    STATE(9659), 1,
      sym__pointer_base_type,
    STATE(3885), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(3924), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(3943), 3,
      sym_implicit_type,
      sym_ref_type,
      sym_scoped_type,
    STATE(4942), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4225), 20,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [24751] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6723), 1,
      anon_sym_DOT_DOT,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(4943), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6330), 10,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    ACTIONS(6328), 25,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
  [24860] = 37,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5233), 1,
      anon_sym_DASH_GT,
    ACTIONS(5239), 1,
      anon_sym_DOT,
    ACTIONS(6124), 1,
      anon_sym_LPAREN,
    ACTIONS(6156), 1,
      anon_sym_LBRACK,
    ACTIONS(6158), 1,
      anon_sym_BANG,
    ACTIONS(6216), 1,
      anon_sym_switch,
    ACTIONS(6232), 1,
      anon_sym_with,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6406), 1,
      anon_sym_as,
    ACTIONS(6733), 1,
      anon_sym_SLASH,
    ACTIONS(6735), 1,
      anon_sym_CARET,
    ACTIONS(6737), 1,
      anon_sym_PIPE,
    ACTIONS(6739), 1,
      anon_sym_AMP,
    ACTIONS(6743), 1,
      anon_sym_GT_GT,
    ACTIONS(6749), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6757), 1,
      anon_sym_is,
    STATE(3577), 1,
      sym_bracketed_argument_list,
    STATE(4561), 1,
      sym_argument_list,
    ACTIONS(6160), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6725), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6729), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6731), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6741), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6745), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6747), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(4944), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 13,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_select,
  [24999] = 33,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6723), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6815), 1,
      anon_sym_SLASH,
    ACTIONS(6825), 1,
      anon_sym_GT_GT,
    ACTIONS(6837), 1,
      anon_sym_as,
    ACTIONS(6839), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6807), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6811), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6813), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6823), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6829), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 4,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    STATE(4945), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
  [25130] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6841), 1,
      anon_sym_and,
    ACTIONS(6843), 1,
      anon_sym_or,
    STATE(4946), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6594), 12,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6592), 31,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
  [25225] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4147), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6803), 1,
      anon_sym_LT,
    STATE(5001), 1,
      sym_type_argument_list,
    STATE(4947), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4140), 13,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_STAR,
      anon_sym_DOT,
      anon_sym_EQ_GT,
    ACTIONS(4138), 28,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_operator,
      anon_sym_this,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      sym_discard,
      anon_sym_and,
      anon_sym_or,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [25321] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6852), 1,
      anon_sym_into,
    STATE(4948), 10,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
      aux_sym__query_body_repeat2,
    ACTIONS(6486), 12,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6484), 30,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
  [25413] = 41,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6334), 1,
      anon_sym_or,
    ACTIONS(6857), 1,
      anon_sym_QMARK,
    ACTIONS(6863), 1,
      anon_sym_SLASH,
    ACTIONS(6865), 1,
      anon_sym_CARET,
    ACTIONS(6867), 1,
      anon_sym_PIPE,
    ACTIONS(6869), 1,
      anon_sym_AMP,
    ACTIONS(6873), 1,
      anon_sym_GT_GT,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6881), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6883), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6885), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6887), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(6889), 1,
      anon_sym_as,
    ACTIONS(6891), 1,
      anon_sym_is,
    ACTIONS(6893), 1,
      anon_sym_with,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6855), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6859), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6861), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6871), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6875), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6877), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6332), 8,
      anon_sym_where,
      anon_sym_and,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
    STATE(4949), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [25559] = 37,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6863), 1,
      anon_sym_SLASH,
    ACTIONS(6865), 1,
      anon_sym_CARET,
    ACTIONS(6867), 1,
      anon_sym_PIPE,
    ACTIONS(6869), 1,
      anon_sym_AMP,
    ACTIONS(6873), 1,
      anon_sym_GT_GT,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6881), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6889), 1,
      anon_sym_as,
    ACTIONS(6891), 1,
      anon_sym_is,
    ACTIONS(6893), 1,
      anon_sym_with,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_or,
    ACTIONS(6855), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6859), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6861), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6871), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6875), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6877), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(4950), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 11,
      anon_sym_where,
      anon_sym_and,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
  [25697] = 21,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(4951), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5275), 10,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_or,
    ACTIONS(5271), 25,
      anon_sym_where,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [25803] = 41,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6326), 1,
      anon_sym_or,
    ACTIONS(6857), 1,
      anon_sym_QMARK,
    ACTIONS(6863), 1,
      anon_sym_SLASH,
    ACTIONS(6865), 1,
      anon_sym_CARET,
    ACTIONS(6867), 1,
      anon_sym_PIPE,
    ACTIONS(6869), 1,
      anon_sym_AMP,
    ACTIONS(6873), 1,
      anon_sym_GT_GT,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6881), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6883), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6885), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6887), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(6889), 1,
      anon_sym_as,
    ACTIONS(6891), 1,
      anon_sym_is,
    ACTIONS(6893), 1,
      anon_sym_with,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6855), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6859), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6861), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6871), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6875), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6877), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6324), 8,
      anon_sym_where,
      anon_sym_and,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
    STATE(4952), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [25949] = 41,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6220), 1,
      anon_sym_or,
    ACTIONS(6857), 1,
      anon_sym_QMARK,
    ACTIONS(6863), 1,
      anon_sym_SLASH,
    ACTIONS(6865), 1,
      anon_sym_CARET,
    ACTIONS(6867), 1,
      anon_sym_PIPE,
    ACTIONS(6869), 1,
      anon_sym_AMP,
    ACTIONS(6873), 1,
      anon_sym_GT_GT,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6881), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6883), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6885), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6887), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(6889), 1,
      anon_sym_as,
    ACTIONS(6891), 1,
      anon_sym_is,
    ACTIONS(6893), 1,
      anon_sym_with,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6855), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6859), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6861), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6871), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6875), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6877), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6190), 8,
      anon_sym_where,
      anon_sym_and,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
    STATE(4953), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [26095] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4145), 1,
      anon_sym_EQ_GT,
    STATE(4954), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5873), 12,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
      anon_sym_or,
    ACTIONS(4310), 31,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_where,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [26187] = 38,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6863), 1,
      anon_sym_SLASH,
    ACTIONS(6865), 1,
      anon_sym_CARET,
    ACTIONS(6867), 1,
      anon_sym_PIPE,
    ACTIONS(6869), 1,
      anon_sym_AMP,
    ACTIONS(6873), 1,
      anon_sym_GT_GT,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6881), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6883), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6889), 1,
      anon_sym_as,
    ACTIONS(6891), 1,
      anon_sym_is,
    ACTIONS(6893), 1,
      anon_sym_with,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_or,
    ACTIONS(6855), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6859), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6861), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6871), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6875), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6877), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(4955), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 10,
      anon_sym_where,
      anon_sym_and,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
  [26327] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6863), 1,
      anon_sym_SLASH,
    ACTIONS(6865), 1,
      anon_sym_CARET,
    ACTIONS(6867), 1,
      anon_sym_PIPE,
    ACTIONS(6869), 1,
      anon_sym_AMP,
    ACTIONS(6873), 1,
      anon_sym_GT_GT,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6881), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6883), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6885), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6887), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(6889), 1,
      anon_sym_as,
    ACTIONS(6891), 1,
      anon_sym_is,
    ACTIONS(6893), 1,
      anon_sym_with,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_or,
    ACTIONS(6855), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6859), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6861), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6871), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6875), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6877), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 8,
      anon_sym_where,
      anon_sym_and,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
    STATE(4956), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [26471] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6895), 1,
      anon_sym_into,
    STATE(4971), 1,
      aux_sym__query_body_repeat2,
    STATE(4957), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6482), 12,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6480), 30,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
  [26565] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4593), 1,
      anon_sym_LBRACK,
    ACTIONS(4599), 1,
      anon_sym_STAR,
    ACTIONS(5375), 1,
      anon_sym_QMARK,
    ACTIONS(6897), 1,
      anon_sym_DOT,
    STATE(4958), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4492), 10,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_or,
    ACTIONS(4494), 30,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_where,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [26663] = 41,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(5418), 1,
      anon_sym_or,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6857), 1,
      anon_sym_QMARK,
    ACTIONS(6863), 1,
      anon_sym_SLASH,
    ACTIONS(6865), 1,
      anon_sym_CARET,
    ACTIONS(6867), 1,
      anon_sym_PIPE,
    ACTIONS(6869), 1,
      anon_sym_AMP,
    ACTIONS(6873), 1,
      anon_sym_GT_GT,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6881), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6883), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6885), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6887), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(6889), 1,
      anon_sym_as,
    ACTIONS(6891), 1,
      anon_sym_is,
    ACTIONS(6893), 1,
      anon_sym_with,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6855), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6859), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6861), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6871), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6875), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6877), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5416), 8,
      anon_sym_where,
      anon_sym_and,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
    STATE(4959), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [26809] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6881), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(4960), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(1229), 10,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_or,
    ACTIONS(1227), 24,
      anon_sym_where,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_and,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [26917] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6895), 1,
      anon_sym_into,
    STATE(4948), 1,
      aux_sym__query_body_repeat2,
    STATE(4961), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6482), 12,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6480), 30,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
  [27011] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6897), 1,
      anon_sym_DOT,
    STATE(4962), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4453), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_or,
    ACTIONS(4455), 32,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_where,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [27103] = 41,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(5646), 1,
      anon_sym_or,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6857), 1,
      anon_sym_QMARK,
    ACTIONS(6863), 1,
      anon_sym_SLASH,
    ACTIONS(6865), 1,
      anon_sym_CARET,
    ACTIONS(6867), 1,
      anon_sym_PIPE,
    ACTIONS(6869), 1,
      anon_sym_AMP,
    ACTIONS(6873), 1,
      anon_sym_GT_GT,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6881), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6883), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6885), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6887), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(6889), 1,
      anon_sym_as,
    ACTIONS(6891), 1,
      anon_sym_is,
    ACTIONS(6893), 1,
      anon_sym_with,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6855), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6859), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6861), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6871), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6875), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6877), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5644), 8,
      anon_sym_where,
      anon_sym_and,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
    STATE(4963), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [27249] = 41,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(5426), 1,
      anon_sym_or,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6857), 1,
      anon_sym_QMARK,
    ACTIONS(6863), 1,
      anon_sym_SLASH,
    ACTIONS(6865), 1,
      anon_sym_CARET,
    ACTIONS(6867), 1,
      anon_sym_PIPE,
    ACTIONS(6869), 1,
      anon_sym_AMP,
    ACTIONS(6873), 1,
      anon_sym_GT_GT,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6881), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6883), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6885), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6887), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(6889), 1,
      anon_sym_as,
    ACTIONS(6891), 1,
      anon_sym_is,
    ACTIONS(6893), 1,
      anon_sym_with,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6855), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6859), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6861), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6871), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6875), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6877), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5424), 8,
      anon_sym_where,
      anon_sym_and,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
    STATE(4964), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [27395] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6899), 1,
      anon_sym_into,
    STATE(4988), 1,
      aux_sym__query_body_repeat2,
    STATE(4965), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6482), 12,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
      anon_sym_or,
    ACTIONS(6480), 30,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_where,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [27489] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6899), 1,
      anon_sym_into,
    STATE(4968), 1,
      aux_sym__query_body_repeat2,
    STATE(4966), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6482), 12,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
      anon_sym_or,
    ACTIONS(6480), 30,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_where,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [27583] = 41,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(5626), 1,
      anon_sym_or,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6857), 1,
      anon_sym_QMARK,
    ACTIONS(6863), 1,
      anon_sym_SLASH,
    ACTIONS(6865), 1,
      anon_sym_CARET,
    ACTIONS(6867), 1,
      anon_sym_PIPE,
    ACTIONS(6869), 1,
      anon_sym_AMP,
    ACTIONS(6873), 1,
      anon_sym_GT_GT,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6881), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6883), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6885), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6887), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(6889), 1,
      anon_sym_as,
    ACTIONS(6891), 1,
      anon_sym_is,
    ACTIONS(6893), 1,
      anon_sym_with,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6855), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6859), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6861), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6871), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6875), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6877), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5624), 8,
      anon_sym_where,
      anon_sym_and,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
    STATE(4967), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [27729] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6899), 1,
      anon_sym_into,
    STATE(4988), 1,
      aux_sym__query_body_repeat2,
    STATE(4968), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6493), 12,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
      anon_sym_or,
    ACTIONS(6491), 30,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_where,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [27823] = 29,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6863), 1,
      anon_sym_SLASH,
    ACTIONS(6873), 1,
      anon_sym_GT_GT,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6881), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6893), 1,
      anon_sym_with,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6859), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6861), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6871), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6344), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_or,
    STATE(4969), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 18,
      anon_sym_where,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_and,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
      anon_sym_as,
      anon_sym_is,
  [27945] = 26,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6863), 1,
      anon_sym_SLASH,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6881), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6893), 1,
      anon_sym_with,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6861), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_or,
    STATE(4970), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 20,
      anon_sym_where,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_and,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
      anon_sym_as,
      anon_sym_is,
  [28061] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6895), 1,
      anon_sym_into,
    STATE(4948), 1,
      aux_sym__query_body_repeat2,
    STATE(4971), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6493), 12,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6491), 30,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
  [28155] = 21,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(4972), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5327), 10,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_or,
    ACTIONS(5325), 25,
      anon_sym_where,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [28261] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6881), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(4973), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6330), 10,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_or,
    ACTIONS(6328), 24,
      anon_sym_where,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_and,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [28369] = 41,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6338), 1,
      anon_sym_or,
    ACTIONS(6857), 1,
      anon_sym_QMARK,
    ACTIONS(6863), 1,
      anon_sym_SLASH,
    ACTIONS(6865), 1,
      anon_sym_CARET,
    ACTIONS(6867), 1,
      anon_sym_PIPE,
    ACTIONS(6869), 1,
      anon_sym_AMP,
    ACTIONS(6873), 1,
      anon_sym_GT_GT,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6881), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6883), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6885), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6887), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(6889), 1,
      anon_sym_as,
    ACTIONS(6891), 1,
      anon_sym_is,
    ACTIONS(6893), 1,
      anon_sym_with,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6855), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6859), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6861), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6871), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6875), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6877), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6336), 8,
      anon_sym_where,
      anon_sym_and,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
    STATE(4974), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [28515] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6881), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6893), 1,
      anon_sym_with,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(4975), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6344), 10,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_or,
    ACTIONS(6342), 22,
      anon_sym_where,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_and,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
      anon_sym_as,
      anon_sym_is,
  [28627] = 21,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    STATE(4976), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5294), 10,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_or,
    ACTIONS(5292), 25,
      anon_sym_where,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [28733] = 35,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6863), 1,
      anon_sym_SLASH,
    ACTIONS(6869), 1,
      anon_sym_AMP,
    ACTIONS(6873), 1,
      anon_sym_GT_GT,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6881), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6889), 1,
      anon_sym_as,
    ACTIONS(6891), 1,
      anon_sym_is,
    ACTIONS(6893), 1,
      anon_sym_with,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6855), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6859), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6861), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6871), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6875), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6877), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_or,
    STATE(4977), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 12,
      anon_sym_where,
      anon_sym_CARET,
      anon_sym_and,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
  [28867] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6899), 1,
      anon_sym_into,
    STATE(4965), 1,
      aux_sym__query_body_repeat2,
    STATE(4978), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6476), 12,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
      anon_sym_or,
    ACTIONS(6474), 30,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_where,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [28961] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(4075), 1,
      anon_sym_where,
    ACTIONS(5988), 1,
      anon_sym_ref,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(2883), 1,
      sym_ref_type,
    STATE(2885), 1,
      sym__scoped_base_type,
    STATE(5346), 1,
      sym_identifier,
    STATE(6202), 1,
      sym__name,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(4979), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3993), 11,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_STAR,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_COLON_COLON,
    ACTIONS(29), 21,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [29071] = 36,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6863), 1,
      anon_sym_SLASH,
    ACTIONS(6865), 1,
      anon_sym_CARET,
    ACTIONS(6869), 1,
      anon_sym_AMP,
    ACTIONS(6873), 1,
      anon_sym_GT_GT,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6881), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6889), 1,
      anon_sym_as,
    ACTIONS(6891), 1,
      anon_sym_is,
    ACTIONS(6893), 1,
      anon_sym_with,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6855), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6859), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6861), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6871), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6875), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6877), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_or,
    STATE(4980), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 11,
      anon_sym_where,
      anon_sym_and,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
  [29207] = 34,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6863), 1,
      anon_sym_SLASH,
    ACTIONS(6873), 1,
      anon_sym_GT_GT,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6881), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6889), 1,
      anon_sym_as,
    ACTIONS(6891), 1,
      anon_sym_is,
    ACTIONS(6893), 1,
      anon_sym_with,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6855), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6859), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6861), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6871), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6875), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6877), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 4,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_or,
    STATE(4981), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 12,
      anon_sym_where,
      anon_sym_CARET,
      anon_sym_and,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
  [29339] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6863), 1,
      anon_sym_SLASH,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6881), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6893), 1,
      anon_sym_with,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6859), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6861), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_or,
    STATE(4982), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 20,
      anon_sym_where,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_and,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
      anon_sym_as,
      anon_sym_is,
  [29457] = 41,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6322), 1,
      anon_sym_or,
    ACTIONS(6857), 1,
      anon_sym_QMARK,
    ACTIONS(6863), 1,
      anon_sym_SLASH,
    ACTIONS(6865), 1,
      anon_sym_CARET,
    ACTIONS(6867), 1,
      anon_sym_PIPE,
    ACTIONS(6869), 1,
      anon_sym_AMP,
    ACTIONS(6873), 1,
      anon_sym_GT_GT,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6881), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6883), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6885), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6887), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(6889), 1,
      anon_sym_as,
    ACTIONS(6891), 1,
      anon_sym_is,
    ACTIONS(6893), 1,
      anon_sym_with,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6855), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6859), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6861), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6871), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6875), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6877), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6320), 8,
      anon_sym_where,
      anon_sym_and,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
    STATE(4983), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [29603] = 41,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(5574), 1,
      anon_sym_or,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6857), 1,
      anon_sym_QMARK,
    ACTIONS(6863), 1,
      anon_sym_SLASH,
    ACTIONS(6865), 1,
      anon_sym_CARET,
    ACTIONS(6867), 1,
      anon_sym_PIPE,
    ACTIONS(6869), 1,
      anon_sym_AMP,
    ACTIONS(6873), 1,
      anon_sym_GT_GT,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6881), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6883), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6885), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6887), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(6889), 1,
      anon_sym_as,
    ACTIONS(6891), 1,
      anon_sym_is,
    ACTIONS(6893), 1,
      anon_sym_with,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6855), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6859), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6861), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6871), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6875), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6877), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5572), 8,
      anon_sym_where,
      anon_sym_and,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
    STATE(4984), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [29749] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6895), 1,
      anon_sym_into,
    STATE(4961), 1,
      aux_sym__query_body_repeat2,
    STATE(4985), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6476), 12,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6474), 30,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
  [29843] = 41,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(5586), 1,
      anon_sym_or,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6857), 1,
      anon_sym_QMARK,
    ACTIONS(6863), 1,
      anon_sym_SLASH,
    ACTIONS(6865), 1,
      anon_sym_CARET,
    ACTIONS(6867), 1,
      anon_sym_PIPE,
    ACTIONS(6869), 1,
      anon_sym_AMP,
    ACTIONS(6873), 1,
      anon_sym_GT_GT,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6881), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6883), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6885), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6887), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(6889), 1,
      anon_sym_as,
    ACTIONS(6891), 1,
      anon_sym_is,
    ACTIONS(6893), 1,
      anon_sym_with,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6855), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6859), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6861), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6871), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6875), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6877), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5584), 8,
      anon_sym_where,
      anon_sym_and,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
    STATE(4986), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [29989] = 33,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6863), 1,
      anon_sym_SLASH,
    ACTIONS(6873), 1,
      anon_sym_GT_GT,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6881), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6889), 1,
      anon_sym_as,
    ACTIONS(6891), 1,
      anon_sym_is,
    ACTIONS(6893), 1,
      anon_sym_with,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6855), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6859), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6861), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6871), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6877), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 4,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_or,
    STATE(4987), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 14,
      anon_sym_where,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_and,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
  [30119] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6901), 1,
      anon_sym_into,
    STATE(4988), 10,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
      aux_sym__query_body_repeat2,
    ACTIONS(6486), 12,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
      anon_sym_or,
    ACTIONS(6484), 30,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_where,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [30211] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6797), 1,
      anon_sym_as,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6906), 1,
      anon_sym_QMARK,
    ACTIONS(6912), 1,
      anon_sym_SLASH,
    ACTIONS(6914), 1,
      anon_sym_CARET,
    ACTIONS(6916), 1,
      anon_sym_PIPE,
    ACTIONS(6918), 1,
      anon_sym_AMP,
    ACTIONS(6922), 1,
      anon_sym_GT_GT,
    ACTIONS(6928), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6930), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6932), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6934), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(6936), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6904), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6908), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6910), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6920), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6924), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6926), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5584), 8,
      anon_sym_where,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
    STATE(4989), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [30354] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4814), 1,
      anon_sym_or,
    ACTIONS(4806), 9,
      anon_sym_where,
      anon_sym_and,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
    STATE(4990), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5886), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5883), 22,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [30447] = 34,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6797), 1,
      anon_sym_as,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6912), 1,
      anon_sym_SLASH,
    ACTIONS(6922), 1,
      anon_sym_GT_GT,
    ACTIONS(6928), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6936), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6904), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6908), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6910), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6920), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6924), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6926), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    STATE(4991), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 12,
      anon_sym_where,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
  [30578] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6938), 1,
      anon_sym_and,
    ACTIONS(6940), 1,
      anon_sym_or,
    STATE(4992), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6594), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6592), 30,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_where,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [30671] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(4993), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5915), 12,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
      anon_sym_or,
    ACTIONS(5913), 31,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_where,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [30760] = 37,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6797), 1,
      anon_sym_as,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6912), 1,
      anon_sym_SLASH,
    ACTIONS(6914), 1,
      anon_sym_CARET,
    ACTIONS(6916), 1,
      anon_sym_PIPE,
    ACTIONS(6918), 1,
      anon_sym_AMP,
    ACTIONS(6922), 1,
      anon_sym_GT_GT,
    ACTIONS(6928), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6936), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6904), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6908), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6910), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6920), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6924), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6926), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(4994), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 11,
      anon_sym_where,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
  [30897] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(4995), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5881), 12,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
      anon_sym_or,
    ACTIONS(5879), 31,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_where,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [30986] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6797), 1,
      anon_sym_as,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6906), 1,
      anon_sym_QMARK,
    ACTIONS(6912), 1,
      anon_sym_SLASH,
    ACTIONS(6914), 1,
      anon_sym_CARET,
    ACTIONS(6916), 1,
      anon_sym_PIPE,
    ACTIONS(6918), 1,
      anon_sym_AMP,
    ACTIONS(6922), 1,
      anon_sym_GT_GT,
    ACTIONS(6928), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6930), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6932), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6934), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(6936), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6904), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6908), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6910), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6920), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6924), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6926), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6336), 8,
      anon_sym_where,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
    STATE(4996), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [31129] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6797), 1,
      anon_sym_as,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6906), 1,
      anon_sym_QMARK,
    ACTIONS(6912), 1,
      anon_sym_SLASH,
    ACTIONS(6914), 1,
      anon_sym_CARET,
    ACTIONS(6916), 1,
      anon_sym_PIPE,
    ACTIONS(6918), 1,
      anon_sym_AMP,
    ACTIONS(6922), 1,
      anon_sym_GT_GT,
    ACTIONS(6928), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6930), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6932), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6934), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(6936), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6904), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6908), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6910), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6920), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6924), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6926), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5572), 8,
      anon_sym_where,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
    STATE(4997), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [31272] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(4998), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4136), 15,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_STAR,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_DASH_GT,
    ACTIONS(4134), 28,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_operator,
      anon_sym_this,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      sym_discard,
      anon_sym_and,
      anon_sym_or,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [31361] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6797), 1,
      anon_sym_as,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6906), 1,
      anon_sym_QMARK,
    ACTIONS(6912), 1,
      anon_sym_SLASH,
    ACTIONS(6914), 1,
      anon_sym_CARET,
    ACTIONS(6916), 1,
      anon_sym_PIPE,
    ACTIONS(6918), 1,
      anon_sym_AMP,
    ACTIONS(6922), 1,
      anon_sym_GT_GT,
    ACTIONS(6928), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6930), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6932), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6934), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(6936), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6904), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6908), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6910), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6920), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6924), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6926), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6942), 8,
      anon_sym_where,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
    STATE(4999), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [31504] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6938), 1,
      anon_sym_and,
    ACTIONS(6940), 1,
      anon_sym_or,
    STATE(5000), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5881), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5879), 30,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_where,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [31597] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5001), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4132), 15,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_STAR,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_DASH_GT,
    ACTIONS(4130), 28,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_operator,
      anon_sym_this,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      sym_discard,
      anon_sym_and,
      anon_sym_or,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [31686] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5002), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5930), 12,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
      anon_sym_or,
    ACTIONS(5928), 31,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_where,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [31775] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6797), 1,
      anon_sym_as,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6906), 1,
      anon_sym_QMARK,
    ACTIONS(6912), 1,
      anon_sym_SLASH,
    ACTIONS(6914), 1,
      anon_sym_CARET,
    ACTIONS(6916), 1,
      anon_sym_PIPE,
    ACTIONS(6918), 1,
      anon_sym_AMP,
    ACTIONS(6922), 1,
      anon_sym_GT_GT,
    ACTIONS(6928), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6930), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6932), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6934), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(6936), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6904), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6908), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6910), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6920), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6924), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6926), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6190), 8,
      anon_sym_where,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
    STATE(5003), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [31918] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5004), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5962), 12,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
      anon_sym_or,
    ACTIONS(5960), 31,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_where,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [32007] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5005), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5848), 12,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
      anon_sym_or,
    ACTIONS(5846), 31,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_where,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [32096] = 26,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6912), 1,
      anon_sym_SLASH,
    ACTIONS(6928), 1,
      anon_sym_DOT_DOT,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6910), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5006), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 20,
      anon_sym_where,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
      anon_sym_as,
      anon_sym_is,
  [32211] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5007), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4168), 15,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_STAR,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_DASH_GT,
    ACTIONS(4157), 28,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_operator,
      anon_sym_this,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      sym_discard,
      anon_sym_and,
      anon_sym_or,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [32300] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6912), 1,
      anon_sym_SLASH,
    ACTIONS(6928), 1,
      anon_sym_DOT_DOT,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6908), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6910), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5008), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 20,
      anon_sym_where,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
      anon_sym_as,
      anon_sym_is,
  [32417] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6797), 1,
      anon_sym_as,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6906), 1,
      anon_sym_QMARK,
    ACTIONS(6912), 1,
      anon_sym_SLASH,
    ACTIONS(6914), 1,
      anon_sym_CARET,
    ACTIONS(6916), 1,
      anon_sym_PIPE,
    ACTIONS(6918), 1,
      anon_sym_AMP,
    ACTIONS(6922), 1,
      anon_sym_GT_GT,
    ACTIONS(6928), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6930), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6932), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6934), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(6936), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6904), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6908), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6910), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6920), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6924), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6926), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5624), 8,
      anon_sym_where,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
    STATE(5009), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [32560] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6938), 1,
      anon_sym_and,
    STATE(5010), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6707), 12,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
      anon_sym_or,
    ACTIONS(6705), 30,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_where,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [32651] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6928), 1,
      anon_sym_DOT_DOT,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6330), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5011), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6328), 24,
      anon_sym_where,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [32758] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5012), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5871), 12,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
      anon_sym_or,
    ACTIONS(5869), 31,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_where,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [32847] = 33,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6797), 1,
      anon_sym_as,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6912), 1,
      anon_sym_SLASH,
    ACTIONS(6922), 1,
      anon_sym_GT_GT,
    ACTIONS(6928), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6936), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6904), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6908), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6910), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6920), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6926), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    STATE(5013), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 14,
      anon_sym_where,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
  [32976] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5014), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4626), 15,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_STAR,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_DASH_GT,
    ACTIONS(4624), 28,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_operator,
      anon_sym_this,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      sym_discard,
      anon_sym_and,
      anon_sym_or,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [33065] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6797), 1,
      anon_sym_as,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6912), 1,
      anon_sym_SLASH,
    ACTIONS(6914), 1,
      anon_sym_CARET,
    ACTIONS(6916), 1,
      anon_sym_PIPE,
    ACTIONS(6918), 1,
      anon_sym_AMP,
    ACTIONS(6922), 1,
      anon_sym_GT_GT,
    ACTIONS(6928), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6930), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6932), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6934), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(6936), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6904), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6908), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6910), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6920), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6924), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6926), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 8,
      anon_sym_where,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
    STATE(5015), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [33208] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(6717), 1,
      anon_sym_ref,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(2883), 1,
      sym_ref_type,
    STATE(2885), 1,
      sym__scoped_base_type,
    STATE(5346), 1,
      sym_identifier,
    STATE(6202), 1,
      sym__name,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(5016), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3993), 10,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_STAR,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [33315] = 38,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6797), 1,
      anon_sym_as,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6912), 1,
      anon_sym_SLASH,
    ACTIONS(6914), 1,
      anon_sym_CARET,
    ACTIONS(6916), 1,
      anon_sym_PIPE,
    ACTIONS(6918), 1,
      anon_sym_AMP,
    ACTIONS(6922), 1,
      anon_sym_GT_GT,
    ACTIONS(6928), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6930), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6936), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6904), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6908), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6910), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6920), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6924), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6926), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(5017), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 10,
      anon_sym_where,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
  [33454] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6928), 1,
      anon_sym_DOT_DOT,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5018), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 22,
      anon_sym_where,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
      anon_sym_as,
      anon_sym_is,
  [33565] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5019), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4140), 15,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_STAR,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_DASH_GT,
    ACTIONS(4138), 28,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_operator,
      anon_sym_this,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      sym_discard,
      anon_sym_and,
      anon_sym_or,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [33654] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5020), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5897), 12,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
      anon_sym_or,
    ACTIONS(5895), 31,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_where,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [33743] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5021), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5940), 12,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
      anon_sym_or,
    ACTIONS(5938), 31,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_where,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [33832] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5022), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5934), 12,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
      anon_sym_or,
    ACTIONS(5932), 31,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_where,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [33921] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5023), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5877), 12,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
      anon_sym_or,
    ACTIONS(5875), 31,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_where,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [34010] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6797), 1,
      anon_sym_as,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6906), 1,
      anon_sym_QMARK,
    ACTIONS(6912), 1,
      anon_sym_SLASH,
    ACTIONS(6914), 1,
      anon_sym_CARET,
    ACTIONS(6916), 1,
      anon_sym_PIPE,
    ACTIONS(6918), 1,
      anon_sym_AMP,
    ACTIONS(6922), 1,
      anon_sym_GT_GT,
    ACTIONS(6928), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6930), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6932), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6934), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(6936), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6904), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6908), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6910), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6920), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6924), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6926), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6266), 8,
      anon_sym_where,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
    STATE(5024), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [34153] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5025), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4128), 15,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_STAR,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_DASH_GT,
    ACTIONS(4126), 28,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_operator,
      anon_sym_this,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      sym_discard,
      anon_sym_and,
      anon_sym_or,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [34242] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5026), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5911), 12,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
      anon_sym_or,
    ACTIONS(5909), 31,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_where,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [34331] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5027), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5863), 12,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
      anon_sym_or,
    ACTIONS(5861), 31,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_where,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [34420] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6797), 1,
      anon_sym_as,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6906), 1,
      anon_sym_QMARK,
    ACTIONS(6912), 1,
      anon_sym_SLASH,
    ACTIONS(6914), 1,
      anon_sym_CARET,
    ACTIONS(6916), 1,
      anon_sym_PIPE,
    ACTIONS(6918), 1,
      anon_sym_AMP,
    ACTIONS(6922), 1,
      anon_sym_GT_GT,
    ACTIONS(6928), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6930), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6932), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6934), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(6936), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6904), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6908), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6910), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6920), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6924), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6926), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6270), 8,
      anon_sym_where,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
    STATE(5028), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [34563] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5029), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5958), 12,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
      anon_sym_or,
    ACTIONS(5956), 31,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_where,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [34652] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6797), 1,
      anon_sym_as,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6906), 1,
      anon_sym_QMARK,
    ACTIONS(6912), 1,
      anon_sym_SLASH,
    ACTIONS(6914), 1,
      anon_sym_CARET,
    ACTIONS(6916), 1,
      anon_sym_PIPE,
    ACTIONS(6918), 1,
      anon_sym_AMP,
    ACTIONS(6922), 1,
      anon_sym_GT_GT,
    ACTIONS(6928), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6930), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6932), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6934), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(6936), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6904), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6908), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6910), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6920), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6924), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6926), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5424), 8,
      anon_sym_where,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
    STATE(5030), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [34795] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6797), 1,
      anon_sym_as,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6906), 1,
      anon_sym_QMARK,
    ACTIONS(6912), 1,
      anon_sym_SLASH,
    ACTIONS(6914), 1,
      anon_sym_CARET,
    ACTIONS(6916), 1,
      anon_sym_PIPE,
    ACTIONS(6918), 1,
      anon_sym_AMP,
    ACTIONS(6922), 1,
      anon_sym_GT_GT,
    ACTIONS(6928), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6930), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6932), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6934), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(6936), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6904), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6908), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6910), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6920), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6924), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6926), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6324), 8,
      anon_sym_where,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
    STATE(5031), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [34938] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5032), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5966), 12,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
      anon_sym_or,
    ACTIONS(5964), 31,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_where,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [35027] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5033), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5867), 12,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
      anon_sym_or,
    ACTIONS(5865), 31,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_where,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [35116] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5034), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5873), 12,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
      anon_sym_or,
    ACTIONS(4310), 31,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_where,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [35205] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5035), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5972), 12,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
      anon_sym_or,
    ACTIONS(5970), 31,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_where,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [35294] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5036), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5930), 12,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
      anon_sym_or,
    ACTIONS(5928), 31,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_where,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [35383] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4814), 1,
      anon_sym_or,
    ACTIONS(4806), 9,
      anon_sym_where,
      anon_sym_and,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
    STATE(5037), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5892), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5889), 22,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [35476] = 36,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6797), 1,
      anon_sym_as,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6912), 1,
      anon_sym_SLASH,
    ACTIONS(6914), 1,
      anon_sym_CARET,
    ACTIONS(6918), 1,
      anon_sym_AMP,
    ACTIONS(6922), 1,
      anon_sym_GT_GT,
    ACTIONS(6928), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6936), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(6904), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6908), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6910), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6920), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6924), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6926), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(5038), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 11,
      anon_sym_where,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
  [35611] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5039), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5944), 12,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
      anon_sym_or,
    ACTIONS(5942), 31,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_where,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [35700] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6797), 1,
      anon_sym_as,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6906), 1,
      anon_sym_QMARK,
    ACTIONS(6912), 1,
      anon_sym_SLASH,
    ACTIONS(6914), 1,
      anon_sym_CARET,
    ACTIONS(6916), 1,
      anon_sym_PIPE,
    ACTIONS(6918), 1,
      anon_sym_AMP,
    ACTIONS(6922), 1,
      anon_sym_GT_GT,
    ACTIONS(6928), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6930), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6932), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6934), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(6936), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6904), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6908), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6910), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6920), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6924), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6926), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6320), 8,
      anon_sym_where,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
    STATE(5040), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [35843] = 35,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6797), 1,
      anon_sym_as,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6912), 1,
      anon_sym_SLASH,
    ACTIONS(6918), 1,
      anon_sym_AMP,
    ACTIONS(6922), 1,
      anon_sym_GT_GT,
    ACTIONS(6928), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6936), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(6904), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6908), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6910), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6920), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6924), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6926), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(5041), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 12,
      anon_sym_where,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
  [35976] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6797), 1,
      anon_sym_as,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6906), 1,
      anon_sym_QMARK,
    ACTIONS(6912), 1,
      anon_sym_SLASH,
    ACTIONS(6914), 1,
      anon_sym_CARET,
    ACTIONS(6916), 1,
      anon_sym_PIPE,
    ACTIONS(6918), 1,
      anon_sym_AMP,
    ACTIONS(6922), 1,
      anon_sym_GT_GT,
    ACTIONS(6928), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6930), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6932), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6934), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(6936), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6904), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6908), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6910), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6920), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6924), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6926), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5644), 8,
      anon_sym_where,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
    STATE(5042), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [36119] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6797), 1,
      anon_sym_as,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6906), 1,
      anon_sym_QMARK,
    ACTIONS(6912), 1,
      anon_sym_SLASH,
    ACTIONS(6914), 1,
      anon_sym_CARET,
    ACTIONS(6916), 1,
      anon_sym_PIPE,
    ACTIONS(6918), 1,
      anon_sym_AMP,
    ACTIONS(6922), 1,
      anon_sym_GT_GT,
    ACTIONS(6928), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6930), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6932), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6934), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(6936), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6904), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6908), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6910), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6920), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6924), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6926), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5416), 8,
      anon_sym_where,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
    STATE(5043), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [36262] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5044), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4151), 15,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_STAR,
      anon_sym_DOT,
      anon_sym_EQ_GT,
      anon_sym_DASH_GT,
    ACTIONS(4149), 28,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_operator,
      anon_sym_this,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      sym_discard,
      anon_sym_and,
      anon_sym_or,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [36351] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5045), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5915), 12,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
      anon_sym_or,
    ACTIONS(5913), 31,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_where,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [36440] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5046), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5948), 12,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
      anon_sym_or,
    ACTIONS(5946), 31,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_where,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [36529] = 29,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6912), 1,
      anon_sym_SLASH,
    ACTIONS(6922), 1,
      anon_sym_GT_GT,
    ACTIONS(6928), 1,
      anon_sym_DOT_DOT,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6908), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6910), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6920), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6344), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    STATE(5047), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 18,
      anon_sym_where,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
      anon_sym_as,
      anon_sym_is,
  [36650] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6928), 1,
      anon_sym_DOT_DOT,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1229), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5048), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(1227), 24,
      anon_sym_where,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [36757] = 37,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6444), 1,
      anon_sym_as,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(6950), 1,
      anon_sym_SLASH,
    ACTIONS(6952), 1,
      anon_sym_CARET,
    ACTIONS(6954), 1,
      anon_sym_PIPE,
    ACTIONS(6956), 1,
      anon_sym_AMP,
    ACTIONS(6960), 1,
      anon_sym_GT_GT,
    ACTIONS(6966), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6968), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6944), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6946), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6948), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6958), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6962), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6964), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(5049), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 10,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
  [36893] = 35,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6976), 1,
      anon_sym_SLASH,
    ACTIONS(6978), 1,
      anon_sym_AMP,
    ACTIONS(6982), 1,
      anon_sym_GT_GT,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6990), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6994), 1,
      anon_sym_is,
    ACTIONS(6996), 1,
      anon_sym_with,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(6970), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6972), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6974), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6980), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6984), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6986), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(5050), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 11,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
  [37025] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6889), 1,
      anon_sym_as,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7002), 1,
      anon_sym_QMARK,
    ACTIONS(7008), 1,
      anon_sym_SLASH,
    ACTIONS(7010), 1,
      anon_sym_CARET,
    ACTIONS(7012), 1,
      anon_sym_PIPE,
    ACTIONS(7014), 1,
      anon_sym_AMP,
    ACTIONS(7018), 1,
      anon_sym_GT_GT,
    ACTIONS(7024), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7026), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7028), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7030), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7032), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6998), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7004), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7006), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7016), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7020), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7022), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(7000), 7,
      anon_sym_where,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
    STATE(5051), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [37167] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7034), 1,
      anon_sym_and,
    STATE(5052), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6707), 12,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
      anon_sym_or,
    ACTIONS(6705), 29,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_where,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [37257] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6976), 1,
      anon_sym_SLASH,
    ACTIONS(6978), 1,
      anon_sym_AMP,
    ACTIONS(6982), 1,
      anon_sym_GT_GT,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6990), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6994), 1,
      anon_sym_is,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7036), 1,
      anon_sym_QMARK,
    ACTIONS(7038), 1,
      anon_sym_CARET,
    ACTIONS(7040), 1,
      anon_sym_PIPE,
    ACTIONS(7042), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7044), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7046), 1,
      anon_sym_QMARK_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6970), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6972), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6974), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6980), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6984), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6986), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6332), 7,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_and,
      anon_sym_or,
    STATE(5053), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [37399] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6889), 1,
      anon_sym_as,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7002), 1,
      anon_sym_QMARK,
    ACTIONS(7008), 1,
      anon_sym_SLASH,
    ACTIONS(7010), 1,
      anon_sym_CARET,
    ACTIONS(7012), 1,
      anon_sym_PIPE,
    ACTIONS(7014), 1,
      anon_sym_AMP,
    ACTIONS(7018), 1,
      anon_sym_GT_GT,
    ACTIONS(7024), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7026), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7028), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7030), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7032), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6998), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7004), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7006), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7016), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7020), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7022), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5584), 7,
      anon_sym_where,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
    STATE(5054), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [37541] = 29,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7008), 1,
      anon_sym_SLASH,
    ACTIONS(7018), 1,
      anon_sym_GT_GT,
    ACTIONS(7024), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7004), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7006), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7016), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6344), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    STATE(5055), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 17,
      anon_sym_where,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
      anon_sym_as,
      anon_sym_is,
  [37661] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6889), 1,
      anon_sym_as,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7002), 1,
      anon_sym_QMARK,
    ACTIONS(7008), 1,
      anon_sym_SLASH,
    ACTIONS(7010), 1,
      anon_sym_CARET,
    ACTIONS(7012), 1,
      anon_sym_PIPE,
    ACTIONS(7014), 1,
      anon_sym_AMP,
    ACTIONS(7018), 1,
      anon_sym_GT_GT,
    ACTIONS(7024), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7026), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7028), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7030), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7032), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6998), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7004), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7006), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7016), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7020), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7022), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5624), 7,
      anon_sym_where,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
    STATE(5056), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [37803] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6966), 1,
      anon_sym_DOT_DOT,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1229), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5057), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(1227), 23,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [37909] = 36,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6976), 1,
      anon_sym_SLASH,
    ACTIONS(6978), 1,
      anon_sym_AMP,
    ACTIONS(6982), 1,
      anon_sym_GT_GT,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6990), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6994), 1,
      anon_sym_is,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7038), 1,
      anon_sym_CARET,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(6970), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6972), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6974), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6980), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6984), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6986), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(5058), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 10,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
  [38043] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7034), 1,
      anon_sym_and,
    ACTIONS(7048), 1,
      anon_sym_or,
    STATE(5059), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5881), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5879), 29,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_where,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [38135] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4806), 4,
      anon_sym_EQ_GT,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
    ACTIONS(5883), 4,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(5060), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5654), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5652), 23,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [38227] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4806), 4,
      anon_sym_EQ_GT,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
    ACTIONS(5889), 4,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(5061), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5630), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5628), 23,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [38319] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6889), 1,
      anon_sym_as,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7002), 1,
      anon_sym_QMARK,
    ACTIONS(7008), 1,
      anon_sym_SLASH,
    ACTIONS(7010), 1,
      anon_sym_CARET,
    ACTIONS(7012), 1,
      anon_sym_PIPE,
    ACTIONS(7014), 1,
      anon_sym_AMP,
    ACTIONS(7018), 1,
      anon_sym_GT_GT,
    ACTIONS(7024), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7026), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7028), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7030), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7032), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6998), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7004), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7006), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7016), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7020), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7022), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6190), 7,
      anon_sym_where,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
    STATE(5062), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [38461] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6889), 1,
      anon_sym_as,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7002), 1,
      anon_sym_QMARK,
    ACTIONS(7008), 1,
      anon_sym_SLASH,
    ACTIONS(7010), 1,
      anon_sym_CARET,
    ACTIONS(7012), 1,
      anon_sym_PIPE,
    ACTIONS(7014), 1,
      anon_sym_AMP,
    ACTIONS(7018), 1,
      anon_sym_GT_GT,
    ACTIONS(7024), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7026), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7028), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7030), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7032), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6998), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7004), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7006), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7016), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7020), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7022), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6324), 7,
      anon_sym_where,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
    STATE(5063), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [38603] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6889), 1,
      anon_sym_as,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7002), 1,
      anon_sym_QMARK,
    ACTIONS(7008), 1,
      anon_sym_SLASH,
    ACTIONS(7010), 1,
      anon_sym_CARET,
    ACTIONS(7012), 1,
      anon_sym_PIPE,
    ACTIONS(7014), 1,
      anon_sym_AMP,
    ACTIONS(7018), 1,
      anon_sym_GT_GT,
    ACTIONS(7024), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7026), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7028), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7030), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7032), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6998), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7004), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7006), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7016), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7020), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7022), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5572), 7,
      anon_sym_where,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
    STATE(5064), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [38745] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(1411), 1,
      anon_sym_LBRACE,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    STATE(5203), 1,
      sym_argument_list,
    STATE(5551), 1,
      sym_initializer_expression,
    STATE(5065), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5267), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5263), 27,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [38841] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(7024), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1229), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5066), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(1227), 23,
      anon_sym_where,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [38947] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6889), 1,
      anon_sym_as,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7002), 1,
      anon_sym_QMARK,
    ACTIONS(7008), 1,
      anon_sym_SLASH,
    ACTIONS(7010), 1,
      anon_sym_CARET,
    ACTIONS(7012), 1,
      anon_sym_PIPE,
    ACTIONS(7014), 1,
      anon_sym_AMP,
    ACTIONS(7018), 1,
      anon_sym_GT_GT,
    ACTIONS(7024), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7026), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7028), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7030), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7032), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6998), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7004), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7006), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7016), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7020), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7022), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6320), 7,
      anon_sym_where,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
    STATE(5067), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [39089] = 26,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7008), 1,
      anon_sym_SLASH,
    ACTIONS(7024), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7006), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5068), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 19,
      anon_sym_where,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
      anon_sym_as,
      anon_sym_is,
  [39203] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7024), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5069), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 21,
      anon_sym_where,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
      anon_sym_as,
      anon_sym_is,
  [39313] = 35,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6889), 1,
      anon_sym_as,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7008), 1,
      anon_sym_SLASH,
    ACTIONS(7014), 1,
      anon_sym_AMP,
    ACTIONS(7018), 1,
      anon_sym_GT_GT,
    ACTIONS(7024), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7032), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(6998), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7004), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7006), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7016), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7020), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7022), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(5070), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 11,
      anon_sym_where,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
  [39445] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6889), 1,
      anon_sym_as,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7002), 1,
      anon_sym_QMARK,
    ACTIONS(7008), 1,
      anon_sym_SLASH,
    ACTIONS(7010), 1,
      anon_sym_CARET,
    ACTIONS(7012), 1,
      anon_sym_PIPE,
    ACTIONS(7014), 1,
      anon_sym_AMP,
    ACTIONS(7018), 1,
      anon_sym_GT_GT,
    ACTIONS(7024), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7026), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7028), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7030), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7032), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6998), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7004), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7006), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7016), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7020), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7022), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5644), 7,
      anon_sym_where,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
    STATE(5071), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [39587] = 36,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6889), 1,
      anon_sym_as,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7008), 1,
      anon_sym_SLASH,
    ACTIONS(7010), 1,
      anon_sym_CARET,
    ACTIONS(7014), 1,
      anon_sym_AMP,
    ACTIONS(7018), 1,
      anon_sym_GT_GT,
    ACTIONS(7024), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7032), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(6998), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7004), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7006), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7016), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7020), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7022), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(5072), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 10,
      anon_sym_where,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
  [39721] = 34,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6976), 1,
      anon_sym_SLASH,
    ACTIONS(6982), 1,
      anon_sym_GT_GT,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6990), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6994), 1,
      anon_sym_is,
    ACTIONS(6996), 1,
      anon_sym_with,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6970), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6972), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6974), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6980), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6984), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6986), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    STATE(5073), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 11,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
  [39851] = 34,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6889), 1,
      anon_sym_as,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7008), 1,
      anon_sym_SLASH,
    ACTIONS(7018), 1,
      anon_sym_GT_GT,
    ACTIONS(7024), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7032), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6998), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7004), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7006), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7016), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7020), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7022), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    STATE(5074), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 11,
      anon_sym_where,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
  [39981] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7008), 1,
      anon_sym_SLASH,
    ACTIONS(7024), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7004), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7006), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5075), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 19,
      anon_sym_where,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
      anon_sym_as,
      anon_sym_is,
  [40097] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7052), 1,
      anon_sym_LT,
    ACTIONS(7055), 1,
      anon_sym_COLON_COLON,
    STATE(5254), 1,
      sym_type_argument_list,
    STATE(5076), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4138), 11,
      anon_sym_COLON,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(4140), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [40191] = 33,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6889), 1,
      anon_sym_as,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7008), 1,
      anon_sym_SLASH,
    ACTIONS(7018), 1,
      anon_sym_GT_GT,
    ACTIONS(7024), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7032), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6998), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7004), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7006), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7016), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7022), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    STATE(5077), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 13,
      anon_sym_where,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
  [40319] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6889), 1,
      anon_sym_as,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7002), 1,
      anon_sym_QMARK,
    ACTIONS(7008), 1,
      anon_sym_SLASH,
    ACTIONS(7010), 1,
      anon_sym_CARET,
    ACTIONS(7012), 1,
      anon_sym_PIPE,
    ACTIONS(7014), 1,
      anon_sym_AMP,
    ACTIONS(7018), 1,
      anon_sym_GT_GT,
    ACTIONS(7024), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7026), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7028), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7030), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7032), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6998), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7004), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7006), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7016), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7020), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7022), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5416), 7,
      anon_sym_where,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
    STATE(5078), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [40461] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6976), 1,
      anon_sym_SLASH,
    ACTIONS(6978), 1,
      anon_sym_AMP,
    ACTIONS(6982), 1,
      anon_sym_GT_GT,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6990), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6994), 1,
      anon_sym_is,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7036), 1,
      anon_sym_QMARK,
    ACTIONS(7038), 1,
      anon_sym_CARET,
    ACTIONS(7040), 1,
      anon_sym_PIPE,
    ACTIONS(7042), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7044), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7046), 1,
      anon_sym_QMARK_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6970), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6972), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6974), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6980), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6984), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6986), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6320), 7,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_and,
      anon_sym_or,
    STATE(5079), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [40603] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6990), 1,
      anon_sym_DOT_DOT,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6330), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5080), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6328), 23,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [40709] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6976), 1,
      anon_sym_SLASH,
    ACTIONS(6978), 1,
      anon_sym_AMP,
    ACTIONS(6982), 1,
      anon_sym_GT_GT,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6990), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6994), 1,
      anon_sym_is,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7036), 1,
      anon_sym_QMARK,
    ACTIONS(7038), 1,
      anon_sym_CARET,
    ACTIONS(7040), 1,
      anon_sym_PIPE,
    ACTIONS(7042), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7044), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7046), 1,
      anon_sym_QMARK_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6970), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6972), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6974), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6980), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6984), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6986), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6324), 7,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_and,
      anon_sym_or,
    STATE(5081), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [40851] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6976), 1,
      anon_sym_SLASH,
    ACTIONS(6978), 1,
      anon_sym_AMP,
    ACTIONS(6982), 1,
      anon_sym_GT_GT,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6990), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6994), 1,
      anon_sym_is,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7036), 1,
      anon_sym_QMARK,
    ACTIONS(7038), 1,
      anon_sym_CARET,
    ACTIONS(7040), 1,
      anon_sym_PIPE,
    ACTIONS(7042), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7044), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7046), 1,
      anon_sym_QMARK_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6970), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6972), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6974), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6980), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6984), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6986), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5416), 7,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_and,
      anon_sym_or,
    STATE(5082), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [40993] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7034), 1,
      anon_sym_and,
    ACTIONS(7048), 1,
      anon_sym_or,
    STATE(5083), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6594), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6592), 29,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_where,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [41085] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6976), 1,
      anon_sym_SLASH,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6990), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6996), 1,
      anon_sym_with,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6972), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6974), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5084), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 19,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
  [41201] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6976), 1,
      anon_sym_SLASH,
    ACTIONS(6978), 1,
      anon_sym_AMP,
    ACTIONS(6982), 1,
      anon_sym_GT_GT,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6990), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6994), 1,
      anon_sym_is,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7036), 1,
      anon_sym_QMARK,
    ACTIONS(7038), 1,
      anon_sym_CARET,
    ACTIONS(7040), 1,
      anon_sym_PIPE,
    ACTIONS(7042), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7044), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7046), 1,
      anon_sym_QMARK_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6970), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6972), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6974), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6980), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6984), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6986), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5644), 7,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_and,
      anon_sym_or,
    STATE(5085), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [41343] = 33,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6976), 1,
      anon_sym_SLASH,
    ACTIONS(6982), 1,
      anon_sym_GT_GT,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6990), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6994), 1,
      anon_sym_is,
    ACTIONS(6996), 1,
      anon_sym_with,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6970), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6972), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6974), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6980), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6986), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    STATE(5086), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 13,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
  [41471] = 37,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6976), 1,
      anon_sym_SLASH,
    ACTIONS(6978), 1,
      anon_sym_AMP,
    ACTIONS(6982), 1,
      anon_sym_GT_GT,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6990), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6994), 1,
      anon_sym_is,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7038), 1,
      anon_sym_CARET,
    ACTIONS(7040), 1,
      anon_sym_PIPE,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6970), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6972), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6974), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6980), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6984), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6986), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(5087), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 10,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
  [41607] = 37,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6889), 1,
      anon_sym_as,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7008), 1,
      anon_sym_SLASH,
    ACTIONS(7010), 1,
      anon_sym_CARET,
    ACTIONS(7012), 1,
      anon_sym_PIPE,
    ACTIONS(7014), 1,
      anon_sym_AMP,
    ACTIONS(7018), 1,
      anon_sym_GT_GT,
    ACTIONS(7024), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7032), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6998), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7004), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7006), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7016), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7020), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7022), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(5088), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 10,
      anon_sym_where,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
  [41743] = 38,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6976), 1,
      anon_sym_SLASH,
    ACTIONS(6978), 1,
      anon_sym_AMP,
    ACTIONS(6982), 1,
      anon_sym_GT_GT,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6990), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6994), 1,
      anon_sym_is,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7038), 1,
      anon_sym_CARET,
    ACTIONS(7040), 1,
      anon_sym_PIPE,
    ACTIONS(7042), 1,
      anon_sym_AMP_AMP,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6970), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6972), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6974), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6980), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6984), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6986), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 9,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(5089), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [41881] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6976), 1,
      anon_sym_SLASH,
    ACTIONS(6978), 1,
      anon_sym_AMP,
    ACTIONS(6982), 1,
      anon_sym_GT_GT,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6990), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6994), 1,
      anon_sym_is,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7038), 1,
      anon_sym_CARET,
    ACTIONS(7040), 1,
      anon_sym_PIPE,
    ACTIONS(7042), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7044), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7046), 1,
      anon_sym_QMARK_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6970), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6972), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6974), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6980), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6984), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6986), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 7,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_and,
      anon_sym_or,
    STATE(5090), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [42023] = 38,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6889), 1,
      anon_sym_as,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7008), 1,
      anon_sym_SLASH,
    ACTIONS(7010), 1,
      anon_sym_CARET,
    ACTIONS(7012), 1,
      anon_sym_PIPE,
    ACTIONS(7014), 1,
      anon_sym_AMP,
    ACTIONS(7018), 1,
      anon_sym_GT_GT,
    ACTIONS(7024), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7026), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7032), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6998), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7004), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7006), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7016), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7020), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7022), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 9,
      anon_sym_where,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
    STATE(5091), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [42161] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3995), 1,
      anon_sym_EQ,
    ACTIONS(3993), 7,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_STAR,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
    ACTIONS(4088), 8,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_EQ_GT,
    STATE(5092), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4091), 26,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      sym_discard,
      anon_sym_and,
      anon_sym_or,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [42253] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6976), 1,
      anon_sym_SLASH,
    ACTIONS(6978), 1,
      anon_sym_AMP,
    ACTIONS(6982), 1,
      anon_sym_GT_GT,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6990), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6994), 1,
      anon_sym_is,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7036), 1,
      anon_sym_QMARK,
    ACTIONS(7038), 1,
      anon_sym_CARET,
    ACTIONS(7040), 1,
      anon_sym_PIPE,
    ACTIONS(7042), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7044), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7046), 1,
      anon_sym_QMARK_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6970), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6972), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6974), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6980), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6984), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6986), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5424), 7,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_and,
      anon_sym_or,
    STATE(5093), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [42395] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6889), 1,
      anon_sym_as,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7002), 1,
      anon_sym_QMARK,
    ACTIONS(7008), 1,
      anon_sym_SLASH,
    ACTIONS(7010), 1,
      anon_sym_CARET,
    ACTIONS(7012), 1,
      anon_sym_PIPE,
    ACTIONS(7014), 1,
      anon_sym_AMP,
    ACTIONS(7018), 1,
      anon_sym_GT_GT,
    ACTIONS(7024), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7026), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7028), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7030), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7032), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6998), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7004), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7006), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7016), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7020), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7022), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5424), 7,
      anon_sym_where,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
    STATE(5094), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [42537] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6976), 1,
      anon_sym_SLASH,
    ACTIONS(6978), 1,
      anon_sym_AMP,
    ACTIONS(6982), 1,
      anon_sym_GT_GT,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6990), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6994), 1,
      anon_sym_is,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7036), 1,
      anon_sym_QMARK,
    ACTIONS(7038), 1,
      anon_sym_CARET,
    ACTIONS(7040), 1,
      anon_sym_PIPE,
    ACTIONS(7042), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7044), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7046), 1,
      anon_sym_QMARK_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6970), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6972), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6974), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6980), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6984), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6986), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6336), 7,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_and,
      anon_sym_or,
    STATE(5095), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [42679] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6976), 1,
      anon_sym_SLASH,
    ACTIONS(6978), 1,
      anon_sym_AMP,
    ACTIONS(6982), 1,
      anon_sym_GT_GT,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6990), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6994), 1,
      anon_sym_is,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7036), 1,
      anon_sym_QMARK,
    ACTIONS(7038), 1,
      anon_sym_CARET,
    ACTIONS(7040), 1,
      anon_sym_PIPE,
    ACTIONS(7042), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7044), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7046), 1,
      anon_sym_QMARK_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6970), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6972), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6974), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6980), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6984), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6986), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5572), 7,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_and,
      anon_sym_or,
    STATE(5096), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [42821] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6990), 1,
      anon_sym_DOT_DOT,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1229), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5097), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(1227), 23,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [42927] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6976), 1,
      anon_sym_SLASH,
    ACTIONS(6978), 1,
      anon_sym_AMP,
    ACTIONS(6982), 1,
      anon_sym_GT_GT,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6990), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6994), 1,
      anon_sym_is,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7036), 1,
      anon_sym_QMARK,
    ACTIONS(7038), 1,
      anon_sym_CARET,
    ACTIONS(7040), 1,
      anon_sym_PIPE,
    ACTIONS(7042), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7044), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7046), 1,
      anon_sym_QMARK_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6970), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6972), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6974), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6980), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6984), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6986), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5584), 7,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_and,
      anon_sym_or,
    STATE(5098), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [43069] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6976), 1,
      anon_sym_SLASH,
    ACTIONS(6978), 1,
      anon_sym_AMP,
    ACTIONS(6982), 1,
      anon_sym_GT_GT,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6990), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6994), 1,
      anon_sym_is,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7036), 1,
      anon_sym_QMARK,
    ACTIONS(7038), 1,
      anon_sym_CARET,
    ACTIONS(7040), 1,
      anon_sym_PIPE,
    ACTIONS(7042), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7044), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7046), 1,
      anon_sym_QMARK_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6970), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6972), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6974), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6980), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6984), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6986), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5624), 7,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_and,
      anon_sym_or,
    STATE(5099), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [43211] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6976), 1,
      anon_sym_SLASH,
    ACTIONS(6978), 1,
      anon_sym_AMP,
    ACTIONS(6982), 1,
      anon_sym_GT_GT,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6990), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6994), 1,
      anon_sym_is,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7036), 1,
      anon_sym_QMARK,
    ACTIONS(7038), 1,
      anon_sym_CARET,
    ACTIONS(7040), 1,
      anon_sym_PIPE,
    ACTIONS(7042), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7044), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7046), 1,
      anon_sym_QMARK_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6970), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6972), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6974), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6980), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6984), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6986), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6190), 7,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_and,
      anon_sym_or,
    STATE(5100), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [43353] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6889), 1,
      anon_sym_as,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7002), 1,
      anon_sym_QMARK,
    ACTIONS(7008), 1,
      anon_sym_SLASH,
    ACTIONS(7010), 1,
      anon_sym_CARET,
    ACTIONS(7012), 1,
      anon_sym_PIPE,
    ACTIONS(7014), 1,
      anon_sym_AMP,
    ACTIONS(7018), 1,
      anon_sym_GT_GT,
    ACTIONS(7024), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7026), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7028), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7030), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7032), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6998), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7004), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7006), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7016), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7020), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7022), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(7057), 7,
      anon_sym_where,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
    STATE(5101), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [43495] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6966), 1,
      anon_sym_DOT_DOT,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6330), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5102), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6328), 23,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [43601] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(7024), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6330), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5103), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6328), 23,
      anon_sym_where,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [43707] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6444), 1,
      anon_sym_as,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(6950), 1,
      anon_sym_SLASH,
    ACTIONS(6952), 1,
      anon_sym_CARET,
    ACTIONS(6954), 1,
      anon_sym_PIPE,
    ACTIONS(6956), 1,
      anon_sym_AMP,
    ACTIONS(6960), 1,
      anon_sym_GT_GT,
    ACTIONS(6966), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6968), 1,
      anon_sym_is,
    ACTIONS(7059), 1,
      anon_sym_QMARK,
    ACTIONS(7061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7063), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7065), 1,
      anon_sym_QMARK_QMARK,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6944), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6946), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6948), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6958), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6962), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6964), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6266), 7,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
    STATE(5104), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [43849] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6444), 1,
      anon_sym_as,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(6950), 1,
      anon_sym_SLASH,
    ACTIONS(6952), 1,
      anon_sym_CARET,
    ACTIONS(6954), 1,
      anon_sym_PIPE,
    ACTIONS(6956), 1,
      anon_sym_AMP,
    ACTIONS(6960), 1,
      anon_sym_GT_GT,
    ACTIONS(6966), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6968), 1,
      anon_sym_is,
    ACTIONS(7059), 1,
      anon_sym_QMARK,
    ACTIONS(7061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7063), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7065), 1,
      anon_sym_QMARK_QMARK,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6944), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6946), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6948), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6958), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6962), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6964), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6332), 7,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
    STATE(5105), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [43991] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6444), 1,
      anon_sym_as,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(6950), 1,
      anon_sym_SLASH,
    ACTIONS(6952), 1,
      anon_sym_CARET,
    ACTIONS(6954), 1,
      anon_sym_PIPE,
    ACTIONS(6956), 1,
      anon_sym_AMP,
    ACTIONS(6960), 1,
      anon_sym_GT_GT,
    ACTIONS(6966), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6968), 1,
      anon_sym_is,
    ACTIONS(7059), 1,
      anon_sym_QMARK,
    ACTIONS(7061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7063), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7065), 1,
      anon_sym_QMARK_QMARK,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6944), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6946), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6948), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6958), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6962), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6964), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6270), 7,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
    STATE(5106), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [44133] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7067), 1,
      anon_sym_into,
    STATE(5119), 1,
      aux_sym__query_body_repeat2,
    STATE(5107), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6476), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6474), 29,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_where,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [44225] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6444), 1,
      anon_sym_as,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(6950), 1,
      anon_sym_SLASH,
    ACTIONS(6952), 1,
      anon_sym_CARET,
    ACTIONS(6954), 1,
      anon_sym_PIPE,
    ACTIONS(6956), 1,
      anon_sym_AMP,
    ACTIONS(6960), 1,
      anon_sym_GT_GT,
    ACTIONS(6966), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6968), 1,
      anon_sym_is,
    ACTIONS(7059), 1,
      anon_sym_QMARK,
    ACTIONS(7061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7063), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7065), 1,
      anon_sym_QMARK_QMARK,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6944), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6946), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6948), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6958), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6962), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6964), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6320), 7,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
    STATE(5108), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [44367] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6990), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6996), 1,
      anon_sym_with,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5109), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 21,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
  [44477] = 29,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(6950), 1,
      anon_sym_SLASH,
    ACTIONS(6960), 1,
      anon_sym_GT_GT,
    ACTIONS(6966), 1,
      anon_sym_DOT_DOT,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6946), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6948), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6958), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6344), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    STATE(5110), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 17,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
  [44597] = 26,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(6950), 1,
      anon_sym_SLASH,
    ACTIONS(6966), 1,
      anon_sym_DOT_DOT,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6948), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5111), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 19,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
  [44711] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(6966), 1,
      anon_sym_DOT_DOT,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5112), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 21,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
  [44821] = 35,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6444), 1,
      anon_sym_as,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(6950), 1,
      anon_sym_SLASH,
    ACTIONS(6956), 1,
      anon_sym_AMP,
    ACTIONS(6960), 1,
      anon_sym_GT_GT,
    ACTIONS(6966), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6968), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(6944), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6946), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6948), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6958), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6962), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6964), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(5113), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 11,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
  [44953] = 36,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6444), 1,
      anon_sym_as,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(6950), 1,
      anon_sym_SLASH,
    ACTIONS(6952), 1,
      anon_sym_CARET,
    ACTIONS(6956), 1,
      anon_sym_AMP,
    ACTIONS(6960), 1,
      anon_sym_GT_GT,
    ACTIONS(6966), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6968), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(6944), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6946), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6948), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6958), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6962), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6964), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(5114), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 10,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
  [45087] = 34,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6444), 1,
      anon_sym_as,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(6950), 1,
      anon_sym_SLASH,
    ACTIONS(6960), 1,
      anon_sym_GT_GT,
    ACTIONS(6966), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6968), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6944), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6946), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6948), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6958), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6962), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6964), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    STATE(5115), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 11,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
  [45217] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6889), 1,
      anon_sym_as,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7002), 1,
      anon_sym_QMARK,
    ACTIONS(7008), 1,
      anon_sym_SLASH,
    ACTIONS(7010), 1,
      anon_sym_CARET,
    ACTIONS(7012), 1,
      anon_sym_PIPE,
    ACTIONS(7014), 1,
      anon_sym_AMP,
    ACTIONS(7018), 1,
      anon_sym_GT_GT,
    ACTIONS(7024), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7026), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7028), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7030), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7032), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6998), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7004), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7006), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7016), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7020), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7022), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(7069), 7,
      anon_sym_where,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
    STATE(5116), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [45359] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(6950), 1,
      anon_sym_SLASH,
    ACTIONS(6966), 1,
      anon_sym_DOT_DOT,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6946), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6948), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5117), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 19,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
  [45475] = 33,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6444), 1,
      anon_sym_as,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(6950), 1,
      anon_sym_SLASH,
    ACTIONS(6960), 1,
      anon_sym_GT_GT,
    ACTIONS(6966), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6968), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6944), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6946), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6948), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6958), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6964), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    STATE(5118), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 13,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
  [45603] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7067), 1,
      anon_sym_into,
    STATE(5138), 1,
      aux_sym__query_body_repeat2,
    STATE(5119), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6482), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6480), 29,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_where,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [45695] = 29,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3193), 1,
      sym__identifier_token,
    ACTIONS(3205), 1,
      anon_sym_LPAREN,
    ACTIONS(4002), 1,
      anon_sym_delegate,
    ACTIONS(5369), 1,
      anon_sym_var,
    ACTIONS(7071), 1,
      sym_predefined_type,
    STATE(4513), 1,
      sym__reserved_identifier,
    STATE(4947), 1,
      sym_identifier,
    STATE(5019), 1,
      sym_generic_name,
    STATE(8163), 1,
      sym__name,
    STATE(8341), 1,
      sym_tuple_type,
    STATE(8610), 1,
      sym_array_type,
    STATE(8852), 1,
      sym__array_base_type,
    STATE(9443), 1,
      sym__pointer_base_type,
    STATE(9462), 1,
      sym__ref_base_type,
    STATE(9513), 1,
      sym_implicit_type,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(8611), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(5120), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3197), 21,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [45815] = 38,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6444), 1,
      anon_sym_as,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(6950), 1,
      anon_sym_SLASH,
    ACTIONS(6952), 1,
      anon_sym_CARET,
    ACTIONS(6954), 1,
      anon_sym_PIPE,
    ACTIONS(6956), 1,
      anon_sym_AMP,
    ACTIONS(6960), 1,
      anon_sym_GT_GT,
    ACTIONS(6966), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6968), 1,
      anon_sym_is,
    ACTIONS(7061), 1,
      anon_sym_AMP_AMP,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6944), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6946), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6948), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6958), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6962), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6964), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 9,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
    STATE(5121), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [45953] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6444), 1,
      anon_sym_as,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(6950), 1,
      anon_sym_SLASH,
    ACTIONS(6952), 1,
      anon_sym_CARET,
    ACTIONS(6954), 1,
      anon_sym_PIPE,
    ACTIONS(6956), 1,
      anon_sym_AMP,
    ACTIONS(6960), 1,
      anon_sym_GT_GT,
    ACTIONS(6966), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6968), 1,
      anon_sym_is,
    ACTIONS(7061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7063), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7065), 1,
      anon_sym_QMARK_QMARK,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6944), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6946), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6948), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6958), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6962), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6964), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 7,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
    STATE(5122), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [46095] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6444), 1,
      anon_sym_as,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(6950), 1,
      anon_sym_SLASH,
    ACTIONS(6952), 1,
      anon_sym_CARET,
    ACTIONS(6954), 1,
      anon_sym_PIPE,
    ACTIONS(6956), 1,
      anon_sym_AMP,
    ACTIONS(6960), 1,
      anon_sym_GT_GT,
    ACTIONS(6966), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6968), 1,
      anon_sym_is,
    ACTIONS(7059), 1,
      anon_sym_QMARK,
    ACTIONS(7061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7063), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7065), 1,
      anon_sym_QMARK_QMARK,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6944), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6946), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6948), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6958), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6962), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6964), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6324), 7,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
    STATE(5123), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [46237] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6444), 1,
      anon_sym_as,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(6950), 1,
      anon_sym_SLASH,
    ACTIONS(6952), 1,
      anon_sym_CARET,
    ACTIONS(6954), 1,
      anon_sym_PIPE,
    ACTIONS(6956), 1,
      anon_sym_AMP,
    ACTIONS(6960), 1,
      anon_sym_GT_GT,
    ACTIONS(6966), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6968), 1,
      anon_sym_is,
    ACTIONS(7059), 1,
      anon_sym_QMARK,
    ACTIONS(7061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7063), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7065), 1,
      anon_sym_QMARK_QMARK,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6944), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6946), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6948), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6958), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6962), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6964), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5416), 7,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
    STATE(5124), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [46379] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7067), 1,
      anon_sym_into,
    STATE(5139), 1,
      aux_sym__query_body_repeat2,
    STATE(5125), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6482), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6480), 29,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_where,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [46471] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6444), 1,
      anon_sym_as,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(6950), 1,
      anon_sym_SLASH,
    ACTIONS(6952), 1,
      anon_sym_CARET,
    ACTIONS(6954), 1,
      anon_sym_PIPE,
    ACTIONS(6956), 1,
      anon_sym_AMP,
    ACTIONS(6960), 1,
      anon_sym_GT_GT,
    ACTIONS(6966), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6968), 1,
      anon_sym_is,
    ACTIONS(7059), 1,
      anon_sym_QMARK,
    ACTIONS(7061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7063), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7065), 1,
      anon_sym_QMARK_QMARK,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6944), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6946), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6948), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6958), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6962), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6964), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5644), 7,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
    STATE(5126), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [46613] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6889), 1,
      anon_sym_as,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7008), 1,
      anon_sym_SLASH,
    ACTIONS(7010), 1,
      anon_sym_CARET,
    ACTIONS(7012), 1,
      anon_sym_PIPE,
    ACTIONS(7014), 1,
      anon_sym_AMP,
    ACTIONS(7018), 1,
      anon_sym_GT_GT,
    ACTIONS(7024), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7026), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7028), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7030), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7032), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6998), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7004), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7006), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7016), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7020), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7022), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 7,
      anon_sym_where,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
    STATE(5127), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [46755] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5128), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4181), 14,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_STAR,
      anon_sym_DOT,
      anon_sym_EQ_GT,
    ACTIONS(4179), 28,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_operator,
      anon_sym_this,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      sym_discard,
      anon_sym_and,
      anon_sym_or,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [46843] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6444), 1,
      anon_sym_as,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(6950), 1,
      anon_sym_SLASH,
    ACTIONS(6952), 1,
      anon_sym_CARET,
    ACTIONS(6954), 1,
      anon_sym_PIPE,
    ACTIONS(6956), 1,
      anon_sym_AMP,
    ACTIONS(6960), 1,
      anon_sym_GT_GT,
    ACTIONS(6966), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6968), 1,
      anon_sym_is,
    ACTIONS(7059), 1,
      anon_sym_QMARK,
    ACTIONS(7061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7063), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7065), 1,
      anon_sym_QMARK_QMARK,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6944), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6946), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6948), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6958), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6962), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6964), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5424), 7,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
    STATE(5129), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [46985] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6444), 1,
      anon_sym_as,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(6950), 1,
      anon_sym_SLASH,
    ACTIONS(6952), 1,
      anon_sym_CARET,
    ACTIONS(6954), 1,
      anon_sym_PIPE,
    ACTIONS(6956), 1,
      anon_sym_AMP,
    ACTIONS(6960), 1,
      anon_sym_GT_GT,
    ACTIONS(6966), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6968), 1,
      anon_sym_is,
    ACTIONS(7059), 1,
      anon_sym_QMARK,
    ACTIONS(7061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7063), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7065), 1,
      anon_sym_QMARK_QMARK,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6944), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6946), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6948), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6958), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6962), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6964), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6336), 7,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
    STATE(5130), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [47127] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6444), 1,
      anon_sym_as,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(6950), 1,
      anon_sym_SLASH,
    ACTIONS(6952), 1,
      anon_sym_CARET,
    ACTIONS(6954), 1,
      anon_sym_PIPE,
    ACTIONS(6956), 1,
      anon_sym_AMP,
    ACTIONS(6960), 1,
      anon_sym_GT_GT,
    ACTIONS(6966), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6968), 1,
      anon_sym_is,
    ACTIONS(7059), 1,
      anon_sym_QMARK,
    ACTIONS(7061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7063), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7065), 1,
      anon_sym_QMARK_QMARK,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6944), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6946), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6948), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6958), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6962), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6964), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5572), 7,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
    STATE(5131), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [47269] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6444), 1,
      anon_sym_as,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(6950), 1,
      anon_sym_SLASH,
    ACTIONS(6952), 1,
      anon_sym_CARET,
    ACTIONS(6954), 1,
      anon_sym_PIPE,
    ACTIONS(6956), 1,
      anon_sym_AMP,
    ACTIONS(6960), 1,
      anon_sym_GT_GT,
    ACTIONS(6966), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6968), 1,
      anon_sym_is,
    ACTIONS(7059), 1,
      anon_sym_QMARK,
    ACTIONS(7061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7063), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7065), 1,
      anon_sym_QMARK_QMARK,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6944), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6946), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6948), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6958), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6962), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6964), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5584), 7,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
    STATE(5132), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [47411] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6444), 1,
      anon_sym_as,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(6950), 1,
      anon_sym_SLASH,
    ACTIONS(6952), 1,
      anon_sym_CARET,
    ACTIONS(6954), 1,
      anon_sym_PIPE,
    ACTIONS(6956), 1,
      anon_sym_AMP,
    ACTIONS(6960), 1,
      anon_sym_GT_GT,
    ACTIONS(6966), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6968), 1,
      anon_sym_is,
    ACTIONS(7059), 1,
      anon_sym_QMARK,
    ACTIONS(7061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7063), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7065), 1,
      anon_sym_QMARK_QMARK,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6944), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6946), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6948), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6958), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6962), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6964), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5624), 7,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
    STATE(5133), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [47553] = 29,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6976), 1,
      anon_sym_SLASH,
    ACTIONS(6982), 1,
      anon_sym_GT_GT,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6990), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6996), 1,
      anon_sym_with,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6972), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6974), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6980), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6344), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    STATE(5134), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 17,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
  [47673] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6889), 1,
      anon_sym_as,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7002), 1,
      anon_sym_QMARK,
    ACTIONS(7008), 1,
      anon_sym_SLASH,
    ACTIONS(7010), 1,
      anon_sym_CARET,
    ACTIONS(7012), 1,
      anon_sym_PIPE,
    ACTIONS(7014), 1,
      anon_sym_AMP,
    ACTIONS(7018), 1,
      anon_sym_GT_GT,
    ACTIONS(7024), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7026), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7028), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7030), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7032), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6998), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7004), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7006), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7016), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7020), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7022), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6336), 7,
      anon_sym_where,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
    STATE(5135), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [47815] = 26,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6976), 1,
      anon_sym_SLASH,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6990), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6996), 1,
      anon_sym_with,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6974), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5136), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 19,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
  [47929] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6444), 1,
      anon_sym_as,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(6950), 1,
      anon_sym_SLASH,
    ACTIONS(6952), 1,
      anon_sym_CARET,
    ACTIONS(6954), 1,
      anon_sym_PIPE,
    ACTIONS(6956), 1,
      anon_sym_AMP,
    ACTIONS(6960), 1,
      anon_sym_GT_GT,
    ACTIONS(6966), 1,
      anon_sym_DOT_DOT,
    ACTIONS(6968), 1,
      anon_sym_is,
    ACTIONS(7059), 1,
      anon_sym_QMARK,
    ACTIONS(7061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7063), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7065), 1,
      anon_sym_QMARK_QMARK,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6944), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6946), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6948), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6958), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6962), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6964), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6190), 7,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
    STATE(5137), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [48071] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7073), 1,
      anon_sym_into,
    STATE(5138), 10,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
      aux_sym__query_body_repeat2,
    ACTIONS(6486), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6484), 29,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_where,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [48161] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7067), 1,
      anon_sym_into,
    STATE(5138), 1,
      aux_sym__query_body_repeat2,
    STATE(5139), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6493), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6491), 29,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_where,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [48253] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6889), 1,
      anon_sym_as,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7002), 1,
      anon_sym_QMARK,
    ACTIONS(7008), 1,
      anon_sym_SLASH,
    ACTIONS(7010), 1,
      anon_sym_CARET,
    ACTIONS(7012), 1,
      anon_sym_PIPE,
    ACTIONS(7014), 1,
      anon_sym_AMP,
    ACTIONS(7018), 1,
      anon_sym_GT_GT,
    ACTIONS(7024), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7026), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7028), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7030), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7032), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6998), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7004), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7006), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7016), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7020), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7022), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(7076), 7,
      anon_sym_where,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
    STATE(5140), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [48395] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5336), 1,
      anon_sym_LBRACK,
    ACTIONS(5343), 1,
      anon_sym_LBRACE,
    ACTIONS(5349), 1,
      anon_sym_QMARK,
    STATE(3784), 1,
      sym_initializer_expression,
    STATE(5141), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5346), 10,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5340), 27,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
  [48490] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7080), 1,
      anon_sym_QMARK,
    ACTIONS(7086), 1,
      anon_sym_SLASH,
    ACTIONS(7088), 1,
      anon_sym_CARET,
    ACTIONS(7090), 1,
      anon_sym_PIPE,
    ACTIONS(7092), 1,
      anon_sym_AMP,
    ACTIONS(7096), 1,
      anon_sym_GT_GT,
    ACTIONS(7102), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7104), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7106), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7108), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7110), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7078), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7082), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7084), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7094), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7098), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7100), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5624), 6,
      anon_sym_SEMI,
      anon_sym_and,
      anon_sym_or,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
    STATE(5142), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [48631] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7118), 1,
      anon_sym_SLASH,
    ACTIONS(7120), 1,
      anon_sym_CARET,
    ACTIONS(7122), 1,
      anon_sym_PIPE,
    ACTIONS(7124), 1,
      anon_sym_AMP,
    ACTIONS(7128), 1,
      anon_sym_GT_GT,
    ACTIONS(7134), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7136), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7138), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7140), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7142), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7112), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7114), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7116), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7126), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7130), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7132), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 6,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_and,
      anon_sym_or,
    STATE(5143), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [48772] = 26,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7086), 1,
      anon_sym_SLASH,
    ACTIONS(7102), 1,
      anon_sym_DOT_DOT,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7084), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5144), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 18,
      anon_sym_SEMI,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
  [48885] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7102), 1,
      anon_sym_DOT_DOT,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5145), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 20,
      anon_sym_SEMI,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
  [48994] = 35,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7086), 1,
      anon_sym_SLASH,
    ACTIONS(7092), 1,
      anon_sym_AMP,
    ACTIONS(7096), 1,
      anon_sym_GT_GT,
    ACTIONS(7102), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7110), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(7078), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7082), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7084), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7094), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7098), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7100), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(5146), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 10,
      anon_sym_SEMI,
      anon_sym_CARET,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
  [49125] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3993), 1,
      anon_sym_COLON_COLON,
    STATE(5147), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4091), 12,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(4088), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [49214] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7118), 1,
      anon_sym_SLASH,
    ACTIONS(7120), 1,
      anon_sym_CARET,
    ACTIONS(7122), 1,
      anon_sym_PIPE,
    ACTIONS(7124), 1,
      anon_sym_AMP,
    ACTIONS(7128), 1,
      anon_sym_GT_GT,
    ACTIONS(7134), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7136), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7138), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7140), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7142), 1,
      anon_sym_is,
    ACTIONS(7144), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7112), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7114), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7116), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7126), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7130), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7132), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6324), 6,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_and,
      anon_sym_or,
    STATE(5148), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [49355] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(7102), 1,
      anon_sym_DOT_DOT,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1229), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5149), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(1227), 22,
      anon_sym_SEMI,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
  [49460] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7118), 1,
      anon_sym_SLASH,
    ACTIONS(7120), 1,
      anon_sym_CARET,
    ACTIONS(7122), 1,
      anon_sym_PIPE,
    ACTIONS(7124), 1,
      anon_sym_AMP,
    ACTIONS(7128), 1,
      anon_sym_GT_GT,
    ACTIONS(7134), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7136), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7138), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7140), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7142), 1,
      anon_sym_is,
    ACTIONS(7144), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7112), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7114), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7116), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7126), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7130), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7132), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5416), 6,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_and,
      anon_sym_or,
    STATE(5150), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [49601] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7152), 1,
      anon_sym_DOT_DOT,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1229), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5151), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(1227), 22,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [49706] = 36,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7086), 1,
      anon_sym_SLASH,
    ACTIONS(7088), 1,
      anon_sym_CARET,
    ACTIONS(7092), 1,
      anon_sym_AMP,
    ACTIONS(7096), 1,
      anon_sym_GT_GT,
    ACTIONS(7102), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7110), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(7078), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7082), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7084), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7094), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7098), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7100), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 9,
      anon_sym_SEMI,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
    STATE(5152), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [49839] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3193), 1,
      sym__identifier_token,
    ACTIONS(6507), 1,
      anon_sym_ref,
    STATE(4513), 1,
      sym__reserved_identifier,
    STATE(4947), 1,
      sym_identifier,
    STATE(5019), 1,
      sym_generic_name,
    STATE(8487), 1,
      sym__name,
    STATE(8828), 1,
      sym_ref_type,
    STATE(8849), 1,
      sym__scoped_base_type,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    ACTIONS(3993), 8,
      anon_sym_LBRACK,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_STAR,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
    STATE(5153), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3197), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [49944] = 34,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7086), 1,
      anon_sym_SLASH,
    ACTIONS(7096), 1,
      anon_sym_GT_GT,
    ACTIONS(7102), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7110), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7078), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7082), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7084), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7094), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7098), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7100), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    STATE(5154), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 10,
      anon_sym_SEMI,
      anon_sym_CARET,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
  [50073] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7152), 1,
      anon_sym_DOT_DOT,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6330), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5155), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6328), 22,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [50178] = 21,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5294), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5156), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5292), 23,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [50281] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7086), 1,
      anon_sym_SLASH,
    ACTIONS(7102), 1,
      anon_sym_DOT_DOT,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7082), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7084), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5157), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 18,
      anon_sym_SEMI,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
  [50396] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(7102), 1,
      anon_sym_DOT_DOT,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6330), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5158), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6328), 22,
      anon_sym_SEMI,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
  [50501] = 33,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7086), 1,
      anon_sym_SLASH,
    ACTIONS(7096), 1,
      anon_sym_GT_GT,
    ACTIONS(7102), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7110), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7078), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7082), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7084), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7094), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7100), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    STATE(5159), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 12,
      anon_sym_SEMI,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
  [50628] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7134), 1,
      anon_sym_DOT_DOT,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5160), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 20,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
  [50737] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7118), 1,
      anon_sym_SLASH,
    ACTIONS(7120), 1,
      anon_sym_CARET,
    ACTIONS(7122), 1,
      anon_sym_PIPE,
    ACTIONS(7124), 1,
      anon_sym_AMP,
    ACTIONS(7128), 1,
      anon_sym_GT_GT,
    ACTIONS(7134), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7136), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7138), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7140), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7142), 1,
      anon_sym_is,
    ACTIONS(7144), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7112), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7114), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7116), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7126), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7130), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7132), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5644), 6,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_and,
      anon_sym_or,
    STATE(5161), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [50878] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7152), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7156), 1,
      anon_sym_QMARK,
    ACTIONS(7162), 1,
      anon_sym_SLASH,
    ACTIONS(7164), 1,
      anon_sym_CARET,
    ACTIONS(7166), 1,
      anon_sym_PIPE,
    ACTIONS(7168), 1,
      anon_sym_AMP,
    ACTIONS(7172), 1,
      anon_sym_GT_GT,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7180), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7182), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7184), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7186), 1,
      anon_sym_as,
    ACTIONS(7188), 1,
      anon_sym_is,
    ACTIONS(7190), 1,
      anon_sym_with,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7154), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7158), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7160), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7170), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7174), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7176), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6190), 6,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
    STATE(5162), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [51019] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(7134), 1,
      anon_sym_DOT_DOT,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1229), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5163), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(1227), 22,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [51124] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7080), 1,
      anon_sym_QMARK,
    ACTIONS(7086), 1,
      anon_sym_SLASH,
    ACTIONS(7088), 1,
      anon_sym_CARET,
    ACTIONS(7090), 1,
      anon_sym_PIPE,
    ACTIONS(7092), 1,
      anon_sym_AMP,
    ACTIONS(7096), 1,
      anon_sym_GT_GT,
    ACTIONS(7102), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7104), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7106), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7108), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7110), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7078), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7082), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7084), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7094), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7098), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7100), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6332), 6,
      anon_sym_SEMI,
      anon_sym_and,
      anon_sym_or,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
    STATE(5164), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [51265] = 21,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5275), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5165), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5271), 23,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [51368] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3193), 1,
      sym__identifier_token,
    ACTIONS(3205), 1,
      anon_sym_LPAREN,
    ACTIONS(4002), 1,
      anon_sym_delegate,
    ACTIONS(7192), 1,
      anon_sym_LBRACK,
    ACTIONS(7194), 1,
      sym_predefined_type,
    STATE(3927), 1,
      sym_array_type,
    STATE(4513), 1,
      sym__reserved_identifier,
    STATE(4947), 1,
      sym_identifier,
    STATE(5019), 1,
      sym_generic_name,
    STATE(8318), 1,
      sym__name,
    STATE(8527), 1,
      sym_tuple_type,
    STATE(8941), 1,
      sym__array_base_type,
    STATE(9443), 1,
      sym__pointer_base_type,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(8717), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(5166), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3197), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [51483] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5167), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3995), 12,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(3993), 29,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_COLON_COLON,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [51570] = 37,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7152), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7162), 1,
      anon_sym_SLASH,
    ACTIONS(7164), 1,
      anon_sym_CARET,
    ACTIONS(7166), 1,
      anon_sym_PIPE,
    ACTIONS(7168), 1,
      anon_sym_AMP,
    ACTIONS(7172), 1,
      anon_sym_GT_GT,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7186), 1,
      anon_sym_as,
    ACTIONS(7188), 1,
      anon_sym_is,
    ACTIONS(7190), 1,
      anon_sym_with,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7154), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7158), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7160), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7170), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7174), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7176), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 9,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
    STATE(5168), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [51705] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7118), 1,
      anon_sym_SLASH,
    ACTIONS(7120), 1,
      anon_sym_CARET,
    ACTIONS(7122), 1,
      anon_sym_PIPE,
    ACTIONS(7124), 1,
      anon_sym_AMP,
    ACTIONS(7128), 1,
      anon_sym_GT_GT,
    ACTIONS(7134), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7136), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7138), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7140), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7142), 1,
      anon_sym_is,
    ACTIONS(7144), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7112), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7114), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7116), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7126), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7130), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7132), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6320), 6,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_and,
      anon_sym_or,
    STATE(5169), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [51846] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7080), 1,
      anon_sym_QMARK,
    ACTIONS(7086), 1,
      anon_sym_SLASH,
    ACTIONS(7088), 1,
      anon_sym_CARET,
    ACTIONS(7090), 1,
      anon_sym_PIPE,
    ACTIONS(7092), 1,
      anon_sym_AMP,
    ACTIONS(7096), 1,
      anon_sym_GT_GT,
    ACTIONS(7102), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7104), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7106), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7108), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7110), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7078), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7082), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7084), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7094), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7098), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7100), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6336), 6,
      anon_sym_SEMI,
      anon_sym_and,
      anon_sym_or,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
    STATE(5170), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [51987] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3193), 1,
      sym__identifier_token,
    ACTIONS(3205), 1,
      anon_sym_LPAREN,
    ACTIONS(4002), 1,
      anon_sym_delegate,
    ACTIONS(7194), 1,
      sym_predefined_type,
    ACTIONS(7196), 1,
      anon_sym_LBRACK,
    STATE(3568), 1,
      sym_array_type,
    STATE(4513), 1,
      sym__reserved_identifier,
    STATE(4947), 1,
      sym_identifier,
    STATE(5019), 1,
      sym_generic_name,
    STATE(8318), 1,
      sym__name,
    STATE(8527), 1,
      sym_tuple_type,
    STATE(8805), 1,
      sym__array_base_type,
    STATE(9443), 1,
      sym__pointer_base_type,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(8717), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(5171), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3197), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [52102] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7118), 1,
      anon_sym_SLASH,
    ACTIONS(7120), 1,
      anon_sym_CARET,
    ACTIONS(7122), 1,
      anon_sym_PIPE,
    ACTIONS(7124), 1,
      anon_sym_AMP,
    ACTIONS(7128), 1,
      anon_sym_GT_GT,
    ACTIONS(7134), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7136), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7138), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7140), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7142), 1,
      anon_sym_is,
    ACTIONS(7144), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7112), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7114), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7116), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7126), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7130), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7132), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5584), 6,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_and,
      anon_sym_or,
    STATE(5172), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [52243] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5173), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4122), 12,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(4124), 29,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_COLON_COLON,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [52330] = 29,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7152), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7162), 1,
      anon_sym_SLASH,
    ACTIONS(7172), 1,
      anon_sym_GT_GT,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7190), 1,
      anon_sym_with,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7158), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7160), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7170), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6344), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    STATE(5174), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 16,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
  [52449] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3193), 1,
      sym__identifier_token,
    ACTIONS(3205), 1,
      anon_sym_LPAREN,
    ACTIONS(4002), 1,
      anon_sym_delegate,
    ACTIONS(7194), 1,
      sym_predefined_type,
    ACTIONS(7198), 1,
      anon_sym_LBRACK,
    STATE(4377), 1,
      sym_array_type,
    STATE(4513), 1,
      sym__reserved_identifier,
    STATE(4947), 1,
      sym_identifier,
    STATE(5019), 1,
      sym_generic_name,
    STATE(8318), 1,
      sym__name,
    STATE(8527), 1,
      sym_tuple_type,
    STATE(8753), 1,
      sym__array_base_type,
    STATE(9443), 1,
      sym__pointer_base_type,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(8717), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(5175), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3197), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [52564] = 26,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7152), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7162), 1,
      anon_sym_SLASH,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7190), 1,
      anon_sym_with,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7160), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5176), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 18,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
  [52677] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5336), 1,
      anon_sym_LBRACK,
    ACTIONS(7200), 1,
      anon_sym_LBRACE,
    ACTIONS(7203), 1,
      anon_sym_QMARK,
    STATE(5552), 1,
      sym_initializer_expression,
    STATE(5177), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5346), 10,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5340), 27,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [52772] = 34,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7152), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7162), 1,
      anon_sym_SLASH,
    ACTIONS(7172), 1,
      anon_sym_GT_GT,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7186), 1,
      anon_sym_as,
    ACTIONS(7188), 1,
      anon_sym_is,
    ACTIONS(7190), 1,
      anon_sym_with,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7154), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7158), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7160), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7170), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7174), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7176), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    STATE(5178), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 10,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_CARET,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
  [52901] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3193), 1,
      sym__identifier_token,
    ACTIONS(5745), 1,
      anon_sym_ref,
    STATE(4513), 1,
      sym__reserved_identifier,
    STATE(4947), 1,
      sym_identifier,
    STATE(5019), 1,
      sym_generic_name,
    STATE(8487), 1,
      sym__name,
    STATE(8828), 1,
      sym_ref_type,
    STATE(8849), 1,
      sym__scoped_base_type,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    ACTIONS(3993), 8,
      anon_sym_LBRACK,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_STAR,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
    STATE(5179), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3197), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [53006] = 37,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7086), 1,
      anon_sym_SLASH,
    ACTIONS(7088), 1,
      anon_sym_CARET,
    ACTIONS(7090), 1,
      anon_sym_PIPE,
    ACTIONS(7092), 1,
      anon_sym_AMP,
    ACTIONS(7096), 1,
      anon_sym_GT_GT,
    ACTIONS(7102), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7110), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7078), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7082), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7084), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7094), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7098), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7100), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 9,
      anon_sym_SEMI,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
    STATE(5180), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [53141] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7152), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7156), 1,
      anon_sym_QMARK,
    ACTIONS(7162), 1,
      anon_sym_SLASH,
    ACTIONS(7164), 1,
      anon_sym_CARET,
    ACTIONS(7166), 1,
      anon_sym_PIPE,
    ACTIONS(7168), 1,
      anon_sym_AMP,
    ACTIONS(7172), 1,
      anon_sym_GT_GT,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7180), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7182), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7184), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7186), 1,
      anon_sym_as,
    ACTIONS(7188), 1,
      anon_sym_is,
    ACTIONS(7190), 1,
      anon_sym_with,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7154), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7158), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7160), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7170), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7174), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7176), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6332), 6,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
    STATE(5181), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [53282] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7152), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7156), 1,
      anon_sym_QMARK,
    ACTIONS(7162), 1,
      anon_sym_SLASH,
    ACTIONS(7164), 1,
      anon_sym_CARET,
    ACTIONS(7166), 1,
      anon_sym_PIPE,
    ACTIONS(7168), 1,
      anon_sym_AMP,
    ACTIONS(7172), 1,
      anon_sym_GT_GT,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7180), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7182), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7184), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7186), 1,
      anon_sym_as,
    ACTIONS(7188), 1,
      anon_sym_is,
    ACTIONS(7190), 1,
      anon_sym_with,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7154), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7158), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7160), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7170), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7174), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7176), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6266), 6,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
    STATE(5182), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [53423] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7152), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7190), 1,
      anon_sym_with,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5183), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 20,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
  [53532] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(1411), 1,
      anon_sym_LBRACE,
    ACTIONS(5298), 1,
      anon_sym_LBRACK,
    STATE(5557), 1,
      sym_initializer_expression,
    STATE(5184), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5301), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5296), 27,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [53625] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7080), 1,
      anon_sym_QMARK,
    ACTIONS(7086), 1,
      anon_sym_SLASH,
    ACTIONS(7088), 1,
      anon_sym_CARET,
    ACTIONS(7090), 1,
      anon_sym_PIPE,
    ACTIONS(7092), 1,
      anon_sym_AMP,
    ACTIONS(7096), 1,
      anon_sym_GT_GT,
    ACTIONS(7102), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7104), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7106), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7108), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7110), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7078), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7082), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7084), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7094), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7098), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7100), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6324), 6,
      anon_sym_SEMI,
      anon_sym_and,
      anon_sym_or,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
    STATE(5185), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [53766] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7080), 1,
      anon_sym_QMARK,
    ACTIONS(7086), 1,
      anon_sym_SLASH,
    ACTIONS(7088), 1,
      anon_sym_CARET,
    ACTIONS(7090), 1,
      anon_sym_PIPE,
    ACTIONS(7092), 1,
      anon_sym_AMP,
    ACTIONS(7096), 1,
      anon_sym_GT_GT,
    ACTIONS(7102), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7104), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7106), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7108), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7110), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7078), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7082), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7084), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7094), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7098), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7100), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6190), 6,
      anon_sym_SEMI,
      anon_sym_and,
      anon_sym_or,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
    STATE(5186), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [53907] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3193), 1,
      sym__identifier_token,
    ACTIONS(3205), 1,
      anon_sym_LPAREN,
    ACTIONS(4002), 1,
      anon_sym_delegate,
    ACTIONS(7194), 1,
      sym_predefined_type,
    ACTIONS(7207), 1,
      anon_sym_LBRACK,
    STATE(4513), 1,
      sym__reserved_identifier,
    STATE(4947), 1,
      sym_identifier,
    STATE(5019), 1,
      sym_generic_name,
    STATE(5184), 1,
      sym_array_type,
    STATE(8318), 1,
      sym__name,
    STATE(8527), 1,
      sym_tuple_type,
    STATE(8724), 1,
      sym__array_base_type,
    STATE(9443), 1,
      sym__pointer_base_type,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(8717), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(5187), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3197), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [54022] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7080), 1,
      anon_sym_QMARK,
    ACTIONS(7086), 1,
      anon_sym_SLASH,
    ACTIONS(7088), 1,
      anon_sym_CARET,
    ACTIONS(7090), 1,
      anon_sym_PIPE,
    ACTIONS(7092), 1,
      anon_sym_AMP,
    ACTIONS(7096), 1,
      anon_sym_GT_GT,
    ACTIONS(7102), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7104), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7106), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7108), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7110), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7078), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7082), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7084), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7094), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7098), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7100), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5416), 6,
      anon_sym_SEMI,
      anon_sym_and,
      anon_sym_or,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
    STATE(5188), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [54163] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5189), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3995), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(3993), 30,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_GT,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [54250] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7118), 1,
      anon_sym_SLASH,
    ACTIONS(7120), 1,
      anon_sym_CARET,
    ACTIONS(7122), 1,
      anon_sym_PIPE,
    ACTIONS(7124), 1,
      anon_sym_AMP,
    ACTIONS(7128), 1,
      anon_sym_GT_GT,
    ACTIONS(7134), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7136), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7138), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7140), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7142), 1,
      anon_sym_is,
    ACTIONS(7144), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7112), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7114), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7116), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7126), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7130), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7132), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6190), 6,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_and,
      anon_sym_or,
    STATE(5190), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [54391] = 29,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7118), 1,
      anon_sym_SLASH,
    ACTIONS(7128), 1,
      anon_sym_GT_GT,
    ACTIONS(7134), 1,
      anon_sym_DOT_DOT,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7114), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7116), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7126), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6344), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    STATE(5191), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 16,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
  [54510] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7209), 1,
      anon_sym_into,
    STATE(5193), 1,
      aux_sym__query_body_repeat2,
    STATE(5192), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6476), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6474), 28,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [54601] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7209), 1,
      anon_sym_into,
    STATE(5195), 1,
      aux_sym__query_body_repeat2,
    STATE(5193), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6482), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6480), 28,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [54692] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7209), 1,
      anon_sym_into,
    STATE(5196), 1,
      aux_sym__query_body_repeat2,
    STATE(5194), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6482), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6480), 28,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [54783] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7211), 1,
      anon_sym_into,
    STATE(5195), 10,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
      aux_sym__query_body_repeat2,
    ACTIONS(6486), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6484), 28,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [54872] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7209), 1,
      anon_sym_into,
    STATE(5195), 1,
      aux_sym__query_body_repeat2,
    STATE(5196), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6493), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6491), 28,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [54963] = 38,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7086), 1,
      anon_sym_SLASH,
    ACTIONS(7088), 1,
      anon_sym_CARET,
    ACTIONS(7090), 1,
      anon_sym_PIPE,
    ACTIONS(7092), 1,
      anon_sym_AMP,
    ACTIONS(7096), 1,
      anon_sym_GT_GT,
    ACTIONS(7102), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7104), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7110), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7078), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7082), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7084), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7094), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7098), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7100), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 8,
      anon_sym_SEMI,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
    STATE(5197), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [55100] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7080), 1,
      anon_sym_QMARK,
    ACTIONS(7086), 1,
      anon_sym_SLASH,
    ACTIONS(7088), 1,
      anon_sym_CARET,
    ACTIONS(7090), 1,
      anon_sym_PIPE,
    ACTIONS(7092), 1,
      anon_sym_AMP,
    ACTIONS(7096), 1,
      anon_sym_GT_GT,
    ACTIONS(7102), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7104), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7106), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7108), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7110), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7078), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7082), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7084), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7094), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7098), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7100), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5644), 6,
      anon_sym_SEMI,
      anon_sym_and,
      anon_sym_or,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
    STATE(5198), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [55241] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7086), 1,
      anon_sym_SLASH,
    ACTIONS(7088), 1,
      anon_sym_CARET,
    ACTIONS(7090), 1,
      anon_sym_PIPE,
    ACTIONS(7092), 1,
      anon_sym_AMP,
    ACTIONS(7096), 1,
      anon_sym_GT_GT,
    ACTIONS(7102), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7104), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7106), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7108), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7110), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7078), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7082), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7084), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7094), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7098), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7100), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 6,
      anon_sym_SEMI,
      anon_sym_and,
      anon_sym_or,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
    STATE(5199), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [55382] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5200), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4122), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(4124), 30,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_GT,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [55469] = 35,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7152), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7162), 1,
      anon_sym_SLASH,
    ACTIONS(7168), 1,
      anon_sym_AMP,
    ACTIONS(7172), 1,
      anon_sym_GT_GT,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7186), 1,
      anon_sym_as,
    ACTIONS(7188), 1,
      anon_sym_is,
    ACTIONS(7190), 1,
      anon_sym_with,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7154), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7158), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7160), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7170), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7174), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7176), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(5201), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 10,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_CARET,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
  [55600] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7152), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7162), 1,
      anon_sym_SLASH,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7190), 1,
      anon_sym_with,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7158), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7160), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5202), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 18,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
  [55715] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(1411), 1,
      anon_sym_LBRACE,
    STATE(5569), 1,
      sym_initializer_expression,
    STATE(5203), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5305), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5303), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [55806] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7118), 1,
      anon_sym_SLASH,
    ACTIONS(7120), 1,
      anon_sym_CARET,
    ACTIONS(7122), 1,
      anon_sym_PIPE,
    ACTIONS(7124), 1,
      anon_sym_AMP,
    ACTIONS(7128), 1,
      anon_sym_GT_GT,
    ACTIONS(7134), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7136), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7138), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7140), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7142), 1,
      anon_sym_is,
    ACTIONS(7144), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7112), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7114), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7116), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7126), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7130), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7132), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5424), 6,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_and,
      anon_sym_or,
    STATE(5204), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [55947] = 26,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7118), 1,
      anon_sym_SLASH,
    ACTIONS(7134), 1,
      anon_sym_DOT_DOT,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7116), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5205), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 18,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
  [56060] = 35,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7118), 1,
      anon_sym_SLASH,
    ACTIONS(7124), 1,
      anon_sym_AMP,
    ACTIONS(7128), 1,
      anon_sym_GT_GT,
    ACTIONS(7134), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7142), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(7112), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7114), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7116), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7126), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7130), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7132), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(5206), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 10,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
  [56191] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7152), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7162), 1,
      anon_sym_SLASH,
    ACTIONS(7164), 1,
      anon_sym_CARET,
    ACTIONS(7166), 1,
      anon_sym_PIPE,
    ACTIONS(7168), 1,
      anon_sym_AMP,
    ACTIONS(7172), 1,
      anon_sym_GT_GT,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7180), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7182), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7184), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7186), 1,
      anon_sym_as,
    ACTIONS(7188), 1,
      anon_sym_is,
    ACTIONS(7190), 1,
      anon_sym_with,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7154), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7158), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7160), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7170), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7174), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7176), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 6,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
    STATE(5207), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [56332] = 36,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7118), 1,
      anon_sym_SLASH,
    ACTIONS(7120), 1,
      anon_sym_CARET,
    ACTIONS(7124), 1,
      anon_sym_AMP,
    ACTIONS(7128), 1,
      anon_sym_GT_GT,
    ACTIONS(7134), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7142), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(7112), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7114), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7116), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7126), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7130), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7132), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 9,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(5208), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [56465] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7080), 1,
      anon_sym_QMARK,
    ACTIONS(7086), 1,
      anon_sym_SLASH,
    ACTIONS(7088), 1,
      anon_sym_CARET,
    ACTIONS(7090), 1,
      anon_sym_PIPE,
    ACTIONS(7092), 1,
      anon_sym_AMP,
    ACTIONS(7096), 1,
      anon_sym_GT_GT,
    ACTIONS(7102), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7104), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7106), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7108), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7110), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7078), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7082), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7084), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7094), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7098), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7100), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6320), 6,
      anon_sym_SEMI,
      anon_sym_and,
      anon_sym_or,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
    STATE(5209), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [56606] = 21,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5327), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5210), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5325), 23,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [56709] = 34,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7118), 1,
      anon_sym_SLASH,
    ACTIONS(7128), 1,
      anon_sym_GT_GT,
    ACTIONS(7134), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7142), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7112), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7114), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7116), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7126), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7130), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7132), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    STATE(5211), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 10,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
  [56838] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7152), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7156), 1,
      anon_sym_QMARK,
    ACTIONS(7162), 1,
      anon_sym_SLASH,
    ACTIONS(7164), 1,
      anon_sym_CARET,
    ACTIONS(7166), 1,
      anon_sym_PIPE,
    ACTIONS(7168), 1,
      anon_sym_AMP,
    ACTIONS(7172), 1,
      anon_sym_GT_GT,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7180), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7182), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7184), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7186), 1,
      anon_sym_as,
    ACTIONS(7188), 1,
      anon_sym_is,
    ACTIONS(7190), 1,
      anon_sym_with,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7154), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7158), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7160), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7170), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7174), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7176), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6320), 6,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
    STATE(5212), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [56979] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7118), 1,
      anon_sym_SLASH,
    ACTIONS(7120), 1,
      anon_sym_CARET,
    ACTIONS(7122), 1,
      anon_sym_PIPE,
    ACTIONS(7124), 1,
      anon_sym_AMP,
    ACTIONS(7128), 1,
      anon_sym_GT_GT,
    ACTIONS(7134), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7136), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7138), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7140), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7142), 1,
      anon_sym_is,
    ACTIONS(7144), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7112), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7114), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7116), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7126), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7130), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7132), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5572), 6,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_and,
      anon_sym_or,
    STATE(5213), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [57120] = 36,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7152), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7162), 1,
      anon_sym_SLASH,
    ACTIONS(7164), 1,
      anon_sym_CARET,
    ACTIONS(7168), 1,
      anon_sym_AMP,
    ACTIONS(7172), 1,
      anon_sym_GT_GT,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7186), 1,
      anon_sym_as,
    ACTIONS(7188), 1,
      anon_sym_is,
    ACTIONS(7190), 1,
      anon_sym_with,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7154), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7158), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7160), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7170), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7174), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7176), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 9,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
    STATE(5214), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [57253] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7118), 1,
      anon_sym_SLASH,
    ACTIONS(7134), 1,
      anon_sym_DOT_DOT,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7114), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7116), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5215), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 18,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
  [57368] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7152), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7156), 1,
      anon_sym_QMARK,
    ACTIONS(7162), 1,
      anon_sym_SLASH,
    ACTIONS(7164), 1,
      anon_sym_CARET,
    ACTIONS(7166), 1,
      anon_sym_PIPE,
    ACTIONS(7168), 1,
      anon_sym_AMP,
    ACTIONS(7172), 1,
      anon_sym_GT_GT,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7180), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7182), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7184), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7186), 1,
      anon_sym_as,
    ACTIONS(7188), 1,
      anon_sym_is,
    ACTIONS(7190), 1,
      anon_sym_with,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7154), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7158), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7160), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7170), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7174), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7176), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6324), 6,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
    STATE(5216), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [57509] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7152), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7156), 1,
      anon_sym_QMARK,
    ACTIONS(7162), 1,
      anon_sym_SLASH,
    ACTIONS(7164), 1,
      anon_sym_CARET,
    ACTIONS(7166), 1,
      anon_sym_PIPE,
    ACTIONS(7168), 1,
      anon_sym_AMP,
    ACTIONS(7172), 1,
      anon_sym_GT_GT,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7180), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7182), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7184), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7186), 1,
      anon_sym_as,
    ACTIONS(7188), 1,
      anon_sym_is,
    ACTIONS(7190), 1,
      anon_sym_with,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7154), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7158), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7160), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7170), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7174), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7176), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5416), 6,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
    STATE(5217), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [57650] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7080), 1,
      anon_sym_QMARK,
    ACTIONS(7086), 1,
      anon_sym_SLASH,
    ACTIONS(7088), 1,
      anon_sym_CARET,
    ACTIONS(7090), 1,
      anon_sym_PIPE,
    ACTIONS(7092), 1,
      anon_sym_AMP,
    ACTIONS(7096), 1,
      anon_sym_GT_GT,
    ACTIONS(7102), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7104), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7106), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7108), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7110), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7078), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7082), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7084), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7094), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7098), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7100), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5424), 6,
      anon_sym_SEMI,
      anon_sym_and,
      anon_sym_or,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
    STATE(5218), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [57791] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7052), 1,
      anon_sym_LT,
    STATE(5254), 1,
      sym_type_argument_list,
    STATE(5219), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4138), 10,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(4140), 29,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [57882] = 33,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7118), 1,
      anon_sym_SLASH,
    ACTIONS(7128), 1,
      anon_sym_GT_GT,
    ACTIONS(7134), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7142), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7112), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7114), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7116), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7126), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7132), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    STATE(5220), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 12,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
  [58009] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(1411), 1,
      anon_sym_LBRACE,
    STATE(5550), 1,
      sym_initializer_expression,
    STATE(5221), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5317), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5315), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [58100] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7152), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7156), 1,
      anon_sym_QMARK,
    ACTIONS(7162), 1,
      anon_sym_SLASH,
    ACTIONS(7164), 1,
      anon_sym_CARET,
    ACTIONS(7166), 1,
      anon_sym_PIPE,
    ACTIONS(7168), 1,
      anon_sym_AMP,
    ACTIONS(7172), 1,
      anon_sym_GT_GT,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7180), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7182), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7184), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7186), 1,
      anon_sym_as,
    ACTIONS(7188), 1,
      anon_sym_is,
    ACTIONS(7190), 1,
      anon_sym_with,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7154), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7158), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7160), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7170), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7174), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7176), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5644), 6,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
    STATE(5222), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [58241] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3193), 1,
      sym__identifier_token,
    ACTIONS(3205), 1,
      anon_sym_LPAREN,
    ACTIONS(4002), 1,
      anon_sym_delegate,
    ACTIONS(7194), 1,
      sym_predefined_type,
    ACTIONS(7214), 1,
      anon_sym_LBRACK,
    STATE(3851), 1,
      sym_array_type,
    STATE(4513), 1,
      sym__reserved_identifier,
    STATE(4947), 1,
      sym_identifier,
    STATE(5019), 1,
      sym_generic_name,
    STATE(8318), 1,
      sym__name,
    STATE(8527), 1,
      sym_tuple_type,
    STATE(8893), 1,
      sym__array_base_type,
    STATE(9443), 1,
      sym__pointer_base_type,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(8717), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(5223), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3197), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [58356] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7152), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7156), 1,
      anon_sym_QMARK,
    ACTIONS(7162), 1,
      anon_sym_SLASH,
    ACTIONS(7164), 1,
      anon_sym_CARET,
    ACTIONS(7166), 1,
      anon_sym_PIPE,
    ACTIONS(7168), 1,
      anon_sym_AMP,
    ACTIONS(7172), 1,
      anon_sym_GT_GT,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7180), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7182), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7184), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7186), 1,
      anon_sym_as,
    ACTIONS(7188), 1,
      anon_sym_is,
    ACTIONS(7190), 1,
      anon_sym_with,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7154), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7158), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7160), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7170), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7174), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7176), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5424), 6,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
    STATE(5224), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [58497] = 37,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7118), 1,
      anon_sym_SLASH,
    ACTIONS(7120), 1,
      anon_sym_CARET,
    ACTIONS(7122), 1,
      anon_sym_PIPE,
    ACTIONS(7124), 1,
      anon_sym_AMP,
    ACTIONS(7128), 1,
      anon_sym_GT_GT,
    ACTIONS(7134), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7142), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7112), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7114), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7116), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7126), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7130), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7132), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 9,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(5225), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [58632] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7152), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7156), 1,
      anon_sym_QMARK,
    ACTIONS(7162), 1,
      anon_sym_SLASH,
    ACTIONS(7164), 1,
      anon_sym_CARET,
    ACTIONS(7166), 1,
      anon_sym_PIPE,
    ACTIONS(7168), 1,
      anon_sym_AMP,
    ACTIONS(7172), 1,
      anon_sym_GT_GT,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7180), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7182), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7184), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7186), 1,
      anon_sym_as,
    ACTIONS(7188), 1,
      anon_sym_is,
    ACTIONS(7190), 1,
      anon_sym_with,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7154), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7158), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7160), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7170), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7174), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7176), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6336), 6,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
    STATE(5226), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [58773] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7118), 1,
      anon_sym_SLASH,
    ACTIONS(7120), 1,
      anon_sym_CARET,
    ACTIONS(7122), 1,
      anon_sym_PIPE,
    ACTIONS(7124), 1,
      anon_sym_AMP,
    ACTIONS(7128), 1,
      anon_sym_GT_GT,
    ACTIONS(7134), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7136), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7138), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7140), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7142), 1,
      anon_sym_is,
    ACTIONS(7144), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7112), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7114), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7116), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7126), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7130), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7132), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5624), 6,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_and,
      anon_sym_or,
    STATE(5227), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [58914] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(7134), 1,
      anon_sym_DOT_DOT,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6330), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5228), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6328), 22,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [59019] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7152), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7156), 1,
      anon_sym_QMARK,
    ACTIONS(7162), 1,
      anon_sym_SLASH,
    ACTIONS(7164), 1,
      anon_sym_CARET,
    ACTIONS(7166), 1,
      anon_sym_PIPE,
    ACTIONS(7168), 1,
      anon_sym_AMP,
    ACTIONS(7172), 1,
      anon_sym_GT_GT,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7180), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7182), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7184), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7186), 1,
      anon_sym_as,
    ACTIONS(7188), 1,
      anon_sym_is,
    ACTIONS(7190), 1,
      anon_sym_with,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7154), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7158), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7160), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7170), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7174), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7176), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6270), 6,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
    STATE(5229), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [59160] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7152), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7156), 1,
      anon_sym_QMARK,
    ACTIONS(7162), 1,
      anon_sym_SLASH,
    ACTIONS(7164), 1,
      anon_sym_CARET,
    ACTIONS(7166), 1,
      anon_sym_PIPE,
    ACTIONS(7168), 1,
      anon_sym_AMP,
    ACTIONS(7172), 1,
      anon_sym_GT_GT,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7180), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7182), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7184), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7186), 1,
      anon_sym_as,
    ACTIONS(7188), 1,
      anon_sym_is,
    ACTIONS(7190), 1,
      anon_sym_with,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7154), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7158), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7160), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7170), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7174), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7176), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5572), 6,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
    STATE(5230), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [59301] = 29,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7086), 1,
      anon_sym_SLASH,
    ACTIONS(7096), 1,
      anon_sym_GT_GT,
    ACTIONS(7102), 1,
      anon_sym_DOT_DOT,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7082), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7084), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7094), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6344), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    STATE(5231), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 16,
      anon_sym_SEMI,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
  [59420] = 38,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7118), 1,
      anon_sym_SLASH,
    ACTIONS(7120), 1,
      anon_sym_CARET,
    ACTIONS(7122), 1,
      anon_sym_PIPE,
    ACTIONS(7124), 1,
      anon_sym_AMP,
    ACTIONS(7128), 1,
      anon_sym_GT_GT,
    ACTIONS(7134), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7136), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7142), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7112), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7114), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7116), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7126), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7130), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7132), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 8,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(5232), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [59557] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7152), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7156), 1,
      anon_sym_QMARK,
    ACTIONS(7162), 1,
      anon_sym_SLASH,
    ACTIONS(7164), 1,
      anon_sym_CARET,
    ACTIONS(7166), 1,
      anon_sym_PIPE,
    ACTIONS(7168), 1,
      anon_sym_AMP,
    ACTIONS(7172), 1,
      anon_sym_GT_GT,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7180), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7182), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7184), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7186), 1,
      anon_sym_as,
    ACTIONS(7188), 1,
      anon_sym_is,
    ACTIONS(7190), 1,
      anon_sym_with,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7154), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7158), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7160), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7170), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7174), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7176), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5584), 6,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
    STATE(5233), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [59698] = 33,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7152), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7162), 1,
      anon_sym_SLASH,
    ACTIONS(7172), 1,
      anon_sym_GT_GT,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7186), 1,
      anon_sym_as,
    ACTIONS(7188), 1,
      anon_sym_is,
    ACTIONS(7190), 1,
      anon_sym_with,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7154), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7158), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7160), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7170), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7176), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    STATE(5234), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 12,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
  [59825] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7152), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7156), 1,
      anon_sym_QMARK,
    ACTIONS(7162), 1,
      anon_sym_SLASH,
    ACTIONS(7164), 1,
      anon_sym_CARET,
    ACTIONS(7166), 1,
      anon_sym_PIPE,
    ACTIONS(7168), 1,
      anon_sym_AMP,
    ACTIONS(7172), 1,
      anon_sym_GT_GT,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7180), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7182), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7184), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7186), 1,
      anon_sym_as,
    ACTIONS(7188), 1,
      anon_sym_is,
    ACTIONS(7190), 1,
      anon_sym_with,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7154), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7158), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7160), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7170), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7174), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7176), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5624), 6,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
    STATE(5235), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [59966] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7080), 1,
      anon_sym_QMARK,
    ACTIONS(7086), 1,
      anon_sym_SLASH,
    ACTIONS(7088), 1,
      anon_sym_CARET,
    ACTIONS(7090), 1,
      anon_sym_PIPE,
    ACTIONS(7092), 1,
      anon_sym_AMP,
    ACTIONS(7096), 1,
      anon_sym_GT_GT,
    ACTIONS(7102), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7104), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7106), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7108), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7110), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7078), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7082), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7084), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7094), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7098), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7100), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5572), 6,
      anon_sym_SEMI,
      anon_sym_and,
      anon_sym_or,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
    STATE(5236), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [60107] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7118), 1,
      anon_sym_SLASH,
    ACTIONS(7120), 1,
      anon_sym_CARET,
    ACTIONS(7122), 1,
      anon_sym_PIPE,
    ACTIONS(7124), 1,
      anon_sym_AMP,
    ACTIONS(7128), 1,
      anon_sym_GT_GT,
    ACTIONS(7134), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7136), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7138), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7140), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7142), 1,
      anon_sym_is,
    ACTIONS(7144), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7112), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7114), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7116), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7126), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7130), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7132), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6336), 6,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_and,
      anon_sym_or,
    STATE(5237), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [60248] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3193), 1,
      sym__identifier_token,
    ACTIONS(3205), 1,
      anon_sym_LPAREN,
    ACTIONS(4002), 1,
      anon_sym_delegate,
    ACTIONS(7194), 1,
      sym_predefined_type,
    ACTIONS(7216), 1,
      anon_sym_LBRACK,
    STATE(3622), 1,
      sym_array_type,
    STATE(4513), 1,
      sym__reserved_identifier,
    STATE(4947), 1,
      sym_identifier,
    STATE(5019), 1,
      sym_generic_name,
    STATE(8318), 1,
      sym__name,
    STATE(8527), 1,
      sym_tuple_type,
    STATE(8829), 1,
      sym__array_base_type,
    STATE(9443), 1,
      sym__pointer_base_type,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(8717), 3,
      sym_nullable_type,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(5238), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3197), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [60363] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7080), 1,
      anon_sym_QMARK,
    ACTIONS(7086), 1,
      anon_sym_SLASH,
    ACTIONS(7088), 1,
      anon_sym_CARET,
    ACTIONS(7090), 1,
      anon_sym_PIPE,
    ACTIONS(7092), 1,
      anon_sym_AMP,
    ACTIONS(7096), 1,
      anon_sym_GT_GT,
    ACTIONS(7102), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7104), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7106), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7108), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7110), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7078), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7082), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7084), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7094), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7098), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7100), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5584), 6,
      anon_sym_SEMI,
      anon_sym_and,
      anon_sym_or,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
    STATE(5239), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [60504] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5240), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4630), 13,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_STAR,
      anon_sym_EQ_GT,
    ACTIONS(4628), 28,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_operator,
      anon_sym_this,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      sym_discard,
      anon_sym_and,
      anon_sym_or,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [60591] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7118), 1,
      anon_sym_SLASH,
    ACTIONS(7120), 1,
      anon_sym_CARET,
    ACTIONS(7122), 1,
      anon_sym_PIPE,
    ACTIONS(7124), 1,
      anon_sym_AMP,
    ACTIONS(7128), 1,
      anon_sym_GT_GT,
    ACTIONS(7134), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7136), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7138), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7140), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7142), 1,
      anon_sym_is,
    ACTIONS(7144), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7112), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7114), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7116), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7126), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7130), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7132), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6332), 6,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_and,
      anon_sym_or,
    STATE(5241), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [60732] = 38,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7152), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7162), 1,
      anon_sym_SLASH,
    ACTIONS(7164), 1,
      anon_sym_CARET,
    ACTIONS(7166), 1,
      anon_sym_PIPE,
    ACTIONS(7168), 1,
      anon_sym_AMP,
    ACTIONS(7172), 1,
      anon_sym_GT_GT,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7180), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7186), 1,
      anon_sym_as,
    ACTIONS(7188), 1,
      anon_sym_is,
    ACTIONS(7190), 1,
      anon_sym_with,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7154), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7158), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7160), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7170), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7174), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7176), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 8,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
    STATE(5242), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [60869] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5243), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4498), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(4500), 29,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [60955] = 43,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(2629), 1,
      aux_sym_preproc_else_token1,
    ACTIONS(2631), 1,
      aux_sym_preproc_elif_token1,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7220), 1,
      anon_sym_QMARK,
    ACTIONS(7226), 1,
      anon_sym_SLASH,
    ACTIONS(7228), 1,
      anon_sym_CARET,
    ACTIONS(7230), 1,
      anon_sym_PIPE,
    ACTIONS(7232), 1,
      anon_sym_AMP,
    ACTIONS(7236), 1,
      anon_sym_GT_GT,
    ACTIONS(7242), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7244), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7246), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7248), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(7254), 1,
      aux_sym_preproc_if_token3,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7218), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7222), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7224), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7234), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7238), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7240), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(9308), 2,
      sym_preproc_else_in_expression,
      sym_preproc_elif_in_expression,
    STATE(5244), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [61101] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7258), 1,
      anon_sym_QMARK,
    ACTIONS(7264), 1,
      anon_sym_SLASH,
    ACTIONS(7266), 1,
      anon_sym_CARET,
    ACTIONS(7268), 1,
      anon_sym_PIPE,
    ACTIONS(7270), 1,
      anon_sym_AMP,
    ACTIONS(7274), 1,
      anon_sym_GT_GT,
    ACTIONS(7280), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7282), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7284), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7286), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7288), 1,
      anon_sym_as,
    ACTIONS(7290), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7256), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7260), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7262), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7272), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7276), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7278), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6336), 5,
      anon_sym_COLON,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
    STATE(5245), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [61241] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6837), 1,
      anon_sym_as,
    ACTIONS(7294), 1,
      anon_sym_QMARK,
    ACTIONS(7300), 1,
      anon_sym_SLASH,
    ACTIONS(7302), 1,
      anon_sym_CARET,
    ACTIONS(7304), 1,
      anon_sym_PIPE,
    ACTIONS(7306), 1,
      anon_sym_AMP,
    ACTIONS(7310), 1,
      anon_sym_GT_GT,
    ACTIONS(7316), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7318), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7320), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7322), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7324), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7292), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7296), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7298), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7308), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7312), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7314), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5424), 5,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_into,
    STATE(5246), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [61381] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7280), 1,
      anon_sym_DOT_DOT,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5247), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
  [61489] = 37,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6837), 1,
      anon_sym_as,
    ACTIONS(7300), 1,
      anon_sym_SLASH,
    ACTIONS(7302), 1,
      anon_sym_CARET,
    ACTIONS(7304), 1,
      anon_sym_PIPE,
    ACTIONS(7306), 1,
      anon_sym_AMP,
    ACTIONS(7310), 1,
      anon_sym_GT_GT,
    ACTIONS(7316), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7324), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7292), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7296), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7298), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7308), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7312), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7314), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 8,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
    STATE(5248), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [61623] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7288), 1,
      anon_sym_as,
    ACTIONS(7328), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 1,
      anon_sym_SLASH,
    ACTIONS(7336), 1,
      anon_sym_CARET,
    ACTIONS(7338), 1,
      anon_sym_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP,
    ACTIONS(7344), 1,
      anon_sym_GT_GT,
    ACTIONS(7350), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7352), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7354), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7356), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7358), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7326), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7330), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7332), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7342), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7346), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7348), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6320), 5,
      anon_sym_EQ_GT,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
    STATE(5249), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [61763] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5250), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4550), 12,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_EQ_GT,
    ACTIONS(4548), 28,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_operator,
      anon_sym_this,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      sym_discard,
      anon_sym_and,
      anon_sym_or,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [61849] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4593), 1,
      anon_sym_LBRACK,
    ACTIONS(7360), 1,
      anon_sym_QMARK,
    STATE(5251), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4492), 10,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(4494), 28,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [61939] = 38,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6837), 1,
      anon_sym_as,
    ACTIONS(7300), 1,
      anon_sym_SLASH,
    ACTIONS(7302), 1,
      anon_sym_CARET,
    ACTIONS(7304), 1,
      anon_sym_PIPE,
    ACTIONS(7306), 1,
      anon_sym_AMP,
    ACTIONS(7310), 1,
      anon_sym_GT_GT,
    ACTIONS(7316), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7318), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7324), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7292), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7296), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7298), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7308), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7312), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7314), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 7,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
    STATE(5252), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [62075] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5253), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4179), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(4181), 29,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [62161] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5254), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4130), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(4132), 29,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [62247] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5329), 1,
      anon_sym_LT,
    ACTIONS(7363), 1,
      anon_sym_COLON_COLON,
    STATE(3715), 1,
      sym_type_argument_list,
    STATE(5255), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4138), 11,
      anon_sym_COLON,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(4140), 26,
      anon_sym_LBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [62339] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7288), 1,
      anon_sym_as,
    ACTIONS(7328), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 1,
      anon_sym_SLASH,
    ACTIONS(7336), 1,
      anon_sym_CARET,
    ACTIONS(7338), 1,
      anon_sym_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP,
    ACTIONS(7344), 1,
      anon_sym_GT_GT,
    ACTIONS(7350), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7352), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7354), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7356), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7358), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7326), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7330), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7332), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7342), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7346), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7348), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6190), 5,
      anon_sym_EQ_GT,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
    STATE(5256), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [62479] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6837), 1,
      anon_sym_as,
    ACTIONS(7294), 1,
      anon_sym_QMARK,
    ACTIONS(7300), 1,
      anon_sym_SLASH,
    ACTIONS(7302), 1,
      anon_sym_CARET,
    ACTIONS(7304), 1,
      anon_sym_PIPE,
    ACTIONS(7306), 1,
      anon_sym_AMP,
    ACTIONS(7310), 1,
      anon_sym_GT_GT,
    ACTIONS(7316), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7318), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7320), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7322), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7324), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7292), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7296), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7298), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7308), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7312), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7314), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6336), 5,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_into,
    STATE(5257), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [62619] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7365), 1,
      anon_sym_and,
    STATE(5258), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6707), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6705), 28,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [62707] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5259), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4585), 12,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_EQ_GT,
    ACTIONS(4583), 28,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_operator,
      anon_sym_this,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      sym_discard,
      anon_sym_and,
      anon_sym_or,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [62793] = 29,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7264), 1,
      anon_sym_SLASH,
    ACTIONS(7274), 1,
      anon_sym_GT_GT,
    ACTIONS(7280), 1,
      anon_sym_DOT_DOT,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7260), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7262), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7272), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6344), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    STATE(5260), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 15,
      anon_sym_COLON,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
  [62911] = 43,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(2629), 1,
      aux_sym_preproc_else_token1,
    ACTIONS(2631), 1,
      aux_sym_preproc_elif_token1,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7220), 1,
      anon_sym_QMARK,
    ACTIONS(7226), 1,
      anon_sym_SLASH,
    ACTIONS(7228), 1,
      anon_sym_CARET,
    ACTIONS(7230), 1,
      anon_sym_PIPE,
    ACTIONS(7232), 1,
      anon_sym_AMP,
    ACTIONS(7236), 1,
      anon_sym_GT_GT,
    ACTIONS(7242), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7244), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7246), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7248), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(7367), 1,
      aux_sym_preproc_if_token3,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7218), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7222), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7224), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7234), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7238), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7240), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(9902), 2,
      sym_preproc_else_in_expression,
      sym_preproc_elif_in_expression,
    STATE(5261), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [63057] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4593), 1,
      anon_sym_LBRACK,
    ACTIONS(4599), 1,
      anon_sym_STAR,
    STATE(5262), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4492), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(4494), 27,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [63147] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6837), 1,
      anon_sym_as,
    ACTIONS(7294), 1,
      anon_sym_QMARK,
    ACTIONS(7300), 1,
      anon_sym_SLASH,
    ACTIONS(7302), 1,
      anon_sym_CARET,
    ACTIONS(7304), 1,
      anon_sym_PIPE,
    ACTIONS(7306), 1,
      anon_sym_AMP,
    ACTIONS(7310), 1,
      anon_sym_GT_GT,
    ACTIONS(7316), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7318), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7320), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7322), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7324), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7292), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7296), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7298), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7308), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7312), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7314), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5572), 5,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_into,
    STATE(5263), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [63287] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7365), 1,
      anon_sym_and,
    ACTIONS(7369), 1,
      anon_sym_or,
    STATE(5264), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6594), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6592), 27,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [63377] = 26,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7264), 1,
      anon_sym_SLASH,
    ACTIONS(7280), 1,
      anon_sym_DOT_DOT,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7262), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5265), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 17,
      anon_sym_COLON,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
  [63489] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3193), 1,
      sym__identifier_token,
    ACTIONS(3205), 1,
      anon_sym_LPAREN,
    ACTIONS(4002), 1,
      anon_sym_delegate,
    ACTIONS(7194), 1,
      sym_predefined_type,
    STATE(4513), 1,
      sym__reserved_identifier,
    STATE(4947), 1,
      sym_identifier,
    STATE(5019), 1,
      sym_generic_name,
    STATE(7200), 1,
      sym_array_type,
    STATE(7232), 1,
      sym_nullable_type,
    STATE(8318), 1,
      sym__name,
    STATE(8527), 1,
      sym_tuple_type,
    STATE(8852), 1,
      sym__array_base_type,
    STATE(9443), 1,
      sym__pointer_base_type,
    STATE(8717), 2,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(5266), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3197), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [63603] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6837), 1,
      anon_sym_as,
    ACTIONS(7294), 1,
      anon_sym_QMARK,
    ACTIONS(7300), 1,
      anon_sym_SLASH,
    ACTIONS(7302), 1,
      anon_sym_CARET,
    ACTIONS(7304), 1,
      anon_sym_PIPE,
    ACTIONS(7306), 1,
      anon_sym_AMP,
    ACTIONS(7310), 1,
      anon_sym_GT_GT,
    ACTIONS(7316), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7318), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7320), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7322), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7324), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7292), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7296), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7298), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7308), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7312), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7314), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6320), 5,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_into,
    STATE(5267), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [63743] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5268), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4583), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(4585), 29,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [63829] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(6608), 1,
      anon_sym_ref,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(2883), 1,
      sym_ref_type,
    STATE(2885), 1,
      sym__scoped_base_type,
    STATE(5346), 1,
      sym_identifier,
    STATE(6202), 1,
      sym__name,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    ACTIONS(3993), 7,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_STAR,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
    STATE(5269), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [63933] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4593), 1,
      anon_sym_LBRACK,
    ACTIONS(4599), 1,
      anon_sym_STAR,
    ACTIONS(7360), 1,
      anon_sym_QMARK,
    ACTIONS(7371), 1,
      anon_sym_DOT,
    ACTIONS(4492), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5270), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4494), 27,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [64027] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7264), 1,
      anon_sym_SLASH,
    ACTIONS(7280), 1,
      anon_sym_DOT_DOT,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7260), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7262), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5271), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 17,
      anon_sym_COLON,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
  [64141] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5272), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4548), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(4550), 29,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [64227] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7190), 1,
      anon_sym_with,
    ACTIONS(7375), 1,
      anon_sym_QMARK,
    ACTIONS(7381), 1,
      anon_sym_SLASH,
    ACTIONS(7383), 1,
      anon_sym_CARET,
    ACTIONS(7385), 1,
      anon_sym_PIPE,
    ACTIONS(7387), 1,
      anon_sym_AMP,
    ACTIONS(7391), 1,
      anon_sym_GT_GT,
    ACTIONS(7397), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7399), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7401), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7403), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7405), 1,
      anon_sym_as,
    ACTIONS(7407), 1,
      anon_sym_is,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7373), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7377), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7379), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7389), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7393), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7395), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5424), 5,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_and,
      anon_sym_or,
    STATE(5273), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [64367] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7334), 1,
      anon_sym_SLASH,
    ACTIONS(7350), 1,
      anon_sym_DOT_DOT,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7330), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7332), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5274), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 17,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_GT,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
  [64481] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6837), 1,
      anon_sym_as,
    ACTIONS(7300), 1,
      anon_sym_SLASH,
    ACTIONS(7302), 1,
      anon_sym_CARET,
    ACTIONS(7304), 1,
      anon_sym_PIPE,
    ACTIONS(7306), 1,
      anon_sym_AMP,
    ACTIONS(7310), 1,
      anon_sym_GT_GT,
    ACTIONS(7316), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7318), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7320), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7322), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7324), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7292), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7296), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7298), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7308), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7312), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7314), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 5,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_into,
    STATE(5275), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [64621] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7288), 1,
      anon_sym_as,
    ACTIONS(7328), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 1,
      anon_sym_SLASH,
    ACTIONS(7336), 1,
      anon_sym_CARET,
    ACTIONS(7338), 1,
      anon_sym_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP,
    ACTIONS(7344), 1,
      anon_sym_GT_GT,
    ACTIONS(7350), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7352), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7354), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7356), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7358), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7326), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7330), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7332), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7342), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7346), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7348), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5424), 5,
      anon_sym_EQ_GT,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
    STATE(5276), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [64761] = 43,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(2629), 1,
      aux_sym_preproc_else_token1,
    ACTIONS(2631), 1,
      aux_sym_preproc_elif_token1,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7220), 1,
      anon_sym_QMARK,
    ACTIONS(7226), 1,
      anon_sym_SLASH,
    ACTIONS(7228), 1,
      anon_sym_CARET,
    ACTIONS(7230), 1,
      anon_sym_PIPE,
    ACTIONS(7232), 1,
      anon_sym_AMP,
    ACTIONS(7236), 1,
      anon_sym_GT_GT,
    ACTIONS(7242), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7244), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7246), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7248), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(7409), 1,
      aux_sym_preproc_if_token3,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7218), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7222), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7224), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7234), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7238), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7240), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(9053), 2,
      sym_preproc_else_in_expression,
      sym_preproc_elif_in_expression,
    STATE(5277), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [64907] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5278), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5380), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5378), 29,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [64993] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7190), 1,
      anon_sym_with,
    ACTIONS(7397), 1,
      anon_sym_DOT_DOT,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5279), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 19,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
  [65101] = 26,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7334), 1,
      anon_sym_SLASH,
    ACTIONS(7350), 1,
      anon_sym_DOT_DOT,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7332), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5280), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 17,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_GT,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
  [65213] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6837), 1,
      anon_sym_as,
    ACTIONS(7294), 1,
      anon_sym_QMARK,
    ACTIONS(7300), 1,
      anon_sym_SLASH,
    ACTIONS(7302), 1,
      anon_sym_CARET,
    ACTIONS(7304), 1,
      anon_sym_PIPE,
    ACTIONS(7306), 1,
      anon_sym_AMP,
    ACTIONS(7310), 1,
      anon_sym_GT_GT,
    ACTIONS(7316), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7318), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7320), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7322), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7324), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7292), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7296), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7298), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7308), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7312), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7314), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5584), 5,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_into,
    STATE(5281), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [65353] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6837), 1,
      anon_sym_as,
    ACTIONS(7294), 1,
      anon_sym_QMARK,
    ACTIONS(7300), 1,
      anon_sym_SLASH,
    ACTIONS(7302), 1,
      anon_sym_CARET,
    ACTIONS(7304), 1,
      anon_sym_PIPE,
    ACTIONS(7306), 1,
      anon_sym_AMP,
    ACTIONS(7310), 1,
      anon_sym_GT_GT,
    ACTIONS(7316), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7318), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7320), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7322), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7324), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7292), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7296), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7298), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7308), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7312), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7314), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5624), 5,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_into,
    STATE(5282), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [65493] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7190), 1,
      anon_sym_with,
    ACTIONS(7381), 1,
      anon_sym_SLASH,
    ACTIONS(7397), 1,
      anon_sym_DOT_DOT,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7377), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7379), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5283), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 17,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
  [65607] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7288), 1,
      anon_sym_as,
    ACTIONS(7328), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 1,
      anon_sym_SLASH,
    ACTIONS(7336), 1,
      anon_sym_CARET,
    ACTIONS(7338), 1,
      anon_sym_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP,
    ACTIONS(7344), 1,
      anon_sym_GT_GT,
    ACTIONS(7350), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7352), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7354), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7356), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7358), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7326), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7330), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7332), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7342), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7346), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7348), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6336), 5,
      anon_sym_EQ_GT,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
    STATE(5284), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [65747] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7288), 1,
      anon_sym_as,
    ACTIONS(7328), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 1,
      anon_sym_SLASH,
    ACTIONS(7336), 1,
      anon_sym_CARET,
    ACTIONS(7338), 1,
      anon_sym_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP,
    ACTIONS(7344), 1,
      anon_sym_GT_GT,
    ACTIONS(7350), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7352), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7354), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7356), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7358), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7326), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7330), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7332), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7342), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7346), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7348), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6270), 5,
      anon_sym_EQ_GT,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
    STATE(5285), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [65887] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5286), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4486), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(4488), 29,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [65973] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6837), 1,
      anon_sym_as,
    ACTIONS(7294), 1,
      anon_sym_QMARK,
    ACTIONS(7300), 1,
      anon_sym_SLASH,
    ACTIONS(7302), 1,
      anon_sym_CARET,
    ACTIONS(7304), 1,
      anon_sym_PIPE,
    ACTIONS(7306), 1,
      anon_sym_AMP,
    ACTIONS(7310), 1,
      anon_sym_GT_GT,
    ACTIONS(7316), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7318), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7320), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7322), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7324), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7292), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7296), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7298), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7308), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7312), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7314), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6190), 5,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_into,
    STATE(5287), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [66113] = 29,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(7300), 1,
      anon_sym_SLASH,
    ACTIONS(7310), 1,
      anon_sym_GT_GT,
    ACTIONS(7316), 1,
      anon_sym_DOT_DOT,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7296), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7298), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7308), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6344), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    STATE(5288), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 15,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
  [66231] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7288), 1,
      anon_sym_as,
    ACTIONS(7328), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 1,
      anon_sym_SLASH,
    ACTIONS(7336), 1,
      anon_sym_CARET,
    ACTIONS(7338), 1,
      anon_sym_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP,
    ACTIONS(7344), 1,
      anon_sym_GT_GT,
    ACTIONS(7350), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7352), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7354), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7356), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7358), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7326), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7330), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7332), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7342), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7346), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7348), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6324), 5,
      anon_sym_EQ_GT,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
    STATE(5289), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [66371] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5290), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4453), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(4455), 29,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [66457] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6837), 1,
      anon_sym_as,
    ACTIONS(7294), 1,
      anon_sym_QMARK,
    ACTIONS(7300), 1,
      anon_sym_SLASH,
    ACTIONS(7302), 1,
      anon_sym_CARET,
    ACTIONS(7304), 1,
      anon_sym_PIPE,
    ACTIONS(7306), 1,
      anon_sym_AMP,
    ACTIONS(7310), 1,
      anon_sym_GT_GT,
    ACTIONS(7316), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7318), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7320), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7322), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7324), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7292), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7296), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7298), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7308), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7312), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7314), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6270), 5,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_into,
    STATE(5291), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [66597] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7190), 1,
      anon_sym_with,
    ACTIONS(7375), 1,
      anon_sym_QMARK,
    ACTIONS(7381), 1,
      anon_sym_SLASH,
    ACTIONS(7383), 1,
      anon_sym_CARET,
    ACTIONS(7385), 1,
      anon_sym_PIPE,
    ACTIONS(7387), 1,
      anon_sym_AMP,
    ACTIONS(7391), 1,
      anon_sym_GT_GT,
    ACTIONS(7397), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7399), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7401), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7403), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7405), 1,
      anon_sym_as,
    ACTIONS(7407), 1,
      anon_sym_is,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7373), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7377), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7379), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7389), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7393), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7395), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6190), 5,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_and,
      anon_sym_or,
    STATE(5292), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [66737] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7258), 1,
      anon_sym_QMARK,
    ACTIONS(7264), 1,
      anon_sym_SLASH,
    ACTIONS(7266), 1,
      anon_sym_CARET,
    ACTIONS(7268), 1,
      anon_sym_PIPE,
    ACTIONS(7270), 1,
      anon_sym_AMP,
    ACTIONS(7274), 1,
      anon_sym_GT_GT,
    ACTIONS(7280), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7282), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7284), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7286), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7288), 1,
      anon_sym_as,
    ACTIONS(7290), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7256), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7260), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7262), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7272), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7276), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7278), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6190), 5,
      anon_sym_COLON,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
    STATE(5293), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [66877] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7190), 1,
      anon_sym_with,
    ACTIONS(7375), 1,
      anon_sym_QMARK,
    ACTIONS(7381), 1,
      anon_sym_SLASH,
    ACTIONS(7383), 1,
      anon_sym_CARET,
    ACTIONS(7385), 1,
      anon_sym_PIPE,
    ACTIONS(7387), 1,
      anon_sym_AMP,
    ACTIONS(7391), 1,
      anon_sym_GT_GT,
    ACTIONS(7397), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7399), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7401), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7403), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7405), 1,
      anon_sym_as,
    ACTIONS(7407), 1,
      anon_sym_is,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7373), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7377), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7379), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7389), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7393), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7395), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6336), 5,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_and,
      anon_sym_or,
    STATE(5294), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [67017] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7411), 1,
      anon_sym_LBRACK,
    ACTIONS(7413), 1,
      anon_sym_QMARK,
    ACTIONS(7415), 1,
      anon_sym_STAR,
    ACTIONS(4494), 9,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_EQ_GT,
    STATE(5295), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4492), 28,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_operator,
      anon_sym_this,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      sym_discard,
      anon_sym_and,
      anon_sym_or,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [67109] = 26,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(7300), 1,
      anon_sym_SLASH,
    ACTIONS(7316), 1,
      anon_sym_DOT_DOT,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7298), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5296), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 17,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
  [67221] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7288), 1,
      anon_sym_as,
    ACTIONS(7328), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 1,
      anon_sym_SLASH,
    ACTIONS(7336), 1,
      anon_sym_CARET,
    ACTIONS(7338), 1,
      anon_sym_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP,
    ACTIONS(7344), 1,
      anon_sym_GT_GT,
    ACTIONS(7350), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7352), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7354), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7356), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7358), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7326), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7330), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7332), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7342), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7346), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7348), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5416), 5,
      anon_sym_EQ_GT,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
    STATE(5297), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [67361] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7417), 1,
      anon_sym_and,
    ACTIONS(7419), 1,
      anon_sym_or,
    STATE(5298), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6594), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6592), 27,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [67451] = 29,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7190), 1,
      anon_sym_with,
    ACTIONS(7381), 1,
      anon_sym_SLASH,
    ACTIONS(7391), 1,
      anon_sym_GT_GT,
    ACTIONS(7397), 1,
      anon_sym_DOT_DOT,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7377), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7379), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7389), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6344), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    STATE(5299), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 15,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
  [67569] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(7316), 1,
      anon_sym_DOT_DOT,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5300), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 19,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
  [67677] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7258), 1,
      anon_sym_QMARK,
    ACTIONS(7264), 1,
      anon_sym_SLASH,
    ACTIONS(7266), 1,
      anon_sym_CARET,
    ACTIONS(7268), 1,
      anon_sym_PIPE,
    ACTIONS(7270), 1,
      anon_sym_AMP,
    ACTIONS(7274), 1,
      anon_sym_GT_GT,
    ACTIONS(7280), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7282), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7284), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7286), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7288), 1,
      anon_sym_as,
    ACTIONS(7290), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7256), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7260), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7262), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7272), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7276), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7278), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6332), 5,
      anon_sym_COLON,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
    STATE(5301), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [67817] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4806), 6,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_and,
      anon_sym_or,
    STATE(5302), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5654), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5652), 23,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [67905] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7190), 1,
      anon_sym_with,
    ACTIONS(7375), 1,
      anon_sym_QMARK,
    ACTIONS(7381), 1,
      anon_sym_SLASH,
    ACTIONS(7383), 1,
      anon_sym_CARET,
    ACTIONS(7385), 1,
      anon_sym_PIPE,
    ACTIONS(7387), 1,
      anon_sym_AMP,
    ACTIONS(7391), 1,
      anon_sym_GT_GT,
    ACTIONS(7397), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7399), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7401), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7403), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7405), 1,
      anon_sym_as,
    ACTIONS(7407), 1,
      anon_sym_is,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7373), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7377), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7379), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7389), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7393), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7395), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5572), 5,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_and,
      anon_sym_or,
    STATE(5303), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [68045] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7190), 1,
      anon_sym_with,
    ACTIONS(7375), 1,
      anon_sym_QMARK,
    ACTIONS(7381), 1,
      anon_sym_SLASH,
    ACTIONS(7383), 1,
      anon_sym_CARET,
    ACTIONS(7385), 1,
      anon_sym_PIPE,
    ACTIONS(7387), 1,
      anon_sym_AMP,
    ACTIONS(7391), 1,
      anon_sym_GT_GT,
    ACTIONS(7397), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7399), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7401), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7403), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7405), 1,
      anon_sym_as,
    ACTIONS(7407), 1,
      anon_sym_is,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7373), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7377), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7379), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7389), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7393), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7395), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5584), 5,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_and,
      anon_sym_or,
    STATE(5304), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [68185] = 44,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7190), 1,
      anon_sym_with,
    ACTIONS(7405), 1,
      anon_sym_as,
    ACTIONS(7421), 1,
      anon_sym_COLON,
    ACTIONS(7423), 1,
      anon_sym_COMMA,
    ACTIONS(7427), 1,
      anon_sym_QMARK,
    ACTIONS(7433), 1,
      anon_sym_SLASH,
    ACTIONS(7435), 1,
      anon_sym_CARET,
    ACTIONS(7437), 1,
      anon_sym_PIPE,
    ACTIONS(7439), 1,
      anon_sym_AMP,
    ACTIONS(7443), 1,
      anon_sym_GT_GT,
    ACTIONS(7449), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7451), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7453), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7455), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7457), 1,
      anon_sym_is,
    ACTIONS(7459), 1,
      sym_interpolation_close_brace,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    STATE(8438), 1,
      sym_interpolation_alignment_clause,
    STATE(9560), 1,
      sym_interpolation_format_clause,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7425), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7429), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7431), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7441), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7445), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7447), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(5305), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [68333] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6837), 1,
      anon_sym_as,
    ACTIONS(7294), 1,
      anon_sym_QMARK,
    ACTIONS(7300), 1,
      anon_sym_SLASH,
    ACTIONS(7302), 1,
      anon_sym_CARET,
    ACTIONS(7304), 1,
      anon_sym_PIPE,
    ACTIONS(7306), 1,
      anon_sym_AMP,
    ACTIONS(7310), 1,
      anon_sym_GT_GT,
    ACTIONS(7316), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7318), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7320), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7322), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7324), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7292), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7296), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7298), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7308), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7312), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7314), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5416), 5,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_into,
    STATE(5306), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [68473] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7258), 1,
      anon_sym_QMARK,
    ACTIONS(7264), 1,
      anon_sym_SLASH,
    ACTIONS(7266), 1,
      anon_sym_CARET,
    ACTIONS(7268), 1,
      anon_sym_PIPE,
    ACTIONS(7270), 1,
      anon_sym_AMP,
    ACTIONS(7274), 1,
      anon_sym_GT_GT,
    ACTIONS(7280), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7282), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7284), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7286), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7288), 1,
      anon_sym_as,
    ACTIONS(7290), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7256), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7260), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7262), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7272), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7276), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7278), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6320), 5,
      anon_sym_COLON,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
    STATE(5307), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [68613] = 43,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(2629), 1,
      aux_sym_preproc_else_token1,
    ACTIONS(2631), 1,
      aux_sym_preproc_elif_token1,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7220), 1,
      anon_sym_QMARK,
    ACTIONS(7226), 1,
      anon_sym_SLASH,
    ACTIONS(7228), 1,
      anon_sym_CARET,
    ACTIONS(7230), 1,
      anon_sym_PIPE,
    ACTIONS(7232), 1,
      anon_sym_AMP,
    ACTIONS(7236), 1,
      anon_sym_GT_GT,
    ACTIONS(7242), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7244), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7246), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7248), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(7461), 1,
      aux_sym_preproc_if_token3,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7218), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7222), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7224), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7234), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7238), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7240), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(9111), 2,
      sym_preproc_else_in_expression,
      sym_preproc_elif_in_expression,
    STATE(5308), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [68759] = 35,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6837), 1,
      anon_sym_as,
    ACTIONS(7300), 1,
      anon_sym_SLASH,
    ACTIONS(7306), 1,
      anon_sym_AMP,
    ACTIONS(7310), 1,
      anon_sym_GT_GT,
    ACTIONS(7316), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7324), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(7292), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7296), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7298), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7308), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7312), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7314), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 9,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
    STATE(5309), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [68889] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7397), 1,
      anon_sym_DOT_DOT,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6330), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5310), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6328), 21,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [68993] = 36,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6837), 1,
      anon_sym_as,
    ACTIONS(7300), 1,
      anon_sym_SLASH,
    ACTIONS(7302), 1,
      anon_sym_CARET,
    ACTIONS(7306), 1,
      anon_sym_AMP,
    ACTIONS(7310), 1,
      anon_sym_GT_GT,
    ACTIONS(7316), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7324), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(7292), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7296), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7298), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7308), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7312), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7314), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 8,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
    STATE(5311), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [69125] = 34,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6837), 1,
      anon_sym_as,
    ACTIONS(7300), 1,
      anon_sym_SLASH,
    ACTIONS(7310), 1,
      anon_sym_GT_GT,
    ACTIONS(7316), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7324), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7292), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7296), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7298), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7308), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7312), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7314), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(6342), 9,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
    STATE(5312), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [69253] = 35,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7190), 1,
      anon_sym_with,
    ACTIONS(7381), 1,
      anon_sym_SLASH,
    ACTIONS(7387), 1,
      anon_sym_AMP,
    ACTIONS(7391), 1,
      anon_sym_GT_GT,
    ACTIONS(7397), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7405), 1,
      anon_sym_as,
    ACTIONS(7407), 1,
      anon_sym_is,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7373), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7377), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7379), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7389), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7393), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7395), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 9,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_CARET,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(5313), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [69383] = 36,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7190), 1,
      anon_sym_with,
    ACTIONS(7381), 1,
      anon_sym_SLASH,
    ACTIONS(7383), 1,
      anon_sym_CARET,
    ACTIONS(7387), 1,
      anon_sym_AMP,
    ACTIONS(7391), 1,
      anon_sym_GT_GT,
    ACTIONS(7397), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7405), 1,
      anon_sym_as,
    ACTIONS(7407), 1,
      anon_sym_is,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7373), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7377), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7379), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7389), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7393), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7395), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 8,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(5314), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [69515] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7288), 1,
      anon_sym_as,
    ACTIONS(7328), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 1,
      anon_sym_SLASH,
    ACTIONS(7336), 1,
      anon_sym_CARET,
    ACTIONS(7338), 1,
      anon_sym_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP,
    ACTIONS(7344), 1,
      anon_sym_GT_GT,
    ACTIONS(7350), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7352), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7354), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7356), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7358), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7326), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7330), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7332), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7342), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7346), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7348), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5572), 5,
      anon_sym_EQ_GT,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
    STATE(5315), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [69655] = 34,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7190), 1,
      anon_sym_with,
    ACTIONS(7381), 1,
      anon_sym_SLASH,
    ACTIONS(7391), 1,
      anon_sym_GT_GT,
    ACTIONS(7397), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7405), 1,
      anon_sym_as,
    ACTIONS(7407), 1,
      anon_sym_is,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7373), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7377), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7379), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7389), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7393), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7395), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(6342), 9,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_CARET,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(5316), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [69783] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7288), 1,
      anon_sym_as,
    ACTIONS(7328), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 1,
      anon_sym_SLASH,
    ACTIONS(7336), 1,
      anon_sym_CARET,
    ACTIONS(7338), 1,
      anon_sym_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP,
    ACTIONS(7344), 1,
      anon_sym_GT_GT,
    ACTIONS(7350), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7352), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7354), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7356), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7358), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7326), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7330), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7332), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7342), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7346), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7348), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5584), 5,
      anon_sym_EQ_GT,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
    STATE(5317), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [69923] = 33,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7190), 1,
      anon_sym_with,
    ACTIONS(7381), 1,
      anon_sym_SLASH,
    ACTIONS(7391), 1,
      anon_sym_GT_GT,
    ACTIONS(7397), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7405), 1,
      anon_sym_as,
    ACTIONS(7407), 1,
      anon_sym_is,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7373), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7377), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7379), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7389), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7395), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    STATE(5318), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 11,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
  [70049] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7258), 1,
      anon_sym_QMARK,
    ACTIONS(7264), 1,
      anon_sym_SLASH,
    ACTIONS(7266), 1,
      anon_sym_CARET,
    ACTIONS(7268), 1,
      anon_sym_PIPE,
    ACTIONS(7270), 1,
      anon_sym_AMP,
    ACTIONS(7274), 1,
      anon_sym_GT_GT,
    ACTIONS(7280), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7282), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7284), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7286), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7288), 1,
      anon_sym_as,
    ACTIONS(7290), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7256), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7260), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7262), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7272), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7276), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7278), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6324), 5,
      anon_sym_COLON,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
    STATE(5319), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [70189] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7190), 1,
      anon_sym_with,
    ACTIONS(7375), 1,
      anon_sym_QMARK,
    ACTIONS(7381), 1,
      anon_sym_SLASH,
    ACTIONS(7383), 1,
      anon_sym_CARET,
    ACTIONS(7385), 1,
      anon_sym_PIPE,
    ACTIONS(7387), 1,
      anon_sym_AMP,
    ACTIONS(7391), 1,
      anon_sym_GT_GT,
    ACTIONS(7397), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7399), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7401), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7403), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7405), 1,
      anon_sym_as,
    ACTIONS(7407), 1,
      anon_sym_is,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7373), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7377), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7379), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7389), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7393), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7395), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6324), 5,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_and,
      anon_sym_or,
    STATE(5320), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [70329] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4593), 1,
      anon_sym_LBRACK,
    ACTIONS(4599), 1,
      anon_sym_STAR,
    ACTIONS(7360), 1,
      anon_sym_QMARK,
    STATE(5321), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4492), 10,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(4494), 27,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [70421] = 37,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7288), 1,
      anon_sym_as,
    ACTIONS(7334), 1,
      anon_sym_SLASH,
    ACTIONS(7336), 1,
      anon_sym_CARET,
    ACTIONS(7338), 1,
      anon_sym_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP,
    ACTIONS(7344), 1,
      anon_sym_GT_GT,
    ACTIONS(7350), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7358), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7326), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7330), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7332), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7342), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7346), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7348), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 8,
      anon_sym_EQ_GT,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
    STATE(5322), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [70555] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7264), 1,
      anon_sym_SLASH,
    ACTIONS(7266), 1,
      anon_sym_CARET,
    ACTIONS(7268), 1,
      anon_sym_PIPE,
    ACTIONS(7270), 1,
      anon_sym_AMP,
    ACTIONS(7274), 1,
      anon_sym_GT_GT,
    ACTIONS(7280), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7282), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7284), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7286), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7288), 1,
      anon_sym_as,
    ACTIONS(7290), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7256), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7260), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7262), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7272), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7276), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7278), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 5,
      anon_sym_COLON,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
    STATE(5323), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [70695] = 29,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7334), 1,
      anon_sym_SLASH,
    ACTIONS(7344), 1,
      anon_sym_GT_GT,
    ACTIONS(7350), 1,
      anon_sym_DOT_DOT,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7330), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7332), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7342), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6344), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    STATE(5324), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 15,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_GT,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
  [70813] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5325), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4482), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(4484), 29,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [70899] = 37,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7190), 1,
      anon_sym_with,
    ACTIONS(7381), 1,
      anon_sym_SLASH,
    ACTIONS(7383), 1,
      anon_sym_CARET,
    ACTIONS(7385), 1,
      anon_sym_PIPE,
    ACTIONS(7387), 1,
      anon_sym_AMP,
    ACTIONS(7391), 1,
      anon_sym_GT_GT,
    ACTIONS(7397), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7405), 1,
      anon_sym_as,
    ACTIONS(7407), 1,
      anon_sym_is,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7373), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7377), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7379), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7389), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7393), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7395), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 8,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(5326), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [71033] = 38,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7190), 1,
      anon_sym_with,
    ACTIONS(7381), 1,
      anon_sym_SLASH,
    ACTIONS(7383), 1,
      anon_sym_CARET,
    ACTIONS(7385), 1,
      anon_sym_PIPE,
    ACTIONS(7387), 1,
      anon_sym_AMP,
    ACTIONS(7391), 1,
      anon_sym_GT_GT,
    ACTIONS(7397), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7399), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7405), 1,
      anon_sym_as,
    ACTIONS(7407), 1,
      anon_sym_is,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7373), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7377), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7379), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7389), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7393), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7395), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 7,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(5327), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [71169] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7258), 1,
      anon_sym_QMARK,
    ACTIONS(7264), 1,
      anon_sym_SLASH,
    ACTIONS(7266), 1,
      anon_sym_CARET,
    ACTIONS(7268), 1,
      anon_sym_PIPE,
    ACTIONS(7270), 1,
      anon_sym_AMP,
    ACTIONS(7274), 1,
      anon_sym_GT_GT,
    ACTIONS(7280), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7282), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7284), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7286), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7288), 1,
      anon_sym_as,
    ACTIONS(7290), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7256), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7260), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7262), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7272), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7276), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7278), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5416), 5,
      anon_sym_COLON,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
    STATE(5328), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [71309] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7258), 1,
      anon_sym_QMARK,
    ACTIONS(7264), 1,
      anon_sym_SLASH,
    ACTIONS(7266), 1,
      anon_sym_CARET,
    ACTIONS(7268), 1,
      anon_sym_PIPE,
    ACTIONS(7270), 1,
      anon_sym_AMP,
    ACTIONS(7274), 1,
      anon_sym_GT_GT,
    ACTIONS(7280), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7282), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7284), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7286), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7288), 1,
      anon_sym_as,
    ACTIONS(7290), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7256), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7260), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7262), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7272), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7276), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7278), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5572), 5,
      anon_sym_COLON,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
    STATE(5329), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [71449] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7190), 1,
      anon_sym_with,
    ACTIONS(7375), 1,
      anon_sym_QMARK,
    ACTIONS(7381), 1,
      anon_sym_SLASH,
    ACTIONS(7383), 1,
      anon_sym_CARET,
    ACTIONS(7385), 1,
      anon_sym_PIPE,
    ACTIONS(7387), 1,
      anon_sym_AMP,
    ACTIONS(7391), 1,
      anon_sym_GT_GT,
    ACTIONS(7397), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7399), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7401), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7403), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7405), 1,
      anon_sym_as,
    ACTIONS(7407), 1,
      anon_sym_is,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7373), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7377), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7379), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7389), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7393), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7395), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5416), 5,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_and,
      anon_sym_or,
    STATE(5330), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [71589] = 35,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7288), 1,
      anon_sym_as,
    ACTIONS(7334), 1,
      anon_sym_SLASH,
    ACTIONS(7340), 1,
      anon_sym_AMP,
    ACTIONS(7344), 1,
      anon_sym_GT_GT,
    ACTIONS(7350), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7358), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(7326), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7330), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7332), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7342), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7346), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7348), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 9,
      anon_sym_CARET,
      anon_sym_EQ_GT,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
    STATE(5331), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [71719] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7190), 1,
      anon_sym_with,
    ACTIONS(7381), 1,
      anon_sym_SLASH,
    ACTIONS(7383), 1,
      anon_sym_CARET,
    ACTIONS(7385), 1,
      anon_sym_PIPE,
    ACTIONS(7387), 1,
      anon_sym_AMP,
    ACTIONS(7391), 1,
      anon_sym_GT_GT,
    ACTIONS(7397), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7399), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7401), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7403), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7405), 1,
      anon_sym_as,
    ACTIONS(7407), 1,
      anon_sym_is,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7373), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7377), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7379), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7389), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7393), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7395), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 5,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_and,
      anon_sym_or,
    STATE(5332), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [71859] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7258), 1,
      anon_sym_QMARK,
    ACTIONS(7264), 1,
      anon_sym_SLASH,
    ACTIONS(7266), 1,
      anon_sym_CARET,
    ACTIONS(7268), 1,
      anon_sym_PIPE,
    ACTIONS(7270), 1,
      anon_sym_AMP,
    ACTIONS(7274), 1,
      anon_sym_GT_GT,
    ACTIONS(7280), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7282), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7284), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7286), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7288), 1,
      anon_sym_as,
    ACTIONS(7290), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7256), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7260), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7262), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7272), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7276), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7278), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5424), 5,
      anon_sym_COLON,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
    STATE(5333), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [71999] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5334), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4554), 12,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_EQ_GT,
    ACTIONS(4552), 28,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_operator,
      anon_sym_this,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      sym_discard,
      anon_sym_and,
      anon_sym_or,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [72085] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5335), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4552), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(4554), 29,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [72171] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5336), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4492), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(4494), 29,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [72257] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(7350), 1,
      anon_sym_DOT_DOT,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6330), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5337), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6328), 21,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_GT,
      anon_sym_switch,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [72361] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5338), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5361), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5359), 29,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [72447] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5339), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4628), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(4630), 29,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [72533] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7258), 1,
      anon_sym_QMARK,
    ACTIONS(7264), 1,
      anon_sym_SLASH,
    ACTIONS(7266), 1,
      anon_sym_CARET,
    ACTIONS(7268), 1,
      anon_sym_PIPE,
    ACTIONS(7270), 1,
      anon_sym_AMP,
    ACTIONS(7274), 1,
      anon_sym_GT_GT,
    ACTIONS(7280), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7282), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7284), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7286), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7288), 1,
      anon_sym_as,
    ACTIONS(7290), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7256), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7260), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7262), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7272), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7276), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7278), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6266), 5,
      anon_sym_COLON,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
    STATE(5340), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [72673] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5341), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4157), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(4168), 29,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [72759] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5342), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4470), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(4472), 29,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [72845] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4806), 6,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_and,
      anon_sym_or,
    STATE(5343), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5630), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5628), 23,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [72933] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7258), 1,
      anon_sym_QMARK,
    ACTIONS(7264), 1,
      anon_sym_SLASH,
    ACTIONS(7266), 1,
      anon_sym_CARET,
    ACTIONS(7268), 1,
      anon_sym_PIPE,
    ACTIONS(7270), 1,
      anon_sym_AMP,
    ACTIONS(7274), 1,
      anon_sym_GT_GT,
    ACTIONS(7280), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7282), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7284), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7286), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7288), 1,
      anon_sym_as,
    ACTIONS(7290), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7256), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7260), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7262), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7272), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7276), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7278), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5644), 5,
      anon_sym_COLON,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
    STATE(5344), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [73073] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5345), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4466), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(4468), 29,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [73159] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7463), 1,
      anon_sym_LT,
    ACTIONS(7465), 1,
      anon_sym_COLON_COLON,
    STATE(2746), 1,
      sym_type_argument_list,
    ACTIONS(4140), 9,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_EQ_GT,
    STATE(5346), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4138), 28,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_operator,
      anon_sym_this,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      sym_discard,
      anon_sym_and,
      anon_sym_or,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [73251] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(7316), 1,
      anon_sym_DOT_DOT,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1229), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5347), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(1227), 21,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [73355] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4145), 1,
      anon_sym_EQ_GT,
    STATE(5348), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5873), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(4310), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [73443] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5349), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4624), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(4626), 29,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [73529] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7258), 1,
      anon_sym_QMARK,
    ACTIONS(7264), 1,
      anon_sym_SLASH,
    ACTIONS(7266), 1,
      anon_sym_CARET,
    ACTIONS(7268), 1,
      anon_sym_PIPE,
    ACTIONS(7270), 1,
      anon_sym_AMP,
    ACTIONS(7274), 1,
      anon_sym_GT_GT,
    ACTIONS(7280), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7282), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7284), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7286), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7288), 1,
      anon_sym_as,
    ACTIONS(7290), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7256), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7260), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7262), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7272), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7276), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7278), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6270), 5,
      anon_sym_COLON,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
    STATE(5350), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [73669] = 26,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4343), 1,
      anon_sym_LBRACE,
    ACTIONS(4359), 1,
      sym_discard,
    ACTIONS(7467), 1,
      sym__identifier_token,
    ACTIONS(7471), 1,
      anon_sym_LPAREN,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(4153), 1,
      sym_parenthesized_variable_designation,
    STATE(4162), 1,
      sym__variable_designation,
    STATE(4163), 1,
      sym_identifier,
    STATE(6139), 1,
      sym_positional_pattern_clause,
    STATE(6746), 1,
      sym_property_pattern_clause,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9890), 1,
      sym__lambda_parameters,
    ACTIONS(4355), 2,
      anon_sym_and,
      anon_sym_or,
    ACTIONS(4357), 4,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(5351), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [73781] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7473), 1,
      aux_sym_raw_string_literal_token1,
    STATE(5352), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5390), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5388), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [73869] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5353), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4546), 12,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_EQ_GT,
    ACTIONS(4544), 28,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_operator,
      anon_sym_this,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      sym_discard,
      anon_sym_and,
      anon_sym_or,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [73955] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5354), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4544), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(4546), 29,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [74041] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7190), 1,
      anon_sym_with,
    ACTIONS(7375), 1,
      anon_sym_QMARK,
    ACTIONS(7381), 1,
      anon_sym_SLASH,
    ACTIONS(7383), 1,
      anon_sym_CARET,
    ACTIONS(7385), 1,
      anon_sym_PIPE,
    ACTIONS(7387), 1,
      anon_sym_AMP,
    ACTIONS(7391), 1,
      anon_sym_GT_GT,
    ACTIONS(7397), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7399), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7401), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7403), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7405), 1,
      anon_sym_as,
    ACTIONS(7407), 1,
      anon_sym_is,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7373), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7377), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7379), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7389), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7393), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7395), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6332), 5,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_and,
      anon_sym_or,
    STATE(5355), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [74181] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(7280), 1,
      anon_sym_DOT_DOT,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1229), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5356), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(1227), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [74285] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5357), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4478), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(4480), 29,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [74371] = 38,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7264), 1,
      anon_sym_SLASH,
    ACTIONS(7266), 1,
      anon_sym_CARET,
    ACTIONS(7268), 1,
      anon_sym_PIPE,
    ACTIONS(7270), 1,
      anon_sym_AMP,
    ACTIONS(7274), 1,
      anon_sym_GT_GT,
    ACTIONS(7280), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7282), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7288), 1,
      anon_sym_as,
    ACTIONS(7290), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7256), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7260), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7262), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7272), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7276), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7278), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 7,
      anon_sym_COLON,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
    STATE(5358), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [74507] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5359), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4126), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(4128), 29,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [74593] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5360), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4431), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(4433), 29,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [74679] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5361), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4134), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(4136), 29,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [74765] = 43,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(2629), 1,
      aux_sym_preproc_else_token1,
    ACTIONS(2631), 1,
      aux_sym_preproc_elif_token1,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7220), 1,
      anon_sym_QMARK,
    ACTIONS(7226), 1,
      anon_sym_SLASH,
    ACTIONS(7228), 1,
      anon_sym_CARET,
    ACTIONS(7230), 1,
      anon_sym_PIPE,
    ACTIONS(7232), 1,
      anon_sym_AMP,
    ACTIONS(7236), 1,
      anon_sym_GT_GT,
    ACTIONS(7242), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7244), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7246), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7248), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(7475), 1,
      aux_sym_preproc_if_token3,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7218), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7222), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7224), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7234), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7238), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7240), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(9616), 2,
      sym_preproc_else_in_expression,
      sym_preproc_elif_in_expression,
    STATE(5362), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [74911] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(7300), 1,
      anon_sym_SLASH,
    ACTIONS(7316), 1,
      anon_sym_DOT_DOT,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7296), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7298), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5363), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 17,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
  [75025] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(7280), 1,
      anon_sym_DOT_DOT,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6330), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5364), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6328), 21,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [75129] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7411), 1,
      anon_sym_LBRACK,
    ACTIONS(7413), 1,
      anon_sym_QMARK,
    ACTIONS(7415), 1,
      anon_sym_STAR,
    ACTIONS(7477), 1,
      anon_sym_DOT,
    ACTIONS(4494), 8,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_EQ_GT,
    STATE(5365), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4492), 28,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_operator,
      anon_sym_this,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      sym_discard,
      anon_sym_and,
      anon_sym_or,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [75223] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7479), 1,
      sym_string_literal_encoding,
    STATE(5366), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5365), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5363), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [75311] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7481), 1,
      sym_string_literal_encoding,
    STATE(5367), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5384), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5382), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [75399] = 43,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(2629), 1,
      aux_sym_preproc_else_token1,
    ACTIONS(2631), 1,
      aux_sym_preproc_elif_token1,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7220), 1,
      anon_sym_QMARK,
    ACTIONS(7226), 1,
      anon_sym_SLASH,
    ACTIONS(7228), 1,
      anon_sym_CARET,
    ACTIONS(7230), 1,
      anon_sym_PIPE,
    ACTIONS(7232), 1,
      anon_sym_AMP,
    ACTIONS(7236), 1,
      anon_sym_GT_GT,
    ACTIONS(7242), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7244), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7246), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7248), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(7483), 1,
      aux_sym_preproc_if_token3,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7218), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7222), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7224), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7234), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7238), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7240), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(9007), 2,
      sym_preproc_else_in_expression,
      sym_preproc_elif_in_expression,
    STATE(5368), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [75545] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6837), 1,
      anon_sym_as,
    ACTIONS(7294), 1,
      anon_sym_QMARK,
    ACTIONS(7300), 1,
      anon_sym_SLASH,
    ACTIONS(7302), 1,
      anon_sym_CARET,
    ACTIONS(7304), 1,
      anon_sym_PIPE,
    ACTIONS(7306), 1,
      anon_sym_AMP,
    ACTIONS(7310), 1,
      anon_sym_GT_GT,
    ACTIONS(7316), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7318), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7320), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7322), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7324), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7292), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7296), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7298), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7308), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7312), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7314), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6324), 5,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_into,
    STATE(5369), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [75685] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7258), 1,
      anon_sym_QMARK,
    ACTIONS(7264), 1,
      anon_sym_SLASH,
    ACTIONS(7266), 1,
      anon_sym_CARET,
    ACTIONS(7268), 1,
      anon_sym_PIPE,
    ACTIONS(7270), 1,
      anon_sym_AMP,
    ACTIONS(7274), 1,
      anon_sym_GT_GT,
    ACTIONS(7280), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7282), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7284), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7286), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7288), 1,
      anon_sym_as,
    ACTIONS(7290), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7256), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7260), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7262), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7272), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7276), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7278), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5584), 5,
      anon_sym_COLON,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
    STATE(5370), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [75825] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7417), 1,
      anon_sym_and,
    STATE(5371), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6707), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6705), 28,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [75913] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7258), 1,
      anon_sym_QMARK,
    ACTIONS(7264), 1,
      anon_sym_SLASH,
    ACTIONS(7266), 1,
      anon_sym_CARET,
    ACTIONS(7268), 1,
      anon_sym_PIPE,
    ACTIONS(7270), 1,
      anon_sym_AMP,
    ACTIONS(7274), 1,
      anon_sym_GT_GT,
    ACTIONS(7280), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7282), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7284), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7286), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7288), 1,
      anon_sym_as,
    ACTIONS(7290), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7256), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7260), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7262), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7272), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7276), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7278), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5624), 5,
      anon_sym_COLON,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
    STATE(5372), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [76053] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(6596), 1,
      anon_sym_ref,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(2883), 1,
      sym_ref_type,
    STATE(2885), 1,
      sym__scoped_base_type,
    STATE(5346), 1,
      sym_identifier,
    STATE(6202), 1,
      sym__name,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    ACTIONS(3993), 7,
      anon_sym_LBRACK,
      anon_sym_RPAREN,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_STAR,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
    STATE(5373), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [76157] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(7316), 1,
      anon_sym_DOT_DOT,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6330), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5374), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6328), 21,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [76261] = 26,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7190), 1,
      anon_sym_with,
    ACTIONS(7381), 1,
      anon_sym_SLASH,
    ACTIONS(7397), 1,
      anon_sym_DOT_DOT,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7379), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5375), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 17,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
  [76373] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7350), 1,
      anon_sym_DOT_DOT,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5376), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 19,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_GT,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
  [76481] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5377), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4149), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(4151), 29,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [76567] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7288), 1,
      anon_sym_as,
    ACTIONS(7328), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 1,
      anon_sym_SLASH,
    ACTIONS(7336), 1,
      anon_sym_CARET,
    ACTIONS(7338), 1,
      anon_sym_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP,
    ACTIONS(7344), 1,
      anon_sym_GT_GT,
    ACTIONS(7350), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7352), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7354), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7356), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7358), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7326), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7330), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7332), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7342), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7346), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7348), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6332), 5,
      anon_sym_EQ_GT,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
    STATE(5378), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [76707] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7371), 1,
      anon_sym_DOT,
    STATE(5379), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4453), 10,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    ACTIONS(4455), 29,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [76795] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7288), 1,
      anon_sym_as,
    ACTIONS(7328), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 1,
      anon_sym_SLASH,
    ACTIONS(7336), 1,
      anon_sym_CARET,
    ACTIONS(7338), 1,
      anon_sym_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP,
    ACTIONS(7344), 1,
      anon_sym_GT_GT,
    ACTIONS(7350), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7352), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7354), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7356), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7358), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7326), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7330), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7332), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7342), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7346), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7348), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5644), 5,
      anon_sym_EQ_GT,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
    STATE(5380), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [76935] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7190), 1,
      anon_sym_with,
    ACTIONS(7375), 1,
      anon_sym_QMARK,
    ACTIONS(7381), 1,
      anon_sym_SLASH,
    ACTIONS(7383), 1,
      anon_sym_CARET,
    ACTIONS(7385), 1,
      anon_sym_PIPE,
    ACTIONS(7387), 1,
      anon_sym_AMP,
    ACTIONS(7391), 1,
      anon_sym_GT_GT,
    ACTIONS(7397), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7399), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7401), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7403), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7405), 1,
      anon_sym_as,
    ACTIONS(7407), 1,
      anon_sym_is,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7373), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7377), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7379), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7389), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7393), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7395), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5644), 5,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_and,
      anon_sym_or,
    STATE(5381), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [77075] = 38,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7288), 1,
      anon_sym_as,
    ACTIONS(7334), 1,
      anon_sym_SLASH,
    ACTIONS(7336), 1,
      anon_sym_CARET,
    ACTIONS(7338), 1,
      anon_sym_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP,
    ACTIONS(7344), 1,
      anon_sym_GT_GT,
    ACTIONS(7350), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7352), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7358), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7326), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7330), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7332), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7342), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7346), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7348), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 7,
      anon_sym_EQ_GT,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
    STATE(5382), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [77211] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5383), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5355), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5353), 29,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [77297] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5384), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4502), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(4504), 29,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [77383] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7411), 1,
      anon_sym_LBRACK,
    ACTIONS(7415), 1,
      anon_sym_STAR,
    STATE(5385), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4494), 10,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_EQ_GT,
    ACTIONS(4492), 28,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_operator,
      anon_sym_this,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      sym_discard,
      anon_sym_and,
      anon_sym_or,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [77473] = 35,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7264), 1,
      anon_sym_SLASH,
    ACTIONS(7270), 1,
      anon_sym_AMP,
    ACTIONS(7274), 1,
      anon_sym_GT_GT,
    ACTIONS(7280), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7288), 1,
      anon_sym_as,
    ACTIONS(7290), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(7256), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7260), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7262), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7272), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7276), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7278), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 9,
      anon_sym_COLON,
      anon_sym_CARET,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
    STATE(5386), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [77603] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7463), 1,
      anon_sym_LT,
    STATE(2746), 1,
      sym_type_argument_list,
    STATE(5387), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4140), 10,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DOT,
      anon_sym_EQ_GT,
    ACTIONS(4138), 28,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_operator,
      anon_sym_this,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      sym_discard,
      anon_sym_and,
      anon_sym_or,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [77693] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7485), 1,
      anon_sym_into,
    STATE(5389), 1,
      aux_sym__query_body_repeat2,
    STATE(5388), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6476), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6474), 27,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [77783] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7485), 1,
      anon_sym_into,
    STATE(5391), 1,
      aux_sym__query_body_repeat2,
    STATE(5389), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6482), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6480), 27,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [77873] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7485), 1,
      anon_sym_into,
    STATE(5392), 1,
      aux_sym__query_body_repeat2,
    STATE(5390), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6482), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6480), 27,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [77963] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7487), 1,
      anon_sym_into,
    STATE(5391), 10,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
      aux_sym__query_body_repeat2,
    ACTIONS(6486), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6484), 27,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [78051] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7485), 1,
      anon_sym_into,
    STATE(5391), 1,
      aux_sym__query_body_repeat2,
    STATE(5392), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6493), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6491), 27,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [78141] = 34,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7288), 1,
      anon_sym_as,
    ACTIONS(7334), 1,
      anon_sym_SLASH,
    ACTIONS(7344), 1,
      anon_sym_GT_GT,
    ACTIONS(7350), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7358), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7326), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7330), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7332), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7342), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7346), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7348), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(6342), 9,
      anon_sym_CARET,
      anon_sym_EQ_GT,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
    STATE(5393), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [78269] = 33,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7288), 1,
      anon_sym_as,
    ACTIONS(7334), 1,
      anon_sym_SLASH,
    ACTIONS(7344), 1,
      anon_sym_GT_GT,
    ACTIONS(7350), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7358), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7326), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7330), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7332), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7342), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7348), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    STATE(5394), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 11,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_GT,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
  [78395] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7397), 1,
      anon_sym_DOT_DOT,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1229), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5395), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(1227), 21,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [78499] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7190), 1,
      anon_sym_with,
    ACTIONS(7375), 1,
      anon_sym_QMARK,
    ACTIONS(7381), 1,
      anon_sym_SLASH,
    ACTIONS(7383), 1,
      anon_sym_CARET,
    ACTIONS(7385), 1,
      anon_sym_PIPE,
    ACTIONS(7387), 1,
      anon_sym_AMP,
    ACTIONS(7391), 1,
      anon_sym_GT_GT,
    ACTIONS(7397), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7399), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7401), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7403), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7405), 1,
      anon_sym_as,
    ACTIONS(7407), 1,
      anon_sym_is,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7373), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7377), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7379), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7389), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7393), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7395), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5624), 5,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_and,
      anon_sym_or,
    STATE(5396), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [78639] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6837), 1,
      anon_sym_as,
    ACTIONS(7294), 1,
      anon_sym_QMARK,
    ACTIONS(7300), 1,
      anon_sym_SLASH,
    ACTIONS(7302), 1,
      anon_sym_CARET,
    ACTIONS(7304), 1,
      anon_sym_PIPE,
    ACTIONS(7306), 1,
      anon_sym_AMP,
    ACTIONS(7310), 1,
      anon_sym_GT_GT,
    ACTIONS(7316), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7318), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7320), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7322), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7324), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7292), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7296), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7298), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7308), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7312), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7314), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5644), 5,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_into,
    STATE(5397), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [78779] = 33,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6837), 1,
      anon_sym_as,
    ACTIONS(7300), 1,
      anon_sym_SLASH,
    ACTIONS(7310), 1,
      anon_sym_GT_GT,
    ACTIONS(7316), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7324), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7292), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7296), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7298), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7308), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7314), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    STATE(5398), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 11,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
  [78905] = 36,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7264), 1,
      anon_sym_SLASH,
    ACTIONS(7266), 1,
      anon_sym_CARET,
    ACTIONS(7270), 1,
      anon_sym_AMP,
    ACTIONS(7274), 1,
      anon_sym_GT_GT,
    ACTIONS(7280), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7288), 1,
      anon_sym_as,
    ACTIONS(7290), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(7256), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7260), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7262), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7272), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7276), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7278), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 8,
      anon_sym_COLON,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
    STATE(5399), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [79037] = 43,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(2629), 1,
      aux_sym_preproc_else_token1,
    ACTIONS(2631), 1,
      aux_sym_preproc_elif_token1,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7220), 1,
      anon_sym_QMARK,
    ACTIONS(7226), 1,
      anon_sym_SLASH,
    ACTIONS(7228), 1,
      anon_sym_CARET,
    ACTIONS(7230), 1,
      anon_sym_PIPE,
    ACTIONS(7232), 1,
      anon_sym_AMP,
    ACTIONS(7236), 1,
      anon_sym_GT_GT,
    ACTIONS(7242), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7244), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7246), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7248), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(7490), 1,
      aux_sym_preproc_if_token3,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7218), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7222), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7224), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7234), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7238), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7240), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(9428), 2,
      sym_preproc_else_in_expression,
      sym_preproc_elif_in_expression,
    STATE(5400), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [79183] = 34,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7264), 1,
      anon_sym_SLASH,
    ACTIONS(7274), 1,
      anon_sym_GT_GT,
    ACTIONS(7280), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7288), 1,
      anon_sym_as,
    ACTIONS(7290), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7256), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7260), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7262), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7272), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7276), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7278), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(6342), 9,
      anon_sym_COLON,
      anon_sym_CARET,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
    STATE(5401), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [79311] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7417), 1,
      anon_sym_and,
    ACTIONS(7419), 1,
      anon_sym_or,
    STATE(5402), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5881), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5879), 27,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [79401] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7288), 1,
      anon_sym_as,
    ACTIONS(7334), 1,
      anon_sym_SLASH,
    ACTIONS(7336), 1,
      anon_sym_CARET,
    ACTIONS(7338), 1,
      anon_sym_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP,
    ACTIONS(7344), 1,
      anon_sym_GT_GT,
    ACTIONS(7350), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7352), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7354), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7356), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7358), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7326), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7330), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7332), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7342), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7346), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7348), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 5,
      anon_sym_EQ_GT,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
    STATE(5403), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [79541] = 36,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7288), 1,
      anon_sym_as,
    ACTIONS(7334), 1,
      anon_sym_SLASH,
    ACTIONS(7336), 1,
      anon_sym_CARET,
    ACTIONS(7340), 1,
      anon_sym_AMP,
    ACTIONS(7344), 1,
      anon_sym_GT_GT,
    ACTIONS(7350), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7358), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(7326), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7330), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7332), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7342), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7346), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7348), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 8,
      anon_sym_EQ_GT,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
    STATE(5404), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [79673] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7288), 1,
      anon_sym_as,
    ACTIONS(7328), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 1,
      anon_sym_SLASH,
    ACTIONS(7336), 1,
      anon_sym_CARET,
    ACTIONS(7338), 1,
      anon_sym_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP,
    ACTIONS(7344), 1,
      anon_sym_GT_GT,
    ACTIONS(7350), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7352), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7354), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7356), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7358), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7326), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7330), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7332), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7342), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7346), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7348), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6266), 5,
      anon_sym_EQ_GT,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
    STATE(5405), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [79813] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3193), 1,
      sym__identifier_token,
    ACTIONS(3205), 1,
      anon_sym_LPAREN,
    ACTIONS(4002), 1,
      anon_sym_delegate,
    ACTIONS(7194), 1,
      sym_predefined_type,
    STATE(4513), 1,
      sym__reserved_identifier,
    STATE(4947), 1,
      sym_identifier,
    STATE(5019), 1,
      sym_generic_name,
    STATE(7169), 1,
      sym_array_type,
    STATE(7180), 1,
      sym_nullable_type,
    STATE(8318), 1,
      sym__name,
    STATE(8527), 1,
      sym_tuple_type,
    STATE(8852), 1,
      sym__array_base_type,
    STATE(9443), 1,
      sym__pointer_base_type,
    STATE(8717), 2,
      sym_pointer_type,
      sym_function_pointer_type,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(5406), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3197), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [79927] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(7350), 1,
      anon_sym_DOT_DOT,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1229), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5407), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(1227), 21,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_GT,
      anon_sym_switch,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [80031] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5408), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4138), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(4140), 29,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [80117] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7365), 1,
      anon_sym_and,
    ACTIONS(7369), 1,
      anon_sym_or,
    STATE(5409), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5881), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5879), 27,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [80207] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6837), 1,
      anon_sym_as,
    ACTIONS(7294), 1,
      anon_sym_QMARK,
    ACTIONS(7300), 1,
      anon_sym_SLASH,
    ACTIONS(7302), 1,
      anon_sym_CARET,
    ACTIONS(7304), 1,
      anon_sym_PIPE,
    ACTIONS(7306), 1,
      anon_sym_AMP,
    ACTIONS(7310), 1,
      anon_sym_GT_GT,
    ACTIONS(7316), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7318), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7320), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7322), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7324), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7292), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7296), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7298), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7308), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7312), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7314), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6266), 5,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_into,
    STATE(5410), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [80347] = 33,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7264), 1,
      anon_sym_SLASH,
    ACTIONS(7274), 1,
      anon_sym_GT_GT,
    ACTIONS(7280), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7288), 1,
      anon_sym_as,
    ACTIONS(7290), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7256), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7260), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7262), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7272), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7278), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    STATE(5411), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 11,
      anon_sym_COLON,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
  [80473] = 37,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7264), 1,
      anon_sym_SLASH,
    ACTIONS(7266), 1,
      anon_sym_CARET,
    ACTIONS(7268), 1,
      anon_sym_PIPE,
    ACTIONS(7270), 1,
      anon_sym_AMP,
    ACTIONS(7274), 1,
      anon_sym_GT_GT,
    ACTIONS(7280), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7288), 1,
      anon_sym_as,
    ACTIONS(7290), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7256), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7260), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7262), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7272), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7276), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7278), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 8,
      anon_sym_COLON,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
    STATE(5412), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [80607] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7190), 1,
      anon_sym_with,
    ACTIONS(7375), 1,
      anon_sym_QMARK,
    ACTIONS(7381), 1,
      anon_sym_SLASH,
    ACTIONS(7383), 1,
      anon_sym_CARET,
    ACTIONS(7385), 1,
      anon_sym_PIPE,
    ACTIONS(7387), 1,
      anon_sym_AMP,
    ACTIONS(7391), 1,
      anon_sym_GT_GT,
    ACTIONS(7397), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7399), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7401), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7403), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7405), 1,
      anon_sym_as,
    ACTIONS(7407), 1,
      anon_sym_is,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7373), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7377), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7379), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7389), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7393), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7395), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6320), 5,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_and,
      anon_sym_or,
    STATE(5413), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [80747] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7288), 1,
      anon_sym_as,
    ACTIONS(7328), 1,
      anon_sym_QMARK,
    ACTIONS(7334), 1,
      anon_sym_SLASH,
    ACTIONS(7336), 1,
      anon_sym_CARET,
    ACTIONS(7338), 1,
      anon_sym_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP,
    ACTIONS(7344), 1,
      anon_sym_GT_GT,
    ACTIONS(7350), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7352), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7354), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7356), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7358), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7326), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7330), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7332), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7342), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7346), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7348), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5624), 5,
      anon_sym_EQ_GT,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
    STATE(5414), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [80887] = 34,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7498), 1,
      anon_sym_SLASH,
    ACTIONS(7502), 1,
      anon_sym_GT_GT,
    ACTIONS(7508), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7510), 1,
      anon_sym_as,
    ACTIONS(7512), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7492), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7494), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7496), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7500), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7504), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7506), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(6342), 8,
      anon_sym_CARET,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_equals,
    STATE(5415), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [81014] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(7516), 1,
      anon_sym_QMARK,
    ACTIONS(7522), 1,
      anon_sym_SLASH,
    ACTIONS(7524), 1,
      anon_sym_CARET,
    ACTIONS(7526), 1,
      anon_sym_PIPE,
    ACTIONS(7528), 1,
      anon_sym_AMP,
    ACTIONS(7532), 1,
      anon_sym_GT_GT,
    ACTIONS(7538), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7540), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7542), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7544), 1,
      anon_sym_QMARK_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7514), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7518), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7520), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7530), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7534), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7536), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5624), 4,
      anon_sym_SEMI,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
    STATE(5416), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [81153] = 29,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7550), 1,
      anon_sym_SLASH,
    ACTIONS(7554), 1,
      anon_sym_GT_GT,
    ACTIONS(7556), 1,
      anon_sym_DOT_DOT,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7546), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7552), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6344), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    STATE(5417), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 14,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_GT,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
  [81270] = 26,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7550), 1,
      anon_sym_SLASH,
    ACTIONS(7556), 1,
      anon_sym_DOT_DOT,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5418), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 16,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_GT,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
  [81381] = 35,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7550), 1,
      anon_sym_SLASH,
    ACTIONS(7554), 1,
      anon_sym_GT_GT,
    ACTIONS(7556), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7560), 1,
      anon_sym_AMP,
    ACTIONS(7566), 1,
      anon_sym_as,
    ACTIONS(7568), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(7546), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7552), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7558), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7562), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 8,
      anon_sym_CARET,
      anon_sym_EQ_GT,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(5419), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [81510] = 36,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7550), 1,
      anon_sym_SLASH,
    ACTIONS(7554), 1,
      anon_sym_GT_GT,
    ACTIONS(7556), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7560), 1,
      anon_sym_AMP,
    ACTIONS(7566), 1,
      anon_sym_as,
    ACTIONS(7568), 1,
      anon_sym_is,
    ACTIONS(7570), 1,
      anon_sym_CARET,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(7546), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7552), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7558), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7562), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 7,
      anon_sym_EQ_GT,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(5420), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [81641] = 34,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7550), 1,
      anon_sym_SLASH,
    ACTIONS(7554), 1,
      anon_sym_GT_GT,
    ACTIONS(7556), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7566), 1,
      anon_sym_as,
    ACTIONS(7568), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7546), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7552), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7558), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7562), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(6342), 8,
      anon_sym_CARET,
      anon_sym_EQ_GT,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(5421), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [81768] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7550), 1,
      anon_sym_SLASH,
    ACTIONS(7556), 1,
      anon_sym_DOT_DOT,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7546), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5422), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 16,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_GT,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
  [81881] = 33,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7550), 1,
      anon_sym_SLASH,
    ACTIONS(7554), 1,
      anon_sym_GT_GT,
    ACTIONS(7556), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7566), 1,
      anon_sym_as,
    ACTIONS(7568), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7546), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7552), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7558), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    STATE(5423), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 10,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_GT,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
  [82006] = 37,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7550), 1,
      anon_sym_SLASH,
    ACTIONS(7554), 1,
      anon_sym_GT_GT,
    ACTIONS(7556), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7560), 1,
      anon_sym_AMP,
    ACTIONS(7566), 1,
      anon_sym_as,
    ACTIONS(7568), 1,
      anon_sym_is,
    ACTIONS(7570), 1,
      anon_sym_CARET,
    ACTIONS(7572), 1,
      anon_sym_PIPE,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7546), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7552), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7558), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7562), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 7,
      anon_sym_EQ_GT,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(5424), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [82139] = 38,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7550), 1,
      anon_sym_SLASH,
    ACTIONS(7554), 1,
      anon_sym_GT_GT,
    ACTIONS(7556), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7560), 1,
      anon_sym_AMP,
    ACTIONS(7566), 1,
      anon_sym_as,
    ACTIONS(7568), 1,
      anon_sym_is,
    ACTIONS(7570), 1,
      anon_sym_CARET,
    ACTIONS(7572), 1,
      anon_sym_PIPE,
    ACTIONS(7574), 1,
      anon_sym_AMP_AMP,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7546), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7552), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7558), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7562), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 6,
      anon_sym_EQ_GT,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(5425), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [82274] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7550), 1,
      anon_sym_SLASH,
    ACTIONS(7554), 1,
      anon_sym_GT_GT,
    ACTIONS(7556), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7560), 1,
      anon_sym_AMP,
    ACTIONS(7566), 1,
      anon_sym_as,
    ACTIONS(7568), 1,
      anon_sym_is,
    ACTIONS(7570), 1,
      anon_sym_CARET,
    ACTIONS(7572), 1,
      anon_sym_PIPE,
    ACTIONS(7574), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7576), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7578), 1,
      anon_sym_QMARK_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7546), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7552), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7558), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7562), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 4,
      anon_sym_EQ_GT,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
    STATE(5426), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [82413] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5427), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5944), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5942), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [82498] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5428), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5948), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5946), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [82583] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5429), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5958), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5956), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [82668] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5430), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5930), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5928), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [82753] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5431), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5930), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5928), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [82838] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5432), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5911), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5909), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [82923] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5433), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5940), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5938), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [83008] = 21,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(5346), 1,
      sym_identifier,
    STATE(6817), 1,
      sym_attribute_target_specifier,
    STATE(8073), 1,
      sym__name,
    STATE(8445), 1,
      sym_attribute,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    ACTIONS(1069), 7,
      anon_sym_field,
      anon_sym_event,
      anon_sym_method,
      anon_sym_param,
      anon_sym_property,
      anon_sym_return,
      anon_sym_type,
    STATE(5434), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [83109] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5435), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5897), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5895), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [83194] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5436), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5934), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5932), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [83279] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5437), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5848), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5846), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [83364] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5438), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5871), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5869), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [83449] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5439), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5877), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5875), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [83534] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7550), 1,
      anon_sym_SLASH,
    ACTIONS(7554), 1,
      anon_sym_GT_GT,
    ACTIONS(7556), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7560), 1,
      anon_sym_AMP,
    ACTIONS(7566), 1,
      anon_sym_as,
    ACTIONS(7568), 1,
      anon_sym_is,
    ACTIONS(7570), 1,
      anon_sym_CARET,
    ACTIONS(7572), 1,
      anon_sym_PIPE,
    ACTIONS(7574), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7576), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7578), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7580), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7546), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7552), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7558), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7562), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6320), 4,
      anon_sym_EQ_GT,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
    STATE(5440), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [83673] = 35,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7186), 1,
      anon_sym_as,
    ACTIONS(7190), 1,
      anon_sym_with,
    ACTIONS(7588), 1,
      anon_sym_SLASH,
    ACTIONS(7590), 1,
      anon_sym_AMP,
    ACTIONS(7594), 1,
      anon_sym_GT_GT,
    ACTIONS(7600), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7602), 1,
      anon_sym_is,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7584), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7586), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7592), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7596), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7598), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 8,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
    STATE(5441), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [83802] = 36,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7186), 1,
      anon_sym_as,
    ACTIONS(7190), 1,
      anon_sym_with,
    ACTIONS(7588), 1,
      anon_sym_SLASH,
    ACTIONS(7590), 1,
      anon_sym_AMP,
    ACTIONS(7594), 1,
      anon_sym_GT_GT,
    ACTIONS(7600), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7602), 1,
      anon_sym_is,
    ACTIONS(7604), 1,
      anon_sym_CARET,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7584), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7586), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7592), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7596), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7598), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 7,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
    STATE(5442), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [83933] = 34,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7186), 1,
      anon_sym_as,
    ACTIONS(7190), 1,
      anon_sym_with,
    ACTIONS(7588), 1,
      anon_sym_SLASH,
    ACTIONS(7594), 1,
      anon_sym_GT_GT,
    ACTIONS(7600), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7602), 1,
      anon_sym_is,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7584), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7586), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7592), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7596), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7598), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(6342), 8,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
    STATE(5443), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [84060] = 33,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7186), 1,
      anon_sym_as,
    ACTIONS(7190), 1,
      anon_sym_with,
    ACTIONS(7588), 1,
      anon_sym_SLASH,
    ACTIONS(7594), 1,
      anon_sym_GT_GT,
    ACTIONS(7600), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7602), 1,
      anon_sym_is,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7584), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7586), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7592), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7598), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    STATE(5444), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 10,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
  [84185] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(7556), 1,
      anon_sym_DOT_DOT,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6330), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5445), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6328), 20,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_GT,
      anon_sym_switch,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [84288] = 37,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7186), 1,
      anon_sym_as,
    ACTIONS(7190), 1,
      anon_sym_with,
    ACTIONS(7588), 1,
      anon_sym_SLASH,
    ACTIONS(7590), 1,
      anon_sym_AMP,
    ACTIONS(7594), 1,
      anon_sym_GT_GT,
    ACTIONS(7600), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7602), 1,
      anon_sym_is,
    ACTIONS(7604), 1,
      anon_sym_CARET,
    ACTIONS(7606), 1,
      anon_sym_PIPE,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7584), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7586), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7592), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7596), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7598), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 7,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
    STATE(5446), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [84421] = 38,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7186), 1,
      anon_sym_as,
    ACTIONS(7190), 1,
      anon_sym_with,
    ACTIONS(7588), 1,
      anon_sym_SLASH,
    ACTIONS(7590), 1,
      anon_sym_AMP,
    ACTIONS(7594), 1,
      anon_sym_GT_GT,
    ACTIONS(7600), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7602), 1,
      anon_sym_is,
    ACTIONS(7604), 1,
      anon_sym_CARET,
    ACTIONS(7606), 1,
      anon_sym_PIPE,
    ACTIONS(7608), 1,
      anon_sym_AMP_AMP,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7584), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7586), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7592), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7596), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7598), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 6,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
    STATE(5447), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [84556] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7186), 1,
      anon_sym_as,
    ACTIONS(7190), 1,
      anon_sym_with,
    ACTIONS(7588), 1,
      anon_sym_SLASH,
    ACTIONS(7590), 1,
      anon_sym_AMP,
    ACTIONS(7594), 1,
      anon_sym_GT_GT,
    ACTIONS(7600), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7602), 1,
      anon_sym_is,
    ACTIONS(7604), 1,
      anon_sym_CARET,
    ACTIONS(7606), 1,
      anon_sym_PIPE,
    ACTIONS(7608), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7610), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7612), 1,
      anon_sym_QMARK_QMARK,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7584), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7586), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7592), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7596), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7598), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 4,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_into,
    STATE(5448), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [84695] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7550), 1,
      anon_sym_SLASH,
    ACTIONS(7554), 1,
      anon_sym_GT_GT,
    ACTIONS(7556), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7560), 1,
      anon_sym_AMP,
    ACTIONS(7566), 1,
      anon_sym_as,
    ACTIONS(7568), 1,
      anon_sym_is,
    ACTIONS(7570), 1,
      anon_sym_CARET,
    ACTIONS(7572), 1,
      anon_sym_PIPE,
    ACTIONS(7574), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7576), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7578), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7580), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7546), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7552), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7558), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7562), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6324), 4,
      anon_sym_EQ_GT,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
    STATE(5449), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [84834] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7550), 1,
      anon_sym_SLASH,
    ACTIONS(7554), 1,
      anon_sym_GT_GT,
    ACTIONS(7556), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7560), 1,
      anon_sym_AMP,
    ACTIONS(7566), 1,
      anon_sym_as,
    ACTIONS(7568), 1,
      anon_sym_is,
    ACTIONS(7570), 1,
      anon_sym_CARET,
    ACTIONS(7572), 1,
      anon_sym_PIPE,
    ACTIONS(7574), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7576), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7578), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7580), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7546), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7552), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7558), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7562), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5416), 4,
      anon_sym_EQ_GT,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
    STATE(5450), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [84973] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7550), 1,
      anon_sym_SLASH,
    ACTIONS(7554), 1,
      anon_sym_GT_GT,
    ACTIONS(7556), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7560), 1,
      anon_sym_AMP,
    ACTIONS(7566), 1,
      anon_sym_as,
    ACTIONS(7568), 1,
      anon_sym_is,
    ACTIONS(7570), 1,
      anon_sym_CARET,
    ACTIONS(7572), 1,
      anon_sym_PIPE,
    ACTIONS(7574), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7576), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7578), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7580), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7546), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7552), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7558), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7562), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5644), 4,
      anon_sym_EQ_GT,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
    STATE(5451), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [85112] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7550), 1,
      anon_sym_SLASH,
    ACTIONS(7554), 1,
      anon_sym_GT_GT,
    ACTIONS(7556), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7560), 1,
      anon_sym_AMP,
    ACTIONS(7566), 1,
      anon_sym_as,
    ACTIONS(7568), 1,
      anon_sym_is,
    ACTIONS(7570), 1,
      anon_sym_CARET,
    ACTIONS(7572), 1,
      anon_sym_PIPE,
    ACTIONS(7574), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7576), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7578), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7580), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7546), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7552), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7558), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7562), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5424), 4,
      anon_sym_EQ_GT,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
    STATE(5452), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [85251] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7411), 1,
      anon_sym_LBRACK,
    ACTIONS(7413), 1,
      anon_sym_QMARK,
    ACTIONS(7415), 1,
      anon_sym_STAR,
    ACTIONS(4604), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    ACTIONS(4494), 8,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_EQ_GT,
    STATE(5453), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4492), 26,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      sym_discard,
      anon_sym_and,
      anon_sym_or,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [85344] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7550), 1,
      anon_sym_SLASH,
    ACTIONS(7554), 1,
      anon_sym_GT_GT,
    ACTIONS(7556), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7560), 1,
      anon_sym_AMP,
    ACTIONS(7566), 1,
      anon_sym_as,
    ACTIONS(7568), 1,
      anon_sym_is,
    ACTIONS(7570), 1,
      anon_sym_CARET,
    ACTIONS(7572), 1,
      anon_sym_PIPE,
    ACTIONS(7574), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7576), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7578), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7580), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7546), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7552), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7558), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7562), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6336), 4,
      anon_sym_EQ_GT,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
    STATE(5454), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [85483] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7550), 1,
      anon_sym_SLASH,
    ACTIONS(7554), 1,
      anon_sym_GT_GT,
    ACTIONS(7556), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7560), 1,
      anon_sym_AMP,
    ACTIONS(7566), 1,
      anon_sym_as,
    ACTIONS(7568), 1,
      anon_sym_is,
    ACTIONS(7570), 1,
      anon_sym_CARET,
    ACTIONS(7572), 1,
      anon_sym_PIPE,
    ACTIONS(7574), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7576), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7578), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7580), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7546), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7552), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7558), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7562), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5572), 4,
      anon_sym_EQ_GT,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
    STATE(5455), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [85622] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7550), 1,
      anon_sym_SLASH,
    ACTIONS(7554), 1,
      anon_sym_GT_GT,
    ACTIONS(7556), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7560), 1,
      anon_sym_AMP,
    ACTIONS(7566), 1,
      anon_sym_as,
    ACTIONS(7568), 1,
      anon_sym_is,
    ACTIONS(7570), 1,
      anon_sym_CARET,
    ACTIONS(7572), 1,
      anon_sym_PIPE,
    ACTIONS(7574), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7576), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7578), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7580), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7546), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7552), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7558), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7562), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5584), 4,
      anon_sym_EQ_GT,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
    STATE(5456), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [85761] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7550), 1,
      anon_sym_SLASH,
    ACTIONS(7554), 1,
      anon_sym_GT_GT,
    ACTIONS(7556), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7560), 1,
      anon_sym_AMP,
    ACTIONS(7566), 1,
      anon_sym_as,
    ACTIONS(7568), 1,
      anon_sym_is,
    ACTIONS(7570), 1,
      anon_sym_CARET,
    ACTIONS(7572), 1,
      anon_sym_PIPE,
    ACTIONS(7574), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7576), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7578), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7580), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7546), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7552), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7558), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7562), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5624), 4,
      anon_sym_EQ_GT,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
    STATE(5457), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [85900] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7550), 1,
      anon_sym_SLASH,
    ACTIONS(7554), 1,
      anon_sym_GT_GT,
    ACTIONS(7556), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7560), 1,
      anon_sym_AMP,
    ACTIONS(7566), 1,
      anon_sym_as,
    ACTIONS(7568), 1,
      anon_sym_is,
    ACTIONS(7570), 1,
      anon_sym_CARET,
    ACTIONS(7572), 1,
      anon_sym_PIPE,
    ACTIONS(7574), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7576), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7578), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7580), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7546), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7552), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7558), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7562), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6190), 4,
      anon_sym_EQ_GT,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
    STATE(5458), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [86039] = 35,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7620), 1,
      anon_sym_SLASH,
    ACTIONS(7622), 1,
      anon_sym_AMP,
    ACTIONS(7626), 1,
      anon_sym_GT_GT,
    ACTIONS(7632), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7634), 1,
      anon_sym_as,
    ACTIONS(7636), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(7614), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7616), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7618), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7624), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7628), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7630), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 8,
      anon_sym_CARET,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_by,
    STATE(5459), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [86168] = 36,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7620), 1,
      anon_sym_SLASH,
    ACTIONS(7622), 1,
      anon_sym_AMP,
    ACTIONS(7626), 1,
      anon_sym_GT_GT,
    ACTIONS(7632), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7634), 1,
      anon_sym_as,
    ACTIONS(7636), 1,
      anon_sym_is,
    ACTIONS(7638), 1,
      anon_sym_CARET,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(7614), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7616), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7618), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7624), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7628), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7630), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 7,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_by,
    STATE(5460), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [86299] = 34,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7620), 1,
      anon_sym_SLASH,
    ACTIONS(7626), 1,
      anon_sym_GT_GT,
    ACTIONS(7632), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7634), 1,
      anon_sym_as,
    ACTIONS(7636), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7614), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7616), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7618), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7624), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7628), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7630), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(6342), 8,
      anon_sym_CARET,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_by,
    STATE(5461), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [86426] = 33,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7620), 1,
      anon_sym_SLASH,
    ACTIONS(7626), 1,
      anon_sym_GT_GT,
    ACTIONS(7632), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7634), 1,
      anon_sym_as,
    ACTIONS(7636), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7614), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7616), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7618), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7624), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7630), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    STATE(5462), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 10,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_by,
  [86551] = 37,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7620), 1,
      anon_sym_SLASH,
    ACTIONS(7622), 1,
      anon_sym_AMP,
    ACTIONS(7626), 1,
      anon_sym_GT_GT,
    ACTIONS(7632), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7634), 1,
      anon_sym_as,
    ACTIONS(7636), 1,
      anon_sym_is,
    ACTIONS(7638), 1,
      anon_sym_CARET,
    ACTIONS(7640), 1,
      anon_sym_PIPE,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7614), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7616), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7618), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7624), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7628), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7630), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 7,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_by,
    STATE(5463), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [86684] = 38,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7620), 1,
      anon_sym_SLASH,
    ACTIONS(7622), 1,
      anon_sym_AMP,
    ACTIONS(7626), 1,
      anon_sym_GT_GT,
    ACTIONS(7632), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7634), 1,
      anon_sym_as,
    ACTIONS(7636), 1,
      anon_sym_is,
    ACTIONS(7638), 1,
      anon_sym_CARET,
    ACTIONS(7640), 1,
      anon_sym_PIPE,
    ACTIONS(7642), 1,
      anon_sym_AMP_AMP,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7614), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7616), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7618), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7624), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7628), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7630), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 6,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_by,
    STATE(5464), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [86819] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7620), 1,
      anon_sym_SLASH,
    ACTIONS(7622), 1,
      anon_sym_AMP,
    ACTIONS(7626), 1,
      anon_sym_GT_GT,
    ACTIONS(7632), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7634), 1,
      anon_sym_as,
    ACTIONS(7636), 1,
      anon_sym_is,
    ACTIONS(7638), 1,
      anon_sym_CARET,
    ACTIONS(7640), 1,
      anon_sym_PIPE,
    ACTIONS(7642), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7644), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7646), 1,
      anon_sym_QMARK_QMARK,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7614), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7616), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7618), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7624), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7628), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7630), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 4,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
      anon_sym_by,
    STATE(5465), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [86958] = 41,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(7516), 1,
      anon_sym_QMARK,
    ACTIONS(7522), 1,
      anon_sym_SLASH,
    ACTIONS(7524), 1,
      anon_sym_CARET,
    ACTIONS(7526), 1,
      anon_sym_PIPE,
    ACTIONS(7528), 1,
      anon_sym_AMP,
    ACTIONS(7532), 1,
      anon_sym_GT_GT,
    ACTIONS(7538), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7540), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7542), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7544), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7648), 1,
      anon_sym_SEMI,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7514), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7518), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7520), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7530), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7534), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7536), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6320), 3,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
    STATE(5466), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [87099] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5467), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(2995), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(2997), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [87184] = 21,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(5346), 1,
      sym_identifier,
    STATE(6812), 1,
      sym_attribute_target_specifier,
    STATE(8073), 1,
      sym__name,
    STATE(8515), 1,
      sym_attribute,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    ACTIONS(1069), 7,
      anon_sym_field,
      anon_sym_event,
      anon_sym_method,
      anon_sym_param,
      anon_sym_property,
      anon_sym_return,
      anon_sym_type,
    STATE(5468), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [87285] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4806), 6,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
    STATE(5469), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5886), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5883), 22,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [87372] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4806), 6,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
    STATE(5470), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5892), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5889), 22,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [87459] = 43,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7118), 1,
      anon_sym_SLASH,
    ACTIONS(7120), 1,
      anon_sym_CARET,
    ACTIONS(7122), 1,
      anon_sym_PIPE,
    ACTIONS(7124), 1,
      anon_sym_AMP,
    ACTIONS(7128), 1,
      anon_sym_GT_GT,
    ACTIONS(7136), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7138), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7140), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7650), 1,
      anon_sym_COLON,
    ACTIONS(7652), 1,
      anon_sym_COMMA,
    ACTIONS(7654), 1,
      anon_sym_RBRACE,
    ACTIONS(7656), 1,
      anon_sym_QMARK,
    ACTIONS(7658), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(7662), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    STATE(8660), 1,
      aux_sym_for_statement_repeat1,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7112), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7114), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7116), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7126), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7130), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7132), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(5471), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [87604] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7664), 1,
      anon_sym_and,
    ACTIONS(7666), 1,
      anon_sym_or,
    STATE(5472), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6594), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6592), 26,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
  [87693] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7411), 1,
      anon_sym_LBRACK,
    ACTIONS(7413), 1,
      anon_sym_QMARK,
    ACTIONS(4494), 9,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_EQ_GT,
    STATE(5473), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4492), 28,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_operator,
      anon_sym_this,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      sym_discard,
      anon_sym_and,
      anon_sym_or,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [87782] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6320), 4,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(5474), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [87921] = 29,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7620), 1,
      anon_sym_SLASH,
    ACTIONS(7626), 1,
      anon_sym_GT_GT,
    ACTIONS(7632), 1,
      anon_sym_DOT_DOT,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7616), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7618), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7624), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6344), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    STATE(5475), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 14,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_by,
      anon_sym_as,
      anon_sym_is,
  [88038] = 26,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7620), 1,
      anon_sym_SLASH,
    ACTIONS(7632), 1,
      anon_sym_DOT_DOT,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7618), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5476), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 16,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_by,
      anon_sym_as,
      anon_sym_is,
  [88149] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7620), 1,
      anon_sym_SLASH,
    ACTIONS(7632), 1,
      anon_sym_DOT_DOT,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7616), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7618), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5477), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 16,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_by,
      anon_sym_as,
      anon_sym_is,
  [88262] = 21,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(5346), 1,
      sym_identifier,
    STATE(6825), 1,
      sym_attribute_target_specifier,
    STATE(8073), 1,
      sym__name,
    STATE(8483), 1,
      sym_attribute,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    ACTIONS(1069), 7,
      anon_sym_field,
      anon_sym_event,
      anon_sym_method,
      anon_sym_param,
      anon_sym_property,
      anon_sym_return,
      anon_sym_type,
    STATE(5478), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [88363] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5479), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3037), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(3039), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [88448] = 29,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7706), 1,
      anon_sym_SLASH,
    ACTIONS(7710), 1,
      anon_sym_GT_GT,
    ACTIONS(7712), 1,
      anon_sym_DOT_DOT,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7702), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7704), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7708), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6344), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    STATE(5480), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 14,
      anon_sym_COLON,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
  [88565] = 26,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7706), 1,
      anon_sym_SLASH,
    ACTIONS(7712), 1,
      anon_sym_DOT_DOT,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7704), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5481), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 16,
      anon_sym_COLON,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
  [88676] = 35,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7566), 1,
      anon_sym_as,
    ACTIONS(7706), 1,
      anon_sym_SLASH,
    ACTIONS(7710), 1,
      anon_sym_GT_GT,
    ACTIONS(7712), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7716), 1,
      anon_sym_AMP,
    ACTIONS(7722), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(7702), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7704), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7708), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7714), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7718), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7720), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 8,
      anon_sym_COLON,
      anon_sym_CARET,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(5482), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [88805] = 36,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7566), 1,
      anon_sym_as,
    ACTIONS(7706), 1,
      anon_sym_SLASH,
    ACTIONS(7710), 1,
      anon_sym_GT_GT,
    ACTIONS(7712), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7716), 1,
      anon_sym_AMP,
    ACTIONS(7722), 1,
      anon_sym_is,
    ACTIONS(7724), 1,
      anon_sym_CARET,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(7702), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7704), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7708), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7714), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7718), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7720), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 7,
      anon_sym_COLON,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(5483), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [88936] = 34,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7566), 1,
      anon_sym_as,
    ACTIONS(7706), 1,
      anon_sym_SLASH,
    ACTIONS(7710), 1,
      anon_sym_GT_GT,
    ACTIONS(7712), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7722), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7702), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7704), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7708), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7714), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7718), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7720), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(6342), 8,
      anon_sym_COLON,
      anon_sym_CARET,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(5484), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [89063] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7706), 1,
      anon_sym_SLASH,
    ACTIONS(7712), 1,
      anon_sym_DOT_DOT,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7702), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7704), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5485), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 16,
      anon_sym_COLON,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
  [89176] = 33,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7566), 1,
      anon_sym_as,
    ACTIONS(7706), 1,
      anon_sym_SLASH,
    ACTIONS(7710), 1,
      anon_sym_GT_GT,
    ACTIONS(7712), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7722), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7702), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7704), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7708), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7714), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7720), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    STATE(5486), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 10,
      anon_sym_COLON,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
  [89301] = 37,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7566), 1,
      anon_sym_as,
    ACTIONS(7706), 1,
      anon_sym_SLASH,
    ACTIONS(7710), 1,
      anon_sym_GT_GT,
    ACTIONS(7712), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7716), 1,
      anon_sym_AMP,
    ACTIONS(7722), 1,
      anon_sym_is,
    ACTIONS(7724), 1,
      anon_sym_CARET,
    ACTIONS(7726), 1,
      anon_sym_PIPE,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7702), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7704), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7708), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7714), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7718), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7720), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 7,
      anon_sym_COLON,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(5487), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [89434] = 38,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7566), 1,
      anon_sym_as,
    ACTIONS(7706), 1,
      anon_sym_SLASH,
    ACTIONS(7710), 1,
      anon_sym_GT_GT,
    ACTIONS(7712), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7716), 1,
      anon_sym_AMP,
    ACTIONS(7722), 1,
      anon_sym_is,
    ACTIONS(7724), 1,
      anon_sym_CARET,
    ACTIONS(7726), 1,
      anon_sym_PIPE,
    ACTIONS(7728), 1,
      anon_sym_AMP_AMP,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7702), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7704), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7708), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7714), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7718), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7720), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 6,
      anon_sym_COLON,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(5488), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [89569] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7566), 1,
      anon_sym_as,
    ACTIONS(7706), 1,
      anon_sym_SLASH,
    ACTIONS(7710), 1,
      anon_sym_GT_GT,
    ACTIONS(7712), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7716), 1,
      anon_sym_AMP,
    ACTIONS(7722), 1,
      anon_sym_is,
    ACTIONS(7724), 1,
      anon_sym_CARET,
    ACTIONS(7726), 1,
      anon_sym_PIPE,
    ACTIONS(7728), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7730), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7732), 1,
      anon_sym_QMARK_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7702), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7704), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7708), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7714), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7718), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7720), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 4,
      anon_sym_COLON,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
    STATE(5489), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [89708] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7566), 1,
      anon_sym_as,
    ACTIONS(7706), 1,
      anon_sym_SLASH,
    ACTIONS(7710), 1,
      anon_sym_GT_GT,
    ACTIONS(7712), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7716), 1,
      anon_sym_AMP,
    ACTIONS(7722), 1,
      anon_sym_is,
    ACTIONS(7724), 1,
      anon_sym_CARET,
    ACTIONS(7726), 1,
      anon_sym_PIPE,
    ACTIONS(7728), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7730), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7732), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7734), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7702), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7704), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7708), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7714), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7718), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7720), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6320), 4,
      anon_sym_COLON,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
    STATE(5490), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [89847] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(7712), 1,
      anon_sym_DOT_DOT,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6330), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5491), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6328), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [89950] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7566), 1,
      anon_sym_as,
    ACTIONS(7706), 1,
      anon_sym_SLASH,
    ACTIONS(7710), 1,
      anon_sym_GT_GT,
    ACTIONS(7712), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7716), 1,
      anon_sym_AMP,
    ACTIONS(7722), 1,
      anon_sym_is,
    ACTIONS(7724), 1,
      anon_sym_CARET,
    ACTIONS(7726), 1,
      anon_sym_PIPE,
    ACTIONS(7728), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7730), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7732), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7734), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7702), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7704), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7708), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7714), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7718), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7720), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6324), 4,
      anon_sym_COLON,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
    STATE(5492), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [90089] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7566), 1,
      anon_sym_as,
    ACTIONS(7706), 1,
      anon_sym_SLASH,
    ACTIONS(7710), 1,
      anon_sym_GT_GT,
    ACTIONS(7712), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7716), 1,
      anon_sym_AMP,
    ACTIONS(7722), 1,
      anon_sym_is,
    ACTIONS(7724), 1,
      anon_sym_CARET,
    ACTIONS(7726), 1,
      anon_sym_PIPE,
    ACTIONS(7728), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7730), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7732), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7734), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7702), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7704), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7708), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7714), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7718), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7720), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5416), 4,
      anon_sym_COLON,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
    STATE(5493), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [90228] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7566), 1,
      anon_sym_as,
    ACTIONS(7706), 1,
      anon_sym_SLASH,
    ACTIONS(7710), 1,
      anon_sym_GT_GT,
    ACTIONS(7712), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7716), 1,
      anon_sym_AMP,
    ACTIONS(7722), 1,
      anon_sym_is,
    ACTIONS(7724), 1,
      anon_sym_CARET,
    ACTIONS(7726), 1,
      anon_sym_PIPE,
    ACTIONS(7728), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7730), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7732), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7734), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7702), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7704), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7708), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7714), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7718), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7720), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5644), 4,
      anon_sym_COLON,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
    STATE(5494), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [90367] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7566), 1,
      anon_sym_as,
    ACTIONS(7706), 1,
      anon_sym_SLASH,
    ACTIONS(7710), 1,
      anon_sym_GT_GT,
    ACTIONS(7712), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7716), 1,
      anon_sym_AMP,
    ACTIONS(7722), 1,
      anon_sym_is,
    ACTIONS(7724), 1,
      anon_sym_CARET,
    ACTIONS(7726), 1,
      anon_sym_PIPE,
    ACTIONS(7728), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7730), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7732), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7734), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7702), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7704), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7708), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7714), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7718), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7720), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5424), 4,
      anon_sym_COLON,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
    STATE(5495), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [90506] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7566), 1,
      anon_sym_as,
    ACTIONS(7706), 1,
      anon_sym_SLASH,
    ACTIONS(7710), 1,
      anon_sym_GT_GT,
    ACTIONS(7712), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7716), 1,
      anon_sym_AMP,
    ACTIONS(7722), 1,
      anon_sym_is,
    ACTIONS(7724), 1,
      anon_sym_CARET,
    ACTIONS(7726), 1,
      anon_sym_PIPE,
    ACTIONS(7728), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7730), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7732), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7734), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7702), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7704), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7708), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7714), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7718), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7720), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6336), 4,
      anon_sym_COLON,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
    STATE(5496), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [90645] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7566), 1,
      anon_sym_as,
    ACTIONS(7706), 1,
      anon_sym_SLASH,
    ACTIONS(7710), 1,
      anon_sym_GT_GT,
    ACTIONS(7712), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7716), 1,
      anon_sym_AMP,
    ACTIONS(7722), 1,
      anon_sym_is,
    ACTIONS(7724), 1,
      anon_sym_CARET,
    ACTIONS(7726), 1,
      anon_sym_PIPE,
    ACTIONS(7728), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7730), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7732), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7734), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7702), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7704), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7708), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7714), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7718), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7720), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5572), 4,
      anon_sym_COLON,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
    STATE(5497), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [90784] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7566), 1,
      anon_sym_as,
    ACTIONS(7706), 1,
      anon_sym_SLASH,
    ACTIONS(7710), 1,
      anon_sym_GT_GT,
    ACTIONS(7712), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7716), 1,
      anon_sym_AMP,
    ACTIONS(7722), 1,
      anon_sym_is,
    ACTIONS(7724), 1,
      anon_sym_CARET,
    ACTIONS(7726), 1,
      anon_sym_PIPE,
    ACTIONS(7728), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7730), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7732), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7734), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7702), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7704), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7708), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7714), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7718), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7720), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5584), 4,
      anon_sym_COLON,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
    STATE(5498), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [90923] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7566), 1,
      anon_sym_as,
    ACTIONS(7706), 1,
      anon_sym_SLASH,
    ACTIONS(7710), 1,
      anon_sym_GT_GT,
    ACTIONS(7712), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7716), 1,
      anon_sym_AMP,
    ACTIONS(7722), 1,
      anon_sym_is,
    ACTIONS(7724), 1,
      anon_sym_CARET,
    ACTIONS(7726), 1,
      anon_sym_PIPE,
    ACTIONS(7728), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7730), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7732), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7734), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7702), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7704), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7708), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7714), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7718), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7720), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5624), 4,
      anon_sym_COLON,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
    STATE(5499), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [91062] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7566), 1,
      anon_sym_as,
    ACTIONS(7706), 1,
      anon_sym_SLASH,
    ACTIONS(7710), 1,
      anon_sym_GT_GT,
    ACTIONS(7712), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7716), 1,
      anon_sym_AMP,
    ACTIONS(7722), 1,
      anon_sym_is,
    ACTIONS(7724), 1,
      anon_sym_CARET,
    ACTIONS(7726), 1,
      anon_sym_PIPE,
    ACTIONS(7728), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7730), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7732), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7734), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7702), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7704), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7708), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7714), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7718), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7720), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6190), 4,
      anon_sym_COLON,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
    STATE(5500), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [91201] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(7632), 1,
      anon_sym_DOT_DOT,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6330), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5501), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6328), 20,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_by,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [91304] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5813), 1,
      anon_sym_LT,
    ACTIONS(7736), 1,
      anon_sym_COLON_COLON,
    STATE(3964), 1,
      sym_type_argument_list,
    STATE(5502), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4138), 10,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(4140), 26,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [91395] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5503), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(2995), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(2997), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [91480] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7664), 1,
      anon_sym_and,
    STATE(5504), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6707), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6705), 27,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
  [91567] = 29,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7498), 1,
      anon_sym_SLASH,
    ACTIONS(7502), 1,
      anon_sym_GT_GT,
    ACTIONS(7508), 1,
      anon_sym_DOT_DOT,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7494), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7496), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7500), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6344), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    STATE(5505), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 14,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_equals,
      anon_sym_as,
      anon_sym_is,
  [91684] = 26,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7498), 1,
      anon_sym_SLASH,
    ACTIONS(7508), 1,
      anon_sym_DOT_DOT,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7496), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5506), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 16,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_equals,
      anon_sym_as,
      anon_sym_is,
  [91795] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7498), 1,
      anon_sym_SLASH,
    ACTIONS(7508), 1,
      anon_sym_DOT_DOT,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7494), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7496), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5507), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 16,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_equals,
      anon_sym_as,
      anon_sym_is,
  [91908] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(7508), 1,
      anon_sym_DOT_DOT,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6330), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5508), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6328), 20,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_equals,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [92011] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5509), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5881), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5879), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [92096] = 29,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7658), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7742), 1,
      anon_sym_SLASH,
    ACTIONS(7746), 1,
      anon_sym_GT_GT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7738), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7740), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7744), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6344), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    STATE(5510), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 14,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
  [92213] = 26,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7658), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7742), 1,
      anon_sym_SLASH,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7740), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5511), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 16,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
  [92324] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7658), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5512), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 18,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
  [92431] = 35,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7658), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(7662), 1,
      anon_sym_is,
    ACTIONS(7742), 1,
      anon_sym_SLASH,
    ACTIONS(7746), 1,
      anon_sym_GT_GT,
    ACTIONS(7750), 1,
      anon_sym_AMP,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(7738), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7740), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7744), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7748), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7752), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7754), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 8,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(5513), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [92560] = 36,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7658), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(7662), 1,
      anon_sym_is,
    ACTIONS(7742), 1,
      anon_sym_SLASH,
    ACTIONS(7746), 1,
      anon_sym_GT_GT,
    ACTIONS(7750), 1,
      anon_sym_AMP,
    ACTIONS(7756), 1,
      anon_sym_CARET,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(7738), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7740), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7744), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7748), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7752), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7754), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 7,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(5514), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [92691] = 34,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7658), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(7662), 1,
      anon_sym_is,
    ACTIONS(7742), 1,
      anon_sym_SLASH,
    ACTIONS(7746), 1,
      anon_sym_GT_GT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7738), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7740), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7744), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7748), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7752), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7754), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(6342), 8,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(5515), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [92818] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7658), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7742), 1,
      anon_sym_SLASH,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7738), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7740), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5516), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 16,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
  [92931] = 33,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7658), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(7662), 1,
      anon_sym_is,
    ACTIONS(7742), 1,
      anon_sym_SLASH,
    ACTIONS(7746), 1,
      anon_sym_GT_GT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7738), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7740), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7744), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7748), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7754), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    STATE(5517), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 10,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
  [93056] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(7658), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6330), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5518), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6328), 20,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [93159] = 37,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7658), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(7662), 1,
      anon_sym_is,
    ACTIONS(7742), 1,
      anon_sym_SLASH,
    ACTIONS(7746), 1,
      anon_sym_GT_GT,
    ACTIONS(7750), 1,
      anon_sym_AMP,
    ACTIONS(7756), 1,
      anon_sym_CARET,
    ACTIONS(7758), 1,
      anon_sym_PIPE,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7738), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7740), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7744), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7748), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7752), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7754), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 7,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(5519), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [93292] = 38,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7658), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(7662), 1,
      anon_sym_is,
    ACTIONS(7742), 1,
      anon_sym_SLASH,
    ACTIONS(7746), 1,
      anon_sym_GT_GT,
    ACTIONS(7750), 1,
      anon_sym_AMP,
    ACTIONS(7756), 1,
      anon_sym_CARET,
    ACTIONS(7758), 1,
      anon_sym_PIPE,
    ACTIONS(7760), 1,
      anon_sym_AMP_AMP,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7738), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7740), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7744), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7748), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7752), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7754), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 6,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(5520), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [93427] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7658), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(7662), 1,
      anon_sym_is,
    ACTIONS(7742), 1,
      anon_sym_SLASH,
    ACTIONS(7746), 1,
      anon_sym_GT_GT,
    ACTIONS(7750), 1,
      anon_sym_AMP,
    ACTIONS(7756), 1,
      anon_sym_CARET,
    ACTIONS(7758), 1,
      anon_sym_PIPE,
    ACTIONS(7760), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7762), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7764), 1,
      anon_sym_QMARK_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7738), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7740), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7744), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7748), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7752), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7754), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 4,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(5521), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [93566] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7656), 1,
      anon_sym_QMARK,
    ACTIONS(7658), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(7662), 1,
      anon_sym_is,
    ACTIONS(7742), 1,
      anon_sym_SLASH,
    ACTIONS(7746), 1,
      anon_sym_GT_GT,
    ACTIONS(7750), 1,
      anon_sym_AMP,
    ACTIONS(7756), 1,
      anon_sym_CARET,
    ACTIONS(7758), 1,
      anon_sym_PIPE,
    ACTIONS(7760), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7762), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7764), 1,
      anon_sym_QMARK_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7738), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7740), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7744), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7748), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7752), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7754), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5416), 4,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(5522), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [93705] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7656), 1,
      anon_sym_QMARK,
    ACTIONS(7658), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(7662), 1,
      anon_sym_is,
    ACTIONS(7742), 1,
      anon_sym_SLASH,
    ACTIONS(7746), 1,
      anon_sym_GT_GT,
    ACTIONS(7750), 1,
      anon_sym_AMP,
    ACTIONS(7756), 1,
      anon_sym_CARET,
    ACTIONS(7758), 1,
      anon_sym_PIPE,
    ACTIONS(7760), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7762), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7764), 1,
      anon_sym_QMARK_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7738), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7740), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7744), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7748), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7752), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7754), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5644), 4,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(5523), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [93844] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7656), 1,
      anon_sym_QMARK,
    ACTIONS(7658), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(7662), 1,
      anon_sym_is,
    ACTIONS(7742), 1,
      anon_sym_SLASH,
    ACTIONS(7746), 1,
      anon_sym_GT_GT,
    ACTIONS(7750), 1,
      anon_sym_AMP,
    ACTIONS(7756), 1,
      anon_sym_CARET,
    ACTIONS(7758), 1,
      anon_sym_PIPE,
    ACTIONS(7760), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7762), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7764), 1,
      anon_sym_QMARK_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7738), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7740), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7744), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7748), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7752), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7754), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5424), 4,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(5524), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [93983] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7656), 1,
      anon_sym_QMARK,
    ACTIONS(7658), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(7662), 1,
      anon_sym_is,
    ACTIONS(7742), 1,
      anon_sym_SLASH,
    ACTIONS(7746), 1,
      anon_sym_GT_GT,
    ACTIONS(7750), 1,
      anon_sym_AMP,
    ACTIONS(7756), 1,
      anon_sym_CARET,
    ACTIONS(7758), 1,
      anon_sym_PIPE,
    ACTIONS(7760), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7762), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7764), 1,
      anon_sym_QMARK_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7738), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7740), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7744), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7748), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7752), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7754), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6336), 4,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(5525), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [94122] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7656), 1,
      anon_sym_QMARK,
    ACTIONS(7658), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(7662), 1,
      anon_sym_is,
    ACTIONS(7742), 1,
      anon_sym_SLASH,
    ACTIONS(7746), 1,
      anon_sym_GT_GT,
    ACTIONS(7750), 1,
      anon_sym_AMP,
    ACTIONS(7756), 1,
      anon_sym_CARET,
    ACTIONS(7758), 1,
      anon_sym_PIPE,
    ACTIONS(7760), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7762), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7764), 1,
      anon_sym_QMARK_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7738), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7740), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7744), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7748), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7752), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7754), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5572), 4,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(5526), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [94261] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7656), 1,
      anon_sym_QMARK,
    ACTIONS(7658), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(7662), 1,
      anon_sym_is,
    ACTIONS(7742), 1,
      anon_sym_SLASH,
    ACTIONS(7746), 1,
      anon_sym_GT_GT,
    ACTIONS(7750), 1,
      anon_sym_AMP,
    ACTIONS(7756), 1,
      anon_sym_CARET,
    ACTIONS(7758), 1,
      anon_sym_PIPE,
    ACTIONS(7760), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7762), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7764), 1,
      anon_sym_QMARK_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7738), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7740), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7744), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7748), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7752), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7754), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5584), 4,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(5527), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [94400] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7656), 1,
      anon_sym_QMARK,
    ACTIONS(7658), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(7662), 1,
      anon_sym_is,
    ACTIONS(7742), 1,
      anon_sym_SLASH,
    ACTIONS(7746), 1,
      anon_sym_GT_GT,
    ACTIONS(7750), 1,
      anon_sym_AMP,
    ACTIONS(7756), 1,
      anon_sym_CARET,
    ACTIONS(7758), 1,
      anon_sym_PIPE,
    ACTIONS(7760), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7762), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7764), 1,
      anon_sym_QMARK_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7738), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7740), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7744), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7748), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7752), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7754), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5624), 4,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(5528), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [94539] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5529), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5654), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5652), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [94624] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7766), 1,
      anon_sym_LPAREN,
    STATE(5530), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(2029), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(2031), 27,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [94711] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5531), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5676), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5674), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [94796] = 29,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7772), 1,
      anon_sym_SLASH,
    ACTIONS(7776), 1,
      anon_sym_GT_GT,
    ACTIONS(7778), 1,
      anon_sym_DOT_DOT,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7768), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7770), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7774), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6344), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    STATE(5532), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 14,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_on,
      anon_sym_as,
      anon_sym_is,
  [94913] = 26,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7772), 1,
      anon_sym_SLASH,
    ACTIONS(7778), 1,
      anon_sym_DOT_DOT,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7770), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5533), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 16,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_on,
      anon_sym_as,
      anon_sym_is,
  [95024] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7772), 1,
      anon_sym_SLASH,
    ACTIONS(7778), 1,
      anon_sym_DOT_DOT,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7768), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7770), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5534), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 16,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_on,
      anon_sym_as,
      anon_sym_is,
  [95137] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(7778), 1,
      anon_sym_DOT_DOT,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6330), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5535), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6328), 20,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_on,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [95240] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5536), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5288), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5286), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [95325] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5537), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5630), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5628), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [95410] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5538), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5516), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5514), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [95495] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5539), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5422), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5420), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [95580] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5540), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5550), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5548), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [95665] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5541), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5594), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5592), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [95750] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5542), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5508), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5506), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [95835] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5543), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5666), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5664), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [95920] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5544), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5680), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5678), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [96005] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5545), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(2999), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(3001), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [96090] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5546), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5472), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5470), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [96175] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5547), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4767), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(4765), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [96260] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5548), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5520), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5518), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [96345] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5549), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5554), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5552), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [96430] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5550), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5558), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5556), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [96515] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5551), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5566), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5564), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [96600] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5552), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5570), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5568), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [96685] = 29,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7784), 1,
      anon_sym_SLASH,
    ACTIONS(7788), 1,
      anon_sym_GT_GT,
    ACTIONS(7790), 1,
      anon_sym_DOT_DOT,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7780), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7782), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7786), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6344), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    STATE(5553), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 14,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_GT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
  [96802] = 26,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7784), 1,
      anon_sym_SLASH,
    ACTIONS(7790), 1,
      anon_sym_DOT_DOT,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7782), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5554), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 16,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_GT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
  [96913] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7784), 1,
      anon_sym_SLASH,
    ACTIONS(7790), 1,
      anon_sym_DOT_DOT,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7780), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7782), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5555), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 16,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_GT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
  [97026] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(7790), 1,
      anon_sym_DOT_DOT,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6330), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5556), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6328), 20,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_GT,
      anon_sym_switch,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [97129] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5557), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5578), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5576), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [97214] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5558), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5590), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5588), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [97299] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5559), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5638), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5636), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [97384] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7186), 1,
      anon_sym_as,
    ACTIONS(7190), 1,
      anon_sym_with,
    ACTIONS(7588), 1,
      anon_sym_SLASH,
    ACTIONS(7590), 1,
      anon_sym_AMP,
    ACTIONS(7594), 1,
      anon_sym_GT_GT,
    ACTIONS(7600), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7602), 1,
      anon_sym_is,
    ACTIONS(7604), 1,
      anon_sym_CARET,
    ACTIONS(7606), 1,
      anon_sym_PIPE,
    ACTIONS(7608), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7610), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7612), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7792), 1,
      anon_sym_QMARK,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7584), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7586), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7592), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7596), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7598), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6266), 4,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_into,
    STATE(5560), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [97523] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5561), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5418), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5416), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [97608] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5562), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5528), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5526), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [97693] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5563), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5650), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5648), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [97778] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5564), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5403), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5401), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [97863] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5565), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5410), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5408), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [97948] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5566), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5430), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5428), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [98033] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5567), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5468), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5466), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [98118] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5568), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5488), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5486), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [98203] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5569), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5496), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5494), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [98288] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5570), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5504), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5502), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [98373] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5571), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(2037), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(2035), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [98458] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5572), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5536), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5534), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [98543] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5573), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5540), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5538), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [98628] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5574), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5582), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5580), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [98713] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5575), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5634), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5632), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [98798] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5576), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5642), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5640), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [98883] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5577), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5646), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5644), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [98968] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5578), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5672), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5670), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [99053] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5579), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5688), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5686), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [99138] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5580), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5414), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5412), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [99223] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7664), 1,
      anon_sym_and,
    ACTIONS(7666), 1,
      anon_sym_or,
    STATE(5581), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5881), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5879), 26,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
  [99312] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5582), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5426), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5424), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [99397] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5583), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5454), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5452), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [99482] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5584), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(2991), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(2993), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [99567] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5585), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5482), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5480), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [99652] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5586), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5492), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5490), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [99737] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5587), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5500), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5498), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [99822] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5588), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5524), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5522), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [99907] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5589), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5532), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5530), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [99992] = 21,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(5346), 1,
      sym_identifier,
    STATE(6811), 1,
      sym_attribute_target_specifier,
    STATE(8073), 1,
      sym__name,
    STATE(8640), 1,
      sym_attribute,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    ACTIONS(1069), 7,
      anon_sym_field,
      anon_sym_event,
      anon_sym_method,
      anon_sym_param,
      anon_sym_property,
      anon_sym_return,
      anon_sym_type,
    STATE(5590), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [100093] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5591), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5546), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5544), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [100178] = 29,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6344), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    STATE(5592), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 14,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
  [100295] = 26,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5593), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 16,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
  [100406] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5594), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 18,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
  [100513] = 35,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7700), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 8,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(5595), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [100642] = 36,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7700), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 7,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(5596), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [100773] = 34,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7700), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(6342), 8,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(5597), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [100900] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5598), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 16,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
  [101013] = 33,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7700), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    STATE(5599), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 10,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
  [101138] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(7516), 1,
      anon_sym_QMARK,
    ACTIONS(7522), 1,
      anon_sym_SLASH,
    ACTIONS(7524), 1,
      anon_sym_CARET,
    ACTIONS(7526), 1,
      anon_sym_PIPE,
    ACTIONS(7528), 1,
      anon_sym_AMP,
    ACTIONS(7532), 1,
      anon_sym_GT_GT,
    ACTIONS(7538), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7540), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7542), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7544), 1,
      anon_sym_QMARK_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7514), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7518), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7520), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7530), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7534), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7536), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6190), 4,
      anon_sym_SEMI,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
    STATE(5600), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [101277] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6330), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5601), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6328), 20,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [101380] = 37,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7700), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 7,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(5602), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [101513] = 38,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7700), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 6,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(5603), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [101648] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 4,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(5604), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [101787] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5605), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5562), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5560), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [101872] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7186), 1,
      anon_sym_as,
    ACTIONS(7190), 1,
      anon_sym_with,
    ACTIONS(7588), 1,
      anon_sym_SLASH,
    ACTIONS(7590), 1,
      anon_sym_AMP,
    ACTIONS(7594), 1,
      anon_sym_GT_GT,
    ACTIONS(7600), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7602), 1,
      anon_sym_is,
    ACTIONS(7604), 1,
      anon_sym_CARET,
    ACTIONS(7606), 1,
      anon_sym_PIPE,
    ACTIONS(7608), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7610), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7612), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7792), 1,
      anon_sym_QMARK,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7584), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7586), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7592), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7596), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7598), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6270), 4,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_into,
    STATE(5606), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [102011] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5607), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5610), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5608), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [102096] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1229), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5608), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(1227), 20,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [102199] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(7516), 1,
      anon_sym_QMARK,
    ACTIONS(7522), 1,
      anon_sym_SLASH,
    ACTIONS(7524), 1,
      anon_sym_CARET,
    ACTIONS(7526), 1,
      anon_sym_PIPE,
    ACTIONS(7528), 1,
      anon_sym_AMP,
    ACTIONS(7532), 1,
      anon_sym_GT_GT,
    ACTIONS(7538), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7540), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7542), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7544), 1,
      anon_sym_QMARK_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7514), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7518), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7520), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7530), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7534), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7536), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6324), 4,
      anon_sym_SEMI,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
    STATE(5609), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [102338] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5416), 4,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(5610), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [102477] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(7516), 1,
      anon_sym_QMARK,
    ACTIONS(7522), 1,
      anon_sym_SLASH,
    ACTIONS(7524), 1,
      anon_sym_CARET,
    ACTIONS(7526), 1,
      anon_sym_PIPE,
    ACTIONS(7528), 1,
      anon_sym_AMP,
    ACTIONS(7532), 1,
      anon_sym_GT_GT,
    ACTIONS(7538), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7540), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7542), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7544), 1,
      anon_sym_QMARK_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7514), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7518), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7520), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7530), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7534), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7536), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6320), 4,
      anon_sym_SEMI,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
    STATE(5611), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [102616] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6324), 4,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(5612), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [102755] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7794), 1,
      anon_sym_into,
    STATE(5616), 1,
      aux_sym__query_body_repeat2,
    STATE(5613), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6482), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6480), 26,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [102844] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7794), 1,
      anon_sym_into,
    STATE(5617), 1,
      aux_sym__query_body_repeat2,
    STATE(5614), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6482), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6480), 26,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [102933] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5615), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5574), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5572), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [103018] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7796), 1,
      anon_sym_into,
    STATE(5616), 10,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
      aux_sym__query_body_repeat2,
    ACTIONS(6486), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6484), 26,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [103105] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7794), 1,
      anon_sym_into,
    STATE(5616), 1,
      aux_sym__query_body_repeat2,
    STATE(5617), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6493), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6491), 26,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [103194] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5618), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5586), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5584), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [103279] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(7516), 1,
      anon_sym_QMARK,
    ACTIONS(7522), 1,
      anon_sym_SLASH,
    ACTIONS(7524), 1,
      anon_sym_CARET,
    ACTIONS(7526), 1,
      anon_sym_PIPE,
    ACTIONS(7528), 1,
      anon_sym_AMP,
    ACTIONS(7532), 1,
      anon_sym_GT_GT,
    ACTIONS(7538), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7540), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7542), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7544), 1,
      anon_sym_QMARK_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7514), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7518), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7520), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7530), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7534), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7536), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5584), 4,
      anon_sym_SEMI,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
    STATE(5619), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [103418] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7186), 1,
      anon_sym_as,
    ACTIONS(7190), 1,
      anon_sym_with,
    ACTIONS(7588), 1,
      anon_sym_SLASH,
    ACTIONS(7590), 1,
      anon_sym_AMP,
    ACTIONS(7594), 1,
      anon_sym_GT_GT,
    ACTIONS(7600), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7602), 1,
      anon_sym_is,
    ACTIONS(7604), 1,
      anon_sym_CARET,
    ACTIONS(7606), 1,
      anon_sym_PIPE,
    ACTIONS(7608), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7610), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7612), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7792), 1,
      anon_sym_QMARK,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7584), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7586), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7592), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7596), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7598), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6190), 4,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_into,
    STATE(5620), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [103557] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7600), 1,
      anon_sym_DOT_DOT,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1229), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5621), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(1227), 20,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [103660] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5424), 4,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(5622), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [103799] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5623), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5598), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5596), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [103884] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6336), 4,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(5624), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [104023] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7799), 1,
      anon_sym_and,
    ACTIONS(7801), 1,
      anon_sym_or,
    STATE(5625), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5881), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5879), 26,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [104112] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7799), 1,
      anon_sym_and,
    ACTIONS(7801), 1,
      anon_sym_or,
    STATE(5626), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6594), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6592), 26,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [104201] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6444), 1,
      anon_sym_as,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7784), 1,
      anon_sym_SLASH,
    ACTIONS(7788), 1,
      anon_sym_GT_GT,
    ACTIONS(7790), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7805), 1,
      anon_sym_QMARK,
    ACTIONS(7807), 1,
      anon_sym_CARET,
    ACTIONS(7809), 1,
      anon_sym_PIPE,
    ACTIONS(7811), 1,
      anon_sym_AMP,
    ACTIONS(7817), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7819), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7821), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7823), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7780), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7782), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7786), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7803), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7813), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7815), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6190), 4,
      anon_sym_EQ_GT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
    STATE(5627), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [104340] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5572), 4,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(5628), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [104479] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5629), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5602), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5600), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [104564] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5584), 4,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(5630), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [104703] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5631), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5606), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5604), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [104788] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5632), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5618), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5616), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [104873] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5624), 4,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(5633), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [105012] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5634), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5622), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5620), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [105097] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5635), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5512), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5510), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [105182] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7632), 1,
      anon_sym_DOT_DOT,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5636), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 18,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_by,
      anon_sym_as,
      anon_sym_is,
  [105289] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7656), 1,
      anon_sym_QMARK,
    ACTIONS(7658), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(7662), 1,
      anon_sym_is,
    ACTIONS(7742), 1,
      anon_sym_SLASH,
    ACTIONS(7746), 1,
      anon_sym_GT_GT,
    ACTIONS(7750), 1,
      anon_sym_AMP,
    ACTIONS(7756), 1,
      anon_sym_CARET,
    ACTIONS(7758), 1,
      anon_sym_PIPE,
    ACTIONS(7760), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7762), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7764), 1,
      anon_sym_QMARK_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7738), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7740), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7744), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7748), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7752), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7754), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6320), 4,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(5637), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [105428] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7656), 1,
      anon_sym_QMARK,
    ACTIONS(7658), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(7662), 1,
      anon_sym_is,
    ACTIONS(7742), 1,
      anon_sym_SLASH,
    ACTIONS(7746), 1,
      anon_sym_GT_GT,
    ACTIONS(7750), 1,
      anon_sym_AMP,
    ACTIONS(7756), 1,
      anon_sym_CARET,
    ACTIONS(7758), 1,
      anon_sym_PIPE,
    ACTIONS(7760), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7762), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7764), 1,
      anon_sym_QMARK_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7738), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7740), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7744), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7748), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7752), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7754), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6324), 4,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(5638), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [105567] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5639), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5626), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5624), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [105652] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7620), 1,
      anon_sym_SLASH,
    ACTIONS(7622), 1,
      anon_sym_AMP,
    ACTIONS(7626), 1,
      anon_sym_GT_GT,
    ACTIONS(7632), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7634), 1,
      anon_sym_as,
    ACTIONS(7636), 1,
      anon_sym_is,
    ACTIONS(7638), 1,
      anon_sym_CARET,
    ACTIONS(7640), 1,
      anon_sym_PIPE,
    ACTIONS(7642), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7644), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7646), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7825), 1,
      anon_sym_QMARK,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7614), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7616), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7618), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7624), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7628), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7630), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6320), 4,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
      anon_sym_by,
    STATE(5640), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [105791] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7620), 1,
      anon_sym_SLASH,
    ACTIONS(7622), 1,
      anon_sym_AMP,
    ACTIONS(7626), 1,
      anon_sym_GT_GT,
    ACTIONS(7632), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7634), 1,
      anon_sym_as,
    ACTIONS(7636), 1,
      anon_sym_is,
    ACTIONS(7638), 1,
      anon_sym_CARET,
    ACTIONS(7640), 1,
      anon_sym_PIPE,
    ACTIONS(7642), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7644), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7646), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7825), 1,
      anon_sym_QMARK,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7614), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7616), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7618), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7624), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7628), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7630), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6324), 4,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
      anon_sym_by,
    STATE(5641), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [105930] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7620), 1,
      anon_sym_SLASH,
    ACTIONS(7622), 1,
      anon_sym_AMP,
    ACTIONS(7626), 1,
      anon_sym_GT_GT,
    ACTIONS(7632), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7634), 1,
      anon_sym_as,
    ACTIONS(7636), 1,
      anon_sym_is,
    ACTIONS(7638), 1,
      anon_sym_CARET,
    ACTIONS(7640), 1,
      anon_sym_PIPE,
    ACTIONS(7642), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7644), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7646), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7825), 1,
      anon_sym_QMARK,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7614), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7616), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7618), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7624), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7628), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7630), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5416), 4,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
      anon_sym_by,
    STATE(5642), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [106069] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7620), 1,
      anon_sym_SLASH,
    ACTIONS(7622), 1,
      anon_sym_AMP,
    ACTIONS(7626), 1,
      anon_sym_GT_GT,
    ACTIONS(7632), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7634), 1,
      anon_sym_as,
    ACTIONS(7636), 1,
      anon_sym_is,
    ACTIONS(7638), 1,
      anon_sym_CARET,
    ACTIONS(7640), 1,
      anon_sym_PIPE,
    ACTIONS(7642), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7644), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7646), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7825), 1,
      anon_sym_QMARK,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7614), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7616), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7618), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7624), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7628), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7630), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5644), 4,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
      anon_sym_by,
    STATE(5643), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [106208] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7620), 1,
      anon_sym_SLASH,
    ACTIONS(7622), 1,
      anon_sym_AMP,
    ACTIONS(7626), 1,
      anon_sym_GT_GT,
    ACTIONS(7632), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7634), 1,
      anon_sym_as,
    ACTIONS(7636), 1,
      anon_sym_is,
    ACTIONS(7638), 1,
      anon_sym_CARET,
    ACTIONS(7640), 1,
      anon_sym_PIPE,
    ACTIONS(7642), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7644), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7646), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7825), 1,
      anon_sym_QMARK,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7614), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7616), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7618), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7624), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7628), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7630), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5424), 4,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
      anon_sym_by,
    STATE(5644), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [106347] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7620), 1,
      anon_sym_SLASH,
    ACTIONS(7622), 1,
      anon_sym_AMP,
    ACTIONS(7626), 1,
      anon_sym_GT_GT,
    ACTIONS(7632), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7634), 1,
      anon_sym_as,
    ACTIONS(7636), 1,
      anon_sym_is,
    ACTIONS(7638), 1,
      anon_sym_CARET,
    ACTIONS(7640), 1,
      anon_sym_PIPE,
    ACTIONS(7642), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7644), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7646), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7825), 1,
      anon_sym_QMARK,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7614), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7616), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7618), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7624), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7628), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7630), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6336), 4,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
      anon_sym_by,
    STATE(5645), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [106486] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7620), 1,
      anon_sym_SLASH,
    ACTIONS(7622), 1,
      anon_sym_AMP,
    ACTIONS(7626), 1,
      anon_sym_GT_GT,
    ACTIONS(7632), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7634), 1,
      anon_sym_as,
    ACTIONS(7636), 1,
      anon_sym_is,
    ACTIONS(7638), 1,
      anon_sym_CARET,
    ACTIONS(7640), 1,
      anon_sym_PIPE,
    ACTIONS(7642), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7644), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7646), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7825), 1,
      anon_sym_QMARK,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7614), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7616), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7618), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7624), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7628), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7630), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5572), 4,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
      anon_sym_by,
    STATE(5646), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [106625] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7620), 1,
      anon_sym_SLASH,
    ACTIONS(7622), 1,
      anon_sym_AMP,
    ACTIONS(7626), 1,
      anon_sym_GT_GT,
    ACTIONS(7632), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7634), 1,
      anon_sym_as,
    ACTIONS(7636), 1,
      anon_sym_is,
    ACTIONS(7638), 1,
      anon_sym_CARET,
    ACTIONS(7640), 1,
      anon_sym_PIPE,
    ACTIONS(7642), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7644), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7646), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7825), 1,
      anon_sym_QMARK,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7614), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7616), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7618), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7624), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7628), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7630), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5584), 4,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
      anon_sym_by,
    STATE(5647), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [106764] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7620), 1,
      anon_sym_SLASH,
    ACTIONS(7622), 1,
      anon_sym_AMP,
    ACTIONS(7626), 1,
      anon_sym_GT_GT,
    ACTIONS(7632), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7634), 1,
      anon_sym_as,
    ACTIONS(7636), 1,
      anon_sym_is,
    ACTIONS(7638), 1,
      anon_sym_CARET,
    ACTIONS(7640), 1,
      anon_sym_PIPE,
    ACTIONS(7642), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7644), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7646), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7825), 1,
      anon_sym_QMARK,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7614), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7616), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7618), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7624), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7628), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7630), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5624), 4,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
      anon_sym_by,
    STATE(5648), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [106903] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7620), 1,
      anon_sym_SLASH,
    ACTIONS(7622), 1,
      anon_sym_AMP,
    ACTIONS(7626), 1,
      anon_sym_GT_GT,
    ACTIONS(7632), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7634), 1,
      anon_sym_as,
    ACTIONS(7636), 1,
      anon_sym_is,
    ACTIONS(7638), 1,
      anon_sym_CARET,
    ACTIONS(7640), 1,
      anon_sym_PIPE,
    ACTIONS(7642), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7644), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7646), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7825), 1,
      anon_sym_QMARK,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7614), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7616), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7618), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7624), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7628), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7630), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6190), 4,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
      anon_sym_by,
    STATE(5649), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [107042] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7827), 1,
      anon_sym_and,
    STATE(5650), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6707), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6705), 27,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [107129] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5651), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5658), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5656), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [107214] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6190), 4,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(5652), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [107353] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(7538), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1229), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5653), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(1227), 20,
      anon_sym_SEMI,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
  [107456] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7550), 1,
      anon_sym_SLASH,
    ACTIONS(7554), 1,
      anon_sym_GT_GT,
    ACTIONS(7556), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7560), 1,
      anon_sym_AMP,
    ACTIONS(7566), 1,
      anon_sym_as,
    ACTIONS(7568), 1,
      anon_sym_is,
    ACTIONS(7570), 1,
      anon_sym_CARET,
    ACTIONS(7572), 1,
      anon_sym_PIPE,
    ACTIONS(7574), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7576), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7578), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7580), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7546), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7552), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7558), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7562), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6332), 4,
      anon_sym_EQ_GT,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
    STATE(5654), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [107595] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7556), 1,
      anon_sym_DOT_DOT,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5655), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 18,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_GT,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
  [107702] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7620), 1,
      anon_sym_SLASH,
    ACTIONS(7622), 1,
      anon_sym_AMP,
    ACTIONS(7626), 1,
      anon_sym_GT_GT,
    ACTIONS(7632), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7634), 1,
      anon_sym_as,
    ACTIONS(7636), 1,
      anon_sym_is,
    ACTIONS(7638), 1,
      anon_sym_CARET,
    ACTIONS(7640), 1,
      anon_sym_PIPE,
    ACTIONS(7642), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7644), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7646), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7825), 1,
      anon_sym_QMARK,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7614), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7616), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7618), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7624), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7628), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7630), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6332), 4,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
      anon_sym_by,
    STATE(5656), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [107841] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(7556), 1,
      anon_sym_DOT_DOT,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1229), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5657), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(1227), 20,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_GT,
      anon_sym_switch,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [107944] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7498), 1,
      anon_sym_SLASH,
    ACTIONS(7502), 1,
      anon_sym_GT_GT,
    ACTIONS(7508), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7510), 1,
      anon_sym_as,
    ACTIONS(7512), 1,
      anon_sym_is,
    ACTIONS(7829), 1,
      anon_sym_QMARK,
    ACTIONS(7831), 1,
      anon_sym_CARET,
    ACTIONS(7833), 1,
      anon_sym_PIPE,
    ACTIONS(7835), 1,
      anon_sym_AMP,
    ACTIONS(7837), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7839), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7841), 1,
      anon_sym_QMARK_QMARK,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7492), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7494), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7496), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7500), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7504), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7506), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6320), 4,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
      anon_sym_equals,
    STATE(5658), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [108083] = 35,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7498), 1,
      anon_sym_SLASH,
    ACTIONS(7502), 1,
      anon_sym_GT_GT,
    ACTIONS(7508), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7510), 1,
      anon_sym_as,
    ACTIONS(7512), 1,
      anon_sym_is,
    ACTIONS(7835), 1,
      anon_sym_AMP,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(7492), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7494), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7496), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7500), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7504), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7506), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 8,
      anon_sym_CARET,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_equals,
    STATE(5659), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [108212] = 36,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7498), 1,
      anon_sym_SLASH,
    ACTIONS(7502), 1,
      anon_sym_GT_GT,
    ACTIONS(7508), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7510), 1,
      anon_sym_as,
    ACTIONS(7512), 1,
      anon_sym_is,
    ACTIONS(7831), 1,
      anon_sym_CARET,
    ACTIONS(7835), 1,
      anon_sym_AMP,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(7492), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7494), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7496), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7500), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7504), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7506), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 7,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_equals,
    STATE(5660), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [108343] = 33,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7498), 1,
      anon_sym_SLASH,
    ACTIONS(7502), 1,
      anon_sym_GT_GT,
    ACTIONS(7508), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7510), 1,
      anon_sym_as,
    ACTIONS(7512), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7492), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7494), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7496), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7500), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7506), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    STATE(5661), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 10,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_equals,
  [108468] = 37,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7498), 1,
      anon_sym_SLASH,
    ACTIONS(7502), 1,
      anon_sym_GT_GT,
    ACTIONS(7508), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7510), 1,
      anon_sym_as,
    ACTIONS(7512), 1,
      anon_sym_is,
    ACTIONS(7831), 1,
      anon_sym_CARET,
    ACTIONS(7833), 1,
      anon_sym_PIPE,
    ACTIONS(7835), 1,
      anon_sym_AMP,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7492), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7494), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7496), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7500), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7504), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7506), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 7,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_equals,
    STATE(5662), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [108601] = 38,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7498), 1,
      anon_sym_SLASH,
    ACTIONS(7502), 1,
      anon_sym_GT_GT,
    ACTIONS(7508), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7510), 1,
      anon_sym_as,
    ACTIONS(7512), 1,
      anon_sym_is,
    ACTIONS(7831), 1,
      anon_sym_CARET,
    ACTIONS(7833), 1,
      anon_sym_PIPE,
    ACTIONS(7835), 1,
      anon_sym_AMP,
    ACTIONS(7837), 1,
      anon_sym_AMP_AMP,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7492), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7494), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7496), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7500), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7504), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7506), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 6,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_equals,
    STATE(5663), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [108736] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7498), 1,
      anon_sym_SLASH,
    ACTIONS(7502), 1,
      anon_sym_GT_GT,
    ACTIONS(7508), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7510), 1,
      anon_sym_as,
    ACTIONS(7512), 1,
      anon_sym_is,
    ACTIONS(7831), 1,
      anon_sym_CARET,
    ACTIONS(7833), 1,
      anon_sym_PIPE,
    ACTIONS(7835), 1,
      anon_sym_AMP,
    ACTIONS(7837), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7839), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7841), 1,
      anon_sym_QMARK_QMARK,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7492), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7494), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7496), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7500), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7504), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7506), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 4,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
      anon_sym_equals,
    STATE(5664), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [108875] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7498), 1,
      anon_sym_SLASH,
    ACTIONS(7502), 1,
      anon_sym_GT_GT,
    ACTIONS(7508), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7510), 1,
      anon_sym_as,
    ACTIONS(7512), 1,
      anon_sym_is,
    ACTIONS(7829), 1,
      anon_sym_QMARK,
    ACTIONS(7831), 1,
      anon_sym_CARET,
    ACTIONS(7833), 1,
      anon_sym_PIPE,
    ACTIONS(7835), 1,
      anon_sym_AMP,
    ACTIONS(7837), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7839), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7841), 1,
      anon_sym_QMARK_QMARK,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7492), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7494), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7496), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7500), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7504), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7506), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6324), 4,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
      anon_sym_equals,
    STATE(5665), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [109014] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7498), 1,
      anon_sym_SLASH,
    ACTIONS(7502), 1,
      anon_sym_GT_GT,
    ACTIONS(7508), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7510), 1,
      anon_sym_as,
    ACTIONS(7512), 1,
      anon_sym_is,
    ACTIONS(7829), 1,
      anon_sym_QMARK,
    ACTIONS(7831), 1,
      anon_sym_CARET,
    ACTIONS(7833), 1,
      anon_sym_PIPE,
    ACTIONS(7835), 1,
      anon_sym_AMP,
    ACTIONS(7837), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7839), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7841), 1,
      anon_sym_QMARK_QMARK,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7492), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7494), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7496), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7500), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7504), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7506), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5416), 4,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
      anon_sym_equals,
    STATE(5666), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [109153] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7498), 1,
      anon_sym_SLASH,
    ACTIONS(7502), 1,
      anon_sym_GT_GT,
    ACTIONS(7508), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7510), 1,
      anon_sym_as,
    ACTIONS(7512), 1,
      anon_sym_is,
    ACTIONS(7829), 1,
      anon_sym_QMARK,
    ACTIONS(7831), 1,
      anon_sym_CARET,
    ACTIONS(7833), 1,
      anon_sym_PIPE,
    ACTIONS(7835), 1,
      anon_sym_AMP,
    ACTIONS(7837), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7839), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7841), 1,
      anon_sym_QMARK_QMARK,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7492), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7494), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7496), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7500), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7504), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7506), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5644), 4,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
      anon_sym_equals,
    STATE(5667), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [109292] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7498), 1,
      anon_sym_SLASH,
    ACTIONS(7502), 1,
      anon_sym_GT_GT,
    ACTIONS(7508), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7510), 1,
      anon_sym_as,
    ACTIONS(7512), 1,
      anon_sym_is,
    ACTIONS(7829), 1,
      anon_sym_QMARK,
    ACTIONS(7831), 1,
      anon_sym_CARET,
    ACTIONS(7833), 1,
      anon_sym_PIPE,
    ACTIONS(7835), 1,
      anon_sym_AMP,
    ACTIONS(7837), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7839), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7841), 1,
      anon_sym_QMARK_QMARK,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7492), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7494), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7496), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7500), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7504), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7506), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5424), 4,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
      anon_sym_equals,
    STATE(5668), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [109431] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7498), 1,
      anon_sym_SLASH,
    ACTIONS(7502), 1,
      anon_sym_GT_GT,
    ACTIONS(7508), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7510), 1,
      anon_sym_as,
    ACTIONS(7512), 1,
      anon_sym_is,
    ACTIONS(7829), 1,
      anon_sym_QMARK,
    ACTIONS(7831), 1,
      anon_sym_CARET,
    ACTIONS(7833), 1,
      anon_sym_PIPE,
    ACTIONS(7835), 1,
      anon_sym_AMP,
    ACTIONS(7837), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7839), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7841), 1,
      anon_sym_QMARK_QMARK,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7492), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7494), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7496), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7500), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7504), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7506), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6336), 4,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
      anon_sym_equals,
    STATE(5669), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [109570] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7498), 1,
      anon_sym_SLASH,
    ACTIONS(7502), 1,
      anon_sym_GT_GT,
    ACTIONS(7508), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7510), 1,
      anon_sym_as,
    ACTIONS(7512), 1,
      anon_sym_is,
    ACTIONS(7829), 1,
      anon_sym_QMARK,
    ACTIONS(7831), 1,
      anon_sym_CARET,
    ACTIONS(7833), 1,
      anon_sym_PIPE,
    ACTIONS(7835), 1,
      anon_sym_AMP,
    ACTIONS(7837), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7839), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7841), 1,
      anon_sym_QMARK_QMARK,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7492), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7494), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7496), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7500), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7504), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7506), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5572), 4,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
      anon_sym_equals,
    STATE(5670), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [109709] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7498), 1,
      anon_sym_SLASH,
    ACTIONS(7502), 1,
      anon_sym_GT_GT,
    ACTIONS(7508), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7510), 1,
      anon_sym_as,
    ACTIONS(7512), 1,
      anon_sym_is,
    ACTIONS(7829), 1,
      anon_sym_QMARK,
    ACTIONS(7831), 1,
      anon_sym_CARET,
    ACTIONS(7833), 1,
      anon_sym_PIPE,
    ACTIONS(7835), 1,
      anon_sym_AMP,
    ACTIONS(7837), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7839), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7841), 1,
      anon_sym_QMARK_QMARK,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7492), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7494), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7496), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7500), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7504), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7506), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5584), 4,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
      anon_sym_equals,
    STATE(5671), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [109848] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7498), 1,
      anon_sym_SLASH,
    ACTIONS(7502), 1,
      anon_sym_GT_GT,
    ACTIONS(7508), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7510), 1,
      anon_sym_as,
    ACTIONS(7512), 1,
      anon_sym_is,
    ACTIONS(7829), 1,
      anon_sym_QMARK,
    ACTIONS(7831), 1,
      anon_sym_CARET,
    ACTIONS(7833), 1,
      anon_sym_PIPE,
    ACTIONS(7835), 1,
      anon_sym_AMP,
    ACTIONS(7837), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7839), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7841), 1,
      anon_sym_QMARK_QMARK,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7492), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7494), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7496), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7500), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7504), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7506), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5624), 4,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
      anon_sym_equals,
    STATE(5672), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [109987] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7498), 1,
      anon_sym_SLASH,
    ACTIONS(7502), 1,
      anon_sym_GT_GT,
    ACTIONS(7508), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7510), 1,
      anon_sym_as,
    ACTIONS(7512), 1,
      anon_sym_is,
    ACTIONS(7829), 1,
      anon_sym_QMARK,
    ACTIONS(7831), 1,
      anon_sym_CARET,
    ACTIONS(7833), 1,
      anon_sym_PIPE,
    ACTIONS(7835), 1,
      anon_sym_AMP,
    ACTIONS(7837), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7839), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7841), 1,
      anon_sym_QMARK_QMARK,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7492), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7494), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7496), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7500), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7504), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7506), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6190), 4,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
      anon_sym_equals,
    STATE(5673), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [110126] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5674), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5478), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5476), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [110211] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7186), 1,
      anon_sym_as,
    ACTIONS(7190), 1,
      anon_sym_with,
    ACTIONS(7588), 1,
      anon_sym_SLASH,
    ACTIONS(7590), 1,
      anon_sym_AMP,
    ACTIONS(7594), 1,
      anon_sym_GT_GT,
    ACTIONS(7600), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7602), 1,
      anon_sym_is,
    ACTIONS(7604), 1,
      anon_sym_CARET,
    ACTIONS(7606), 1,
      anon_sym_PIPE,
    ACTIONS(7608), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7610), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7612), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7792), 1,
      anon_sym_QMARK,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7584), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7586), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7592), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7596), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7598), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6320), 4,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_into,
    STATE(5675), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [110350] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7566), 1,
      anon_sym_as,
    ACTIONS(7706), 1,
      anon_sym_SLASH,
    ACTIONS(7710), 1,
      anon_sym_GT_GT,
    ACTIONS(7712), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7716), 1,
      anon_sym_AMP,
    ACTIONS(7722), 1,
      anon_sym_is,
    ACTIONS(7724), 1,
      anon_sym_CARET,
    ACTIONS(7726), 1,
      anon_sym_PIPE,
    ACTIONS(7728), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7730), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7732), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7734), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7702), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7704), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7708), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7714), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7718), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7720), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6332), 4,
      anon_sym_COLON,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
    STATE(5676), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [110489] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7600), 1,
      anon_sym_DOT_DOT,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6330), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5677), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6328), 20,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [110592] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7620), 1,
      anon_sym_SLASH,
    ACTIONS(7622), 1,
      anon_sym_AMP,
    ACTIONS(7626), 1,
      anon_sym_GT_GT,
    ACTIONS(7632), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7634), 1,
      anon_sym_as,
    ACTIONS(7636), 1,
      anon_sym_is,
    ACTIONS(7638), 1,
      anon_sym_CARET,
    ACTIONS(7640), 1,
      anon_sym_PIPE,
    ACTIONS(7642), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7644), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7646), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7825), 1,
      anon_sym_QMARK,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7614), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7616), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7618), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7624), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7628), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7630), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6266), 4,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
      anon_sym_by,
    STATE(5678), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [110731] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7498), 1,
      anon_sym_SLASH,
    ACTIONS(7502), 1,
      anon_sym_GT_GT,
    ACTIONS(7508), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7510), 1,
      anon_sym_as,
    ACTIONS(7512), 1,
      anon_sym_is,
    ACTIONS(7829), 1,
      anon_sym_QMARK,
    ACTIONS(7831), 1,
      anon_sym_CARET,
    ACTIONS(7833), 1,
      anon_sym_PIPE,
    ACTIONS(7835), 1,
      anon_sym_AMP,
    ACTIONS(7837), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7839), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7841), 1,
      anon_sym_QMARK_QMARK,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7492), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7494), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7496), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7500), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7504), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7506), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6332), 4,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
      anon_sym_equals,
    STATE(5679), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [110870] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7620), 1,
      anon_sym_SLASH,
    ACTIONS(7622), 1,
      anon_sym_AMP,
    ACTIONS(7626), 1,
      anon_sym_GT_GT,
    ACTIONS(7632), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7634), 1,
      anon_sym_as,
    ACTIONS(7636), 1,
      anon_sym_is,
    ACTIONS(7638), 1,
      anon_sym_CARET,
    ACTIONS(7640), 1,
      anon_sym_PIPE,
    ACTIONS(7642), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7644), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7646), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7825), 1,
      anon_sym_QMARK,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7614), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7616), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7618), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7624), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7628), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7630), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6270), 4,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
      anon_sym_by,
    STATE(5680), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [111009] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7186), 1,
      anon_sym_as,
    ACTIONS(7190), 1,
      anon_sym_with,
    ACTIONS(7588), 1,
      anon_sym_SLASH,
    ACTIONS(7590), 1,
      anon_sym_AMP,
    ACTIONS(7594), 1,
      anon_sym_GT_GT,
    ACTIONS(7600), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7602), 1,
      anon_sym_is,
    ACTIONS(7604), 1,
      anon_sym_CARET,
    ACTIONS(7606), 1,
      anon_sym_PIPE,
    ACTIONS(7608), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7610), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7612), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7792), 1,
      anon_sym_QMARK,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7584), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7586), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7592), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7596), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7598), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6324), 4,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_into,
    STATE(5681), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [111148] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6444), 1,
      anon_sym_as,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7784), 1,
      anon_sym_SLASH,
    ACTIONS(7788), 1,
      anon_sym_GT_GT,
    ACTIONS(7790), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7805), 1,
      anon_sym_QMARK,
    ACTIONS(7807), 1,
      anon_sym_CARET,
    ACTIONS(7809), 1,
      anon_sym_PIPE,
    ACTIONS(7811), 1,
      anon_sym_AMP,
    ACTIONS(7817), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7819), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7821), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7823), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7780), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7782), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7786), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7803), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7813), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7815), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6266), 4,
      anon_sym_EQ_GT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
    STATE(5682), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [111287] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7186), 1,
      anon_sym_as,
    ACTIONS(7190), 1,
      anon_sym_with,
    ACTIONS(7588), 1,
      anon_sym_SLASH,
    ACTIONS(7590), 1,
      anon_sym_AMP,
    ACTIONS(7594), 1,
      anon_sym_GT_GT,
    ACTIONS(7600), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7602), 1,
      anon_sym_is,
    ACTIONS(7604), 1,
      anon_sym_CARET,
    ACTIONS(7606), 1,
      anon_sym_PIPE,
    ACTIONS(7608), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7610), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7612), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7792), 1,
      anon_sym_QMARK,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7584), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7586), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7592), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7596), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7598), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5416), 4,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_into,
    STATE(5683), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [111426] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7508), 1,
      anon_sym_DOT_DOT,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5684), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 18,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_equals,
      anon_sym_as,
      anon_sym_is,
  [111533] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7186), 1,
      anon_sym_as,
    ACTIONS(7190), 1,
      anon_sym_with,
    ACTIONS(7588), 1,
      anon_sym_SLASH,
    ACTIONS(7590), 1,
      anon_sym_AMP,
    ACTIONS(7594), 1,
      anon_sym_GT_GT,
    ACTIONS(7600), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7602), 1,
      anon_sym_is,
    ACTIONS(7604), 1,
      anon_sym_CARET,
    ACTIONS(7606), 1,
      anon_sym_PIPE,
    ACTIONS(7608), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7610), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7612), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7792), 1,
      anon_sym_QMARK,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7584), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7586), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7592), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7596), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7598), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5644), 4,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_into,
    STATE(5685), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [111672] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7772), 1,
      anon_sym_SLASH,
    ACTIONS(7776), 1,
      anon_sym_GT_GT,
    ACTIONS(7778), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7845), 1,
      anon_sym_QMARK,
    ACTIONS(7847), 1,
      anon_sym_CARET,
    ACTIONS(7849), 1,
      anon_sym_PIPE,
    ACTIONS(7851), 1,
      anon_sym_AMP,
    ACTIONS(7857), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7859), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7861), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7863), 1,
      anon_sym_as,
    ACTIONS(7865), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7768), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7770), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7774), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7843), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7853), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7855), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6320), 4,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
      anon_sym_on,
    STATE(5686), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [111811] = 35,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7772), 1,
      anon_sym_SLASH,
    ACTIONS(7776), 1,
      anon_sym_GT_GT,
    ACTIONS(7778), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7851), 1,
      anon_sym_AMP,
    ACTIONS(7863), 1,
      anon_sym_as,
    ACTIONS(7865), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(7768), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7770), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7774), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7843), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7853), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7855), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 8,
      anon_sym_CARET,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_on,
    STATE(5687), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [111940] = 36,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7772), 1,
      anon_sym_SLASH,
    ACTIONS(7776), 1,
      anon_sym_GT_GT,
    ACTIONS(7778), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7847), 1,
      anon_sym_CARET,
    ACTIONS(7851), 1,
      anon_sym_AMP,
    ACTIONS(7863), 1,
      anon_sym_as,
    ACTIONS(7865), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(7768), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7770), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7774), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7843), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7853), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7855), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 7,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_on,
    STATE(5688), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [112071] = 34,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7772), 1,
      anon_sym_SLASH,
    ACTIONS(7776), 1,
      anon_sym_GT_GT,
    ACTIONS(7778), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7863), 1,
      anon_sym_as,
    ACTIONS(7865), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7768), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7770), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7774), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7843), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7853), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7855), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(6342), 8,
      anon_sym_CARET,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_on,
    STATE(5689), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [112198] = 33,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7772), 1,
      anon_sym_SLASH,
    ACTIONS(7776), 1,
      anon_sym_GT_GT,
    ACTIONS(7778), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7863), 1,
      anon_sym_as,
    ACTIONS(7865), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7768), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7770), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7774), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7843), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7855), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    STATE(5690), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 10,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_on,
  [112323] = 37,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7772), 1,
      anon_sym_SLASH,
    ACTIONS(7776), 1,
      anon_sym_GT_GT,
    ACTIONS(7778), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7847), 1,
      anon_sym_CARET,
    ACTIONS(7849), 1,
      anon_sym_PIPE,
    ACTIONS(7851), 1,
      anon_sym_AMP,
    ACTIONS(7863), 1,
      anon_sym_as,
    ACTIONS(7865), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7768), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7770), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7774), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7843), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7853), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7855), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 7,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_on,
    STATE(5691), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [112456] = 38,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7772), 1,
      anon_sym_SLASH,
    ACTIONS(7776), 1,
      anon_sym_GT_GT,
    ACTIONS(7778), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7847), 1,
      anon_sym_CARET,
    ACTIONS(7849), 1,
      anon_sym_PIPE,
    ACTIONS(7851), 1,
      anon_sym_AMP,
    ACTIONS(7857), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7863), 1,
      anon_sym_as,
    ACTIONS(7865), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7768), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7770), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7774), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7843), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7853), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7855), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 6,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_on,
    STATE(5692), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [112591] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7772), 1,
      anon_sym_SLASH,
    ACTIONS(7776), 1,
      anon_sym_GT_GT,
    ACTIONS(7778), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7847), 1,
      anon_sym_CARET,
    ACTIONS(7849), 1,
      anon_sym_PIPE,
    ACTIONS(7851), 1,
      anon_sym_AMP,
    ACTIONS(7857), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7859), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7861), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7863), 1,
      anon_sym_as,
    ACTIONS(7865), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7768), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7770), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7774), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7843), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7853), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7855), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 4,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
      anon_sym_on,
    STATE(5693), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [112730] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7772), 1,
      anon_sym_SLASH,
    ACTIONS(7776), 1,
      anon_sym_GT_GT,
    ACTIONS(7778), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7845), 1,
      anon_sym_QMARK,
    ACTIONS(7847), 1,
      anon_sym_CARET,
    ACTIONS(7849), 1,
      anon_sym_PIPE,
    ACTIONS(7851), 1,
      anon_sym_AMP,
    ACTIONS(7857), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7859), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7861), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7863), 1,
      anon_sym_as,
    ACTIONS(7865), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7768), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7770), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7774), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7843), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7853), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7855), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6324), 4,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
      anon_sym_on,
    STATE(5694), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [112869] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7772), 1,
      anon_sym_SLASH,
    ACTIONS(7776), 1,
      anon_sym_GT_GT,
    ACTIONS(7778), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7845), 1,
      anon_sym_QMARK,
    ACTIONS(7847), 1,
      anon_sym_CARET,
    ACTIONS(7849), 1,
      anon_sym_PIPE,
    ACTIONS(7851), 1,
      anon_sym_AMP,
    ACTIONS(7857), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7859), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7861), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7863), 1,
      anon_sym_as,
    ACTIONS(7865), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7768), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7770), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7774), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7843), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7853), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7855), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5416), 4,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
      anon_sym_on,
    STATE(5695), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [113008] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7772), 1,
      anon_sym_SLASH,
    ACTIONS(7776), 1,
      anon_sym_GT_GT,
    ACTIONS(7778), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7845), 1,
      anon_sym_QMARK,
    ACTIONS(7847), 1,
      anon_sym_CARET,
    ACTIONS(7849), 1,
      anon_sym_PIPE,
    ACTIONS(7851), 1,
      anon_sym_AMP,
    ACTIONS(7857), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7859), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7861), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7863), 1,
      anon_sym_as,
    ACTIONS(7865), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7768), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7770), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7774), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7843), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7853), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7855), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5644), 4,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
      anon_sym_on,
    STATE(5696), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [113147] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7772), 1,
      anon_sym_SLASH,
    ACTIONS(7776), 1,
      anon_sym_GT_GT,
    ACTIONS(7778), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7845), 1,
      anon_sym_QMARK,
    ACTIONS(7847), 1,
      anon_sym_CARET,
    ACTIONS(7849), 1,
      anon_sym_PIPE,
    ACTIONS(7851), 1,
      anon_sym_AMP,
    ACTIONS(7857), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7859), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7861), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7863), 1,
      anon_sym_as,
    ACTIONS(7865), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7768), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7770), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7774), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7843), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7853), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7855), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5424), 4,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
      anon_sym_on,
    STATE(5697), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [113286] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7772), 1,
      anon_sym_SLASH,
    ACTIONS(7776), 1,
      anon_sym_GT_GT,
    ACTIONS(7778), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7845), 1,
      anon_sym_QMARK,
    ACTIONS(7847), 1,
      anon_sym_CARET,
    ACTIONS(7849), 1,
      anon_sym_PIPE,
    ACTIONS(7851), 1,
      anon_sym_AMP,
    ACTIONS(7857), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7859), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7861), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7863), 1,
      anon_sym_as,
    ACTIONS(7865), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7768), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7770), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7774), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7843), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7853), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7855), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6336), 4,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
      anon_sym_on,
    STATE(5698), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [113425] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7772), 1,
      anon_sym_SLASH,
    ACTIONS(7776), 1,
      anon_sym_GT_GT,
    ACTIONS(7778), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7845), 1,
      anon_sym_QMARK,
    ACTIONS(7847), 1,
      anon_sym_CARET,
    ACTIONS(7849), 1,
      anon_sym_PIPE,
    ACTIONS(7851), 1,
      anon_sym_AMP,
    ACTIONS(7857), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7859), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7861), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7863), 1,
      anon_sym_as,
    ACTIONS(7865), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7768), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7770), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7774), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7843), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7853), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7855), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5572), 4,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
      anon_sym_on,
    STATE(5699), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [113564] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7772), 1,
      anon_sym_SLASH,
    ACTIONS(7776), 1,
      anon_sym_GT_GT,
    ACTIONS(7778), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7845), 1,
      anon_sym_QMARK,
    ACTIONS(7847), 1,
      anon_sym_CARET,
    ACTIONS(7849), 1,
      anon_sym_PIPE,
    ACTIONS(7851), 1,
      anon_sym_AMP,
    ACTIONS(7857), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7859), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7861), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7863), 1,
      anon_sym_as,
    ACTIONS(7865), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7768), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7770), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7774), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7843), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7853), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7855), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5584), 4,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
      anon_sym_on,
    STATE(5700), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [113703] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7772), 1,
      anon_sym_SLASH,
    ACTIONS(7776), 1,
      anon_sym_GT_GT,
    ACTIONS(7778), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7845), 1,
      anon_sym_QMARK,
    ACTIONS(7847), 1,
      anon_sym_CARET,
    ACTIONS(7849), 1,
      anon_sym_PIPE,
    ACTIONS(7851), 1,
      anon_sym_AMP,
    ACTIONS(7857), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7859), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7861), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7863), 1,
      anon_sym_as,
    ACTIONS(7865), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7768), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7770), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7774), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7843), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7853), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7855), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5624), 4,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
      anon_sym_on,
    STATE(5701), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [113842] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7772), 1,
      anon_sym_SLASH,
    ACTIONS(7776), 1,
      anon_sym_GT_GT,
    ACTIONS(7778), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7845), 1,
      anon_sym_QMARK,
    ACTIONS(7847), 1,
      anon_sym_CARET,
    ACTIONS(7849), 1,
      anon_sym_PIPE,
    ACTIONS(7851), 1,
      anon_sym_AMP,
    ACTIONS(7857), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7859), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7861), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7863), 1,
      anon_sym_as,
    ACTIONS(7865), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7768), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7770), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7774), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7843), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7853), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7855), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6190), 4,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
      anon_sym_on,
    STATE(5702), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [113981] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7186), 1,
      anon_sym_as,
    ACTIONS(7190), 1,
      anon_sym_with,
    ACTIONS(7588), 1,
      anon_sym_SLASH,
    ACTIONS(7590), 1,
      anon_sym_AMP,
    ACTIONS(7594), 1,
      anon_sym_GT_GT,
    ACTIONS(7600), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7602), 1,
      anon_sym_is,
    ACTIONS(7604), 1,
      anon_sym_CARET,
    ACTIONS(7606), 1,
      anon_sym_PIPE,
    ACTIONS(7608), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7610), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7612), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7792), 1,
      anon_sym_QMARK,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7584), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7586), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7592), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7596), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7598), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5424), 4,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_into,
    STATE(5703), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [114120] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7186), 1,
      anon_sym_as,
    ACTIONS(7190), 1,
      anon_sym_with,
    ACTIONS(7588), 1,
      anon_sym_SLASH,
    ACTIONS(7590), 1,
      anon_sym_AMP,
    ACTIONS(7594), 1,
      anon_sym_GT_GT,
    ACTIONS(7600), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7602), 1,
      anon_sym_is,
    ACTIONS(7604), 1,
      anon_sym_CARET,
    ACTIONS(7606), 1,
      anon_sym_PIPE,
    ACTIONS(7608), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7610), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7612), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7792), 1,
      anon_sym_QMARK,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7584), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7586), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7592), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7596), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7598), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6336), 4,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_into,
    STATE(5704), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [114259] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6444), 1,
      anon_sym_as,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7784), 1,
      anon_sym_SLASH,
    ACTIONS(7788), 1,
      anon_sym_GT_GT,
    ACTIONS(7790), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7805), 1,
      anon_sym_QMARK,
    ACTIONS(7807), 1,
      anon_sym_CARET,
    ACTIONS(7809), 1,
      anon_sym_PIPE,
    ACTIONS(7811), 1,
      anon_sym_AMP,
    ACTIONS(7817), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7819), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7821), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7823), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7780), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7782), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7786), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7803), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7813), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7815), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6270), 4,
      anon_sym_EQ_GT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
    STATE(5705), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [114398] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7186), 1,
      anon_sym_as,
    ACTIONS(7190), 1,
      anon_sym_with,
    ACTIONS(7588), 1,
      anon_sym_SLASH,
    ACTIONS(7590), 1,
      anon_sym_AMP,
    ACTIONS(7594), 1,
      anon_sym_GT_GT,
    ACTIONS(7600), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7602), 1,
      anon_sym_is,
    ACTIONS(7604), 1,
      anon_sym_CARET,
    ACTIONS(7606), 1,
      anon_sym_PIPE,
    ACTIONS(7608), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7610), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7612), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7792), 1,
      anon_sym_QMARK,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7584), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7586), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7592), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7596), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7598), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5572), 4,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_into,
    STATE(5706), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [114537] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7186), 1,
      anon_sym_as,
    ACTIONS(7190), 1,
      anon_sym_with,
    ACTIONS(7588), 1,
      anon_sym_SLASH,
    ACTIONS(7590), 1,
      anon_sym_AMP,
    ACTIONS(7594), 1,
      anon_sym_GT_GT,
    ACTIONS(7600), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7602), 1,
      anon_sym_is,
    ACTIONS(7604), 1,
      anon_sym_CARET,
    ACTIONS(7606), 1,
      anon_sym_PIPE,
    ACTIONS(7608), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7610), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7612), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7792), 1,
      anon_sym_QMARK,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7584), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7586), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7592), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7596), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7598), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5584), 4,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_into,
    STATE(5707), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [114676] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7186), 1,
      anon_sym_as,
    ACTIONS(7190), 1,
      anon_sym_with,
    ACTIONS(7588), 1,
      anon_sym_SLASH,
    ACTIONS(7590), 1,
      anon_sym_AMP,
    ACTIONS(7594), 1,
      anon_sym_GT_GT,
    ACTIONS(7600), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7602), 1,
      anon_sym_is,
    ACTIONS(7604), 1,
      anon_sym_CARET,
    ACTIONS(7606), 1,
      anon_sym_PIPE,
    ACTIONS(7608), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7610), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7612), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7792), 1,
      anon_sym_QMARK,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7584), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7586), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7592), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7596), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7598), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5624), 4,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_into,
    STATE(5708), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [114815] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7712), 1,
      anon_sym_DOT_DOT,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5709), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 18,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
  [114922] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7498), 1,
      anon_sym_SLASH,
    ACTIONS(7502), 1,
      anon_sym_GT_GT,
    ACTIONS(7508), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7510), 1,
      anon_sym_as,
    ACTIONS(7512), 1,
      anon_sym_is,
    ACTIONS(7829), 1,
      anon_sym_QMARK,
    ACTIONS(7831), 1,
      anon_sym_CARET,
    ACTIONS(7833), 1,
      anon_sym_PIPE,
    ACTIONS(7835), 1,
      anon_sym_AMP,
    ACTIONS(7837), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7839), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7841), 1,
      anon_sym_QMARK_QMARK,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7492), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7494), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7496), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7500), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7504), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7506), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6266), 4,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
      anon_sym_equals,
    STATE(5710), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [115061] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7772), 1,
      anon_sym_SLASH,
    ACTIONS(7776), 1,
      anon_sym_GT_GT,
    ACTIONS(7778), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7845), 1,
      anon_sym_QMARK,
    ACTIONS(7847), 1,
      anon_sym_CARET,
    ACTIONS(7849), 1,
      anon_sym_PIPE,
    ACTIONS(7851), 1,
      anon_sym_AMP,
    ACTIONS(7857), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7859), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7861), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7863), 1,
      anon_sym_as,
    ACTIONS(7865), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7768), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7770), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7774), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7843), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7853), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7855), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6332), 4,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
      anon_sym_on,
    STATE(5711), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [115200] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7498), 1,
      anon_sym_SLASH,
    ACTIONS(7502), 1,
      anon_sym_GT_GT,
    ACTIONS(7508), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7510), 1,
      anon_sym_as,
    ACTIONS(7512), 1,
      anon_sym_is,
    ACTIONS(7829), 1,
      anon_sym_QMARK,
    ACTIONS(7831), 1,
      anon_sym_CARET,
    ACTIONS(7833), 1,
      anon_sym_PIPE,
    ACTIONS(7835), 1,
      anon_sym_AMP,
    ACTIONS(7837), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7839), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7841), 1,
      anon_sym_QMARK_QMARK,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7492), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7494), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7496), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7500), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7504), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7506), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6270), 4,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
      anon_sym_equals,
    STATE(5712), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [115339] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(7712), 1,
      anon_sym_DOT_DOT,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1229), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5713), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(1227), 20,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [115442] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(7632), 1,
      anon_sym_DOT_DOT,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1229), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5714), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(1227), 20,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_by,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [115545] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7778), 1,
      anon_sym_DOT_DOT,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5715), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 18,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_on,
      anon_sym_as,
      anon_sym_is,
  [115652] = 29,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7190), 1,
      anon_sym_with,
    ACTIONS(7588), 1,
      anon_sym_SLASH,
    ACTIONS(7594), 1,
      anon_sym_GT_GT,
    ACTIONS(7600), 1,
      anon_sym_DOT_DOT,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7584), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7586), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7592), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6344), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    STATE(5716), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 14,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
  [115769] = 26,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7190), 1,
      anon_sym_with,
    ACTIONS(7588), 1,
      anon_sym_SLASH,
    ACTIONS(7600), 1,
      anon_sym_DOT_DOT,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7586), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5717), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 16,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
  [115880] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7190), 1,
      anon_sym_with,
    ACTIONS(7600), 1,
      anon_sym_DOT_DOT,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5718), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 18,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
  [115987] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7190), 1,
      anon_sym_with,
    ACTIONS(7588), 1,
      anon_sym_SLASH,
    ACTIONS(7600), 1,
      anon_sym_DOT_DOT,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7584), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7586), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5719), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 16,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
  [116100] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7827), 1,
      anon_sym_and,
    ACTIONS(7867), 1,
      anon_sym_or,
    STATE(5720), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5881), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5879), 26,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [116189] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7827), 1,
      anon_sym_and,
    ACTIONS(7867), 1,
      anon_sym_or,
    STATE(5721), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6594), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6592), 26,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [116278] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7772), 1,
      anon_sym_SLASH,
    ACTIONS(7776), 1,
      anon_sym_GT_GT,
    ACTIONS(7778), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7845), 1,
      anon_sym_QMARK,
    ACTIONS(7847), 1,
      anon_sym_CARET,
    ACTIONS(7849), 1,
      anon_sym_PIPE,
    ACTIONS(7851), 1,
      anon_sym_AMP,
    ACTIONS(7857), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7859), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7861), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7863), 1,
      anon_sym_as,
    ACTIONS(7865), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7768), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7770), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7774), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7843), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7853), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7855), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6266), 4,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
      anon_sym_on,
    STATE(5722), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [116417] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7772), 1,
      anon_sym_SLASH,
    ACTIONS(7776), 1,
      anon_sym_GT_GT,
    ACTIONS(7778), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7845), 1,
      anon_sym_QMARK,
    ACTIONS(7847), 1,
      anon_sym_CARET,
    ACTIONS(7849), 1,
      anon_sym_PIPE,
    ACTIONS(7851), 1,
      anon_sym_AMP,
    ACTIONS(7857), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7859), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7861), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7863), 1,
      anon_sym_as,
    ACTIONS(7865), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7768), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7770), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7774), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7843), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7853), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7855), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6270), 4,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
      anon_sym_on,
    STATE(5723), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [116556] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(7508), 1,
      anon_sym_DOT_DOT,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1229), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5724), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(1227), 20,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_equals,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [116659] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7790), 1,
      anon_sym_DOT_DOT,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5725), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 18,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_GT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
  [116766] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7656), 1,
      anon_sym_QMARK,
    ACTIONS(7658), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(7662), 1,
      anon_sym_is,
    ACTIONS(7742), 1,
      anon_sym_SLASH,
    ACTIONS(7746), 1,
      anon_sym_GT_GT,
    ACTIONS(7750), 1,
      anon_sym_AMP,
    ACTIONS(7756), 1,
      anon_sym_CARET,
    ACTIONS(7758), 1,
      anon_sym_PIPE,
    ACTIONS(7760), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7762), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7764), 1,
      anon_sym_QMARK_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7738), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7740), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7744), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7748), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7752), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7754), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6190), 4,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(5726), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [116905] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(7658), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1229), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5727), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(1227), 20,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [117008] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(7778), 1,
      anon_sym_DOT_DOT,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1229), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5728), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(1227), 20,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_on,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [117111] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(7790), 1,
      anon_sym_DOT_DOT,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1229), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5729), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(1227), 20,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_GT,
      anon_sym_switch,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [117214] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5730), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5684), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5682), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [117299] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5731), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5384), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5382), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [117384] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6444), 1,
      anon_sym_as,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7784), 1,
      anon_sym_SLASH,
    ACTIONS(7788), 1,
      anon_sym_GT_GT,
    ACTIONS(7790), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7805), 1,
      anon_sym_QMARK,
    ACTIONS(7807), 1,
      anon_sym_CARET,
    ACTIONS(7809), 1,
      anon_sym_PIPE,
    ACTIONS(7811), 1,
      anon_sym_AMP,
    ACTIONS(7817), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7819), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7821), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7823), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7780), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7782), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7786), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7803), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7813), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7815), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6332), 4,
      anon_sym_EQ_GT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
    STATE(5732), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [117523] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6444), 1,
      anon_sym_as,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7784), 1,
      anon_sym_SLASH,
    ACTIONS(7788), 1,
      anon_sym_GT_GT,
    ACTIONS(7790), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7805), 1,
      anon_sym_QMARK,
    ACTIONS(7807), 1,
      anon_sym_CARET,
    ACTIONS(7809), 1,
      anon_sym_PIPE,
    ACTIONS(7811), 1,
      anon_sym_AMP,
    ACTIONS(7817), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7819), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7821), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7823), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7780), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7782), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7786), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7803), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7813), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7815), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6320), 4,
      anon_sym_EQ_GT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
    STATE(5733), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [117662] = 35,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6444), 1,
      anon_sym_as,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7784), 1,
      anon_sym_SLASH,
    ACTIONS(7788), 1,
      anon_sym_GT_GT,
    ACTIONS(7790), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7811), 1,
      anon_sym_AMP,
    ACTIONS(7823), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(7780), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7782), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7786), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7803), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7813), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7815), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 8,
      anon_sym_CARET,
      anon_sym_EQ_GT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
    STATE(5734), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [117791] = 36,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6444), 1,
      anon_sym_as,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7784), 1,
      anon_sym_SLASH,
    ACTIONS(7788), 1,
      anon_sym_GT_GT,
    ACTIONS(7790), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7807), 1,
      anon_sym_CARET,
    ACTIONS(7811), 1,
      anon_sym_AMP,
    ACTIONS(7823), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(7780), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7782), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7786), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7803), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7813), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7815), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 7,
      anon_sym_EQ_GT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
    STATE(5735), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [117922] = 34,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6444), 1,
      anon_sym_as,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7784), 1,
      anon_sym_SLASH,
    ACTIONS(7788), 1,
      anon_sym_GT_GT,
    ACTIONS(7790), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7823), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7780), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7782), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7786), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7803), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7813), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7815), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(6342), 8,
      anon_sym_CARET,
      anon_sym_EQ_GT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
    STATE(5736), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [118049] = 33,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6444), 1,
      anon_sym_as,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7784), 1,
      anon_sym_SLASH,
    ACTIONS(7788), 1,
      anon_sym_GT_GT,
    ACTIONS(7790), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7823), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7780), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7782), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7786), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7803), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7815), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    STATE(5737), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 10,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_GT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
  [118174] = 37,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6444), 1,
      anon_sym_as,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7784), 1,
      anon_sym_SLASH,
    ACTIONS(7788), 1,
      anon_sym_GT_GT,
    ACTIONS(7790), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7807), 1,
      anon_sym_CARET,
    ACTIONS(7809), 1,
      anon_sym_PIPE,
    ACTIONS(7811), 1,
      anon_sym_AMP,
    ACTIONS(7823), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7780), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7782), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7786), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7803), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7813), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7815), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 7,
      anon_sym_EQ_GT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
    STATE(5738), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [118307] = 38,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6444), 1,
      anon_sym_as,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7784), 1,
      anon_sym_SLASH,
    ACTIONS(7788), 1,
      anon_sym_GT_GT,
    ACTIONS(7790), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7807), 1,
      anon_sym_CARET,
    ACTIONS(7809), 1,
      anon_sym_PIPE,
    ACTIONS(7811), 1,
      anon_sym_AMP,
    ACTIONS(7817), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7823), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7780), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7782), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7786), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7803), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7813), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7815), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 6,
      anon_sym_EQ_GT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
    STATE(5739), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [118442] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6444), 1,
      anon_sym_as,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7784), 1,
      anon_sym_SLASH,
    ACTIONS(7788), 1,
      anon_sym_GT_GT,
    ACTIONS(7790), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7807), 1,
      anon_sym_CARET,
    ACTIONS(7809), 1,
      anon_sym_PIPE,
    ACTIONS(7811), 1,
      anon_sym_AMP,
    ACTIONS(7817), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7819), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7821), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7823), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7780), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7782), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7786), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7803), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7813), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7815), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 4,
      anon_sym_EQ_GT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
    STATE(5740), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [118581] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6444), 1,
      anon_sym_as,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7784), 1,
      anon_sym_SLASH,
    ACTIONS(7788), 1,
      anon_sym_GT_GT,
    ACTIONS(7790), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7805), 1,
      anon_sym_QMARK,
    ACTIONS(7807), 1,
      anon_sym_CARET,
    ACTIONS(7809), 1,
      anon_sym_PIPE,
    ACTIONS(7811), 1,
      anon_sym_AMP,
    ACTIONS(7817), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7819), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7821), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7823), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7780), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7782), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7786), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7803), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7813), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7815), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6324), 4,
      anon_sym_EQ_GT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
    STATE(5741), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [118720] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6444), 1,
      anon_sym_as,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7784), 1,
      anon_sym_SLASH,
    ACTIONS(7788), 1,
      anon_sym_GT_GT,
    ACTIONS(7790), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7805), 1,
      anon_sym_QMARK,
    ACTIONS(7807), 1,
      anon_sym_CARET,
    ACTIONS(7809), 1,
      anon_sym_PIPE,
    ACTIONS(7811), 1,
      anon_sym_AMP,
    ACTIONS(7817), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7819), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7821), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7823), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7780), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7782), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7786), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7803), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7813), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7815), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5416), 4,
      anon_sym_EQ_GT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
    STATE(5742), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [118859] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6444), 1,
      anon_sym_as,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7784), 1,
      anon_sym_SLASH,
    ACTIONS(7788), 1,
      anon_sym_GT_GT,
    ACTIONS(7790), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7805), 1,
      anon_sym_QMARK,
    ACTIONS(7807), 1,
      anon_sym_CARET,
    ACTIONS(7809), 1,
      anon_sym_PIPE,
    ACTIONS(7811), 1,
      anon_sym_AMP,
    ACTIONS(7817), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7819), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7821), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7823), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7780), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7782), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7786), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7803), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7813), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7815), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5644), 4,
      anon_sym_EQ_GT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
    STATE(5743), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [118998] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5744), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5966), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5964), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [119083] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6444), 1,
      anon_sym_as,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7784), 1,
      anon_sym_SLASH,
    ACTIONS(7788), 1,
      anon_sym_GT_GT,
    ACTIONS(7790), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7805), 1,
      anon_sym_QMARK,
    ACTIONS(7807), 1,
      anon_sym_CARET,
    ACTIONS(7809), 1,
      anon_sym_PIPE,
    ACTIONS(7811), 1,
      anon_sym_AMP,
    ACTIONS(7817), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7819), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7821), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7823), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7780), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7782), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7786), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7803), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7813), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7815), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5424), 4,
      anon_sym_EQ_GT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
    STATE(5745), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [119222] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6444), 1,
      anon_sym_as,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7784), 1,
      anon_sym_SLASH,
    ACTIONS(7788), 1,
      anon_sym_GT_GT,
    ACTIONS(7790), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7805), 1,
      anon_sym_QMARK,
    ACTIONS(7807), 1,
      anon_sym_CARET,
    ACTIONS(7809), 1,
      anon_sym_PIPE,
    ACTIONS(7811), 1,
      anon_sym_AMP,
    ACTIONS(7817), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7819), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7821), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7823), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7780), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7782), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7786), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7803), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7813), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7815), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6336), 4,
      anon_sym_EQ_GT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
    STATE(5746), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [119361] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7799), 1,
      anon_sym_and,
    STATE(5747), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6707), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6705), 27,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [119448] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6444), 1,
      anon_sym_as,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7784), 1,
      anon_sym_SLASH,
    ACTIONS(7788), 1,
      anon_sym_GT_GT,
    ACTIONS(7790), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7805), 1,
      anon_sym_QMARK,
    ACTIONS(7807), 1,
      anon_sym_CARET,
    ACTIONS(7809), 1,
      anon_sym_PIPE,
    ACTIONS(7811), 1,
      anon_sym_AMP,
    ACTIONS(7817), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7819), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7821), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7823), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7780), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7782), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7786), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7803), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7813), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7815), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5572), 4,
      anon_sym_EQ_GT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
    STATE(5748), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [119587] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6444), 1,
      anon_sym_as,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7784), 1,
      anon_sym_SLASH,
    ACTIONS(7788), 1,
      anon_sym_GT_GT,
    ACTIONS(7790), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7805), 1,
      anon_sym_QMARK,
    ACTIONS(7807), 1,
      anon_sym_CARET,
    ACTIONS(7809), 1,
      anon_sym_PIPE,
    ACTIONS(7811), 1,
      anon_sym_AMP,
    ACTIONS(7817), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7819), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7821), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7823), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7780), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7782), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7786), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7803), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7813), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7815), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5584), 4,
      anon_sym_EQ_GT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
    STATE(5749), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [119726] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6434), 1,
      anon_sym_switch,
    ACTIONS(6444), 1,
      anon_sym_as,
    ACTIONS(6448), 1,
      anon_sym_with,
    ACTIONS(7784), 1,
      anon_sym_SLASH,
    ACTIONS(7788), 1,
      anon_sym_GT_GT,
    ACTIONS(7790), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7805), 1,
      anon_sym_QMARK,
    ACTIONS(7807), 1,
      anon_sym_CARET,
    ACTIONS(7809), 1,
      anon_sym_PIPE,
    ACTIONS(7811), 1,
      anon_sym_AMP,
    ACTIONS(7817), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7819), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7821), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7823), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7780), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7782), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7786), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7803), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7813), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7815), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5624), 4,
      anon_sym_EQ_GT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_into,
    STATE(5750), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [119865] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5751), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5662), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5660), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [119950] = 21,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(5346), 1,
      sym_identifier,
    STATE(6827), 1,
      sym_attribute_target_specifier,
    STATE(8073), 1,
      sym__name,
    STATE(8582), 1,
      sym_attribute,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    ACTIONS(1069), 7,
      anon_sym_field,
      anon_sym_event,
      anon_sym_method,
      anon_sym_param,
      anon_sym_property,
      anon_sym_return,
      anon_sym_type,
    STATE(5752), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [120051] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7794), 1,
      anon_sym_into,
    STATE(5613), 1,
      aux_sym__query_body_repeat2,
    STATE(5753), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6476), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6474), 26,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [120140] = 26,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4343), 1,
      anon_sym_LBRACE,
    ACTIONS(4359), 1,
      sym_discard,
    ACTIONS(7467), 1,
      sym__identifier_token,
    ACTIONS(7471), 1,
      anon_sym_LPAREN,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(4153), 1,
      sym_parenthesized_variable_designation,
    STATE(4162), 1,
      sym__variable_designation,
    STATE(4163), 1,
      sym_identifier,
    STATE(6139), 1,
      sym_positional_pattern_clause,
    STATE(6746), 1,
      sym_property_pattern_clause,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9832), 1,
      sym__lambda_parameters,
    ACTIONS(4355), 2,
      anon_sym_and,
      anon_sym_or,
    ACTIONS(4357), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(5754), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [120251] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7869), 1,
      anon_sym_into,
    STATE(5756), 1,
      aux_sym__query_body_repeat2,
    STATE(5755), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6476), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6474), 26,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_GT,
      anon_sym_switch,
      anon_sym_when,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [120340] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7869), 1,
      anon_sym_into,
    STATE(5758), 1,
      aux_sym__query_body_repeat2,
    STATE(5756), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6482), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6480), 26,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_GT,
      anon_sym_switch,
      anon_sym_when,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [120429] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7869), 1,
      anon_sym_into,
    STATE(5759), 1,
      aux_sym__query_body_repeat2,
    STATE(5757), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6482), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6480), 26,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_GT,
      anon_sym_switch,
      anon_sym_when,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [120518] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7871), 1,
      anon_sym_into,
    STATE(5758), 10,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
      aux_sym__query_body_repeat2,
    ACTIONS(6486), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6484), 26,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_GT,
      anon_sym_switch,
      anon_sym_when,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [120605] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7869), 1,
      anon_sym_into,
    STATE(5758), 1,
      aux_sym__query_body_repeat2,
    STATE(5759), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6493), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6491), 26,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_GT,
      anon_sym_switch,
      anon_sym_when,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [120694] = 29,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7522), 1,
      anon_sym_SLASH,
    ACTIONS(7532), 1,
      anon_sym_GT_GT,
    ACTIONS(7538), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7518), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7520), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7530), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6344), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    STATE(5760), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 14,
      anon_sym_SEMI,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
  [120811] = 26,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7522), 1,
      anon_sym_SLASH,
    ACTIONS(7538), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7520), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5761), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 16,
      anon_sym_SEMI,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
  [120922] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7538), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5762), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 18,
      anon_sym_SEMI,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
  [121029] = 35,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(7522), 1,
      anon_sym_SLASH,
    ACTIONS(7528), 1,
      anon_sym_AMP,
    ACTIONS(7532), 1,
      anon_sym_GT_GT,
    ACTIONS(7538), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(7514), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7518), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7520), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7530), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7534), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7536), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 8,
      anon_sym_SEMI,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
    STATE(5763), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [121158] = 36,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(7522), 1,
      anon_sym_SLASH,
    ACTIONS(7524), 1,
      anon_sym_CARET,
    ACTIONS(7528), 1,
      anon_sym_AMP,
    ACTIONS(7532), 1,
      anon_sym_GT_GT,
    ACTIONS(7538), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(7514), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7518), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7520), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7530), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7534), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7536), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 7,
      anon_sym_SEMI,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
    STATE(5764), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [121289] = 34,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(7522), 1,
      anon_sym_SLASH,
    ACTIONS(7532), 1,
      anon_sym_GT_GT,
    ACTIONS(7538), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7514), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7518), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7520), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7530), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7534), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7536), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(6342), 8,
      anon_sym_SEMI,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
    STATE(5765), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [121416] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7522), 1,
      anon_sym_SLASH,
    ACTIONS(7538), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7518), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7520), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5766), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 16,
      anon_sym_SEMI,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
  [121529] = 33,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(7522), 1,
      anon_sym_SLASH,
    ACTIONS(7532), 1,
      anon_sym_GT_GT,
    ACTIONS(7538), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7514), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7518), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7520), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7530), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7536), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    STATE(5767), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 10,
      anon_sym_SEMI,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
  [121654] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(7538), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6330), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5768), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6328), 20,
      anon_sym_SEMI,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
  [121757] = 37,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(7522), 1,
      anon_sym_SLASH,
    ACTIONS(7524), 1,
      anon_sym_CARET,
    ACTIONS(7526), 1,
      anon_sym_PIPE,
    ACTIONS(7528), 1,
      anon_sym_AMP,
    ACTIONS(7532), 1,
      anon_sym_GT_GT,
    ACTIONS(7538), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7514), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7518), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7520), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7530), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7534), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7536), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 7,
      anon_sym_SEMI,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
    STATE(5769), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [121890] = 38,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(7522), 1,
      anon_sym_SLASH,
    ACTIONS(7524), 1,
      anon_sym_CARET,
    ACTIONS(7526), 1,
      anon_sym_PIPE,
    ACTIONS(7528), 1,
      anon_sym_AMP,
    ACTIONS(7532), 1,
      anon_sym_GT_GT,
    ACTIONS(7538), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7540), 1,
      anon_sym_AMP_AMP,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7514), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7518), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7520), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7530), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7534), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7536), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 6,
      anon_sym_SEMI,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
    STATE(5770), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [122025] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(7522), 1,
      anon_sym_SLASH,
    ACTIONS(7524), 1,
      anon_sym_CARET,
    ACTIONS(7526), 1,
      anon_sym_PIPE,
    ACTIONS(7528), 1,
      anon_sym_AMP,
    ACTIONS(7532), 1,
      anon_sym_GT_GT,
    ACTIONS(7538), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7540), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7542), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7544), 1,
      anon_sym_QMARK_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7514), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7518), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7520), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7530), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7534), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7536), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 4,
      anon_sym_SEMI,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
    STATE(5771), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [122164] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5772), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5962), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5960), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [122249] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5773), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5863), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5861), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [122334] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5774), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5867), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5865), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [122419] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5775), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5873), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(4310), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [122504] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(7516), 1,
      anon_sym_QMARK,
    ACTIONS(7522), 1,
      anon_sym_SLASH,
    ACTIONS(7524), 1,
      anon_sym_CARET,
    ACTIONS(7526), 1,
      anon_sym_PIPE,
    ACTIONS(7528), 1,
      anon_sym_AMP,
    ACTIONS(7532), 1,
      anon_sym_GT_GT,
    ACTIONS(7538), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7540), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7542), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7544), 1,
      anon_sym_QMARK_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7514), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7518), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7520), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7530), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7534), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7536), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5416), 4,
      anon_sym_SEMI,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
    STATE(5776), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [122643] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5777), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5972), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5970), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [122728] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7874), 1,
      anon_sym_into,
    STATE(5779), 1,
      aux_sym__query_body_repeat2,
    STATE(5778), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6476), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6474), 26,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_when,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [122817] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7874), 1,
      anon_sym_into,
    STATE(5781), 1,
      aux_sym__query_body_repeat2,
    STATE(5779), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6482), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6480), 26,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_when,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [122906] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7874), 1,
      anon_sym_into,
    STATE(5782), 1,
      aux_sym__query_body_repeat2,
    STATE(5780), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6482), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6480), 26,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_when,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [122995] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7876), 1,
      anon_sym_into,
    STATE(5781), 10,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
      aux_sym__query_body_repeat2,
    ACTIONS(6486), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6484), 26,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_when,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [123082] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7874), 1,
      anon_sym_into,
    STATE(5781), 1,
      aux_sym__query_body_repeat2,
    STATE(5782), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6493), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6491), 26,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_when,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [123171] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(7516), 1,
      anon_sym_QMARK,
    ACTIONS(7522), 1,
      anon_sym_SLASH,
    ACTIONS(7524), 1,
      anon_sym_CARET,
    ACTIONS(7526), 1,
      anon_sym_PIPE,
    ACTIONS(7528), 1,
      anon_sym_AMP,
    ACTIONS(7532), 1,
      anon_sym_GT_GT,
    ACTIONS(7538), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7540), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7542), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7544), 1,
      anon_sym_QMARK_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7514), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7518), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7520), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7530), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7534), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7536), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5644), 4,
      anon_sym_SEMI,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
    STATE(5783), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [123310] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5784), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5915), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5913), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [123395] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5785), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5915), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5913), 28,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [123480] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(7516), 1,
      anon_sym_QMARK,
    ACTIONS(7522), 1,
      anon_sym_SLASH,
    ACTIONS(7524), 1,
      anon_sym_CARET,
    ACTIONS(7526), 1,
      anon_sym_PIPE,
    ACTIONS(7528), 1,
      anon_sym_AMP,
    ACTIONS(7532), 1,
      anon_sym_GT_GT,
    ACTIONS(7538), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7540), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7542), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7544), 1,
      anon_sym_QMARK_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7514), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7518), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7520), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7530), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7534), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7536), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5424), 4,
      anon_sym_SEMI,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
    STATE(5786), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [123619] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(7516), 1,
      anon_sym_QMARK,
    ACTIONS(7522), 1,
      anon_sym_SLASH,
    ACTIONS(7524), 1,
      anon_sym_CARET,
    ACTIONS(7526), 1,
      anon_sym_PIPE,
    ACTIONS(7528), 1,
      anon_sym_AMP,
    ACTIONS(7532), 1,
      anon_sym_GT_GT,
    ACTIONS(7538), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7540), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7542), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7544), 1,
      anon_sym_QMARK_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7514), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7518), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7520), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7530), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7534), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7536), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6336), 4,
      anon_sym_SEMI,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
    STATE(5787), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [123758] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(7516), 1,
      anon_sym_QMARK,
    ACTIONS(7522), 1,
      anon_sym_SLASH,
    ACTIONS(7524), 1,
      anon_sym_CARET,
    ACTIONS(7526), 1,
      anon_sym_PIPE,
    ACTIONS(7528), 1,
      anon_sym_AMP,
    ACTIONS(7532), 1,
      anon_sym_GT_GT,
    ACTIONS(7538), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7540), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7542), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7544), 1,
      anon_sym_QMARK_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7514), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7518), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7520), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7530), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7534), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7536), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5572), 4,
      anon_sym_SEMI,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
    STATE(5788), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [123897] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5644), 4,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(5789), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [124036] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7881), 1,
      anon_sym_QMARK,
    ACTIONS(7887), 1,
      anon_sym_SLASH,
    ACTIONS(7889), 1,
      anon_sym_CARET,
    ACTIONS(7891), 1,
      anon_sym_PIPE,
    ACTIONS(7893), 1,
      anon_sym_AMP,
    ACTIONS(7897), 1,
      anon_sym_GT_GT,
    ACTIONS(7903), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7905), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7907), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7909), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7911), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7883), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7885), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7895), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7899), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7901), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6320), 3,
      anon_sym_EQ_GT,
      anon_sym_and,
      anon_sym_or,
    STATE(5790), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [124174] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(7913), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(5791), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [124312] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7190), 1,
      anon_sym_with,
    ACTIONS(7405), 1,
      anon_sym_as,
    ACTIONS(7427), 1,
      anon_sym_QMARK,
    ACTIONS(7433), 1,
      anon_sym_SLASH,
    ACTIONS(7435), 1,
      anon_sym_CARET,
    ACTIONS(7437), 1,
      anon_sym_PIPE,
    ACTIONS(7439), 1,
      anon_sym_AMP,
    ACTIONS(7443), 1,
      anon_sym_GT_GT,
    ACTIONS(7449), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7451), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7453), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7455), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7457), 1,
      anon_sym_is,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7425), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7429), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7431), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7441), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7445), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7447), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6190), 3,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
    STATE(5792), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [124450] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7915), 1,
      anon_sym_and,
    STATE(5793), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6707), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6705), 26,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_GT,
      anon_sym_switch,
      anon_sym_when,
      anon_sym_DOT_DOT,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [124536] = 42,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(2677), 1,
      anon_sym_COMMA,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(7917), 1,
      anon_sym_RBRACK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    STATE(8473), 1,
      aux_sym_array_rank_specifier_repeat1,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(5794), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [124678] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7449), 1,
      anon_sym_DOT_DOT,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1229), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5795), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(1227), 19,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [124780] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4343), 1,
      anon_sym_LBRACE,
    ACTIONS(4359), 1,
      sym_discard,
    ACTIONS(7467), 1,
      sym__identifier_token,
    ACTIONS(7471), 1,
      anon_sym_LPAREN,
    ACTIONS(7919), 1,
      anon_sym_COMMA,
    ACTIONS(7922), 1,
      anon_sym_RPAREN,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(4153), 1,
      sym_parenthesized_variable_designation,
    STATE(4162), 1,
      sym__variable_designation,
    STATE(6139), 1,
      sym_positional_pattern_clause,
    STATE(6746), 1,
      sym_property_pattern_clause,
    STATE(7797), 1,
      sym_identifier,
    STATE(9076), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    ACTIONS(4355), 2,
      anon_sym_and,
      anon_sym_or,
    STATE(5796), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [124892] = 29,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7928), 1,
      anon_sym_SLASH,
    ACTIONS(7932), 1,
      anon_sym_GT_GT,
    ACTIONS(7934), 1,
      anon_sym_DOT_DOT,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7924), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7926), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7930), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6344), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    STATE(5797), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 13,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_equals,
      anon_sym_as,
      anon_sym_is,
  [125008] = 26,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7928), 1,
      anon_sym_SLASH,
    ACTIONS(7934), 1,
      anon_sym_DOT_DOT,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7926), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5798), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 15,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_equals,
      anon_sym_as,
      anon_sym_is,
  [125118] = 35,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7928), 1,
      anon_sym_SLASH,
    ACTIONS(7932), 1,
      anon_sym_GT_GT,
    ACTIONS(7934), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7938), 1,
      anon_sym_AMP,
    ACTIONS(7944), 1,
      anon_sym_as,
    ACTIONS(7946), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(7924), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7926), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7930), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7936), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7940), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7942), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 7,
      anon_sym_CARET,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_equals,
    STATE(5799), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [125246] = 36,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7928), 1,
      anon_sym_SLASH,
    ACTIONS(7932), 1,
      anon_sym_GT_GT,
    ACTIONS(7934), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7938), 1,
      anon_sym_AMP,
    ACTIONS(7944), 1,
      anon_sym_as,
    ACTIONS(7946), 1,
      anon_sym_is,
    ACTIONS(7948), 1,
      anon_sym_CARET,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(7924), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7926), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7930), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7936), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7940), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7942), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 6,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_equals,
    STATE(5800), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [125376] = 34,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7928), 1,
      anon_sym_SLASH,
    ACTIONS(7932), 1,
      anon_sym_GT_GT,
    ACTIONS(7934), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7944), 1,
      anon_sym_as,
    ACTIONS(7946), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7924), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7926), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7930), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7936), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7940), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7942), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(6342), 7,
      anon_sym_CARET,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_equals,
    STATE(5801), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [125502] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7928), 1,
      anon_sym_SLASH,
    ACTIONS(7934), 1,
      anon_sym_DOT_DOT,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7924), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7926), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5802), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 15,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_equals,
      anon_sym_as,
      anon_sym_is,
  [125614] = 33,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7928), 1,
      anon_sym_SLASH,
    ACTIONS(7932), 1,
      anon_sym_GT_GT,
    ACTIONS(7934), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7944), 1,
      anon_sym_as,
    ACTIONS(7946), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7924), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7926), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7930), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7936), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7942), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(6342), 9,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_equals,
    STATE(5803), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [125738] = 37,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7928), 1,
      anon_sym_SLASH,
    ACTIONS(7932), 1,
      anon_sym_GT_GT,
    ACTIONS(7934), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7938), 1,
      anon_sym_AMP,
    ACTIONS(7944), 1,
      anon_sym_as,
    ACTIONS(7946), 1,
      anon_sym_is,
    ACTIONS(7948), 1,
      anon_sym_CARET,
    ACTIONS(7950), 1,
      anon_sym_PIPE,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7924), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7926), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7930), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7936), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7940), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7942), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 6,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_equals,
    STATE(5804), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [125870] = 38,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7928), 1,
      anon_sym_SLASH,
    ACTIONS(7932), 1,
      anon_sym_GT_GT,
    ACTIONS(7934), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7938), 1,
      anon_sym_AMP,
    ACTIONS(7944), 1,
      anon_sym_as,
    ACTIONS(7946), 1,
      anon_sym_is,
    ACTIONS(7948), 1,
      anon_sym_CARET,
    ACTIONS(7950), 1,
      anon_sym_PIPE,
    ACTIONS(7952), 1,
      anon_sym_AMP_AMP,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7924), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7926), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7930), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7936), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7940), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7942), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 5,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_equals,
    STATE(5805), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [126004] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7928), 1,
      anon_sym_SLASH,
    ACTIONS(7932), 1,
      anon_sym_GT_GT,
    ACTIONS(7934), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7938), 1,
      anon_sym_AMP,
    ACTIONS(7944), 1,
      anon_sym_as,
    ACTIONS(7946), 1,
      anon_sym_is,
    ACTIONS(7948), 1,
      anon_sym_CARET,
    ACTIONS(7950), 1,
      anon_sym_PIPE,
    ACTIONS(7952), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7954), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7956), 1,
      anon_sym_QMARK_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7924), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7926), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7930), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7936), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7940), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7942), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 3,
      anon_sym_and,
      anon_sym_or,
      anon_sym_equals,
    STATE(5806), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [126142] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7958), 1,
      anon_sym_into,
    STATE(5835), 1,
      aux_sym__query_body_repeat2,
    STATE(5807), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6476), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6474), 25,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [126230] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(7242), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1229), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5808), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(1227), 19,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
  [126332] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7190), 1,
      anon_sym_with,
    ACTIONS(7405), 1,
      anon_sym_as,
    ACTIONS(7427), 1,
      anon_sym_QMARK,
    ACTIONS(7433), 1,
      anon_sym_SLASH,
    ACTIONS(7435), 1,
      anon_sym_CARET,
    ACTIONS(7437), 1,
      anon_sym_PIPE,
    ACTIONS(7439), 1,
      anon_sym_AMP,
    ACTIONS(7443), 1,
      anon_sym_GT_GT,
    ACTIONS(7449), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7451), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7453), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7455), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7457), 1,
      anon_sym_is,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7425), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7429), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7431), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7441), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7445), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7447), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5424), 3,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
    STATE(5809), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [126470] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7928), 1,
      anon_sym_SLASH,
    ACTIONS(7932), 1,
      anon_sym_GT_GT,
    ACTIONS(7934), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7938), 1,
      anon_sym_AMP,
    ACTIONS(7944), 1,
      anon_sym_as,
    ACTIONS(7946), 1,
      anon_sym_is,
    ACTIONS(7948), 1,
      anon_sym_CARET,
    ACTIONS(7950), 1,
      anon_sym_PIPE,
    ACTIONS(7952), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7954), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7956), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7960), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7924), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7926), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7930), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7936), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7940), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7942), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6320), 3,
      anon_sym_and,
      anon_sym_or,
      anon_sym_equals,
    STATE(5810), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [126608] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(7934), 1,
      anon_sym_DOT_DOT,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6330), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5811), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6328), 19,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_equals,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [126710] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7928), 1,
      anon_sym_SLASH,
    ACTIONS(7932), 1,
      anon_sym_GT_GT,
    ACTIONS(7934), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7938), 1,
      anon_sym_AMP,
    ACTIONS(7944), 1,
      anon_sym_as,
    ACTIONS(7946), 1,
      anon_sym_is,
    ACTIONS(7948), 1,
      anon_sym_CARET,
    ACTIONS(7950), 1,
      anon_sym_PIPE,
    ACTIONS(7952), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7954), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7956), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7960), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7924), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7926), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7930), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7936), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7940), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7942), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6324), 3,
      anon_sym_and,
      anon_sym_or,
      anon_sym_equals,
    STATE(5812), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [126848] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7928), 1,
      anon_sym_SLASH,
    ACTIONS(7932), 1,
      anon_sym_GT_GT,
    ACTIONS(7934), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7938), 1,
      anon_sym_AMP,
    ACTIONS(7944), 1,
      anon_sym_as,
    ACTIONS(7946), 1,
      anon_sym_is,
    ACTIONS(7948), 1,
      anon_sym_CARET,
    ACTIONS(7950), 1,
      anon_sym_PIPE,
    ACTIONS(7952), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7954), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7956), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7960), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7924), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7926), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7930), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7936), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7940), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7942), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5416), 3,
      anon_sym_and,
      anon_sym_or,
      anon_sym_equals,
    STATE(5813), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [126986] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7928), 1,
      anon_sym_SLASH,
    ACTIONS(7932), 1,
      anon_sym_GT_GT,
    ACTIONS(7934), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7938), 1,
      anon_sym_AMP,
    ACTIONS(7944), 1,
      anon_sym_as,
    ACTIONS(7946), 1,
      anon_sym_is,
    ACTIONS(7948), 1,
      anon_sym_CARET,
    ACTIONS(7950), 1,
      anon_sym_PIPE,
    ACTIONS(7952), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7954), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7956), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7960), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7924), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7926), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7930), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7936), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7940), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7942), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5644), 3,
      anon_sym_and,
      anon_sym_or,
      anon_sym_equals,
    STATE(5814), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [127124] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7928), 1,
      anon_sym_SLASH,
    ACTIONS(7932), 1,
      anon_sym_GT_GT,
    ACTIONS(7934), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7938), 1,
      anon_sym_AMP,
    ACTIONS(7944), 1,
      anon_sym_as,
    ACTIONS(7946), 1,
      anon_sym_is,
    ACTIONS(7948), 1,
      anon_sym_CARET,
    ACTIONS(7950), 1,
      anon_sym_PIPE,
    ACTIONS(7952), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7954), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7956), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7960), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7924), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7926), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7930), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7936), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7940), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7942), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5424), 3,
      anon_sym_and,
      anon_sym_or,
      anon_sym_equals,
    STATE(5815), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [127262] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7928), 1,
      anon_sym_SLASH,
    ACTIONS(7932), 1,
      anon_sym_GT_GT,
    ACTIONS(7934), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7938), 1,
      anon_sym_AMP,
    ACTIONS(7944), 1,
      anon_sym_as,
    ACTIONS(7946), 1,
      anon_sym_is,
    ACTIONS(7948), 1,
      anon_sym_CARET,
    ACTIONS(7950), 1,
      anon_sym_PIPE,
    ACTIONS(7952), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7954), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7956), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7960), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7924), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7926), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7930), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7936), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7940), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7942), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6336), 3,
      anon_sym_and,
      anon_sym_or,
      anon_sym_equals,
    STATE(5816), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [127400] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7928), 1,
      anon_sym_SLASH,
    ACTIONS(7932), 1,
      anon_sym_GT_GT,
    ACTIONS(7934), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7938), 1,
      anon_sym_AMP,
    ACTIONS(7944), 1,
      anon_sym_as,
    ACTIONS(7946), 1,
      anon_sym_is,
    ACTIONS(7948), 1,
      anon_sym_CARET,
    ACTIONS(7950), 1,
      anon_sym_PIPE,
    ACTIONS(7952), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7954), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7956), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7960), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7924), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7926), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7930), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7936), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7940), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7942), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5572), 3,
      anon_sym_and,
      anon_sym_or,
      anon_sym_equals,
    STATE(5817), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [127538] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7928), 1,
      anon_sym_SLASH,
    ACTIONS(7932), 1,
      anon_sym_GT_GT,
    ACTIONS(7934), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7938), 1,
      anon_sym_AMP,
    ACTIONS(7944), 1,
      anon_sym_as,
    ACTIONS(7946), 1,
      anon_sym_is,
    ACTIONS(7948), 1,
      anon_sym_CARET,
    ACTIONS(7950), 1,
      anon_sym_PIPE,
    ACTIONS(7952), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7954), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7956), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7960), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7924), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7926), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7930), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7936), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7940), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7942), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5584), 3,
      anon_sym_and,
      anon_sym_or,
      anon_sym_equals,
    STATE(5818), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [127676] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7928), 1,
      anon_sym_SLASH,
    ACTIONS(7932), 1,
      anon_sym_GT_GT,
    ACTIONS(7934), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7938), 1,
      anon_sym_AMP,
    ACTIONS(7944), 1,
      anon_sym_as,
    ACTIONS(7946), 1,
      anon_sym_is,
    ACTIONS(7948), 1,
      anon_sym_CARET,
    ACTIONS(7950), 1,
      anon_sym_PIPE,
    ACTIONS(7952), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7954), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7956), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7960), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7924), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7926), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7930), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7936), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7940), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7942), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5624), 3,
      anon_sym_and,
      anon_sym_or,
      anon_sym_equals,
    STATE(5819), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [127814] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7928), 1,
      anon_sym_SLASH,
    ACTIONS(7932), 1,
      anon_sym_GT_GT,
    ACTIONS(7934), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7938), 1,
      anon_sym_AMP,
    ACTIONS(7944), 1,
      anon_sym_as,
    ACTIONS(7946), 1,
      anon_sym_is,
    ACTIONS(7948), 1,
      anon_sym_CARET,
    ACTIONS(7950), 1,
      anon_sym_PIPE,
    ACTIONS(7952), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7954), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7956), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7960), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7924), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7926), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7930), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7936), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7940), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7942), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6190), 3,
      anon_sym_and,
      anon_sym_or,
      anon_sym_equals,
    STATE(5820), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [127952] = 42,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(7962), 1,
      anon_sym_COMMA,
    ACTIONS(7964), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    STATE(8422), 1,
      aux_sym_for_statement_repeat1,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(5821), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [128094] = 42,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(7962), 1,
      anon_sym_COMMA,
    ACTIONS(7966), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    STATE(8424), 1,
      aux_sym_for_statement_repeat1,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(5822), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [128236] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7190), 1,
      anon_sym_with,
    ACTIONS(7405), 1,
      anon_sym_as,
    ACTIONS(7427), 1,
      anon_sym_QMARK,
    ACTIONS(7433), 1,
      anon_sym_SLASH,
    ACTIONS(7435), 1,
      anon_sym_CARET,
    ACTIONS(7437), 1,
      anon_sym_PIPE,
    ACTIONS(7439), 1,
      anon_sym_AMP,
    ACTIONS(7443), 1,
      anon_sym_GT_GT,
    ACTIONS(7449), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7451), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7453), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7455), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7457), 1,
      anon_sym_is,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7425), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7429), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7431), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7441), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7445), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7447), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6336), 3,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
    STATE(5823), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [128374] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7220), 1,
      anon_sym_QMARK,
    ACTIONS(7226), 1,
      anon_sym_SLASH,
    ACTIONS(7228), 1,
      anon_sym_CARET,
    ACTIONS(7230), 1,
      anon_sym_PIPE,
    ACTIONS(7232), 1,
      anon_sym_AMP,
    ACTIONS(7236), 1,
      anon_sym_GT_GT,
    ACTIONS(7242), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7244), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7246), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7248), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7218), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7222), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7224), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7234), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7238), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7240), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5424), 3,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
    STATE(5824), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [128512] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7190), 1,
      anon_sym_with,
    ACTIONS(7405), 1,
      anon_sym_as,
    ACTIONS(7427), 1,
      anon_sym_QMARK,
    ACTIONS(7433), 1,
      anon_sym_SLASH,
    ACTIONS(7435), 1,
      anon_sym_CARET,
    ACTIONS(7437), 1,
      anon_sym_PIPE,
    ACTIONS(7439), 1,
      anon_sym_AMP,
    ACTIONS(7443), 1,
      anon_sym_GT_GT,
    ACTIONS(7449), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7451), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7453), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7455), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7457), 1,
      anon_sym_is,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7425), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7429), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7431), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7441), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7445), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7447), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5572), 3,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
    STATE(5825), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [128650] = 42,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(2677), 1,
      anon_sym_COMMA,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(7968), 1,
      anon_sym_RBRACK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    STATE(8530), 1,
      aux_sym_array_rank_specifier_repeat1,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(5826), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [128792] = 29,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7226), 1,
      anon_sym_SLASH,
    ACTIONS(7236), 1,
      anon_sym_GT_GT,
    ACTIONS(7242), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7222), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7224), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7234), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6344), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    STATE(5827), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 13,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
  [128908] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7190), 1,
      anon_sym_with,
    ACTIONS(7405), 1,
      anon_sym_as,
    ACTIONS(7427), 1,
      anon_sym_QMARK,
    ACTIONS(7433), 1,
      anon_sym_SLASH,
    ACTIONS(7435), 1,
      anon_sym_CARET,
    ACTIONS(7437), 1,
      anon_sym_PIPE,
    ACTIONS(7439), 1,
      anon_sym_AMP,
    ACTIONS(7443), 1,
      anon_sym_GT_GT,
    ACTIONS(7449), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7451), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7453), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7455), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7457), 1,
      anon_sym_is,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7425), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7429), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7431), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7441), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7445), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7447), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5584), 3,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
    STATE(5828), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [129046] = 26,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7226), 1,
      anon_sym_SLASH,
    ACTIONS(7242), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7224), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5829), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 15,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
  [129156] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7242), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5830), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 17,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
  [129262] = 35,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7226), 1,
      anon_sym_SLASH,
    ACTIONS(7232), 1,
      anon_sym_AMP,
    ACTIONS(7236), 1,
      anon_sym_GT_GT,
    ACTIONS(7242), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(7218), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7222), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7224), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7234), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7238), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7240), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 7,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
    STATE(5831), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [129390] = 36,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7226), 1,
      anon_sym_SLASH,
    ACTIONS(7228), 1,
      anon_sym_CARET,
    ACTIONS(7232), 1,
      anon_sym_AMP,
    ACTIONS(7236), 1,
      anon_sym_GT_GT,
    ACTIONS(7242), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(7218), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7222), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7224), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7234), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7238), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7240), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 6,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
    STATE(5832), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [129520] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4343), 1,
      anon_sym_LBRACE,
    ACTIONS(4359), 1,
      sym_discard,
    ACTIONS(7467), 1,
      sym__identifier_token,
    ACTIONS(7471), 1,
      anon_sym_LPAREN,
    ACTIONS(7919), 1,
      anon_sym_COMMA,
    ACTIONS(7970), 1,
      anon_sym_RPAREN,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(4153), 1,
      sym_parenthesized_variable_designation,
    STATE(4162), 1,
      sym__variable_designation,
    STATE(6139), 1,
      sym_positional_pattern_clause,
    STATE(6746), 1,
      sym_property_pattern_clause,
    STATE(7797), 1,
      sym_identifier,
    STATE(9076), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    ACTIONS(4355), 2,
      anon_sym_and,
      anon_sym_or,
    STATE(5833), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [129632] = 34,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7226), 1,
      anon_sym_SLASH,
    ACTIONS(7236), 1,
      anon_sym_GT_GT,
    ACTIONS(7242), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7218), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7222), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7224), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7234), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7238), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7240), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(6342), 7,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
    STATE(5834), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [129758] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7958), 1,
      anon_sym_into,
    STATE(5886), 1,
      aux_sym__query_body_repeat2,
    STATE(5835), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6482), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6480), 25,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [129846] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7958), 1,
      anon_sym_into,
    STATE(5898), 1,
      aux_sym__query_body_repeat2,
    STATE(5836), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6482), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6480), 25,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [129934] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7226), 1,
      anon_sym_SLASH,
    ACTIONS(7242), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7222), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7224), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5837), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 15,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
  [130046] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7190), 1,
      anon_sym_with,
    ACTIONS(7405), 1,
      anon_sym_as,
    ACTIONS(7427), 1,
      anon_sym_QMARK,
    ACTIONS(7433), 1,
      anon_sym_SLASH,
    ACTIONS(7435), 1,
      anon_sym_CARET,
    ACTIONS(7437), 1,
      anon_sym_PIPE,
    ACTIONS(7439), 1,
      anon_sym_AMP,
    ACTIONS(7443), 1,
      anon_sym_GT_GT,
    ACTIONS(7449), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7451), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7453), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7455), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7457), 1,
      anon_sym_is,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7425), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7429), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7431), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7441), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7445), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7447), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5624), 3,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
    STATE(5838), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [130184] = 42,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(7972), 1,
      anon_sym_COMMA,
    ACTIONS(7974), 1,
      anon_sym_RBRACE,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    STATE(8596), 1,
      aux_sym_for_statement_repeat1,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(5839), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [130326] = 33,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7226), 1,
      anon_sym_SLASH,
    ACTIONS(7236), 1,
      anon_sym_GT_GT,
    ACTIONS(7242), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7218), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7222), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7224), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7234), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7240), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(6342), 9,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
    STATE(5840), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [130450] = 29,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7980), 1,
      anon_sym_SLASH,
    ACTIONS(7984), 1,
      anon_sym_GT_GT,
    ACTIONS(7986), 1,
      anon_sym_DOT_DOT,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7976), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7978), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7982), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6344), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    STATE(5841), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 13,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_on,
      anon_sym_as,
      anon_sym_is,
  [130566] = 26,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7980), 1,
      anon_sym_SLASH,
    ACTIONS(7986), 1,
      anon_sym_DOT_DOT,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7978), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5842), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 15,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_on,
      anon_sym_as,
      anon_sym_is,
  [130676] = 35,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7980), 1,
      anon_sym_SLASH,
    ACTIONS(7984), 1,
      anon_sym_GT_GT,
    ACTIONS(7986), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7990), 1,
      anon_sym_AMP,
    ACTIONS(7996), 1,
      anon_sym_as,
    ACTIONS(7998), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(7976), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7978), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7982), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7988), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7992), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7994), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 7,
      anon_sym_CARET,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_on,
    STATE(5843), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [130804] = 36,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7980), 1,
      anon_sym_SLASH,
    ACTIONS(7984), 1,
      anon_sym_GT_GT,
    ACTIONS(7986), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7990), 1,
      anon_sym_AMP,
    ACTIONS(7996), 1,
      anon_sym_as,
    ACTIONS(7998), 1,
      anon_sym_is,
    ACTIONS(8000), 1,
      anon_sym_CARET,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(7976), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7978), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7982), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7988), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7992), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7994), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 6,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_on,
    STATE(5844), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [130934] = 34,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7980), 1,
      anon_sym_SLASH,
    ACTIONS(7984), 1,
      anon_sym_GT_GT,
    ACTIONS(7986), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7996), 1,
      anon_sym_as,
    ACTIONS(7998), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7976), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7978), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7982), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7988), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7992), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7994), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(6342), 7,
      anon_sym_CARET,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_on,
    STATE(5845), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [131060] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7980), 1,
      anon_sym_SLASH,
    ACTIONS(7986), 1,
      anon_sym_DOT_DOT,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7976), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7978), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5846), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 15,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_on,
      anon_sym_as,
      anon_sym_is,
  [131172] = 33,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7980), 1,
      anon_sym_SLASH,
    ACTIONS(7984), 1,
      anon_sym_GT_GT,
    ACTIONS(7986), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7996), 1,
      anon_sym_as,
    ACTIONS(7998), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7976), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7978), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7982), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7988), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7994), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(6342), 9,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_on,
    STATE(5847), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [131296] = 37,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7980), 1,
      anon_sym_SLASH,
    ACTIONS(7984), 1,
      anon_sym_GT_GT,
    ACTIONS(7986), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7990), 1,
      anon_sym_AMP,
    ACTIONS(7996), 1,
      anon_sym_as,
    ACTIONS(7998), 1,
      anon_sym_is,
    ACTIONS(8000), 1,
      anon_sym_CARET,
    ACTIONS(8002), 1,
      anon_sym_PIPE,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7976), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7978), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7982), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7988), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7992), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7994), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 6,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_on,
    STATE(5848), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [131428] = 38,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7980), 1,
      anon_sym_SLASH,
    ACTIONS(7984), 1,
      anon_sym_GT_GT,
    ACTIONS(7986), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7990), 1,
      anon_sym_AMP,
    ACTIONS(7996), 1,
      anon_sym_as,
    ACTIONS(7998), 1,
      anon_sym_is,
    ACTIONS(8000), 1,
      anon_sym_CARET,
    ACTIONS(8002), 1,
      anon_sym_PIPE,
    ACTIONS(8004), 1,
      anon_sym_AMP_AMP,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7976), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7978), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7982), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7988), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7992), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7994), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 5,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_on,
    STATE(5849), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [131562] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7980), 1,
      anon_sym_SLASH,
    ACTIONS(7984), 1,
      anon_sym_GT_GT,
    ACTIONS(7986), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7990), 1,
      anon_sym_AMP,
    ACTIONS(7996), 1,
      anon_sym_as,
    ACTIONS(7998), 1,
      anon_sym_is,
    ACTIONS(8000), 1,
      anon_sym_CARET,
    ACTIONS(8002), 1,
      anon_sym_PIPE,
    ACTIONS(8004), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8006), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8008), 1,
      anon_sym_QMARK_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7976), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7978), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7982), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7988), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7992), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7994), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 3,
      anon_sym_and,
      anon_sym_or,
      anon_sym_on,
    STATE(5850), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [131700] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(7242), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6330), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5851), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6328), 19,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
  [131802] = 37,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7226), 1,
      anon_sym_SLASH,
    ACTIONS(7228), 1,
      anon_sym_CARET,
    ACTIONS(7230), 1,
      anon_sym_PIPE,
    ACTIONS(7232), 1,
      anon_sym_AMP,
    ACTIONS(7236), 1,
      anon_sym_GT_GT,
    ACTIONS(7242), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7218), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7222), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7224), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7234), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7238), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7240), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 6,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
    STATE(5852), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [131934] = 38,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7226), 1,
      anon_sym_SLASH,
    ACTIONS(7228), 1,
      anon_sym_CARET,
    ACTIONS(7230), 1,
      anon_sym_PIPE,
    ACTIONS(7232), 1,
      anon_sym_AMP,
    ACTIONS(7236), 1,
      anon_sym_GT_GT,
    ACTIONS(7242), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7244), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7218), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7222), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7224), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7234), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7238), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7240), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 5,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
    STATE(5853), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [132068] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7226), 1,
      anon_sym_SLASH,
    ACTIONS(7228), 1,
      anon_sym_CARET,
    ACTIONS(7230), 1,
      anon_sym_PIPE,
    ACTIONS(7232), 1,
      anon_sym_AMP,
    ACTIONS(7236), 1,
      anon_sym_GT_GT,
    ACTIONS(7242), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7244), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7246), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7248), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7218), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7222), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7224), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7234), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7238), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7240), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 3,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
    STATE(5854), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [132206] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7980), 1,
      anon_sym_SLASH,
    ACTIONS(7984), 1,
      anon_sym_GT_GT,
    ACTIONS(7986), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7990), 1,
      anon_sym_AMP,
    ACTIONS(7996), 1,
      anon_sym_as,
    ACTIONS(7998), 1,
      anon_sym_is,
    ACTIONS(8000), 1,
      anon_sym_CARET,
    ACTIONS(8002), 1,
      anon_sym_PIPE,
    ACTIONS(8004), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8006), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8008), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8010), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7976), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7978), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7982), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7988), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7992), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7994), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6320), 3,
      anon_sym_and,
      anon_sym_or,
      anon_sym_on,
    STATE(5855), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [132344] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(7986), 1,
      anon_sym_DOT_DOT,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6330), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5856), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6328), 19,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_on,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [132446] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7980), 1,
      anon_sym_SLASH,
    ACTIONS(7984), 1,
      anon_sym_GT_GT,
    ACTIONS(7986), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7990), 1,
      anon_sym_AMP,
    ACTIONS(7996), 1,
      anon_sym_as,
    ACTIONS(7998), 1,
      anon_sym_is,
    ACTIONS(8000), 1,
      anon_sym_CARET,
    ACTIONS(8002), 1,
      anon_sym_PIPE,
    ACTIONS(8004), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8006), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8008), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8010), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7976), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7978), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7982), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7988), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7992), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7994), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6324), 3,
      anon_sym_and,
      anon_sym_or,
      anon_sym_on,
    STATE(5857), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [132584] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7980), 1,
      anon_sym_SLASH,
    ACTIONS(7984), 1,
      anon_sym_GT_GT,
    ACTIONS(7986), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7990), 1,
      anon_sym_AMP,
    ACTIONS(7996), 1,
      anon_sym_as,
    ACTIONS(7998), 1,
      anon_sym_is,
    ACTIONS(8000), 1,
      anon_sym_CARET,
    ACTIONS(8002), 1,
      anon_sym_PIPE,
    ACTIONS(8004), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8006), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8008), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8010), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7976), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7978), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7982), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7988), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7992), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7994), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5416), 3,
      anon_sym_and,
      anon_sym_or,
      anon_sym_on,
    STATE(5858), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [132722] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7980), 1,
      anon_sym_SLASH,
    ACTIONS(7984), 1,
      anon_sym_GT_GT,
    ACTIONS(7986), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7990), 1,
      anon_sym_AMP,
    ACTIONS(7996), 1,
      anon_sym_as,
    ACTIONS(7998), 1,
      anon_sym_is,
    ACTIONS(8000), 1,
      anon_sym_CARET,
    ACTIONS(8002), 1,
      anon_sym_PIPE,
    ACTIONS(8004), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8006), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8008), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8010), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7976), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7978), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7982), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7988), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7992), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7994), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5644), 3,
      anon_sym_and,
      anon_sym_or,
      anon_sym_on,
    STATE(5859), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [132860] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7980), 1,
      anon_sym_SLASH,
    ACTIONS(7984), 1,
      anon_sym_GT_GT,
    ACTIONS(7986), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7990), 1,
      anon_sym_AMP,
    ACTIONS(7996), 1,
      anon_sym_as,
    ACTIONS(7998), 1,
      anon_sym_is,
    ACTIONS(8000), 1,
      anon_sym_CARET,
    ACTIONS(8002), 1,
      anon_sym_PIPE,
    ACTIONS(8004), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8006), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8008), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8010), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7976), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7978), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7982), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7988), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7992), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7994), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5424), 3,
      anon_sym_and,
      anon_sym_or,
      anon_sym_on,
    STATE(5860), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [132998] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7980), 1,
      anon_sym_SLASH,
    ACTIONS(7984), 1,
      anon_sym_GT_GT,
    ACTIONS(7986), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7990), 1,
      anon_sym_AMP,
    ACTIONS(7996), 1,
      anon_sym_as,
    ACTIONS(7998), 1,
      anon_sym_is,
    ACTIONS(8000), 1,
      anon_sym_CARET,
    ACTIONS(8002), 1,
      anon_sym_PIPE,
    ACTIONS(8004), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8006), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8008), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8010), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7976), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7978), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7982), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7988), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7992), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7994), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6336), 3,
      anon_sym_and,
      anon_sym_or,
      anon_sym_on,
    STATE(5861), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [133136] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7980), 1,
      anon_sym_SLASH,
    ACTIONS(7984), 1,
      anon_sym_GT_GT,
    ACTIONS(7986), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7990), 1,
      anon_sym_AMP,
    ACTIONS(7996), 1,
      anon_sym_as,
    ACTIONS(7998), 1,
      anon_sym_is,
    ACTIONS(8000), 1,
      anon_sym_CARET,
    ACTIONS(8002), 1,
      anon_sym_PIPE,
    ACTIONS(8004), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8006), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8008), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8010), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7976), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7978), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7982), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7988), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7992), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7994), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5572), 3,
      anon_sym_and,
      anon_sym_or,
      anon_sym_on,
    STATE(5862), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [133274] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7980), 1,
      anon_sym_SLASH,
    ACTIONS(7984), 1,
      anon_sym_GT_GT,
    ACTIONS(7986), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7990), 1,
      anon_sym_AMP,
    ACTIONS(7996), 1,
      anon_sym_as,
    ACTIONS(7998), 1,
      anon_sym_is,
    ACTIONS(8000), 1,
      anon_sym_CARET,
    ACTIONS(8002), 1,
      anon_sym_PIPE,
    ACTIONS(8004), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8006), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8008), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8010), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7976), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7978), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7982), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7988), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7992), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7994), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5584), 3,
      anon_sym_and,
      anon_sym_or,
      anon_sym_on,
    STATE(5863), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [133412] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7980), 1,
      anon_sym_SLASH,
    ACTIONS(7984), 1,
      anon_sym_GT_GT,
    ACTIONS(7986), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7990), 1,
      anon_sym_AMP,
    ACTIONS(7996), 1,
      anon_sym_as,
    ACTIONS(7998), 1,
      anon_sym_is,
    ACTIONS(8000), 1,
      anon_sym_CARET,
    ACTIONS(8002), 1,
      anon_sym_PIPE,
    ACTIONS(8004), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8006), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8008), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8010), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7976), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7978), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7982), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7988), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7992), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7994), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5624), 3,
      anon_sym_and,
      anon_sym_or,
      anon_sym_on,
    STATE(5864), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [133550] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7980), 1,
      anon_sym_SLASH,
    ACTIONS(7984), 1,
      anon_sym_GT_GT,
    ACTIONS(7986), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7990), 1,
      anon_sym_AMP,
    ACTIONS(7996), 1,
      anon_sym_as,
    ACTIONS(7998), 1,
      anon_sym_is,
    ACTIONS(8000), 1,
      anon_sym_CARET,
    ACTIONS(8002), 1,
      anon_sym_PIPE,
    ACTIONS(8004), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8006), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8008), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8010), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7976), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7978), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7982), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7988), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7992), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7994), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6190), 3,
      anon_sym_and,
      anon_sym_or,
      anon_sym_on,
    STATE(5865), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [133688] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8012), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
    STATE(5866), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [133826] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8012), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
    STATE(5867), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [133964] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8014), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
    STATE(5868), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [134102] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8016), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
    STATE(5869), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [134240] = 42,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(8018), 1,
      anon_sym_COMMA,
    ACTIONS(8020), 1,
      anon_sym_RBRACE,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    STATE(8519), 1,
      aux_sym_for_statement_repeat1,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(5870), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [134382] = 42,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(7962), 1,
      anon_sym_COMMA,
    ACTIONS(8022), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    STATE(8656), 1,
      aux_sym_for_statement_repeat1,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(5871), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [134524] = 42,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(2677), 1,
      anon_sym_COMMA,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(8024), 1,
      anon_sym_RBRACK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    STATE(8547), 1,
      aux_sym_array_rank_specifier_repeat1,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(5872), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [134666] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7190), 1,
      anon_sym_with,
    ACTIONS(7405), 1,
      anon_sym_as,
    ACTIONS(7427), 1,
      anon_sym_QMARK,
    ACTIONS(7433), 1,
      anon_sym_SLASH,
    ACTIONS(7435), 1,
      anon_sym_CARET,
    ACTIONS(7437), 1,
      anon_sym_PIPE,
    ACTIONS(7439), 1,
      anon_sym_AMP,
    ACTIONS(7443), 1,
      anon_sym_GT_GT,
    ACTIONS(7449), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7451), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7453), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7455), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7457), 1,
      anon_sym_is,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7425), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7429), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7431), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7441), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7445), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7447), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6320), 3,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
    STATE(5873), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [134804] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4343), 1,
      anon_sym_LBRACE,
    ACTIONS(4359), 1,
      sym_discard,
    ACTIONS(7467), 1,
      sym__identifier_token,
    ACTIONS(7471), 1,
      anon_sym_LPAREN,
    ACTIONS(7919), 1,
      anon_sym_COMMA,
    ACTIONS(8026), 1,
      anon_sym_RPAREN,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(4153), 1,
      sym_parenthesized_variable_designation,
    STATE(4162), 1,
      sym__variable_designation,
    STATE(6139), 1,
      sym_positional_pattern_clause,
    STATE(6746), 1,
      sym_property_pattern_clause,
    STATE(7797), 1,
      sym_identifier,
    STATE(9076), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    ACTIONS(4355), 2,
      anon_sym_and,
      anon_sym_or,
    STATE(5874), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [134916] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4343), 1,
      anon_sym_LBRACE,
    ACTIONS(4359), 1,
      sym_discard,
    ACTIONS(7467), 1,
      sym__identifier_token,
    ACTIONS(7471), 1,
      anon_sym_LPAREN,
    ACTIONS(7919), 1,
      anon_sym_COMMA,
    ACTIONS(8028), 1,
      anon_sym_RPAREN,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(4153), 1,
      sym_parenthesized_variable_designation,
    STATE(4162), 1,
      sym__variable_designation,
    STATE(6139), 1,
      sym_positional_pattern_clause,
    STATE(6746), 1,
      sym_property_pattern_clause,
    STATE(7797), 1,
      sym_identifier,
    STATE(9076), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    ACTIONS(4355), 2,
      anon_sym_and,
      anon_sym_or,
    STATE(5875), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [135028] = 29,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7887), 1,
      anon_sym_SLASH,
    ACTIONS(7897), 1,
      anon_sym_GT_GT,
    ACTIONS(7903), 1,
      anon_sym_DOT_DOT,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7883), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7885), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7895), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6344), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    STATE(5876), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 13,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_GT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
  [135144] = 26,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7887), 1,
      anon_sym_SLASH,
    ACTIONS(7903), 1,
      anon_sym_DOT_DOT,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7885), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5877), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 15,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_GT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
  [135254] = 35,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7887), 1,
      anon_sym_SLASH,
    ACTIONS(7893), 1,
      anon_sym_AMP,
    ACTIONS(7897), 1,
      anon_sym_GT_GT,
    ACTIONS(7903), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7911), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(7879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7883), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7885), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7895), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7899), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7901), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 7,
      anon_sym_CARET,
      anon_sym_EQ_GT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(5878), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [135382] = 36,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7887), 1,
      anon_sym_SLASH,
    ACTIONS(7889), 1,
      anon_sym_CARET,
    ACTIONS(7893), 1,
      anon_sym_AMP,
    ACTIONS(7897), 1,
      anon_sym_GT_GT,
    ACTIONS(7903), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7911), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(7879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7883), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7885), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7895), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7899), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7901), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 6,
      anon_sym_EQ_GT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(5879), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [135512] = 34,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7887), 1,
      anon_sym_SLASH,
    ACTIONS(7897), 1,
      anon_sym_GT_GT,
    ACTIONS(7903), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7911), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7883), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7885), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7895), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7899), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7901), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(6342), 7,
      anon_sym_CARET,
      anon_sym_EQ_GT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(5880), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [135638] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7887), 1,
      anon_sym_SLASH,
    ACTIONS(7903), 1,
      anon_sym_DOT_DOT,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7883), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7885), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5881), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 15,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_GT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
  [135750] = 33,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7887), 1,
      anon_sym_SLASH,
    ACTIONS(7897), 1,
      anon_sym_GT_GT,
    ACTIONS(7903), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7911), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7883), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7885), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7895), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7901), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(6342), 9,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_GT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(5882), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [135874] = 37,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7887), 1,
      anon_sym_SLASH,
    ACTIONS(7889), 1,
      anon_sym_CARET,
    ACTIONS(7891), 1,
      anon_sym_PIPE,
    ACTIONS(7893), 1,
      anon_sym_AMP,
    ACTIONS(7897), 1,
      anon_sym_GT_GT,
    ACTIONS(7903), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7911), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7883), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7885), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7895), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7899), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7901), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 6,
      anon_sym_EQ_GT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(5883), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [136006] = 38,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7887), 1,
      anon_sym_SLASH,
    ACTIONS(7889), 1,
      anon_sym_CARET,
    ACTIONS(7891), 1,
      anon_sym_PIPE,
    ACTIONS(7893), 1,
      anon_sym_AMP,
    ACTIONS(7897), 1,
      anon_sym_GT_GT,
    ACTIONS(7903), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7905), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7911), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7883), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7885), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7895), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7899), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7901), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 5,
      anon_sym_EQ_GT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(5884), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [136140] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7887), 1,
      anon_sym_SLASH,
    ACTIONS(7889), 1,
      anon_sym_CARET,
    ACTIONS(7891), 1,
      anon_sym_PIPE,
    ACTIONS(7893), 1,
      anon_sym_AMP,
    ACTIONS(7897), 1,
      anon_sym_GT_GT,
    ACTIONS(7903), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7905), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7907), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7909), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7911), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7883), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7885), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7895), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7899), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7901), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 3,
      anon_sym_EQ_GT,
      anon_sym_and,
      anon_sym_or,
    STATE(5885), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [136278] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8030), 1,
      anon_sym_into,
    STATE(5886), 10,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
      aux_sym__query_body_repeat2,
    ACTIONS(6486), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6484), 25,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [136364] = 42,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(7962), 1,
      anon_sym_COMMA,
    ACTIONS(8033), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    STATE(8639), 1,
      aux_sym_for_statement_repeat1,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(5887), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [136506] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(7903), 1,
      anon_sym_DOT_DOT,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6330), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5888), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6328), 19,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_GT,
      anon_sym_switch,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [136608] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7881), 1,
      anon_sym_QMARK,
    ACTIONS(7887), 1,
      anon_sym_SLASH,
    ACTIONS(7889), 1,
      anon_sym_CARET,
    ACTIONS(7891), 1,
      anon_sym_PIPE,
    ACTIONS(7893), 1,
      anon_sym_AMP,
    ACTIONS(7897), 1,
      anon_sym_GT_GT,
    ACTIONS(7903), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7905), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7907), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7909), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7911), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7883), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7885), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7895), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7899), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7901), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6324), 3,
      anon_sym_EQ_GT,
      anon_sym_and,
      anon_sym_or,
    STATE(5889), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [136746] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7881), 1,
      anon_sym_QMARK,
    ACTIONS(7887), 1,
      anon_sym_SLASH,
    ACTIONS(7889), 1,
      anon_sym_CARET,
    ACTIONS(7891), 1,
      anon_sym_PIPE,
    ACTIONS(7893), 1,
      anon_sym_AMP,
    ACTIONS(7897), 1,
      anon_sym_GT_GT,
    ACTIONS(7903), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7905), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7907), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7909), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7911), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7883), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7885), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7895), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7899), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7901), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5416), 3,
      anon_sym_EQ_GT,
      anon_sym_and,
      anon_sym_or,
    STATE(5890), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [136884] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7881), 1,
      anon_sym_QMARK,
    ACTIONS(7887), 1,
      anon_sym_SLASH,
    ACTIONS(7889), 1,
      anon_sym_CARET,
    ACTIONS(7891), 1,
      anon_sym_PIPE,
    ACTIONS(7893), 1,
      anon_sym_AMP,
    ACTIONS(7897), 1,
      anon_sym_GT_GT,
    ACTIONS(7903), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7905), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7907), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7909), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7911), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7883), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7885), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7895), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7899), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7901), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5644), 3,
      anon_sym_EQ_GT,
      anon_sym_and,
      anon_sym_or,
    STATE(5891), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [137022] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7881), 1,
      anon_sym_QMARK,
    ACTIONS(7887), 1,
      anon_sym_SLASH,
    ACTIONS(7889), 1,
      anon_sym_CARET,
    ACTIONS(7891), 1,
      anon_sym_PIPE,
    ACTIONS(7893), 1,
      anon_sym_AMP,
    ACTIONS(7897), 1,
      anon_sym_GT_GT,
    ACTIONS(7903), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7905), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7907), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7909), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7911), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7883), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7885), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7895), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7899), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7901), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5424), 3,
      anon_sym_EQ_GT,
      anon_sym_and,
      anon_sym_or,
    STATE(5892), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [137160] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7881), 1,
      anon_sym_QMARK,
    ACTIONS(7887), 1,
      anon_sym_SLASH,
    ACTIONS(7889), 1,
      anon_sym_CARET,
    ACTIONS(7891), 1,
      anon_sym_PIPE,
    ACTIONS(7893), 1,
      anon_sym_AMP,
    ACTIONS(7897), 1,
      anon_sym_GT_GT,
    ACTIONS(7903), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7905), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7907), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7909), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7911), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7883), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7885), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7895), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7899), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7901), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6336), 3,
      anon_sym_EQ_GT,
      anon_sym_and,
      anon_sym_or,
    STATE(5893), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [137298] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7881), 1,
      anon_sym_QMARK,
    ACTIONS(7887), 1,
      anon_sym_SLASH,
    ACTIONS(7889), 1,
      anon_sym_CARET,
    ACTIONS(7891), 1,
      anon_sym_PIPE,
    ACTIONS(7893), 1,
      anon_sym_AMP,
    ACTIONS(7897), 1,
      anon_sym_GT_GT,
    ACTIONS(7903), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7905), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7907), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7909), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7911), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7883), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7885), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7895), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7899), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7901), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5572), 3,
      anon_sym_EQ_GT,
      anon_sym_and,
      anon_sym_or,
    STATE(5894), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [137436] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7881), 1,
      anon_sym_QMARK,
    ACTIONS(7887), 1,
      anon_sym_SLASH,
    ACTIONS(7889), 1,
      anon_sym_CARET,
    ACTIONS(7891), 1,
      anon_sym_PIPE,
    ACTIONS(7893), 1,
      anon_sym_AMP,
    ACTIONS(7897), 1,
      anon_sym_GT_GT,
    ACTIONS(7903), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7905), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7907), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7909), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7911), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7883), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7885), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7895), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7899), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7901), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5584), 3,
      anon_sym_EQ_GT,
      anon_sym_and,
      anon_sym_or,
    STATE(5895), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [137574] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7881), 1,
      anon_sym_QMARK,
    ACTIONS(7887), 1,
      anon_sym_SLASH,
    ACTIONS(7889), 1,
      anon_sym_CARET,
    ACTIONS(7891), 1,
      anon_sym_PIPE,
    ACTIONS(7893), 1,
      anon_sym_AMP,
    ACTIONS(7897), 1,
      anon_sym_GT_GT,
    ACTIONS(7903), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7905), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7907), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7909), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7911), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7883), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7885), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7895), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7899), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7901), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5624), 3,
      anon_sym_EQ_GT,
      anon_sym_and,
      anon_sym_or,
    STATE(5896), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [137712] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7881), 1,
      anon_sym_QMARK,
    ACTIONS(7887), 1,
      anon_sym_SLASH,
    ACTIONS(7889), 1,
      anon_sym_CARET,
    ACTIONS(7891), 1,
      anon_sym_PIPE,
    ACTIONS(7893), 1,
      anon_sym_AMP,
    ACTIONS(7897), 1,
      anon_sym_GT_GT,
    ACTIONS(7903), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7905), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7907), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7909), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7911), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7883), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7885), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7895), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7899), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7901), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6190), 3,
      anon_sym_EQ_GT,
      anon_sym_and,
      anon_sym_or,
    STATE(5897), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [137850] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7958), 1,
      anon_sym_into,
    STATE(5886), 1,
      aux_sym__query_body_repeat2,
    STATE(5898), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6493), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6491), 25,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [137938] = 29,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7190), 1,
      anon_sym_with,
    ACTIONS(7433), 1,
      anon_sym_SLASH,
    ACTIONS(7443), 1,
      anon_sym_GT_GT,
    ACTIONS(7449), 1,
      anon_sym_DOT_DOT,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7429), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7431), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7441), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6344), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    STATE(5899), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 13,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
  [138054] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4343), 1,
      anon_sym_LBRACE,
    ACTIONS(4359), 1,
      sym_discard,
    ACTIONS(7467), 1,
      sym__identifier_token,
    ACTIONS(7471), 1,
      anon_sym_LPAREN,
    ACTIONS(7919), 1,
      anon_sym_COMMA,
    ACTIONS(8035), 1,
      anon_sym_RPAREN,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(4153), 1,
      sym_parenthesized_variable_designation,
    STATE(4162), 1,
      sym__variable_designation,
    STATE(6139), 1,
      sym_positional_pattern_clause,
    STATE(6746), 1,
      sym_property_pattern_clause,
    STATE(7797), 1,
      sym_identifier,
    STATE(9076), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    ACTIONS(4355), 2,
      anon_sym_and,
      anon_sym_or,
    STATE(5900), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [138166] = 26,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7190), 1,
      anon_sym_with,
    ACTIONS(7433), 1,
      anon_sym_SLASH,
    ACTIONS(7449), 1,
      anon_sym_DOT_DOT,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7431), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5901), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 15,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
  [138276] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7190), 1,
      anon_sym_with,
    ACTIONS(7449), 1,
      anon_sym_DOT_DOT,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5902), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 17,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
  [138382] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4343), 1,
      anon_sym_LBRACE,
    ACTIONS(4359), 1,
      sym_discard,
    ACTIONS(7467), 1,
      sym__identifier_token,
    ACTIONS(7471), 1,
      anon_sym_LPAREN,
    ACTIONS(7919), 1,
      anon_sym_COMMA,
    ACTIONS(8037), 1,
      anon_sym_RPAREN,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(4153), 1,
      sym_parenthesized_variable_designation,
    STATE(4162), 1,
      sym__variable_designation,
    STATE(6139), 1,
      sym_positional_pattern_clause,
    STATE(6746), 1,
      sym_property_pattern_clause,
    STATE(7797), 1,
      sym_identifier,
    STATE(9076), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    ACTIONS(4355), 2,
      anon_sym_and,
      anon_sym_or,
    STATE(5903), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [138494] = 35,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7190), 1,
      anon_sym_with,
    ACTIONS(7405), 1,
      anon_sym_as,
    ACTIONS(7433), 1,
      anon_sym_SLASH,
    ACTIONS(7439), 1,
      anon_sym_AMP,
    ACTIONS(7443), 1,
      anon_sym_GT_GT,
    ACTIONS(7449), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7457), 1,
      anon_sym_is,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7425), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7429), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7431), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7441), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7445), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7447), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 7,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(5904), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [138622] = 42,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(8039), 1,
      anon_sym_COMMA,
    ACTIONS(8041), 1,
      anon_sym_RBRACE,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    STATE(8433), 1,
      aux_sym_for_statement_repeat1,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(5905), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [138764] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4343), 1,
      anon_sym_LBRACE,
    ACTIONS(4359), 1,
      sym_discard,
    ACTIONS(7467), 1,
      sym__identifier_token,
    ACTIONS(7471), 1,
      anon_sym_LPAREN,
    ACTIONS(7919), 1,
      anon_sym_COMMA,
    ACTIONS(8043), 1,
      anon_sym_RPAREN,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(4153), 1,
      sym_parenthesized_variable_designation,
    STATE(4162), 1,
      sym__variable_designation,
    STATE(6139), 1,
      sym_positional_pattern_clause,
    STATE(6746), 1,
      sym_property_pattern_clause,
    STATE(7797), 1,
      sym_identifier,
    STATE(9076), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    ACTIONS(4355), 2,
      anon_sym_and,
      anon_sym_or,
    STATE(5906), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [138876] = 36,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7190), 1,
      anon_sym_with,
    ACTIONS(7405), 1,
      anon_sym_as,
    ACTIONS(7433), 1,
      anon_sym_SLASH,
    ACTIONS(7435), 1,
      anon_sym_CARET,
    ACTIONS(7439), 1,
      anon_sym_AMP,
    ACTIONS(7443), 1,
      anon_sym_GT_GT,
    ACTIONS(7449), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7457), 1,
      anon_sym_is,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7425), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7429), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7431), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7441), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7445), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7447), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 6,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(5907), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [139006] = 41,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(8045), 1,
      anon_sym_SEMI,
    ACTIONS(8049), 1,
      anon_sym_QMARK,
    ACTIONS(8055), 1,
      anon_sym_SLASH,
    ACTIONS(8057), 1,
      anon_sym_CARET,
    ACTIONS(8059), 1,
      anon_sym_PIPE,
    ACTIONS(8061), 1,
      anon_sym_AMP,
    ACTIONS(8065), 1,
      anon_sym_GT_GT,
    ACTIONS(8071), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8073), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8075), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8077), 1,
      anon_sym_QMARK_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6320), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(8047), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8051), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8053), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8063), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8067), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8069), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(5908), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [139146] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4343), 1,
      anon_sym_LBRACE,
    ACTIONS(4359), 1,
      sym_discard,
    ACTIONS(7467), 1,
      sym__identifier_token,
    ACTIONS(7471), 1,
      anon_sym_LPAREN,
    ACTIONS(7919), 1,
      anon_sym_COMMA,
    ACTIONS(8079), 1,
      anon_sym_RPAREN,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(4153), 1,
      sym_parenthesized_variable_designation,
    STATE(4162), 1,
      sym__variable_designation,
    STATE(6139), 1,
      sym_positional_pattern_clause,
    STATE(6746), 1,
      sym_property_pattern_clause,
    STATE(7797), 1,
      sym_identifier,
    STATE(9076), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    ACTIONS(4355), 2,
      anon_sym_and,
      anon_sym_or,
    STATE(5909), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [139258] = 34,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7190), 1,
      anon_sym_with,
    ACTIONS(7405), 1,
      anon_sym_as,
    ACTIONS(7433), 1,
      anon_sym_SLASH,
    ACTIONS(7443), 1,
      anon_sym_GT_GT,
    ACTIONS(7449), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7457), 1,
      anon_sym_is,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7425), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7429), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7431), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7441), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7445), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7447), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(6342), 7,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(5910), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [139384] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4343), 1,
      anon_sym_LBRACE,
    ACTIONS(4359), 1,
      sym_discard,
    ACTIONS(7467), 1,
      sym__identifier_token,
    ACTIONS(7471), 1,
      anon_sym_LPAREN,
    ACTIONS(7919), 1,
      anon_sym_COMMA,
    ACTIONS(8081), 1,
      anon_sym_RPAREN,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(4153), 1,
      sym_parenthesized_variable_designation,
    STATE(4162), 1,
      sym__variable_designation,
    STATE(6139), 1,
      sym_positional_pattern_clause,
    STATE(6746), 1,
      sym_property_pattern_clause,
    STATE(7797), 1,
      sym_identifier,
    STATE(9076), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    ACTIONS(4355), 2,
      anon_sym_and,
      anon_sym_or,
    STATE(5911), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [139496] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7190), 1,
      anon_sym_with,
    ACTIONS(7433), 1,
      anon_sym_SLASH,
    ACTIONS(7449), 1,
      anon_sym_DOT_DOT,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7429), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7431), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5912), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 15,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
  [139608] = 33,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7190), 1,
      anon_sym_with,
    ACTIONS(7405), 1,
      anon_sym_as,
    ACTIONS(7433), 1,
      anon_sym_SLASH,
    ACTIONS(7443), 1,
      anon_sym_GT_GT,
    ACTIONS(7449), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7457), 1,
      anon_sym_is,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7425), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7429), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7431), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7441), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7447), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(6342), 9,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(5913), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [139732] = 37,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7190), 1,
      anon_sym_with,
    ACTIONS(7405), 1,
      anon_sym_as,
    ACTIONS(7433), 1,
      anon_sym_SLASH,
    ACTIONS(7435), 1,
      anon_sym_CARET,
    ACTIONS(7437), 1,
      anon_sym_PIPE,
    ACTIONS(7439), 1,
      anon_sym_AMP,
    ACTIONS(7443), 1,
      anon_sym_GT_GT,
    ACTIONS(7449), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7457), 1,
      anon_sym_is,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7425), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7429), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7431), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7441), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7445), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7447), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 6,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(5914), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [139864] = 38,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7190), 1,
      anon_sym_with,
    ACTIONS(7405), 1,
      anon_sym_as,
    ACTIONS(7433), 1,
      anon_sym_SLASH,
    ACTIONS(7435), 1,
      anon_sym_CARET,
    ACTIONS(7437), 1,
      anon_sym_PIPE,
    ACTIONS(7439), 1,
      anon_sym_AMP,
    ACTIONS(7443), 1,
      anon_sym_GT_GT,
    ACTIONS(7449), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7451), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7457), 1,
      anon_sym_is,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7425), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7429), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7431), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7441), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7445), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7447), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 5,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(5915), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [139998] = 41,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7656), 1,
      anon_sym_QMARK,
    ACTIONS(7658), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(7662), 1,
      anon_sym_is,
    ACTIONS(7742), 1,
      anon_sym_SLASH,
    ACTIONS(7746), 1,
      anon_sym_GT_GT,
    ACTIONS(7750), 1,
      anon_sym_AMP,
    ACTIONS(7756), 1,
      anon_sym_CARET,
    ACTIONS(7758), 1,
      anon_sym_PIPE,
    ACTIONS(7760), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7762), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7764), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8083), 1,
      anon_sym_COMMA,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6190), 2,
      anon_sym_COLON,
      anon_sym_RPAREN,
    ACTIONS(7738), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7740), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7744), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7748), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7752), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7754), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(5916), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [140138] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7220), 1,
      anon_sym_QMARK,
    ACTIONS(7226), 1,
      anon_sym_SLASH,
    ACTIONS(7228), 1,
      anon_sym_CARET,
    ACTIONS(7230), 1,
      anon_sym_PIPE,
    ACTIONS(7232), 1,
      anon_sym_AMP,
    ACTIONS(7236), 1,
      anon_sym_GT_GT,
    ACTIONS(7242), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7244), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7246), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7248), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7218), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7222), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7224), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7234), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7238), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7240), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6320), 3,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
    STATE(5917), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [140276] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7190), 1,
      anon_sym_with,
    ACTIONS(7405), 1,
      anon_sym_as,
    ACTIONS(7433), 1,
      anon_sym_SLASH,
    ACTIONS(7435), 1,
      anon_sym_CARET,
    ACTIONS(7437), 1,
      anon_sym_PIPE,
    ACTIONS(7439), 1,
      anon_sym_AMP,
    ACTIONS(7443), 1,
      anon_sym_GT_GT,
    ACTIONS(7449), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7451), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7453), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7455), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7457), 1,
      anon_sym_is,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7425), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7429), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7431), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7441), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7445), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7447), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 3,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
    STATE(5918), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [140414] = 42,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(2677), 1,
      anon_sym_COMMA,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(8085), 1,
      anon_sym_RBRACK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    STATE(8575), 1,
      aux_sym_array_rank_specifier_repeat1,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(5919), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [140556] = 42,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(7962), 1,
      anon_sym_COMMA,
    ACTIONS(8087), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    STATE(8658), 1,
      aux_sym_for_statement_repeat1,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(5920), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [140698] = 42,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(2677), 1,
      anon_sym_COMMA,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(8089), 1,
      anon_sym_RBRACK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    STATE(8409), 1,
      aux_sym_array_rank_specifier_repeat1,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(5921), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [140840] = 29,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8055), 1,
      anon_sym_SLASH,
    ACTIONS(8065), 1,
      anon_sym_GT_GT,
    ACTIONS(8071), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8051), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8053), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8063), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6344), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    STATE(5922), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 13,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
  [140956] = 26,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8055), 1,
      anon_sym_SLASH,
    ACTIONS(8071), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8053), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5923), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
  [141066] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8071), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5924), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 17,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
  [141172] = 35,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(8055), 1,
      anon_sym_SLASH,
    ACTIONS(8061), 1,
      anon_sym_AMP,
    ACTIONS(8065), 1,
      anon_sym_GT_GT,
    ACTIONS(8071), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(8047), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8051), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8053), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8063), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8067), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8069), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 7,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(5925), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [141300] = 36,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(8055), 1,
      anon_sym_SLASH,
    ACTIONS(8057), 1,
      anon_sym_CARET,
    ACTIONS(8061), 1,
      anon_sym_AMP,
    ACTIONS(8065), 1,
      anon_sym_GT_GT,
    ACTIONS(8071), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(8047), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8051), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8053), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8063), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8067), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8069), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 6,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(5926), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [141430] = 34,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(8055), 1,
      anon_sym_SLASH,
    ACTIONS(8065), 1,
      anon_sym_GT_GT,
    ACTIONS(8071), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8047), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8051), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8053), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8063), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8067), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8069), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(6342), 7,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(5927), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [141556] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8055), 1,
      anon_sym_SLASH,
    ACTIONS(8071), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8051), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8053), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5928), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
  [141668] = 33,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(8055), 1,
      anon_sym_SLASH,
    ACTIONS(8065), 1,
      anon_sym_GT_GT,
    ACTIONS(8071), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8047), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8051), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8053), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8063), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8069), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(6342), 9,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(5929), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [141792] = 26,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4343), 1,
      anon_sym_LBRACE,
    ACTIONS(4359), 1,
      sym_discard,
    ACTIONS(7467), 1,
      sym__identifier_token,
    ACTIONS(7471), 1,
      anon_sym_LPAREN,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(4153), 1,
      sym_parenthesized_variable_designation,
    STATE(4162), 1,
      sym__variable_designation,
    STATE(4163), 1,
      sym_identifier,
    STATE(6139), 1,
      sym_positional_pattern_clause,
    STATE(6746), 1,
      sym_property_pattern_clause,
    STATE(9076), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    ACTIONS(4355), 2,
      anon_sym_and,
      anon_sym_or,
    ACTIONS(4357), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    STATE(5930), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [141902] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7220), 1,
      anon_sym_QMARK,
    ACTIONS(7226), 1,
      anon_sym_SLASH,
    ACTIONS(7228), 1,
      anon_sym_CARET,
    ACTIONS(7230), 1,
      anon_sym_PIPE,
    ACTIONS(7232), 1,
      anon_sym_AMP,
    ACTIONS(7236), 1,
      anon_sym_GT_GT,
    ACTIONS(7242), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7244), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7246), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7248), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7218), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7222), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7224), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7234), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7238), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7240), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5624), 3,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
    STATE(5931), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [142040] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7220), 1,
      anon_sym_QMARK,
    ACTIONS(7226), 1,
      anon_sym_SLASH,
    ACTIONS(7228), 1,
      anon_sym_CARET,
    ACTIONS(7230), 1,
      anon_sym_PIPE,
    ACTIONS(7232), 1,
      anon_sym_AMP,
    ACTIONS(7236), 1,
      anon_sym_GT_GT,
    ACTIONS(7242), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7244), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7246), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7248), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7218), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7222), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7224), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7234), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7238), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7240), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6324), 3,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
    STATE(5932), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [142178] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(5933), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5873), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(4310), 27,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_GT,
      anon_sym_switch,
      anon_sym_when,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [142262] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4343), 1,
      anon_sym_LBRACE,
    ACTIONS(4359), 1,
      sym_discard,
    ACTIONS(7467), 1,
      sym__identifier_token,
    ACTIONS(7471), 1,
      anon_sym_LPAREN,
    ACTIONS(7919), 1,
      anon_sym_COMMA,
    ACTIONS(8091), 1,
      anon_sym_RPAREN,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(4153), 1,
      sym_parenthesized_variable_designation,
    STATE(4162), 1,
      sym__variable_designation,
    STATE(6139), 1,
      sym_positional_pattern_clause,
    STATE(6746), 1,
      sym_property_pattern_clause,
    STATE(7797), 1,
      sym_identifier,
    STATE(9076), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    ACTIONS(4355), 2,
      anon_sym_and,
      anon_sym_or,
    STATE(5934), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [142374] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8093), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
    STATE(5935), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [142512] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4593), 1,
      anon_sym_LBRACK,
    ACTIONS(4599), 1,
      anon_sym_STAR,
    ACTIONS(5405), 1,
      anon_sym_QMARK,
    ACTIONS(8095), 1,
      anon_sym_DOT,
    ACTIONS(4492), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5936), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4494), 25,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [142604] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8095), 1,
      anon_sym_DOT,
    STATE(5937), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4453), 10,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    ACTIONS(4455), 27,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [142690] = 29,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(8101), 1,
      anon_sym_SLASH,
    ACTIONS(8105), 1,
      anon_sym_GT_GT,
    ACTIONS(8107), 1,
      anon_sym_DOT_DOT,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8103), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6344), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    STATE(5938), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 13,
      anon_sym_in,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
  [142806] = 26,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(8101), 1,
      anon_sym_SLASH,
    ACTIONS(8107), 1,
      anon_sym_DOT_DOT,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5939), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 15,
      anon_sym_in,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
  [142916] = 35,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(8101), 1,
      anon_sym_SLASH,
    ACTIONS(8105), 1,
      anon_sym_GT_GT,
    ACTIONS(8107), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8111), 1,
      anon_sym_AMP,
    ACTIONS(8117), 1,
      anon_sym_as,
    ACTIONS(8119), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(8097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8103), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8109), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8113), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8115), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 7,
      anon_sym_in,
      anon_sym_CARET,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(5940), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [143044] = 36,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(8101), 1,
      anon_sym_SLASH,
    ACTIONS(8105), 1,
      anon_sym_GT_GT,
    ACTIONS(8107), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8111), 1,
      anon_sym_AMP,
    ACTIONS(8117), 1,
      anon_sym_as,
    ACTIONS(8119), 1,
      anon_sym_is,
    ACTIONS(8121), 1,
      anon_sym_CARET,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(8097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8103), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8109), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8113), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8115), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 6,
      anon_sym_in,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(5941), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [143174] = 34,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(8101), 1,
      anon_sym_SLASH,
    ACTIONS(8105), 1,
      anon_sym_GT_GT,
    ACTIONS(8107), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8117), 1,
      anon_sym_as,
    ACTIONS(8119), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8103), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8109), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8113), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8115), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(6342), 7,
      anon_sym_in,
      anon_sym_CARET,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(5942), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [143300] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(8101), 1,
      anon_sym_SLASH,
    ACTIONS(8107), 1,
      anon_sym_DOT_DOT,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5943), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 15,
      anon_sym_in,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
  [143412] = 33,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(8101), 1,
      anon_sym_SLASH,
    ACTIONS(8105), 1,
      anon_sym_GT_GT,
    ACTIONS(8107), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8117), 1,
      anon_sym_as,
    ACTIONS(8119), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8103), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8109), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8115), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(6342), 9,
      anon_sym_in,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(5944), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [143536] = 37,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(8101), 1,
      anon_sym_SLASH,
    ACTIONS(8105), 1,
      anon_sym_GT_GT,
    ACTIONS(8107), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8111), 1,
      anon_sym_AMP,
    ACTIONS(8117), 1,
      anon_sym_as,
    ACTIONS(8119), 1,
      anon_sym_is,
    ACTIONS(8121), 1,
      anon_sym_CARET,
    ACTIONS(8123), 1,
      anon_sym_PIPE,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8103), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8109), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8113), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8115), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 6,
      anon_sym_in,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(5945), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [143668] = 38,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(8101), 1,
      anon_sym_SLASH,
    ACTIONS(8105), 1,
      anon_sym_GT_GT,
    ACTIONS(8107), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8111), 1,
      anon_sym_AMP,
    ACTIONS(8117), 1,
      anon_sym_as,
    ACTIONS(8119), 1,
      anon_sym_is,
    ACTIONS(8121), 1,
      anon_sym_CARET,
    ACTIONS(8123), 1,
      anon_sym_PIPE,
    ACTIONS(8125), 1,
      anon_sym_AMP_AMP,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8103), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8109), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8113), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8115), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 5,
      anon_sym_in,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(5946), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [143802] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(8101), 1,
      anon_sym_SLASH,
    ACTIONS(8105), 1,
      anon_sym_GT_GT,
    ACTIONS(8107), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8111), 1,
      anon_sym_AMP,
    ACTIONS(8117), 1,
      anon_sym_as,
    ACTIONS(8119), 1,
      anon_sym_is,
    ACTIONS(8121), 1,
      anon_sym_CARET,
    ACTIONS(8123), 1,
      anon_sym_PIPE,
    ACTIONS(8125), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8127), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8129), 1,
      anon_sym_QMARK_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8103), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8109), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8113), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8115), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 3,
      anon_sym_in,
      anon_sym_and,
      anon_sym_or,
    STATE(5947), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [143940] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4343), 1,
      anon_sym_LBRACE,
    ACTIONS(4359), 1,
      sym_discard,
    ACTIONS(7467), 1,
      sym__identifier_token,
    ACTIONS(7471), 1,
      anon_sym_LPAREN,
    ACTIONS(7919), 1,
      anon_sym_COMMA,
    ACTIONS(8131), 1,
      anon_sym_RPAREN,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(4153), 1,
      sym_parenthesized_variable_designation,
    STATE(4162), 1,
      sym__variable_designation,
    STATE(6139), 1,
      sym_positional_pattern_clause,
    STATE(6746), 1,
      sym_property_pattern_clause,
    STATE(7797), 1,
      sym_identifier,
    STATE(9076), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    ACTIONS(4355), 2,
      anon_sym_and,
      anon_sym_or,
    STATE(5948), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [144052] = 42,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(7962), 1,
      anon_sym_COMMA,
    ACTIONS(8133), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    STATE(8695), 1,
      aux_sym_for_statement_repeat1,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(5949), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [144194] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(8071), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6330), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5950), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6328), 19,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [144296] = 37,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(8055), 1,
      anon_sym_SLASH,
    ACTIONS(8057), 1,
      anon_sym_CARET,
    ACTIONS(8059), 1,
      anon_sym_PIPE,
    ACTIONS(8061), 1,
      anon_sym_AMP,
    ACTIONS(8065), 1,
      anon_sym_GT_GT,
    ACTIONS(8071), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8047), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8051), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8053), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8063), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8067), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8069), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 6,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(5951), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [144428] = 38,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(8055), 1,
      anon_sym_SLASH,
    ACTIONS(8057), 1,
      anon_sym_CARET,
    ACTIONS(8059), 1,
      anon_sym_PIPE,
    ACTIONS(8061), 1,
      anon_sym_AMP,
    ACTIONS(8065), 1,
      anon_sym_GT_GT,
    ACTIONS(8071), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8073), 1,
      anon_sym_AMP_AMP,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8047), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8051), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8053), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8063), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8067), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8069), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 5,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(5952), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [144562] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(8055), 1,
      anon_sym_SLASH,
    ACTIONS(8057), 1,
      anon_sym_CARET,
    ACTIONS(8059), 1,
      anon_sym_PIPE,
    ACTIONS(8061), 1,
      anon_sym_AMP,
    ACTIONS(8065), 1,
      anon_sym_GT_GT,
    ACTIONS(8071), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8073), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8075), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8077), 1,
      anon_sym_QMARK_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8047), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8051), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8053), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8063), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8067), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8069), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 3,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    STATE(5953), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [144700] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(8049), 1,
      anon_sym_QMARK,
    ACTIONS(8055), 1,
      anon_sym_SLASH,
    ACTIONS(8057), 1,
      anon_sym_CARET,
    ACTIONS(8059), 1,
      anon_sym_PIPE,
    ACTIONS(8061), 1,
      anon_sym_AMP,
    ACTIONS(8065), 1,
      anon_sym_GT_GT,
    ACTIONS(8071), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8073), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8075), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8077), 1,
      anon_sym_QMARK_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8047), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8051), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8053), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8063), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8067), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8069), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5416), 3,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    STATE(5954), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [144838] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7220), 1,
      anon_sym_QMARK,
    ACTIONS(7226), 1,
      anon_sym_SLASH,
    ACTIONS(7228), 1,
      anon_sym_CARET,
    ACTIONS(7230), 1,
      anon_sym_PIPE,
    ACTIONS(7232), 1,
      anon_sym_AMP,
    ACTIONS(7236), 1,
      anon_sym_GT_GT,
    ACTIONS(7242), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7244), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7246), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7248), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7218), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7222), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7224), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7234), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7238), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7240), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8135), 3,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
    STATE(5955), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [144976] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7220), 1,
      anon_sym_QMARK,
    ACTIONS(7226), 1,
      anon_sym_SLASH,
    ACTIONS(7228), 1,
      anon_sym_CARET,
    ACTIONS(7230), 1,
      anon_sym_PIPE,
    ACTIONS(7232), 1,
      anon_sym_AMP,
    ACTIONS(7236), 1,
      anon_sym_GT_GT,
    ACTIONS(7242), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7244), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7246), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7248), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7218), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7222), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7224), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7234), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7238), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7240), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5644), 3,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
    STATE(5956), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [145114] = 42,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(7962), 1,
      anon_sym_COMMA,
    ACTIONS(8137), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    STATE(8465), 1,
      aux_sym_for_statement_repeat1,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(5957), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [145256] = 42,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(7962), 1,
      anon_sym_COMMA,
    ACTIONS(8139), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    STATE(8489), 1,
      aux_sym_for_statement_repeat1,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(5958), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [145398] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(8101), 1,
      anon_sym_SLASH,
    ACTIONS(8105), 1,
      anon_sym_GT_GT,
    ACTIONS(8107), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8111), 1,
      anon_sym_AMP,
    ACTIONS(8117), 1,
      anon_sym_as,
    ACTIONS(8119), 1,
      anon_sym_is,
    ACTIONS(8121), 1,
      anon_sym_CARET,
    ACTIONS(8123), 1,
      anon_sym_PIPE,
    ACTIONS(8125), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8127), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8129), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8141), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8103), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8109), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8113), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8115), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6320), 3,
      anon_sym_in,
      anon_sym_and,
      anon_sym_or,
    STATE(5959), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [145536] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(8107), 1,
      anon_sym_DOT_DOT,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6330), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5960), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6328), 19,
      anon_sym_in,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [145638] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(8101), 1,
      anon_sym_SLASH,
    ACTIONS(8105), 1,
      anon_sym_GT_GT,
    ACTIONS(8107), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8111), 1,
      anon_sym_AMP,
    ACTIONS(8117), 1,
      anon_sym_as,
    ACTIONS(8119), 1,
      anon_sym_is,
    ACTIONS(8121), 1,
      anon_sym_CARET,
    ACTIONS(8123), 1,
      anon_sym_PIPE,
    ACTIONS(8125), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8127), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8129), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8141), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8103), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8109), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8113), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8115), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6324), 3,
      anon_sym_in,
      anon_sym_and,
      anon_sym_or,
    STATE(5961), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [145776] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(8101), 1,
      anon_sym_SLASH,
    ACTIONS(8105), 1,
      anon_sym_GT_GT,
    ACTIONS(8107), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8111), 1,
      anon_sym_AMP,
    ACTIONS(8117), 1,
      anon_sym_as,
    ACTIONS(8119), 1,
      anon_sym_is,
    ACTIONS(8121), 1,
      anon_sym_CARET,
    ACTIONS(8123), 1,
      anon_sym_PIPE,
    ACTIONS(8125), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8127), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8129), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8141), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8103), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8109), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8113), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8115), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5416), 3,
      anon_sym_in,
      anon_sym_and,
      anon_sym_or,
    STATE(5962), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [145914] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(8101), 1,
      anon_sym_SLASH,
    ACTIONS(8105), 1,
      anon_sym_GT_GT,
    ACTIONS(8107), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8111), 1,
      anon_sym_AMP,
    ACTIONS(8117), 1,
      anon_sym_as,
    ACTIONS(8119), 1,
      anon_sym_is,
    ACTIONS(8121), 1,
      anon_sym_CARET,
    ACTIONS(8123), 1,
      anon_sym_PIPE,
    ACTIONS(8125), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8127), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8129), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8141), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8103), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8109), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8113), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8115), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5644), 3,
      anon_sym_in,
      anon_sym_and,
      anon_sym_or,
    STATE(5963), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [146052] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(8101), 1,
      anon_sym_SLASH,
    ACTIONS(8105), 1,
      anon_sym_GT_GT,
    ACTIONS(8107), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8111), 1,
      anon_sym_AMP,
    ACTIONS(8117), 1,
      anon_sym_as,
    ACTIONS(8119), 1,
      anon_sym_is,
    ACTIONS(8121), 1,
      anon_sym_CARET,
    ACTIONS(8123), 1,
      anon_sym_PIPE,
    ACTIONS(8125), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8127), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8129), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8141), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8103), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8109), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8113), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8115), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5424), 3,
      anon_sym_in,
      anon_sym_and,
      anon_sym_or,
    STATE(5964), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [146190] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(8101), 1,
      anon_sym_SLASH,
    ACTIONS(8105), 1,
      anon_sym_GT_GT,
    ACTIONS(8107), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8111), 1,
      anon_sym_AMP,
    ACTIONS(8117), 1,
      anon_sym_as,
    ACTIONS(8119), 1,
      anon_sym_is,
    ACTIONS(8121), 1,
      anon_sym_CARET,
    ACTIONS(8123), 1,
      anon_sym_PIPE,
    ACTIONS(8125), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8127), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8129), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8141), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8103), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8109), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8113), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8115), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6336), 3,
      anon_sym_in,
      anon_sym_and,
      anon_sym_or,
    STATE(5965), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [146328] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(8101), 1,
      anon_sym_SLASH,
    ACTIONS(8105), 1,
      anon_sym_GT_GT,
    ACTIONS(8107), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8111), 1,
      anon_sym_AMP,
    ACTIONS(8117), 1,
      anon_sym_as,
    ACTIONS(8119), 1,
      anon_sym_is,
    ACTIONS(8121), 1,
      anon_sym_CARET,
    ACTIONS(8123), 1,
      anon_sym_PIPE,
    ACTIONS(8125), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8127), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8129), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8141), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8103), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8109), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8113), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8115), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5572), 3,
      anon_sym_in,
      anon_sym_and,
      anon_sym_or,
    STATE(5966), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [146466] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(8101), 1,
      anon_sym_SLASH,
    ACTIONS(8105), 1,
      anon_sym_GT_GT,
    ACTIONS(8107), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8111), 1,
      anon_sym_AMP,
    ACTIONS(8117), 1,
      anon_sym_as,
    ACTIONS(8119), 1,
      anon_sym_is,
    ACTIONS(8121), 1,
      anon_sym_CARET,
    ACTIONS(8123), 1,
      anon_sym_PIPE,
    ACTIONS(8125), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8127), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8129), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8141), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8103), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8109), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8113), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8115), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5584), 3,
      anon_sym_in,
      anon_sym_and,
      anon_sym_or,
    STATE(5967), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [146604] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(8101), 1,
      anon_sym_SLASH,
    ACTIONS(8105), 1,
      anon_sym_GT_GT,
    ACTIONS(8107), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8111), 1,
      anon_sym_AMP,
    ACTIONS(8117), 1,
      anon_sym_as,
    ACTIONS(8119), 1,
      anon_sym_is,
    ACTIONS(8121), 1,
      anon_sym_CARET,
    ACTIONS(8123), 1,
      anon_sym_PIPE,
    ACTIONS(8125), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8127), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8129), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8141), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8103), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8109), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8113), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8115), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5624), 3,
      anon_sym_in,
      anon_sym_and,
      anon_sym_or,
    STATE(5968), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [146742] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(8101), 1,
      anon_sym_SLASH,
    ACTIONS(8105), 1,
      anon_sym_GT_GT,
    ACTIONS(8107), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8111), 1,
      anon_sym_AMP,
    ACTIONS(8117), 1,
      anon_sym_as,
    ACTIONS(8119), 1,
      anon_sym_is,
    ACTIONS(8121), 1,
      anon_sym_CARET,
    ACTIONS(8123), 1,
      anon_sym_PIPE,
    ACTIONS(8125), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8127), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8129), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8141), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8103), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8109), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8113), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8115), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6190), 3,
      anon_sym_in,
      anon_sym_and,
      anon_sym_or,
    STATE(5969), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [146880] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(8049), 1,
      anon_sym_QMARK,
    ACTIONS(8055), 1,
      anon_sym_SLASH,
    ACTIONS(8057), 1,
      anon_sym_CARET,
    ACTIONS(8059), 1,
      anon_sym_PIPE,
    ACTIONS(8061), 1,
      anon_sym_AMP,
    ACTIONS(8065), 1,
      anon_sym_GT_GT,
    ACTIONS(8071), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8073), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8075), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8077), 1,
      anon_sym_QMARK_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8047), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8051), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8053), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8063), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8067), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8069), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5644), 3,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    STATE(5970), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [147018] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7220), 1,
      anon_sym_QMARK,
    ACTIONS(7226), 1,
      anon_sym_SLASH,
    ACTIONS(7228), 1,
      anon_sym_CARET,
    ACTIONS(7230), 1,
      anon_sym_PIPE,
    ACTIONS(7232), 1,
      anon_sym_AMP,
    ACTIONS(7236), 1,
      anon_sym_GT_GT,
    ACTIONS(7242), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7244), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7246), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7248), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7218), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7222), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7224), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7234), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7238), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7240), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8143), 3,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
    STATE(5971), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [147156] = 42,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(7962), 1,
      anon_sym_COMMA,
    ACTIONS(8145), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    STATE(8665), 1,
      aux_sym_for_statement_repeat1,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(5972), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [147298] = 42,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(7962), 1,
      anon_sym_COMMA,
    ACTIONS(8147), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    STATE(8671), 1,
      aux_sym_for_statement_repeat1,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(5973), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [147440] = 42,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(7962), 1,
      anon_sym_COMMA,
    ACTIONS(8149), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    STATE(8557), 1,
      aux_sym_for_statement_repeat1,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(5974), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [147582] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4343), 1,
      anon_sym_LBRACE,
    ACTIONS(4359), 1,
      sym_discard,
    ACTIONS(7467), 1,
      sym__identifier_token,
    ACTIONS(7471), 1,
      anon_sym_LPAREN,
    ACTIONS(7919), 1,
      anon_sym_COMMA,
    ACTIONS(8151), 1,
      anon_sym_RPAREN,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(4153), 1,
      sym_parenthesized_variable_designation,
    STATE(4162), 1,
      sym__variable_designation,
    STATE(6139), 1,
      sym_positional_pattern_clause,
    STATE(6746), 1,
      sym_property_pattern_clause,
    STATE(7797), 1,
      sym_identifier,
    STATE(9076), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    ACTIONS(4355), 2,
      anon_sym_and,
      anon_sym_or,
    STATE(5975), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [147694] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(8049), 1,
      anon_sym_QMARK,
    ACTIONS(8055), 1,
      anon_sym_SLASH,
    ACTIONS(8057), 1,
      anon_sym_CARET,
    ACTIONS(8059), 1,
      anon_sym_PIPE,
    ACTIONS(8061), 1,
      anon_sym_AMP,
    ACTIONS(8065), 1,
      anon_sym_GT_GT,
    ACTIONS(8071), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8073), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8075), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8077), 1,
      anon_sym_QMARK_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8047), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8051), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8053), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8063), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8067), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8069), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5424), 3,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    STATE(5976), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [147832] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7220), 1,
      anon_sym_QMARK,
    ACTIONS(7226), 1,
      anon_sym_SLASH,
    ACTIONS(7228), 1,
      anon_sym_CARET,
    ACTIONS(7230), 1,
      anon_sym_PIPE,
    ACTIONS(7232), 1,
      anon_sym_AMP,
    ACTIONS(7236), 1,
      anon_sym_GT_GT,
    ACTIONS(7242), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7244), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7246), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7248), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7218), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7222), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7224), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7234), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7238), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7240), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5416), 3,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
    STATE(5977), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [147970] = 42,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(7962), 1,
      anon_sym_COMMA,
    ACTIONS(8153), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    STATE(8685), 1,
      aux_sym_for_statement_repeat1,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(5978), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [148112] = 42,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(7962), 1,
      anon_sym_COMMA,
    ACTIONS(8155), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    STATE(8646), 1,
      aux_sym_for_statement_repeat1,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(5979), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [148254] = 42,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(8157), 1,
      anon_sym_COMMA,
    ACTIONS(8159), 1,
      anon_sym_RBRACE,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    STATE(8692), 1,
      aux_sym_for_statement_repeat1,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(5980), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [148396] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(8049), 1,
      anon_sym_QMARK,
    ACTIONS(8055), 1,
      anon_sym_SLASH,
    ACTIONS(8057), 1,
      anon_sym_CARET,
    ACTIONS(8059), 1,
      anon_sym_PIPE,
    ACTIONS(8061), 1,
      anon_sym_AMP,
    ACTIONS(8065), 1,
      anon_sym_GT_GT,
    ACTIONS(8071), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8073), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8075), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8077), 1,
      anon_sym_QMARK_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8047), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8051), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8053), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8063), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8067), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8069), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6336), 3,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    STATE(5981), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [148534] = 42,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(2677), 1,
      anon_sym_COMMA,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(8161), 1,
      anon_sym_RBRACK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    STATE(8521), 1,
      aux_sym_array_rank_specifier_repeat1,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(5982), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [148676] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4343), 1,
      anon_sym_LBRACE,
    ACTIONS(4359), 1,
      sym_discard,
    ACTIONS(7467), 1,
      sym__identifier_token,
    ACTIONS(7471), 1,
      anon_sym_LPAREN,
    ACTIONS(7919), 1,
      anon_sym_COMMA,
    ACTIONS(8163), 1,
      anon_sym_RPAREN,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(4153), 1,
      sym_parenthesized_variable_designation,
    STATE(4162), 1,
      sym__variable_designation,
    STATE(6139), 1,
      sym_positional_pattern_clause,
    STATE(6746), 1,
      sym_property_pattern_clause,
    STATE(7797), 1,
      sym_identifier,
    STATE(9076), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    ACTIONS(4355), 2,
      anon_sym_and,
      anon_sym_or,
    STATE(5983), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [148788] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7220), 1,
      anon_sym_QMARK,
    ACTIONS(7226), 1,
      anon_sym_SLASH,
    ACTIONS(7228), 1,
      anon_sym_CARET,
    ACTIONS(7230), 1,
      anon_sym_PIPE,
    ACTIONS(7232), 1,
      anon_sym_AMP,
    ACTIONS(7236), 1,
      anon_sym_GT_GT,
    ACTIONS(7242), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7244), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7246), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7248), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7218), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7222), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7224), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7234), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7238), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7240), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6336), 3,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
    STATE(5984), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [148926] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(8049), 1,
      anon_sym_QMARK,
    ACTIONS(8055), 1,
      anon_sym_SLASH,
    ACTIONS(8057), 1,
      anon_sym_CARET,
    ACTIONS(8059), 1,
      anon_sym_PIPE,
    ACTIONS(8061), 1,
      anon_sym_AMP,
    ACTIONS(8065), 1,
      anon_sym_GT_GT,
    ACTIONS(8071), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8073), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8075), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8077), 1,
      anon_sym_QMARK_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8047), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8051), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8053), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8063), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8067), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8069), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6320), 3,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    STATE(5985), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [149064] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(8049), 1,
      anon_sym_QMARK,
    ACTIONS(8055), 1,
      anon_sym_SLASH,
    ACTIONS(8057), 1,
      anon_sym_CARET,
    ACTIONS(8059), 1,
      anon_sym_PIPE,
    ACTIONS(8061), 1,
      anon_sym_AMP,
    ACTIONS(8065), 1,
      anon_sym_GT_GT,
    ACTIONS(8071), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8073), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8075), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8077), 1,
      anon_sym_QMARK_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8047), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8051), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8053), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8063), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8067), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8069), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6324), 3,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    STATE(5986), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [149202] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4343), 1,
      anon_sym_LBRACE,
    ACTIONS(4359), 1,
      sym_discard,
    ACTIONS(7467), 1,
      sym__identifier_token,
    ACTIONS(7471), 1,
      anon_sym_LPAREN,
    ACTIONS(7919), 1,
      anon_sym_COMMA,
    ACTIONS(8165), 1,
      anon_sym_RPAREN,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(4153), 1,
      sym_parenthesized_variable_designation,
    STATE(4162), 1,
      sym__variable_designation,
    STATE(6139), 1,
      sym_positional_pattern_clause,
    STATE(6746), 1,
      sym_property_pattern_clause,
    STATE(7797), 1,
      sym_identifier,
    STATE(9076), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    ACTIONS(4355), 2,
      anon_sym_and,
      anon_sym_or,
    STATE(5987), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [149314] = 29,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(8171), 1,
      anon_sym_SLASH,
    ACTIONS(8175), 1,
      anon_sym_GT_GT,
    ACTIONS(8177), 1,
      anon_sym_DOT_DOT,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8167), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8169), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8173), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6344), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    STATE(5988), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 13,
      anon_sym_COLON,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
  [149430] = 26,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(8171), 1,
      anon_sym_SLASH,
    ACTIONS(8177), 1,
      anon_sym_DOT_DOT,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8169), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5989), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 15,
      anon_sym_COLON,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
  [149540] = 35,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(8171), 1,
      anon_sym_SLASH,
    ACTIONS(8175), 1,
      anon_sym_GT_GT,
    ACTIONS(8177), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8181), 1,
      anon_sym_AMP,
    ACTIONS(8187), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(8167), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8169), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8173), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8179), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8183), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8185), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 7,
      anon_sym_COLON,
      anon_sym_CARET,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(5990), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [149668] = 36,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(8171), 1,
      anon_sym_SLASH,
    ACTIONS(8175), 1,
      anon_sym_GT_GT,
    ACTIONS(8177), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8181), 1,
      anon_sym_AMP,
    ACTIONS(8187), 1,
      anon_sym_is,
    ACTIONS(8189), 1,
      anon_sym_CARET,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(8167), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8169), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8173), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8179), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8183), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8185), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 6,
      anon_sym_COLON,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(5991), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [149798] = 42,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(7962), 1,
      anon_sym_COMMA,
    ACTIONS(8191), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    STATE(8578), 1,
      aux_sym_for_statement_repeat1,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(5992), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [149940] = 42,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(7962), 1,
      anon_sym_COMMA,
    ACTIONS(8193), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    STATE(8581), 1,
      aux_sym_for_statement_repeat1,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(5993), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [150082] = 34,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(8171), 1,
      anon_sym_SLASH,
    ACTIONS(8175), 1,
      anon_sym_GT_GT,
    ACTIONS(8177), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8187), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8167), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8169), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8173), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8179), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8183), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8185), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(6342), 7,
      anon_sym_COLON,
      anon_sym_CARET,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(5994), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [150208] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(8171), 1,
      anon_sym_SLASH,
    ACTIONS(8177), 1,
      anon_sym_DOT_DOT,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8167), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8169), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(5995), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 15,
      anon_sym_COLON,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
  [150320] = 33,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(8171), 1,
      anon_sym_SLASH,
    ACTIONS(8175), 1,
      anon_sym_GT_GT,
    ACTIONS(8177), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8187), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8167), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8169), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8173), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8179), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8185), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(6342), 9,
      anon_sym_COLON,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(5996), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [150444] = 37,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(8171), 1,
      anon_sym_SLASH,
    ACTIONS(8175), 1,
      anon_sym_GT_GT,
    ACTIONS(8177), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8181), 1,
      anon_sym_AMP,
    ACTIONS(8187), 1,
      anon_sym_is,
    ACTIONS(8189), 1,
      anon_sym_CARET,
    ACTIONS(8195), 1,
      anon_sym_PIPE,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8167), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8169), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8173), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8179), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8183), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8185), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 6,
      anon_sym_COLON,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(5997), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [150576] = 38,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(8171), 1,
      anon_sym_SLASH,
    ACTIONS(8175), 1,
      anon_sym_GT_GT,
    ACTIONS(8177), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8181), 1,
      anon_sym_AMP,
    ACTIONS(8187), 1,
      anon_sym_is,
    ACTIONS(8189), 1,
      anon_sym_CARET,
    ACTIONS(8195), 1,
      anon_sym_PIPE,
    ACTIONS(8197), 1,
      anon_sym_AMP_AMP,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8167), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8169), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8173), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8179), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8183), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8185), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 5,
      anon_sym_COLON,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(5998), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [150710] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(8171), 1,
      anon_sym_SLASH,
    ACTIONS(8175), 1,
      anon_sym_GT_GT,
    ACTIONS(8177), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8181), 1,
      anon_sym_AMP,
    ACTIONS(8187), 1,
      anon_sym_is,
    ACTIONS(8189), 1,
      anon_sym_CARET,
    ACTIONS(8195), 1,
      anon_sym_PIPE,
    ACTIONS(8197), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8199), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8201), 1,
      anon_sym_QMARK_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8167), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8169), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8173), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8179), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8183), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8185), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 3,
      anon_sym_COLON,
      anon_sym_and,
      anon_sym_or,
    STATE(5999), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [150848] = 42,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(8049), 1,
      anon_sym_QMARK,
    ACTIONS(8055), 1,
      anon_sym_SLASH,
    ACTIONS(8057), 1,
      anon_sym_CARET,
    ACTIONS(8059), 1,
      anon_sym_PIPE,
    ACTIONS(8061), 1,
      anon_sym_AMP,
    ACTIONS(8065), 1,
      anon_sym_GT_GT,
    ACTIONS(8071), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8073), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8075), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8077), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8203), 1,
      anon_sym_SEMI,
    ACTIONS(8205), 1,
      anon_sym_COMMA,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    STATE(8552), 1,
      aux_sym_for_statement_repeat1,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8047), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8051), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8053), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8063), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8067), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8069), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6000), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [150990] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(8049), 1,
      anon_sym_QMARK,
    ACTIONS(8055), 1,
      anon_sym_SLASH,
    ACTIONS(8057), 1,
      anon_sym_CARET,
    ACTIONS(8059), 1,
      anon_sym_PIPE,
    ACTIONS(8061), 1,
      anon_sym_AMP,
    ACTIONS(8065), 1,
      anon_sym_GT_GT,
    ACTIONS(8071), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8073), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8075), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8077), 1,
      anon_sym_QMARK_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8047), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8051), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8053), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8063), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8067), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8069), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6190), 3,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    STATE(6001), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [151128] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(8071), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1229), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(6002), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(1227), 19,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [151230] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4343), 1,
      anon_sym_LBRACE,
    ACTIONS(4359), 1,
      sym_discard,
    ACTIONS(7467), 1,
      sym__identifier_token,
    ACTIONS(7471), 1,
      anon_sym_LPAREN,
    ACTIONS(7919), 1,
      anon_sym_COMMA,
    ACTIONS(8207), 1,
      anon_sym_RPAREN,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(4153), 1,
      sym_parenthesized_variable_designation,
    STATE(4162), 1,
      sym__variable_designation,
    STATE(6139), 1,
      sym_positional_pattern_clause,
    STATE(6746), 1,
      sym_property_pattern_clause,
    STATE(7797), 1,
      sym_identifier,
    STATE(9076), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    ACTIONS(4355), 2,
      anon_sym_and,
      anon_sym_or,
    STATE(6003), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [151342] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(8049), 1,
      anon_sym_QMARK,
    ACTIONS(8055), 1,
      anon_sym_SLASH,
    ACTIONS(8057), 1,
      anon_sym_CARET,
    ACTIONS(8059), 1,
      anon_sym_PIPE,
    ACTIONS(8061), 1,
      anon_sym_AMP,
    ACTIONS(8065), 1,
      anon_sym_GT_GT,
    ACTIONS(8071), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8073), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8075), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8077), 1,
      anon_sym_QMARK_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8047), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8051), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8053), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8063), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8067), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8069), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5572), 3,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    STATE(6004), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [151480] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(8171), 1,
      anon_sym_SLASH,
    ACTIONS(8175), 1,
      anon_sym_GT_GT,
    ACTIONS(8177), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8181), 1,
      anon_sym_AMP,
    ACTIONS(8187), 1,
      anon_sym_is,
    ACTIONS(8189), 1,
      anon_sym_CARET,
    ACTIONS(8195), 1,
      anon_sym_PIPE,
    ACTIONS(8197), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8199), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8201), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8209), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8167), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8169), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8173), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8179), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8183), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8185), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6320), 3,
      anon_sym_COLON,
      anon_sym_and,
      anon_sym_or,
    STATE(6005), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [151618] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(8177), 1,
      anon_sym_DOT_DOT,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6330), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(6006), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6328), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [151720] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(8171), 1,
      anon_sym_SLASH,
    ACTIONS(8175), 1,
      anon_sym_GT_GT,
    ACTIONS(8177), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8181), 1,
      anon_sym_AMP,
    ACTIONS(8187), 1,
      anon_sym_is,
    ACTIONS(8189), 1,
      anon_sym_CARET,
    ACTIONS(8195), 1,
      anon_sym_PIPE,
    ACTIONS(8197), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8199), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8201), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8209), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8167), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8169), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8173), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8179), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8183), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8185), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6324), 3,
      anon_sym_COLON,
      anon_sym_and,
      anon_sym_or,
    STATE(6007), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [151858] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(8171), 1,
      anon_sym_SLASH,
    ACTIONS(8175), 1,
      anon_sym_GT_GT,
    ACTIONS(8177), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8181), 1,
      anon_sym_AMP,
    ACTIONS(8187), 1,
      anon_sym_is,
    ACTIONS(8189), 1,
      anon_sym_CARET,
    ACTIONS(8195), 1,
      anon_sym_PIPE,
    ACTIONS(8197), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8199), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8201), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8209), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8167), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8169), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8173), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8179), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8183), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8185), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5416), 3,
      anon_sym_COLON,
      anon_sym_and,
      anon_sym_or,
    STATE(6008), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [151996] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(8171), 1,
      anon_sym_SLASH,
    ACTIONS(8175), 1,
      anon_sym_GT_GT,
    ACTIONS(8177), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8181), 1,
      anon_sym_AMP,
    ACTIONS(8187), 1,
      anon_sym_is,
    ACTIONS(8189), 1,
      anon_sym_CARET,
    ACTIONS(8195), 1,
      anon_sym_PIPE,
    ACTIONS(8197), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8199), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8201), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8209), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8167), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8169), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8173), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8179), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8183), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8185), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5644), 3,
      anon_sym_COLON,
      anon_sym_and,
      anon_sym_or,
    STATE(6009), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [152134] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(8171), 1,
      anon_sym_SLASH,
    ACTIONS(8175), 1,
      anon_sym_GT_GT,
    ACTIONS(8177), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8181), 1,
      anon_sym_AMP,
    ACTIONS(8187), 1,
      anon_sym_is,
    ACTIONS(8189), 1,
      anon_sym_CARET,
    ACTIONS(8195), 1,
      anon_sym_PIPE,
    ACTIONS(8197), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8199), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8201), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8209), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8167), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8169), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8173), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8179), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8183), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8185), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5424), 3,
      anon_sym_COLON,
      anon_sym_and,
      anon_sym_or,
    STATE(6010), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [152272] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(8171), 1,
      anon_sym_SLASH,
    ACTIONS(8175), 1,
      anon_sym_GT_GT,
    ACTIONS(8177), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8181), 1,
      anon_sym_AMP,
    ACTIONS(8187), 1,
      anon_sym_is,
    ACTIONS(8189), 1,
      anon_sym_CARET,
    ACTIONS(8195), 1,
      anon_sym_PIPE,
    ACTIONS(8197), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8199), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8201), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8209), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8167), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8169), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8173), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8179), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8183), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8185), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6336), 3,
      anon_sym_COLON,
      anon_sym_and,
      anon_sym_or,
    STATE(6011), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [152410] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(8171), 1,
      anon_sym_SLASH,
    ACTIONS(8175), 1,
      anon_sym_GT_GT,
    ACTIONS(8177), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8181), 1,
      anon_sym_AMP,
    ACTIONS(8187), 1,
      anon_sym_is,
    ACTIONS(8189), 1,
      anon_sym_CARET,
    ACTIONS(8195), 1,
      anon_sym_PIPE,
    ACTIONS(8197), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8199), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8201), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8209), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8167), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8169), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8173), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8179), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8183), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8185), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5572), 3,
      anon_sym_COLON,
      anon_sym_and,
      anon_sym_or,
    STATE(6012), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [152548] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(8171), 1,
      anon_sym_SLASH,
    ACTIONS(8175), 1,
      anon_sym_GT_GT,
    ACTIONS(8177), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8181), 1,
      anon_sym_AMP,
    ACTIONS(8187), 1,
      anon_sym_is,
    ACTIONS(8189), 1,
      anon_sym_CARET,
    ACTIONS(8195), 1,
      anon_sym_PIPE,
    ACTIONS(8197), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8199), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8201), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8209), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8167), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8169), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8173), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8179), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8183), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8185), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5584), 3,
      anon_sym_COLON,
      anon_sym_and,
      anon_sym_or,
    STATE(6013), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [152686] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(8171), 1,
      anon_sym_SLASH,
    ACTIONS(8175), 1,
      anon_sym_GT_GT,
    ACTIONS(8177), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8181), 1,
      anon_sym_AMP,
    ACTIONS(8187), 1,
      anon_sym_is,
    ACTIONS(8189), 1,
      anon_sym_CARET,
    ACTIONS(8195), 1,
      anon_sym_PIPE,
    ACTIONS(8197), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8199), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8201), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8209), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8167), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8169), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8173), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8179), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8183), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8185), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5624), 3,
      anon_sym_COLON,
      anon_sym_and,
      anon_sym_or,
    STATE(6014), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [152824] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(8171), 1,
      anon_sym_SLASH,
    ACTIONS(8175), 1,
      anon_sym_GT_GT,
    ACTIONS(8177), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8181), 1,
      anon_sym_AMP,
    ACTIONS(8187), 1,
      anon_sym_is,
    ACTIONS(8189), 1,
      anon_sym_CARET,
    ACTIONS(8195), 1,
      anon_sym_PIPE,
    ACTIONS(8197), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8199), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8201), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8209), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8167), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8169), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8173), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8179), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8183), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8185), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6190), 3,
      anon_sym_COLON,
      anon_sym_and,
      anon_sym_or,
    STATE(6015), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [152962] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(8049), 1,
      anon_sym_QMARK,
    ACTIONS(8055), 1,
      anon_sym_SLASH,
    ACTIONS(8057), 1,
      anon_sym_CARET,
    ACTIONS(8059), 1,
      anon_sym_PIPE,
    ACTIONS(8061), 1,
      anon_sym_AMP,
    ACTIONS(8065), 1,
      anon_sym_GT_GT,
    ACTIONS(8071), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8073), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8075), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8077), 1,
      anon_sym_QMARK_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8047), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8051), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8053), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8063), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8067), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8069), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5584), 3,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    STATE(6016), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [153100] = 42,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(7962), 1,
      anon_sym_COMMA,
    ACTIONS(8211), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    STATE(8396), 1,
      aux_sym_for_statement_repeat1,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6017), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [153242] = 42,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(7962), 1,
      anon_sym_COMMA,
    ACTIONS(8213), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    STATE(8397), 1,
      aux_sym_for_statement_repeat1,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6018), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [153384] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7915), 1,
      anon_sym_and,
    ACTIONS(8215), 1,
      anon_sym_or,
    STATE(6019), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6594), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6592), 25,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_GT,
      anon_sym_switch,
      anon_sym_when,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [153472] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(6020), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4433), 10,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_GT,
      anon_sym_EQ_GT,
    ACTIONS(4431), 28,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_operator,
      anon_sym_this,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      sym_discard,
      anon_sym_and,
      anon_sym_or,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [153556] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7220), 1,
      anon_sym_QMARK,
    ACTIONS(7226), 1,
      anon_sym_SLASH,
    ACTIONS(7228), 1,
      anon_sym_CARET,
    ACTIONS(7230), 1,
      anon_sym_PIPE,
    ACTIONS(7232), 1,
      anon_sym_AMP,
    ACTIONS(7236), 1,
      anon_sym_GT_GT,
    ACTIONS(7242), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7244), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7246), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7248), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7218), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7222), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7224), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7234), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7238), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7240), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5572), 3,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
    STATE(6021), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [153694] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8217), 1,
      anon_sym_and,
    STATE(6022), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6707), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6705), 26,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_when,
      anon_sym_DOT_DOT,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [153780] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7449), 1,
      anon_sym_DOT_DOT,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6330), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(6023), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6328), 19,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [153882] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4343), 1,
      anon_sym_LBRACE,
    ACTIONS(4359), 1,
      sym_discard,
    ACTIONS(7467), 1,
      sym__identifier_token,
    ACTIONS(7471), 1,
      anon_sym_LPAREN,
    ACTIONS(7919), 1,
      anon_sym_COMMA,
    ACTIONS(8219), 1,
      anon_sym_RPAREN,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(4153), 1,
      sym_parenthesized_variable_designation,
    STATE(4162), 1,
      sym__variable_designation,
    STATE(6139), 1,
      sym_positional_pattern_clause,
    STATE(6746), 1,
      sym_property_pattern_clause,
    STATE(7797), 1,
      sym_identifier,
    STATE(9076), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    ACTIONS(4355), 2,
      anon_sym_and,
      anon_sym_or,
    STATE(6024), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [153994] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(8101), 1,
      anon_sym_SLASH,
    ACTIONS(8105), 1,
      anon_sym_GT_GT,
    ACTIONS(8107), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8111), 1,
      anon_sym_AMP,
    ACTIONS(8117), 1,
      anon_sym_as,
    ACTIONS(8119), 1,
      anon_sym_is,
    ACTIONS(8121), 1,
      anon_sym_CARET,
    ACTIONS(8123), 1,
      anon_sym_PIPE,
    ACTIONS(8125), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8127), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8129), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8141), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8103), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8109), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8113), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8115), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6332), 3,
      anon_sym_in,
      anon_sym_and,
      anon_sym_or,
    STATE(6025), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [154132] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7220), 1,
      anon_sym_QMARK,
    ACTIONS(7226), 1,
      anon_sym_SLASH,
    ACTIONS(7228), 1,
      anon_sym_CARET,
    ACTIONS(7230), 1,
      anon_sym_PIPE,
    ACTIONS(7232), 1,
      anon_sym_AMP,
    ACTIONS(7236), 1,
      anon_sym_GT_GT,
    ACTIONS(7242), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7244), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7246), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7248), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7218), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7222), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7224), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7234), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7238), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7240), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5584), 3,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
    STATE(6026), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [154270] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8221), 1,
      anon_sym_and,
    STATE(6027), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6707), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6705), 26,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [154356] = 42,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(2677), 1,
      anon_sym_COMMA,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(8223), 1,
      anon_sym_RBRACK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    STATE(8525), 1,
      aux_sym_array_rank_specifier_repeat1,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6028), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [154498] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(8049), 1,
      anon_sym_QMARK,
    ACTIONS(8055), 1,
      anon_sym_SLASH,
    ACTIONS(8057), 1,
      anon_sym_CARET,
    ACTIONS(8059), 1,
      anon_sym_PIPE,
    ACTIONS(8061), 1,
      anon_sym_AMP,
    ACTIONS(8065), 1,
      anon_sym_GT_GT,
    ACTIONS(8071), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8073), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8075), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8077), 1,
      anon_sym_QMARK_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8047), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8051), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8053), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8063), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8067), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8069), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5624), 3,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    STATE(6029), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [154636] = 42,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(7962), 1,
      anon_sym_COMMA,
    ACTIONS(8225), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    STATE(8406), 1,
      aux_sym_for_statement_repeat1,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6030), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [154778] = 42,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(7962), 1,
      anon_sym_COMMA,
    ACTIONS(8227), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    STATE(8411), 1,
      aux_sym_for_statement_repeat1,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6031), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [154920] = 42,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(7962), 1,
      anon_sym_COMMA,
    ACTIONS(8229), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    STATE(8413), 1,
      aux_sym_for_statement_repeat1,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6032), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [155062] = 26,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4343), 1,
      anon_sym_LBRACE,
    ACTIONS(4359), 1,
      sym_discard,
    ACTIONS(7467), 1,
      sym__identifier_token,
    ACTIONS(7471), 1,
      anon_sym_LPAREN,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(4153), 1,
      sym_parenthesized_variable_designation,
    STATE(4162), 1,
      sym__variable_designation,
    STATE(6139), 1,
      sym_positional_pattern_clause,
    STATE(6746), 1,
      sym_property_pattern_clause,
    STATE(8172), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9765), 1,
      sym__lambda_parameters,
    ACTIONS(4355), 2,
      anon_sym_and,
      anon_sym_or,
    ACTIONS(4357), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(6033), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [155172] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4343), 1,
      anon_sym_LBRACE,
    ACTIONS(4359), 1,
      sym_discard,
    ACTIONS(7467), 1,
      sym__identifier_token,
    ACTIONS(7471), 1,
      anon_sym_LPAREN,
    ACTIONS(7919), 1,
      anon_sym_COMMA,
    ACTIONS(8231), 1,
      anon_sym_RPAREN,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(4153), 1,
      sym_parenthesized_variable_designation,
    STATE(4162), 1,
      sym__variable_designation,
    STATE(6139), 1,
      sym_positional_pattern_clause,
    STATE(6746), 1,
      sym_property_pattern_clause,
    STATE(7797), 1,
      sym_identifier,
    STATE(9076), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    ACTIONS(4355), 2,
      anon_sym_and,
      anon_sym_or,
    STATE(6034), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [155284] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8233), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
    STATE(6035), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [155422] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8235), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
    STATE(6036), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [155560] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4343), 1,
      anon_sym_LBRACE,
    ACTIONS(4359), 1,
      sym_discard,
    ACTIONS(7467), 1,
      sym__identifier_token,
    ACTIONS(7471), 1,
      anon_sym_LPAREN,
    ACTIONS(7919), 1,
      anon_sym_COMMA,
    ACTIONS(8237), 1,
      anon_sym_RPAREN,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(4153), 1,
      sym_parenthesized_variable_designation,
    STATE(4162), 1,
      sym__variable_designation,
    STATE(6139), 1,
      sym_positional_pattern_clause,
    STATE(6746), 1,
      sym_property_pattern_clause,
    STATE(7797), 1,
      sym_identifier,
    STATE(9076), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    ACTIONS(4355), 2,
      anon_sym_and,
      anon_sym_or,
    STATE(6037), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [155672] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(8171), 1,
      anon_sym_SLASH,
    ACTIONS(8175), 1,
      anon_sym_GT_GT,
    ACTIONS(8177), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8181), 1,
      anon_sym_AMP,
    ACTIONS(8187), 1,
      anon_sym_is,
    ACTIONS(8189), 1,
      anon_sym_CARET,
    ACTIONS(8195), 1,
      anon_sym_PIPE,
    ACTIONS(8197), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8199), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8201), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8209), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8167), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8169), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8173), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8179), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8183), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8185), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6332), 3,
      anon_sym_COLON,
      anon_sym_and,
      anon_sym_or,
    STATE(6038), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [155810] = 42,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(7962), 1,
      anon_sym_COMMA,
    ACTIONS(8239), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    STATE(8442), 1,
      aux_sym_for_statement_repeat1,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6039), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [155952] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(8177), 1,
      anon_sym_DOT_DOT,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(6040), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
  [156058] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7190), 1,
      anon_sym_with,
    ACTIONS(7405), 1,
      anon_sym_as,
    ACTIONS(7427), 1,
      anon_sym_QMARK,
    ACTIONS(7433), 1,
      anon_sym_SLASH,
    ACTIONS(7435), 1,
      anon_sym_CARET,
    ACTIONS(7437), 1,
      anon_sym_PIPE,
    ACTIONS(7439), 1,
      anon_sym_AMP,
    ACTIONS(7443), 1,
      anon_sym_GT_GT,
    ACTIONS(7449), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7451), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7453), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7455), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7457), 1,
      anon_sym_is,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7425), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7429), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7431), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7441), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7445), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7447), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6324), 3,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
    STATE(6041), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [156196] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(8177), 1,
      anon_sym_DOT_DOT,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1229), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(6042), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(1227), 19,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [156298] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8217), 1,
      anon_sym_and,
    ACTIONS(8241), 1,
      anon_sym_or,
    STATE(6043), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6594), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6592), 25,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_when,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [156386] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7190), 1,
      anon_sym_with,
    ACTIONS(7405), 1,
      anon_sym_as,
    ACTIONS(7427), 1,
      anon_sym_QMARK,
    ACTIONS(7433), 1,
      anon_sym_SLASH,
    ACTIONS(7435), 1,
      anon_sym_CARET,
    ACTIONS(7437), 1,
      anon_sym_PIPE,
    ACTIONS(7439), 1,
      anon_sym_AMP,
    ACTIONS(7443), 1,
      anon_sym_GT_GT,
    ACTIONS(7449), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7451), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7453), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7455), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7457), 1,
      anon_sym_is,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7425), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7429), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7431), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7441), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7445), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7447), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5416), 3,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
    STATE(6044), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [156524] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7220), 1,
      anon_sym_QMARK,
    ACTIONS(7226), 1,
      anon_sym_SLASH,
    ACTIONS(7228), 1,
      anon_sym_CARET,
    ACTIONS(7230), 1,
      anon_sym_PIPE,
    ACTIONS(7232), 1,
      anon_sym_AMP,
    ACTIONS(7236), 1,
      anon_sym_GT_GT,
    ACTIONS(7242), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7244), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7246), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7248), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7218), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7222), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7224), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7234), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7238), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7240), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6190), 3,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
    STATE(6045), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [156662] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4343), 1,
      anon_sym_LBRACE,
    ACTIONS(4359), 1,
      sym_discard,
    ACTIONS(7467), 1,
      sym__identifier_token,
    ACTIONS(7471), 1,
      anon_sym_LPAREN,
    ACTIONS(7919), 1,
      anon_sym_COMMA,
    ACTIONS(8243), 1,
      anon_sym_RPAREN,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(4153), 1,
      sym_parenthesized_variable_designation,
    STATE(4162), 1,
      sym__variable_designation,
    STATE(6139), 1,
      sym_positional_pattern_clause,
    STATE(6746), 1,
      sym_property_pattern_clause,
    STATE(7797), 1,
      sym_identifier,
    STATE(9076), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    ACTIONS(4355), 2,
      anon_sym_and,
      anon_sym_or,
    STATE(6046), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [156774] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(8247), 1,
      anon_sym_QMARK,
    ACTIONS(8253), 1,
      anon_sym_SLASH,
    ACTIONS(8255), 1,
      anon_sym_CARET,
    ACTIONS(8257), 1,
      anon_sym_PIPE,
    ACTIONS(8259), 1,
      anon_sym_AMP,
    ACTIONS(8263), 1,
      anon_sym_GT_GT,
    ACTIONS(8269), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8271), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8273), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8275), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8277), 1,
      anon_sym_as,
    ACTIONS(8279), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8245), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8249), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8251), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8261), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8265), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8267), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6332), 3,
      anon_sym_and,
      anon_sym_or,
      anon_sym_by,
    STATE(6047), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [156912] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(8269), 1,
      anon_sym_DOT_DOT,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(6048), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 17,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_by,
      anon_sym_as,
      anon_sym_is,
  [157018] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(8269), 1,
      anon_sym_DOT_DOT,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1229), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(6049), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(1227), 19,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_by,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [157120] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4343), 1,
      anon_sym_LBRACE,
    ACTIONS(4359), 1,
      sym_discard,
    ACTIONS(7467), 1,
      sym__identifier_token,
    ACTIONS(7471), 1,
      anon_sym_LPAREN,
    ACTIONS(7919), 1,
      anon_sym_COMMA,
    ACTIONS(8281), 1,
      anon_sym_RPAREN,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(4153), 1,
      sym_parenthesized_variable_designation,
    STATE(4162), 1,
      sym__variable_designation,
    STATE(6139), 1,
      sym_positional_pattern_clause,
    STATE(6746), 1,
      sym_property_pattern_clause,
    STATE(7797), 1,
      sym_identifier,
    STATE(9076), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    ACTIONS(4355), 2,
      anon_sym_and,
      anon_sym_or,
    STATE(6050), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [157232] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8283), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
    STATE(6051), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [157370] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4343), 1,
      anon_sym_LBRACE,
    ACTIONS(4359), 1,
      sym_discard,
    ACTIONS(7467), 1,
      sym__identifier_token,
    ACTIONS(7471), 1,
      anon_sym_LPAREN,
    ACTIONS(7919), 1,
      anon_sym_COMMA,
    ACTIONS(8285), 1,
      anon_sym_RPAREN,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(4153), 1,
      sym_parenthesized_variable_designation,
    STATE(4162), 1,
      sym__variable_designation,
    STATE(6139), 1,
      sym_positional_pattern_clause,
    STATE(6746), 1,
      sym_property_pattern_clause,
    STATE(7797), 1,
      sym_identifier,
    STATE(9076), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    ACTIONS(4355), 2,
      anon_sym_and,
      anon_sym_or,
    STATE(6052), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [157482] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7934), 1,
      anon_sym_DOT_DOT,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(6053), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 17,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_equals,
      anon_sym_as,
      anon_sym_is,
  [157588] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(7934), 1,
      anon_sym_DOT_DOT,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1229), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(6054), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(1227), 19,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_equals,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [157690] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4343), 1,
      anon_sym_LBRACE,
    ACTIONS(4359), 1,
      sym_discard,
    ACTIONS(7467), 1,
      sym__identifier_token,
    ACTIONS(7471), 1,
      anon_sym_LPAREN,
    ACTIONS(7919), 1,
      anon_sym_COMMA,
    ACTIONS(8287), 1,
      anon_sym_RPAREN,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(4153), 1,
      sym_parenthesized_variable_designation,
    STATE(4162), 1,
      sym__variable_designation,
    STATE(6139), 1,
      sym_positional_pattern_clause,
    STATE(6746), 1,
      sym_property_pattern_clause,
    STATE(7797), 1,
      sym_identifier,
    STATE(9076), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    ACTIONS(4355), 2,
      anon_sym_and,
      anon_sym_or,
    STATE(6055), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [157802] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7928), 1,
      anon_sym_SLASH,
    ACTIONS(7932), 1,
      anon_sym_GT_GT,
    ACTIONS(7934), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7938), 1,
      anon_sym_AMP,
    ACTIONS(7944), 1,
      anon_sym_as,
    ACTIONS(7946), 1,
      anon_sym_is,
    ACTIONS(7948), 1,
      anon_sym_CARET,
    ACTIONS(7950), 1,
      anon_sym_PIPE,
    ACTIONS(7952), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7954), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7956), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7960), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7924), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7926), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7930), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7936), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7940), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7942), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6332), 3,
      anon_sym_and,
      anon_sym_or,
      anon_sym_equals,
    STATE(6056), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [157940] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7986), 1,
      anon_sym_DOT_DOT,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(6057), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 17,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_on,
      anon_sym_as,
      anon_sym_is,
  [158046] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(7986), 1,
      anon_sym_DOT_DOT,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1229), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(6058), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(1227), 19,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_on,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [158148] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4343), 1,
      anon_sym_LBRACE,
    ACTIONS(4359), 1,
      sym_discard,
    ACTIONS(7467), 1,
      sym__identifier_token,
    ACTIONS(7471), 1,
      anon_sym_LPAREN,
    ACTIONS(7919), 1,
      anon_sym_COMMA,
    ACTIONS(8289), 1,
      anon_sym_RPAREN,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(4153), 1,
      sym_parenthesized_variable_designation,
    STATE(4162), 1,
      sym__variable_designation,
    STATE(6139), 1,
      sym_positional_pattern_clause,
    STATE(6746), 1,
      sym_property_pattern_clause,
    STATE(7797), 1,
      sym_identifier,
    STATE(9076), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    ACTIONS(4355), 2,
      anon_sym_and,
      anon_sym_or,
    STATE(6059), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [158260] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7980), 1,
      anon_sym_SLASH,
    ACTIONS(7984), 1,
      anon_sym_GT_GT,
    ACTIONS(7986), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7990), 1,
      anon_sym_AMP,
    ACTIONS(7996), 1,
      anon_sym_as,
    ACTIONS(7998), 1,
      anon_sym_is,
    ACTIONS(8000), 1,
      anon_sym_CARET,
    ACTIONS(8002), 1,
      anon_sym_PIPE,
    ACTIONS(8004), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8006), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8008), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8010), 1,
      anon_sym_QMARK,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7976), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7978), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7982), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7988), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7992), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7994), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6332), 3,
      anon_sym_and,
      anon_sym_or,
      anon_sym_on,
    STATE(6060), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [158398] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7903), 1,
      anon_sym_DOT_DOT,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(6061), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 17,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_GT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
  [158504] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(7903), 1,
      anon_sym_DOT_DOT,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1229), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(6062), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(1227), 19,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_GT,
      anon_sym_switch,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [158606] = 41,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6190), 1,
      anon_sym_RPAREN,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8083), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(6063), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [158746] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6992), 1,
      anon_sym_as,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(7881), 1,
      anon_sym_QMARK,
    ACTIONS(7887), 1,
      anon_sym_SLASH,
    ACTIONS(7889), 1,
      anon_sym_CARET,
    ACTIONS(7891), 1,
      anon_sym_PIPE,
    ACTIONS(7893), 1,
      anon_sym_AMP,
    ACTIONS(7897), 1,
      anon_sym_GT_GT,
    ACTIONS(7903), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7905), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7907), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7909), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7911), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7883), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7885), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7895), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7899), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7901), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6332), 3,
      anon_sym_EQ_GT,
      anon_sym_and,
      anon_sym_or,
    STATE(6064), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [158884] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5336), 1,
      anon_sym_LBRACK,
    ACTIONS(5921), 1,
      anon_sym_LBRACE,
    ACTIONS(5924), 1,
      anon_sym_QMARK,
    STATE(4328), 1,
      sym_initializer_expression,
    STATE(6065), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5346), 10,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5340), 24,
      anon_sym_LPAREN,
      anon_sym_in,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [158976] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8083), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
    STATE(6066), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [159114] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8291), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
    STATE(6067), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [159252] = 29,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(8253), 1,
      anon_sym_SLASH,
    ACTIONS(8263), 1,
      anon_sym_GT_GT,
    ACTIONS(8269), 1,
      anon_sym_DOT_DOT,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8249), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8251), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8261), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6344), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    STATE(6068), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 13,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_by,
      anon_sym_as,
      anon_sym_is,
  [159368] = 26,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(8253), 1,
      anon_sym_SLASH,
    ACTIONS(8269), 1,
      anon_sym_DOT_DOT,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8251), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(6069), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 15,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_by,
      anon_sym_as,
      anon_sym_is,
  [159478] = 35,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(8253), 1,
      anon_sym_SLASH,
    ACTIONS(8259), 1,
      anon_sym_AMP,
    ACTIONS(8263), 1,
      anon_sym_GT_GT,
    ACTIONS(8269), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8277), 1,
      anon_sym_as,
    ACTIONS(8279), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(8245), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8249), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8251), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8261), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8265), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8267), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 7,
      anon_sym_CARET,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_by,
    STATE(6070), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [159606] = 36,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(8253), 1,
      anon_sym_SLASH,
    ACTIONS(8255), 1,
      anon_sym_CARET,
    ACTIONS(8259), 1,
      anon_sym_AMP,
    ACTIONS(8263), 1,
      anon_sym_GT_GT,
    ACTIONS(8269), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8277), 1,
      anon_sym_as,
    ACTIONS(8279), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(8245), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8249), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8251), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8261), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8265), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8267), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 6,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_by,
    STATE(6071), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [159736] = 34,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(8253), 1,
      anon_sym_SLASH,
    ACTIONS(8263), 1,
      anon_sym_GT_GT,
    ACTIONS(8269), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8277), 1,
      anon_sym_as,
    ACTIONS(8279), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8245), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8249), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8251), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8261), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8265), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8267), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(6342), 7,
      anon_sym_CARET,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_by,
    STATE(6072), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [159862] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(8253), 1,
      anon_sym_SLASH,
    ACTIONS(8269), 1,
      anon_sym_DOT_DOT,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8249), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8251), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(6073), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 15,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_by,
      anon_sym_as,
      anon_sym_is,
  [159974] = 33,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(8253), 1,
      anon_sym_SLASH,
    ACTIONS(8263), 1,
      anon_sym_GT_GT,
    ACTIONS(8269), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8277), 1,
      anon_sym_as,
    ACTIONS(8279), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8245), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8249), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8251), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8261), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8267), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(6342), 9,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_by,
    STATE(6074), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [160098] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8221), 1,
      anon_sym_and,
    ACTIONS(8293), 1,
      anon_sym_or,
    STATE(6075), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5881), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5879), 25,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [160186] = 42,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(7962), 1,
      anon_sym_COMMA,
    ACTIONS(8295), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    STATE(8462), 1,
      aux_sym_for_statement_repeat1,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6076), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [160328] = 42,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(8297), 1,
      anon_sym_COMMA,
    ACTIONS(8299), 1,
      anon_sym_RBRACE,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    STATE(8623), 1,
      aux_sym_for_statement_repeat1,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6077), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [160470] = 37,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(8253), 1,
      anon_sym_SLASH,
    ACTIONS(8255), 1,
      anon_sym_CARET,
    ACTIONS(8257), 1,
      anon_sym_PIPE,
    ACTIONS(8259), 1,
      anon_sym_AMP,
    ACTIONS(8263), 1,
      anon_sym_GT_GT,
    ACTIONS(8269), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8277), 1,
      anon_sym_as,
    ACTIONS(8279), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8245), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8249), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8251), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8261), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8265), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8267), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 6,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_by,
    STATE(6078), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [160602] = 38,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(8253), 1,
      anon_sym_SLASH,
    ACTIONS(8255), 1,
      anon_sym_CARET,
    ACTIONS(8257), 1,
      anon_sym_PIPE,
    ACTIONS(8259), 1,
      anon_sym_AMP,
    ACTIONS(8263), 1,
      anon_sym_GT_GT,
    ACTIONS(8269), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8271), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8277), 1,
      anon_sym_as,
    ACTIONS(8279), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8245), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8249), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8251), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8261), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8265), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8267), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 5,
      anon_sym_and,
      anon_sym_or,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_by,
    STATE(6079), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [160736] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(8253), 1,
      anon_sym_SLASH,
    ACTIONS(8255), 1,
      anon_sym_CARET,
    ACTIONS(8257), 1,
      anon_sym_PIPE,
    ACTIONS(8259), 1,
      anon_sym_AMP,
    ACTIONS(8263), 1,
      anon_sym_GT_GT,
    ACTIONS(8269), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8271), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8273), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8275), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8277), 1,
      anon_sym_as,
    ACTIONS(8279), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8245), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8249), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8251), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8261), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8265), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8267), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 3,
      anon_sym_and,
      anon_sym_or,
      anon_sym_by,
    STATE(6080), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [160874] = 42,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(8049), 1,
      anon_sym_QMARK,
    ACTIONS(8055), 1,
      anon_sym_SLASH,
    ACTIONS(8057), 1,
      anon_sym_CARET,
    ACTIONS(8059), 1,
      anon_sym_PIPE,
    ACTIONS(8061), 1,
      anon_sym_AMP,
    ACTIONS(8065), 1,
      anon_sym_GT_GT,
    ACTIONS(8071), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8073), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8075), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8077), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8205), 1,
      anon_sym_COMMA,
    ACTIONS(8301), 1,
      anon_sym_SEMI,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    STATE(8615), 1,
      aux_sym_for_statement_repeat1,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8047), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8051), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8053), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8063), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8067), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8069), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6081), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [161016] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4343), 1,
      anon_sym_LBRACE,
    ACTIONS(4359), 1,
      sym_discard,
    ACTIONS(7467), 1,
      sym__identifier_token,
    ACTIONS(7471), 1,
      anon_sym_LPAREN,
    ACTIONS(7919), 1,
      anon_sym_COMMA,
    ACTIONS(8303), 1,
      anon_sym_RPAREN,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(4153), 1,
      sym_parenthesized_variable_designation,
    STATE(4162), 1,
      sym__variable_designation,
    STATE(6139), 1,
      sym_positional_pattern_clause,
    STATE(6746), 1,
      sym_property_pattern_clause,
    STATE(7797), 1,
      sym_identifier,
    STATE(9076), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    ACTIONS(4355), 2,
      anon_sym_and,
      anon_sym_or,
    STATE(6082), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [161128] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(8107), 1,
      anon_sym_DOT_DOT,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(6083), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 17,
      anon_sym_in,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
  [161234] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(8107), 1,
      anon_sym_DOT_DOT,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1229), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(6084), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(1227), 19,
      anon_sym_in,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [161336] = 42,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(2677), 1,
      anon_sym_COMMA,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(8305), 1,
      anon_sym_RBRACK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    STATE(8682), 1,
      aux_sym_array_rank_specifier_repeat1,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6085), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [161478] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(8247), 1,
      anon_sym_QMARK,
    ACTIONS(8253), 1,
      anon_sym_SLASH,
    ACTIONS(8255), 1,
      anon_sym_CARET,
    ACTIONS(8257), 1,
      anon_sym_PIPE,
    ACTIONS(8259), 1,
      anon_sym_AMP,
    ACTIONS(8263), 1,
      anon_sym_GT_GT,
    ACTIONS(8269), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8271), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8273), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8275), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8277), 1,
      anon_sym_as,
    ACTIONS(8279), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8245), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8249), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8251), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8261), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8265), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8267), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6320), 3,
      anon_sym_and,
      anon_sym_or,
      anon_sym_by,
    STATE(6086), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [161616] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(8269), 1,
      anon_sym_DOT_DOT,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6330), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(6087), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6328), 19,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_by,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [161718] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(8247), 1,
      anon_sym_QMARK,
    ACTIONS(8253), 1,
      anon_sym_SLASH,
    ACTIONS(8255), 1,
      anon_sym_CARET,
    ACTIONS(8257), 1,
      anon_sym_PIPE,
    ACTIONS(8259), 1,
      anon_sym_AMP,
    ACTIONS(8263), 1,
      anon_sym_GT_GT,
    ACTIONS(8269), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8271), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8273), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8275), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8277), 1,
      anon_sym_as,
    ACTIONS(8279), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8245), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8249), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8251), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8261), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8265), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8267), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6324), 3,
      anon_sym_and,
      anon_sym_or,
      anon_sym_by,
    STATE(6088), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [161856] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(8247), 1,
      anon_sym_QMARK,
    ACTIONS(8253), 1,
      anon_sym_SLASH,
    ACTIONS(8255), 1,
      anon_sym_CARET,
    ACTIONS(8257), 1,
      anon_sym_PIPE,
    ACTIONS(8259), 1,
      anon_sym_AMP,
    ACTIONS(8263), 1,
      anon_sym_GT_GT,
    ACTIONS(8269), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8271), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8273), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8275), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8277), 1,
      anon_sym_as,
    ACTIONS(8279), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8245), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8249), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8251), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8261), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8265), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8267), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5416), 3,
      anon_sym_and,
      anon_sym_or,
      anon_sym_by,
    STATE(6089), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [161994] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(8247), 1,
      anon_sym_QMARK,
    ACTIONS(8253), 1,
      anon_sym_SLASH,
    ACTIONS(8255), 1,
      anon_sym_CARET,
    ACTIONS(8257), 1,
      anon_sym_PIPE,
    ACTIONS(8259), 1,
      anon_sym_AMP,
    ACTIONS(8263), 1,
      anon_sym_GT_GT,
    ACTIONS(8269), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8271), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8273), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8275), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8277), 1,
      anon_sym_as,
    ACTIONS(8279), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8245), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8249), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8251), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8261), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8265), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8267), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5644), 3,
      anon_sym_and,
      anon_sym_or,
      anon_sym_by,
    STATE(6090), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [162132] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(8247), 1,
      anon_sym_QMARK,
    ACTIONS(8253), 1,
      anon_sym_SLASH,
    ACTIONS(8255), 1,
      anon_sym_CARET,
    ACTIONS(8257), 1,
      anon_sym_PIPE,
    ACTIONS(8259), 1,
      anon_sym_AMP,
    ACTIONS(8263), 1,
      anon_sym_GT_GT,
    ACTIONS(8269), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8271), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8273), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8275), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8277), 1,
      anon_sym_as,
    ACTIONS(8279), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8245), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8249), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8251), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8261), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8265), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8267), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5424), 3,
      anon_sym_and,
      anon_sym_or,
      anon_sym_by,
    STATE(6091), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [162270] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(8247), 1,
      anon_sym_QMARK,
    ACTIONS(8253), 1,
      anon_sym_SLASH,
    ACTIONS(8255), 1,
      anon_sym_CARET,
    ACTIONS(8257), 1,
      anon_sym_PIPE,
    ACTIONS(8259), 1,
      anon_sym_AMP,
    ACTIONS(8263), 1,
      anon_sym_GT_GT,
    ACTIONS(8269), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8271), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8273), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8275), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8277), 1,
      anon_sym_as,
    ACTIONS(8279), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8245), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8249), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8251), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8261), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8265), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8267), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6336), 3,
      anon_sym_and,
      anon_sym_or,
      anon_sym_by,
    STATE(6092), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [162408] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8221), 1,
      anon_sym_and,
    ACTIONS(8293), 1,
      anon_sym_or,
    STATE(6093), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6594), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6592), 25,
      sym_interpolation_close_brace,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [162496] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(8247), 1,
      anon_sym_QMARK,
    ACTIONS(8253), 1,
      anon_sym_SLASH,
    ACTIONS(8255), 1,
      anon_sym_CARET,
    ACTIONS(8257), 1,
      anon_sym_PIPE,
    ACTIONS(8259), 1,
      anon_sym_AMP,
    ACTIONS(8263), 1,
      anon_sym_GT_GT,
    ACTIONS(8269), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8271), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8273), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8275), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8277), 1,
      anon_sym_as,
    ACTIONS(8279), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8245), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8249), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8251), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8261), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8265), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8267), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5572), 3,
      anon_sym_and,
      anon_sym_or,
      anon_sym_by,
    STATE(6094), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [162634] = 42,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(8049), 1,
      anon_sym_QMARK,
    ACTIONS(8055), 1,
      anon_sym_SLASH,
    ACTIONS(8057), 1,
      anon_sym_CARET,
    ACTIONS(8059), 1,
      anon_sym_PIPE,
    ACTIONS(8061), 1,
      anon_sym_AMP,
    ACTIONS(8065), 1,
      anon_sym_GT_GT,
    ACTIONS(8071), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8073), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8075), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8077), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8205), 1,
      anon_sym_COMMA,
    ACTIONS(8307), 1,
      anon_sym_SEMI,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    STATE(8663), 1,
      aux_sym_for_statement_repeat1,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8047), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8051), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8053), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8063), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8067), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8069), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6095), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [162776] = 42,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(8049), 1,
      anon_sym_QMARK,
    ACTIONS(8055), 1,
      anon_sym_SLASH,
    ACTIONS(8057), 1,
      anon_sym_CARET,
    ACTIONS(8059), 1,
      anon_sym_PIPE,
    ACTIONS(8061), 1,
      anon_sym_AMP,
    ACTIONS(8065), 1,
      anon_sym_GT_GT,
    ACTIONS(8071), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8073), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8075), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8077), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8205), 1,
      anon_sym_COMMA,
    ACTIONS(8309), 1,
      anon_sym_SEMI,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    STATE(8673), 1,
      aux_sym_for_statement_repeat1,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8047), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8051), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8053), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8063), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8067), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8069), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6096), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [162918] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(8247), 1,
      anon_sym_QMARK,
    ACTIONS(8253), 1,
      anon_sym_SLASH,
    ACTIONS(8255), 1,
      anon_sym_CARET,
    ACTIONS(8257), 1,
      anon_sym_PIPE,
    ACTIONS(8259), 1,
      anon_sym_AMP,
    ACTIONS(8263), 1,
      anon_sym_GT_GT,
    ACTIONS(8269), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8271), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8273), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8275), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8277), 1,
      anon_sym_as,
    ACTIONS(8279), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8245), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8249), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8251), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8261), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8265), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8267), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5584), 3,
      anon_sym_and,
      anon_sym_or,
      anon_sym_by,
    STATE(6097), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [163056] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(8247), 1,
      anon_sym_QMARK,
    ACTIONS(8253), 1,
      anon_sym_SLASH,
    ACTIONS(8255), 1,
      anon_sym_CARET,
    ACTIONS(8257), 1,
      anon_sym_PIPE,
    ACTIONS(8259), 1,
      anon_sym_AMP,
    ACTIONS(8263), 1,
      anon_sym_GT_GT,
    ACTIONS(8269), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8271), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8273), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8275), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8277), 1,
      anon_sym_as,
    ACTIONS(8279), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8245), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8249), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8251), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8261), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8265), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8267), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5624), 3,
      anon_sym_and,
      anon_sym_or,
      anon_sym_by,
    STATE(6098), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [163194] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6988), 1,
      anon_sym_switch,
    ACTIONS(6996), 1,
      anon_sym_with,
    ACTIONS(8247), 1,
      anon_sym_QMARK,
    ACTIONS(8253), 1,
      anon_sym_SLASH,
    ACTIONS(8255), 1,
      anon_sym_CARET,
    ACTIONS(8257), 1,
      anon_sym_PIPE,
    ACTIONS(8259), 1,
      anon_sym_AMP,
    ACTIONS(8263), 1,
      anon_sym_GT_GT,
    ACTIONS(8269), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8271), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8273), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8275), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8277), 1,
      anon_sym_as,
    ACTIONS(8279), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8245), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8249), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8251), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8261), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8265), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8267), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6190), 3,
      anon_sym_and,
      anon_sym_or,
      anon_sym_by,
    STATE(6099), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [163332] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7190), 1,
      anon_sym_with,
    ACTIONS(7405), 1,
      anon_sym_as,
    ACTIONS(7427), 1,
      anon_sym_QMARK,
    ACTIONS(7433), 1,
      anon_sym_SLASH,
    ACTIONS(7435), 1,
      anon_sym_CARET,
    ACTIONS(7437), 1,
      anon_sym_PIPE,
    ACTIONS(7439), 1,
      anon_sym_AMP,
    ACTIONS(7443), 1,
      anon_sym_GT_GT,
    ACTIONS(7449), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7451), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7453), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7455), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7457), 1,
      anon_sym_is,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7425), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7429), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7431), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7441), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7445), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7447), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(5644), 3,
      sym_interpolation_close_brace,
      anon_sym_COLON,
      anon_sym_COMMA,
    STATE(6100), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [163470] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8311), 1,
      anon_sym_into,
    STATE(6102), 1,
      aux_sym__query_body_repeat2,
    STATE(6101), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6476), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6474), 25,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_by,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [163558] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8311), 1,
      anon_sym_into,
    STATE(6104), 1,
      aux_sym__query_body_repeat2,
    STATE(6102), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6482), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6480), 25,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_by,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [163646] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8311), 1,
      anon_sym_into,
    STATE(6105), 1,
      aux_sym__query_body_repeat2,
    STATE(6103), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6482), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6480), 25,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_by,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [163734] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8313), 1,
      anon_sym_into,
    STATE(6104), 10,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
      aux_sym__query_body_repeat2,
    ACTIONS(6486), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6484), 25,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_by,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [163820] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8311), 1,
      anon_sym_into,
    STATE(6104), 1,
      aux_sym__query_body_repeat2,
    STATE(6105), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6493), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6491), 25,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_by,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [163908] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4343), 1,
      anon_sym_LBRACE,
    ACTIONS(4359), 1,
      sym_discard,
    ACTIONS(7467), 1,
      sym__identifier_token,
    ACTIONS(7471), 1,
      anon_sym_LPAREN,
    ACTIONS(7919), 1,
      anon_sym_COMMA,
    ACTIONS(8316), 1,
      anon_sym_RPAREN,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(4153), 1,
      sym_parenthesized_variable_designation,
    STATE(4162), 1,
      sym__variable_designation,
    STATE(6139), 1,
      sym_positional_pattern_clause,
    STATE(6746), 1,
      sym_property_pattern_clause,
    STATE(7797), 1,
      sym_identifier,
    STATE(9076), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    ACTIONS(4355), 2,
      anon_sym_and,
      anon_sym_or,
    STATE(6106), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [164020] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8318), 1,
      anon_sym_into,
    STATE(6108), 1,
      aux_sym__query_body_repeat2,
    STATE(6107), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6476), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6474), 25,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_equals,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [164108] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8318), 1,
      anon_sym_into,
    STATE(6110), 1,
      aux_sym__query_body_repeat2,
    STATE(6108), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6482), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6480), 25,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_equals,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [164196] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8318), 1,
      anon_sym_into,
    STATE(6111), 1,
      aux_sym__query_body_repeat2,
    STATE(6109), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6482), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6480), 25,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_equals,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [164284] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8320), 1,
      anon_sym_into,
    STATE(6110), 10,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
      aux_sym__query_body_repeat2,
    ACTIONS(6486), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6484), 25,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_equals,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [164370] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8318), 1,
      anon_sym_into,
    STATE(6110), 1,
      aux_sym__query_body_repeat2,
    STATE(6111), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6493), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6491), 25,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_equals,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [164458] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8323), 1,
      anon_sym_into,
    STATE(6113), 1,
      aux_sym__query_body_repeat2,
    STATE(6112), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6476), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6474), 25,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_on,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [164546] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8323), 1,
      anon_sym_into,
    STATE(6115), 1,
      aux_sym__query_body_repeat2,
    STATE(6113), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6482), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6480), 25,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_on,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [164634] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8323), 1,
      anon_sym_into,
    STATE(6116), 1,
      aux_sym__query_body_repeat2,
    STATE(6114), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6482), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6480), 25,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_on,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [164722] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8325), 1,
      anon_sym_into,
    STATE(6115), 10,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
      aux_sym__query_body_repeat2,
    ACTIONS(6486), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6484), 25,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_on,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [164808] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8323), 1,
      anon_sym_into,
    STATE(6115), 1,
      aux_sym__query_body_repeat2,
    STATE(6116), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6493), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6491), 25,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_on,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [164896] = 42,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7652), 1,
      anon_sym_COMMA,
    ACTIONS(7654), 1,
      anon_sym_RBRACE,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    STATE(8660), 1,
      aux_sym_for_statement_repeat1,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6117), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [165038] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8328), 1,
      anon_sym_into,
    STATE(6119), 1,
      aux_sym__query_body_repeat2,
    STATE(6118), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6476), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6474), 25,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_GT,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [165126] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8328), 1,
      anon_sym_into,
    STATE(6121), 1,
      aux_sym__query_body_repeat2,
    STATE(6119), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6482), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6480), 25,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_GT,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [165214] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8328), 1,
      anon_sym_into,
    STATE(6122), 1,
      aux_sym__query_body_repeat2,
    STATE(6120), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6482), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6480), 25,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_GT,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [165302] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8330), 1,
      anon_sym_into,
    STATE(6121), 10,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
      aux_sym__query_body_repeat2,
    ACTIONS(6486), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6484), 25,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_GT,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [165388] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8328), 1,
      anon_sym_into,
    STATE(6121), 1,
      aux_sym__query_body_repeat2,
    STATE(6122), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6493), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6491), 25,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_GT,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [165476] = 42,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(7962), 1,
      anon_sym_COMMA,
    ACTIONS(8333), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    STATE(8653), 1,
      aux_sym_for_statement_repeat1,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6123), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [165618] = 42,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(7962), 1,
      anon_sym_COMMA,
    ACTIONS(8335), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    STATE(8504), 1,
      aux_sym_for_statement_repeat1,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6124), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [165760] = 21,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8337), 1,
      sym__identifier_token,
    ACTIONS(8341), 1,
      anon_sym_LPAREN,
    ACTIONS(8343), 1,
      anon_sym_BANG,
    ACTIONS(8347), 1,
      anon_sym_SQUOTE,
    ACTIONS(8349), 1,
      sym_integer_literal,
    STATE(7808), 1,
      sym__reserved_identifier,
    STATE(8102), 1,
      sym__preproc_expression,
    ACTIONS(8345), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8240), 6,
      sym_character_literal,
      sym_boolean_literal,
      sym_identifier,
      sym_preproc_parenthesized_expression,
      sym_preproc_unary_expression,
      sym_preproc_binary_expression,
    STATE(6125), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(8339), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [165859] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(8357), 1,
      anon_sym_SLASH,
    ACTIONS(8359), 1,
      anon_sym_CARET,
    ACTIONS(8361), 1,
      anon_sym_PIPE,
    ACTIONS(8363), 1,
      anon_sym_AMP,
    ACTIONS(8367), 1,
      anon_sym_GT_GT,
    ACTIONS(8373), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8375), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8377), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8379), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8381), 1,
      anon_sym_as,
    ACTIONS(8383), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6342), 2,
      anon_sym_into,
      anon_sym_on,
    ACTIONS(8351), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8353), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8355), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8365), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8369), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8371), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6126), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [165996] = 21,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(141), 1,
      anon_sym_SQUOTE,
    ACTIONS(8385), 1,
      anon_sym_LPAREN,
    ACTIONS(8387), 1,
      anon_sym_BANG,
    ACTIONS(8389), 1,
      sym_integer_literal,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8036), 1,
      sym__preproc_expression,
    ACTIONS(77), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8247), 6,
      sym_character_literal,
      sym_boolean_literal,
      sym_identifier,
      sym_preproc_parenthesized_expression,
      sym_preproc_unary_expression,
      sym_preproc_binary_expression,
    STATE(6127), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [166095] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(8397), 1,
      anon_sym_SLASH,
    ACTIONS(8399), 1,
      anon_sym_CARET,
    ACTIONS(8401), 1,
      anon_sym_PIPE,
    ACTIONS(8403), 1,
      anon_sym_AMP,
    ACTIONS(8407), 1,
      anon_sym_GT_GT,
    ACTIONS(8413), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8415), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8417), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8419), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8421), 1,
      anon_sym_as,
    ACTIONS(8423), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6342), 2,
      anon_sym_into,
      anon_sym_by,
    ACTIONS(8391), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8393), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8395), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8405), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8409), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8411), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6128), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [166232] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8083), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(6129), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [166369] = 21,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8337), 1,
      sym__identifier_token,
    ACTIONS(8341), 1,
      anon_sym_LPAREN,
    ACTIONS(8343), 1,
      anon_sym_BANG,
    ACTIONS(8347), 1,
      anon_sym_SQUOTE,
    ACTIONS(8349), 1,
      sym_integer_literal,
    STATE(7808), 1,
      sym__reserved_identifier,
    STATE(8104), 1,
      sym__preproc_expression,
    ACTIONS(8345), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8240), 6,
      sym_character_literal,
      sym_boolean_literal,
      sym_identifier,
      sym_preproc_parenthesized_expression,
      sym_preproc_unary_expression,
      sym_preproc_binary_expression,
    STATE(6130), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(8339), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [166468] = 21,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8337), 1,
      sym__identifier_token,
    ACTIONS(8341), 1,
      anon_sym_LPAREN,
    ACTIONS(8343), 1,
      anon_sym_BANG,
    ACTIONS(8347), 1,
      anon_sym_SQUOTE,
    ACTIONS(8349), 1,
      sym_integer_literal,
    STATE(7808), 1,
      sym__reserved_identifier,
    STATE(8037), 1,
      sym__preproc_expression,
    ACTIONS(8345), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8240), 6,
      sym_character_literal,
      sym_boolean_literal,
      sym_identifier,
      sym_preproc_parenthesized_expression,
      sym_preproc_unary_expression,
      sym_preproc_binary_expression,
    STATE(6131), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(8339), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [166567] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(8397), 1,
      anon_sym_SLASH,
    ACTIONS(8399), 1,
      anon_sym_CARET,
    ACTIONS(8401), 1,
      anon_sym_PIPE,
    ACTIONS(8403), 1,
      anon_sym_AMP,
    ACTIONS(8407), 1,
      anon_sym_GT_GT,
    ACTIONS(8413), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8415), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8417), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8419), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8421), 1,
      anon_sym_as,
    ACTIONS(8423), 1,
      anon_sym_is,
    ACTIONS(8425), 1,
      anon_sym_QMARK,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5584), 2,
      anon_sym_into,
      anon_sym_by,
    ACTIONS(8391), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8393), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8395), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8405), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8409), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8411), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6132), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [166704] = 26,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4343), 1,
      anon_sym_LBRACE,
    ACTIONS(4357), 1,
      anon_sym_COLON,
    ACTIONS(4359), 1,
      sym_discard,
    ACTIONS(7467), 1,
      sym__identifier_token,
    ACTIONS(7471), 1,
      anon_sym_LPAREN,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(4153), 1,
      sym_parenthesized_variable_designation,
    STATE(4162), 1,
      sym__variable_designation,
    STATE(4163), 1,
      sym_identifier,
    STATE(6693), 1,
      sym_positional_pattern_clause,
    STATE(6774), 1,
      sym_property_pattern_clause,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9832), 1,
      sym__lambda_parameters,
    ACTIONS(4355), 3,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
    STATE(6133), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 21,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [166813] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(8397), 1,
      anon_sym_SLASH,
    ACTIONS(8399), 1,
      anon_sym_CARET,
    ACTIONS(8401), 1,
      anon_sym_PIPE,
    ACTIONS(8403), 1,
      anon_sym_AMP,
    ACTIONS(8407), 1,
      anon_sym_GT_GT,
    ACTIONS(8413), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8415), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8417), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8419), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8421), 1,
      anon_sym_as,
    ACTIONS(8423), 1,
      anon_sym_is,
    ACTIONS(8425), 1,
      anon_sym_QMARK,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5624), 2,
      anon_sym_into,
      anon_sym_by,
    ACTIONS(8391), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8393), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8395), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8405), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8409), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8411), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6134), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [166950] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(8431), 1,
      anon_sym_SLASH,
    ACTIONS(8433), 1,
      anon_sym_DOT_DOT,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8427), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8429), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(6135), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 14,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_equals,
      anon_sym_as,
      anon_sym_is,
  [167061] = 33,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(8431), 1,
      anon_sym_SLASH,
    ACTIONS(8433), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8439), 1,
      anon_sym_GT_GT,
    ACTIONS(8443), 1,
      anon_sym_as,
    ACTIONS(8445), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8427), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8429), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8435), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8437), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8441), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(6342), 8,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_equals,
    STATE(6136), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [167184] = 21,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8337), 1,
      sym__identifier_token,
    ACTIONS(8341), 1,
      anon_sym_LPAREN,
    ACTIONS(8343), 1,
      anon_sym_BANG,
    ACTIONS(8347), 1,
      anon_sym_SQUOTE,
    ACTIONS(8349), 1,
      sym_integer_literal,
    STATE(7808), 1,
      sym__reserved_identifier,
    STATE(8044), 1,
      sym__preproc_expression,
    ACTIONS(8345), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8240), 6,
      sym_character_literal,
      sym_boolean_literal,
      sym_identifier,
      sym_preproc_parenthesized_expression,
      sym_preproc_unary_expression,
      sym_preproc_binary_expression,
    STATE(6137), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(8339), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [167283] = 37,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(8431), 1,
      anon_sym_SLASH,
    ACTIONS(8433), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8439), 1,
      anon_sym_GT_GT,
    ACTIONS(8443), 1,
      anon_sym_as,
    ACTIONS(8445), 1,
      anon_sym_is,
    ACTIONS(8447), 1,
      anon_sym_CARET,
    ACTIONS(8449), 1,
      anon_sym_PIPE,
    ACTIONS(8451), 1,
      anon_sym_AMP,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8427), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8429), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8435), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8437), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8441), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8453), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6342), 5,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_equals,
    STATE(6138), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [167414] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4343), 1,
      anon_sym_LBRACE,
    ACTIONS(4359), 1,
      sym_discard,
    ACTIONS(7467), 1,
      sym__identifier_token,
    ACTIONS(8455), 1,
      anon_sym_LPAREN,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(4153), 1,
      sym_parenthesized_variable_designation,
    STATE(4156), 1,
      sym_identifier,
    STATE(4161), 1,
      sym__variable_designation,
    STATE(6716), 1,
      sym_property_pattern_clause,
    ACTIONS(4407), 2,
      anon_sym_and,
      anon_sym_or,
    ACTIONS(4405), 4,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(6139), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [167517] = 38,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(8431), 1,
      anon_sym_SLASH,
    ACTIONS(8433), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8439), 1,
      anon_sym_GT_GT,
    ACTIONS(8443), 1,
      anon_sym_as,
    ACTIONS(8445), 1,
      anon_sym_is,
    ACTIONS(8447), 1,
      anon_sym_CARET,
    ACTIONS(8449), 1,
      anon_sym_PIPE,
    ACTIONS(8451), 1,
      anon_sym_AMP,
    ACTIONS(8457), 1,
      anon_sym_AMP_AMP,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8427), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8429), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8435), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8437), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8441), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8453), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6342), 4,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_equals,
    STATE(6140), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [167650] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(8431), 1,
      anon_sym_SLASH,
    ACTIONS(8433), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8439), 1,
      anon_sym_GT_GT,
    ACTIONS(8443), 1,
      anon_sym_as,
    ACTIONS(8445), 1,
      anon_sym_is,
    ACTIONS(8447), 1,
      anon_sym_CARET,
    ACTIONS(8449), 1,
      anon_sym_PIPE,
    ACTIONS(8451), 1,
      anon_sym_AMP,
    ACTIONS(8457), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8459), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8461), 1,
      anon_sym_QMARK_QMARK,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6342), 2,
      anon_sym_into,
      anon_sym_equals,
    ACTIONS(8427), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8429), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8435), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8437), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8441), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8453), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    STATE(6141), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [167787] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8135), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    STATE(6142), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [167924] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(8397), 1,
      anon_sym_SLASH,
    ACTIONS(8399), 1,
      anon_sym_CARET,
    ACTIONS(8401), 1,
      anon_sym_PIPE,
    ACTIONS(8403), 1,
      anon_sym_AMP,
    ACTIONS(8407), 1,
      anon_sym_GT_GT,
    ACTIONS(8413), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8415), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8417), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8419), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8421), 1,
      anon_sym_as,
    ACTIONS(8423), 1,
      anon_sym_is,
    ACTIONS(8425), 1,
      anon_sym_QMARK,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6336), 2,
      anon_sym_into,
      anon_sym_by,
    ACTIONS(8391), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8393), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8395), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8405), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8409), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8411), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6143), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [168061] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6837), 1,
      anon_sym_as,
    ACTIONS(8465), 1,
      anon_sym_QMARK,
    ACTIONS(8471), 1,
      anon_sym_SLASH,
    ACTIONS(8473), 1,
      anon_sym_CARET,
    ACTIONS(8475), 1,
      anon_sym_PIPE,
    ACTIONS(8477), 1,
      anon_sym_AMP,
    ACTIONS(8481), 1,
      anon_sym_GT_GT,
    ACTIONS(8487), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8489), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8491), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8493), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8495), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6270), 2,
      anon_sym_EQ_GT,
      anon_sym_into,
    ACTIONS(8463), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8467), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8469), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8479), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8483), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8485), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6144), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [168198] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8497), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    STATE(6145), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [168335] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5883), 1,
      anon_sym_COLON,
    ACTIONS(4806), 3,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
    STATE(6146), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5654), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5652), 22,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [168422] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5889), 1,
      anon_sym_COLON,
    ACTIONS(4806), 3,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
    STATE(6147), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5630), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5628), 22,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [168509] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(8431), 1,
      anon_sym_SLASH,
    ACTIONS(8433), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8439), 1,
      anon_sym_GT_GT,
    ACTIONS(8443), 1,
      anon_sym_as,
    ACTIONS(8445), 1,
      anon_sym_is,
    ACTIONS(8447), 1,
      anon_sym_CARET,
    ACTIONS(8449), 1,
      anon_sym_PIPE,
    ACTIONS(8451), 1,
      anon_sym_AMP,
    ACTIONS(8457), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8459), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8461), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8499), 1,
      anon_sym_QMARK,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6266), 2,
      anon_sym_into,
      anon_sym_equals,
    ACTIONS(8427), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8429), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8435), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8437), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8441), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8453), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    STATE(6148), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [168646] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5399), 1,
      anon_sym_LPAREN,
    ACTIONS(8501), 1,
      anon_sym_LBRACK,
    STATE(6699), 1,
      sym_attribute_list,
    STATE(6149), 10,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
      aux_sym_class_declaration_repeat1,
    ACTIONS(5394), 33,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_static,
      anon_sym_ref,
      anon_sym_delegate,
      anon_sym_async,
      anon_sym_file,
      anon_sym_readonly,
      anon_sym_in,
      anon_sym_out,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_this,
      anon_sym_scoped,
      anon_sym_params,
      anon_sym_var,
      sym_predefined_type,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [168733] = 26,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(8397), 1,
      anon_sym_SLASH,
    ACTIONS(8413), 1,
      anon_sym_DOT_DOT,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8395), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(6150), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 14,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_by,
      anon_sym_as,
      anon_sym_is,
  [168842] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(8431), 1,
      anon_sym_SLASH,
    ACTIONS(8433), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8439), 1,
      anon_sym_GT_GT,
    ACTIONS(8443), 1,
      anon_sym_as,
    ACTIONS(8445), 1,
      anon_sym_is,
    ACTIONS(8447), 1,
      anon_sym_CARET,
    ACTIONS(8449), 1,
      anon_sym_PIPE,
    ACTIONS(8451), 1,
      anon_sym_AMP,
    ACTIONS(8457), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8459), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8461), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8499), 1,
      anon_sym_QMARK,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6270), 2,
      anon_sym_into,
      anon_sym_equals,
    ACTIONS(8427), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8429), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8435), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8437), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8441), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8453), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    STATE(6151), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [168979] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(8049), 1,
      anon_sym_QMARK,
    ACTIONS(8055), 1,
      anon_sym_SLASH,
    ACTIONS(8057), 1,
      anon_sym_CARET,
    ACTIONS(8059), 1,
      anon_sym_PIPE,
    ACTIONS(8061), 1,
      anon_sym_AMP,
    ACTIONS(8065), 1,
      anon_sym_GT_GT,
    ACTIONS(8071), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8073), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8075), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8077), 1,
      anon_sym_QMARK_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8047), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8051), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8053), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8063), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8067), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8069), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8504), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    STATE(6152), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [169116] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(8431), 1,
      anon_sym_SLASH,
    ACTIONS(8433), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8439), 1,
      anon_sym_GT_GT,
    ACTIONS(8443), 1,
      anon_sym_as,
    ACTIONS(8445), 1,
      anon_sym_is,
    ACTIONS(8447), 1,
      anon_sym_CARET,
    ACTIONS(8449), 1,
      anon_sym_PIPE,
    ACTIONS(8451), 1,
      anon_sym_AMP,
    ACTIONS(8457), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8459), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8461), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8499), 1,
      anon_sym_QMARK,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6190), 2,
      anon_sym_into,
      anon_sym_equals,
    ACTIONS(8427), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8429), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8435), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8437), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8441), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8453), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    STATE(6153), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [169253] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(8433), 1,
      anon_sym_DOT_DOT,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1229), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(6154), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(1227), 18,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_equals,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [169354] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7178), 1,
      anon_sym_switch,
    ACTIONS(7190), 1,
      anon_sym_with,
    ACTIONS(7405), 1,
      anon_sym_as,
    ACTIONS(7427), 1,
      anon_sym_QMARK,
    ACTIONS(7433), 1,
      anon_sym_SLASH,
    ACTIONS(7435), 1,
      anon_sym_CARET,
    ACTIONS(7437), 1,
      anon_sym_PIPE,
    ACTIONS(7439), 1,
      anon_sym_AMP,
    ACTIONS(7443), 1,
      anon_sym_GT_GT,
    ACTIONS(7449), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7451), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7453), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7455), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7457), 1,
      anon_sym_is,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7425), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7429), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7431), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7441), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7445), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7447), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8506), 2,
      sym_interpolation_close_brace,
      anon_sym_COLON,
    STATE(6155), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [169491] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(8397), 1,
      anon_sym_SLASH,
    ACTIONS(8399), 1,
      anon_sym_CARET,
    ACTIONS(8401), 1,
      anon_sym_PIPE,
    ACTIONS(8403), 1,
      anon_sym_AMP,
    ACTIONS(8407), 1,
      anon_sym_GT_GT,
    ACTIONS(8413), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8415), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8417), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8419), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8421), 1,
      anon_sym_as,
    ACTIONS(8423), 1,
      anon_sym_is,
    ACTIONS(8425), 1,
      anon_sym_QMARK,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5572), 2,
      anon_sym_into,
      anon_sym_by,
    ACTIONS(8391), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8393), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8395), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8405), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8409), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8411), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6156), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [169628] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8508), 1,
      anon_sym_and,
    STATE(6157), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6707), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6705), 25,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_when,
      anon_sym_DOT_DOT,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [169713] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4343), 1,
      anon_sym_LBRACE,
    ACTIONS(4359), 1,
      sym_discard,
    ACTIONS(7467), 1,
      sym__identifier_token,
    ACTIONS(8455), 1,
      anon_sym_LPAREN,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(4153), 1,
      sym_parenthesized_variable_designation,
    STATE(4156), 1,
      sym_identifier,
    STATE(4166), 1,
      sym__variable_designation,
    STATE(6733), 1,
      sym_property_pattern_clause,
    ACTIONS(4401), 2,
      anon_sym_and,
      anon_sym_or,
    ACTIONS(4399), 4,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(6158), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [169816] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8510), 1,
      anon_sym_and,
    ACTIONS(8512), 1,
      anon_sym_or,
    STATE(6159), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6594), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6592), 24,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_on,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [169903] = 29,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(8397), 1,
      anon_sym_SLASH,
    ACTIONS(8407), 1,
      anon_sym_GT_GT,
    ACTIONS(8413), 1,
      anon_sym_DOT_DOT,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8393), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8395), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8405), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6344), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    STATE(6160), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 12,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_by,
      anon_sym_as,
      anon_sym_is,
  [170018] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(8413), 1,
      anon_sym_DOT_DOT,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(6161), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 16,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_by,
      anon_sym_as,
      anon_sym_is,
  [170123] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(8049), 1,
      anon_sym_QMARK,
    ACTIONS(8055), 1,
      anon_sym_SLASH,
    ACTIONS(8057), 1,
      anon_sym_CARET,
    ACTIONS(8059), 1,
      anon_sym_PIPE,
    ACTIONS(8061), 1,
      anon_sym_AMP,
    ACTIONS(8065), 1,
      anon_sym_GT_GT,
    ACTIONS(8071), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8073), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8075), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8077), 1,
      anon_sym_QMARK_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8047), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8051), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8053), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8063), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8067), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8069), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8514), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    STATE(6162), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [170260] = 26,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4343), 1,
      anon_sym_LBRACE,
    ACTIONS(4357), 1,
      anon_sym_EQ_GT,
    ACTIONS(4359), 1,
      sym_discard,
    ACTIONS(7467), 1,
      sym__identifier_token,
    ACTIONS(8516), 1,
      anon_sym_LPAREN,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(4153), 1,
      sym_parenthesized_variable_designation,
    STATE(4162), 1,
      sym__variable_designation,
    STATE(5933), 1,
      sym_identifier,
    STATE(6693), 1,
      sym_positional_pattern_clause,
    STATE(6774), 1,
      sym_property_pattern_clause,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9890), 1,
      sym__lambda_parameters,
    ACTIONS(4355), 3,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
    STATE(6163), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 21,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [170369] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8518), 1,
      anon_sym_and,
    ACTIONS(8520), 1,
      anon_sym_or,
    STATE(6164), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6594), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6592), 24,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_GT,
      anon_sym_switch,
      anon_sym_when,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [170456] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8522), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(6165), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [170593] = 21,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8337), 1,
      sym__identifier_token,
    ACTIONS(8341), 1,
      anon_sym_LPAREN,
    ACTIONS(8343), 1,
      anon_sym_BANG,
    ACTIONS(8347), 1,
      anon_sym_SQUOTE,
    ACTIONS(8349), 1,
      sym_integer_literal,
    STATE(7808), 1,
      sym__reserved_identifier,
    STATE(8101), 1,
      sym__preproc_expression,
    ACTIONS(8345), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8240), 6,
      sym_character_literal,
      sym_boolean_literal,
      sym_identifier,
      sym_preproc_parenthesized_expression,
      sym_preproc_unary_expression,
      sym_preproc_binary_expression,
    STATE(6166), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(8339), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [170692] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8524), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    STATE(6167), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [170829] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8526), 1,
      anon_sym_and,
    ACTIONS(8528), 1,
      anon_sym_or,
    STATE(6168), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6594), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6592), 24,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_GT,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [170916] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(8357), 1,
      anon_sym_SLASH,
    ACTIONS(8359), 1,
      anon_sym_CARET,
    ACTIONS(8361), 1,
      anon_sym_PIPE,
    ACTIONS(8363), 1,
      anon_sym_AMP,
    ACTIONS(8367), 1,
      anon_sym_GT_GT,
    ACTIONS(8373), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8375), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8377), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8379), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8381), 1,
      anon_sym_as,
    ACTIONS(8383), 1,
      anon_sym_is,
    ACTIONS(8530), 1,
      anon_sym_QMARK,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6266), 2,
      anon_sym_into,
      anon_sym_on,
    ACTIONS(8351), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8353), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8355), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8365), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8369), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8371), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6169), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [171053] = 21,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(141), 1,
      anon_sym_SQUOTE,
    ACTIONS(8385), 1,
      anon_sym_LPAREN,
    ACTIONS(8387), 1,
      anon_sym_BANG,
    ACTIONS(8389), 1,
      sym_integer_literal,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8117), 1,
      sym__preproc_expression,
    ACTIONS(77), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8247), 6,
      sym_character_literal,
      sym_boolean_literal,
      sym_identifier,
      sym_preproc_parenthesized_expression,
      sym_preproc_unary_expression,
      sym_preproc_binary_expression,
    STATE(6170), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [171152] = 21,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8337), 1,
      sym__identifier_token,
    ACTIONS(8341), 1,
      anon_sym_LPAREN,
    ACTIONS(8343), 1,
      anon_sym_BANG,
    ACTIONS(8347), 1,
      anon_sym_SQUOTE,
    ACTIONS(8349), 1,
      sym_integer_literal,
    STATE(7808), 1,
      sym__reserved_identifier,
    STATE(8192), 1,
      sym__preproc_expression,
    ACTIONS(8345), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8240), 6,
      sym_character_literal,
      sym_boolean_literal,
      sym_identifier,
      sym_preproc_parenthesized_expression,
      sym_preproc_unary_expression,
      sym_preproc_binary_expression,
    STATE(6171), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(8339), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [171251] = 35,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(8397), 1,
      anon_sym_SLASH,
    ACTIONS(8403), 1,
      anon_sym_AMP,
    ACTIONS(8407), 1,
      anon_sym_GT_GT,
    ACTIONS(8413), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8421), 1,
      anon_sym_as,
    ACTIONS(8423), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(8391), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8393), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8395), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8405), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8409), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8411), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 6,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_by,
    STATE(6172), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [171378] = 21,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8337), 1,
      sym__identifier_token,
    ACTIONS(8341), 1,
      anon_sym_LPAREN,
    ACTIONS(8343), 1,
      anon_sym_BANG,
    ACTIONS(8347), 1,
      anon_sym_SQUOTE,
    ACTIONS(8349), 1,
      sym_integer_literal,
    STATE(7808), 1,
      sym__reserved_identifier,
    STATE(8103), 1,
      sym__preproc_expression,
    ACTIONS(8345), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8240), 6,
      sym_character_literal,
      sym_boolean_literal,
      sym_identifier,
      sym_preproc_parenthesized_expression,
      sym_preproc_unary_expression,
      sym_preproc_binary_expression,
    STATE(6173), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(8339), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [171477] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(8357), 1,
      anon_sym_SLASH,
    ACTIONS(8359), 1,
      anon_sym_CARET,
    ACTIONS(8361), 1,
      anon_sym_PIPE,
    ACTIONS(8363), 1,
      anon_sym_AMP,
    ACTIONS(8367), 1,
      anon_sym_GT_GT,
    ACTIONS(8373), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8375), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8377), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8379), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8381), 1,
      anon_sym_as,
    ACTIONS(8383), 1,
      anon_sym_is,
    ACTIONS(8530), 1,
      anon_sym_QMARK,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6270), 2,
      anon_sym_into,
      anon_sym_on,
    ACTIONS(8351), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8353), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8355), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8365), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8369), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8371), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6174), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [171614] = 21,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(141), 1,
      anon_sym_SQUOTE,
    ACTIONS(8385), 1,
      anon_sym_LPAREN,
    ACTIONS(8387), 1,
      anon_sym_BANG,
    ACTIONS(8389), 1,
      sym_integer_literal,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8118), 1,
      sym__preproc_expression,
    ACTIONS(77), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8247), 6,
      sym_character_literal,
      sym_boolean_literal,
      sym_identifier,
      sym_preproc_parenthesized_expression,
      sym_preproc_unary_expression,
      sym_preproc_binary_expression,
    STATE(6175), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [171713] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(8357), 1,
      anon_sym_SLASH,
    ACTIONS(8359), 1,
      anon_sym_CARET,
    ACTIONS(8361), 1,
      anon_sym_PIPE,
    ACTIONS(8363), 1,
      anon_sym_AMP,
    ACTIONS(8367), 1,
      anon_sym_GT_GT,
    ACTIONS(8373), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8375), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8377), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8379), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8381), 1,
      anon_sym_as,
    ACTIONS(8383), 1,
      anon_sym_is,
    ACTIONS(8530), 1,
      anon_sym_QMARK,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6190), 2,
      anon_sym_into,
      anon_sym_on,
    ACTIONS(8351), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8353), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8355), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8365), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8369), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8371), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6176), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [171850] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(8373), 1,
      anon_sym_DOT_DOT,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1229), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(6177), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(1227), 18,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_on,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [171951] = 36,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(8397), 1,
      anon_sym_SLASH,
    ACTIONS(8399), 1,
      anon_sym_CARET,
    ACTIONS(8403), 1,
      anon_sym_AMP,
    ACTIONS(8407), 1,
      anon_sym_GT_GT,
    ACTIONS(8413), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8421), 1,
      anon_sym_as,
    ACTIONS(8423), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(8391), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8393), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8395), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8405), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8409), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8411), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 5,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_by,
    STATE(6178), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [172080] = 41,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7118), 1,
      anon_sym_SLASH,
    ACTIONS(7120), 1,
      anon_sym_CARET,
    ACTIONS(7122), 1,
      anon_sym_PIPE,
    ACTIONS(7124), 1,
      anon_sym_AMP,
    ACTIONS(7128), 1,
      anon_sym_GT_GT,
    ACTIONS(7136), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7138), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7140), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7650), 1,
      anon_sym_COLON,
    ACTIONS(7656), 1,
      anon_sym_QMARK,
    ACTIONS(7658), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(7662), 1,
      anon_sym_is,
    ACTIONS(8233), 1,
      anon_sym_COMMA,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7112), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7114), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7116), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7126), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7130), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7132), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6179), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [172219] = 34,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(8397), 1,
      anon_sym_SLASH,
    ACTIONS(8407), 1,
      anon_sym_GT_GT,
    ACTIONS(8413), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8421), 1,
      anon_sym_as,
    ACTIONS(8423), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8391), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8393), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8395), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8405), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8409), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8411), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(6342), 6,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_by,
    STATE(6180), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [172344] = 26,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4343), 1,
      anon_sym_LBRACE,
    ACTIONS(4357), 1,
      anon_sym_COLON,
    ACTIONS(4359), 1,
      sym_discard,
    ACTIONS(7467), 1,
      sym__identifier_token,
    ACTIONS(7471), 1,
      anon_sym_LPAREN,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(4153), 1,
      sym_parenthesized_variable_designation,
    STATE(4162), 1,
      sym__variable_designation,
    STATE(4163), 1,
      sym_identifier,
    STATE(6693), 1,
      sym_positional_pattern_clause,
    STATE(6774), 1,
      sym_property_pattern_clause,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9890), 1,
      sym__lambda_parameters,
    ACTIONS(4355), 3,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
    STATE(6181), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 21,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [172453] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(8431), 1,
      anon_sym_SLASH,
    ACTIONS(8433), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8439), 1,
      anon_sym_GT_GT,
    ACTIONS(8443), 1,
      anon_sym_as,
    ACTIONS(8445), 1,
      anon_sym_is,
    ACTIONS(8447), 1,
      anon_sym_CARET,
    ACTIONS(8449), 1,
      anon_sym_PIPE,
    ACTIONS(8451), 1,
      anon_sym_AMP,
    ACTIONS(8457), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8459), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8461), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8499), 1,
      anon_sym_QMARK,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6320), 2,
      anon_sym_into,
      anon_sym_equals,
    ACTIONS(8427), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8429), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8435), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8437), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8441), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8453), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    STATE(6182), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [172590] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(8433), 1,
      anon_sym_DOT_DOT,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6330), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(6183), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6328), 18,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_equals,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [172691] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8532), 1,
      anon_sym_and,
    STATE(6184), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6707), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6705), 25,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_by,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [172776] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8534), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(6185), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [172913] = 21,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(141), 1,
      anon_sym_SQUOTE,
    ACTIONS(8385), 1,
      anon_sym_LPAREN,
    ACTIONS(8387), 1,
      anon_sym_BANG,
    ACTIONS(8389), 1,
      sym_integer_literal,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8119), 1,
      sym__preproc_expression,
    ACTIONS(77), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8247), 6,
      sym_character_literal,
      sym_boolean_literal,
      sym_identifier,
      sym_preproc_parenthesized_expression,
      sym_preproc_unary_expression,
      sym_preproc_binary_expression,
    STATE(6186), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [173012] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(8431), 1,
      anon_sym_SLASH,
    ACTIONS(8433), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8439), 1,
      anon_sym_GT_GT,
    ACTIONS(8443), 1,
      anon_sym_as,
    ACTIONS(8445), 1,
      anon_sym_is,
    ACTIONS(8447), 1,
      anon_sym_CARET,
    ACTIONS(8449), 1,
      anon_sym_PIPE,
    ACTIONS(8451), 1,
      anon_sym_AMP,
    ACTIONS(8457), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8459), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8461), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8499), 1,
      anon_sym_QMARK,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6324), 2,
      anon_sym_into,
      anon_sym_equals,
    ACTIONS(8427), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8429), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8435), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8437), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8441), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8453), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    STATE(6187), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [173149] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(8431), 1,
      anon_sym_SLASH,
    ACTIONS(8433), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8439), 1,
      anon_sym_GT_GT,
    ACTIONS(8443), 1,
      anon_sym_as,
    ACTIONS(8445), 1,
      anon_sym_is,
    ACTIONS(8447), 1,
      anon_sym_CARET,
    ACTIONS(8449), 1,
      anon_sym_PIPE,
    ACTIONS(8451), 1,
      anon_sym_AMP,
    ACTIONS(8457), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8459), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8461), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8499), 1,
      anon_sym_QMARK,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5416), 2,
      anon_sym_into,
      anon_sym_equals,
    ACTIONS(8427), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8429), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8435), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8437), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8441), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8453), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    STATE(6188), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [173286] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(8487), 1,
      anon_sym_DOT_DOT,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1229), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(6189), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(1227), 18,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_GT,
      anon_sym_switch,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [173387] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(8431), 1,
      anon_sym_SLASH,
    ACTIONS(8433), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8439), 1,
      anon_sym_GT_GT,
    ACTIONS(8443), 1,
      anon_sym_as,
    ACTIONS(8445), 1,
      anon_sym_is,
    ACTIONS(8447), 1,
      anon_sym_CARET,
    ACTIONS(8449), 1,
      anon_sym_PIPE,
    ACTIONS(8451), 1,
      anon_sym_AMP,
    ACTIONS(8457), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8459), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8461), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8499), 1,
      anon_sym_QMARK,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5644), 2,
      anon_sym_into,
      anon_sym_equals,
    ACTIONS(8427), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8429), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8435), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8437), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8441), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8453), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    STATE(6190), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [173524] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(8431), 1,
      anon_sym_SLASH,
    ACTIONS(8433), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8439), 1,
      anon_sym_GT_GT,
    ACTIONS(8443), 1,
      anon_sym_as,
    ACTIONS(8445), 1,
      anon_sym_is,
    ACTIONS(8447), 1,
      anon_sym_CARET,
    ACTIONS(8449), 1,
      anon_sym_PIPE,
    ACTIONS(8451), 1,
      anon_sym_AMP,
    ACTIONS(8457), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8459), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8461), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8499), 1,
      anon_sym_QMARK,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5424), 2,
      anon_sym_into,
      anon_sym_equals,
    ACTIONS(8427), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8429), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8435), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8437), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8441), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8453), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    STATE(6191), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [173661] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8536), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    STATE(6192), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [173798] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(8431), 1,
      anon_sym_SLASH,
    ACTIONS(8433), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8439), 1,
      anon_sym_GT_GT,
    ACTIONS(8443), 1,
      anon_sym_as,
    ACTIONS(8445), 1,
      anon_sym_is,
    ACTIONS(8447), 1,
      anon_sym_CARET,
    ACTIONS(8449), 1,
      anon_sym_PIPE,
    ACTIONS(8451), 1,
      anon_sym_AMP,
    ACTIONS(8457), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8459), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8461), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8499), 1,
      anon_sym_QMARK,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6336), 2,
      anon_sym_into,
      anon_sym_equals,
    ACTIONS(8427), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8429), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8435), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8437), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8441), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8453), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    STATE(6193), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [173935] = 21,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8337), 1,
      sym__identifier_token,
    ACTIONS(8341), 1,
      anon_sym_LPAREN,
    ACTIONS(8343), 1,
      anon_sym_BANG,
    ACTIONS(8347), 1,
      anon_sym_SQUOTE,
    ACTIONS(8349), 1,
      sym_integer_literal,
    STATE(7808), 1,
      sym__reserved_identifier,
    STATE(8169), 1,
      sym__preproc_expression,
    ACTIONS(8345), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8240), 6,
      sym_character_literal,
      sym_boolean_literal,
      sym_identifier,
      sym_preproc_parenthesized_expression,
      sym_preproc_unary_expression,
      sym_preproc_binary_expression,
    STATE(6194), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(8339), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [174034] = 21,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(141), 1,
      anon_sym_SQUOTE,
    ACTIONS(8385), 1,
      anon_sym_LPAREN,
    ACTIONS(8387), 1,
      anon_sym_BANG,
    ACTIONS(8389), 1,
      sym_integer_literal,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8205), 1,
      sym__preproc_expression,
    ACTIONS(77), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8247), 6,
      sym_character_literal,
      sym_boolean_literal,
      sym_identifier,
      sym_preproc_parenthesized_expression,
      sym_preproc_unary_expression,
      sym_preproc_binary_expression,
    STATE(6195), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [174133] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8532), 1,
      anon_sym_and,
    ACTIONS(8538), 1,
      anon_sym_or,
    STATE(6196), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5881), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5879), 24,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_by,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [174220] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8510), 1,
      anon_sym_and,
    STATE(6197), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6707), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6705), 25,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_on,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [174305] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8510), 1,
      anon_sym_and,
    ACTIONS(8512), 1,
      anon_sym_or,
    STATE(6198), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5881), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5879), 24,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_on,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [174392] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8508), 1,
      anon_sym_and,
    ACTIONS(8540), 1,
      anon_sym_or,
    STATE(6199), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6594), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6592), 24,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_when,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [174479] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6837), 1,
      anon_sym_as,
    ACTIONS(8465), 1,
      anon_sym_QMARK,
    ACTIONS(8471), 1,
      anon_sym_SLASH,
    ACTIONS(8473), 1,
      anon_sym_CARET,
    ACTIONS(8475), 1,
      anon_sym_PIPE,
    ACTIONS(8477), 1,
      anon_sym_AMP,
    ACTIONS(8481), 1,
      anon_sym_GT_GT,
    ACTIONS(8487), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8489), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8491), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8493), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8495), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6266), 2,
      anon_sym_EQ_GT,
      anon_sym_into,
    ACTIONS(8463), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8467), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8469), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8479), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8483), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8485), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6200), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [174616] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8542), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(6201), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [174753] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8544), 1,
      anon_sym_DOT,
    ACTIONS(4455), 8,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_EQ_GT,
    STATE(6202), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4453), 28,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_operator,
      anon_sym_this,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      sym_discard,
      anon_sym_and,
      anon_sym_or,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [174838] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(8431), 1,
      anon_sym_SLASH,
    ACTIONS(8433), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8439), 1,
      anon_sym_GT_GT,
    ACTIONS(8443), 1,
      anon_sym_as,
    ACTIONS(8445), 1,
      anon_sym_is,
    ACTIONS(8447), 1,
      anon_sym_CARET,
    ACTIONS(8449), 1,
      anon_sym_PIPE,
    ACTIONS(8451), 1,
      anon_sym_AMP,
    ACTIONS(8457), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8459), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8461), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8499), 1,
      anon_sym_QMARK,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5572), 2,
      anon_sym_into,
      anon_sym_equals,
    ACTIONS(8427), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8429), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8435), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8437), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8441), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8453), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    STATE(6203), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [174975] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4593), 1,
      anon_sym_LBRACK,
    ACTIONS(4599), 1,
      anon_sym_STAR,
    ACTIONS(5850), 1,
      anon_sym_QMARK,
    ACTIONS(8546), 1,
      anon_sym_DOT,
    ACTIONS(4492), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(6204), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4494), 24,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [175066] = 21,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(141), 1,
      anon_sym_SQUOTE,
    ACTIONS(8385), 1,
      anon_sym_LPAREN,
    ACTIONS(8387), 1,
      anon_sym_BANG,
    ACTIONS(8389), 1,
      sym_integer_literal,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(7994), 1,
      sym__preproc_expression,
    ACTIONS(77), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8247), 6,
      sym_character_literal,
      sym_boolean_literal,
      sym_identifier,
      sym_preproc_parenthesized_expression,
      sym_preproc_unary_expression,
      sym_preproc_binary_expression,
    STATE(6205), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [175165] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8546), 1,
      anon_sym_DOT,
    STATE(6206), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4453), 10,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    ACTIONS(4455), 26,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_in,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_and,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [175250] = 21,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8337), 1,
      sym__identifier_token,
    ACTIONS(8341), 1,
      anon_sym_LPAREN,
    ACTIONS(8343), 1,
      anon_sym_BANG,
    ACTIONS(8347), 1,
      anon_sym_SQUOTE,
    ACTIONS(8349), 1,
      sym_integer_literal,
    STATE(7808), 1,
      sym__reserved_identifier,
    STATE(8082), 1,
      sym__preproc_expression,
    ACTIONS(8345), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8240), 6,
      sym_character_literal,
      sym_boolean_literal,
      sym_identifier,
      sym_preproc_parenthesized_expression,
      sym_preproc_unary_expression,
      sym_preproc_binary_expression,
    STATE(6207), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(8339), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [175349] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(8431), 1,
      anon_sym_SLASH,
    ACTIONS(8433), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8439), 1,
      anon_sym_GT_GT,
    ACTIONS(8443), 1,
      anon_sym_as,
    ACTIONS(8445), 1,
      anon_sym_is,
    ACTIONS(8447), 1,
      anon_sym_CARET,
    ACTIONS(8449), 1,
      anon_sym_PIPE,
    ACTIONS(8451), 1,
      anon_sym_AMP,
    ACTIONS(8457), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8459), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8461), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8499), 1,
      anon_sym_QMARK,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5584), 2,
      anon_sym_into,
      anon_sym_equals,
    ACTIONS(8427), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8429), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8435), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8437), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8441), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8453), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    STATE(6208), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [175486] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(8049), 1,
      anon_sym_QMARK,
    ACTIONS(8055), 1,
      anon_sym_SLASH,
    ACTIONS(8057), 1,
      anon_sym_CARET,
    ACTIONS(8059), 1,
      anon_sym_PIPE,
    ACTIONS(8061), 1,
      anon_sym_AMP,
    ACTIONS(8065), 1,
      anon_sym_GT_GT,
    ACTIONS(8071), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8073), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8075), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8077), 1,
      anon_sym_QMARK_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8047), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8051), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8053), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8063), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8067), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8069), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8548), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    STATE(6209), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [175623] = 41,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(8233), 1,
      anon_sym_COMMA,
    ACTIONS(8550), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6210), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [175762] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8552), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(6211), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [175899] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(8049), 1,
      anon_sym_QMARK,
    ACTIONS(8055), 1,
      anon_sym_SLASH,
    ACTIONS(8057), 1,
      anon_sym_CARET,
    ACTIONS(8059), 1,
      anon_sym_PIPE,
    ACTIONS(8061), 1,
      anon_sym_AMP,
    ACTIONS(8065), 1,
      anon_sym_GT_GT,
    ACTIONS(8071), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8073), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8075), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8077), 1,
      anon_sym_QMARK_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8047), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8051), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8053), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8063), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8067), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8069), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8554), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    STATE(6212), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [176036] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6837), 1,
      anon_sym_as,
    ACTIONS(8465), 1,
      anon_sym_QMARK,
    ACTIONS(8471), 1,
      anon_sym_SLASH,
    ACTIONS(8473), 1,
      anon_sym_CARET,
    ACTIONS(8475), 1,
      anon_sym_PIPE,
    ACTIONS(8477), 1,
      anon_sym_AMP,
    ACTIONS(8481), 1,
      anon_sym_GT_GT,
    ACTIONS(8487), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8489), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8491), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8493), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8495), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6320), 2,
      anon_sym_EQ_GT,
      anon_sym_into,
    ACTIONS(8463), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8467), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8469), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8479), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8483), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8485), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6213), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [176173] = 35,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6837), 1,
      anon_sym_as,
    ACTIONS(8471), 1,
      anon_sym_SLASH,
    ACTIONS(8477), 1,
      anon_sym_AMP,
    ACTIONS(8481), 1,
      anon_sym_GT_GT,
    ACTIONS(8487), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8495), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(8463), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8467), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8469), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8479), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8483), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8485), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 6,
      anon_sym_CARET,
      anon_sym_EQ_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
    STATE(6214), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [176300] = 36,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6837), 1,
      anon_sym_as,
    ACTIONS(8471), 1,
      anon_sym_SLASH,
    ACTIONS(8473), 1,
      anon_sym_CARET,
    ACTIONS(8477), 1,
      anon_sym_AMP,
    ACTIONS(8481), 1,
      anon_sym_GT_GT,
    ACTIONS(8487), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8495), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(8463), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8467), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8469), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8479), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8483), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8485), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 5,
      anon_sym_EQ_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
    STATE(6215), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [176429] = 34,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6837), 1,
      anon_sym_as,
    ACTIONS(8471), 1,
      anon_sym_SLASH,
    ACTIONS(8481), 1,
      anon_sym_GT_GT,
    ACTIONS(8487), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8495), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8463), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8467), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8469), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8479), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8483), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8485), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(6342), 6,
      anon_sym_CARET,
      anon_sym_EQ_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
    STATE(6216), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [176554] = 33,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6837), 1,
      anon_sym_as,
    ACTIONS(8471), 1,
      anon_sym_SLASH,
    ACTIONS(8481), 1,
      anon_sym_GT_GT,
    ACTIONS(8487), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8495), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8463), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8467), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8469), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8479), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8485), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(6342), 8,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
    STATE(6217), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [176677] = 37,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6837), 1,
      anon_sym_as,
    ACTIONS(8471), 1,
      anon_sym_SLASH,
    ACTIONS(8473), 1,
      anon_sym_CARET,
    ACTIONS(8475), 1,
      anon_sym_PIPE,
    ACTIONS(8477), 1,
      anon_sym_AMP,
    ACTIONS(8481), 1,
      anon_sym_GT_GT,
    ACTIONS(8487), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8495), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8463), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8467), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8469), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8479), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8483), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8485), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 5,
      anon_sym_EQ_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
    STATE(6218), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [176808] = 38,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6837), 1,
      anon_sym_as,
    ACTIONS(8471), 1,
      anon_sym_SLASH,
    ACTIONS(8473), 1,
      anon_sym_CARET,
    ACTIONS(8475), 1,
      anon_sym_PIPE,
    ACTIONS(8477), 1,
      anon_sym_AMP,
    ACTIONS(8481), 1,
      anon_sym_GT_GT,
    ACTIONS(8487), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8489), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8495), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8463), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8467), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8469), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8479), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8483), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8485), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 4,
      anon_sym_EQ_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
    STATE(6219), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [176941] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6837), 1,
      anon_sym_as,
    ACTIONS(8471), 1,
      anon_sym_SLASH,
    ACTIONS(8473), 1,
      anon_sym_CARET,
    ACTIONS(8475), 1,
      anon_sym_PIPE,
    ACTIONS(8477), 1,
      anon_sym_AMP,
    ACTIONS(8481), 1,
      anon_sym_GT_GT,
    ACTIONS(8487), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8489), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8491), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8493), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8495), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6342), 2,
      anon_sym_EQ_GT,
      anon_sym_into,
    ACTIONS(8463), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8467), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8469), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8479), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8483), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8485), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6220), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [177078] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(7411), 1,
      anon_sym_LBRACK,
    ACTIONS(7413), 1,
      anon_sym_QMARK,
    ACTIONS(7415), 1,
      anon_sym_STAR,
    ACTIONS(8556), 1,
      anon_sym_DOT,
    ACTIONS(4494), 6,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_EQ_GT,
    STATE(6221), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4492), 26,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      sym_discard,
      anon_sym_and,
      anon_sym_or,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [177171] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(8431), 1,
      anon_sym_SLASH,
    ACTIONS(8433), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8439), 1,
      anon_sym_GT_GT,
    ACTIONS(8443), 1,
      anon_sym_as,
    ACTIONS(8445), 1,
      anon_sym_is,
    ACTIONS(8447), 1,
      anon_sym_CARET,
    ACTIONS(8449), 1,
      anon_sym_PIPE,
    ACTIONS(8451), 1,
      anon_sym_AMP,
    ACTIONS(8457), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8459), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8461), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8499), 1,
      anon_sym_QMARK,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5624), 2,
      anon_sym_into,
      anon_sym_equals,
    ACTIONS(8427), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8429), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8435), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8437), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8441), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8453), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    STATE(6222), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [177308] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8558), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    STATE(6223), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [177445] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(8397), 1,
      anon_sym_SLASH,
    ACTIONS(8399), 1,
      anon_sym_CARET,
    ACTIONS(8401), 1,
      anon_sym_PIPE,
    ACTIONS(8403), 1,
      anon_sym_AMP,
    ACTIONS(8407), 1,
      anon_sym_GT_GT,
    ACTIONS(8413), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8415), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8417), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8419), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8421), 1,
      anon_sym_as,
    ACTIONS(8423), 1,
      anon_sym_is,
    ACTIONS(8425), 1,
      anon_sym_QMARK,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5424), 2,
      anon_sym_into,
      anon_sym_by,
    ACTIONS(8391), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8393), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8395), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8405), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8409), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8411), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6224), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [177582] = 38,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(8357), 1,
      anon_sym_SLASH,
    ACTIONS(8359), 1,
      anon_sym_CARET,
    ACTIONS(8361), 1,
      anon_sym_PIPE,
    ACTIONS(8363), 1,
      anon_sym_AMP,
    ACTIONS(8367), 1,
      anon_sym_GT_GT,
    ACTIONS(8373), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8375), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8381), 1,
      anon_sym_as,
    ACTIONS(8383), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8351), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8353), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8355), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8365), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8369), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8371), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 4,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_on,
    STATE(6225), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [177715] = 41,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(8233), 1,
      anon_sym_COMMA,
    ACTIONS(8560), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6226), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [177854] = 29,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(8431), 1,
      anon_sym_SLASH,
    ACTIONS(8433), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8439), 1,
      anon_sym_GT_GT,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8427), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8429), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8437), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6344), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    STATE(6227), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 12,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_equals,
      anon_sym_as,
      anon_sym_is,
  [177969] = 21,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8337), 1,
      sym__identifier_token,
    ACTIONS(8341), 1,
      anon_sym_LPAREN,
    ACTIONS(8343), 1,
      anon_sym_BANG,
    ACTIONS(8347), 1,
      anon_sym_SQUOTE,
    ACTIONS(8349), 1,
      sym_integer_literal,
    STATE(7808), 1,
      sym__reserved_identifier,
    STATE(8054), 1,
      sym__preproc_expression,
    ACTIONS(8345), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8240), 6,
      sym_character_literal,
      sym_boolean_literal,
      sym_identifier,
      sym_preproc_parenthesized_expression,
      sym_preproc_unary_expression,
      sym_preproc_binary_expression,
    STATE(6228), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(8339), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [178068] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8143), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    STATE(6229), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [178205] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8526), 1,
      anon_sym_and,
    STATE(6230), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6707), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6705), 25,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_GT,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [178290] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(8049), 1,
      anon_sym_QMARK,
    ACTIONS(8055), 1,
      anon_sym_SLASH,
    ACTIONS(8057), 1,
      anon_sym_CARET,
    ACTIONS(8059), 1,
      anon_sym_PIPE,
    ACTIONS(8061), 1,
      anon_sym_AMP,
    ACTIONS(8065), 1,
      anon_sym_GT_GT,
    ACTIONS(8071), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8073), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8075), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8077), 1,
      anon_sym_QMARK_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7913), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(8047), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8051), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8053), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8063), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8067), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8069), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6231), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [178427] = 26,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(8431), 1,
      anon_sym_SLASH,
    ACTIONS(8433), 1,
      anon_sym_DOT_DOT,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8429), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(6232), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 14,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_equals,
      anon_sym_as,
      anon_sym_is,
  [178536] = 21,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8337), 1,
      sym__identifier_token,
    ACTIONS(8341), 1,
      anon_sym_LPAREN,
    ACTIONS(8343), 1,
      anon_sym_BANG,
    ACTIONS(8347), 1,
      anon_sym_SQUOTE,
    ACTIONS(8349), 1,
      sym_integer_literal,
    STATE(7808), 1,
      sym__reserved_identifier,
    STATE(8021), 1,
      sym__preproc_expression,
    ACTIONS(8345), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8240), 6,
      sym_character_literal,
      sym_boolean_literal,
      sym_identifier,
      sym_preproc_parenthesized_expression,
      sym_preproc_unary_expression,
      sym_preproc_binary_expression,
    STATE(6233), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(8339), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [178635] = 21,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8337), 1,
      sym__identifier_token,
    ACTIONS(8341), 1,
      anon_sym_LPAREN,
    ACTIONS(8343), 1,
      anon_sym_BANG,
    ACTIONS(8347), 1,
      anon_sym_SQUOTE,
    ACTIONS(8349), 1,
      sym_integer_literal,
    STATE(7808), 1,
      sym__reserved_identifier,
    STATE(8087), 1,
      sym__preproc_expression,
    ACTIONS(8345), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8240), 6,
      sym_character_literal,
      sym_boolean_literal,
      sym_identifier,
      sym_preproc_parenthesized_expression,
      sym_preproc_unary_expression,
      sym_preproc_binary_expression,
    STATE(6234), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(8339), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [178734] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8504), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(6235), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [178871] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8514), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(6236), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [179008] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8562), 1,
      anon_sym_and,
    ACTIONS(8564), 1,
      anon_sym_or,
    STATE(6237), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5881), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5879), 24,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_equals,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [179095] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8532), 1,
      anon_sym_and,
    ACTIONS(8538), 1,
      anon_sym_or,
    STATE(6238), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6594), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6592), 24,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_by,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [179182] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6837), 1,
      anon_sym_as,
    ACTIONS(8465), 1,
      anon_sym_QMARK,
    ACTIONS(8471), 1,
      anon_sym_SLASH,
    ACTIONS(8473), 1,
      anon_sym_CARET,
    ACTIONS(8475), 1,
      anon_sym_PIPE,
    ACTIONS(8477), 1,
      anon_sym_AMP,
    ACTIONS(8481), 1,
      anon_sym_GT_GT,
    ACTIONS(8487), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8489), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8491), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8493), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8495), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6190), 2,
      anon_sym_EQ_GT,
      anon_sym_into,
    ACTIONS(8463), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8467), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8469), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8479), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8483), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8485), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6239), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [179319] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(8433), 1,
      anon_sym_DOT_DOT,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(6240), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 16,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_equals,
      anon_sym_as,
      anon_sym_is,
  [179424] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4806), 4,
      anon_sym_COLON,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
    STATE(6241), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5654), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5652), 22,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [179509] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4806), 4,
      anon_sym_COLON,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
    STATE(6242), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5630), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5628), 22,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [179594] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(8487), 1,
      anon_sym_DOT_DOT,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6330), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(6243), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6328), 18,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_GT,
      anon_sym_switch,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [179695] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6837), 1,
      anon_sym_as,
    ACTIONS(8465), 1,
      anon_sym_QMARK,
    ACTIONS(8471), 1,
      anon_sym_SLASH,
    ACTIONS(8473), 1,
      anon_sym_CARET,
    ACTIONS(8475), 1,
      anon_sym_PIPE,
    ACTIONS(8477), 1,
      anon_sym_AMP,
    ACTIONS(8481), 1,
      anon_sym_GT_GT,
    ACTIONS(8487), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8489), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8491), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8493), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8495), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6324), 2,
      anon_sym_EQ_GT,
      anon_sym_into,
    ACTIONS(8463), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8467), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8469), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8479), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8483), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8485), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6244), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [179832] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6837), 1,
      anon_sym_as,
    ACTIONS(8465), 1,
      anon_sym_QMARK,
    ACTIONS(8471), 1,
      anon_sym_SLASH,
    ACTIONS(8473), 1,
      anon_sym_CARET,
    ACTIONS(8475), 1,
      anon_sym_PIPE,
    ACTIONS(8477), 1,
      anon_sym_AMP,
    ACTIONS(8481), 1,
      anon_sym_GT_GT,
    ACTIONS(8487), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8489), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8491), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8493), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8495), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5416), 2,
      anon_sym_EQ_GT,
      anon_sym_into,
    ACTIONS(8463), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8467), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8469), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8479), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8483), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8485), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6245), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [179969] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6837), 1,
      anon_sym_as,
    ACTIONS(8465), 1,
      anon_sym_QMARK,
    ACTIONS(8471), 1,
      anon_sym_SLASH,
    ACTIONS(8473), 1,
      anon_sym_CARET,
    ACTIONS(8475), 1,
      anon_sym_PIPE,
    ACTIONS(8477), 1,
      anon_sym_AMP,
    ACTIONS(8481), 1,
      anon_sym_GT_GT,
    ACTIONS(8487), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8489), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8491), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8493), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8495), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5644), 2,
      anon_sym_EQ_GT,
      anon_sym_into,
    ACTIONS(8463), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8467), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8469), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8479), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8483), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8485), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6246), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [180106] = 35,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(8431), 1,
      anon_sym_SLASH,
    ACTIONS(8433), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8439), 1,
      anon_sym_GT_GT,
    ACTIONS(8443), 1,
      anon_sym_as,
    ACTIONS(8445), 1,
      anon_sym_is,
    ACTIONS(8451), 1,
      anon_sym_AMP,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(8427), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8429), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8435), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8437), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8441), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8453), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6342), 6,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_equals,
    STATE(6247), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [180233] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8548), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(6248), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [180370] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6837), 1,
      anon_sym_as,
    ACTIONS(8465), 1,
      anon_sym_QMARK,
    ACTIONS(8471), 1,
      anon_sym_SLASH,
    ACTIONS(8473), 1,
      anon_sym_CARET,
    ACTIONS(8475), 1,
      anon_sym_PIPE,
    ACTIONS(8477), 1,
      anon_sym_AMP,
    ACTIONS(8481), 1,
      anon_sym_GT_GT,
    ACTIONS(8487), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8489), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8491), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8493), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8495), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5424), 2,
      anon_sym_EQ_GT,
      anon_sym_into,
    ACTIONS(8463), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8467), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8469), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8479), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8483), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8485), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6249), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [180507] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6837), 1,
      anon_sym_as,
    ACTIONS(8465), 1,
      anon_sym_QMARK,
    ACTIONS(8471), 1,
      anon_sym_SLASH,
    ACTIONS(8473), 1,
      anon_sym_CARET,
    ACTIONS(8475), 1,
      anon_sym_PIPE,
    ACTIONS(8477), 1,
      anon_sym_AMP,
    ACTIONS(8481), 1,
      anon_sym_GT_GT,
    ACTIONS(8487), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8489), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8491), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8493), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8495), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6336), 2,
      anon_sym_EQ_GT,
      anon_sym_into,
    ACTIONS(8463), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8467), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8469), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8479), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8483), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8485), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6250), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [180644] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8518), 1,
      anon_sym_and,
    STATE(6251), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6707), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6705), 25,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_GT,
      anon_sym_switch,
      anon_sym_when,
      anon_sym_DOT_DOT,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [180729] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6837), 1,
      anon_sym_as,
    ACTIONS(8465), 1,
      anon_sym_QMARK,
    ACTIONS(8471), 1,
      anon_sym_SLASH,
    ACTIONS(8473), 1,
      anon_sym_CARET,
    ACTIONS(8475), 1,
      anon_sym_PIPE,
    ACTIONS(8477), 1,
      anon_sym_AMP,
    ACTIONS(8481), 1,
      anon_sym_GT_GT,
    ACTIONS(8487), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8489), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8491), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8493), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8495), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5572), 2,
      anon_sym_EQ_GT,
      anon_sym_into,
    ACTIONS(8463), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8467), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8469), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8479), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8483), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8485), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6252), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [180866] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6837), 1,
      anon_sym_as,
    ACTIONS(8465), 1,
      anon_sym_QMARK,
    ACTIONS(8471), 1,
      anon_sym_SLASH,
    ACTIONS(8473), 1,
      anon_sym_CARET,
    ACTIONS(8475), 1,
      anon_sym_PIPE,
    ACTIONS(8477), 1,
      anon_sym_AMP,
    ACTIONS(8481), 1,
      anon_sym_GT_GT,
    ACTIONS(8487), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8489), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8491), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8493), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8495), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5584), 2,
      anon_sym_EQ_GT,
      anon_sym_into,
    ACTIONS(8463), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8467), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8469), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8479), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8483), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8485), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6253), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [181003] = 29,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(8471), 1,
      anon_sym_SLASH,
    ACTIONS(8481), 1,
      anon_sym_GT_GT,
    ACTIONS(8487), 1,
      anon_sym_DOT_DOT,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8467), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8469), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8479), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6344), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    STATE(6254), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 12,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
  [181118] = 26,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(8471), 1,
      anon_sym_SLASH,
    ACTIONS(8487), 1,
      anon_sym_DOT_DOT,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8469), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(6255), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 14,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
  [181227] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(8487), 1,
      anon_sym_DOT_DOT,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(6256), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 16,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
  [181332] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(8471), 1,
      anon_sym_SLASH,
    ACTIONS(8487), 1,
      anon_sym_DOT_DOT,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8467), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8469), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(6257), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 14,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
  [181443] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(6837), 1,
      anon_sym_as,
    ACTIONS(8465), 1,
      anon_sym_QMARK,
    ACTIONS(8471), 1,
      anon_sym_SLASH,
    ACTIONS(8473), 1,
      anon_sym_CARET,
    ACTIONS(8475), 1,
      anon_sym_PIPE,
    ACTIONS(8477), 1,
      anon_sym_AMP,
    ACTIONS(8481), 1,
      anon_sym_GT_GT,
    ACTIONS(8487), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8489), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8491), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8493), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8495), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5624), 2,
      anon_sym_EQ_GT,
      anon_sym_into,
    ACTIONS(8463), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8467), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8469), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8479), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8483), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8485), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6258), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [181580] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8554), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(6259), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [181717] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(8397), 1,
      anon_sym_SLASH,
    ACTIONS(8413), 1,
      anon_sym_DOT_DOT,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8393), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8395), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(6260), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 14,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_by,
      anon_sym_as,
      anon_sym_is,
  [181828] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(7411), 1,
      anon_sym_LBRACK,
    ACTIONS(7413), 1,
      anon_sym_QMARK,
    ACTIONS(7415), 1,
      anon_sym_STAR,
    ACTIONS(8566), 1,
      anon_sym_DOT,
    ACTIONS(4494), 6,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
    STATE(6261), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4492), 26,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      sym_discard,
      anon_sym_and,
      anon_sym_or,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [181921] = 36,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(8431), 1,
      anon_sym_SLASH,
    ACTIONS(8433), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8439), 1,
      anon_sym_GT_GT,
    ACTIONS(8443), 1,
      anon_sym_as,
    ACTIONS(8445), 1,
      anon_sym_is,
    ACTIONS(8447), 1,
      anon_sym_CARET,
    ACTIONS(8451), 1,
      anon_sym_AMP,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(8427), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8429), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8435), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8437), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8441), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8453), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6342), 5,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_equals,
    STATE(6262), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [182050] = 26,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4343), 1,
      anon_sym_LBRACE,
    ACTIONS(4357), 1,
      anon_sym_COMMA,
    ACTIONS(4359), 1,
      sym_discard,
    ACTIONS(7467), 1,
      sym__identifier_token,
    ACTIONS(7471), 1,
      anon_sym_LPAREN,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(4153), 1,
      sym_parenthesized_variable_designation,
    STATE(4162), 1,
      sym__variable_designation,
    STATE(6139), 1,
      sym_positional_pattern_clause,
    STATE(6746), 1,
      sym_property_pattern_clause,
    STATE(7891), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9832), 1,
      sym__lambda_parameters,
    ACTIONS(4355), 2,
      anon_sym_and,
      anon_sym_or,
    STATE(6263), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [182159] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(8357), 1,
      anon_sym_SLASH,
    ACTIONS(8359), 1,
      anon_sym_CARET,
    ACTIONS(8361), 1,
      anon_sym_PIPE,
    ACTIONS(8363), 1,
      anon_sym_AMP,
    ACTIONS(8367), 1,
      anon_sym_GT_GT,
    ACTIONS(8373), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8375), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8377), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8379), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8381), 1,
      anon_sym_as,
    ACTIONS(8383), 1,
      anon_sym_is,
    ACTIONS(8530), 1,
      anon_sym_QMARK,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6320), 2,
      anon_sym_into,
      anon_sym_on,
    ACTIONS(8351), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8353), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8355), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8365), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8369), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8371), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6264), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [182296] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(8373), 1,
      anon_sym_DOT_DOT,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6330), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(6265), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6328), 18,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_on,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [182397] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(8357), 1,
      anon_sym_SLASH,
    ACTIONS(8359), 1,
      anon_sym_CARET,
    ACTIONS(8361), 1,
      anon_sym_PIPE,
    ACTIONS(8363), 1,
      anon_sym_AMP,
    ACTIONS(8367), 1,
      anon_sym_GT_GT,
    ACTIONS(8373), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8375), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8377), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8379), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8381), 1,
      anon_sym_as,
    ACTIONS(8383), 1,
      anon_sym_is,
    ACTIONS(8530), 1,
      anon_sym_QMARK,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6324), 2,
      anon_sym_into,
      anon_sym_on,
    ACTIONS(8351), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8353), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8355), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8365), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8369), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8371), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6266), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [182534] = 21,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8337), 1,
      sym__identifier_token,
    ACTIONS(8341), 1,
      anon_sym_LPAREN,
    ACTIONS(8343), 1,
      anon_sym_BANG,
    ACTIONS(8347), 1,
      anon_sym_SQUOTE,
    ACTIONS(8349), 1,
      sym_integer_literal,
    STATE(7808), 1,
      sym__reserved_identifier,
    STATE(7954), 1,
      sym__preproc_expression,
    ACTIONS(8345), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8240), 6,
      sym_character_literal,
      sym_boolean_literal,
      sym_identifier,
      sym_preproc_parenthesized_expression,
      sym_preproc_unary_expression,
      sym_preproc_binary_expression,
    STATE(6267), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(8339), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [182633] = 21,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8337), 1,
      sym__identifier_token,
    ACTIONS(8341), 1,
      anon_sym_LPAREN,
    ACTIONS(8343), 1,
      anon_sym_BANG,
    ACTIONS(8347), 1,
      anon_sym_SQUOTE,
    ACTIONS(8349), 1,
      sym_integer_literal,
    STATE(7808), 1,
      sym__reserved_identifier,
    STATE(7972), 1,
      sym__preproc_expression,
    ACTIONS(8345), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8240), 6,
      sym_character_literal,
      sym_boolean_literal,
      sym_identifier,
      sym_preproc_parenthesized_expression,
      sym_preproc_unary_expression,
      sym_preproc_binary_expression,
    STATE(6268), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(8339), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [182732] = 21,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8337), 1,
      sym__identifier_token,
    ACTIONS(8341), 1,
      anon_sym_LPAREN,
    ACTIONS(8343), 1,
      anon_sym_BANG,
    ACTIONS(8347), 1,
      anon_sym_SQUOTE,
    ACTIONS(8349), 1,
      sym_integer_literal,
    STATE(7808), 1,
      sym__reserved_identifier,
    STATE(8128), 1,
      sym__preproc_expression,
    ACTIONS(8345), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8240), 6,
      sym_character_literal,
      sym_boolean_literal,
      sym_identifier,
      sym_preproc_parenthesized_expression,
      sym_preproc_unary_expression,
      sym_preproc_binary_expression,
    STATE(6269), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(8339), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [182831] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(8357), 1,
      anon_sym_SLASH,
    ACTIONS(8359), 1,
      anon_sym_CARET,
    ACTIONS(8361), 1,
      anon_sym_PIPE,
    ACTIONS(8363), 1,
      anon_sym_AMP,
    ACTIONS(8367), 1,
      anon_sym_GT_GT,
    ACTIONS(8373), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8375), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8377), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8379), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8381), 1,
      anon_sym_as,
    ACTIONS(8383), 1,
      anon_sym_is,
    ACTIONS(8530), 1,
      anon_sym_QMARK,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5416), 2,
      anon_sym_into,
      anon_sym_on,
    ACTIONS(8351), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8353), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8355), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8365), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8369), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8371), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6270), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [182968] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(8357), 1,
      anon_sym_SLASH,
    ACTIONS(8359), 1,
      anon_sym_CARET,
    ACTIONS(8361), 1,
      anon_sym_PIPE,
    ACTIONS(8363), 1,
      anon_sym_AMP,
    ACTIONS(8367), 1,
      anon_sym_GT_GT,
    ACTIONS(8373), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8375), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8377), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8379), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8381), 1,
      anon_sym_as,
    ACTIONS(8383), 1,
      anon_sym_is,
    ACTIONS(8530), 1,
      anon_sym_QMARK,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5644), 2,
      anon_sym_into,
      anon_sym_on,
    ACTIONS(8351), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8353), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8355), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8365), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8369), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8371), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6271), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [183105] = 21,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8337), 1,
      sym__identifier_token,
    ACTIONS(8341), 1,
      anon_sym_LPAREN,
    ACTIONS(8343), 1,
      anon_sym_BANG,
    ACTIONS(8347), 1,
      anon_sym_SQUOTE,
    ACTIONS(8349), 1,
      sym_integer_literal,
    STATE(7808), 1,
      sym__reserved_identifier,
    STATE(7997), 1,
      sym__preproc_expression,
    ACTIONS(8345), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8240), 6,
      sym_character_literal,
      sym_boolean_literal,
      sym_identifier,
      sym_preproc_parenthesized_expression,
      sym_preproc_unary_expression,
      sym_preproc_binary_expression,
    STATE(6272), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(8339), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [183204] = 21,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8337), 1,
      sym__identifier_token,
    ACTIONS(8341), 1,
      anon_sym_LPAREN,
    ACTIONS(8343), 1,
      anon_sym_BANG,
    ACTIONS(8347), 1,
      anon_sym_SQUOTE,
    ACTIONS(8349), 1,
      sym_integer_literal,
    STATE(7808), 1,
      sym__reserved_identifier,
    STATE(7999), 1,
      sym__preproc_expression,
    ACTIONS(8345), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8240), 6,
      sym_character_literal,
      sym_boolean_literal,
      sym_identifier,
      sym_preproc_parenthesized_expression,
      sym_preproc_unary_expression,
      sym_preproc_binary_expression,
    STATE(6273), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(8339), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [183303] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(8357), 1,
      anon_sym_SLASH,
    ACTIONS(8359), 1,
      anon_sym_CARET,
    ACTIONS(8361), 1,
      anon_sym_PIPE,
    ACTIONS(8363), 1,
      anon_sym_AMP,
    ACTIONS(8367), 1,
      anon_sym_GT_GT,
    ACTIONS(8373), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8375), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8377), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8379), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8381), 1,
      anon_sym_as,
    ACTIONS(8383), 1,
      anon_sym_is,
    ACTIONS(8530), 1,
      anon_sym_QMARK,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5424), 2,
      anon_sym_into,
      anon_sym_on,
    ACTIONS(8351), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8353), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8355), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8365), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8369), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8371), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6274), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [183440] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(8357), 1,
      anon_sym_SLASH,
    ACTIONS(8359), 1,
      anon_sym_CARET,
    ACTIONS(8361), 1,
      anon_sym_PIPE,
    ACTIONS(8363), 1,
      anon_sym_AMP,
    ACTIONS(8367), 1,
      anon_sym_GT_GT,
    ACTIONS(8373), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8375), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8377), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8379), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8381), 1,
      anon_sym_as,
    ACTIONS(8383), 1,
      anon_sym_is,
    ACTIONS(8530), 1,
      anon_sym_QMARK,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6336), 2,
      anon_sym_into,
      anon_sym_on,
    ACTIONS(8351), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8353), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8355), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8365), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8369), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8371), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6275), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [183577] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(8357), 1,
      anon_sym_SLASH,
    ACTIONS(8359), 1,
      anon_sym_CARET,
    ACTIONS(8361), 1,
      anon_sym_PIPE,
    ACTIONS(8363), 1,
      anon_sym_AMP,
    ACTIONS(8367), 1,
      anon_sym_GT_GT,
    ACTIONS(8373), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8375), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8377), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8379), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8381), 1,
      anon_sym_as,
    ACTIONS(8383), 1,
      anon_sym_is,
    ACTIONS(8530), 1,
      anon_sym_QMARK,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5572), 2,
      anon_sym_into,
      anon_sym_on,
    ACTIONS(8351), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8353), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8355), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8365), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8369), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8371), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6276), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [183714] = 34,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(8431), 1,
      anon_sym_SLASH,
    ACTIONS(8433), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8439), 1,
      anon_sym_GT_GT,
    ACTIONS(8443), 1,
      anon_sym_as,
    ACTIONS(8445), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8427), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8429), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8435), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8437), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8441), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8453), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(6342), 6,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_equals,
    STATE(6277), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [183839] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8526), 1,
      anon_sym_and,
    ACTIONS(8528), 1,
      anon_sym_or,
    STATE(6278), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5881), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5879), 24,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_GT,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [183926] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8568), 1,
      anon_sym_SEMI,
    STATE(6279), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5654), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5652), 25,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
  [184011] = 21,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8337), 1,
      sym__identifier_token,
    ACTIONS(8341), 1,
      anon_sym_LPAREN,
    ACTIONS(8343), 1,
      anon_sym_BANG,
    ACTIONS(8347), 1,
      anon_sym_SQUOTE,
    ACTIONS(8349), 1,
      sym_integer_literal,
    STATE(7808), 1,
      sym__reserved_identifier,
    STATE(8025), 1,
      sym__preproc_expression,
    ACTIONS(8345), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8240), 6,
      sym_character_literal,
      sym_boolean_literal,
      sym_identifier,
      sym_preproc_parenthesized_expression,
      sym_preproc_unary_expression,
      sym_preproc_binary_expression,
    STATE(6280), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(8339), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [184110] = 33,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(8397), 1,
      anon_sym_SLASH,
    ACTIONS(8407), 1,
      anon_sym_GT_GT,
    ACTIONS(8413), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8421), 1,
      anon_sym_as,
    ACTIONS(8423), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8391), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8393), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8395), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8405), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8411), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(6342), 8,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_by,
    STATE(6281), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [184233] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(8397), 1,
      anon_sym_SLASH,
    ACTIONS(8399), 1,
      anon_sym_CARET,
    ACTIONS(8401), 1,
      anon_sym_PIPE,
    ACTIONS(8403), 1,
      anon_sym_AMP,
    ACTIONS(8407), 1,
      anon_sym_GT_GT,
    ACTIONS(8413), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8415), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8417), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8419), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8421), 1,
      anon_sym_as,
    ACTIONS(8423), 1,
      anon_sym_is,
    ACTIONS(8425), 1,
      anon_sym_QMARK,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6320), 2,
      anon_sym_into,
      anon_sym_by,
    ACTIONS(8391), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8393), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8395), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8405), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8409), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8411), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6282), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [184370] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(8357), 1,
      anon_sym_SLASH,
    ACTIONS(8359), 1,
      anon_sym_CARET,
    ACTIONS(8361), 1,
      anon_sym_PIPE,
    ACTIONS(8363), 1,
      anon_sym_AMP,
    ACTIONS(8367), 1,
      anon_sym_GT_GT,
    ACTIONS(8373), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8375), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8377), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8379), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8381), 1,
      anon_sym_as,
    ACTIONS(8383), 1,
      anon_sym_is,
    ACTIONS(8530), 1,
      anon_sym_QMARK,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5584), 2,
      anon_sym_into,
      anon_sym_on,
    ACTIONS(8351), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8353), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8355), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8365), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8369), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8371), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6283), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [184507] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8570), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    STATE(6284), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [184644] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(6976), 1,
      anon_sym_SLASH,
    ACTIONS(6978), 1,
      anon_sym_AMP,
    ACTIONS(6982), 1,
      anon_sym_GT_GT,
    ACTIONS(7038), 1,
      anon_sym_CARET,
    ACTIONS(7040), 1,
      anon_sym_PIPE,
    ACTIONS(7042), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7044), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7046), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7700), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6970), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6972), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6974), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6980), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6984), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6986), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(8233), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(6285), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [184781] = 21,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8337), 1,
      sym__identifier_token,
    ACTIONS(8341), 1,
      anon_sym_LPAREN,
    ACTIONS(8343), 1,
      anon_sym_BANG,
    ACTIONS(8347), 1,
      anon_sym_SQUOTE,
    ACTIONS(8349), 1,
      sym_integer_literal,
    STATE(7808), 1,
      sym__reserved_identifier,
    STATE(8024), 1,
      sym__preproc_expression,
    ACTIONS(8345), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8240), 6,
      sym_character_literal,
      sym_boolean_literal,
      sym_identifier,
      sym_preproc_parenthesized_expression,
      sym_preproc_unary_expression,
      sym_preproc_binary_expression,
    STATE(6286), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(8339), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [184880] = 41,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(8233), 1,
      anon_sym_COMMA,
    ACTIONS(8572), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6287), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [185019] = 21,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8337), 1,
      sym__identifier_token,
    ACTIONS(8341), 1,
      anon_sym_LPAREN,
    ACTIONS(8343), 1,
      anon_sym_BANG,
    ACTIONS(8347), 1,
      anon_sym_SQUOTE,
    ACTIONS(8349), 1,
      sym_integer_literal,
    STATE(7808), 1,
      sym__reserved_identifier,
    STATE(8041), 1,
      sym__preproc_expression,
    ACTIONS(8345), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8240), 6,
      sym_character_literal,
      sym_boolean_literal,
      sym_identifier,
      sym_preproc_parenthesized_expression,
      sym_preproc_unary_expression,
      sym_preproc_binary_expression,
    STATE(6288), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(8339), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [185118] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(8357), 1,
      anon_sym_SLASH,
    ACTIONS(8359), 1,
      anon_sym_CARET,
    ACTIONS(8361), 1,
      anon_sym_PIPE,
    ACTIONS(8363), 1,
      anon_sym_AMP,
    ACTIONS(8367), 1,
      anon_sym_GT_GT,
    ACTIONS(8373), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8375), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8377), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8379), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8381), 1,
      anon_sym_as,
    ACTIONS(8383), 1,
      anon_sym_is,
    ACTIONS(8530), 1,
      anon_sym_QMARK,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5624), 2,
      anon_sym_into,
      anon_sym_on,
    ACTIONS(8351), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8353), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8355), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8365), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8369), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8371), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6289), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [185255] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(8397), 1,
      anon_sym_SLASH,
    ACTIONS(8399), 1,
      anon_sym_CARET,
    ACTIONS(8401), 1,
      anon_sym_PIPE,
    ACTIONS(8403), 1,
      anon_sym_AMP,
    ACTIONS(8407), 1,
      anon_sym_GT_GT,
    ACTIONS(8413), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8415), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8417), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8419), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8421), 1,
      anon_sym_as,
    ACTIONS(8423), 1,
      anon_sym_is,
    ACTIONS(8425), 1,
      anon_sym_QMARK,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6266), 2,
      anon_sym_into,
      anon_sym_by,
    ACTIONS(8391), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8393), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8395), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8405), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8409), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8411), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6290), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [185392] = 21,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8337), 1,
      sym__identifier_token,
    ACTIONS(8341), 1,
      anon_sym_LPAREN,
    ACTIONS(8343), 1,
      anon_sym_BANG,
    ACTIONS(8347), 1,
      anon_sym_SQUOTE,
    ACTIONS(8349), 1,
      sym_integer_literal,
    STATE(7808), 1,
      sym__reserved_identifier,
    STATE(7969), 1,
      sym__preproc_expression,
    ACTIONS(8345), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(8240), 6,
      sym_character_literal,
      sym_boolean_literal,
      sym_identifier,
      sym_preproc_parenthesized_expression,
      sym_preproc_unary_expression,
      sym_preproc_binary_expression,
    STATE(6291), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(8339), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [185491] = 37,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(8397), 1,
      anon_sym_SLASH,
    ACTIONS(8399), 1,
      anon_sym_CARET,
    ACTIONS(8401), 1,
      anon_sym_PIPE,
    ACTIONS(8403), 1,
      anon_sym_AMP,
    ACTIONS(8407), 1,
      anon_sym_GT_GT,
    ACTIONS(8413), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8421), 1,
      anon_sym_as,
    ACTIONS(8423), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8391), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8393), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8395), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8405), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8409), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8411), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 5,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_by,
    STATE(6292), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [185622] = 38,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(8397), 1,
      anon_sym_SLASH,
    ACTIONS(8399), 1,
      anon_sym_CARET,
    ACTIONS(8401), 1,
      anon_sym_PIPE,
    ACTIONS(8403), 1,
      anon_sym_AMP,
    ACTIONS(8407), 1,
      anon_sym_GT_GT,
    ACTIONS(8413), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8415), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8421), 1,
      anon_sym_as,
    ACTIONS(8423), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8391), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8393), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8395), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8405), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8409), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8411), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 4,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_by,
    STATE(6293), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [185755] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(8397), 1,
      anon_sym_SLASH,
    ACTIONS(8399), 1,
      anon_sym_CARET,
    ACTIONS(8401), 1,
      anon_sym_PIPE,
    ACTIONS(8403), 1,
      anon_sym_AMP,
    ACTIONS(8407), 1,
      anon_sym_GT_GT,
    ACTIONS(8413), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8415), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8417), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8419), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8421), 1,
      anon_sym_as,
    ACTIONS(8423), 1,
      anon_sym_is,
    ACTIONS(8425), 1,
      anon_sym_QMARK,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6270), 2,
      anon_sym_into,
      anon_sym_by,
    ACTIONS(8391), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8393), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8395), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8405), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8409), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8411), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6294), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [185892] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(8413), 1,
      anon_sym_DOT_DOT,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6330), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(6295), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6328), 18,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_by,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [185993] = 41,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(8233), 1,
      anon_sym_COMMA,
    ACTIONS(8574), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6296), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [186132] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(8397), 1,
      anon_sym_SLASH,
    ACTIONS(8399), 1,
      anon_sym_CARET,
    ACTIONS(8401), 1,
      anon_sym_PIPE,
    ACTIONS(8403), 1,
      anon_sym_AMP,
    ACTIONS(8407), 1,
      anon_sym_GT_GT,
    ACTIONS(8413), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8415), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8417), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8419), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8421), 1,
      anon_sym_as,
    ACTIONS(8423), 1,
      anon_sym_is,
    ACTIONS(8425), 1,
      anon_sym_QMARK,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6190), 2,
      anon_sym_into,
      anon_sym_by,
    ACTIONS(8391), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8393), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8395), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8405), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8409), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8411), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6297), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [186269] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(8413), 1,
      anon_sym_DOT_DOT,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1229), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(6298), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(1227), 18,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_by,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [186370] = 29,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(8357), 1,
      anon_sym_SLASH,
    ACTIONS(8367), 1,
      anon_sym_GT_GT,
    ACTIONS(8373), 1,
      anon_sym_DOT_DOT,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8353), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8355), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8365), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6344), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    STATE(6299), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 12,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_on,
      anon_sym_as,
      anon_sym_is,
  [186485] = 26,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(8357), 1,
      anon_sym_SLASH,
    ACTIONS(8373), 1,
      anon_sym_DOT_DOT,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8355), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(6300), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 14,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_on,
      anon_sym_as,
      anon_sym_is,
  [186594] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(8373), 1,
      anon_sym_DOT_DOT,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(6301), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 16,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_on,
      anon_sym_as,
      anon_sym_is,
  [186699] = 35,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(8357), 1,
      anon_sym_SLASH,
    ACTIONS(8363), 1,
      anon_sym_AMP,
    ACTIONS(8367), 1,
      anon_sym_GT_GT,
    ACTIONS(8373), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8381), 1,
      anon_sym_as,
    ACTIONS(8383), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(8351), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8353), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8355), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8365), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8369), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8371), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 6,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_on,
    STATE(6302), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [186826] = 36,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(8357), 1,
      anon_sym_SLASH,
    ACTIONS(8359), 1,
      anon_sym_CARET,
    ACTIONS(8363), 1,
      anon_sym_AMP,
    ACTIONS(8367), 1,
      anon_sym_GT_GT,
    ACTIONS(8373), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8381), 1,
      anon_sym_as,
    ACTIONS(8383), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(8351), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8353), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8355), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8365), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8369), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8371), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 5,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_on,
    STATE(6303), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [186955] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8562), 1,
      anon_sym_and,
    ACTIONS(8564), 1,
      anon_sym_or,
    STATE(6304), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6594), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6592), 24,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_equals,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [187042] = 34,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(8357), 1,
      anon_sym_SLASH,
    ACTIONS(8367), 1,
      anon_sym_GT_GT,
    ACTIONS(8373), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8381), 1,
      anon_sym_as,
    ACTIONS(8383), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8351), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8353), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8355), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8365), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8369), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8371), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(6342), 6,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_on,
    STATE(6305), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [187167] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(8357), 1,
      anon_sym_SLASH,
    ACTIONS(8373), 1,
      anon_sym_DOT_DOT,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8353), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8355), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(6306), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 14,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_on,
      anon_sym_as,
      anon_sym_is,
  [187278] = 33,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(8357), 1,
      anon_sym_SLASH,
    ACTIONS(8367), 1,
      anon_sym_GT_GT,
    ACTIONS(8373), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8381), 1,
      anon_sym_as,
    ACTIONS(8383), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8351), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8353), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8355), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8365), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8371), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(6342), 8,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_on,
    STATE(6307), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [187401] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(8397), 1,
      anon_sym_SLASH,
    ACTIONS(8399), 1,
      anon_sym_CARET,
    ACTIONS(8401), 1,
      anon_sym_PIPE,
    ACTIONS(8403), 1,
      anon_sym_AMP,
    ACTIONS(8407), 1,
      anon_sym_GT_GT,
    ACTIONS(8413), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8415), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8417), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8419), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8421), 1,
      anon_sym_as,
    ACTIONS(8423), 1,
      anon_sym_is,
    ACTIONS(8425), 1,
      anon_sym_QMARK,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6324), 2,
      anon_sym_into,
      anon_sym_by,
    ACTIONS(8391), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8393), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8395), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8405), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8409), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8411), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6308), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [187538] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(8397), 1,
      anon_sym_SLASH,
    ACTIONS(8399), 1,
      anon_sym_CARET,
    ACTIONS(8401), 1,
      anon_sym_PIPE,
    ACTIONS(8403), 1,
      anon_sym_AMP,
    ACTIONS(8407), 1,
      anon_sym_GT_GT,
    ACTIONS(8413), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8415), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8417), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8419), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8421), 1,
      anon_sym_as,
    ACTIONS(8423), 1,
      anon_sym_is,
    ACTIONS(8425), 1,
      anon_sym_QMARK,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5416), 2,
      anon_sym_into,
      anon_sym_by,
    ACTIONS(8391), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8393), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8395), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8405), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8409), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8411), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6309), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [187675] = 37,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(8357), 1,
      anon_sym_SLASH,
    ACTIONS(8359), 1,
      anon_sym_CARET,
    ACTIONS(8361), 1,
      anon_sym_PIPE,
    ACTIONS(8363), 1,
      anon_sym_AMP,
    ACTIONS(8367), 1,
      anon_sym_GT_GT,
    ACTIONS(8373), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8381), 1,
      anon_sym_as,
    ACTIONS(8383), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8351), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8353), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8355), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8365), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8369), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8371), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 5,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_on,
    STATE(6310), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [187806] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6787), 1,
      anon_sym_switch,
    ACTIONS(6801), 1,
      anon_sym_with,
    ACTIONS(8397), 1,
      anon_sym_SLASH,
    ACTIONS(8399), 1,
      anon_sym_CARET,
    ACTIONS(8401), 1,
      anon_sym_PIPE,
    ACTIONS(8403), 1,
      anon_sym_AMP,
    ACTIONS(8407), 1,
      anon_sym_GT_GT,
    ACTIONS(8413), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8415), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8417), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8419), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8421), 1,
      anon_sym_as,
    ACTIONS(8423), 1,
      anon_sym_is,
    ACTIONS(8425), 1,
      anon_sym_QMARK,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(5644), 2,
      anon_sym_into,
      anon_sym_by,
    ACTIONS(8391), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8393), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8395), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8405), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8409), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8411), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6311), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [187943] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8562), 1,
      anon_sym_and,
    STATE(6312), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6707), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6705), 25,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_into,
      anon_sym_equals,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [188028] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(8576), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6313), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [188164] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8578), 1,
      anon_sym_and,
    ACTIONS(8580), 1,
      anon_sym_or,
    STATE(6314), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6594), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6592), 23,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_GT,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [188250] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5424), 1,
      anon_sym_by,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8584), 1,
      anon_sym_QMARK,
    ACTIONS(8590), 1,
      anon_sym_SLASH,
    ACTIONS(8592), 1,
      anon_sym_CARET,
    ACTIONS(8594), 1,
      anon_sym_PIPE,
    ACTIONS(8596), 1,
      anon_sym_AMP,
    ACTIONS(8600), 1,
      anon_sym_GT_GT,
    ACTIONS(8606), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8608), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8610), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8612), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8614), 1,
      anon_sym_as,
    ACTIONS(8616), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8586), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8588), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8598), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8602), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8604), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6315), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [188386] = 29,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8622), 1,
      anon_sym_SLASH,
    ACTIONS(8626), 1,
      anon_sym_GT_GT,
    ACTIONS(8628), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8618), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8620), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8624), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6344), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    STATE(6316), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 11,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
  [188500] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(8630), 1,
      anon_sym_COLON,
    ACTIONS(8634), 1,
      anon_sym_QMARK,
    ACTIONS(8640), 1,
      anon_sym_SLASH,
    ACTIONS(8642), 1,
      anon_sym_CARET,
    ACTIONS(8644), 1,
      anon_sym_PIPE,
    ACTIONS(8646), 1,
      anon_sym_AMP,
    ACTIONS(8650), 1,
      anon_sym_GT_GT,
    ACTIONS(8656), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8658), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8660), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8662), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8664), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8632), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8636), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8638), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8648), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8652), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8654), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6317), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [188636] = 26,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8622), 1,
      anon_sym_SLASH,
    ACTIONS(8628), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8620), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(6318), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 13,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
  [188744] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8628), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(6319), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 15,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
  [188848] = 35,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(8622), 1,
      anon_sym_SLASH,
    ACTIONS(8626), 1,
      anon_sym_GT_GT,
    ACTIONS(8628), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8668), 1,
      anon_sym_AMP,
    ACTIONS(8674), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(8618), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8620), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8624), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8666), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8670), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8672), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 5,
      anon_sym_CARET,
      anon_sym_EQ_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(6320), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [188974] = 36,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(8622), 1,
      anon_sym_SLASH,
    ACTIONS(8626), 1,
      anon_sym_GT_GT,
    ACTIONS(8628), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8668), 1,
      anon_sym_AMP,
    ACTIONS(8674), 1,
      anon_sym_is,
    ACTIONS(8676), 1,
      anon_sym_CARET,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(8618), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8620), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8624), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8666), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8670), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8672), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 4,
      anon_sym_EQ_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(6321), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [189102] = 34,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(8622), 1,
      anon_sym_SLASH,
    ACTIONS(8626), 1,
      anon_sym_GT_GT,
    ACTIONS(8628), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8674), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8618), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8620), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8624), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8666), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8670), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8672), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(6342), 5,
      anon_sym_CARET,
      anon_sym_EQ_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(6322), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [189226] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8622), 1,
      anon_sym_SLASH,
    ACTIONS(8628), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8618), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8620), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(6323), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 13,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
  [189336] = 33,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(8622), 1,
      anon_sym_SLASH,
    ACTIONS(8626), 1,
      anon_sym_GT_GT,
    ACTIONS(8628), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8674), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8618), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8620), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8624), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8666), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8672), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(6342), 7,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_EQ_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(6324), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [189458] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(8628), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6330), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(6325), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6328), 17,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_GT,
      anon_sym_switch,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [189558] = 37,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(8622), 1,
      anon_sym_SLASH,
    ACTIONS(8626), 1,
      anon_sym_GT_GT,
    ACTIONS(8628), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8668), 1,
      anon_sym_AMP,
    ACTIONS(8674), 1,
      anon_sym_is,
    ACTIONS(8676), 1,
      anon_sym_CARET,
    ACTIONS(8678), 1,
      anon_sym_PIPE,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8618), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8620), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8624), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8666), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8670), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8672), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 4,
      anon_sym_EQ_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(6326), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [189688] = 38,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(8622), 1,
      anon_sym_SLASH,
    ACTIONS(8626), 1,
      anon_sym_GT_GT,
    ACTIONS(8628), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8668), 1,
      anon_sym_AMP,
    ACTIONS(8674), 1,
      anon_sym_is,
    ACTIONS(8676), 1,
      anon_sym_CARET,
    ACTIONS(8678), 1,
      anon_sym_PIPE,
    ACTIONS(8680), 1,
      anon_sym_AMP_AMP,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8618), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8620), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8624), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8666), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8670), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8672), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 3,
      anon_sym_EQ_GT,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(6327), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [189820] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6342), 1,
      anon_sym_EQ_GT,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(8622), 1,
      anon_sym_SLASH,
    ACTIONS(8626), 1,
      anon_sym_GT_GT,
    ACTIONS(8628), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8668), 1,
      anon_sym_AMP,
    ACTIONS(8674), 1,
      anon_sym_is,
    ACTIONS(8676), 1,
      anon_sym_CARET,
    ACTIONS(8678), 1,
      anon_sym_PIPE,
    ACTIONS(8680), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8682), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8684), 1,
      anon_sym_QMARK_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8618), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8620), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8624), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8666), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8670), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8672), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6328), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [189956] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6336), 1,
      anon_sym_by,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8584), 1,
      anon_sym_QMARK,
    ACTIONS(8590), 1,
      anon_sym_SLASH,
    ACTIONS(8592), 1,
      anon_sym_CARET,
    ACTIONS(8594), 1,
      anon_sym_PIPE,
    ACTIONS(8596), 1,
      anon_sym_AMP,
    ACTIONS(8600), 1,
      anon_sym_GT_GT,
    ACTIONS(8606), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8608), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8610), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8612), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8614), 1,
      anon_sym_as,
    ACTIONS(8616), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8586), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8588), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8598), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8602), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8604), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6329), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [190092] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5416), 1,
      anon_sym_EQ_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(8622), 1,
      anon_sym_SLASH,
    ACTIONS(8626), 1,
      anon_sym_GT_GT,
    ACTIONS(8628), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8668), 1,
      anon_sym_AMP,
    ACTIONS(8674), 1,
      anon_sym_is,
    ACTIONS(8676), 1,
      anon_sym_CARET,
    ACTIONS(8678), 1,
      anon_sym_PIPE,
    ACTIONS(8680), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8682), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8684), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8686), 1,
      anon_sym_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8618), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8620), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8624), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8666), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8670), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8672), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6330), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [190228] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8688), 1,
      anon_sym_and,
    STATE(6331), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6707), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6705), 24,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_equals,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [190312] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5644), 1,
      anon_sym_EQ_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(8622), 1,
      anon_sym_SLASH,
    ACTIONS(8626), 1,
      anon_sym_GT_GT,
    ACTIONS(8628), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8668), 1,
      anon_sym_AMP,
    ACTIONS(8674), 1,
      anon_sym_is,
    ACTIONS(8676), 1,
      anon_sym_CARET,
    ACTIONS(8678), 1,
      anon_sym_PIPE,
    ACTIONS(8680), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8682), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8684), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8686), 1,
      anon_sym_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8618), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8620), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8624), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8666), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8670), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8672), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6332), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [190448] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5424), 1,
      anon_sym_EQ_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(8622), 1,
      anon_sym_SLASH,
    ACTIONS(8626), 1,
      anon_sym_GT_GT,
    ACTIONS(8628), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8668), 1,
      anon_sym_AMP,
    ACTIONS(8674), 1,
      anon_sym_is,
    ACTIONS(8676), 1,
      anon_sym_CARET,
    ACTIONS(8678), 1,
      anon_sym_PIPE,
    ACTIONS(8680), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8682), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8684), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8686), 1,
      anon_sym_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8618), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8620), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8624), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8666), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8670), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8672), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6333), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [190584] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6336), 1,
      anon_sym_EQ_GT,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(8622), 1,
      anon_sym_SLASH,
    ACTIONS(8626), 1,
      anon_sym_GT_GT,
    ACTIONS(8628), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8668), 1,
      anon_sym_AMP,
    ACTIONS(8674), 1,
      anon_sym_is,
    ACTIONS(8676), 1,
      anon_sym_CARET,
    ACTIONS(8678), 1,
      anon_sym_PIPE,
    ACTIONS(8680), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8682), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8684), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8686), 1,
      anon_sym_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8618), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8620), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8624), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8666), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8670), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8672), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6334), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [190720] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5572), 1,
      anon_sym_EQ_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(8622), 1,
      anon_sym_SLASH,
    ACTIONS(8626), 1,
      anon_sym_GT_GT,
    ACTIONS(8628), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8668), 1,
      anon_sym_AMP,
    ACTIONS(8674), 1,
      anon_sym_is,
    ACTIONS(8676), 1,
      anon_sym_CARET,
    ACTIONS(8678), 1,
      anon_sym_PIPE,
    ACTIONS(8680), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8682), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8684), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8686), 1,
      anon_sym_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8618), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8620), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8624), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8666), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8670), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8672), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6335), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [190856] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5584), 1,
      anon_sym_EQ_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(8622), 1,
      anon_sym_SLASH,
    ACTIONS(8626), 1,
      anon_sym_GT_GT,
    ACTIONS(8628), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8668), 1,
      anon_sym_AMP,
    ACTIONS(8674), 1,
      anon_sym_is,
    ACTIONS(8676), 1,
      anon_sym_CARET,
    ACTIONS(8678), 1,
      anon_sym_PIPE,
    ACTIONS(8680), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8682), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8684), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8686), 1,
      anon_sym_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8618), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8620), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8624), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8666), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8670), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8672), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6336), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [190992] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5624), 1,
      anon_sym_EQ_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(8622), 1,
      anon_sym_SLASH,
    ACTIONS(8626), 1,
      anon_sym_GT_GT,
    ACTIONS(8628), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8668), 1,
      anon_sym_AMP,
    ACTIONS(8674), 1,
      anon_sym_is,
    ACTIONS(8676), 1,
      anon_sym_CARET,
    ACTIONS(8678), 1,
      anon_sym_PIPE,
    ACTIONS(8680), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8682), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8684), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8686), 1,
      anon_sym_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8618), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8620), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8624), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8666), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8670), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8672), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6337), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [191128] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5572), 1,
      anon_sym_by,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8584), 1,
      anon_sym_QMARK,
    ACTIONS(8590), 1,
      anon_sym_SLASH,
    ACTIONS(8592), 1,
      anon_sym_CARET,
    ACTIONS(8594), 1,
      anon_sym_PIPE,
    ACTIONS(8596), 1,
      anon_sym_AMP,
    ACTIONS(8600), 1,
      anon_sym_GT_GT,
    ACTIONS(8606), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8608), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8610), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8612), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8614), 1,
      anon_sym_as,
    ACTIONS(8616), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8586), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8588), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8598), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8602), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8604), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6338), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [191264] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5584), 1,
      anon_sym_by,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8584), 1,
      anon_sym_QMARK,
    ACTIONS(8590), 1,
      anon_sym_SLASH,
    ACTIONS(8592), 1,
      anon_sym_CARET,
    ACTIONS(8594), 1,
      anon_sym_PIPE,
    ACTIONS(8596), 1,
      anon_sym_AMP,
    ACTIONS(8600), 1,
      anon_sym_GT_GT,
    ACTIONS(8606), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8608), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8610), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8612), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8614), 1,
      anon_sym_as,
    ACTIONS(8616), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8586), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8588), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8598), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8602), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8604), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6339), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [191400] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5624), 1,
      anon_sym_by,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8584), 1,
      anon_sym_QMARK,
    ACTIONS(8590), 1,
      anon_sym_SLASH,
    ACTIONS(8592), 1,
      anon_sym_CARET,
    ACTIONS(8594), 1,
      anon_sym_PIPE,
    ACTIONS(8596), 1,
      anon_sym_AMP,
    ACTIONS(8600), 1,
      anon_sym_GT_GT,
    ACTIONS(8606), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8608), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8610), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8612), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8614), 1,
      anon_sym_as,
    ACTIONS(8616), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8586), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8588), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8598), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8602), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8604), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6340), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [191536] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(8634), 1,
      anon_sym_QMARK,
    ACTIONS(8640), 1,
      anon_sym_SLASH,
    ACTIONS(8642), 1,
      anon_sym_CARET,
    ACTIONS(8644), 1,
      anon_sym_PIPE,
    ACTIONS(8646), 1,
      anon_sym_AMP,
    ACTIONS(8650), 1,
      anon_sym_GT_GT,
    ACTIONS(8656), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8658), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8660), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8662), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8664), 1,
      anon_sym_is,
    ACTIONS(8690), 1,
      anon_sym_COLON,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8632), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8636), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8638), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8648), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8652), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8654), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6341), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [191672] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(8692), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6342), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [191808] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(7516), 1,
      anon_sym_QMARK,
    ACTIONS(7522), 1,
      anon_sym_SLASH,
    ACTIONS(7524), 1,
      anon_sym_CARET,
    ACTIONS(7526), 1,
      anon_sym_PIPE,
    ACTIONS(7528), 1,
      anon_sym_AMP,
    ACTIONS(7532), 1,
      anon_sym_GT_GT,
    ACTIONS(7538), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7540), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7542), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7544), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8694), 1,
      anon_sym_SEMI,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7514), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7518), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7520), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7530), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7534), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7536), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6343), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [191944] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(7411), 1,
      anon_sym_LBRACK,
    ACTIONS(7413), 1,
      anon_sym_QMARK,
    ACTIONS(7415), 1,
      anon_sym_STAR,
    ACTIONS(8696), 1,
      anon_sym_DOT,
    ACTIONS(4494), 5,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
    STATE(6344), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4492), 26,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      sym_discard,
      anon_sym_and,
      anon_sym_or,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [192036] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(8698), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6345), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [192172] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(8700), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6346), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [192308] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8702), 1,
      anon_sym_SEMI,
    STATE(6347), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5654), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5652), 24,
      anon_sym_LBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RBRACE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [192392] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(8634), 1,
      anon_sym_QMARK,
    ACTIONS(8640), 1,
      anon_sym_SLASH,
    ACTIONS(8642), 1,
      anon_sym_CARET,
    ACTIONS(8644), 1,
      anon_sym_PIPE,
    ACTIONS(8646), 1,
      anon_sym_AMP,
    ACTIONS(8650), 1,
      anon_sym_GT_GT,
    ACTIONS(8656), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8658), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8660), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8662), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8664), 1,
      anon_sym_is,
    ACTIONS(8704), 1,
      anon_sym_COLON,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8632), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8636), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8638), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8648), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8652), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8654), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6348), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [192528] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(7516), 1,
      anon_sym_QMARK,
    ACTIONS(7522), 1,
      anon_sym_SLASH,
    ACTIONS(7524), 1,
      anon_sym_CARET,
    ACTIONS(7526), 1,
      anon_sym_PIPE,
    ACTIONS(7528), 1,
      anon_sym_AMP,
    ACTIONS(7532), 1,
      anon_sym_GT_GT,
    ACTIONS(7538), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7540), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7542), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7544), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8706), 1,
      anon_sym_SEMI,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7514), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7518), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7520), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7530), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7534), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7536), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6349), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [192664] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(8634), 1,
      anon_sym_QMARK,
    ACTIONS(8640), 1,
      anon_sym_SLASH,
    ACTIONS(8642), 1,
      anon_sym_CARET,
    ACTIONS(8644), 1,
      anon_sym_PIPE,
    ACTIONS(8646), 1,
      anon_sym_AMP,
    ACTIONS(8650), 1,
      anon_sym_GT_GT,
    ACTIONS(8656), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8658), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8660), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8662), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8664), 1,
      anon_sym_is,
    ACTIONS(8708), 1,
      anon_sym_COLON,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8632), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8636), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8638), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8648), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8652), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8654), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6350), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [192800] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8710), 1,
      anon_sym_RPAREN,
    STATE(6351), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5288), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5286), 24,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [192884] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(7516), 1,
      anon_sym_QMARK,
    ACTIONS(7522), 1,
      anon_sym_SLASH,
    ACTIONS(7524), 1,
      anon_sym_CARET,
    ACTIONS(7526), 1,
      anon_sym_PIPE,
    ACTIONS(7528), 1,
      anon_sym_AMP,
    ACTIONS(7532), 1,
      anon_sym_GT_GT,
    ACTIONS(7538), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7540), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7542), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7544), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8712), 1,
      anon_sym_SEMI,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7514), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7518), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7520), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7530), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7534), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7536), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6352), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [193020] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(8714), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6353), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [193156] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(8634), 1,
      anon_sym_QMARK,
    ACTIONS(8640), 1,
      anon_sym_SLASH,
    ACTIONS(8642), 1,
      anon_sym_CARET,
    ACTIONS(8644), 1,
      anon_sym_PIPE,
    ACTIONS(8646), 1,
      anon_sym_AMP,
    ACTIONS(8650), 1,
      anon_sym_GT_GT,
    ACTIONS(8656), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8658), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8660), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8662), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8664), 1,
      anon_sym_is,
    ACTIONS(8716), 1,
      anon_sym_COLON,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8632), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8636), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8638), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8648), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8652), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8654), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6354), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [193292] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(7516), 1,
      anon_sym_QMARK,
    ACTIONS(7522), 1,
      anon_sym_SLASH,
    ACTIONS(7524), 1,
      anon_sym_CARET,
    ACTIONS(7526), 1,
      anon_sym_PIPE,
    ACTIONS(7528), 1,
      anon_sym_AMP,
    ACTIONS(7532), 1,
      anon_sym_GT_GT,
    ACTIONS(7538), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7540), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7542), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7544), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8718), 1,
      anon_sym_SEMI,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7514), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7518), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7520), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7530), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7534), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7536), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6355), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [193428] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6324), 1,
      anon_sym_by,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8584), 1,
      anon_sym_QMARK,
    ACTIONS(8590), 1,
      anon_sym_SLASH,
    ACTIONS(8592), 1,
      anon_sym_CARET,
    ACTIONS(8594), 1,
      anon_sym_PIPE,
    ACTIONS(8596), 1,
      anon_sym_AMP,
    ACTIONS(8600), 1,
      anon_sym_GT_GT,
    ACTIONS(8606), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8608), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8610), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8612), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8614), 1,
      anon_sym_as,
    ACTIONS(8616), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8586), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8588), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8598), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8602), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8604), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6356), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [193564] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8722), 1,
      anon_sym_QMARK,
    ACTIONS(8728), 1,
      anon_sym_SLASH,
    ACTIONS(8730), 1,
      anon_sym_CARET,
    ACTIONS(8732), 1,
      anon_sym_PIPE,
    ACTIONS(8734), 1,
      anon_sym_AMP,
    ACTIONS(8738), 1,
      anon_sym_GT_GT,
    ACTIONS(8744), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8746), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8748), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8750), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8752), 1,
      anon_sym_equals,
    ACTIONS(8754), 1,
      anon_sym_as,
    ACTIONS(8756), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8720), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8724), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8726), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8736), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8740), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8742), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6357), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [193700] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(8634), 1,
      anon_sym_QMARK,
    ACTIONS(8640), 1,
      anon_sym_SLASH,
    ACTIONS(8642), 1,
      anon_sym_CARET,
    ACTIONS(8644), 1,
      anon_sym_PIPE,
    ACTIONS(8646), 1,
      anon_sym_AMP,
    ACTIONS(8650), 1,
      anon_sym_GT_GT,
    ACTIONS(8656), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8658), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8660), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8662), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8664), 1,
      anon_sym_is,
    ACTIONS(8758), 1,
      anon_sym_COLON,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8632), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8636), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8638), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8648), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8652), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8654), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6358), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [193836] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(2079), 1,
      anon_sym_SEMI,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(7516), 1,
      anon_sym_QMARK,
    ACTIONS(7522), 1,
      anon_sym_SLASH,
    ACTIONS(7524), 1,
      anon_sym_CARET,
    ACTIONS(7526), 1,
      anon_sym_PIPE,
    ACTIONS(7528), 1,
      anon_sym_AMP,
    ACTIONS(7532), 1,
      anon_sym_GT_GT,
    ACTIONS(7538), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7540), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7542), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7544), 1,
      anon_sym_QMARK_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7514), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7518), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7520), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7530), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7534), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7536), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6359), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [193972] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(8634), 1,
      anon_sym_QMARK,
    ACTIONS(8640), 1,
      anon_sym_SLASH,
    ACTIONS(8642), 1,
      anon_sym_CARET,
    ACTIONS(8644), 1,
      anon_sym_PIPE,
    ACTIONS(8646), 1,
      anon_sym_AMP,
    ACTIONS(8650), 1,
      anon_sym_GT_GT,
    ACTIONS(8656), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8658), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8660), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8662), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8664), 1,
      anon_sym_is,
    ACTIONS(8760), 1,
      anon_sym_COLON,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8632), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8636), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8638), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8648), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8652), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8654), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6360), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [194108] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(8634), 1,
      anon_sym_QMARK,
    ACTIONS(8640), 1,
      anon_sym_SLASH,
    ACTIONS(8642), 1,
      anon_sym_CARET,
    ACTIONS(8644), 1,
      anon_sym_PIPE,
    ACTIONS(8646), 1,
      anon_sym_AMP,
    ACTIONS(8650), 1,
      anon_sym_GT_GT,
    ACTIONS(8656), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8658), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8660), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8662), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8664), 1,
      anon_sym_is,
    ACTIONS(8762), 1,
      anon_sym_COLON,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8632), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8636), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8638), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8648), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8652), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8654), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6361), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [194244] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(8634), 1,
      anon_sym_QMARK,
    ACTIONS(8640), 1,
      anon_sym_SLASH,
    ACTIONS(8642), 1,
      anon_sym_CARET,
    ACTIONS(8644), 1,
      anon_sym_PIPE,
    ACTIONS(8646), 1,
      anon_sym_AMP,
    ACTIONS(8650), 1,
      anon_sym_GT_GT,
    ACTIONS(8656), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8658), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8660), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8662), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8664), 1,
      anon_sym_is,
    ACTIONS(8764), 1,
      anon_sym_COLON,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8632), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8636), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8638), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8648), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8652), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8654), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6362), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [194380] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(8634), 1,
      anon_sym_QMARK,
    ACTIONS(8640), 1,
      anon_sym_SLASH,
    ACTIONS(8642), 1,
      anon_sym_CARET,
    ACTIONS(8644), 1,
      anon_sym_PIPE,
    ACTIONS(8646), 1,
      anon_sym_AMP,
    ACTIONS(8650), 1,
      anon_sym_GT_GT,
    ACTIONS(8656), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8658), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8660), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8662), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8664), 1,
      anon_sym_is,
    ACTIONS(8766), 1,
      anon_sym_COLON,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8632), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8636), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8638), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8648), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8652), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8654), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6363), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [194516] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(8634), 1,
      anon_sym_QMARK,
    ACTIONS(8640), 1,
      anon_sym_SLASH,
    ACTIONS(8642), 1,
      anon_sym_CARET,
    ACTIONS(8644), 1,
      anon_sym_PIPE,
    ACTIONS(8646), 1,
      anon_sym_AMP,
    ACTIONS(8650), 1,
      anon_sym_GT_GT,
    ACTIONS(8656), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8658), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8660), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8662), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8664), 1,
      anon_sym_is,
    ACTIONS(8768), 1,
      anon_sym_COLON,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8632), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8636), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8638), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8648), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8652), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8654), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6364), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [194652] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(8770), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6365), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [194788] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(8634), 1,
      anon_sym_QMARK,
    ACTIONS(8640), 1,
      anon_sym_SLASH,
    ACTIONS(8642), 1,
      anon_sym_CARET,
    ACTIONS(8644), 1,
      anon_sym_PIPE,
    ACTIONS(8646), 1,
      anon_sym_AMP,
    ACTIONS(8650), 1,
      anon_sym_GT_GT,
    ACTIONS(8656), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8658), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8660), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8662), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8664), 1,
      anon_sym_is,
    ACTIONS(8772), 1,
      anon_sym_COLON,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8632), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8636), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8638), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8648), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8652), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8654), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6366), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [194924] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(8634), 1,
      anon_sym_QMARK,
    ACTIONS(8640), 1,
      anon_sym_SLASH,
    ACTIONS(8642), 1,
      anon_sym_CARET,
    ACTIONS(8644), 1,
      anon_sym_PIPE,
    ACTIONS(8646), 1,
      anon_sym_AMP,
    ACTIONS(8650), 1,
      anon_sym_GT_GT,
    ACTIONS(8656), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8658), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8660), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8662), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8664), 1,
      anon_sym_is,
    ACTIONS(8774), 1,
      anon_sym_COLON,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8632), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8636), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8638), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8648), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8652), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8654), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6367), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [195060] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(8634), 1,
      anon_sym_QMARK,
    ACTIONS(8640), 1,
      anon_sym_SLASH,
    ACTIONS(8642), 1,
      anon_sym_CARET,
    ACTIONS(8644), 1,
      anon_sym_PIPE,
    ACTIONS(8646), 1,
      anon_sym_AMP,
    ACTIONS(8650), 1,
      anon_sym_GT_GT,
    ACTIONS(8656), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8658), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8660), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8662), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8664), 1,
      anon_sym_is,
    ACTIONS(8776), 1,
      anon_sym_COLON,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8632), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8636), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8638), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8648), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8652), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8654), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6368), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [195196] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(8634), 1,
      anon_sym_QMARK,
    ACTIONS(8640), 1,
      anon_sym_SLASH,
    ACTIONS(8642), 1,
      anon_sym_CARET,
    ACTIONS(8644), 1,
      anon_sym_PIPE,
    ACTIONS(8646), 1,
      anon_sym_AMP,
    ACTIONS(8650), 1,
      anon_sym_GT_GT,
    ACTIONS(8656), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8658), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8660), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8662), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8664), 1,
      anon_sym_is,
    ACTIONS(8778), 1,
      anon_sym_COLON,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8632), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8636), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8638), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8648), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8652), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8654), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6369), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [195332] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(8634), 1,
      anon_sym_QMARK,
    ACTIONS(8640), 1,
      anon_sym_SLASH,
    ACTIONS(8642), 1,
      anon_sym_CARET,
    ACTIONS(8644), 1,
      anon_sym_PIPE,
    ACTIONS(8646), 1,
      anon_sym_AMP,
    ACTIONS(8650), 1,
      anon_sym_GT_GT,
    ACTIONS(8656), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8658), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8660), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8662), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8664), 1,
      anon_sym_is,
    ACTIONS(8780), 1,
      anon_sym_COLON,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8632), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8636), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8638), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8648), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8652), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8654), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6370), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [195468] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(8634), 1,
      anon_sym_QMARK,
    ACTIONS(8640), 1,
      anon_sym_SLASH,
    ACTIONS(8642), 1,
      anon_sym_CARET,
    ACTIONS(8644), 1,
      anon_sym_PIPE,
    ACTIONS(8646), 1,
      anon_sym_AMP,
    ACTIONS(8650), 1,
      anon_sym_GT_GT,
    ACTIONS(8656), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8658), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8660), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8662), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8664), 1,
      anon_sym_is,
    ACTIONS(8782), 1,
      anon_sym_COLON,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8632), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8636), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8638), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8648), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8652), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8654), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6371), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [195604] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(8634), 1,
      anon_sym_QMARK,
    ACTIONS(8640), 1,
      anon_sym_SLASH,
    ACTIONS(8642), 1,
      anon_sym_CARET,
    ACTIONS(8644), 1,
      anon_sym_PIPE,
    ACTIONS(8646), 1,
      anon_sym_AMP,
    ACTIONS(8650), 1,
      anon_sym_GT_GT,
    ACTIONS(8656), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8658), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8660), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8662), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8664), 1,
      anon_sym_is,
    ACTIONS(8784), 1,
      anon_sym_COLON,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8632), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8636), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8638), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8648), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8652), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8654), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6372), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [195740] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(8634), 1,
      anon_sym_QMARK,
    ACTIONS(8640), 1,
      anon_sym_SLASH,
    ACTIONS(8642), 1,
      anon_sym_CARET,
    ACTIONS(8644), 1,
      anon_sym_PIPE,
    ACTIONS(8646), 1,
      anon_sym_AMP,
    ACTIONS(8650), 1,
      anon_sym_GT_GT,
    ACTIONS(8656), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8658), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8660), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8662), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8664), 1,
      anon_sym_is,
    ACTIONS(8786), 1,
      anon_sym_COLON,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8632), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8636), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8638), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8648), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8652), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8654), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6373), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [195876] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(8634), 1,
      anon_sym_QMARK,
    ACTIONS(8640), 1,
      anon_sym_SLASH,
    ACTIONS(8642), 1,
      anon_sym_CARET,
    ACTIONS(8644), 1,
      anon_sym_PIPE,
    ACTIONS(8646), 1,
      anon_sym_AMP,
    ACTIONS(8650), 1,
      anon_sym_GT_GT,
    ACTIONS(8656), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8658), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8660), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8662), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8664), 1,
      anon_sym_is,
    ACTIONS(8788), 1,
      anon_sym_COLON,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8632), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8636), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8638), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8648), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8652), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8654), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6374), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [196012] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(8634), 1,
      anon_sym_QMARK,
    ACTIONS(8640), 1,
      anon_sym_SLASH,
    ACTIONS(8642), 1,
      anon_sym_CARET,
    ACTIONS(8644), 1,
      anon_sym_PIPE,
    ACTIONS(8646), 1,
      anon_sym_AMP,
    ACTIONS(8650), 1,
      anon_sym_GT_GT,
    ACTIONS(8656), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8658), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8660), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8662), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8664), 1,
      anon_sym_is,
    ACTIONS(8790), 1,
      anon_sym_COLON,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8632), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8636), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8638), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8648), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8652), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8654), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6375), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [196148] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(8792), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6376), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [196284] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(8794), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6377), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [196420] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(8634), 1,
      anon_sym_QMARK,
    ACTIONS(8640), 1,
      anon_sym_SLASH,
    ACTIONS(8642), 1,
      anon_sym_CARET,
    ACTIONS(8644), 1,
      anon_sym_PIPE,
    ACTIONS(8646), 1,
      anon_sym_AMP,
    ACTIONS(8650), 1,
      anon_sym_GT_GT,
    ACTIONS(8656), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8658), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8660), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8662), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8664), 1,
      anon_sym_is,
    ACTIONS(8796), 1,
      anon_sym_COLON,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8632), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8636), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8638), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8648), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8652), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8654), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6378), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [196556] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(8798), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6379), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [196692] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(7516), 1,
      anon_sym_QMARK,
    ACTIONS(7522), 1,
      anon_sym_SLASH,
    ACTIONS(7524), 1,
      anon_sym_CARET,
    ACTIONS(7526), 1,
      anon_sym_PIPE,
    ACTIONS(7528), 1,
      anon_sym_AMP,
    ACTIONS(7532), 1,
      anon_sym_GT_GT,
    ACTIONS(7538), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7540), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7542), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7544), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8800), 1,
      anon_sym_SEMI,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7514), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7518), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7520), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7530), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7534), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7536), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6380), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [196828] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(8634), 1,
      anon_sym_QMARK,
    ACTIONS(8640), 1,
      anon_sym_SLASH,
    ACTIONS(8642), 1,
      anon_sym_CARET,
    ACTIONS(8644), 1,
      anon_sym_PIPE,
    ACTIONS(8646), 1,
      anon_sym_AMP,
    ACTIONS(8650), 1,
      anon_sym_GT_GT,
    ACTIONS(8656), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8658), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8660), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8662), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8664), 1,
      anon_sym_is,
    ACTIONS(8802), 1,
      anon_sym_COLON,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8632), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8636), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8638), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8648), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8652), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8654), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6381), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [196964] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(7516), 1,
      anon_sym_QMARK,
    ACTIONS(7522), 1,
      anon_sym_SLASH,
    ACTIONS(7524), 1,
      anon_sym_CARET,
    ACTIONS(7526), 1,
      anon_sym_PIPE,
    ACTIONS(7528), 1,
      anon_sym_AMP,
    ACTIONS(7532), 1,
      anon_sym_GT_GT,
    ACTIONS(7538), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7540), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7542), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7544), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8804), 1,
      anon_sym_SEMI,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7514), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7518), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7520), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7530), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7534), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7536), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6382), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [197100] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(8806), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6383), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [197236] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(8808), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6384), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [197372] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(8810), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6385), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [197508] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(8634), 1,
      anon_sym_QMARK,
    ACTIONS(8640), 1,
      anon_sym_SLASH,
    ACTIONS(8642), 1,
      anon_sym_CARET,
    ACTIONS(8644), 1,
      anon_sym_PIPE,
    ACTIONS(8646), 1,
      anon_sym_AMP,
    ACTIONS(8650), 1,
      anon_sym_GT_GT,
    ACTIONS(8656), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8658), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8660), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8662), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8664), 1,
      anon_sym_is,
    ACTIONS(8812), 1,
      anon_sym_COLON,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8632), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8636), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8638), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8648), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8652), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8654), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6386), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [197644] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8816), 1,
      anon_sym_QMARK,
    ACTIONS(8822), 1,
      anon_sym_SLASH,
    ACTIONS(8824), 1,
      anon_sym_CARET,
    ACTIONS(8826), 1,
      anon_sym_PIPE,
    ACTIONS(8828), 1,
      anon_sym_AMP,
    ACTIONS(8832), 1,
      anon_sym_GT_GT,
    ACTIONS(8838), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8840), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8842), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8844), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8846), 1,
      anon_sym_on,
    ACTIONS(8848), 1,
      anon_sym_as,
    ACTIONS(8850), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8814), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8818), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8820), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8830), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8834), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8836), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6387), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [197780] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(8852), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6388), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [197916] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(7516), 1,
      anon_sym_QMARK,
    ACTIONS(7522), 1,
      anon_sym_SLASH,
    ACTIONS(7524), 1,
      anon_sym_CARET,
    ACTIONS(7526), 1,
      anon_sym_PIPE,
    ACTIONS(7528), 1,
      anon_sym_AMP,
    ACTIONS(7532), 1,
      anon_sym_GT_GT,
    ACTIONS(7538), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7540), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7542), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7544), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8854), 1,
      anon_sym_SEMI,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7514), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7518), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7520), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7530), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7534), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7536), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6389), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [198052] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8856), 1,
      anon_sym_RPAREN,
    STATE(6390), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5288), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5286), 24,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [198136] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8578), 1,
      anon_sym_and,
    ACTIONS(8580), 1,
      anon_sym_or,
    STATE(6391), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5881), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5879), 23,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_GT,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [198222] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8584), 1,
      anon_sym_QMARK,
    ACTIONS(8590), 1,
      anon_sym_SLASH,
    ACTIONS(8592), 1,
      anon_sym_CARET,
    ACTIONS(8594), 1,
      anon_sym_PIPE,
    ACTIONS(8596), 1,
      anon_sym_AMP,
    ACTIONS(8600), 1,
      anon_sym_GT_GT,
    ACTIONS(8606), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8608), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8610), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8612), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8614), 1,
      anon_sym_as,
    ACTIONS(8616), 1,
      anon_sym_is,
    ACTIONS(8858), 1,
      anon_sym_by,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8586), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8588), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8598), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8602), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8604), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6392), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [198358] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(7516), 1,
      anon_sym_QMARK,
    ACTIONS(7522), 1,
      anon_sym_SLASH,
    ACTIONS(7524), 1,
      anon_sym_CARET,
    ACTIONS(7526), 1,
      anon_sym_PIPE,
    ACTIONS(7528), 1,
      anon_sym_AMP,
    ACTIONS(7532), 1,
      anon_sym_GT_GT,
    ACTIONS(7538), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7540), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7542), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7544), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8860), 1,
      anon_sym_SEMI,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7514), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7518), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7520), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7530), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7534), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7536), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6393), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [198494] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(8634), 1,
      anon_sym_QMARK,
    ACTIONS(8640), 1,
      anon_sym_SLASH,
    ACTIONS(8642), 1,
      anon_sym_CARET,
    ACTIONS(8644), 1,
      anon_sym_PIPE,
    ACTIONS(8646), 1,
      anon_sym_AMP,
    ACTIONS(8650), 1,
      anon_sym_GT_GT,
    ACTIONS(8656), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8658), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8660), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8662), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8664), 1,
      anon_sym_is,
    ACTIONS(8862), 1,
      anon_sym_COLON,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8632), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8636), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8638), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8648), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8652), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8654), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6394), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [198630] = 35,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(8870), 1,
      anon_sym_SLASH,
    ACTIONS(8872), 1,
      anon_sym_AMP,
    ACTIONS(8876), 1,
      anon_sym_GT_GT,
    ACTIONS(8882), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8884), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(8864), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8866), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8868), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8874), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8878), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8880), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 5,
      anon_sym_in,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(6395), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [198756] = 36,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(8870), 1,
      anon_sym_SLASH,
    ACTIONS(8872), 1,
      anon_sym_AMP,
    ACTIONS(8876), 1,
      anon_sym_GT_GT,
    ACTIONS(8882), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8884), 1,
      anon_sym_is,
    ACTIONS(8886), 1,
      anon_sym_CARET,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(8864), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8866), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8868), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8874), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8878), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8880), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 4,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(6396), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [198884] = 34,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(8870), 1,
      anon_sym_SLASH,
    ACTIONS(8876), 1,
      anon_sym_GT_GT,
    ACTIONS(8882), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8884), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8864), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8866), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8868), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8874), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8878), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8880), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(6342), 5,
      anon_sym_in,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(6397), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [199008] = 33,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(8870), 1,
      anon_sym_SLASH,
    ACTIONS(8876), 1,
      anon_sym_GT_GT,
    ACTIONS(8882), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8884), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8864), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8866), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8868), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8874), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8880), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(6342), 7,
      anon_sym_in,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(6398), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [199130] = 37,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(8870), 1,
      anon_sym_SLASH,
    ACTIONS(8872), 1,
      anon_sym_AMP,
    ACTIONS(8876), 1,
      anon_sym_GT_GT,
    ACTIONS(8882), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8884), 1,
      anon_sym_is,
    ACTIONS(8886), 1,
      anon_sym_CARET,
    ACTIONS(8888), 1,
      anon_sym_PIPE,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8864), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8866), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8868), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8874), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8878), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8880), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 4,
      anon_sym_in,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(6399), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [199260] = 38,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(8870), 1,
      anon_sym_SLASH,
    ACTIONS(8872), 1,
      anon_sym_AMP,
    ACTIONS(8876), 1,
      anon_sym_GT_GT,
    ACTIONS(8882), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8884), 1,
      anon_sym_is,
    ACTIONS(8886), 1,
      anon_sym_CARET,
    ACTIONS(8888), 1,
      anon_sym_PIPE,
    ACTIONS(8890), 1,
      anon_sym_AMP_AMP,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8864), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8866), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8868), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8874), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8878), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8880), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 3,
      anon_sym_in,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(6400), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [199392] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6342), 1,
      anon_sym_in,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(8870), 1,
      anon_sym_SLASH,
    ACTIONS(8872), 1,
      anon_sym_AMP,
    ACTIONS(8876), 1,
      anon_sym_GT_GT,
    ACTIONS(8882), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8884), 1,
      anon_sym_is,
    ACTIONS(8886), 1,
      anon_sym_CARET,
    ACTIONS(8888), 1,
      anon_sym_PIPE,
    ACTIONS(8890), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8892), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8894), 1,
      anon_sym_QMARK_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8864), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8866), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8868), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8874), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8878), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8880), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6401), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [199528] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8584), 1,
      anon_sym_QMARK,
    ACTIONS(8590), 1,
      anon_sym_SLASH,
    ACTIONS(8592), 1,
      anon_sym_CARET,
    ACTIONS(8594), 1,
      anon_sym_PIPE,
    ACTIONS(8596), 1,
      anon_sym_AMP,
    ACTIONS(8600), 1,
      anon_sym_GT_GT,
    ACTIONS(8606), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8608), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8610), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8612), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8614), 1,
      anon_sym_as,
    ACTIONS(8616), 1,
      anon_sym_is,
    ACTIONS(8896), 1,
      anon_sym_by,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8586), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8588), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8598), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8602), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8604), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6402), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [199664] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5416), 1,
      anon_sym_in,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(8870), 1,
      anon_sym_SLASH,
    ACTIONS(8872), 1,
      anon_sym_AMP,
    ACTIONS(8876), 1,
      anon_sym_GT_GT,
    ACTIONS(8882), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8884), 1,
      anon_sym_is,
    ACTIONS(8886), 1,
      anon_sym_CARET,
    ACTIONS(8888), 1,
      anon_sym_PIPE,
    ACTIONS(8890), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8892), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8894), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8898), 1,
      anon_sym_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8864), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8866), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8868), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8874), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8878), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8880), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6403), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [199800] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(7516), 1,
      anon_sym_QMARK,
    ACTIONS(7522), 1,
      anon_sym_SLASH,
    ACTIONS(7524), 1,
      anon_sym_CARET,
    ACTIONS(7526), 1,
      anon_sym_PIPE,
    ACTIONS(7528), 1,
      anon_sym_AMP,
    ACTIONS(7532), 1,
      anon_sym_GT_GT,
    ACTIONS(7538), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7540), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7542), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7544), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8900), 1,
      anon_sym_SEMI,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7514), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7518), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7520), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7530), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7534), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7536), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6404), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [199936] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5644), 1,
      anon_sym_in,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(8870), 1,
      anon_sym_SLASH,
    ACTIONS(8872), 1,
      anon_sym_AMP,
    ACTIONS(8876), 1,
      anon_sym_GT_GT,
    ACTIONS(8882), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8884), 1,
      anon_sym_is,
    ACTIONS(8886), 1,
      anon_sym_CARET,
    ACTIONS(8888), 1,
      anon_sym_PIPE,
    ACTIONS(8890), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8892), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8894), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8898), 1,
      anon_sym_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8864), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8866), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8868), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8874), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8878), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8880), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6405), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [200072] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5424), 1,
      anon_sym_in,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(8870), 1,
      anon_sym_SLASH,
    ACTIONS(8872), 1,
      anon_sym_AMP,
    ACTIONS(8876), 1,
      anon_sym_GT_GT,
    ACTIONS(8882), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8884), 1,
      anon_sym_is,
    ACTIONS(8886), 1,
      anon_sym_CARET,
    ACTIONS(8888), 1,
      anon_sym_PIPE,
    ACTIONS(8890), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8892), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8894), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8898), 1,
      anon_sym_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8864), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8866), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8868), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8874), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8878), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8880), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6406), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [200208] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(8902), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6407), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [200344] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(7516), 1,
      anon_sym_QMARK,
    ACTIONS(7522), 1,
      anon_sym_SLASH,
    ACTIONS(7524), 1,
      anon_sym_CARET,
    ACTIONS(7526), 1,
      anon_sym_PIPE,
    ACTIONS(7528), 1,
      anon_sym_AMP,
    ACTIONS(7532), 1,
      anon_sym_GT_GT,
    ACTIONS(7538), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7540), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7542), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7544), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8904), 1,
      anon_sym_SEMI,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7514), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7518), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7520), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7530), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7534), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7536), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6408), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [200480] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6336), 1,
      anon_sym_in,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(8870), 1,
      anon_sym_SLASH,
    ACTIONS(8872), 1,
      anon_sym_AMP,
    ACTIONS(8876), 1,
      anon_sym_GT_GT,
    ACTIONS(8882), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8884), 1,
      anon_sym_is,
    ACTIONS(8886), 1,
      anon_sym_CARET,
    ACTIONS(8888), 1,
      anon_sym_PIPE,
    ACTIONS(8890), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8892), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8894), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8898), 1,
      anon_sym_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8864), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8866), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8868), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8874), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8878), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8880), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6409), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [200616] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7118), 1,
      anon_sym_SLASH,
    ACTIONS(7120), 1,
      anon_sym_CARET,
    ACTIONS(7122), 1,
      anon_sym_PIPE,
    ACTIONS(7124), 1,
      anon_sym_AMP,
    ACTIONS(7128), 1,
      anon_sym_GT_GT,
    ACTIONS(7136), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7138), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7140), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(8634), 1,
      anon_sym_QMARK,
    ACTIONS(8656), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8664), 1,
      anon_sym_is,
    ACTIONS(8906), 1,
      anon_sym_COLON,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7112), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7114), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7116), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7126), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7130), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7132), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6410), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [200752] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5572), 1,
      anon_sym_in,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(8870), 1,
      anon_sym_SLASH,
    ACTIONS(8872), 1,
      anon_sym_AMP,
    ACTIONS(8876), 1,
      anon_sym_GT_GT,
    ACTIONS(8882), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8884), 1,
      anon_sym_is,
    ACTIONS(8886), 1,
      anon_sym_CARET,
    ACTIONS(8888), 1,
      anon_sym_PIPE,
    ACTIONS(8890), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8892), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8894), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8898), 1,
      anon_sym_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8864), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8866), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8868), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8874), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8878), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8880), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6411), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [200888] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5584), 1,
      anon_sym_in,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(8870), 1,
      anon_sym_SLASH,
    ACTIONS(8872), 1,
      anon_sym_AMP,
    ACTIONS(8876), 1,
      anon_sym_GT_GT,
    ACTIONS(8882), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8884), 1,
      anon_sym_is,
    ACTIONS(8886), 1,
      anon_sym_CARET,
    ACTIONS(8888), 1,
      anon_sym_PIPE,
    ACTIONS(8890), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8892), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8894), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8898), 1,
      anon_sym_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8864), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8866), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8868), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8874), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8878), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8880), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6412), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [201024] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(7516), 1,
      anon_sym_QMARK,
    ACTIONS(7522), 1,
      anon_sym_SLASH,
    ACTIONS(7524), 1,
      anon_sym_CARET,
    ACTIONS(7526), 1,
      anon_sym_PIPE,
    ACTIONS(7528), 1,
      anon_sym_AMP,
    ACTIONS(7532), 1,
      anon_sym_GT_GT,
    ACTIONS(7538), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7540), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7542), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7544), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8908), 1,
      anon_sym_SEMI,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7514), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7518), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7520), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7530), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7534), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7536), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6413), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [201160] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5624), 1,
      anon_sym_in,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(8870), 1,
      anon_sym_SLASH,
    ACTIONS(8872), 1,
      anon_sym_AMP,
    ACTIONS(8876), 1,
      anon_sym_GT_GT,
    ACTIONS(8882), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8884), 1,
      anon_sym_is,
    ACTIONS(8886), 1,
      anon_sym_CARET,
    ACTIONS(8888), 1,
      anon_sym_PIPE,
    ACTIONS(8890), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8892), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8894), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8898), 1,
      anon_sym_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8864), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8866), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8868), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8874), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8878), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8880), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6414), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [201296] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(8910), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6415), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [201432] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(8634), 1,
      anon_sym_QMARK,
    ACTIONS(8640), 1,
      anon_sym_SLASH,
    ACTIONS(8642), 1,
      anon_sym_CARET,
    ACTIONS(8644), 1,
      anon_sym_PIPE,
    ACTIONS(8646), 1,
      anon_sym_AMP,
    ACTIONS(8650), 1,
      anon_sym_GT_GT,
    ACTIONS(8656), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8658), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8660), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8662), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8664), 1,
      anon_sym_is,
    ACTIONS(8912), 1,
      anon_sym_COLON,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8632), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8636), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8638), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8648), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8652), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8654), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6416), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [201568] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(8914), 1,
      anon_sym_LPAREN,
    ACTIONS(8916), 1,
      anon_sym_operator,
    ACTIONS(8918), 1,
      anon_sym_this,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(7194), 1,
      sym_explicit_interface_specifier,
    STATE(7510), 1,
      sym_identifier,
    STATE(8010), 1,
      sym_tuple_pattern,
    STATE(8392), 1,
      sym_variable_declarator,
    STATE(9517), 1,
      sym__name,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(6417), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [201672] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6320), 1,
      anon_sym_equals,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8722), 1,
      anon_sym_QMARK,
    ACTIONS(8728), 1,
      anon_sym_SLASH,
    ACTIONS(8730), 1,
      anon_sym_CARET,
    ACTIONS(8732), 1,
      anon_sym_PIPE,
    ACTIONS(8734), 1,
      anon_sym_AMP,
    ACTIONS(8738), 1,
      anon_sym_GT_GT,
    ACTIONS(8744), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8746), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8748), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8750), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8754), 1,
      anon_sym_as,
    ACTIONS(8756), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8720), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8724), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8726), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8736), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8740), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8742), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6418), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [201808] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8584), 1,
      anon_sym_QMARK,
    ACTIONS(8590), 1,
      anon_sym_SLASH,
    ACTIONS(8592), 1,
      anon_sym_CARET,
    ACTIONS(8594), 1,
      anon_sym_PIPE,
    ACTIONS(8596), 1,
      anon_sym_AMP,
    ACTIONS(8600), 1,
      anon_sym_GT_GT,
    ACTIONS(8606), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8608), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8610), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8612), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8614), 1,
      anon_sym_as,
    ACTIONS(8616), 1,
      anon_sym_is,
    ACTIONS(8920), 1,
      anon_sym_by,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8586), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8588), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8598), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8602), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8604), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6419), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [201944] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(8870), 1,
      anon_sym_SLASH,
    ACTIONS(8872), 1,
      anon_sym_AMP,
    ACTIONS(8876), 1,
      anon_sym_GT_GT,
    ACTIONS(8882), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8884), 1,
      anon_sym_is,
    ACTIONS(8886), 1,
      anon_sym_CARET,
    ACTIONS(8888), 1,
      anon_sym_PIPE,
    ACTIONS(8890), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8892), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8894), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8898), 1,
      anon_sym_QMARK,
    ACTIONS(8922), 1,
      anon_sym_in,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8864), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8866), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8868), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8874), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8878), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8880), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6420), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [202080] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(8924), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6421), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [202216] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(8926), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6422), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [202352] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(8928), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6423), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [202488] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8930), 1,
      anon_sym_and,
    STATE(6424), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6707), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6705), 24,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_on,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [202572] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(8932), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6425), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [202708] = 29,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8640), 1,
      anon_sym_SLASH,
    ACTIONS(8650), 1,
      anon_sym_GT_GT,
    ACTIONS(8656), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8636), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8638), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8648), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6344), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    STATE(6426), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 11,
      anon_sym_COLON,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
  [202822] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(8634), 1,
      anon_sym_QMARK,
    ACTIONS(8640), 1,
      anon_sym_SLASH,
    ACTIONS(8642), 1,
      anon_sym_CARET,
    ACTIONS(8644), 1,
      anon_sym_PIPE,
    ACTIONS(8646), 1,
      anon_sym_AMP,
    ACTIONS(8650), 1,
      anon_sym_GT_GT,
    ACTIONS(8656), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8658), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8660), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8662), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8664), 1,
      anon_sym_is,
    ACTIONS(8934), 1,
      anon_sym_COLON,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8632), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8636), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8638), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8648), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8652), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8654), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6427), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [202958] = 26,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8640), 1,
      anon_sym_SLASH,
    ACTIONS(8656), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8638), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(6428), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 13,
      anon_sym_COLON,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
  [203066] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(8936), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6429), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [203202] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(7516), 1,
      anon_sym_QMARK,
    ACTIONS(7522), 1,
      anon_sym_SLASH,
    ACTIONS(7524), 1,
      anon_sym_CARET,
    ACTIONS(7526), 1,
      anon_sym_PIPE,
    ACTIONS(7528), 1,
      anon_sym_AMP,
    ACTIONS(7532), 1,
      anon_sym_GT_GT,
    ACTIONS(7538), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7540), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7542), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7544), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8938), 1,
      anon_sym_SEMI,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7514), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7518), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7520), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7530), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7534), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7536), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6430), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [203338] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(8940), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6431), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [203474] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(8634), 1,
      anon_sym_QMARK,
    ACTIONS(8640), 1,
      anon_sym_SLASH,
    ACTIONS(8642), 1,
      anon_sym_CARET,
    ACTIONS(8644), 1,
      anon_sym_PIPE,
    ACTIONS(8646), 1,
      anon_sym_AMP,
    ACTIONS(8650), 1,
      anon_sym_GT_GT,
    ACTIONS(8656), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8658), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8660), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8662), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8664), 1,
      anon_sym_is,
    ACTIONS(8942), 1,
      anon_sym_COLON,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8632), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8636), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8638), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8648), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8652), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8654), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6432), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [203610] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8656), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(6433), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 15,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
  [203714] = 35,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(8640), 1,
      anon_sym_SLASH,
    ACTIONS(8646), 1,
      anon_sym_AMP,
    ACTIONS(8650), 1,
      anon_sym_GT_GT,
    ACTIONS(8656), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8664), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(8632), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8636), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8638), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8648), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8652), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8654), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 5,
      anon_sym_COLON,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(6434), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [203840] = 36,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(8640), 1,
      anon_sym_SLASH,
    ACTIONS(8642), 1,
      anon_sym_CARET,
    ACTIONS(8646), 1,
      anon_sym_AMP,
    ACTIONS(8650), 1,
      anon_sym_GT_GT,
    ACTIONS(8656), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8664), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(8632), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8636), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8638), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8648), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8652), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8654), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 4,
      anon_sym_COLON,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(6435), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [203968] = 34,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(8640), 1,
      anon_sym_SLASH,
    ACTIONS(8650), 1,
      anon_sym_GT_GT,
    ACTIONS(8656), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8664), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8632), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8636), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8638), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8648), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8652), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8654), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(6342), 5,
      anon_sym_COLON,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(6436), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [204092] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8640), 1,
      anon_sym_SLASH,
    ACTIONS(8656), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8636), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8638), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(6437), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 13,
      anon_sym_COLON,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
  [204202] = 33,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(8640), 1,
      anon_sym_SLASH,
    ACTIONS(8650), 1,
      anon_sym_GT_GT,
    ACTIONS(8656), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8664), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8632), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8636), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8638), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8648), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8654), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(6342), 7,
      anon_sym_COLON,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(6438), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [204324] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(8656), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6330), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(6439), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6328), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [204424] = 37,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(8640), 1,
      anon_sym_SLASH,
    ACTIONS(8642), 1,
      anon_sym_CARET,
    ACTIONS(8644), 1,
      anon_sym_PIPE,
    ACTIONS(8646), 1,
      anon_sym_AMP,
    ACTIONS(8650), 1,
      anon_sym_GT_GT,
    ACTIONS(8656), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8664), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8632), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8636), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8638), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8648), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8652), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8654), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 4,
      anon_sym_COLON,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(6440), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [204554] = 38,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(8640), 1,
      anon_sym_SLASH,
    ACTIONS(8642), 1,
      anon_sym_CARET,
    ACTIONS(8644), 1,
      anon_sym_PIPE,
    ACTIONS(8646), 1,
      anon_sym_AMP,
    ACTIONS(8650), 1,
      anon_sym_GT_GT,
    ACTIONS(8656), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8658), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8664), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8632), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8636), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8638), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8648), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8652), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8654), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 3,
      anon_sym_COLON,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
    STATE(6441), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [204686] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6342), 1,
      anon_sym_COLON,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(8640), 1,
      anon_sym_SLASH,
    ACTIONS(8642), 1,
      anon_sym_CARET,
    ACTIONS(8644), 1,
      anon_sym_PIPE,
    ACTIONS(8646), 1,
      anon_sym_AMP,
    ACTIONS(8650), 1,
      anon_sym_GT_GT,
    ACTIONS(8656), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8658), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8660), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8662), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8664), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8632), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8636), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8638), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8648), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8652), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8654), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6442), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [204822] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(7516), 1,
      anon_sym_QMARK,
    ACTIONS(7522), 1,
      anon_sym_SLASH,
    ACTIONS(7524), 1,
      anon_sym_CARET,
    ACTIONS(7526), 1,
      anon_sym_PIPE,
    ACTIONS(7528), 1,
      anon_sym_AMP,
    ACTIONS(7532), 1,
      anon_sym_GT_GT,
    ACTIONS(7538), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7540), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7542), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7544), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8045), 1,
      anon_sym_SEMI,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7514), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7518), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7520), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7530), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7534), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7536), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6443), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [204958] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6320), 1,
      anon_sym_in,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(8870), 1,
      anon_sym_SLASH,
    ACTIONS(8872), 1,
      anon_sym_AMP,
    ACTIONS(8876), 1,
      anon_sym_GT_GT,
    ACTIONS(8882), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8884), 1,
      anon_sym_is,
    ACTIONS(8886), 1,
      anon_sym_CARET,
    ACTIONS(8888), 1,
      anon_sym_PIPE,
    ACTIONS(8890), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8892), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8894), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8898), 1,
      anon_sym_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8864), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8866), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8868), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8874), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8878), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8880), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6444), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [205094] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(8634), 1,
      anon_sym_QMARK,
    ACTIONS(8640), 1,
      anon_sym_SLASH,
    ACTIONS(8642), 1,
      anon_sym_CARET,
    ACTIONS(8644), 1,
      anon_sym_PIPE,
    ACTIONS(8646), 1,
      anon_sym_AMP,
    ACTIONS(8650), 1,
      anon_sym_GT_GT,
    ACTIONS(8656), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8658), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8660), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8662), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8664), 1,
      anon_sym_is,
    ACTIONS(8944), 1,
      anon_sym_COLON,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8632), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8636), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8638), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8648), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8652), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8654), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6445), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [205230] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6324), 1,
      anon_sym_in,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(8870), 1,
      anon_sym_SLASH,
    ACTIONS(8872), 1,
      anon_sym_AMP,
    ACTIONS(8876), 1,
      anon_sym_GT_GT,
    ACTIONS(8882), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8884), 1,
      anon_sym_is,
    ACTIONS(8886), 1,
      anon_sym_CARET,
    ACTIONS(8888), 1,
      anon_sym_PIPE,
    ACTIONS(8890), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8892), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8894), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8898), 1,
      anon_sym_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8864), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8866), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8868), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8874), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8878), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8880), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6446), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [205366] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6324), 1,
      anon_sym_equals,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8722), 1,
      anon_sym_QMARK,
    ACTIONS(8728), 1,
      anon_sym_SLASH,
    ACTIONS(8730), 1,
      anon_sym_CARET,
    ACTIONS(8732), 1,
      anon_sym_PIPE,
    ACTIONS(8734), 1,
      anon_sym_AMP,
    ACTIONS(8738), 1,
      anon_sym_GT_GT,
    ACTIONS(8744), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8746), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8748), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8750), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8754), 1,
      anon_sym_as,
    ACTIONS(8756), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8720), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8724), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8726), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8736), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8740), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8742), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6447), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [205502] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5416), 1,
      anon_sym_COLON,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(8634), 1,
      anon_sym_QMARK,
    ACTIONS(8640), 1,
      anon_sym_SLASH,
    ACTIONS(8642), 1,
      anon_sym_CARET,
    ACTIONS(8644), 1,
      anon_sym_PIPE,
    ACTIONS(8646), 1,
      anon_sym_AMP,
    ACTIONS(8650), 1,
      anon_sym_GT_GT,
    ACTIONS(8656), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8658), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8660), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8662), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8664), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8632), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8636), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8638), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8648), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8652), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8654), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6448), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [205638] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(8946), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6449), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [205774] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(8634), 1,
      anon_sym_QMARK,
    ACTIONS(8640), 1,
      anon_sym_SLASH,
    ACTIONS(8642), 1,
      anon_sym_CARET,
    ACTIONS(8644), 1,
      anon_sym_PIPE,
    ACTIONS(8646), 1,
      anon_sym_AMP,
    ACTIONS(8650), 1,
      anon_sym_GT_GT,
    ACTIONS(8656), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8658), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8660), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8662), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8664), 1,
      anon_sym_is,
    ACTIONS(8948), 1,
      anon_sym_COLON,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8632), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8636), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8638), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8648), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8652), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8654), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6450), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [205910] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5644), 1,
      anon_sym_COLON,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(8634), 1,
      anon_sym_QMARK,
    ACTIONS(8640), 1,
      anon_sym_SLASH,
    ACTIONS(8642), 1,
      anon_sym_CARET,
    ACTIONS(8644), 1,
      anon_sym_PIPE,
    ACTIONS(8646), 1,
      anon_sym_AMP,
    ACTIONS(8650), 1,
      anon_sym_GT_GT,
    ACTIONS(8656), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8658), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8660), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8662), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8664), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8632), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8636), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8638), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8648), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8652), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8654), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6451), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [206046] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(8950), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6452), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [206182] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5424), 1,
      anon_sym_COLON,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(8634), 1,
      anon_sym_QMARK,
    ACTIONS(8640), 1,
      anon_sym_SLASH,
    ACTIONS(8642), 1,
      anon_sym_CARET,
    ACTIONS(8644), 1,
      anon_sym_PIPE,
    ACTIONS(8646), 1,
      anon_sym_AMP,
    ACTIONS(8650), 1,
      anon_sym_GT_GT,
    ACTIONS(8656), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8658), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8660), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8662), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8664), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8632), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8636), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8638), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8648), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8652), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8654), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6453), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [206318] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(8952), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6454), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [206454] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6336), 1,
      anon_sym_COLON,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(8634), 1,
      anon_sym_QMARK,
    ACTIONS(8640), 1,
      anon_sym_SLASH,
    ACTIONS(8642), 1,
      anon_sym_CARET,
    ACTIONS(8644), 1,
      anon_sym_PIPE,
    ACTIONS(8646), 1,
      anon_sym_AMP,
    ACTIONS(8650), 1,
      anon_sym_GT_GT,
    ACTIONS(8656), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8658), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8660), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8662), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8664), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8632), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8636), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8638), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8648), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8652), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8654), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6455), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [206590] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(8954), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6456), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [206726] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6320), 1,
      anon_sym_on,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8816), 1,
      anon_sym_QMARK,
    ACTIONS(8822), 1,
      anon_sym_SLASH,
    ACTIONS(8824), 1,
      anon_sym_CARET,
    ACTIONS(8826), 1,
      anon_sym_PIPE,
    ACTIONS(8828), 1,
      anon_sym_AMP,
    ACTIONS(8832), 1,
      anon_sym_GT_GT,
    ACTIONS(8838), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8840), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8842), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8844), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8848), 1,
      anon_sym_as,
    ACTIONS(8850), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8814), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8818), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8820), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8830), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8834), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8836), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6457), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [206862] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(8634), 1,
      anon_sym_QMARK,
    ACTIONS(8640), 1,
      anon_sym_SLASH,
    ACTIONS(8642), 1,
      anon_sym_CARET,
    ACTIONS(8644), 1,
      anon_sym_PIPE,
    ACTIONS(8646), 1,
      anon_sym_AMP,
    ACTIONS(8650), 1,
      anon_sym_GT_GT,
    ACTIONS(8656), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8658), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8660), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8662), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8664), 1,
      anon_sym_is,
    ACTIONS(8956), 1,
      anon_sym_COLON,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8632), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8636), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8638), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8648), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8652), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8654), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6458), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [206998] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6324), 1,
      anon_sym_on,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8816), 1,
      anon_sym_QMARK,
    ACTIONS(8822), 1,
      anon_sym_SLASH,
    ACTIONS(8824), 1,
      anon_sym_CARET,
    ACTIONS(8826), 1,
      anon_sym_PIPE,
    ACTIONS(8828), 1,
      anon_sym_AMP,
    ACTIONS(8832), 1,
      anon_sym_GT_GT,
    ACTIONS(8838), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8840), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8842), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8844), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8848), 1,
      anon_sym_as,
    ACTIONS(8850), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8814), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8818), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8820), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8830), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8834), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8836), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6459), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [207134] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(8634), 1,
      anon_sym_QMARK,
    ACTIONS(8640), 1,
      anon_sym_SLASH,
    ACTIONS(8642), 1,
      anon_sym_CARET,
    ACTIONS(8644), 1,
      anon_sym_PIPE,
    ACTIONS(8646), 1,
      anon_sym_AMP,
    ACTIONS(8650), 1,
      anon_sym_GT_GT,
    ACTIONS(8656), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8658), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8660), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8662), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8664), 1,
      anon_sym_is,
    ACTIONS(8958), 1,
      anon_sym_COLON,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8632), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8636), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8638), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8648), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8652), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8654), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6460), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [207270] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8960), 1,
      anon_sym_and,
    STATE(6461), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6707), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6705), 24,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_by,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [207354] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(8634), 1,
      anon_sym_QMARK,
    ACTIONS(8640), 1,
      anon_sym_SLASH,
    ACTIONS(8642), 1,
      anon_sym_CARET,
    ACTIONS(8644), 1,
      anon_sym_PIPE,
    ACTIONS(8646), 1,
      anon_sym_AMP,
    ACTIONS(8650), 1,
      anon_sym_GT_GT,
    ACTIONS(8656), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8658), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8660), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8662), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8664), 1,
      anon_sym_is,
    ACTIONS(8962), 1,
      anon_sym_COLON,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8632), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8636), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8638), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8648), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8652), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8654), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6462), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [207490] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(8634), 1,
      anon_sym_QMARK,
    ACTIONS(8640), 1,
      anon_sym_SLASH,
    ACTIONS(8642), 1,
      anon_sym_CARET,
    ACTIONS(8644), 1,
      anon_sym_PIPE,
    ACTIONS(8646), 1,
      anon_sym_AMP,
    ACTIONS(8650), 1,
      anon_sym_GT_GT,
    ACTIONS(8656), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8658), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8660), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8662), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8664), 1,
      anon_sym_is,
    ACTIONS(8964), 1,
      anon_sym_COLON,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8632), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8636), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8638), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8648), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8652), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8654), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6463), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [207626] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5572), 1,
      anon_sym_COLON,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(8634), 1,
      anon_sym_QMARK,
    ACTIONS(8640), 1,
      anon_sym_SLASH,
    ACTIONS(8642), 1,
      anon_sym_CARET,
    ACTIONS(8644), 1,
      anon_sym_PIPE,
    ACTIONS(8646), 1,
      anon_sym_AMP,
    ACTIONS(8650), 1,
      anon_sym_GT_GT,
    ACTIONS(8656), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8658), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8660), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8662), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8664), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8632), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8636), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8638), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8648), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8652), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8654), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6464), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [207762] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5584), 1,
      anon_sym_COLON,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(8634), 1,
      anon_sym_QMARK,
    ACTIONS(8640), 1,
      anon_sym_SLASH,
    ACTIONS(8642), 1,
      anon_sym_CARET,
    ACTIONS(8644), 1,
      anon_sym_PIPE,
    ACTIONS(8646), 1,
      anon_sym_AMP,
    ACTIONS(8650), 1,
      anon_sym_GT_GT,
    ACTIONS(8656), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8658), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8660), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8662), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8664), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8632), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8636), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8638), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8648), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8652), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8654), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6465), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [207898] = 21,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4494), 1,
      anon_sym_LBRACE,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(7411), 1,
      anon_sym_LBRACK,
    ACTIONS(7413), 1,
      anon_sym_QMARK,
    ACTIONS(7415), 1,
      anon_sym_STAR,
    ACTIONS(8566), 1,
      anon_sym_DOT,
    ACTIONS(8969), 1,
      anon_sym_LPAREN,
    STATE(8900), 1,
      sym_attribute_argument_list,
    ACTIONS(8966), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(6466), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4492), 26,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      sym_discard,
      anon_sym_and,
      anon_sym_or,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [207996] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8972), 1,
      anon_sym_and,
    STATE(6467), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6707), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6705), 24,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [208080] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(8634), 1,
      anon_sym_QMARK,
    ACTIONS(8640), 1,
      anon_sym_SLASH,
    ACTIONS(8642), 1,
      anon_sym_CARET,
    ACTIONS(8644), 1,
      anon_sym_PIPE,
    ACTIONS(8646), 1,
      anon_sym_AMP,
    ACTIONS(8650), 1,
      anon_sym_GT_GT,
    ACTIONS(8656), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8658), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8660), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8662), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8664), 1,
      anon_sym_is,
    ACTIONS(8974), 1,
      anon_sym_COLON,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8632), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8636), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8638), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8648), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8652), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8654), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6468), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [208216] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8976), 1,
      anon_sym_and,
    ACTIONS(8978), 1,
      anon_sym_or,
    STATE(6469), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5881), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5879), 23,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_in,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [208302] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5624), 1,
      anon_sym_COLON,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(8634), 1,
      anon_sym_QMARK,
    ACTIONS(8640), 1,
      anon_sym_SLASH,
    ACTIONS(8642), 1,
      anon_sym_CARET,
    ACTIONS(8644), 1,
      anon_sym_PIPE,
    ACTIONS(8646), 1,
      anon_sym_AMP,
    ACTIONS(8650), 1,
      anon_sym_GT_GT,
    ACTIONS(8656), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8658), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8660), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8662), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8664), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8632), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8636), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8638), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8648), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8652), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8654), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6470), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [208438] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8584), 1,
      anon_sym_QMARK,
    ACTIONS(8590), 1,
      anon_sym_SLASH,
    ACTIONS(8592), 1,
      anon_sym_CARET,
    ACTIONS(8594), 1,
      anon_sym_PIPE,
    ACTIONS(8596), 1,
      anon_sym_AMP,
    ACTIONS(8600), 1,
      anon_sym_GT_GT,
    ACTIONS(8606), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8608), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8610), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8612), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8614), 1,
      anon_sym_as,
    ACTIONS(8616), 1,
      anon_sym_is,
    ACTIONS(8980), 1,
      anon_sym_by,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8586), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8588), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8598), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8602), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8604), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6471), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [208574] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(7516), 1,
      anon_sym_QMARK,
    ACTIONS(7522), 1,
      anon_sym_SLASH,
    ACTIONS(7524), 1,
      anon_sym_CARET,
    ACTIONS(7526), 1,
      anon_sym_PIPE,
    ACTIONS(7528), 1,
      anon_sym_AMP,
    ACTIONS(7532), 1,
      anon_sym_GT_GT,
    ACTIONS(7538), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7540), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7542), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7544), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8982), 1,
      anon_sym_SEMI,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7514), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7518), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7520), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7530), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7534), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7536), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6472), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [208710] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(8870), 1,
      anon_sym_SLASH,
    ACTIONS(8872), 1,
      anon_sym_AMP,
    ACTIONS(8876), 1,
      anon_sym_GT_GT,
    ACTIONS(8882), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8884), 1,
      anon_sym_is,
    ACTIONS(8886), 1,
      anon_sym_CARET,
    ACTIONS(8888), 1,
      anon_sym_PIPE,
    ACTIONS(8890), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8892), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8894), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8898), 1,
      anon_sym_QMARK,
    ACTIONS(8984), 1,
      anon_sym_in,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8864), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8866), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8868), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8874), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8878), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8880), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6473), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [208846] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8976), 1,
      anon_sym_and,
    ACTIONS(8978), 1,
      anon_sym_or,
    STATE(6474), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6594), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6592), 23,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_in,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [208932] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(8986), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6475), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [209068] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(7516), 1,
      anon_sym_QMARK,
    ACTIONS(7522), 1,
      anon_sym_SLASH,
    ACTIONS(7524), 1,
      anon_sym_CARET,
    ACTIONS(7526), 1,
      anon_sym_PIPE,
    ACTIONS(7528), 1,
      anon_sym_AMP,
    ACTIONS(7532), 1,
      anon_sym_GT_GT,
    ACTIONS(7538), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7540), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7542), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7544), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8988), 1,
      anon_sym_SEMI,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7514), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7518), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7520), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7530), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7534), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7536), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6476), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [209204] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(7516), 1,
      anon_sym_QMARK,
    ACTIONS(7522), 1,
      anon_sym_SLASH,
    ACTIONS(7524), 1,
      anon_sym_CARET,
    ACTIONS(7526), 1,
      anon_sym_PIPE,
    ACTIONS(7528), 1,
      anon_sym_AMP,
    ACTIONS(7532), 1,
      anon_sym_GT_GT,
    ACTIONS(7538), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7540), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7542), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7544), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8990), 1,
      anon_sym_SEMI,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7514), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7518), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7520), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7530), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7534), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7536), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6477), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [209340] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(7516), 1,
      anon_sym_QMARK,
    ACTIONS(7522), 1,
      anon_sym_SLASH,
    ACTIONS(7524), 1,
      anon_sym_CARET,
    ACTIONS(7526), 1,
      anon_sym_PIPE,
    ACTIONS(7528), 1,
      anon_sym_AMP,
    ACTIONS(7532), 1,
      anon_sym_GT_GT,
    ACTIONS(7538), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7540), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7542), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7544), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8992), 1,
      anon_sym_SEMI,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7514), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7518), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7520), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7530), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7534), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7536), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6478), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [209476] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(7516), 1,
      anon_sym_QMARK,
    ACTIONS(7522), 1,
      anon_sym_SLASH,
    ACTIONS(7524), 1,
      anon_sym_CARET,
    ACTIONS(7526), 1,
      anon_sym_PIPE,
    ACTIONS(7528), 1,
      anon_sym_AMP,
    ACTIONS(7532), 1,
      anon_sym_GT_GT,
    ACTIONS(7538), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7540), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7542), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7544), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8994), 1,
      anon_sym_SEMI,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7514), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7518), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7520), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7530), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7534), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7536), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6479), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [209612] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(8996), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6480), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [209748] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(8998), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6481), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [209884] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(9000), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6482), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [210020] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(9002), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6483), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [210156] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(8914), 1,
      anon_sym_LPAREN,
    ACTIONS(9004), 1,
      anon_sym_operator,
    ACTIONS(9006), 1,
      anon_sym_this,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(7209), 1,
      sym_explicit_interface_specifier,
    STATE(7509), 1,
      sym_identifier,
    STATE(8010), 1,
      sym_tuple_pattern,
    STATE(8392), 1,
      sym_variable_declarator,
    STATE(9517), 1,
      sym__name,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(6484), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [210260] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(9008), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6485), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [210396] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(9010), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6486), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [210532] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(8634), 1,
      anon_sym_QMARK,
    ACTIONS(8640), 1,
      anon_sym_SLASH,
    ACTIONS(8642), 1,
      anon_sym_CARET,
    ACTIONS(8644), 1,
      anon_sym_PIPE,
    ACTIONS(8646), 1,
      anon_sym_AMP,
    ACTIONS(8650), 1,
      anon_sym_GT_GT,
    ACTIONS(8656), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8658), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8660), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8662), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8664), 1,
      anon_sym_is,
    ACTIONS(9012), 1,
      anon_sym_COLON,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8632), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8636), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8638), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8648), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8652), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8654), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6487), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [210668] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8972), 1,
      anon_sym_and,
    ACTIONS(9014), 1,
      anon_sym_or,
    STATE(6488), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5881), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5879), 23,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [210754] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8584), 1,
      anon_sym_QMARK,
    ACTIONS(8590), 1,
      anon_sym_SLASH,
    ACTIONS(8592), 1,
      anon_sym_CARET,
    ACTIONS(8594), 1,
      anon_sym_PIPE,
    ACTIONS(8596), 1,
      anon_sym_AMP,
    ACTIONS(8600), 1,
      anon_sym_GT_GT,
    ACTIONS(8606), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8608), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8610), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8612), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8614), 1,
      anon_sym_as,
    ACTIONS(8616), 1,
      anon_sym_is,
    ACTIONS(9016), 1,
      anon_sym_by,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8586), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8588), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8598), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8602), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8604), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6489), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [210890] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9018), 1,
      anon_sym_into,
    STATE(6495), 1,
      aux_sym__query_body_repeat2,
    STATE(6490), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6482), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6480), 23,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_by,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [210976] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9018), 1,
      anon_sym_into,
    STATE(6496), 1,
      aux_sym__query_body_repeat2,
    STATE(6491), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6482), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6480), 23,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_by,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [211062] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(9020), 1,
      anon_sym_COMMA,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6492), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [211198] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(7516), 1,
      anon_sym_QMARK,
    ACTIONS(7522), 1,
      anon_sym_SLASH,
    ACTIONS(7524), 1,
      anon_sym_CARET,
    ACTIONS(7526), 1,
      anon_sym_PIPE,
    ACTIONS(7528), 1,
      anon_sym_AMP,
    ACTIONS(7532), 1,
      anon_sym_GT_GT,
    ACTIONS(7538), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7540), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7542), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7544), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(9022), 1,
      anon_sym_SEMI,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7514), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7518), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7520), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7530), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7534), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7536), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6493), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [211334] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8972), 1,
      anon_sym_and,
    ACTIONS(9014), 1,
      anon_sym_or,
    STATE(6494), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6594), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6592), 23,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [211420] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9024), 1,
      anon_sym_into,
    STATE(6495), 10,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
      aux_sym__query_body_repeat2,
    ACTIONS(6486), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6484), 23,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_by,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [211504] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9018), 1,
      anon_sym_into,
    STATE(6495), 1,
      aux_sym__query_body_repeat2,
    STATE(6496), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6493), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6491), 23,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_by,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [211590] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(9027), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6497), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [211726] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(7516), 1,
      anon_sym_QMARK,
    ACTIONS(7522), 1,
      anon_sym_SLASH,
    ACTIONS(7524), 1,
      anon_sym_CARET,
    ACTIONS(7526), 1,
      anon_sym_PIPE,
    ACTIONS(7528), 1,
      anon_sym_AMP,
    ACTIONS(7532), 1,
      anon_sym_GT_GT,
    ACTIONS(7538), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7540), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7542), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7544), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(9029), 1,
      anon_sym_SEMI,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7514), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7518), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7520), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7530), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7534), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7536), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6498), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [211862] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(7516), 1,
      anon_sym_QMARK,
    ACTIONS(7522), 1,
      anon_sym_SLASH,
    ACTIONS(7524), 1,
      anon_sym_CARET,
    ACTIONS(7526), 1,
      anon_sym_PIPE,
    ACTIONS(7528), 1,
      anon_sym_AMP,
    ACTIONS(7532), 1,
      anon_sym_GT_GT,
    ACTIONS(7538), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7540), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7542), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7544), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(9031), 1,
      anon_sym_SEMI,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7514), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7518), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7520), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7530), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7534), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7536), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6499), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [211998] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9033), 1,
      anon_sym_RPAREN,
    STATE(6500), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5288), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5286), 24,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [212082] = 29,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8728), 1,
      anon_sym_SLASH,
    ACTIONS(8738), 1,
      anon_sym_GT_GT,
    ACTIONS(8744), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8724), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8726), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8736), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6344), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    STATE(6501), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 11,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_equals,
      anon_sym_as,
      anon_sym_is,
  [212196] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(8634), 1,
      anon_sym_QMARK,
    ACTIONS(8640), 1,
      anon_sym_SLASH,
    ACTIONS(8642), 1,
      anon_sym_CARET,
    ACTIONS(8644), 1,
      anon_sym_PIPE,
    ACTIONS(8646), 1,
      anon_sym_AMP,
    ACTIONS(8650), 1,
      anon_sym_GT_GT,
    ACTIONS(8656), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8658), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8660), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8662), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8664), 1,
      anon_sym_is,
    ACTIONS(9035), 1,
      anon_sym_COLON,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8632), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8636), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8638), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8648), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8652), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8654), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6502), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [212332] = 26,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8728), 1,
      anon_sym_SLASH,
    ACTIONS(8744), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8726), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(6503), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 13,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_equals,
      anon_sym_as,
      anon_sym_is,
  [212440] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8744), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(6504), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 15,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_equals,
      anon_sym_as,
      anon_sym_is,
  [212544] = 35,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8728), 1,
      anon_sym_SLASH,
    ACTIONS(8734), 1,
      anon_sym_AMP,
    ACTIONS(8738), 1,
      anon_sym_GT_GT,
    ACTIONS(8744), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8754), 1,
      anon_sym_as,
    ACTIONS(8756), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(8720), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8724), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8726), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8736), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8740), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8742), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 5,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_equals,
    STATE(6505), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [212670] = 36,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8728), 1,
      anon_sym_SLASH,
    ACTIONS(8730), 1,
      anon_sym_CARET,
    ACTIONS(8734), 1,
      anon_sym_AMP,
    ACTIONS(8738), 1,
      anon_sym_GT_GT,
    ACTIONS(8744), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8754), 1,
      anon_sym_as,
    ACTIONS(8756), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(8720), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8724), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8726), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8736), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8740), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8742), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 4,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_equals,
    STATE(6506), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [212798] = 34,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8728), 1,
      anon_sym_SLASH,
    ACTIONS(8738), 1,
      anon_sym_GT_GT,
    ACTIONS(8744), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8754), 1,
      anon_sym_as,
    ACTIONS(8756), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8720), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8724), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8726), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8736), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8740), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8742), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(6342), 5,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_equals,
    STATE(6507), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [212922] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8728), 1,
      anon_sym_SLASH,
    ACTIONS(8744), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8724), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8726), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(6508), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 13,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_equals,
      anon_sym_as,
      anon_sym_is,
  [213032] = 33,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8728), 1,
      anon_sym_SLASH,
    ACTIONS(8738), 1,
      anon_sym_GT_GT,
    ACTIONS(8744), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8754), 1,
      anon_sym_as,
    ACTIONS(8756), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8720), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8724), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8726), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8736), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8742), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(6342), 7,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_equals,
    STATE(6509), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [213154] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(8744), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6330), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(6510), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6328), 17,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_equals,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [213254] = 37,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8728), 1,
      anon_sym_SLASH,
    ACTIONS(8730), 1,
      anon_sym_CARET,
    ACTIONS(8732), 1,
      anon_sym_PIPE,
    ACTIONS(8734), 1,
      anon_sym_AMP,
    ACTIONS(8738), 1,
      anon_sym_GT_GT,
    ACTIONS(8744), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8754), 1,
      anon_sym_as,
    ACTIONS(8756), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8720), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8724), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8726), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8736), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8740), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8742), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 4,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_equals,
    STATE(6511), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [213384] = 38,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8728), 1,
      anon_sym_SLASH,
    ACTIONS(8730), 1,
      anon_sym_CARET,
    ACTIONS(8732), 1,
      anon_sym_PIPE,
    ACTIONS(8734), 1,
      anon_sym_AMP,
    ACTIONS(8738), 1,
      anon_sym_GT_GT,
    ACTIONS(8744), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8746), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8754), 1,
      anon_sym_as,
    ACTIONS(8756), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8720), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8724), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8726), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8736), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8740), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8742), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 3,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_equals,
    STATE(6512), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [213516] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6342), 1,
      anon_sym_equals,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8728), 1,
      anon_sym_SLASH,
    ACTIONS(8730), 1,
      anon_sym_CARET,
    ACTIONS(8732), 1,
      anon_sym_PIPE,
    ACTIONS(8734), 1,
      anon_sym_AMP,
    ACTIONS(8738), 1,
      anon_sym_GT_GT,
    ACTIONS(8744), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8746), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8748), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8750), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8754), 1,
      anon_sym_as,
    ACTIONS(8756), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8720), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8724), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8726), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8736), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8740), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8742), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6513), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [213652] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(7516), 1,
      anon_sym_QMARK,
    ACTIONS(7522), 1,
      anon_sym_SLASH,
    ACTIONS(7524), 1,
      anon_sym_CARET,
    ACTIONS(7526), 1,
      anon_sym_PIPE,
    ACTIONS(7528), 1,
      anon_sym_AMP,
    ACTIONS(7532), 1,
      anon_sym_GT_GT,
    ACTIONS(7538), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7540), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7542), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7544), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(9037), 1,
      anon_sym_SEMI,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7514), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7518), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7520), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7530), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7534), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7536), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6514), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [213788] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5416), 1,
      anon_sym_equals,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8722), 1,
      anon_sym_QMARK,
    ACTIONS(8728), 1,
      anon_sym_SLASH,
    ACTIONS(8730), 1,
      anon_sym_CARET,
    ACTIONS(8732), 1,
      anon_sym_PIPE,
    ACTIONS(8734), 1,
      anon_sym_AMP,
    ACTIONS(8738), 1,
      anon_sym_GT_GT,
    ACTIONS(8744), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8746), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8748), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8750), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8754), 1,
      anon_sym_as,
    ACTIONS(8756), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8720), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8724), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8726), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8736), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8740), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8742), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6515), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [213924] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5644), 1,
      anon_sym_equals,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8722), 1,
      anon_sym_QMARK,
    ACTIONS(8728), 1,
      anon_sym_SLASH,
    ACTIONS(8730), 1,
      anon_sym_CARET,
    ACTIONS(8732), 1,
      anon_sym_PIPE,
    ACTIONS(8734), 1,
      anon_sym_AMP,
    ACTIONS(8738), 1,
      anon_sym_GT_GT,
    ACTIONS(8744), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8746), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8748), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8750), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8754), 1,
      anon_sym_as,
    ACTIONS(8756), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8720), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8724), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8726), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8736), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8740), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8742), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6516), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [214060] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4361), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6803), 1,
      anon_sym_LT,
    STATE(5001), 1,
      sym_type_argument_list,
    ACTIONS(4140), 6,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_QMARK,
      anon_sym_STAR,
      anon_sym_DOT,
    STATE(6517), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4138), 27,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_COLON,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      sym_discard,
      anon_sym_and,
      anon_sym_or,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [214148] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5424), 1,
      anon_sym_equals,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8722), 1,
      anon_sym_QMARK,
    ACTIONS(8728), 1,
      anon_sym_SLASH,
    ACTIONS(8730), 1,
      anon_sym_CARET,
    ACTIONS(8732), 1,
      anon_sym_PIPE,
    ACTIONS(8734), 1,
      anon_sym_AMP,
    ACTIONS(8738), 1,
      anon_sym_GT_GT,
    ACTIONS(8744), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8746), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8748), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8750), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8754), 1,
      anon_sym_as,
    ACTIONS(8756), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8720), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8724), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8726), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8736), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8740), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8742), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6518), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [214284] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6190), 1,
      anon_sym_COLON,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(8634), 1,
      anon_sym_QMARK,
    ACTIONS(8640), 1,
      anon_sym_SLASH,
    ACTIONS(8642), 1,
      anon_sym_CARET,
    ACTIONS(8644), 1,
      anon_sym_PIPE,
    ACTIONS(8646), 1,
      anon_sym_AMP,
    ACTIONS(8650), 1,
      anon_sym_GT_GT,
    ACTIONS(8656), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8658), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8660), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8662), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8664), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8632), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8636), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8638), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8648), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8652), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8654), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6519), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [214420] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6336), 1,
      anon_sym_equals,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8722), 1,
      anon_sym_QMARK,
    ACTIONS(8728), 1,
      anon_sym_SLASH,
    ACTIONS(8730), 1,
      anon_sym_CARET,
    ACTIONS(8732), 1,
      anon_sym_PIPE,
    ACTIONS(8734), 1,
      anon_sym_AMP,
    ACTIONS(8738), 1,
      anon_sym_GT_GT,
    ACTIONS(8744), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8746), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8748), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8750), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8754), 1,
      anon_sym_as,
    ACTIONS(8756), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8720), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8724), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8726), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8736), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8740), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8742), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6520), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [214556] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(8656), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1229), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(6521), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(1227), 17,
      anon_sym_COLON,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [214656] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(8634), 1,
      anon_sym_QMARK,
    ACTIONS(8640), 1,
      anon_sym_SLASH,
    ACTIONS(8642), 1,
      anon_sym_CARET,
    ACTIONS(8644), 1,
      anon_sym_PIPE,
    ACTIONS(8646), 1,
      anon_sym_AMP,
    ACTIONS(8650), 1,
      anon_sym_GT_GT,
    ACTIONS(8656), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8658), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8660), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8662), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8664), 1,
      anon_sym_is,
    ACTIONS(9039), 1,
      anon_sym_COLON,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8632), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8636), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8638), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8648), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8652), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8654), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6522), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [214792] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8960), 1,
      anon_sym_and,
    ACTIONS(9041), 1,
      anon_sym_or,
    STATE(6523), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5881), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5879), 23,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_by,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [214878] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8584), 1,
      anon_sym_QMARK,
    ACTIONS(8590), 1,
      anon_sym_SLASH,
    ACTIONS(8592), 1,
      anon_sym_CARET,
    ACTIONS(8594), 1,
      anon_sym_PIPE,
    ACTIONS(8596), 1,
      anon_sym_AMP,
    ACTIONS(8600), 1,
      anon_sym_GT_GT,
    ACTIONS(8606), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8608), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8610), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8612), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8614), 1,
      anon_sym_as,
    ACTIONS(8616), 1,
      anon_sym_is,
    ACTIONS(9043), 1,
      anon_sym_by,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8586), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8588), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8598), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8602), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8604), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6524), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [215014] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5572), 1,
      anon_sym_equals,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8722), 1,
      anon_sym_QMARK,
    ACTIONS(8728), 1,
      anon_sym_SLASH,
    ACTIONS(8730), 1,
      anon_sym_CARET,
    ACTIONS(8732), 1,
      anon_sym_PIPE,
    ACTIONS(8734), 1,
      anon_sym_AMP,
    ACTIONS(8738), 1,
      anon_sym_GT_GT,
    ACTIONS(8744), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8746), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8748), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8750), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8754), 1,
      anon_sym_as,
    ACTIONS(8756), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8720), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8724), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8726), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8736), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8740), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8742), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6525), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [215150] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5584), 1,
      anon_sym_equals,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8722), 1,
      anon_sym_QMARK,
    ACTIONS(8728), 1,
      anon_sym_SLASH,
    ACTIONS(8730), 1,
      anon_sym_CARET,
    ACTIONS(8732), 1,
      anon_sym_PIPE,
    ACTIONS(8734), 1,
      anon_sym_AMP,
    ACTIONS(8738), 1,
      anon_sym_GT_GT,
    ACTIONS(8744), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8746), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8748), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8750), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8754), 1,
      anon_sym_as,
    ACTIONS(8756), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8720), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8724), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8726), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8736), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8740), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8742), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6526), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [215286] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5624), 1,
      anon_sym_equals,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8722), 1,
      anon_sym_QMARK,
    ACTIONS(8728), 1,
      anon_sym_SLASH,
    ACTIONS(8730), 1,
      anon_sym_CARET,
    ACTIONS(8732), 1,
      anon_sym_PIPE,
    ACTIONS(8734), 1,
      anon_sym_AMP,
    ACTIONS(8738), 1,
      anon_sym_GT_GT,
    ACTIONS(8744), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8746), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8748), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8750), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8754), 1,
      anon_sym_as,
    ACTIONS(8756), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8720), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8724), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8726), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8736), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8740), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8742), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6527), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [215422] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8960), 1,
      anon_sym_and,
    ACTIONS(9041), 1,
      anon_sym_or,
    STATE(6528), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6594), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6592), 23,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_by,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [215508] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(2025), 1,
      anon_sym_SEMI,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(7516), 1,
      anon_sym_QMARK,
    ACTIONS(7522), 1,
      anon_sym_SLASH,
    ACTIONS(7524), 1,
      anon_sym_CARET,
    ACTIONS(7526), 1,
      anon_sym_PIPE,
    ACTIONS(7528), 1,
      anon_sym_AMP,
    ACTIONS(7532), 1,
      anon_sym_GT_GT,
    ACTIONS(7538), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7540), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7542), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7544), 1,
      anon_sym_QMARK_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7514), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7518), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7520), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7530), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7534), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7536), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6529), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [215644] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(2069), 1,
      anon_sym_SEMI,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(7516), 1,
      anon_sym_QMARK,
    ACTIONS(7522), 1,
      anon_sym_SLASH,
    ACTIONS(7524), 1,
      anon_sym_CARET,
    ACTIONS(7526), 1,
      anon_sym_PIPE,
    ACTIONS(7528), 1,
      anon_sym_AMP,
    ACTIONS(7532), 1,
      anon_sym_GT_GT,
    ACTIONS(7538), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7540), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7542), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7544), 1,
      anon_sym_QMARK_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7514), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7518), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7520), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7530), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7534), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7536), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6530), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [215780] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6190), 1,
      anon_sym_by,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8584), 1,
      anon_sym_QMARK,
    ACTIONS(8590), 1,
      anon_sym_SLASH,
    ACTIONS(8592), 1,
      anon_sym_CARET,
    ACTIONS(8594), 1,
      anon_sym_PIPE,
    ACTIONS(8596), 1,
      anon_sym_AMP,
    ACTIONS(8600), 1,
      anon_sym_GT_GT,
    ACTIONS(8606), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8608), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8610), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8612), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8614), 1,
      anon_sym_as,
    ACTIONS(8616), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8586), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8588), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8598), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8602), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8604), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6531), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [215916] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(8606), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1229), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(6532), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(1227), 17,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_by,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [216016] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(8634), 1,
      anon_sym_QMARK,
    ACTIONS(8640), 1,
      anon_sym_SLASH,
    ACTIONS(8642), 1,
      anon_sym_CARET,
    ACTIONS(8644), 1,
      anon_sym_PIPE,
    ACTIONS(8646), 1,
      anon_sym_AMP,
    ACTIONS(8650), 1,
      anon_sym_GT_GT,
    ACTIONS(8656), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8658), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8660), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8662), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8664), 1,
      anon_sym_is,
    ACTIONS(9045), 1,
      anon_sym_COLON,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8632), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8636), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8638), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8648), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8652), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8654), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6533), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [216152] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9047), 1,
      anon_sym_RPAREN,
    STATE(6534), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5288), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5286), 24,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [216236] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8584), 1,
      anon_sym_QMARK,
    ACTIONS(8590), 1,
      anon_sym_SLASH,
    ACTIONS(8592), 1,
      anon_sym_CARET,
    ACTIONS(8594), 1,
      anon_sym_PIPE,
    ACTIONS(8596), 1,
      anon_sym_AMP,
    ACTIONS(8600), 1,
      anon_sym_GT_GT,
    ACTIONS(8606), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8608), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8610), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8612), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8614), 1,
      anon_sym_as,
    ACTIONS(8616), 1,
      anon_sym_is,
    ACTIONS(9049), 1,
      anon_sym_by,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8586), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8588), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8598), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8602), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8604), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6535), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [216372] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(9051), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6536), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [216508] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(9053), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6537), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [216644] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(7516), 1,
      anon_sym_QMARK,
    ACTIONS(7522), 1,
      anon_sym_SLASH,
    ACTIONS(7524), 1,
      anon_sym_CARET,
    ACTIONS(7526), 1,
      anon_sym_PIPE,
    ACTIONS(7528), 1,
      anon_sym_AMP,
    ACTIONS(7532), 1,
      anon_sym_GT_GT,
    ACTIONS(7538), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7540), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7542), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7544), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(9055), 1,
      anon_sym_SEMI,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7514), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7518), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7520), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7530), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7534), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7536), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6538), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [216780] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(9057), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6539), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [216916] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6320), 1,
      anon_sym_by,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8584), 1,
      anon_sym_QMARK,
    ACTIONS(8590), 1,
      anon_sym_SLASH,
    ACTIONS(8592), 1,
      anon_sym_CARET,
    ACTIONS(8594), 1,
      anon_sym_PIPE,
    ACTIONS(8596), 1,
      anon_sym_AMP,
    ACTIONS(8600), 1,
      anon_sym_GT_GT,
    ACTIONS(8606), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8608), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8610), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8612), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8614), 1,
      anon_sym_as,
    ACTIONS(8616), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8586), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8588), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8598), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8602), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8604), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6540), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [217052] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(8634), 1,
      anon_sym_QMARK,
    ACTIONS(8640), 1,
      anon_sym_SLASH,
    ACTIONS(8642), 1,
      anon_sym_CARET,
    ACTIONS(8644), 1,
      anon_sym_PIPE,
    ACTIONS(8646), 1,
      anon_sym_AMP,
    ACTIONS(8650), 1,
      anon_sym_GT_GT,
    ACTIONS(8656), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8658), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8660), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8662), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8664), 1,
      anon_sym_is,
    ACTIONS(9059), 1,
      anon_sym_COLON,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8632), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8636), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8638), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8648), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8652), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8654), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6541), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [217188] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8688), 1,
      anon_sym_and,
    ACTIONS(9061), 1,
      anon_sym_or,
    STATE(6542), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5881), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5879), 23,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_equals,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [217274] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8584), 1,
      anon_sym_QMARK,
    ACTIONS(8590), 1,
      anon_sym_SLASH,
    ACTIONS(8592), 1,
      anon_sym_CARET,
    ACTIONS(8594), 1,
      anon_sym_PIPE,
    ACTIONS(8596), 1,
      anon_sym_AMP,
    ACTIONS(8600), 1,
      anon_sym_GT_GT,
    ACTIONS(8606), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8608), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8610), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8612), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8614), 1,
      anon_sym_as,
    ACTIONS(8616), 1,
      anon_sym_is,
    ACTIONS(9063), 1,
      anon_sym_by,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8586), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8588), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8598), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8602), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8604), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6543), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [217410] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8688), 1,
      anon_sym_and,
    ACTIONS(9061), 1,
      anon_sym_or,
    STATE(6544), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6594), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6592), 23,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_equals,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [217496] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(9065), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6545), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [217632] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(7516), 1,
      anon_sym_QMARK,
    ACTIONS(7522), 1,
      anon_sym_SLASH,
    ACTIONS(7524), 1,
      anon_sym_CARET,
    ACTIONS(7526), 1,
      anon_sym_PIPE,
    ACTIONS(7528), 1,
      anon_sym_AMP,
    ACTIONS(7532), 1,
      anon_sym_GT_GT,
    ACTIONS(7538), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7540), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7542), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7544), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(9067), 1,
      anon_sym_SEMI,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7514), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7518), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7520), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7530), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7534), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7536), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6546), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [217768] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6190), 1,
      anon_sym_equals,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8722), 1,
      anon_sym_QMARK,
    ACTIONS(8728), 1,
      anon_sym_SLASH,
    ACTIONS(8730), 1,
      anon_sym_CARET,
    ACTIONS(8732), 1,
      anon_sym_PIPE,
    ACTIONS(8734), 1,
      anon_sym_AMP,
    ACTIONS(8738), 1,
      anon_sym_GT_GT,
    ACTIONS(8744), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8746), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8748), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8750), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8754), 1,
      anon_sym_as,
    ACTIONS(8756), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8720), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8724), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8726), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8736), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8740), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8742), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6547), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [217904] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(8744), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1229), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(6548), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(1227), 17,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_equals,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [218004] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(8634), 1,
      anon_sym_QMARK,
    ACTIONS(8640), 1,
      anon_sym_SLASH,
    ACTIONS(8642), 1,
      anon_sym_CARET,
    ACTIONS(8644), 1,
      anon_sym_PIPE,
    ACTIONS(8646), 1,
      anon_sym_AMP,
    ACTIONS(8650), 1,
      anon_sym_GT_GT,
    ACTIONS(8656), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8658), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8660), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8662), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8664), 1,
      anon_sym_is,
    ACTIONS(9069), 1,
      anon_sym_COLON,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8632), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8636), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8638), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8648), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8652), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8654), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6549), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [218140] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8930), 1,
      anon_sym_and,
    ACTIONS(9071), 1,
      anon_sym_or,
    STATE(6550), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5881), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5879), 23,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_on,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [218226] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8584), 1,
      anon_sym_QMARK,
    ACTIONS(8590), 1,
      anon_sym_SLASH,
    ACTIONS(8592), 1,
      anon_sym_CARET,
    ACTIONS(8594), 1,
      anon_sym_PIPE,
    ACTIONS(8596), 1,
      anon_sym_AMP,
    ACTIONS(8600), 1,
      anon_sym_GT_GT,
    ACTIONS(8606), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8608), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8610), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8612), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8614), 1,
      anon_sym_as,
    ACTIONS(8616), 1,
      anon_sym_is,
    ACTIONS(9073), 1,
      anon_sym_by,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8586), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8588), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8598), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8602), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8604), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6551), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [218362] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8930), 1,
      anon_sym_and,
    ACTIONS(9071), 1,
      anon_sym_or,
    STATE(6552), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6594), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6592), 23,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_on,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [218448] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(9075), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6553), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [218584] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6190), 1,
      anon_sym_on,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8816), 1,
      anon_sym_QMARK,
    ACTIONS(8822), 1,
      anon_sym_SLASH,
    ACTIONS(8824), 1,
      anon_sym_CARET,
    ACTIONS(8826), 1,
      anon_sym_PIPE,
    ACTIONS(8828), 1,
      anon_sym_AMP,
    ACTIONS(8832), 1,
      anon_sym_GT_GT,
    ACTIONS(8838), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8840), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8842), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8844), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8848), 1,
      anon_sym_as,
    ACTIONS(8850), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8814), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8818), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8820), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8830), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8834), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8836), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6554), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [218720] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(8838), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1229), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(6555), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(1227), 17,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_on,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [218820] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(8634), 1,
      anon_sym_QMARK,
    ACTIONS(8640), 1,
      anon_sym_SLASH,
    ACTIONS(8642), 1,
      anon_sym_CARET,
    ACTIONS(8644), 1,
      anon_sym_PIPE,
    ACTIONS(8646), 1,
      anon_sym_AMP,
    ACTIONS(8650), 1,
      anon_sym_GT_GT,
    ACTIONS(8656), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8658), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8660), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8662), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8664), 1,
      anon_sym_is,
    ACTIONS(9077), 1,
      anon_sym_COLON,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8632), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8636), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8638), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8648), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8652), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8654), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6556), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [218956] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8584), 1,
      anon_sym_QMARK,
    ACTIONS(8590), 1,
      anon_sym_SLASH,
    ACTIONS(8592), 1,
      anon_sym_CARET,
    ACTIONS(8594), 1,
      anon_sym_PIPE,
    ACTIONS(8596), 1,
      anon_sym_AMP,
    ACTIONS(8600), 1,
      anon_sym_GT_GT,
    ACTIONS(8606), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8608), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8610), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8612), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8614), 1,
      anon_sym_as,
    ACTIONS(8616), 1,
      anon_sym_is,
    ACTIONS(9079), 1,
      anon_sym_by,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8586), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8588), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8598), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8602), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8604), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6557), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [219092] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(9081), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6558), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [219228] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(7516), 1,
      anon_sym_QMARK,
    ACTIONS(7522), 1,
      anon_sym_SLASH,
    ACTIONS(7524), 1,
      anon_sym_CARET,
    ACTIONS(7526), 1,
      anon_sym_PIPE,
    ACTIONS(7528), 1,
      anon_sym_AMP,
    ACTIONS(7532), 1,
      anon_sym_GT_GT,
    ACTIONS(7538), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7540), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7542), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7544), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(9083), 1,
      anon_sym_SEMI,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7514), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7518), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7520), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7530), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7534), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7536), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6559), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [219364] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6190), 1,
      anon_sym_EQ_GT,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(8622), 1,
      anon_sym_SLASH,
    ACTIONS(8626), 1,
      anon_sym_GT_GT,
    ACTIONS(8628), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8668), 1,
      anon_sym_AMP,
    ACTIONS(8674), 1,
      anon_sym_is,
    ACTIONS(8676), 1,
      anon_sym_CARET,
    ACTIONS(8678), 1,
      anon_sym_PIPE,
    ACTIONS(8680), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8682), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8684), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8686), 1,
      anon_sym_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8618), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8620), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8624), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8666), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8670), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8672), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6560), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [219500] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(8628), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1229), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(6561), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(1227), 17,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_GT,
      anon_sym_switch,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [219600] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(8634), 1,
      anon_sym_QMARK,
    ACTIONS(8640), 1,
      anon_sym_SLASH,
    ACTIONS(8642), 1,
      anon_sym_CARET,
    ACTIONS(8644), 1,
      anon_sym_PIPE,
    ACTIONS(8646), 1,
      anon_sym_AMP,
    ACTIONS(8650), 1,
      anon_sym_GT_GT,
    ACTIONS(8656), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8658), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8660), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8662), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8664), 1,
      anon_sym_is,
    ACTIONS(9085), 1,
      anon_sym_COLON,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8632), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8636), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8638), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8648), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8652), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8654), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6562), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [219736] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8584), 1,
      anon_sym_QMARK,
    ACTIONS(8590), 1,
      anon_sym_SLASH,
    ACTIONS(8592), 1,
      anon_sym_CARET,
    ACTIONS(8594), 1,
      anon_sym_PIPE,
    ACTIONS(8596), 1,
      anon_sym_AMP,
    ACTIONS(8600), 1,
      anon_sym_GT_GT,
    ACTIONS(8606), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8608), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8610), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8612), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8614), 1,
      anon_sym_as,
    ACTIONS(8616), 1,
      anon_sym_is,
    ACTIONS(9087), 1,
      anon_sym_by,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8586), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8588), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8598), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8602), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8604), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6563), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [219872] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(7516), 1,
      anon_sym_QMARK,
    ACTIONS(7522), 1,
      anon_sym_SLASH,
    ACTIONS(7524), 1,
      anon_sym_CARET,
    ACTIONS(7526), 1,
      anon_sym_PIPE,
    ACTIONS(7528), 1,
      anon_sym_AMP,
    ACTIONS(7532), 1,
      anon_sym_GT_GT,
    ACTIONS(7538), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7540), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7542), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7544), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(9089), 1,
      anon_sym_SEMI,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7514), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7518), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7520), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7530), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7534), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7536), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6564), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [220008] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(9091), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6565), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [220144] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(7706), 1,
      anon_sym_SLASH,
    ACTIONS(7710), 1,
      anon_sym_GT_GT,
    ACTIONS(7716), 1,
      anon_sym_AMP,
    ACTIONS(7724), 1,
      anon_sym_CARET,
    ACTIONS(7726), 1,
      anon_sym_PIPE,
    ACTIONS(7728), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7730), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7732), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8634), 1,
      anon_sym_QMARK,
    ACTIONS(8656), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8664), 1,
      anon_sym_is,
    ACTIONS(9093), 1,
      anon_sym_COLON,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7702), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7704), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7708), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7714), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7718), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7720), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6566), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [220280] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8584), 1,
      anon_sym_QMARK,
    ACTIONS(8590), 1,
      anon_sym_SLASH,
    ACTIONS(8592), 1,
      anon_sym_CARET,
    ACTIONS(8594), 1,
      anon_sym_PIPE,
    ACTIONS(8596), 1,
      anon_sym_AMP,
    ACTIONS(8600), 1,
      anon_sym_GT_GT,
    ACTIONS(8606), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8608), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8610), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8612), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8614), 1,
      anon_sym_as,
    ACTIONS(8616), 1,
      anon_sym_is,
    ACTIONS(9095), 1,
      anon_sym_by,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8586), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8588), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8598), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8602), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8604), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6567), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [220416] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8584), 1,
      anon_sym_QMARK,
    ACTIONS(8590), 1,
      anon_sym_SLASH,
    ACTIONS(8592), 1,
      anon_sym_CARET,
    ACTIONS(8594), 1,
      anon_sym_PIPE,
    ACTIONS(8596), 1,
      anon_sym_AMP,
    ACTIONS(8600), 1,
      anon_sym_GT_GT,
    ACTIONS(8606), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8608), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8610), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8612), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8614), 1,
      anon_sym_as,
    ACTIONS(8616), 1,
      anon_sym_is,
    ACTIONS(9097), 1,
      anon_sym_by,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8586), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8588), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8598), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8602), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8604), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6568), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [220552] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8584), 1,
      anon_sym_QMARK,
    ACTIONS(8590), 1,
      anon_sym_SLASH,
    ACTIONS(8592), 1,
      anon_sym_CARET,
    ACTIONS(8594), 1,
      anon_sym_PIPE,
    ACTIONS(8596), 1,
      anon_sym_AMP,
    ACTIONS(8600), 1,
      anon_sym_GT_GT,
    ACTIONS(8606), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8608), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8610), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8612), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8614), 1,
      anon_sym_as,
    ACTIONS(8616), 1,
      anon_sym_is,
    ACTIONS(9099), 1,
      anon_sym_by,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8586), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8588), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8598), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8602), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8604), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6569), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [220688] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8584), 1,
      anon_sym_QMARK,
    ACTIONS(8590), 1,
      anon_sym_SLASH,
    ACTIONS(8592), 1,
      anon_sym_CARET,
    ACTIONS(8594), 1,
      anon_sym_PIPE,
    ACTIONS(8596), 1,
      anon_sym_AMP,
    ACTIONS(8600), 1,
      anon_sym_GT_GT,
    ACTIONS(8606), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8608), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8610), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8612), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8614), 1,
      anon_sym_as,
    ACTIONS(8616), 1,
      anon_sym_is,
    ACTIONS(9101), 1,
      anon_sym_by,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8586), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8588), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8598), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8602), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8604), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6570), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [220824] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8584), 1,
      anon_sym_QMARK,
    ACTIONS(8590), 1,
      anon_sym_SLASH,
    ACTIONS(8592), 1,
      anon_sym_CARET,
    ACTIONS(8594), 1,
      anon_sym_PIPE,
    ACTIONS(8596), 1,
      anon_sym_AMP,
    ACTIONS(8600), 1,
      anon_sym_GT_GT,
    ACTIONS(8606), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8608), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8610), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8612), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8614), 1,
      anon_sym_as,
    ACTIONS(8616), 1,
      anon_sym_is,
    ACTIONS(9103), 1,
      anon_sym_by,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8586), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8588), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8598), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8602), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8604), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6571), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [220960] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(9105), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6572), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [221096] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8584), 1,
      anon_sym_QMARK,
    ACTIONS(8590), 1,
      anon_sym_SLASH,
    ACTIONS(8592), 1,
      anon_sym_CARET,
    ACTIONS(8594), 1,
      anon_sym_PIPE,
    ACTIONS(8596), 1,
      anon_sym_AMP,
    ACTIONS(8600), 1,
      anon_sym_GT_GT,
    ACTIONS(8606), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8608), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8610), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8612), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8614), 1,
      anon_sym_as,
    ACTIONS(8616), 1,
      anon_sym_is,
    ACTIONS(9107), 1,
      anon_sym_by,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8586), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8588), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8598), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8602), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8604), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6573), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [221232] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(7516), 1,
      anon_sym_QMARK,
    ACTIONS(7522), 1,
      anon_sym_SLASH,
    ACTIONS(7524), 1,
      anon_sym_CARET,
    ACTIONS(7526), 1,
      anon_sym_PIPE,
    ACTIONS(7528), 1,
      anon_sym_AMP,
    ACTIONS(7532), 1,
      anon_sym_GT_GT,
    ACTIONS(7538), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7540), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7542), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7544), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(9109), 1,
      anon_sym_SEMI,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7514), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7518), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7520), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7530), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7534), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7536), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6574), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [221368] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(9111), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6575), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [221504] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(9113), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6576), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [221640] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8584), 1,
      anon_sym_QMARK,
    ACTIONS(8590), 1,
      anon_sym_SLASH,
    ACTIONS(8592), 1,
      anon_sym_CARET,
    ACTIONS(8594), 1,
      anon_sym_PIPE,
    ACTIONS(8596), 1,
      anon_sym_AMP,
    ACTIONS(8600), 1,
      anon_sym_GT_GT,
    ACTIONS(8606), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8608), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8610), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8612), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8614), 1,
      anon_sym_as,
    ACTIONS(8616), 1,
      anon_sym_is,
    ACTIONS(9115), 1,
      anon_sym_by,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8586), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8588), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8598), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8602), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8604), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6577), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [221776] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(8634), 1,
      anon_sym_QMARK,
    ACTIONS(8640), 1,
      anon_sym_SLASH,
    ACTIONS(8642), 1,
      anon_sym_CARET,
    ACTIONS(8644), 1,
      anon_sym_PIPE,
    ACTIONS(8646), 1,
      anon_sym_AMP,
    ACTIONS(8650), 1,
      anon_sym_GT_GT,
    ACTIONS(8656), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8658), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8660), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8662), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8664), 1,
      anon_sym_is,
    ACTIONS(9117), 1,
      anon_sym_COLON,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8632), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8636), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8638), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8648), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8652), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8654), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6578), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [221912] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(8622), 1,
      anon_sym_SLASH,
    ACTIONS(8626), 1,
      anon_sym_GT_GT,
    ACTIONS(8628), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8668), 1,
      anon_sym_AMP,
    ACTIONS(8674), 1,
      anon_sym_is,
    ACTIONS(8676), 1,
      anon_sym_CARET,
    ACTIONS(8678), 1,
      anon_sym_PIPE,
    ACTIONS(8680), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8682), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8684), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8686), 1,
      anon_sym_QMARK,
    ACTIONS(8942), 1,
      anon_sym_EQ_GT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8618), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8620), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8624), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8666), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8670), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8672), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6579), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [222048] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4088), 4,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
    ACTIONS(3993), 6,
      anon_sym_LBRACK,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_STAR,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
    STATE(6580), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4091), 26,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      sym_discard,
      anon_sym_and,
      anon_sym_or,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [222132] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8578), 1,
      anon_sym_and,
    STATE(6581), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6707), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6705), 24,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_GT,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [222216] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(8914), 1,
      anon_sym_LPAREN,
    ACTIONS(9119), 1,
      anon_sym_operator,
    ACTIONS(9121), 1,
      anon_sym_this,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(7281), 1,
      sym_explicit_interface_specifier,
    STATE(7511), 1,
      sym_identifier,
    STATE(8010), 1,
      sym_tuple_pattern,
    STATE(8392), 1,
      sym_variable_declarator,
    STATE(9517), 1,
      sym__name,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(6582), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [222320] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9123), 1,
      anon_sym_RPAREN,
    STATE(6583), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5288), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5286), 24,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [222404] = 29,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8822), 1,
      anon_sym_SLASH,
    ACTIONS(8832), 1,
      anon_sym_GT_GT,
    ACTIONS(8838), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8818), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8820), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8830), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6344), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    STATE(6584), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 11,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_on,
      anon_sym_as,
      anon_sym_is,
  [222518] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(7516), 1,
      anon_sym_QMARK,
    ACTIONS(7522), 1,
      anon_sym_SLASH,
    ACTIONS(7524), 1,
      anon_sym_CARET,
    ACTIONS(7526), 1,
      anon_sym_PIPE,
    ACTIONS(7528), 1,
      anon_sym_AMP,
    ACTIONS(7532), 1,
      anon_sym_GT_GT,
    ACTIONS(7538), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7540), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7542), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7544), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(9125), 1,
      anon_sym_SEMI,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7514), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7518), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7520), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7530), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7534), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7536), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6585), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [222654] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(7516), 1,
      anon_sym_QMARK,
    ACTIONS(7522), 1,
      anon_sym_SLASH,
    ACTIONS(7524), 1,
      anon_sym_CARET,
    ACTIONS(7526), 1,
      anon_sym_PIPE,
    ACTIONS(7528), 1,
      anon_sym_AMP,
    ACTIONS(7532), 1,
      anon_sym_GT_GT,
    ACTIONS(7538), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7540), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7542), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7544), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(9127), 1,
      anon_sym_SEMI,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7514), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7518), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7520), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7530), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7534), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7536), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6586), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [222790] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(2033), 1,
      anon_sym_SEMI,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(7516), 1,
      anon_sym_QMARK,
    ACTIONS(7522), 1,
      anon_sym_SLASH,
    ACTIONS(7524), 1,
      anon_sym_CARET,
    ACTIONS(7526), 1,
      anon_sym_PIPE,
    ACTIONS(7528), 1,
      anon_sym_AMP,
    ACTIONS(7532), 1,
      anon_sym_GT_GT,
    ACTIONS(7538), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7540), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7542), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7544), 1,
      anon_sym_QMARK_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7514), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7518), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7520), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7530), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7534), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7536), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6587), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [222926] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(8634), 1,
      anon_sym_QMARK,
    ACTIONS(8640), 1,
      anon_sym_SLASH,
    ACTIONS(8642), 1,
      anon_sym_CARET,
    ACTIONS(8644), 1,
      anon_sym_PIPE,
    ACTIONS(8646), 1,
      anon_sym_AMP,
    ACTIONS(8650), 1,
      anon_sym_GT_GT,
    ACTIONS(8656), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8658), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8660), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8662), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8664), 1,
      anon_sym_is,
    ACTIONS(9129), 1,
      anon_sym_COLON,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8632), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8636), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8638), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8648), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8652), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8654), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6588), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [223062] = 26,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8822), 1,
      anon_sym_SLASH,
    ACTIONS(8838), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8820), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(6589), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 13,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_on,
      anon_sym_as,
      anon_sym_is,
  [223170] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6190), 1,
      anon_sym_in,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(8870), 1,
      anon_sym_SLASH,
    ACTIONS(8872), 1,
      anon_sym_AMP,
    ACTIONS(8876), 1,
      anon_sym_GT_GT,
    ACTIONS(8882), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8884), 1,
      anon_sym_is,
    ACTIONS(8886), 1,
      anon_sym_CARET,
    ACTIONS(8888), 1,
      anon_sym_PIPE,
    ACTIONS(8890), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8892), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8894), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8898), 1,
      anon_sym_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8864), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8866), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8868), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8874), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8878), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8880), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6590), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [223306] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8838), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(6591), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 15,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_on,
      anon_sym_as,
      anon_sym_is,
  [223410] = 35,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8822), 1,
      anon_sym_SLASH,
    ACTIONS(8828), 1,
      anon_sym_AMP,
    ACTIONS(8832), 1,
      anon_sym_GT_GT,
    ACTIONS(8838), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8848), 1,
      anon_sym_as,
    ACTIONS(8850), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(8814), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8818), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8820), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8830), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8834), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8836), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 5,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_on,
    STATE(6592), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [223536] = 36,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8822), 1,
      anon_sym_SLASH,
    ACTIONS(8824), 1,
      anon_sym_CARET,
    ACTIONS(8828), 1,
      anon_sym_AMP,
    ACTIONS(8832), 1,
      anon_sym_GT_GT,
    ACTIONS(8838), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8848), 1,
      anon_sym_as,
    ACTIONS(8850), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(8814), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8818), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8820), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8830), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8834), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8836), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 4,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_on,
    STATE(6593), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [223664] = 34,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8822), 1,
      anon_sym_SLASH,
    ACTIONS(8832), 1,
      anon_sym_GT_GT,
    ACTIONS(8838), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8848), 1,
      anon_sym_as,
    ACTIONS(8850), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8814), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8818), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8820), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8830), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8834), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8836), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(6342), 5,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_on,
    STATE(6594), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [223788] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(8870), 1,
      anon_sym_SLASH,
    ACTIONS(8872), 1,
      anon_sym_AMP,
    ACTIONS(8876), 1,
      anon_sym_GT_GT,
    ACTIONS(8882), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8884), 1,
      anon_sym_is,
    ACTIONS(8886), 1,
      anon_sym_CARET,
    ACTIONS(8888), 1,
      anon_sym_PIPE,
    ACTIONS(8890), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8892), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8894), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8898), 1,
      anon_sym_QMARK,
    ACTIONS(9131), 1,
      anon_sym_in,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8864), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8866), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8868), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8874), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8878), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8880), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6595), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [223924] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(9133), 1,
      anon_sym_COMMA,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6596), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [224060] = 29,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8870), 1,
      anon_sym_SLASH,
    ACTIONS(8876), 1,
      anon_sym_GT_GT,
    ACTIONS(8882), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8866), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8868), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8874), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6344), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    STATE(6597), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 11,
      anon_sym_in,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
  [224174] = 26,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8870), 1,
      anon_sym_SLASH,
    ACTIONS(8882), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8868), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(6598), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 13,
      anon_sym_in,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
  [224282] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8882), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(6599), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 15,
      anon_sym_in,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
  [224386] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8870), 1,
      anon_sym_SLASH,
    ACTIONS(8882), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8866), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8868), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(6600), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 13,
      anon_sym_in,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
  [224496] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(8882), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6330), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(6601), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6328), 17,
      anon_sym_in,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [224596] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(9135), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6602), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [224732] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(8870), 1,
      anon_sym_SLASH,
    ACTIONS(8872), 1,
      anon_sym_AMP,
    ACTIONS(8876), 1,
      anon_sym_GT_GT,
    ACTIONS(8882), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8884), 1,
      anon_sym_is,
    ACTIONS(8886), 1,
      anon_sym_CARET,
    ACTIONS(8888), 1,
      anon_sym_PIPE,
    ACTIONS(8890), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8892), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8894), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8898), 1,
      anon_sym_QMARK,
    ACTIONS(9137), 1,
      anon_sym_in,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8864), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8866), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8868), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8874), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8878), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8880), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6603), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [224868] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8822), 1,
      anon_sym_SLASH,
    ACTIONS(8838), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8818), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8820), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(6604), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 13,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_on,
      anon_sym_as,
      anon_sym_is,
  [224978] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6320), 1,
      anon_sym_COLON,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(8634), 1,
      anon_sym_QMARK,
    ACTIONS(8640), 1,
      anon_sym_SLASH,
    ACTIONS(8642), 1,
      anon_sym_CARET,
    ACTIONS(8644), 1,
      anon_sym_PIPE,
    ACTIONS(8646), 1,
      anon_sym_AMP,
    ACTIONS(8650), 1,
      anon_sym_GT_GT,
    ACTIONS(8656), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8658), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8660), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8662), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8664), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8632), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8636), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8638), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8648), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8652), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8654), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6605), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [225114] = 33,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8822), 1,
      anon_sym_SLASH,
    ACTIONS(8832), 1,
      anon_sym_GT_GT,
    ACTIONS(8838), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8848), 1,
      anon_sym_as,
    ACTIONS(8850), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8814), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8818), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8820), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8830), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8836), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(6342), 7,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_on,
    STATE(6606), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [225236] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(8838), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6330), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(6607), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6328), 17,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_on,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [225336] = 37,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8822), 1,
      anon_sym_SLASH,
    ACTIONS(8824), 1,
      anon_sym_CARET,
    ACTIONS(8826), 1,
      anon_sym_PIPE,
    ACTIONS(8828), 1,
      anon_sym_AMP,
    ACTIONS(8832), 1,
      anon_sym_GT_GT,
    ACTIONS(8838), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8848), 1,
      anon_sym_as,
    ACTIONS(8850), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8814), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8818), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8820), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8830), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8834), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8836), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 4,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_on,
    STATE(6608), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [225466] = 38,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8822), 1,
      anon_sym_SLASH,
    ACTIONS(8824), 1,
      anon_sym_CARET,
    ACTIONS(8826), 1,
      anon_sym_PIPE,
    ACTIONS(8828), 1,
      anon_sym_AMP,
    ACTIONS(8832), 1,
      anon_sym_GT_GT,
    ACTIONS(8838), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8840), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8848), 1,
      anon_sym_as,
    ACTIONS(8850), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8814), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8818), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8820), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8830), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8834), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8836), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 3,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_on,
    STATE(6609), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [225598] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6342), 1,
      anon_sym_on,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8822), 1,
      anon_sym_SLASH,
    ACTIONS(8824), 1,
      anon_sym_CARET,
    ACTIONS(8826), 1,
      anon_sym_PIPE,
    ACTIONS(8828), 1,
      anon_sym_AMP,
    ACTIONS(8832), 1,
      anon_sym_GT_GT,
    ACTIONS(8838), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8840), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8842), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8844), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8848), 1,
      anon_sym_as,
    ACTIONS(8850), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8814), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8818), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8820), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8830), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8834), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8836), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6610), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [225734] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5416), 1,
      anon_sym_on,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8816), 1,
      anon_sym_QMARK,
    ACTIONS(8822), 1,
      anon_sym_SLASH,
    ACTIONS(8824), 1,
      anon_sym_CARET,
    ACTIONS(8826), 1,
      anon_sym_PIPE,
    ACTIONS(8828), 1,
      anon_sym_AMP,
    ACTIONS(8832), 1,
      anon_sym_GT_GT,
    ACTIONS(8838), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8840), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8842), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8844), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8848), 1,
      anon_sym_as,
    ACTIONS(8850), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8814), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8818), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8820), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8830), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8834), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8836), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6611), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [225870] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(9139), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6612), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [226006] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(9141), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6613), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [226142] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8584), 1,
      anon_sym_QMARK,
    ACTIONS(8590), 1,
      anon_sym_SLASH,
    ACTIONS(8592), 1,
      anon_sym_CARET,
    ACTIONS(8594), 1,
      anon_sym_PIPE,
    ACTIONS(8596), 1,
      anon_sym_AMP,
    ACTIONS(8600), 1,
      anon_sym_GT_GT,
    ACTIONS(8606), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8608), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8610), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8612), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8614), 1,
      anon_sym_as,
    ACTIONS(8616), 1,
      anon_sym_is,
    ACTIONS(9143), 1,
      anon_sym_by,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8586), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8588), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8598), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8602), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8604), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6614), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [226278] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(9145), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6615), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [226414] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(7516), 1,
      anon_sym_QMARK,
    ACTIONS(7522), 1,
      anon_sym_SLASH,
    ACTIONS(7524), 1,
      anon_sym_CARET,
    ACTIONS(7526), 1,
      anon_sym_PIPE,
    ACTIONS(7528), 1,
      anon_sym_AMP,
    ACTIONS(7532), 1,
      anon_sym_GT_GT,
    ACTIONS(7538), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7540), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7542), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7544), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(9147), 1,
      anon_sym_SEMI,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7514), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7518), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7520), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7530), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7534), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7536), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6616), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [226550] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(7516), 1,
      anon_sym_QMARK,
    ACTIONS(7522), 1,
      anon_sym_SLASH,
    ACTIONS(7524), 1,
      anon_sym_CARET,
    ACTIONS(7526), 1,
      anon_sym_PIPE,
    ACTIONS(7528), 1,
      anon_sym_AMP,
    ACTIONS(7532), 1,
      anon_sym_GT_GT,
    ACTIONS(7538), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7540), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7542), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7544), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(9149), 1,
      anon_sym_SEMI,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7514), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7518), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7520), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7530), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7534), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7536), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6617), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [226686] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(9151), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6618), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [226822] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(9153), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6619), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [226958] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(9155), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6620), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [227094] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(7516), 1,
      anon_sym_QMARK,
    ACTIONS(7522), 1,
      anon_sym_SLASH,
    ACTIONS(7524), 1,
      anon_sym_CARET,
    ACTIONS(7526), 1,
      anon_sym_PIPE,
    ACTIONS(7528), 1,
      anon_sym_AMP,
    ACTIONS(7532), 1,
      anon_sym_GT_GT,
    ACTIONS(7538), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7540), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7542), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7544), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(9157), 1,
      anon_sym_SEMI,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7514), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7518), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7520), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7530), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7534), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7536), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6621), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [227230] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5644), 1,
      anon_sym_on,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8816), 1,
      anon_sym_QMARK,
    ACTIONS(8822), 1,
      anon_sym_SLASH,
    ACTIONS(8824), 1,
      anon_sym_CARET,
    ACTIONS(8826), 1,
      anon_sym_PIPE,
    ACTIONS(8828), 1,
      anon_sym_AMP,
    ACTIONS(8832), 1,
      anon_sym_GT_GT,
    ACTIONS(8838), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8840), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8842), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8844), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8848), 1,
      anon_sym_as,
    ACTIONS(8850), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8814), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8818), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8820), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8830), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8834), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8836), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6622), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [227366] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(8634), 1,
      anon_sym_QMARK,
    ACTIONS(8640), 1,
      anon_sym_SLASH,
    ACTIONS(8642), 1,
      anon_sym_CARET,
    ACTIONS(8644), 1,
      anon_sym_PIPE,
    ACTIONS(8646), 1,
      anon_sym_AMP,
    ACTIONS(8650), 1,
      anon_sym_GT_GT,
    ACTIONS(8656), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8658), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8660), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8662), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8664), 1,
      anon_sym_is,
    ACTIONS(9159), 1,
      anon_sym_COLON,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8632), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8636), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8638), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8648), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8652), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8654), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6623), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [227502] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(9161), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6624), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [227638] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5424), 1,
      anon_sym_on,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8816), 1,
      anon_sym_QMARK,
    ACTIONS(8822), 1,
      anon_sym_SLASH,
    ACTIONS(8824), 1,
      anon_sym_CARET,
    ACTIONS(8826), 1,
      anon_sym_PIPE,
    ACTIONS(8828), 1,
      anon_sym_AMP,
    ACTIONS(8832), 1,
      anon_sym_GT_GT,
    ACTIONS(8838), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8840), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8842), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8844), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8848), 1,
      anon_sym_as,
    ACTIONS(8850), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8814), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8818), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8820), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8830), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8834), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8836), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6625), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [227774] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6336), 1,
      anon_sym_on,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8816), 1,
      anon_sym_QMARK,
    ACTIONS(8822), 1,
      anon_sym_SLASH,
    ACTIONS(8824), 1,
      anon_sym_CARET,
    ACTIONS(8826), 1,
      anon_sym_PIPE,
    ACTIONS(8828), 1,
      anon_sym_AMP,
    ACTIONS(8832), 1,
      anon_sym_GT_GT,
    ACTIONS(8838), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8840), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8842), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8844), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8848), 1,
      anon_sym_as,
    ACTIONS(8850), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8814), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8818), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8820), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8830), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8834), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8836), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6626), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [227910] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5572), 1,
      anon_sym_on,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8816), 1,
      anon_sym_QMARK,
    ACTIONS(8822), 1,
      anon_sym_SLASH,
    ACTIONS(8824), 1,
      anon_sym_CARET,
    ACTIONS(8826), 1,
      anon_sym_PIPE,
    ACTIONS(8828), 1,
      anon_sym_AMP,
    ACTIONS(8832), 1,
      anon_sym_GT_GT,
    ACTIONS(8838), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8840), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8842), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8844), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8848), 1,
      anon_sym_as,
    ACTIONS(8850), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8814), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8818), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8820), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8830), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8834), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8836), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6627), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [228046] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(9163), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6628), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [228182] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5584), 1,
      anon_sym_on,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8816), 1,
      anon_sym_QMARK,
    ACTIONS(8822), 1,
      anon_sym_SLASH,
    ACTIONS(8824), 1,
      anon_sym_CARET,
    ACTIONS(8826), 1,
      anon_sym_PIPE,
    ACTIONS(8828), 1,
      anon_sym_AMP,
    ACTIONS(8832), 1,
      anon_sym_GT_GT,
    ACTIONS(8838), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8840), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8842), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8844), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8848), 1,
      anon_sym_as,
    ACTIONS(8850), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8814), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8818), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8820), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8830), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8834), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8836), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6629), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [228318] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5624), 1,
      anon_sym_on,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8816), 1,
      anon_sym_QMARK,
    ACTIONS(8822), 1,
      anon_sym_SLASH,
    ACTIONS(8824), 1,
      anon_sym_CARET,
    ACTIONS(8826), 1,
      anon_sym_PIPE,
    ACTIONS(8828), 1,
      anon_sym_AMP,
    ACTIONS(8832), 1,
      anon_sym_GT_GT,
    ACTIONS(8838), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8840), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8842), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8844), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8848), 1,
      anon_sym_as,
    ACTIONS(8850), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8814), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8818), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8820), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8830), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8834), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8836), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6630), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [228454] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(9165), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6631), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [228590] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(8634), 1,
      anon_sym_QMARK,
    ACTIONS(8640), 1,
      anon_sym_SLASH,
    ACTIONS(8642), 1,
      anon_sym_CARET,
    ACTIONS(8644), 1,
      anon_sym_PIPE,
    ACTIONS(8646), 1,
      anon_sym_AMP,
    ACTIONS(8650), 1,
      anon_sym_GT_GT,
    ACTIONS(8656), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8658), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8660), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8662), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8664), 1,
      anon_sym_is,
    ACTIONS(9167), 1,
      anon_sym_COLON,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8632), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8636), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8638), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8648), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8652), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8654), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6632), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [228726] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8584), 1,
      anon_sym_QMARK,
    ACTIONS(8590), 1,
      anon_sym_SLASH,
    ACTIONS(8592), 1,
      anon_sym_CARET,
    ACTIONS(8594), 1,
      anon_sym_PIPE,
    ACTIONS(8596), 1,
      anon_sym_AMP,
    ACTIONS(8600), 1,
      anon_sym_GT_GT,
    ACTIONS(8606), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8608), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8610), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8612), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8614), 1,
      anon_sym_as,
    ACTIONS(8616), 1,
      anon_sym_is,
    ACTIONS(9169), 1,
      anon_sym_by,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8586), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8588), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8598), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8602), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8604), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6633), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [228862] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6324), 1,
      anon_sym_COLON,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(8634), 1,
      anon_sym_QMARK,
    ACTIONS(8640), 1,
      anon_sym_SLASH,
    ACTIONS(8642), 1,
      anon_sym_CARET,
    ACTIONS(8644), 1,
      anon_sym_PIPE,
    ACTIONS(8646), 1,
      anon_sym_AMP,
    ACTIONS(8650), 1,
      anon_sym_GT_GT,
    ACTIONS(8656), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8658), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8660), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8662), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8664), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8632), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8636), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8638), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8648), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8652), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8654), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6634), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [228998] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(9171), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6635), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [229134] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9173), 1,
      anon_sym_into,
    STATE(6638), 1,
      aux_sym__query_body_repeat2,
    STATE(6636), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6482), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6480), 23,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_equals,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [229220] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9173), 1,
      anon_sym_into,
    STATE(6639), 1,
      aux_sym__query_body_repeat2,
    STATE(6637), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6482), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6480), 23,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_equals,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [229306] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9175), 1,
      anon_sym_into,
    STATE(6638), 10,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
      aux_sym__query_body_repeat2,
    ACTIONS(6486), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6484), 23,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_equals,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [229390] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9173), 1,
      anon_sym_into,
    STATE(6638), 1,
      aux_sym__query_body_repeat2,
    STATE(6639), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6493), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6491), 23,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_equals,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [229476] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7220), 1,
      anon_sym_QMARK,
    ACTIONS(7226), 1,
      anon_sym_SLASH,
    ACTIONS(7228), 1,
      anon_sym_CARET,
    ACTIONS(7230), 1,
      anon_sym_PIPE,
    ACTIONS(7232), 1,
      anon_sym_AMP,
    ACTIONS(7236), 1,
      anon_sym_GT_GT,
    ACTIONS(7242), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7244), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7246), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7248), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(9178), 1,
      aux_sym_preproc_if_token3,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7218), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7222), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7224), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7234), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7238), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7240), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6640), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [229612] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(8870), 1,
      anon_sym_SLASH,
    ACTIONS(8872), 1,
      anon_sym_AMP,
    ACTIONS(8876), 1,
      anon_sym_GT_GT,
    ACTIONS(8882), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8884), 1,
      anon_sym_is,
    ACTIONS(8886), 1,
      anon_sym_CARET,
    ACTIONS(8888), 1,
      anon_sym_PIPE,
    ACTIONS(8890), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8892), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8894), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8898), 1,
      anon_sym_QMARK,
    ACTIONS(9180), 1,
      anon_sym_in,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8864), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8866), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8868), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8874), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8878), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8880), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6641), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [229748] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(9182), 1,
      anon_sym_COMMA,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6642), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [229884] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(8870), 1,
      anon_sym_SLASH,
    ACTIONS(8872), 1,
      anon_sym_AMP,
    ACTIONS(8876), 1,
      anon_sym_GT_GT,
    ACTIONS(8882), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8884), 1,
      anon_sym_is,
    ACTIONS(8886), 1,
      anon_sym_CARET,
    ACTIONS(8888), 1,
      anon_sym_PIPE,
    ACTIONS(8890), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8892), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8894), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8898), 1,
      anon_sym_QMARK,
    ACTIONS(9184), 1,
      anon_sym_in,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8864), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8866), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8868), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8874), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8878), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8880), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6643), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [230020] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9186), 1,
      anon_sym_into,
    STATE(6646), 1,
      aux_sym__query_body_repeat2,
    STATE(6644), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6482), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6480), 23,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_on,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [230106] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9186), 1,
      anon_sym_into,
    STATE(6647), 1,
      aux_sym__query_body_repeat2,
    STATE(6645), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6482), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6480), 23,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_on,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [230192] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9188), 1,
      anon_sym_into,
    STATE(6646), 10,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
      aux_sym__query_body_repeat2,
    ACTIONS(6486), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6484), 23,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_on,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [230276] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9186), 1,
      anon_sym_into,
    STATE(6646), 1,
      aux_sym__query_body_repeat2,
    STATE(6647), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6493), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6491), 23,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_on,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [230362] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9018), 1,
      anon_sym_into,
    STATE(6490), 1,
      aux_sym__query_body_repeat2,
    STATE(6648), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6476), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6474), 23,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_by,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [230448] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(9191), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6649), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [230584] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(8870), 1,
      anon_sym_SLASH,
    ACTIONS(8872), 1,
      anon_sym_AMP,
    ACTIONS(8876), 1,
      anon_sym_GT_GT,
    ACTIONS(8882), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8884), 1,
      anon_sym_is,
    ACTIONS(8886), 1,
      anon_sym_CARET,
    ACTIONS(8888), 1,
      anon_sym_PIPE,
    ACTIONS(8890), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8892), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8894), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8898), 1,
      anon_sym_QMARK,
    ACTIONS(9193), 1,
      anon_sym_in,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8864), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8866), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8868), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8874), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8878), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8880), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6650), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [230720] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(9195), 1,
      anon_sym_COMMA,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6651), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [230856] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(8870), 1,
      anon_sym_SLASH,
    ACTIONS(8872), 1,
      anon_sym_AMP,
    ACTIONS(8876), 1,
      anon_sym_GT_GT,
    ACTIONS(8882), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8884), 1,
      anon_sym_is,
    ACTIONS(8886), 1,
      anon_sym_CARET,
    ACTIONS(8888), 1,
      anon_sym_PIPE,
    ACTIONS(8890), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8892), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8894), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8898), 1,
      anon_sym_QMARK,
    ACTIONS(9197), 1,
      anon_sym_in,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8864), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8866), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8868), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8874), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8878), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8880), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6652), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [230992] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6320), 1,
      anon_sym_EQ_GT,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(8622), 1,
      anon_sym_SLASH,
    ACTIONS(8626), 1,
      anon_sym_GT_GT,
    ACTIONS(8628), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8668), 1,
      anon_sym_AMP,
    ACTIONS(8674), 1,
      anon_sym_is,
    ACTIONS(8676), 1,
      anon_sym_CARET,
    ACTIONS(8678), 1,
      anon_sym_PIPE,
    ACTIONS(8680), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8682), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8684), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8686), 1,
      anon_sym_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8618), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8620), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8624), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8666), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8670), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8672), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6653), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [231128] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(9199), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6654), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [231264] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(9201), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6655), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [231400] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(9203), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6656), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [231536] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9205), 1,
      anon_sym_into,
    STATE(6659), 1,
      aux_sym__query_body_repeat2,
    STATE(6657), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6482), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6480), 23,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_GT,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [231622] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9205), 1,
      anon_sym_into,
    STATE(6660), 1,
      aux_sym__query_body_repeat2,
    STATE(6658), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6482), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6480), 23,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_GT,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [231708] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9207), 1,
      anon_sym_into,
    STATE(6659), 10,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
      aux_sym__query_body_repeat2,
    ACTIONS(6486), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6484), 23,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_GT,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [231792] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9205), 1,
      anon_sym_into,
    STATE(6659), 1,
      aux_sym__query_body_repeat2,
    STATE(6660), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6493), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6491), 23,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_GT,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [231878] = 29,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8590), 1,
      anon_sym_SLASH,
    ACTIONS(8600), 1,
      anon_sym_GT_GT,
    ACTIONS(8606), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8586), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8588), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8598), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6344), 5,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    STATE(6661), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 11,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_by,
      anon_sym_as,
      anon_sym_is,
  [231992] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9832), 1,
      sym__lambda_parameters,
    ACTIONS(4433), 6,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
    STATE(6662), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4431), 26,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      sym_discard,
      anon_sym_and,
      anon_sym_or,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [232082] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9173), 1,
      anon_sym_into,
    STATE(6636), 1,
      aux_sym__query_body_repeat2,
    STATE(6663), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6476), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6474), 23,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_equals,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [232168] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(9210), 1,
      anon_sym_COMMA,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6664), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [232304] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(8634), 1,
      anon_sym_QMARK,
    ACTIONS(8640), 1,
      anon_sym_SLASH,
    ACTIONS(8642), 1,
      anon_sym_CARET,
    ACTIONS(8644), 1,
      anon_sym_PIPE,
    ACTIONS(8646), 1,
      anon_sym_AMP,
    ACTIONS(8650), 1,
      anon_sym_GT_GT,
    ACTIONS(8656), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8658), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8660), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8662), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8664), 1,
      anon_sym_is,
    ACTIONS(9212), 1,
      anon_sym_COLON,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8632), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8636), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8638), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8648), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8652), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8654), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6665), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [232440] = 26,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8590), 1,
      anon_sym_SLASH,
    ACTIONS(8606), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8588), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 8,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(6666), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 13,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_by,
      anon_sym_as,
      anon_sym_is,
  [232548] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8606), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(6667), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 15,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_by,
      anon_sym_as,
      anon_sym_is,
  [232652] = 35,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8590), 1,
      anon_sym_SLASH,
    ACTIONS(8596), 1,
      anon_sym_AMP,
    ACTIONS(8600), 1,
      anon_sym_GT_GT,
    ACTIONS(8606), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8614), 1,
      anon_sym_as,
    ACTIONS(8616), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(8582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8586), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8588), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8598), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8602), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8604), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 5,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_by,
    STATE(6668), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [232778] = 36,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8590), 1,
      anon_sym_SLASH,
    ACTIONS(8592), 1,
      anon_sym_CARET,
    ACTIONS(8596), 1,
      anon_sym_AMP,
    ACTIONS(8600), 1,
      anon_sym_GT_GT,
    ACTIONS(8606), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8614), 1,
      anon_sym_as,
    ACTIONS(8616), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6344), 2,
      anon_sym_QMARK,
      anon_sym_PIPE,
    ACTIONS(8582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8586), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8588), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8598), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8602), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8604), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 4,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_by,
    STATE(6669), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [232906] = 34,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8590), 1,
      anon_sym_SLASH,
    ACTIONS(8600), 1,
      anon_sym_GT_GT,
    ACTIONS(8606), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8614), 1,
      anon_sym_as,
    ACTIONS(8616), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8586), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8588), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8598), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8602), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8604), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(6342), 5,
      anon_sym_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_by,
    STATE(6670), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [233030] = 27,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8590), 1,
      anon_sym_SLASH,
    ACTIONS(8606), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8586), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8588), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6344), 6,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(6671), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6342), 13,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_by,
      anon_sym_as,
      anon_sym_is,
  [233140] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9186), 1,
      anon_sym_into,
    STATE(6644), 1,
      aux_sym__query_body_repeat2,
    STATE(6672), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6476), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6474), 23,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_on,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [233226] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(9214), 1,
      anon_sym_COMMA,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6673), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [233362] = 33,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8590), 1,
      anon_sym_SLASH,
    ACTIONS(8600), 1,
      anon_sym_GT_GT,
    ACTIONS(8606), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8614), 1,
      anon_sym_as,
    ACTIONS(8616), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8586), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8588), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8598), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8604), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6344), 3,
      anon_sym_QMARK,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(6342), 7,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_by,
    STATE(6674), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [233484] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(8606), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6330), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(6675), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6328), 17,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_by,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [233584] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8816), 1,
      anon_sym_QMARK,
    ACTIONS(8822), 1,
      anon_sym_SLASH,
    ACTIONS(8824), 1,
      anon_sym_CARET,
    ACTIONS(8826), 1,
      anon_sym_PIPE,
    ACTIONS(8828), 1,
      anon_sym_AMP,
    ACTIONS(8832), 1,
      anon_sym_GT_GT,
    ACTIONS(8838), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8840), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8842), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8844), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8848), 1,
      anon_sym_as,
    ACTIONS(8850), 1,
      anon_sym_is,
    ACTIONS(9216), 1,
      anon_sym_on,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8814), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8818), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8820), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8830), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8834), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8836), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6676), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [233720] = 37,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8590), 1,
      anon_sym_SLASH,
    ACTIONS(8592), 1,
      anon_sym_CARET,
    ACTIONS(8594), 1,
      anon_sym_PIPE,
    ACTIONS(8596), 1,
      anon_sym_AMP,
    ACTIONS(8600), 1,
      anon_sym_GT_GT,
    ACTIONS(8606), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8614), 1,
      anon_sym_as,
    ACTIONS(8616), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8586), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8588), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8598), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8602), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8604), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 4,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_by,
    STATE(6677), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [233850] = 38,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8590), 1,
      anon_sym_SLASH,
    ACTIONS(8592), 1,
      anon_sym_CARET,
    ACTIONS(8594), 1,
      anon_sym_PIPE,
    ACTIONS(8596), 1,
      anon_sym_AMP,
    ACTIONS(8600), 1,
      anon_sym_GT_GT,
    ACTIONS(8606), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8608), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8614), 1,
      anon_sym_as,
    ACTIONS(8616), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8586), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8588), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8598), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8602), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8604), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    ACTIONS(6342), 3,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_by,
    STATE(6678), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [233982] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9205), 1,
      anon_sym_into,
    STATE(6657), 1,
      aux_sym__query_body_repeat2,
    STATE(6679), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6476), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6474), 23,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_EQ_GT,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [234068] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6342), 1,
      anon_sym_by,
    ACTIONS(6344), 1,
      anon_sym_QMARK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8590), 1,
      anon_sym_SLASH,
    ACTIONS(8592), 1,
      anon_sym_CARET,
    ACTIONS(8594), 1,
      anon_sym_PIPE,
    ACTIONS(8596), 1,
      anon_sym_AMP,
    ACTIONS(8600), 1,
      anon_sym_GT_GT,
    ACTIONS(8606), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8608), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8610), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8612), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8614), 1,
      anon_sym_as,
    ACTIONS(8616), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8586), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8588), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8598), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8602), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8604), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6680), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [234204] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6324), 1,
      anon_sym_EQ_GT,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(8622), 1,
      anon_sym_SLASH,
    ACTIONS(8626), 1,
      anon_sym_GT_GT,
    ACTIONS(8628), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8668), 1,
      anon_sym_AMP,
    ACTIONS(8674), 1,
      anon_sym_is,
    ACTIONS(8676), 1,
      anon_sym_CARET,
    ACTIONS(8678), 1,
      anon_sym_PIPE,
    ACTIONS(8680), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8682), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8684), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8686), 1,
      anon_sym_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8618), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8620), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8624), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8666), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8670), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8672), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6681), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [234340] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5416), 1,
      anon_sym_by,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8584), 1,
      anon_sym_QMARK,
    ACTIONS(8590), 1,
      anon_sym_SLASH,
    ACTIONS(8592), 1,
      anon_sym_CARET,
    ACTIONS(8594), 1,
      anon_sym_PIPE,
    ACTIONS(8596), 1,
      anon_sym_AMP,
    ACTIONS(8600), 1,
      anon_sym_GT_GT,
    ACTIONS(8606), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8608), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8610), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8612), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8614), 1,
      anon_sym_as,
    ACTIONS(8616), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8586), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8588), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8598), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8602), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8604), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6682), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [234476] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(7516), 1,
      anon_sym_QMARK,
    ACTIONS(7522), 1,
      anon_sym_SLASH,
    ACTIONS(7524), 1,
      anon_sym_CARET,
    ACTIONS(7526), 1,
      anon_sym_PIPE,
    ACTIONS(7528), 1,
      anon_sym_AMP,
    ACTIONS(7532), 1,
      anon_sym_GT_GT,
    ACTIONS(7538), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7540), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7542), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7544), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(9218), 1,
      anon_sym_SEMI,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7514), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7518), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7520), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7530), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7534), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7536), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6683), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [234612] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7670), 1,
      anon_sym_QMARK,
    ACTIONS(7676), 1,
      anon_sym_SLASH,
    ACTIONS(7678), 1,
      anon_sym_CARET,
    ACTIONS(7680), 1,
      anon_sym_PIPE,
    ACTIONS(7682), 1,
      anon_sym_AMP,
    ACTIONS(7686), 1,
      anon_sym_GT_GT,
    ACTIONS(7692), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7694), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7696), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7698), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7700), 1,
      anon_sym_is,
    ACTIONS(9220), 1,
      anon_sym_RPAREN,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7668), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7672), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7674), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7684), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7688), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7690), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6684), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [234748] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(8882), 1,
      anon_sym_DOT_DOT,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1229), 9,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
    STATE(6685), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(1227), 17,
      anon_sym_in,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_with,
  [234848] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(7516), 1,
      anon_sym_QMARK,
    ACTIONS(7522), 1,
      anon_sym_SLASH,
    ACTIONS(7524), 1,
      anon_sym_CARET,
    ACTIONS(7526), 1,
      anon_sym_PIPE,
    ACTIONS(7528), 1,
      anon_sym_AMP,
    ACTIONS(7532), 1,
      anon_sym_GT_GT,
    ACTIONS(7538), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7540), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7542), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7544), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(9222), 1,
      anon_sym_SEMI,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7514), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7518), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7520), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7530), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7534), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7536), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6686), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [234984] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(8634), 1,
      anon_sym_QMARK,
    ACTIONS(8640), 1,
      anon_sym_SLASH,
    ACTIONS(8642), 1,
      anon_sym_CARET,
    ACTIONS(8644), 1,
      anon_sym_PIPE,
    ACTIONS(8646), 1,
      anon_sym_AMP,
    ACTIONS(8650), 1,
      anon_sym_GT_GT,
    ACTIONS(8656), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8658), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8660), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8662), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8664), 1,
      anon_sym_is,
    ACTIONS(9224), 1,
      anon_sym_COLON,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8632), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8636), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8638), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8648), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8652), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8654), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6687), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [235120] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8976), 1,
      anon_sym_and,
    STATE(6688), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(6707), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(6705), 24,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_in,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_or,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [235204] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5644), 1,
      anon_sym_by,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(8584), 1,
      anon_sym_QMARK,
    ACTIONS(8590), 1,
      anon_sym_SLASH,
    ACTIONS(8592), 1,
      anon_sym_CARET,
    ACTIONS(8594), 1,
      anon_sym_PIPE,
    ACTIONS(8596), 1,
      anon_sym_AMP,
    ACTIONS(8600), 1,
      anon_sym_GT_GT,
    ACTIONS(8606), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8608), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8610), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8612), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(8614), 1,
      anon_sym_as,
    ACTIONS(8616), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8582), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8586), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8588), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8598), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8602), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8604), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6689), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [235340] = 40,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7118), 1,
      anon_sym_SLASH,
    ACTIONS(7120), 1,
      anon_sym_CARET,
    ACTIONS(7122), 1,
      anon_sym_PIPE,
    ACTIONS(7124), 1,
      anon_sym_AMP,
    ACTIONS(7128), 1,
      anon_sym_GT_GT,
    ACTIONS(7136), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7138), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7140), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7650), 1,
      anon_sym_COLON,
    ACTIONS(7660), 1,
      anon_sym_as,
    ACTIONS(8634), 1,
      anon_sym_QMARK,
    ACTIONS(8656), 1,
      anon_sym_DOT_DOT,
    ACTIONS(8664), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7112), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7114), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7116), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7126), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7130), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7132), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6690), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [235476] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(7411), 1,
      anon_sym_LBRACK,
    ACTIONS(7413), 1,
      anon_sym_QMARK,
    ACTIONS(7415), 1,
      anon_sym_STAR,
    ACTIONS(9226), 1,
      anon_sym_DOT,
    ACTIONS(4494), 4,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
    STATE(6691), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4492), 26,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      sym_discard,
      anon_sym_and,
      anon_sym_or,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [235567] = 39,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6863), 1,
      anon_sym_SLASH,
    ACTIONS(6865), 1,
      anon_sym_CARET,
    ACTIONS(6867), 1,
      anon_sym_PIPE,
    ACTIONS(6869), 1,
      anon_sym_AMP,
    ACTIONS(6873), 1,
      anon_sym_GT_GT,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6883), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6885), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6887), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7220), 1,
      anon_sym_QMARK,
    ACTIONS(7242), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6855), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6859), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6861), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6871), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6875), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6877), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6692), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [235700] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4343), 1,
      anon_sym_LBRACE,
    ACTIONS(4359), 1,
      sym_discard,
    ACTIONS(7467), 1,
      sym__identifier_token,
    ACTIONS(8455), 1,
      anon_sym_LPAREN,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(4153), 1,
      sym_parenthesized_variable_designation,
    STATE(4156), 1,
      sym_identifier,
    STATE(4161), 1,
      sym__variable_designation,
    STATE(6772), 1,
      sym_property_pattern_clause,
    ACTIONS(4405), 2,
      anon_sym_COLON,
      anon_sym_EQ_GT,
    ACTIONS(4407), 3,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
    STATE(6693), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 21,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [235801] = 39,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7220), 1,
      anon_sym_QMARK,
    ACTIONS(7242), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(7620), 1,
      anon_sym_SLASH,
    ACTIONS(7622), 1,
      anon_sym_AMP,
    ACTIONS(7626), 1,
      anon_sym_GT_GT,
    ACTIONS(7638), 1,
      anon_sym_CARET,
    ACTIONS(7640), 1,
      anon_sym_PIPE,
    ACTIONS(7642), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7644), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7646), 1,
      anon_sym_QMARK_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7614), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7616), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7618), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7624), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7628), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7630), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6694), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [235934] = 39,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7162), 1,
      anon_sym_SLASH,
    ACTIONS(7164), 1,
      anon_sym_CARET,
    ACTIONS(7166), 1,
      anon_sym_PIPE,
    ACTIONS(7168), 1,
      anon_sym_AMP,
    ACTIONS(7172), 1,
      anon_sym_GT_GT,
    ACTIONS(7180), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7182), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7184), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7220), 1,
      anon_sym_QMARK,
    ACTIONS(7242), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7154), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7158), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7160), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7170), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7174), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7176), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6695), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [236067] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5699), 2,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
    STATE(6696), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5697), 33,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_static,
      anon_sym_ref,
      anon_sym_delegate,
      anon_sym_async,
      anon_sym_file,
      anon_sym_readonly,
      anon_sym_in,
      anon_sym_out,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_this,
      anon_sym_scoped,
      anon_sym_params,
      anon_sym_var,
      sym_predefined_type,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [236148] = 39,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7220), 1,
      anon_sym_QMARK,
    ACTIONS(7242), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(7887), 1,
      anon_sym_SLASH,
    ACTIONS(7889), 1,
      anon_sym_CARET,
    ACTIONS(7891), 1,
      anon_sym_PIPE,
    ACTIONS(7893), 1,
      anon_sym_AMP,
    ACTIONS(7897), 1,
      anon_sym_GT_GT,
    ACTIONS(7905), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7907), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7909), 1,
      anon_sym_QMARK_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7879), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7883), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7885), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7895), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7899), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7901), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6697), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [236281] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8265), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9765), 1,
      sym__lambda_parameters,
    ACTIONS(4433), 5,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
    STATE(6698), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4431), 26,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      sym_discard,
      anon_sym_and,
      anon_sym_or,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [236370] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5703), 2,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
    STATE(6699), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5701), 33,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_static,
      anon_sym_ref,
      anon_sym_delegate,
      anon_sym_async,
      anon_sym_file,
      anon_sym_readonly,
      anon_sym_in,
      anon_sym_out,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_this,
      anon_sym_scoped,
      anon_sym_params,
      anon_sym_var,
      sym_predefined_type,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [236451] = 39,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7220), 1,
      anon_sym_QMARK,
    ACTIONS(7242), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(7334), 1,
      anon_sym_SLASH,
    ACTIONS(7336), 1,
      anon_sym_CARET,
    ACTIONS(7338), 1,
      anon_sym_PIPE,
    ACTIONS(7340), 1,
      anon_sym_AMP,
    ACTIONS(7344), 1,
      anon_sym_GT_GT,
    ACTIONS(7352), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7354), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7356), 1,
      anon_sym_QMARK_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7326), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7330), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7332), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7342), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7346), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7348), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6700), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [236584] = 39,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7220), 1,
      anon_sym_QMARK,
    ACTIONS(7242), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(7498), 1,
      anon_sym_SLASH,
    ACTIONS(7502), 1,
      anon_sym_GT_GT,
    ACTIONS(7831), 1,
      anon_sym_CARET,
    ACTIONS(7833), 1,
      anon_sym_PIPE,
    ACTIONS(7835), 1,
      anon_sym_AMP,
    ACTIONS(7837), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7839), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7841), 1,
      anon_sym_QMARK_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7492), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7494), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7496), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7500), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7504), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7506), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6701), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [236717] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5725), 2,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
    STATE(6702), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5723), 33,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_static,
      anon_sym_ref,
      anon_sym_delegate,
      anon_sym_async,
      anon_sym_file,
      anon_sym_readonly,
      anon_sym_in,
      anon_sym_out,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_this,
      anon_sym_scoped,
      anon_sym_params,
      anon_sym_var,
      sym_predefined_type,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [236798] = 39,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7220), 1,
      anon_sym_QMARK,
    ACTIONS(7242), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(7772), 1,
      anon_sym_SLASH,
    ACTIONS(7776), 1,
      anon_sym_GT_GT,
    ACTIONS(7847), 1,
      anon_sym_CARET,
    ACTIONS(7849), 1,
      anon_sym_PIPE,
    ACTIONS(7851), 1,
      anon_sym_AMP,
    ACTIONS(7857), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7859), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7861), 1,
      anon_sym_QMARK_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7768), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7770), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7774), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7843), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7853), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7855), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6703), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [236931] = 39,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6418), 1,
      anon_sym_SLASH,
    ACTIONS(6420), 1,
      anon_sym_CARET,
    ACTIONS(6422), 1,
      anon_sym_PIPE,
    ACTIONS(6424), 1,
      anon_sym_AMP,
    ACTIONS(6428), 1,
      anon_sym_GT_GT,
    ACTIONS(6438), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6440), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6442), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7220), 1,
      anon_sym_QMARK,
    ACTIONS(7242), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6410), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6414), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6416), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6426), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6430), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6432), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6704), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [237064] = 39,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7220), 1,
      anon_sym_QMARK,
    ACTIONS(7242), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(7264), 1,
      anon_sym_SLASH,
    ACTIONS(7266), 1,
      anon_sym_CARET,
    ACTIONS(7268), 1,
      anon_sym_PIPE,
    ACTIONS(7270), 1,
      anon_sym_AMP,
    ACTIONS(7274), 1,
      anon_sym_GT_GT,
    ACTIONS(7282), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7284), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7286), 1,
      anon_sym_QMARK_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7256), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7260), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7262), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7272), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7276), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7278), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6705), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [237197] = 39,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7086), 1,
      anon_sym_SLASH,
    ACTIONS(7088), 1,
      anon_sym_CARET,
    ACTIONS(7090), 1,
      anon_sym_PIPE,
    ACTIONS(7092), 1,
      anon_sym_AMP,
    ACTIONS(7096), 1,
      anon_sym_GT_GT,
    ACTIONS(7104), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7106), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7108), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7220), 1,
      anon_sym_QMARK,
    ACTIONS(7242), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7078), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7082), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7084), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7094), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7098), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7100), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6706), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [237330] = 39,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7220), 1,
      anon_sym_QMARK,
    ACTIONS(7242), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(7784), 1,
      anon_sym_SLASH,
    ACTIONS(7788), 1,
      anon_sym_GT_GT,
    ACTIONS(7807), 1,
      anon_sym_CARET,
    ACTIONS(7809), 1,
      anon_sym_PIPE,
    ACTIONS(7811), 1,
      anon_sym_AMP,
    ACTIONS(7817), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7819), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7821), 1,
      anon_sym_QMARK_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7780), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7782), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7786), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7803), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7813), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7815), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6707), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [237463] = 39,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7220), 1,
      anon_sym_QMARK,
    ACTIONS(7242), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(8101), 1,
      anon_sym_SLASH,
    ACTIONS(8105), 1,
      anon_sym_GT_GT,
    ACTIONS(8111), 1,
      anon_sym_AMP,
    ACTIONS(8121), 1,
      anon_sym_CARET,
    ACTIONS(8123), 1,
      anon_sym_PIPE,
    ACTIONS(8125), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8127), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8129), 1,
      anon_sym_QMARK_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8097), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8099), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8103), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8109), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8113), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8115), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6708), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [237596] = 39,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7050), 1,
      anon_sym_LPAREN,
    ACTIONS(7148), 1,
      anon_sym_BANG,
    ACTIONS(7220), 1,
      anon_sym_QMARK,
    ACTIONS(7242), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(7381), 1,
      anon_sym_SLASH,
    ACTIONS(7383), 1,
      anon_sym_CARET,
    ACTIONS(7385), 1,
      anon_sym_PIPE,
    ACTIONS(7387), 1,
      anon_sym_AMP,
    ACTIONS(7391), 1,
      anon_sym_GT_GT,
    ACTIONS(7399), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7401), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7403), 1,
      anon_sym_QMARK_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(5540), 1,
      sym_argument_list,
    ACTIONS(7150), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7373), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7377), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7379), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7389), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7393), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7395), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6709), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [237729] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3993), 9,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_STAR,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    STATE(6710), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3995), 26,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      sym_discard,
      anon_sym_and,
      anon_sym_or,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [237810] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4124), 9,
      anon_sym_LBRACK,
      anon_sym_COLON,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_STAR,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    STATE(6711), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4122), 26,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      sym_discard,
      anon_sym_and,
      anon_sym_or,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [237891] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(7411), 1,
      anon_sym_LBRACK,
    ACTIONS(7413), 1,
      anon_sym_QMARK,
    ACTIONS(7415), 1,
      anon_sym_STAR,
    ACTIONS(9228), 1,
      anon_sym_DOT,
    ACTIONS(4494), 4,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
    STATE(6712), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4492), 26,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      sym_discard,
      anon_sym_and,
      anon_sym_or,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [237982] = 39,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5830), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7220), 1,
      anon_sym_QMARK,
    ACTIONS(7226), 1,
      anon_sym_SLASH,
    ACTIONS(7228), 1,
      anon_sym_CARET,
    ACTIONS(7230), 1,
      anon_sym_PIPE,
    ACTIONS(7232), 1,
      anon_sym_AMP,
    ACTIONS(7236), 1,
      anon_sym_GT_GT,
    ACTIONS(7242), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7244), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7246), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7248), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    STATE(3507), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7218), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7222), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7224), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7234), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7238), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7240), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6713), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [238115] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(7411), 1,
      anon_sym_LBRACK,
    ACTIONS(7413), 1,
      anon_sym_QMARK,
    ACTIONS(7415), 1,
      anon_sym_STAR,
    ACTIONS(9230), 1,
      anon_sym_DOT,
    ACTIONS(4494), 4,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
    STATE(6714), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4492), 26,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      sym_discard,
      anon_sym_and,
      anon_sym_or,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [238206] = 39,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7220), 1,
      anon_sym_QMARK,
    ACTIONS(7242), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(7706), 1,
      anon_sym_SLASH,
    ACTIONS(7710), 1,
      anon_sym_GT_GT,
    ACTIONS(7716), 1,
      anon_sym_AMP,
    ACTIONS(7724), 1,
      anon_sym_CARET,
    ACTIONS(7726), 1,
      anon_sym_PIPE,
    ACTIONS(7728), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7730), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7732), 1,
      anon_sym_QMARK_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7702), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7704), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7708), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7714), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7718), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7720), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6715), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [238339] = 21,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4359), 1,
      sym_discard,
    ACTIONS(7467), 1,
      sym__identifier_token,
    ACTIONS(8455), 1,
      anon_sym_LPAREN,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(4153), 1,
      sym_parenthesized_variable_designation,
    STATE(4156), 1,
      sym_identifier,
    STATE(4190), 1,
      sym__variable_designation,
    ACTIONS(4443), 2,
      anon_sym_and,
      anon_sym_or,
    ACTIONS(4441), 4,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(6716), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [238436] = 39,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5273), 1,
      anon_sym_LBRACK,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7220), 1,
      anon_sym_QMARK,
    ACTIONS(7226), 1,
      anon_sym_SLASH,
    ACTIONS(7228), 1,
      anon_sym_CARET,
    ACTIONS(7230), 1,
      anon_sym_PIPE,
    ACTIONS(7232), 1,
      anon_sym_AMP,
    ACTIONS(7236), 1,
      anon_sym_GT_GT,
    ACTIONS(7242), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7244), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7246), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7248), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    STATE(3001), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7218), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7222), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7224), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7234), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7238), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7240), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6717), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [238569] = 39,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7220), 1,
      anon_sym_QMARK,
    ACTIONS(7226), 1,
      anon_sym_SLASH,
    ACTIONS(7228), 1,
      anon_sym_CARET,
    ACTIONS(7230), 1,
      anon_sym_PIPE,
    ACTIONS(7232), 1,
      anon_sym_AMP,
    ACTIONS(7236), 1,
      anon_sym_GT_GT,
    ACTIONS(7242), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7244), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7246), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7248), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7218), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7222), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7224), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7234), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7238), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7240), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6718), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [238702] = 39,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(6976), 1,
      anon_sym_SLASH,
    ACTIONS(6978), 1,
      anon_sym_AMP,
    ACTIONS(6982), 1,
      anon_sym_GT_GT,
    ACTIONS(7038), 1,
      anon_sym_CARET,
    ACTIONS(7040), 1,
      anon_sym_PIPE,
    ACTIONS(7042), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7044), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7046), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7220), 1,
      anon_sym_QMARK,
    ACTIONS(7242), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6970), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6972), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6974), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6980), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6984), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6986), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6719), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [238835] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(2989), 2,
      anon_sym_while,
      anon_sym_else,
    STATE(6720), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(2991), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(2993), 22,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [238918] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4343), 1,
      anon_sym_LBRACE,
    ACTIONS(4359), 1,
      sym_discard,
    ACTIONS(7467), 1,
      sym__identifier_token,
    ACTIONS(8455), 1,
      anon_sym_LPAREN,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(4153), 1,
      sym_parenthesized_variable_designation,
    STATE(4156), 1,
      sym_identifier,
    STATE(4166), 1,
      sym__variable_designation,
    STATE(6776), 1,
      sym_property_pattern_clause,
    ACTIONS(4399), 2,
      anon_sym_COLON,
      anon_sym_EQ_GT,
    ACTIONS(4401), 3,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
    STATE(6721), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 21,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [239019] = 39,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7118), 1,
      anon_sym_SLASH,
    ACTIONS(7120), 1,
      anon_sym_CARET,
    ACTIONS(7122), 1,
      anon_sym_PIPE,
    ACTIONS(7124), 1,
      anon_sym_AMP,
    ACTIONS(7128), 1,
      anon_sym_GT_GT,
    ACTIONS(7136), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7138), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7140), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7220), 1,
      anon_sym_QMARK,
    ACTIONS(7242), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7112), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7114), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7116), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7126), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7130), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7132), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6722), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [239152] = 39,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5233), 1,
      anon_sym_DASH_GT,
    ACTIONS(5239), 1,
      anon_sym_DOT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6156), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7220), 1,
      anon_sym_QMARK,
    ACTIONS(7226), 1,
      anon_sym_SLASH,
    ACTIONS(7228), 1,
      anon_sym_CARET,
    ACTIONS(7230), 1,
      anon_sym_PIPE,
    ACTIONS(7232), 1,
      anon_sym_AMP,
    ACTIONS(7236), 1,
      anon_sym_GT_GT,
    ACTIONS(7242), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7244), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7246), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7248), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    STATE(3577), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7218), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7222), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7224), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7234), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7238), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7240), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6723), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [239285] = 21,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4359), 1,
      sym_discard,
    ACTIONS(7467), 1,
      sym__identifier_token,
    ACTIONS(8455), 1,
      anon_sym_LPAREN,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(4153), 1,
      sym_parenthesized_variable_designation,
    STATE(4156), 1,
      sym_identifier,
    STATE(4167), 1,
      sym__variable_designation,
    ACTIONS(4401), 2,
      anon_sym_and,
      anon_sym_or,
    ACTIONS(4399), 4,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(6724), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [239382] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(7411), 1,
      anon_sym_LBRACK,
    ACTIONS(7413), 1,
      anon_sym_QMARK,
    ACTIONS(7415), 1,
      anon_sym_STAR,
    ACTIONS(9232), 1,
      anon_sym_DOT,
    ACTIONS(4494), 4,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
    STATE(6725), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4492), 26,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      sym_discard,
      anon_sym_and,
      anon_sym_or,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [239473] = 39,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4973), 1,
      anon_sym_DOT,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7146), 1,
      anon_sym_LBRACK,
    ACTIONS(7220), 1,
      anon_sym_QMARK,
    ACTIONS(7226), 1,
      anon_sym_SLASH,
    ACTIONS(7228), 1,
      anon_sym_CARET,
    ACTIONS(7230), 1,
      anon_sym_PIPE,
    ACTIONS(7232), 1,
      anon_sym_AMP,
    ACTIONS(7236), 1,
      anon_sym_GT_GT,
    ACTIONS(7242), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7244), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7246), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7248), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    STATE(3888), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7218), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7222), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7224), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7234), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7238), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7240), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6726), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [239606] = 39,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7220), 1,
      anon_sym_QMARK,
    ACTIONS(7242), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(7550), 1,
      anon_sym_SLASH,
    ACTIONS(7554), 1,
      anon_sym_GT_GT,
    ACTIONS(7560), 1,
      anon_sym_AMP,
    ACTIONS(7570), 1,
      anon_sym_CARET,
    ACTIONS(7572), 1,
      anon_sym_PIPE,
    ACTIONS(7574), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7576), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7578), 1,
      anon_sym_QMARK_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7546), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7548), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7552), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7558), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7562), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7564), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6727), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [239739] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(7411), 1,
      anon_sym_LBRACK,
    ACTIONS(7413), 1,
      anon_sym_QMARK,
    ACTIONS(7415), 1,
      anon_sym_STAR,
    ACTIONS(9234), 1,
      anon_sym_DOT,
    ACTIONS(4494), 4,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
    STATE(6728), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4492), 26,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      sym_discard,
      anon_sym_and,
      anon_sym_or,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [239830] = 39,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5759), 1,
      anon_sym_LPAREN,
    ACTIONS(5780), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(6950), 1,
      anon_sym_SLASH,
    ACTIONS(6952), 1,
      anon_sym_CARET,
    ACTIONS(6954), 1,
      anon_sym_PIPE,
    ACTIONS(6956), 1,
      anon_sym_AMP,
    ACTIONS(6960), 1,
      anon_sym_GT_GT,
    ACTIONS(7061), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7063), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7065), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7220), 1,
      anon_sym_QMARK,
    ACTIONS(7242), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4044), 1,
      sym_argument_list,
    ACTIONS(5782), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6944), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6946), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6948), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6958), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6962), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6964), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6729), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [239963] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(7411), 1,
      anon_sym_LBRACK,
    ACTIONS(7413), 1,
      anon_sym_QMARK,
    ACTIONS(7415), 1,
      anon_sym_STAR,
    ACTIONS(9236), 1,
      anon_sym_DOT,
    ACTIONS(4494), 4,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
    STATE(6730), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4492), 26,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      sym_discard,
      anon_sym_and,
      anon_sym_or,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [240054] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9765), 1,
      sym__lambda_parameters,
    ACTIONS(4433), 5,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
    STATE(6731), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4431), 26,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      sym_discard,
      anon_sym_and,
      anon_sym_or,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [240143] = 39,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7220), 1,
      anon_sym_QMARK,
    ACTIONS(7242), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(8171), 1,
      anon_sym_SLASH,
    ACTIONS(8175), 1,
      anon_sym_GT_GT,
    ACTIONS(8181), 1,
      anon_sym_AMP,
    ACTIONS(8189), 1,
      anon_sym_CARET,
    ACTIONS(8195), 1,
      anon_sym_PIPE,
    ACTIONS(8197), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8199), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8201), 1,
      anon_sym_QMARK_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8167), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8169), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8173), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8179), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8183), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8185), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6732), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [240276] = 21,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4359), 1,
      sym_discard,
    ACTIONS(7467), 1,
      sym__identifier_token,
    ACTIONS(8455), 1,
      anon_sym_LPAREN,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(4153), 1,
      sym_parenthesized_variable_designation,
    STATE(4156), 1,
      sym_identifier,
    STATE(4207), 1,
      sym__variable_designation,
    ACTIONS(4439), 2,
      anon_sym_and,
      anon_sym_or,
    ACTIONS(4437), 4,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(6733), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [240373] = 39,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4634), 1,
      anon_sym_DOT,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5778), 1,
      anon_sym_LBRACK,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7220), 1,
      anon_sym_QMARK,
    ACTIONS(7226), 1,
      anon_sym_SLASH,
    ACTIONS(7228), 1,
      anon_sym_CARET,
    ACTIONS(7230), 1,
      anon_sym_PIPE,
    ACTIONS(7232), 1,
      anon_sym_AMP,
    ACTIONS(7236), 1,
      anon_sym_GT_GT,
    ACTIONS(7242), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7244), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7246), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7248), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    STATE(3189), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7218), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7222), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7224), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7234), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7238), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7240), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6734), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [240506] = 39,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(5249), 1,
      anon_sym_DOT,
    ACTIONS(5265), 1,
      anon_sym_LPAREN,
    ACTIONS(5277), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6771), 1,
      anon_sym_SLASH,
    ACTIONS(6773), 1,
      anon_sym_CARET,
    ACTIONS(6775), 1,
      anon_sym_PIPE,
    ACTIONS(6777), 1,
      anon_sym_AMP,
    ACTIONS(6781), 1,
      anon_sym_GT_GT,
    ACTIONS(6791), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6793), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6795), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7220), 1,
      anon_sym_QMARK,
    ACTIONS(7242), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(3682), 1,
      sym_argument_list,
    ACTIONS(5279), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6763), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6767), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6769), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6779), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6783), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6785), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6735), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [240639] = 39,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7220), 1,
      anon_sym_QMARK,
    ACTIONS(7242), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(7928), 1,
      anon_sym_SLASH,
    ACTIONS(7932), 1,
      anon_sym_GT_GT,
    ACTIONS(7938), 1,
      anon_sym_AMP,
    ACTIONS(7948), 1,
      anon_sym_CARET,
    ACTIONS(7950), 1,
      anon_sym_PIPE,
    ACTIONS(7952), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7954), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7956), 1,
      anon_sym_QMARK_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7924), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7926), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7930), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7936), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7940), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7942), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6736), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [240772] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(2997), 2,
      anon_sym_while,
      anon_sym_else,
    STATE(6737), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(2999), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(3001), 22,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [240855] = 19,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4145), 1,
      anon_sym_EQ_GT,
    ACTIONS(4147), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6803), 1,
      anon_sym_LT,
    ACTIONS(9238), 1,
      anon_sym_EQ,
    STATE(5001), 1,
      sym_type_argument_list,
    ACTIONS(9240), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(4140), 5,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_QMARK,
      anon_sym_STAR,
      anon_sym_DOT,
    STATE(6738), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4138), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [240948] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5721), 2,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
    STATE(6739), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5719), 33,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_static,
      anon_sym_ref,
      anon_sym_delegate,
      anon_sym_async,
      anon_sym_file,
      anon_sym_readonly,
      anon_sym_in,
      anon_sym_out,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_this,
      anon_sym_scoped,
      anon_sym_params,
      anon_sym_var,
      sym_predefined_type,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [241029] = 39,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7220), 1,
      anon_sym_QMARK,
    ACTIONS(7242), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(8253), 1,
      anon_sym_SLASH,
    ACTIONS(8255), 1,
      anon_sym_CARET,
    ACTIONS(8257), 1,
      anon_sym_PIPE,
    ACTIONS(8259), 1,
      anon_sym_AMP,
    ACTIONS(8263), 1,
      anon_sym_GT_GT,
    ACTIONS(8271), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8273), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8275), 1,
      anon_sym_QMARK_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(8245), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(8249), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(8251), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(8261), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(8265), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(8267), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6740), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [241162] = 39,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7220), 1,
      anon_sym_QMARK,
    ACTIONS(7242), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    ACTIONS(7980), 1,
      anon_sym_SLASH,
    ACTIONS(7984), 1,
      anon_sym_GT_GT,
    ACTIONS(7990), 1,
      anon_sym_AMP,
    ACTIONS(8000), 1,
      anon_sym_CARET,
    ACTIONS(8002), 1,
      anon_sym_PIPE,
    ACTIONS(8004), 1,
      anon_sym_AMP_AMP,
    ACTIONS(8006), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(8008), 1,
      anon_sym_QMARK_QMARK,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7976), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7978), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7982), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7988), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7992), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7994), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6741), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [241295] = 39,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4602), 1,
      anon_sym_DOT,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(5832), 1,
      anon_sym_BANG,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7220), 1,
      anon_sym_QMARK,
    ACTIONS(7226), 1,
      anon_sym_SLASH,
    ACTIONS(7228), 1,
      anon_sym_CARET,
    ACTIONS(7230), 1,
      anon_sym_PIPE,
    ACTIONS(7232), 1,
      anon_sym_AMP,
    ACTIONS(7236), 1,
      anon_sym_GT_GT,
    ACTIONS(7242), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7244), 1,
      anon_sym_AMP_AMP,
    ACTIONS(7246), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(7248), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4293), 1,
      sym_argument_list,
    ACTIONS(5834), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(7218), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(7222), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(7224), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(7234), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(7238), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(7240), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6742), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [241428] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9076), 1,
      sym__lambda_parameters,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    ACTIONS(4433), 5,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
    STATE(6743), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4431), 26,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      sym_discard,
      anon_sym_and,
      anon_sym_or,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [241517] = 39,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5233), 1,
      anon_sym_DASH_GT,
    ACTIONS(5239), 1,
      anon_sym_DOT,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6124), 1,
      anon_sym_LPAREN,
    ACTIONS(6158), 1,
      anon_sym_BANG,
    ACTIONS(6200), 1,
      anon_sym_SLASH,
    ACTIONS(6202), 1,
      anon_sym_CARET,
    ACTIONS(6204), 1,
      anon_sym_PIPE,
    ACTIONS(6206), 1,
      anon_sym_AMP,
    ACTIONS(6210), 1,
      anon_sym_GT_GT,
    ACTIONS(6222), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6224), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6226), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7220), 1,
      anon_sym_QMARK,
    ACTIONS(7242), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4561), 1,
      sym_argument_list,
    ACTIONS(6160), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6192), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6196), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6198), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6208), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6212), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6214), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6744), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [241650] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5713), 2,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
    STATE(6745), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5711), 33,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_static,
      anon_sym_ref,
      anon_sym_delegate,
      anon_sym_async,
      anon_sym_file,
      anon_sym_readonly,
      anon_sym_in,
      anon_sym_out,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_this,
      anon_sym_scoped,
      anon_sym_params,
      anon_sym_var,
      sym_predefined_type,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [241731] = 21,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4359), 1,
      sym_discard,
    ACTIONS(7467), 1,
      sym__identifier_token,
    ACTIONS(8455), 1,
      anon_sym_LPAREN,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(4153), 1,
      sym_parenthesized_variable_designation,
    STATE(4156), 1,
      sym_identifier,
    STATE(4182), 1,
      sym__variable_designation,
    ACTIONS(4407), 2,
      anon_sym_and,
      anon_sym_or,
    ACTIONS(4405), 4,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(6746), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [241828] = 39,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5233), 1,
      anon_sym_DASH_GT,
    ACTIONS(5239), 1,
      anon_sym_DOT,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(6124), 1,
      anon_sym_LPAREN,
    ACTIONS(6158), 1,
      anon_sym_BANG,
    ACTIONS(6394), 1,
      anon_sym_SLASH,
    ACTIONS(6398), 1,
      anon_sym_GT_GT,
    ACTIONS(6452), 1,
      anon_sym_CARET,
    ACTIONS(6454), 1,
      anon_sym_PIPE,
    ACTIONS(6456), 1,
      anon_sym_AMP,
    ACTIONS(6458), 1,
      anon_sym_AMP_AMP,
    ACTIONS(6460), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(6462), 1,
      anon_sym_QMARK_QMARK,
    ACTIONS(6879), 1,
      anon_sym_switch,
    ACTIONS(6893), 1,
      anon_sym_with,
    ACTIONS(7220), 1,
      anon_sym_QMARK,
    ACTIONS(7242), 1,
      anon_sym_DOT_DOT,
    ACTIONS(7250), 1,
      anon_sym_as,
    ACTIONS(7252), 1,
      anon_sym_is,
    STATE(3050), 1,
      sym_bracketed_argument_list,
    STATE(4561), 1,
      sym_argument_list,
    ACTIONS(6160), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(6388), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(6390), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(6392), 2,
      anon_sym_STAR,
      anon_sym_PERCENT,
    ACTIONS(6396), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(6400), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(6402), 2,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
    STATE(6747), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [241961] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9242), 1,
      anon_sym_SEMI,
    STATE(6748), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5654), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5652), 22,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [242043] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4147), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6803), 1,
      anon_sym_LT,
    ACTIONS(9244), 1,
      anon_sym_EQ,
    STATE(5001), 1,
      sym_type_argument_list,
    ACTIONS(9240), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
    ACTIONS(4140), 4,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR,
      anon_sym_DOT,
    STATE(6749), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4138), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [242133] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4147), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6803), 1,
      anon_sym_LT,
    ACTIONS(9246), 1,
      anon_sym_LPAREN,
    STATE(5001), 1,
      sym_type_argument_list,
    STATE(7694), 1,
      sym_parameter_list,
    ACTIONS(4140), 4,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR,
      anon_sym_DOT,
    STATE(6750), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4138), 25,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_operator,
      anon_sym_this,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [242223] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(8914), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(7374), 1,
      sym_explicit_interface_specifier,
    STATE(7527), 1,
      sym_identifier,
    STATE(8010), 1,
      sym_tuple_pattern,
    STATE(8392), 1,
      sym_variable_declarator,
    STATE(9517), 1,
      sym__name,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(6751), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [242321] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4147), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6803), 1,
      anon_sym_LT,
    ACTIONS(9249), 1,
      anon_sym_EQ,
    ACTIONS(9251), 1,
      anon_sym_COMMA,
    ACTIONS(9254), 1,
      anon_sym_RPAREN,
    STATE(5001), 1,
      sym_type_argument_list,
    STATE(8667), 1,
      aux_sym_tuple_pattern_repeat1,
    ACTIONS(4140), 4,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR,
      anon_sym_DOT,
    STATE(6752), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4138), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [242415] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(5741), 1,
      anon_sym_LBRACK,
    ACTIONS(9257), 1,
      aux_sym_preproc_if_token3,
    ACTIONS(9259), 1,
      aux_sym_preproc_else_token1,
    ACTIONS(9261), 1,
      aux_sym_preproc_elif_token1,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(7115), 1,
      aux_sym_class_declaration_repeat1,
    STATE(7300), 1,
      sym_attribute_list,
    STATE(7960), 1,
      sym_enum_member_declaration,
    STATE(8281), 1,
      sym_identifier,
    STATE(9824), 2,
      sym_preproc_else_in_enum_member_declaration,
      sym_preproc_elif_in_enum_member_declaration,
    STATE(6753), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [242515] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(8914), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(7337), 1,
      sym_explicit_interface_specifier,
    STATE(7526), 1,
      sym_identifier,
    STATE(8010), 1,
      sym_tuple_pattern,
    STATE(8392), 1,
      sym_variable_declarator,
    STATE(9517), 1,
      sym__name,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(6754), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [242613] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9263), 1,
      anon_sym_SEMI,
    STATE(6755), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5654), 11,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_GT_GT,
      anon_sym_DOT,
    ACTIONS(5652), 22,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
      anon_sym_switch,
      anon_sym_DOT_DOT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_as,
      anon_sym_is,
      anon_sym_DASH_GT,
      anon_sym_with,
  [242695] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4147), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6803), 1,
      anon_sym_LT,
    ACTIONS(9246), 1,
      anon_sym_LPAREN,
    STATE(5001), 1,
      sym_type_argument_list,
    STATE(7690), 1,
      sym_parameter_list,
    ACTIONS(4140), 4,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR,
      anon_sym_DOT,
    STATE(6756), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4138), 25,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_operator,
      anon_sym_this,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [242785] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4147), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6803), 1,
      anon_sym_LT,
    ACTIONS(9246), 1,
      anon_sym_LPAREN,
    STATE(5001), 1,
      sym_type_argument_list,
    STATE(7703), 1,
      sym_parameter_list,
    ACTIONS(4140), 4,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR,
      anon_sym_DOT,
    STATE(6757), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4138), 25,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_operator,
      anon_sym_this,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [242875] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(5741), 1,
      anon_sym_LBRACK,
    ACTIONS(9259), 1,
      aux_sym_preproc_else_token1,
    ACTIONS(9261), 1,
      aux_sym_preproc_elif_token1,
    ACTIONS(9265), 1,
      aux_sym_preproc_if_token3,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(7115), 1,
      aux_sym_class_declaration_repeat1,
    STATE(7300), 1,
      sym_attribute_list,
    STATE(8014), 1,
      sym_enum_member_declaration,
    STATE(8281), 1,
      sym_identifier,
    STATE(9896), 2,
      sym_preproc_else_in_enum_member_declaration,
      sym_preproc_elif_in_enum_member_declaration,
    STATE(6758), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [242975] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(7411), 1,
      anon_sym_LBRACK,
    ACTIONS(7413), 1,
      anon_sym_QMARK,
    ACTIONS(7415), 1,
      anon_sym_STAR,
    ACTIONS(9267), 1,
      anon_sym_DOT,
    ACTIONS(4494), 3,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_EQ_GT,
    STATE(6759), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4492), 26,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      sym_discard,
      anon_sym_and,
      anon_sym_or,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [243065] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4147), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6803), 1,
      anon_sym_LT,
    ACTIONS(9249), 1,
      anon_sym_EQ,
    STATE(5001), 1,
      sym_type_argument_list,
    ACTIONS(9269), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
    ACTIONS(4140), 4,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR,
      anon_sym_DOT,
    STATE(6760), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4138), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [243155] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(8914), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(7386), 1,
      sym_explicit_interface_specifier,
    STATE(7537), 1,
      sym_identifier,
    STATE(8010), 1,
      sym_tuple_pattern,
    STATE(8392), 1,
      sym_variable_declarator,
    STATE(9517), 1,
      sym__name,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(6761), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [243253] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8265), 1,
      sym_identifier,
    STATE(9076), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    ACTIONS(4433), 4,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
    STATE(6762), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4431), 26,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      sym_discard,
      anon_sym_and,
      anon_sym_or,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [243341] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(7411), 1,
      anon_sym_LBRACK,
    ACTIONS(7413), 1,
      anon_sym_QMARK,
    ACTIONS(7415), 1,
      anon_sym_STAR,
    ACTIONS(9271), 1,
      anon_sym_DOT,
    ACTIONS(4494), 3,
      anon_sym_COLON,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
    STATE(6763), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4492), 26,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      sym_discard,
      anon_sym_and,
      anon_sym_or,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [243431] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(7411), 1,
      anon_sym_LBRACK,
    ACTIONS(7413), 1,
      anon_sym_QMARK,
    ACTIONS(7415), 1,
      anon_sym_STAR,
    ACTIONS(9273), 1,
      anon_sym_DOT,
    ACTIONS(4494), 3,
      anon_sym_COLON,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
    STATE(6764), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4492), 26,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      sym_discard,
      anon_sym_and,
      anon_sym_or,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [243521] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(7411), 1,
      anon_sym_LBRACK,
    ACTIONS(7413), 1,
      anon_sym_QMARK,
    ACTIONS(7415), 1,
      anon_sym_STAR,
    ACTIONS(9275), 1,
      anon_sym_DOT,
    ACTIONS(4494), 3,
      anon_sym_COLON,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
    STATE(6765), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4492), 26,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      sym_discard,
      anon_sym_and,
      anon_sym_or,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [243611] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4147), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6803), 1,
      anon_sym_LT,
    ACTIONS(9277), 1,
      anon_sym_EQ,
    STATE(5001), 1,
      sym_type_argument_list,
    ACTIONS(4140), 6,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_QMARK,
      anon_sym_STAR,
      anon_sym_DOT,
    STATE(6766), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4138), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [243698] = 19,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4147), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6803), 1,
      anon_sym_LT,
    ACTIONS(9279), 1,
      anon_sym_COMMA,
    ACTIONS(9282), 1,
      anon_sym_RPAREN,
    STATE(5001), 1,
      sym_type_argument_list,
    STATE(8667), 1,
      aux_sym_tuple_pattern_repeat1,
    ACTIONS(4140), 4,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR,
      anon_sym_DOT,
    STATE(6767), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4138), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [243789] = 19,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4147), 1,
      anon_sym_COLON_COLON,
    ACTIONS(4269), 1,
      anon_sym_COMMA,
    ACTIONS(6803), 1,
      anon_sym_LT,
    ACTIONS(9249), 1,
      anon_sym_EQ,
    ACTIONS(9269), 1,
      anon_sym_RPAREN,
    STATE(5001), 1,
      sym_type_argument_list,
    ACTIONS(4140), 4,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR,
      anon_sym_DOT,
    STATE(6768), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4138), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [243880] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7463), 1,
      anon_sym_LT,
    ACTIONS(9284), 1,
      anon_sym_COLON_COLON,
    STATE(2746), 1,
      sym_type_argument_list,
    ACTIONS(4140), 3,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_DOT,
    STATE(6769), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4138), 27,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_COLON,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      sym_discard,
      anon_sym_and,
      anon_sym_or,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [243965] = 21,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4359), 1,
      sym_discard,
    ACTIONS(7467), 1,
      sym__identifier_token,
    ACTIONS(8455), 1,
      anon_sym_LPAREN,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(4153), 1,
      sym_parenthesized_variable_designation,
    STATE(4156), 1,
      sym_identifier,
    STATE(4167), 1,
      sym__variable_designation,
    ACTIONS(4399), 2,
      anon_sym_COLON,
      anon_sym_EQ_GT,
    ACTIONS(4401), 3,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
    STATE(6770), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 21,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [244060] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7411), 1,
      anon_sym_LBRACK,
    ACTIONS(7413), 1,
      anon_sym_QMARK,
    ACTIONS(7415), 1,
      anon_sym_STAR,
    ACTIONS(9286), 1,
      anon_sym_DOT,
    ACTIONS(4494), 3,
      anon_sym_COLON,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
    STATE(6771), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4492), 26,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      sym_discard,
      anon_sym_and,
      anon_sym_or,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [244147] = 21,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4359), 1,
      sym_discard,
    ACTIONS(7467), 1,
      sym__identifier_token,
    ACTIONS(8455), 1,
      anon_sym_LPAREN,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(4153), 1,
      sym_parenthesized_variable_designation,
    STATE(4156), 1,
      sym_identifier,
    STATE(4190), 1,
      sym__variable_designation,
    ACTIONS(4441), 2,
      anon_sym_COLON,
      anon_sym_EQ_GT,
    ACTIONS(4443), 3,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
    STATE(6772), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 21,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [244242] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4147), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6803), 1,
      anon_sym_LT,
    ACTIONS(9288), 1,
      anon_sym_EQ,
    STATE(5001), 1,
      sym_type_argument_list,
    ACTIONS(4140), 6,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_QMARK,
      anon_sym_STAR,
      anon_sym_DOT,
    STATE(6773), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4138), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [244329] = 21,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4359), 1,
      sym_discard,
    ACTIONS(7467), 1,
      sym__identifier_token,
    ACTIONS(8455), 1,
      anon_sym_LPAREN,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(4153), 1,
      sym_parenthesized_variable_designation,
    STATE(4156), 1,
      sym_identifier,
    STATE(4182), 1,
      sym__variable_designation,
    ACTIONS(4405), 2,
      anon_sym_COLON,
      anon_sym_EQ_GT,
    ACTIONS(4407), 3,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
    STATE(6774), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 21,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [244424] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9290), 1,
      anon_sym_using,
    ACTIONS(3993), 7,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_STAR,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
    STATE(6775), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3995), 25,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_operator,
      anon_sym_this,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [244505] = 21,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4359), 1,
      sym_discard,
    ACTIONS(7467), 1,
      sym__identifier_token,
    ACTIONS(8455), 1,
      anon_sym_LPAREN,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(4153), 1,
      sym_parenthesized_variable_designation,
    STATE(4156), 1,
      sym_identifier,
    STATE(4207), 1,
      sym__variable_designation,
    ACTIONS(4437), 2,
      anon_sym_COLON,
      anon_sym_EQ_GT,
    ACTIONS(4439), 3,
      anon_sym_when,
      anon_sym_and,
      anon_sym_or,
    STATE(6776), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 21,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [244600] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(5741), 1,
      anon_sym_LBRACK,
    ACTIONS(9292), 1,
      anon_sym_COMMA,
    ACTIONS(9294), 1,
      anon_sym_RBRACE,
    ACTIONS(9296), 1,
      aux_sym_preproc_if_token1,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(7138), 1,
      aux_sym_class_declaration_repeat1,
    STATE(7300), 1,
      sym_attribute_list,
    STATE(8672), 1,
      sym_identifier,
    STATE(8669), 2,
      sym_enum_member_declaration,
      sym_preproc_if_in_enum_member_declaration,
    STATE(6777), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [244697] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9298), 1,
      anon_sym_RBRACK,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(5346), 1,
      sym_identifier,
    STATE(8073), 1,
      sym__name,
    STATE(8899), 1,
      sym_attribute,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(6778), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [244789] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9300), 1,
      anon_sym_RBRACK,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(5346), 1,
      sym_identifier,
    STATE(8073), 1,
      sym__name,
    STATE(8899), 1,
      sym_attribute,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(6779), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [244881] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9302), 1,
      anon_sym_RBRACK,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(5346), 1,
      sym_identifier,
    STATE(8073), 1,
      sym__name,
    STATE(8899), 1,
      sym_attribute,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(6780), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [244973] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9304), 1,
      anon_sym_RBRACK,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(5346), 1,
      sym_identifier,
    STATE(8073), 1,
      sym__name,
    STATE(8899), 1,
      sym_attribute,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(6781), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [245065] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9306), 1,
      anon_sym_RBRACK,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(5346), 1,
      sym_identifier,
    STATE(8073), 1,
      sym__name,
    STATE(8899), 1,
      sym_attribute,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(6782), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [245157] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9308), 1,
      anon_sym_RBRACK,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(5346), 1,
      sym_identifier,
    STATE(8073), 1,
      sym__name,
    STATE(8899), 1,
      sym_attribute,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(6783), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [245249] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9310), 1,
      anon_sym_unsafe,
    ACTIONS(9312), 1,
      anon_sym_static,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(7911), 1,
      sym_identifier,
    STATE(8918), 1,
      sym__name,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(6784), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [245341] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(7411), 1,
      anon_sym_LBRACK,
    ACTIONS(7413), 1,
      anon_sym_QMARK,
    ACTIONS(7415), 1,
      anon_sym_STAR,
    ACTIONS(8566), 1,
      anon_sym_DOT,
    ACTIONS(8969), 1,
      anon_sym_LPAREN,
    STATE(8900), 1,
      sym_attribute_argument_list,
    ACTIONS(9314), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(6785), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4492), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [245433] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9316), 1,
      anon_sym_unsafe,
    ACTIONS(9318), 1,
      anon_sym_static,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(7937), 1,
      sym_identifier,
    STATE(8818), 1,
      sym__name,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(6786), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [245525] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9320), 1,
      anon_sym_RBRACK,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(5346), 1,
      sym_identifier,
    STATE(8073), 1,
      sym__name,
    STATE(8899), 1,
      sym_attribute,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(6787), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [245617] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9322), 1,
      anon_sym_RBRACK,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(5346), 1,
      sym_identifier,
    STATE(8073), 1,
      sym__name,
    STATE(8899), 1,
      sym_attribute,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(6788), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [245709] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9324), 1,
      anon_sym_RBRACK,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(5346), 1,
      sym_identifier,
    STATE(8073), 1,
      sym__name,
    STATE(8899), 1,
      sym_attribute,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(6789), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [245801] = 21,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(5741), 1,
      anon_sym_LBRACK,
    ACTIONS(9296), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(9326), 1,
      anon_sym_RBRACE,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(7138), 1,
      aux_sym_class_declaration_repeat1,
    STATE(7300), 1,
      sym_attribute_list,
    STATE(8672), 1,
      sym_identifier,
    STATE(8938), 2,
      sym_enum_member_declaration,
      sym_preproc_if_in_enum_member_declaration,
    STATE(6790), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [245895] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9328), 1,
      anon_sym_operator,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(5346), 1,
      sym_identifier,
    STATE(9081), 1,
      sym__name,
    STATE(9409), 1,
      sym_explicit_interface_specifier,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(6791), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [245987] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9330), 1,
      anon_sym_RBRACK,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(5346), 1,
      sym_identifier,
    STATE(8073), 1,
      sym__name,
    STATE(8899), 1,
      sym_attribute,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(6792), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [246079] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9332), 1,
      anon_sym_RBRACK,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(5346), 1,
      sym_identifier,
    STATE(8073), 1,
      sym__name,
    STATE(8899), 1,
      sym_attribute,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(6793), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [246171] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9334), 1,
      anon_sym_unsafe,
    ACTIONS(9336), 1,
      anon_sym_static,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(7796), 1,
      sym_identifier,
    STATE(8730), 1,
      sym__name,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(6794), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [246263] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4145), 1,
      anon_sym_EQ_GT,
    ACTIONS(4147), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6803), 1,
      anon_sym_LT,
    STATE(5001), 1,
      sym_type_argument_list,
    ACTIONS(4140), 5,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_QMARK,
      anon_sym_STAR,
      anon_sym_DOT,
    STATE(6795), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4138), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [246349] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9338), 1,
      anon_sym_RBRACK,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(5346), 1,
      sym_identifier,
    STATE(8073), 1,
      sym__name,
    STATE(8899), 1,
      sym_attribute,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(6796), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [246441] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9340), 1,
      anon_sym_operator,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(5346), 1,
      sym_identifier,
    STATE(9079), 1,
      sym_explicit_interface_specifier,
    STATE(9081), 1,
      sym__name,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(6797), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [246533] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9342), 1,
      anon_sym_RBRACK,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(5346), 1,
      sym_identifier,
    STATE(8073), 1,
      sym__name,
    STATE(8899), 1,
      sym_attribute,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(6798), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [246625] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9344), 1,
      anon_sym_RBRACK,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(5346), 1,
      sym_identifier,
    STATE(8073), 1,
      sym__name,
    STATE(8899), 1,
      sym_attribute,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(6799), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [246717] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9346), 1,
      anon_sym_RBRACK,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(5346), 1,
      sym_identifier,
    STATE(8073), 1,
      sym__name,
    STATE(8899), 1,
      sym_attribute,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(6800), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [246809] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9348), 1,
      anon_sym_RBRACK,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(5346), 1,
      sym_identifier,
    STATE(8073), 1,
      sym__name,
    STATE(8899), 1,
      sym_attribute,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(6801), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [246901] = 21,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(5741), 1,
      anon_sym_LBRACK,
    ACTIONS(9296), 1,
      aux_sym_preproc_if_token1,
    ACTIONS(9350), 1,
      anon_sym_RBRACE,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(7138), 1,
      aux_sym_class_declaration_repeat1,
    STATE(7300), 1,
      sym_attribute_list,
    STATE(8672), 1,
      sym_identifier,
    STATE(8938), 2,
      sym_enum_member_declaration,
      sym_preproc_if_in_enum_member_declaration,
    STATE(6802), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [246995] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9352), 1,
      anon_sym_RBRACK,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(5346), 1,
      sym_identifier,
    STATE(8073), 1,
      sym__name,
    STATE(8899), 1,
      sym_attribute,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(6803), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [247087] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9354), 1,
      anon_sym_unsafe,
    ACTIONS(9356), 1,
      anon_sym_static,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(7927), 1,
      sym_identifier,
    STATE(8796), 1,
      sym__name,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(6804), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [247179] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9360), 1,
      anon_sym_LPAREN,
    ACTIONS(9362), 6,
      anon_sym_ref,
      anon_sym_readonly,
      anon_sym_in,
      anon_sym_out,
      anon_sym_this,
      anon_sym_scoped,
    STATE(6805), 10,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
      aux_sym__parameter_type_with_modifiers_repeat1,
    ACTIONS(9358), 24,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_delegate,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_var,
      sym_predefined_type,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [247259] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9365), 1,
      anon_sym_RBRACK,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(5346), 1,
      sym_identifier,
    STATE(8073), 1,
      sym__name,
    STATE(8899), 1,
      sym_attribute,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(6806), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [247351] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9367), 1,
      anon_sym_operator,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(5346), 1,
      sym_identifier,
    STATE(9081), 1,
      sym__name,
    STATE(9436), 1,
      sym_explicit_interface_specifier,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(6807), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [247443] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9369), 1,
      anon_sym_RBRACK,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(5346), 1,
      sym_identifier,
    STATE(8073), 1,
      sym__name,
    STATE(8899), 1,
      sym_attribute,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(6808), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [247535] = 19,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9371), 1,
      anon_sym_unsafe,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(5346), 1,
      sym_identifier,
    STATE(8792), 1,
      sym__name,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(6809), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [247624] = 19,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(5346), 1,
      sym_identifier,
    STATE(7692), 1,
      sym__name,
    STATE(8264), 1,
      sym_primary_constructor_base_type,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(6810), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [247713] = 19,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(5346), 1,
      sym_identifier,
    STATE(8073), 1,
      sym__name,
    STATE(8399), 1,
      sym_attribute,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(6811), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [247802] = 19,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(5346), 1,
      sym_identifier,
    STATE(8073), 1,
      sym__name,
    STATE(8586), 1,
      sym_attribute,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(6812), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [247891] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4147), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6803), 1,
      anon_sym_LT,
    ACTIONS(9373), 1,
      anon_sym_in,
    STATE(5001), 1,
      sym_type_argument_list,
    ACTIONS(4140), 4,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR,
      anon_sym_DOT,
    STATE(6813), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4138), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [247976] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3193), 1,
      sym__identifier_token,
    ACTIONS(5741), 1,
      anon_sym_LBRACK,
    STATE(4513), 1,
      sym__reserved_identifier,
    STATE(6864), 1,
      aux_sym_class_declaration_repeat1,
    STATE(7300), 1,
      sym_attribute_list,
    STATE(8576), 1,
      sym_type_parameter,
    STATE(8767), 1,
      sym_identifier,
    ACTIONS(5751), 2,
      anon_sym_in,
      anon_sym_out,
    STATE(6814), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3197), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [248067] = 19,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9375), 1,
      anon_sym_unsafe,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(5346), 1,
      sym_identifier,
    STATE(8918), 1,
      sym__name,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(6815), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [248156] = 19,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9377), 1,
      anon_sym_unsafe,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(5346), 1,
      sym_identifier,
    STATE(8884), 1,
      sym__name,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(6816), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [248245] = 19,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(5346), 1,
      sym_identifier,
    STATE(8073), 1,
      sym__name,
    STATE(8400), 1,
      sym_attribute,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(6817), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [248334] = 19,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(5346), 1,
      sym_identifier,
    STATE(8073), 1,
      sym__name,
    STATE(8410), 1,
      sym_attribute,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(6818), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [248423] = 19,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(5346), 1,
      sym_identifier,
    STATE(8073), 1,
      sym__name,
    STATE(8448), 1,
      sym_attribute,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(6819), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [248512] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4147), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6803), 1,
      anon_sym_LT,
    ACTIONS(9379), 1,
      anon_sym_in,
    STATE(5001), 1,
      sym_type_argument_list,
    ACTIONS(4140), 4,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR,
      anon_sym_DOT,
    STATE(6820), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4138), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [248597] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3193), 1,
      sym__identifier_token,
    ACTIONS(5741), 1,
      anon_sym_LBRACK,
    STATE(4513), 1,
      sym__reserved_identifier,
    STATE(6864), 1,
      aux_sym_class_declaration_repeat1,
    STATE(7300), 1,
      sym_attribute_list,
    STATE(8767), 1,
      sym_identifier,
    STATE(8868), 1,
      sym_type_parameter,
    ACTIONS(5751), 2,
      anon_sym_in,
      anon_sym_out,
    STATE(6821), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3197), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [248688] = 19,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(5346), 1,
      sym_identifier,
    STATE(8073), 1,
      sym__name,
    STATE(8899), 1,
      sym_attribute,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(6822), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [248777] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(2695), 1,
      anon_sym_LPAREN,
    STATE(6823), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(2669), 30,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_ref,
      anon_sym_delegate,
      anon_sym_file,
      anon_sym_readonly,
      anon_sym_in,
      anon_sym_out,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_this,
      anon_sym_scoped,
      anon_sym_var,
      sym_predefined_type,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [248854] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(5741), 1,
      anon_sym_LBRACK,
    ACTIONS(9296), 1,
      aux_sym_preproc_if_token1,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(7138), 1,
      aux_sym_class_declaration_repeat1,
    STATE(7300), 1,
      sym_attribute_list,
    STATE(8672), 1,
      sym_identifier,
    STATE(8938), 2,
      sym_enum_member_declaration,
      sym_preproc_if_in_enum_member_declaration,
    STATE(6824), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [248945] = 19,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(5346), 1,
      sym_identifier,
    STATE(8073), 1,
      sym__name,
    STATE(8512), 1,
      sym_attribute,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(6825), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [249034] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4591), 1,
      anon_sym_EQ_GT,
    ACTIONS(5956), 1,
      anon_sym_RPAREN,
    ACTIONS(4589), 3,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
    STATE(6826), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4587), 26,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      sym_discard,
      anon_sym_and,
      anon_sym_or,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [249115] = 19,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(5346), 1,
      sym_identifier,
    STATE(8073), 1,
      sym__name,
    STATE(8617), 1,
      sym_attribute,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(6827), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [249204] = 19,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9381), 1,
      anon_sym_unsafe,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(5346), 1,
      sym_identifier,
    STATE(8709), 1,
      sym__name,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(6828), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [249293] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9383), 1,
      anon_sym_COMMA,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9387), 1,
      anon_sym_RPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8301), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9765), 1,
      sym__lambda_parameters,
    STATE(6829), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [249383] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(8165), 1,
      anon_sym_RPAREN,
    ACTIONS(9383), 1,
      anon_sym_COMMA,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8301), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9765), 1,
      sym__lambda_parameters,
    STATE(6830), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [249473] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(4359), 1,
      sym_discard,
    ACTIONS(8455), 1,
      anon_sym_LPAREN,
    ACTIONS(9389), 1,
      anon_sym_RPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(4153), 1,
      sym_parenthesized_variable_designation,
    STATE(4156), 1,
      sym_identifier,
    STATE(8562), 1,
      sym__variable_designation,
    STATE(6831), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [249563] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9383), 1,
      anon_sym_COMMA,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9391), 1,
      anon_sym_RPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8301), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9765), 1,
      sym__lambda_parameters,
    STATE(6832), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [249653] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(5346), 1,
      sym_identifier,
    STATE(8361), 1,
      sym__name,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(6833), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [249739] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(5741), 1,
      anon_sym_LBRACK,
    ACTIONS(9393), 1,
      aux_sym_preproc_if_token3,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(7115), 1,
      aux_sym_class_declaration_repeat1,
    STATE(7300), 1,
      sym_attribute_list,
    STATE(8281), 1,
      sym_identifier,
    STATE(9313), 1,
      sym_enum_member_declaration,
    STATE(6834), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [249829] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(7940), 1,
      sym_identifier,
    STATE(8884), 1,
      sym__name,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(6835), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [249915] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(5346), 1,
      sym_identifier,
    STATE(8884), 1,
      sym__name,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(6836), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [250001] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9383), 1,
      anon_sym_COMMA,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9395), 1,
      anon_sym_RPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8301), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9765), 1,
      sym__lambda_parameters,
    STATE(6837), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [250091] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9383), 1,
      anon_sym_COMMA,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9397), 1,
      anon_sym_RPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8301), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9765), 1,
      sym__lambda_parameters,
    STATE(6838), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [250181] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(4359), 1,
      sym_discard,
    ACTIONS(8455), 1,
      anon_sym_LPAREN,
    ACTIONS(9399), 1,
      anon_sym_RPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(4153), 1,
      sym_parenthesized_variable_designation,
    STATE(4156), 1,
      sym_identifier,
    STATE(8647), 1,
      sym__variable_designation,
    STATE(6839), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [250271] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9383), 1,
      anon_sym_COMMA,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9401), 1,
      anon_sym_RPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8301), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9765), 1,
      sym__lambda_parameters,
    STATE(6840), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [250361] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(8231), 1,
      anon_sym_RPAREN,
    ACTIONS(9383), 1,
      anon_sym_COMMA,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8301), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9765), 1,
      sym__lambda_parameters,
    STATE(6841), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [250451] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9383), 1,
      anon_sym_COMMA,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9403), 1,
      anon_sym_RPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8301), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9765), 1,
      sym__lambda_parameters,
    STATE(6842), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [250541] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(4359), 1,
      sym_discard,
    ACTIONS(8455), 1,
      anon_sym_LPAREN,
    ACTIONS(9405), 1,
      anon_sym_RPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(4153), 1,
      sym_parenthesized_variable_designation,
    STATE(4156), 1,
      sym_identifier,
    STATE(8618), 1,
      sym__variable_designation,
    STATE(6843), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [250631] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(5346), 1,
      sym_identifier,
    STATE(8968), 1,
      sym__name,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(6844), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [250717] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9383), 1,
      anon_sym_COMMA,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9407), 1,
      anon_sym_RPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8301), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9765), 1,
      sym__lambda_parameters,
    STATE(6845), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [250807] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(8237), 1,
      anon_sym_RPAREN,
    ACTIONS(9383), 1,
      anon_sym_COMMA,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8301), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9765), 1,
      sym__lambda_parameters,
    STATE(6846), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [250897] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(5346), 1,
      sym_identifier,
    STATE(8792), 1,
      sym__name,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(6847), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [250983] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9383), 1,
      anon_sym_COMMA,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9409), 1,
      anon_sym_RPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8301), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9765), 1,
      sym__lambda_parameters,
    STATE(6848), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [251073] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(7845), 1,
      sym_identifier,
    STATE(8792), 1,
      sym__name,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(6849), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [251159] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(5346), 1,
      sym_identifier,
    STATE(7867), 1,
      sym__name,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(6850), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [251245] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(5346), 1,
      sym_identifier,
    STATE(8048), 1,
      sym__name,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(6851), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [251331] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(7917), 1,
      sym_identifier,
    STATE(8709), 1,
      sym__name,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(6852), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [251417] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9383), 1,
      anon_sym_COMMA,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9411), 1,
      anon_sym_RPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8301), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9765), 1,
      sym__lambda_parameters,
    STATE(6853), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [251507] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9413), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(7559), 1,
      sym_identifier,
    STATE(8010), 1,
      sym_tuple_pattern,
    STATE(8392), 1,
      sym_variable_declarator,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9890), 1,
      sym__lambda_parameters,
    STATE(6854), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [251597] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(5346), 1,
      sym_identifier,
    STATE(8709), 1,
      sym__name,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(6855), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [251683] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(8281), 1,
      anon_sym_RPAREN,
    ACTIONS(9383), 1,
      anon_sym_COMMA,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8301), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9765), 1,
      sym__lambda_parameters,
    STATE(6856), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [251773] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9413), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(7787), 1,
      sym_identifier,
    STATE(8010), 1,
      sym_tuple_pattern,
    STATE(8392), 1,
      sym_variable_declarator,
    STATE(9648), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(6857), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [251863] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(8026), 1,
      anon_sym_RPAREN,
    ACTIONS(9383), 1,
      anon_sym_COMMA,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8301), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9765), 1,
      sym__lambda_parameters,
    STATE(6858), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [251953] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9383), 1,
      anon_sym_COMMA,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9415), 1,
      anon_sym_RPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8301), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9765), 1,
      sym__lambda_parameters,
    STATE(6859), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [252043] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(8289), 1,
      anon_sym_RPAREN,
    ACTIONS(9383), 1,
      anon_sym_COMMA,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8301), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9765), 1,
      sym__lambda_parameters,
    STATE(6860), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [252133] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(8316), 1,
      anon_sym_RPAREN,
    ACTIONS(9383), 1,
      anon_sym_COMMA,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8301), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9765), 1,
      sym__lambda_parameters,
    STATE(6861), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [252223] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9413), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(7555), 1,
      sym_identifier,
    STATE(8010), 1,
      sym_tuple_pattern,
    STATE(8392), 1,
      sym_variable_declarator,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9890), 1,
      sym__lambda_parameters,
    STATE(6862), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [252313] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(8037), 1,
      anon_sym_RPAREN,
    ACTIONS(9383), 1,
      anon_sym_COMMA,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8301), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9765), 1,
      sym__lambda_parameters,
    STATE(6863), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [252403] = 19,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3193), 1,
      sym__identifier_token,
    ACTIONS(5741), 1,
      anon_sym_LBRACK,
    STATE(4513), 1,
      sym__reserved_identifier,
    STATE(6970), 1,
      aux_sym_class_declaration_repeat1,
    STATE(7300), 1,
      sym_attribute_list,
    STATE(8947), 1,
      sym_identifier,
    ACTIONS(9417), 2,
      anon_sym_in,
      anon_sym_out,
    STATE(6864), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3197), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [252491] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9383), 1,
      anon_sym_COMMA,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8295), 1,
      sym_identifier,
    STATE(8436), 1,
      sym_using_variable_declarator,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9765), 1,
      sym__lambda_parameters,
    STATE(6865), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [252581] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9383), 1,
      anon_sym_COMMA,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9419), 1,
      anon_sym_RPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8301), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9765), 1,
      sym__lambda_parameters,
    STATE(6866), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [252671] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(8151), 1,
      anon_sym_RPAREN,
    ACTIONS(9383), 1,
      anon_sym_COMMA,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8301), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9765), 1,
      sym__lambda_parameters,
    STATE(6867), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [252761] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(5346), 1,
      sym_identifier,
    STATE(8864), 1,
      sym__name,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(6868), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [252847] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9383), 1,
      anon_sym_COMMA,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9421), 1,
      anon_sym_RPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8301), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9765), 1,
      sym__lambda_parameters,
    STATE(6869), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [252937] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9413), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(7558), 1,
      sym_identifier,
    STATE(8010), 1,
      sym_tuple_pattern,
    STATE(8392), 1,
      sym_variable_declarator,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9890), 1,
      sym__lambda_parameters,
    STATE(6870), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [253027] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9383), 1,
      anon_sym_COMMA,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9423), 1,
      anon_sym_RPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8301), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9765), 1,
      sym__lambda_parameters,
    STATE(6871), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [253117] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9383), 1,
      anon_sym_COMMA,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9425), 1,
      anon_sym_RPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8301), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9765), 1,
      sym__lambda_parameters,
    STATE(6872), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [253207] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(8285), 1,
      anon_sym_RPAREN,
    ACTIONS(9383), 1,
      anon_sym_COMMA,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8301), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9765), 1,
      sym__lambda_parameters,
    STATE(6873), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [253297] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(8243), 1,
      anon_sym_RPAREN,
    ACTIONS(9383), 1,
      anon_sym_COMMA,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8301), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9765), 1,
      sym__lambda_parameters,
    STATE(6874), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [253387] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(7911), 1,
      sym_identifier,
    STATE(8918), 1,
      sym__name,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(6875), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [253473] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9383), 1,
      anon_sym_COMMA,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9427), 1,
      anon_sym_RPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8301), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9765), 1,
      sym__lambda_parameters,
    STATE(6876), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [253563] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(8035), 1,
      anon_sym_RPAREN,
    ACTIONS(9383), 1,
      anon_sym_COMMA,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8301), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9765), 1,
      sym__lambda_parameters,
    STATE(6877), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [253653] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(8303), 1,
      anon_sym_RPAREN,
    ACTIONS(9383), 1,
      anon_sym_COMMA,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8301), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9765), 1,
      sym__lambda_parameters,
    STATE(6878), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [253743] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(5346), 1,
      sym_identifier,
    STATE(8814), 1,
      sym__name,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(6879), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [253829] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9413), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(7560), 1,
      sym_identifier,
    STATE(8010), 1,
      sym_tuple_pattern,
    STATE(8392), 1,
      sym_variable_declarator,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9890), 1,
      sym__lambda_parameters,
    STATE(6880), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [253919] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(8219), 1,
      anon_sym_RPAREN,
    ACTIONS(9383), 1,
      anon_sym_COMMA,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8301), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9765), 1,
      sym__lambda_parameters,
    STATE(6881), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [254009] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(8091), 1,
      anon_sym_RPAREN,
    ACTIONS(9383), 1,
      anon_sym_COMMA,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8301), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9765), 1,
      sym__lambda_parameters,
    STATE(6882), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [254099] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9383), 1,
      anon_sym_COMMA,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9429), 1,
      anon_sym_RPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8301), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9765), 1,
      sym__lambda_parameters,
    STATE(6883), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [254189] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9383), 1,
      anon_sym_COMMA,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9431), 1,
      anon_sym_RPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8301), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9765), 1,
      sym__lambda_parameters,
    STATE(6884), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [254279] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(4359), 1,
      sym_discard,
    ACTIONS(8455), 1,
      anon_sym_LPAREN,
    ACTIONS(9433), 1,
      anon_sym_RPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(4153), 1,
      sym_parenthesized_variable_designation,
    STATE(4156), 1,
      sym_identifier,
    STATE(8645), 1,
      sym__variable_designation,
    STATE(6885), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [254369] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(8163), 1,
      anon_sym_RPAREN,
    ACTIONS(9383), 1,
      anon_sym_COMMA,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8301), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9765), 1,
      sym__lambda_parameters,
    STATE(6886), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [254459] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(8043), 1,
      anon_sym_RPAREN,
    ACTIONS(9383), 1,
      anon_sym_COMMA,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8301), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9765), 1,
      sym__lambda_parameters,
    STATE(6887), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [254549] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(8131), 1,
      anon_sym_RPAREN,
    ACTIONS(9383), 1,
      anon_sym_COMMA,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8301), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9765), 1,
      sym__lambda_parameters,
    STATE(6888), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [254639] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9435), 1,
      anon_sym_DOT,
    ACTIONS(4455), 3,
      anon_sym_COLON,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
    STATE(6889), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4453), 26,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      sym_discard,
      anon_sym_and,
      anon_sym_or,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [254717] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(4359), 1,
      sym_discard,
    ACTIONS(8455), 1,
      anon_sym_LPAREN,
    ACTIONS(9437), 1,
      anon_sym_RPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(4153), 1,
      sym_parenthesized_variable_designation,
    STATE(4156), 1,
      sym_identifier,
    STATE(8699), 1,
      sym__variable_designation,
    STATE(6890), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [254807] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9383), 1,
      anon_sym_COMMA,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9439), 1,
      anon_sym_RPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8301), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9765), 1,
      sym__lambda_parameters,
    STATE(6891), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [254897] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(7922), 1,
      anon_sym_RPAREN,
    ACTIONS(9383), 1,
      anon_sym_COMMA,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8301), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9765), 1,
      sym__lambda_parameters,
    STATE(6892), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [254987] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9383), 1,
      anon_sym_COMMA,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9441), 1,
      anon_sym_RPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8301), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9765), 1,
      sym__lambda_parameters,
    STATE(6893), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [255077] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9413), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(7558), 1,
      sym_identifier,
    STATE(8010), 1,
      sym_tuple_pattern,
    STATE(8392), 1,
      sym_variable_declarator,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9765), 1,
      sym__lambda_parameters,
    STATE(6894), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [255167] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9383), 1,
      anon_sym_COMMA,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9443), 1,
      anon_sym_RPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8301), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9765), 1,
      sym__lambda_parameters,
    STATE(6895), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [255257] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(8287), 1,
      anon_sym_RPAREN,
    ACTIONS(9383), 1,
      anon_sym_COMMA,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8301), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9765), 1,
      sym__lambda_parameters,
    STATE(6896), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [255347] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(5346), 1,
      sym_identifier,
    STATE(8319), 1,
      sym__name,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(6897), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [255433] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(8028), 1,
      anon_sym_RPAREN,
    ACTIONS(9383), 1,
      anon_sym_COMMA,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8301), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9765), 1,
      sym__lambda_parameters,
    STATE(6898), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [255523] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9383), 1,
      anon_sym_COMMA,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9445), 1,
      anon_sym_RPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8301), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9765), 1,
      sym__lambda_parameters,
    STATE(6899), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [255613] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9383), 1,
      anon_sym_COMMA,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9447), 1,
      anon_sym_RPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8301), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9765), 1,
      sym__lambda_parameters,
    STATE(6900), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [255703] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9454), 1,
      anon_sym_LPAREN,
    ACTIONS(9451), 2,
      anon_sym_static,
      anon_sym_async,
    STATE(6901), 10,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
      aux_sym_lambda_expression_repeat1,
    ACTIONS(9449), 26,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_ref,
      anon_sym_delegate,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      sym_predefined_type,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [255781] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9413), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(7787), 1,
      sym_identifier,
    STATE(8010), 1,
      sym_tuple_pattern,
    STATE(8392), 1,
      sym_variable_declarator,
    STATE(9534), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(6902), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [255871] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(8207), 1,
      anon_sym_RPAREN,
    ACTIONS(9383), 1,
      anon_sym_COMMA,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8301), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9765), 1,
      sym__lambda_parameters,
    STATE(6903), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [255961] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(5346), 1,
      sym_identifier,
    STATE(8497), 1,
      sym__name,
    STATE(5007), 3,
      sym_alias_qualified_name,
      sym__simple_name,
      sym_qualified_name,
    STATE(6904), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [256047] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9383), 1,
      anon_sym_COMMA,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9456), 1,
      anon_sym_RPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8301), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9765), 1,
      sym__lambda_parameters,
    STATE(6905), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [256137] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(8079), 1,
      anon_sym_RPAREN,
    ACTIONS(9383), 1,
      anon_sym_COMMA,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8301), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9765), 1,
      sym__lambda_parameters,
    STATE(6906), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [256227] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(7970), 1,
      anon_sym_RPAREN,
    ACTIONS(9383), 1,
      anon_sym_COMMA,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8301), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9765), 1,
      sym__lambda_parameters,
    STATE(6907), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [256317] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(8081), 1,
      anon_sym_RPAREN,
    ACTIONS(9383), 1,
      anon_sym_COMMA,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8301), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9765), 1,
      sym__lambda_parameters,
    STATE(6908), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [256407] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9383), 1,
      anon_sym_COMMA,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9458), 1,
      anon_sym_RPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8301), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9765), 1,
      sym__lambda_parameters,
    STATE(6909), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [256497] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4494), 1,
      anon_sym_LPAREN,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(7411), 1,
      anon_sym_LBRACK,
    ACTIONS(7413), 1,
      anon_sym_QMARK,
    ACTIONS(7415), 1,
      anon_sym_STAR,
    ACTIONS(9460), 1,
      anon_sym_DOT,
    STATE(6910), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4492), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [256582] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4494), 1,
      anon_sym_LPAREN,
    ACTIONS(5233), 1,
      anon_sym_DASH_GT,
    ACTIONS(7411), 1,
      anon_sym_LBRACK,
    ACTIONS(7413), 1,
      anon_sym_QMARK,
    ACTIONS(7415), 1,
      anon_sym_STAR,
    ACTIONS(9462), 1,
      anon_sym_DOT,
    STATE(6911), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4492), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [256667] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4494), 1,
      anon_sym_LPAREN,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(7411), 1,
      anon_sym_LBRACK,
    ACTIONS(7413), 1,
      anon_sym_QMARK,
    ACTIONS(7415), 1,
      anon_sym_STAR,
    ACTIONS(9464), 1,
      anon_sym_DOT,
    STATE(6912), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4492), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [256752] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4494), 1,
      anon_sym_LPAREN,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(7411), 1,
      anon_sym_LBRACK,
    ACTIONS(7413), 1,
      anon_sym_QMARK,
    ACTIONS(7415), 1,
      anon_sym_STAR,
    ACTIONS(9466), 1,
      anon_sym_DOT,
    STATE(6913), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4492), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [256837] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4494), 1,
      anon_sym_LPAREN,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(7411), 1,
      anon_sym_LBRACK,
    ACTIONS(7413), 1,
      anon_sym_QMARK,
    ACTIONS(7415), 1,
      anon_sym_STAR,
    ACTIONS(9460), 1,
      anon_sym_DOT,
    STATE(6914), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4492), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [256922] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4494), 1,
      anon_sym_LPAREN,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(7411), 1,
      anon_sym_LBRACK,
    ACTIONS(7413), 1,
      anon_sym_QMARK,
    ACTIONS(7415), 1,
      anon_sym_STAR,
    ACTIONS(9468), 1,
      anon_sym_DOT,
    STATE(6915), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4492), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [257007] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4494), 1,
      anon_sym_LPAREN,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(7411), 1,
      anon_sym_LBRACK,
    ACTIONS(7413), 1,
      anon_sym_QMARK,
    ACTIONS(7415), 1,
      anon_sym_STAR,
    ACTIONS(9468), 1,
      anon_sym_DOT,
    STATE(6916), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4492), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [257092] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4494), 1,
      anon_sym_LPAREN,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(7411), 1,
      anon_sym_LBRACK,
    ACTIONS(7413), 1,
      anon_sym_QMARK,
    ACTIONS(7415), 1,
      anon_sym_STAR,
    ACTIONS(9470), 1,
      anon_sym_DOT,
    STATE(6917), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4492), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [257177] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4494), 1,
      anon_sym_LPAREN,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(7411), 1,
      anon_sym_LBRACK,
    ACTIONS(7413), 1,
      anon_sym_QMARK,
    ACTIONS(7415), 1,
      anon_sym_STAR,
    ACTIONS(9472), 1,
      anon_sym_DOT,
    STATE(6918), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4492), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [257262] = 19,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(4359), 1,
      sym_discard,
    ACTIONS(8455), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(4153), 1,
      sym_parenthesized_variable_designation,
    STATE(4156), 1,
      sym_identifier,
    STATE(8797), 1,
      sym__variable_designation,
    STATE(6919), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [257349] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4494), 1,
      anon_sym_LPAREN,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(7411), 1,
      anon_sym_LBRACK,
    ACTIONS(7413), 1,
      anon_sym_QMARK,
    ACTIONS(7415), 1,
      anon_sym_STAR,
    ACTIONS(9474), 1,
      anon_sym_DOT,
    STATE(6920), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4492), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [257434] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4494), 1,
      anon_sym_LPAREN,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7411), 1,
      anon_sym_LBRACK,
    ACTIONS(7413), 1,
      anon_sym_QMARK,
    ACTIONS(7415), 1,
      anon_sym_STAR,
    ACTIONS(9476), 1,
      anon_sym_DOT,
    STATE(6921), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4492), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [257519] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4494), 1,
      anon_sym_LPAREN,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(7411), 1,
      anon_sym_LBRACK,
    ACTIONS(7413), 1,
      anon_sym_QMARK,
    ACTIONS(7415), 1,
      anon_sym_STAR,
    ACTIONS(9478), 1,
      anon_sym_DOT,
    STATE(6922), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4492), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [257604] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9482), 1,
      anon_sym_LPAREN,
    STATE(6923), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(9480), 28,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_static,
      anon_sym_ref,
      anon_sym_delegate,
      anon_sym_async,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      sym_predefined_type,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [257679] = 19,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9383), 1,
      anon_sym_COMMA,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8420), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9765), 1,
      sym__lambda_parameters,
    STATE(6924), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [257766] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4494), 1,
      anon_sym_LPAREN,
    ACTIONS(5233), 1,
      anon_sym_DASH_GT,
    ACTIONS(7411), 1,
      anon_sym_LBRACK,
    ACTIONS(7413), 1,
      anon_sym_QMARK,
    ACTIONS(7415), 1,
      anon_sym_STAR,
    ACTIONS(9484), 1,
      anon_sym_DOT,
    STATE(6925), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4492), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [257851] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4494), 1,
      anon_sym_LPAREN,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(7411), 1,
      anon_sym_LBRACK,
    ACTIONS(7413), 1,
      anon_sym_QMARK,
    ACTIONS(7415), 1,
      anon_sym_STAR,
    ACTIONS(9486), 1,
      anon_sym_DOT,
    STATE(6926), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4492), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [257936] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4494), 1,
      anon_sym_LPAREN,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(7411), 1,
      anon_sym_LBRACK,
    ACTIONS(7413), 1,
      anon_sym_QMARK,
    ACTIONS(7415), 1,
      anon_sym_STAR,
    ACTIONS(9488), 1,
      anon_sym_DOT,
    STATE(6927), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4492), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [258021] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4494), 1,
      anon_sym_LPAREN,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(7411), 1,
      anon_sym_LBRACK,
    ACTIONS(7413), 1,
      anon_sym_QMARK,
    ACTIONS(7415), 1,
      anon_sym_STAR,
    ACTIONS(9490), 1,
      anon_sym_DOT,
    STATE(6928), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4492), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [258106] = 19,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7467), 1,
      sym__identifier_token,
    ACTIONS(9413), 1,
      anon_sym_LPAREN,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(8949), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9835), 1,
      sym_tuple_pattern,
    STATE(9912), 1,
      sym__lambda_parameters,
    STATE(6929), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [258193] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4494), 1,
      anon_sym_LPAREN,
    ACTIONS(7411), 1,
      anon_sym_LBRACK,
    ACTIONS(7413), 1,
      anon_sym_QMARK,
    ACTIONS(7415), 1,
      anon_sym_STAR,
    ACTIONS(4636), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    STATE(6930), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4492), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [258276] = 19,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7467), 1,
      sym__identifier_token,
    ACTIONS(9413), 1,
      anon_sym_LPAREN,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(8929), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9772), 1,
      sym_tuple_pattern,
    STATE(9912), 1,
      sym__lambda_parameters,
    STATE(6931), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [258363] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4494), 1,
      anon_sym_LPAREN,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(7411), 1,
      anon_sym_LBRACK,
    ACTIONS(7413), 1,
      anon_sym_QMARK,
    ACTIONS(7415), 1,
      anon_sym_STAR,
    ACTIONS(9492), 1,
      anon_sym_DOT,
    STATE(6932), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4492), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [258448] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4494), 1,
      anon_sym_LPAREN,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(7411), 1,
      anon_sym_LBRACK,
    ACTIONS(7413), 1,
      anon_sym_QMARK,
    ACTIONS(7415), 1,
      anon_sym_STAR,
    ACTIONS(9486), 1,
      anon_sym_DOT,
    STATE(6933), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4492), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [258533] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4494), 1,
      anon_sym_LPAREN,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(7411), 1,
      anon_sym_LBRACK,
    ACTIONS(7413), 1,
      anon_sym_QMARK,
    ACTIONS(7415), 1,
      anon_sym_STAR,
    ACTIONS(9494), 1,
      anon_sym_DOT,
    STATE(6934), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4492), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [258618] = 19,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7467), 1,
      sym__identifier_token,
    ACTIONS(9413), 1,
      anon_sym_LPAREN,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(8722), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9820), 1,
      sym_tuple_pattern,
    STATE(9912), 1,
      sym__lambda_parameters,
    STATE(6935), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [258705] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9496), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(5128), 1,
      sym__simple_name,
    STATE(5387), 1,
      sym_identifier,
    ACTIONS(9502), 2,
      anon_sym_operator,
      anon_sym_this,
    STATE(6936), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(9499), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [258790] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4494), 1,
      anon_sym_LPAREN,
    ACTIONS(4975), 1,
      anon_sym_DASH_GT,
    ACTIONS(7411), 1,
      anon_sym_LBRACK,
    ACTIONS(7413), 1,
      anon_sym_QMARK,
    ACTIONS(7415), 1,
      anon_sym_STAR,
    ACTIONS(9504), 1,
      anon_sym_DOT,
    STATE(6937), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4492), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [258875] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4494), 1,
      anon_sym_LPAREN,
    ACTIONS(7411), 1,
      anon_sym_LBRACK,
    ACTIONS(7413), 1,
      anon_sym_QMARK,
    ACTIONS(7415), 1,
      anon_sym_STAR,
    ACTIONS(7477), 1,
      anon_sym_DOT,
    ACTIONS(9506), 1,
      anon_sym_SEMI,
    STATE(6938), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4492), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [258960] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9510), 1,
      anon_sym_LPAREN,
    STATE(6939), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(9508), 28,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_ref,
      anon_sym_delegate,
      anon_sym_file,
      anon_sym_in,
      anon_sym_out,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      sym_predefined_type,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [259035] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4494), 1,
      anon_sym_LPAREN,
    ACTIONS(7411), 1,
      anon_sym_LBRACK,
    ACTIONS(7413), 1,
      anon_sym_QMARK,
    ACTIONS(7415), 1,
      anon_sym_STAR,
    ACTIONS(5233), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    STATE(6940), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4492), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [259118] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4494), 1,
      anon_sym_LPAREN,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(7411), 1,
      anon_sym_LBRACK,
    ACTIONS(7413), 1,
      anon_sym_QMARK,
    ACTIONS(7415), 1,
      anon_sym_STAR,
    ACTIONS(9492), 1,
      anon_sym_DOT,
    STATE(6941), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4492), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [259203] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4494), 1,
      anon_sym_LPAREN,
    ACTIONS(7411), 1,
      anon_sym_LBRACK,
    ACTIONS(7413), 1,
      anon_sym_QMARK,
    ACTIONS(7415), 1,
      anon_sym_STAR,
    ACTIONS(7477), 1,
      anon_sym_DOT,
    ACTIONS(9512), 1,
      anon_sym_SEMI,
    STATE(6942), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4492), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [259288] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4494), 1,
      anon_sym_LPAREN,
    ACTIONS(4604), 1,
      anon_sym_DASH_GT,
    ACTIONS(7411), 1,
      anon_sym_LBRACK,
    ACTIONS(7413), 1,
      anon_sym_QMARK,
    ACTIONS(7415), 1,
      anon_sym_STAR,
    ACTIONS(9514), 1,
      anon_sym_DOT,
    STATE(6943), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4492), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [259373] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4494), 1,
      anon_sym_LPAREN,
    ACTIONS(7411), 1,
      anon_sym_LBRACK,
    ACTIONS(7413), 1,
      anon_sym_QMARK,
    ACTIONS(7415), 1,
      anon_sym_STAR,
    ACTIONS(4975), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    STATE(6944), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4492), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [259456] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8988), 1,
      sym_identifier,
    ACTIONS(9516), 4,
      anon_sym_Cdecl,
      anon_sym_Stdcall,
      anon_sym_Thiscall,
      anon_sym_Fastcall,
    STATE(6945), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [259537] = 19,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7467), 1,
      sym__identifier_token,
    ACTIONS(9413), 1,
      anon_sym_LPAREN,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(8830), 1,
      sym_identifier,
    STATE(9535), 1,
      sym_tuple_pattern,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9912), 1,
      sym__lambda_parameters,
    STATE(6946), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [259624] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8622), 1,
      sym_identifier,
    ACTIONS(9518), 4,
      anon_sym_Cdecl,
      anon_sym_Stdcall,
      anon_sym_Thiscall,
      anon_sym_Fastcall,
    STATE(6947), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [259705] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4494), 1,
      anon_sym_LPAREN,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(7411), 1,
      anon_sym_LBRACK,
    ACTIONS(7413), 1,
      anon_sym_QMARK,
    ACTIONS(7415), 1,
      anon_sym_STAR,
    ACTIONS(9520), 1,
      anon_sym_DOT,
    STATE(6948), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4492), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [259790] = 19,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7467), 1,
      sym__identifier_token,
    ACTIONS(9413), 1,
      anon_sym_LPAREN,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(8834), 1,
      sym_identifier,
    STATE(9545), 1,
      sym_tuple_pattern,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9912), 1,
      sym__lambda_parameters,
    STATE(6949), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [259877] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4494), 1,
      anon_sym_LPAREN,
    ACTIONS(4636), 1,
      anon_sym_DASH_GT,
    ACTIONS(7411), 1,
      anon_sym_LBRACK,
    ACTIONS(7413), 1,
      anon_sym_QMARK,
    ACTIONS(7415), 1,
      anon_sym_STAR,
    ACTIONS(9472), 1,
      anon_sym_DOT,
    STATE(6950), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4492), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [259962] = 19,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7467), 1,
      sym__identifier_token,
    ACTIONS(9413), 1,
      anon_sym_LPAREN,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(8906), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9718), 1,
      sym_tuple_pattern,
    STATE(9912), 1,
      sym__lambda_parameters,
    STATE(6951), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [260049] = 19,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7467), 1,
      sym__identifier_token,
    ACTIONS(9413), 1,
      anon_sym_LPAREN,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(8908), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9722), 1,
      sym_tuple_pattern,
    STATE(9912), 1,
      sym__lambda_parameters,
    STATE(6952), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [260136] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4494), 1,
      anon_sym_LPAREN,
    ACTIONS(7411), 1,
      anon_sym_LBRACK,
    ACTIONS(7413), 1,
      anon_sym_QMARK,
    ACTIONS(7415), 1,
      anon_sym_STAR,
    ACTIONS(5247), 2,
      anon_sym_DOT,
      anon_sym_DASH_GT,
    STATE(6953), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4492), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [260219] = 19,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7467), 1,
      sym__identifier_token,
    ACTIONS(9413), 1,
      anon_sym_LPAREN,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(8928), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9770), 1,
      sym_tuple_pattern,
    STATE(9912), 1,
      sym__lambda_parameters,
    STATE(6954), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [260306] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4494), 1,
      anon_sym_LPAREN,
    ACTIONS(5247), 1,
      anon_sym_DASH_GT,
    ACTIONS(7411), 1,
      anon_sym_LBRACK,
    ACTIONS(7413), 1,
      anon_sym_QMARK,
    ACTIONS(7415), 1,
      anon_sym_STAR,
    ACTIONS(9522), 1,
      anon_sym_DOT,
    STATE(6955), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4492), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [260391] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9648), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(6956), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [260475] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9064), 1,
      sym__lambda_parameters,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(6957), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [260559] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4433), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9064), 1,
      sym__lambda_parameters,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(6958), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4431), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [260641] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8231), 1,
      sym_identifier,
    STATE(9550), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(6959), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [260725] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9248), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(6960), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [260809] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9297), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(6961), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [260893] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9908), 1,
      sym__lambda_parameters,
    STATE(6962), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [260977] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4433), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9908), 1,
      sym__lambda_parameters,
    STATE(6963), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4431), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [261059] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8265), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9765), 1,
      sym__lambda_parameters,
    STATE(6964), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [261143] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9024), 1,
      sym__lambda_parameters,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(6965), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [261227] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9778), 1,
      sym__lambda_parameters,
    STATE(6966), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [261311] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9938), 1,
      sym__lambda_parameters,
    STATE(6967), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [261395] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4433), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9938), 1,
      sym__lambda_parameters,
    STATE(6968), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4431), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [261477] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9233), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(6969), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [261561] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9524), 1,
      anon_sym_LBRACK,
    STATE(7300), 1,
      sym_attribute_list,
    STATE(6970), 10,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
      aux_sym_class_declaration_repeat1,
    ACTIONS(5394), 25,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_in,
      anon_sym_out,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [261637] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9453), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(6971), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [261721] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(8914), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(7980), 1,
      sym_identifier,
    STATE(8010), 1,
      sym_tuple_pattern,
    STATE(8694), 1,
      sym_variable_declarator,
    STATE(6972), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [261805] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9706), 1,
      sym__lambda_parameters,
    STATE(6973), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [261889] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4433), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9706), 1,
      sym__lambda_parameters,
    STATE(6974), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4431), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [261971] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9917), 1,
      sym__lambda_parameters,
    STATE(6975), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [262055] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9925), 1,
      sym__lambda_parameters,
    STATE(6976), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [262139] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9012), 1,
      sym__lambda_parameters,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(6977), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [262223] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(8914), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(7636), 1,
      sym_identifier,
    STATE(8010), 1,
      sym_tuple_pattern,
    STATE(8392), 1,
      sym_variable_declarator,
    STATE(6978), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [262307] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9200), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(6979), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [262391] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4433), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9200), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(6980), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4431), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [262473] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9256), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(6981), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [262557] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9267), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(6982), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [262641] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9502), 1,
      anon_sym_operator,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(5128), 1,
      sym__simple_name,
    STATE(5387), 1,
      sym_identifier,
    STATE(6983), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [262725] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9362), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(6984), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [262809] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4433), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9362), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(6985), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4431), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [262891] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9424), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(6986), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [262975] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9444), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(6987), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [263059] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9582), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(6988), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [263143] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4433), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9582), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(6989), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4431), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [263225] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9606), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(6990), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [263309] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9612), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(6991), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [263393] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9638), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(6992), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [263477] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4433), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9638), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(6993), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4431), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [263559] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9657), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(6994), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [263643] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9672), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(6995), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [263727] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9698), 1,
      sym__lambda_parameters,
    STATE(6996), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [263811] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4433), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9698), 1,
      sym__lambda_parameters,
    STATE(6997), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4431), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [263893] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9719), 1,
      sym__lambda_parameters,
    STATE(6998), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [263977] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9830), 1,
      sym__lambda_parameters,
    STATE(6999), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [264061] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9733), 1,
      sym__lambda_parameters,
    STATE(7000), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [264145] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9774), 1,
      sym__lambda_parameters,
    STATE(7001), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [264229] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4433), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9774), 1,
      sym__lambda_parameters,
    STATE(7002), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4431), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [264311] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9793), 1,
      sym__lambda_parameters,
    STATE(7003), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [264395] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9805), 1,
      sym__lambda_parameters,
    STATE(7004), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [264479] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4433), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9830), 1,
      sym__lambda_parameters,
    STATE(7005), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4431), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [264561] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9829), 1,
      sym__lambda_parameters,
    STATE(7006), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [264645] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4433), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9829), 1,
      sym__lambda_parameters,
    STATE(7007), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4431), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [264727] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9838), 1,
      sym__lambda_parameters,
    STATE(7008), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [264811] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9848), 1,
      sym__lambda_parameters,
    STATE(7009), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [264895] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9268), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7010), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [264979] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4433), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9268), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7011), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4431), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [265061] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9278), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7012), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [265145] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9289), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7013), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [265229] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9870), 1,
      sym__lambda_parameters,
    STATE(7014), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [265313] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4433), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9870), 1,
      sym__lambda_parameters,
    STATE(7015), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4431), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [265395] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9885), 1,
      sym__lambda_parameters,
    STATE(7016), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [265479] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9900), 1,
      sym__lambda_parameters,
    STATE(7017), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [265563] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9945), 1,
      sym__lambda_parameters,
    STATE(7018), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [265647] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4433), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9945), 1,
      sym__lambda_parameters,
    STATE(7019), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4431), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [265729] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9964), 1,
      sym__lambda_parameters,
    STATE(7020), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [265813] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9970), 1,
      sym__lambda_parameters,
    STATE(7021), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [265897] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9049), 1,
      sym__lambda_parameters,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7022), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [265981] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4433), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9049), 1,
      sym__lambda_parameters,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7023), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4431), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [266063] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9106), 1,
      sym__lambda_parameters,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7024), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [266147] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9118), 1,
      sym__lambda_parameters,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7025), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [266231] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8310), 1,
      sym_identifier,
    STATE(9170), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7026), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [266315] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9884), 1,
      sym__lambda_parameters,
    STATE(7027), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [266399] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4433), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9884), 1,
      sym__lambda_parameters,
    STATE(7028), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4431), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [266481] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8997), 1,
      sym__lambda_parameters,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7029), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [266565] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9006), 1,
      sym__lambda_parameters,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7030), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [266649] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9449), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7031), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [266733] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9247), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7032), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [266817] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4433), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9247), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7033), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4431), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [266899] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9168), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7034), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [266983] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9189), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7035), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [267067] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9223), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7036), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [267151] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4433), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9223), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7037), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4431), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [267233] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9246), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7038), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [267317] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9255), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7039), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [267401] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9238), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7040), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [267485] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4433), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9238), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7041), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4431), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [267567] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9412), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7042), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [267651] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9434), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7043), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [267735] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9320), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7044), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [267819] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4433), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9320), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7045), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4431), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [267901] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9757), 1,
      sym__lambda_parameters,
    STATE(7046), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [267985] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9918), 1,
      sym__lambda_parameters,
    STATE(7047), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [268069] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4433), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9449), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7048), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4431), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [268151] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9029), 1,
      sym__lambda_parameters,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7049), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [268235] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4433), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9029), 1,
      sym__lambda_parameters,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7050), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4431), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [268317] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9058), 1,
      sym__lambda_parameters,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7051), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [268401] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9073), 1,
      sym__lambda_parameters,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7052), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [268485] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9188), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7053), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [268569] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4433), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9188), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7054), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4431), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [268651] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9202), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7055), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [268735] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9205), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7056), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [268819] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9236), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7057), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [268903] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4433), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9236), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7058), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4431), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [268985] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9251), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7059), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [269069] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9264), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7060), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [269153] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9292), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7061), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [269237] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4433), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9292), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7062), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4431), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [269319] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9309), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7063), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [269403] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9316), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7064), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [269487] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9390), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7065), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [269571] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4433), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9390), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7066), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4431), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [269653] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9448), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7067), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [269737] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9493), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7068), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [269821] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9646), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7069), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [269905] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4433), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9646), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7070), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4431), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [269987] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9679), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7071), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [270071] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9920), 1,
      sym__lambda_parameters,
    STATE(7072), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [270155] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9335), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7073), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [270239] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4433), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9335), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7074), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4431), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [270321] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9341), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7075), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [270405] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9344), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7076), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [270489] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9845), 1,
      sym__lambda_parameters,
    STATE(7077), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [270573] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4433), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9845), 1,
      sym__lambda_parameters,
    STATE(7078), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4431), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [270655] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9898), 1,
      sym__lambda_parameters,
    STATE(7079), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [270739] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9944), 1,
      sym__lambda_parameters,
    STATE(7080), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [270823] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9357), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7081), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [270907] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4433), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9357), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7082), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4431), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [270989] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9369), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7083), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [271073] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9375), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7084), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [271157] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9035), 1,
      sym__lambda_parameters,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7085), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [271241] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4433), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9035), 1,
      sym__lambda_parameters,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7086), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4431), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [271323] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9046), 1,
      sym__lambda_parameters,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7087), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [271407] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9050), 1,
      sym__lambda_parameters,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7088), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [271491] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8202), 1,
      sym_identifier,
    STATE(9550), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7089), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [271575] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(8914), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(7671), 1,
      sym_identifier,
    STATE(8010), 1,
      sym_tuple_pattern,
    STATE(8392), 1,
      sym_variable_declarator,
    STATE(7090), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [271659] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9082), 1,
      sym__lambda_parameters,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7091), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [271743] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4433), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9082), 1,
      sym__lambda_parameters,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7092), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4431), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [271825] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9089), 1,
      sym__lambda_parameters,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7093), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [271909] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9100), 1,
      sym__lambda_parameters,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7094), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [271993] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9124), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7095), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [272077] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4433), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9124), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7096), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4431), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [272159] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9134), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7097), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [272243] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9140), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7098), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [272327] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9195), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7099), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [272411] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4433), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9195), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7100), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4431), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [272493] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9210), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7101), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [272577] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9235), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7102), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [272661] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9645), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7103), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [272745] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(8914), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8068), 1,
      sym_tuple_pattern,
    STATE(8083), 1,
      sym_identifier,
    STATE(8603), 1,
      sym_variable_declarator,
    STATE(7104), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [272829] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9890), 1,
      sym__lambda_parameters,
    STATE(7105), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [272913] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4433), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9648), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7106), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4431), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [272995] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8167), 1,
      sym_identifier,
    STATE(9170), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7107), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [273079] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9170), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7108), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [273163] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(8914), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(7584), 1,
      sym_identifier,
    STATE(8010), 1,
      sym_tuple_pattern,
    STATE(8392), 1,
      sym_variable_declarator,
    STATE(7109), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [273247] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8310), 1,
      sym_identifier,
    STATE(9086), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7110), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [273331] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9096), 1,
      sym__lambda_parameters,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7111), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [273415] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(8914), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(7980), 1,
      sym_identifier,
    STATE(8010), 1,
      sym_tuple_pattern,
    STATE(8392), 1,
      sym_variable_declarator,
    STATE(7112), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [273499] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9862), 1,
      sym__lambda_parameters,
    STATE(7113), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [273583] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9310), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7114), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [273667] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(5741), 1,
      anon_sym_LBRACK,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(6970), 1,
      aux_sym_class_declaration_repeat1,
    STATE(7300), 1,
      sym_attribute_list,
    STATE(8286), 1,
      sym_identifier,
    STATE(7115), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [273751] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9550), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7116), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [273835] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9371), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7117), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [273919] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(8914), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8068), 1,
      sym_tuple_pattern,
    STATE(8083), 1,
      sym_identifier,
    STATE(8694), 1,
      sym_variable_declarator,
    STATE(7118), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [274003] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8216), 1,
      sym_identifier,
    STATE(9550), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7119), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [274087] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9627), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7120), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [274171] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4433), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9627), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7121), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4431), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [274253] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9630), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7122), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [274337] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9632), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7123), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [274421] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9495), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7124), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [274505] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9765), 1,
      sym__lambda_parameters,
    STATE(7125), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [274589] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9544), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7126), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [274673] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8310), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9860), 1,
      sym__lambda_parameters,
    STATE(7127), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [274757] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9249), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7128), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [274841] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9122), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7129), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [274925] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4433), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9249), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7130), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4431), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [275007] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9534), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7131), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [275091] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4433), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9534), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7132), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4431), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [275173] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9580), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7133), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [275257] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8167), 1,
      sym_identifier,
    STATE(9550), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7134), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [275341] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9636), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7135), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [275425] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(8914), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(7675), 1,
      sym_identifier,
    STATE(8010), 1,
      sym_tuple_pattern,
    STATE(8392), 1,
      sym_variable_declarator,
    STATE(7136), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [275509] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9799), 1,
      sym__lambda_parameters,
    STATE(7137), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [275593] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(5741), 1,
      anon_sym_LBRACK,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(6970), 1,
      aux_sym_class_declaration_repeat1,
    STATE(7300), 1,
      sym_attribute_list,
    STATE(8588), 1,
      sym_identifier,
    STATE(7138), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [275677] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9832), 1,
      sym__lambda_parameters,
    STATE(7139), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [275761] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9293), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7140), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [275845] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9860), 1,
      sym__lambda_parameters,
    STATE(7141), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [275929] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9887), 1,
      sym__lambda_parameters,
    STATE(7142), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [276013] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9018), 1,
      sym__lambda_parameters,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7143), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [276097] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4433), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9018), 1,
      sym__lambda_parameters,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7144), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4431), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [276179] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9031), 1,
      sym__lambda_parameters,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7145), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [276263] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9040), 1,
      sym__lambda_parameters,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7146), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [276347] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9076), 1,
      sym__lambda_parameters,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7147), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [276431] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(5323), 1,
      sym_discard,
    ACTIONS(8914), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8444), 1,
      sym_identifier,
    STATE(8499), 1,
      sym_tuple_pattern,
    STATE(7148), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [276515] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9086), 1,
      sym__lambda_parameters,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7149), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [276599] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9094), 1,
      sym__lambda_parameters,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7150), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [276683] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9120), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7151), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [276767] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4433), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9120), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7152), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4431), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [276849] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9129), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7153), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [276933] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9137), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7154), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [277017] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9156), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7155), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [277101] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4433), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9156), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7156), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4431), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [277183] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9163), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7157), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [277267] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9169), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7158), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [277351] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9184), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7159), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [277435] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4433), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9184), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7160), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4431), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [277517] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9191), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7161), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [277601] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9196), 1,
      sym__lambda_parameters,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(7162), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [277685] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9912), 1,
      sym__lambda_parameters,
    STATE(7163), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [277769] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(8914), 1,
      anon_sym_LPAREN,
    ACTIONS(9527), 1,
      sym_discard,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8873), 1,
      sym_tuple_pattern,
    STATE(8875), 1,
      sym_identifier,
    STATE(7164), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [277853] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4433), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9912), 1,
      sym__lambda_parameters,
    STATE(7165), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4431), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [277935] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9119), 1,
      sym_identifier,
    STATE(9685), 1,
      sym_parameter_list,
    STATE(9716), 1,
      sym__lambda_parameters,
    STATE(7166), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [278019] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4328), 1,
      sym__identifier_token,
    STATE(3562), 1,
      sym_identifier,
    STATE(3572), 1,
      sym__reserved_identifier,
    STATE(3597), 1,
      sym_generic_name,
    STATE(3723), 1,
      sym__simple_name,
    STATE(7167), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4330), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [278100] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4536), 1,
      sym__identifier_token,
    STATE(2928), 1,
      sym__reserved_identifier,
    STATE(2938), 1,
      sym_identifier,
    STATE(2944), 1,
      sym_generic_name,
    STATE(2969), 1,
      sym__simple_name,
    STATE(7168), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4538), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [278181] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(7411), 1,
      anon_sym_LBRACK,
    ACTIONS(7413), 1,
      anon_sym_QMARK,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8478), 1,
      sym_identifier,
    STATE(7169), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [278262] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4349), 1,
      sym__identifier_token,
    STATE(3584), 1,
      sym_identifier,
    STATE(3625), 1,
      sym__reserved_identifier,
    STATE(3648), 1,
      sym_generic_name,
    STATE(3673), 1,
      sym__simple_name,
    STATE(7170), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4351), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [278343] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7467), 1,
      sym__identifier_token,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(7514), 1,
      sym_identifier,
    ACTIONS(9529), 2,
      anon_sym_class,
      anon_sym_struct,
    STATE(7171), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [278422] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(2753), 1,
      sym_identifier,
    STATE(2955), 1,
      sym__simple_name,
    STATE(7172), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [278503] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(2753), 1,
      sym_identifier,
    STATE(2767), 1,
      sym__simple_name,
    STATE(7173), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [278584] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9531), 1,
      sym__identifier_token,
    STATE(3150), 1,
      sym_identifier,
    STATE(3191), 1,
      sym__simple_name,
    STATE(3208), 1,
      sym_generic_name,
    STATE(3210), 1,
      sym__reserved_identifier,
    STATE(7174), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(9533), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [278665] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9535), 1,
      sym__identifier_token,
    STATE(2808), 1,
      sym_identifier,
    STATE(2822), 1,
      sym_generic_name,
    STATE(2825), 1,
      sym__reserved_identifier,
    STATE(2836), 1,
      sym__simple_name,
    STATE(7175), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(9537), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [278746] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3193), 1,
      sym__identifier_token,
    STATE(4513), 1,
      sym__reserved_identifier,
    STATE(4786), 1,
      sym_identifier,
    STATE(5014), 1,
      sym__simple_name,
    STATE(5019), 1,
      sym_generic_name,
    STATE(7176), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3197), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [278827] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9539), 1,
      anon_sym_RBRACE,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8430), 1,
      sym_with_initializer,
    STATE(9107), 1,
      sym_identifier,
    STATE(7177), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [278908] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7467), 1,
      sym__identifier_token,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(7517), 1,
      sym_identifier,
    ACTIONS(9541), 2,
      anon_sym_class,
      anon_sym_struct,
    STATE(7178), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [278987] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(2753), 1,
      sym_identifier,
    STATE(2890), 1,
      sym__simple_name,
    STATE(7179), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [279068] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(7411), 1,
      anon_sym_LBRACK,
    ACTIONS(7415), 1,
      anon_sym_STAR,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8478), 1,
      sym_identifier,
    STATE(7180), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [279149] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4337), 1,
      sym__identifier_token,
    STATE(3584), 1,
      sym_identifier,
    STATE(3648), 1,
      sym_generic_name,
    STATE(3677), 1,
      sym__simple_name,
    STATE(3939), 1,
      sym__reserved_identifier,
    STATE(7181), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4339), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [279230] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9543), 1,
      sym__identifier_token,
    STATE(2953), 1,
      sym_identifier,
    STATE(3012), 1,
      sym__simple_name,
    STATE(3019), 1,
      sym__reserved_identifier,
    STATE(3021), 1,
      sym_generic_name,
    STATE(7182), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(9545), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [279311] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(2753), 1,
      sym_identifier,
    STATE(2933), 1,
      sym__simple_name,
    STATE(7183), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [279392] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7467), 1,
      sym__identifier_token,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(7516), 1,
      sym_identifier,
    ACTIONS(9547), 2,
      anon_sym_class,
      anon_sym_struct,
    STATE(7184), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [279471] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9549), 1,
      sym__identifier_token,
    STATE(2749), 1,
      sym_generic_name,
    STATE(2753), 1,
      sym_identifier,
    STATE(2766), 1,
      sym__simple_name,
    STATE(2812), 1,
      sym__reserved_identifier,
    STATE(7185), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(9551), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [279552] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4328), 1,
      sym__identifier_token,
    STATE(3562), 1,
      sym_identifier,
    STATE(3572), 1,
      sym__reserved_identifier,
    STATE(3597), 1,
      sym_generic_name,
    STATE(3599), 1,
      sym__simple_name,
    STATE(7186), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4330), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [279633] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9549), 1,
      sym__identifier_token,
    STATE(2749), 1,
      sym_generic_name,
    STATE(2753), 1,
      sym_identifier,
    STATE(2767), 1,
      sym__simple_name,
    STATE(2812), 1,
      sym__reserved_identifier,
    STATE(7187), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(9551), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [279714] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9549), 1,
      sym__identifier_token,
    STATE(2749), 1,
      sym_generic_name,
    STATE(2753), 1,
      sym_identifier,
    STATE(2812), 1,
      sym__reserved_identifier,
    STATE(2864), 1,
      sym__simple_name,
    STATE(7188), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(9551), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [279795] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4536), 1,
      sym__identifier_token,
    STATE(2928), 1,
      sym__reserved_identifier,
    STATE(2938), 1,
      sym_identifier,
    STATE(2944), 1,
      sym_generic_name,
    STATE(4709), 1,
      sym__simple_name,
    STATE(7189), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4538), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [279876] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9549), 1,
      sym__identifier_token,
    STATE(2749), 1,
      sym_generic_name,
    STATE(2753), 1,
      sym_identifier,
    STATE(2812), 1,
      sym__reserved_identifier,
    STATE(2834), 1,
      sym__simple_name,
    STATE(7190), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(9551), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [279957] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(2753), 1,
      sym_identifier,
    STATE(2910), 1,
      sym__simple_name,
    STATE(7191), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [280038] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(2753), 1,
      sym_identifier,
    STATE(2949), 1,
      sym__simple_name,
    STATE(7192), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [280119] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(2753), 1,
      sym_identifier,
    STATE(2894), 1,
      sym__simple_name,
    STATE(7193), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [280200] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9553), 1,
      anon_sym_operator,
    ACTIONS(9555), 1,
      anon_sym_this,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(7701), 1,
      sym_identifier,
    STATE(7194), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [280281] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9535), 1,
      sym__identifier_token,
    STATE(2808), 1,
      sym_identifier,
    STATE(2822), 1,
      sym_generic_name,
    STATE(2825), 1,
      sym__reserved_identifier,
    STATE(2837), 1,
      sym__simple_name,
    STATE(7195), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(9537), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [280362] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4328), 1,
      sym__identifier_token,
    STATE(3562), 1,
      sym_identifier,
    STATE(3572), 1,
      sym__reserved_identifier,
    STATE(3593), 1,
      sym__simple_name,
    STATE(3597), 1,
      sym_generic_name,
    STATE(7196), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4330), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [280443] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9557), 1,
      sym__identifier_token,
    STATE(4786), 1,
      sym_identifier,
    STATE(5019), 1,
      sym_generic_name,
    STATE(5128), 1,
      sym__simple_name,
    STATE(6711), 1,
      sym__reserved_identifier,
    STATE(7197), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(9559), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [280524] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9535), 1,
      sym__identifier_token,
    STATE(2808), 1,
      sym_identifier,
    STATE(2822), 1,
      sym_generic_name,
    STATE(2825), 1,
      sym__reserved_identifier,
    STATE(2826), 1,
      sym__simple_name,
    STATE(7198), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(9537), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [280605] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(5014), 1,
      sym__simple_name,
    STATE(5387), 1,
      sym_identifier,
    STATE(7199), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [280686] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(7411), 1,
      anon_sym_LBRACK,
    ACTIONS(7413), 1,
      anon_sym_QMARK,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8491), 1,
      sym_identifier,
    STATE(7200), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [280767] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9561), 1,
      anon_sym_RBRACE,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8687), 1,
      sym_with_initializer,
    STATE(9107), 1,
      sym_identifier,
    STATE(7201), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [280848] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(2753), 1,
      sym_identifier,
    STATE(2951), 1,
      sym__simple_name,
    STATE(7202), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [280929] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4575), 1,
      sym__identifier_token,
    STATE(5200), 1,
      sym__reserved_identifier,
    STATE(5219), 1,
      sym_identifier,
    STATE(5408), 1,
      sym_generic_name,
    STATE(5578), 1,
      sym__simple_name,
    STATE(7203), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4577), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [281010] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4337), 1,
      sym__identifier_token,
    STATE(3584), 1,
      sym_identifier,
    STATE(3648), 1,
      sym_generic_name,
    STATE(3768), 1,
      sym__simple_name,
    STATE(3939), 1,
      sym__reserved_identifier,
    STATE(7204), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4339), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [281091] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4349), 1,
      sym__identifier_token,
    STATE(3584), 1,
      sym_identifier,
    STATE(3625), 1,
      sym__reserved_identifier,
    STATE(3648), 1,
      sym_generic_name,
    STATE(3768), 1,
      sym__simple_name,
    STATE(7205), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4351), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [281172] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8867), 1,
      sym_identifier,
    ACTIONS(9383), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(7206), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [281251] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4248), 1,
      sym__identifier_token,
    STATE(3894), 1,
      sym_identifier,
    STATE(3911), 1,
      sym__reserved_identifier,
    STATE(3959), 1,
      sym_generic_name,
    STATE(4050), 1,
      sym__simple_name,
    STATE(7207), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4250), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [281332] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7467), 1,
      sym__identifier_token,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(7520), 1,
      sym_identifier,
    ACTIONS(9563), 2,
      anon_sym_class,
      anon_sym_struct,
    STATE(7208), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [281411] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9565), 1,
      anon_sym_operator,
    ACTIONS(9567), 1,
      anon_sym_this,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(7699), 1,
      sym_identifier,
    STATE(7209), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [281492] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9549), 1,
      sym__identifier_token,
    STATE(2749), 1,
      sym_generic_name,
    STATE(2753), 1,
      sym_identifier,
    STATE(2812), 1,
      sym__reserved_identifier,
    STATE(2853), 1,
      sym__simple_name,
    STATE(7210), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(9551), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [281573] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4349), 1,
      sym__identifier_token,
    STATE(3584), 1,
      sym_identifier,
    STATE(3625), 1,
      sym__reserved_identifier,
    STATE(3648), 1,
      sym_generic_name,
    STATE(3677), 1,
      sym__simple_name,
    STATE(7211), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4351), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [281654] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9569), 1,
      sym__identifier_token,
    STATE(3203), 1,
      sym_identifier,
    STATE(3234), 1,
      sym__simple_name,
    STATE(3326), 1,
      sym_generic_name,
    STATE(3386), 1,
      sym__reserved_identifier,
    STATE(7212), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(9571), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [281735] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7467), 1,
      sym__identifier_token,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(7519), 1,
      sym_identifier,
    ACTIONS(9573), 2,
      anon_sym_class,
      anon_sym_struct,
    STATE(7213), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [281814] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(2753), 1,
      sym_identifier,
    STATE(2758), 1,
      sym__simple_name,
    STATE(7214), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [281895] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9535), 1,
      sym__identifier_token,
    STATE(2808), 1,
      sym_identifier,
    STATE(2822), 1,
      sym_generic_name,
    STATE(2825), 1,
      sym__reserved_identifier,
    STATE(2866), 1,
      sym__simple_name,
    STATE(7215), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(9537), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [281976] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(2753), 1,
      sym_identifier,
    STATE(2982), 1,
      sym__simple_name,
    STATE(7216), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [282057] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7467), 1,
      sym__identifier_token,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(7513), 1,
      sym_identifier,
    ACTIONS(9575), 2,
      anon_sym_class,
      anon_sym_struct,
    STATE(7217), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [282136] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4337), 1,
      sym__identifier_token,
    STATE(3850), 1,
      sym_identifier,
    STATE(3900), 1,
      sym_generic_name,
    STATE(3939), 1,
      sym__reserved_identifier,
    STATE(3949), 1,
      sym__simple_name,
    STATE(7218), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4339), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [282217] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4337), 1,
      sym__identifier_token,
    STATE(3850), 1,
      sym_identifier,
    STATE(3900), 1,
      sym_generic_name,
    STATE(3939), 1,
      sym__reserved_identifier,
    STATE(3950), 1,
      sym__simple_name,
    STATE(7219), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4339), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [282298] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(2753), 1,
      sym_identifier,
    STATE(2759), 1,
      sym__simple_name,
    STATE(7220), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [282379] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(2753), 1,
      sym_identifier,
    STATE(2891), 1,
      sym__simple_name,
    STATE(7221), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [282460] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9549), 1,
      sym__identifier_token,
    STATE(2749), 1,
      sym_generic_name,
    STATE(2753), 1,
      sym_identifier,
    STATE(2758), 1,
      sym__simple_name,
    STATE(2812), 1,
      sym__reserved_identifier,
    STATE(7222), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(9551), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [282541] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(2753), 1,
      sym_identifier,
    STATE(2934), 1,
      sym__simple_name,
    STATE(7223), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [282622] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(2753), 1,
      sym_identifier,
    STATE(2967), 1,
      sym__simple_name,
    STATE(7224), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [282703] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4575), 1,
      sym__identifier_token,
    STATE(5200), 1,
      sym__reserved_identifier,
    STATE(5219), 1,
      sym_identifier,
    STATE(5349), 1,
      sym__simple_name,
    STATE(5408), 1,
      sym_generic_name,
    STATE(7225), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4577), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [282784] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4337), 1,
      sym__identifier_token,
    STATE(3894), 1,
      sym_identifier,
    STATE(3939), 1,
      sym__reserved_identifier,
    STATE(3959), 1,
      sym_generic_name,
    STATE(4050), 1,
      sym__simple_name,
    STATE(7226), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4339), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [282865] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(2753), 1,
      sym_identifier,
    STATE(2872), 1,
      sym__simple_name,
    STATE(7227), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [282946] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9577), 1,
      sym__identifier_token,
    STATE(2938), 1,
      sym_identifier,
    STATE(2944), 1,
      sym_generic_name,
    STATE(2972), 1,
      sym__simple_name,
    STATE(3183), 1,
      sym__reserved_identifier,
    STATE(7228), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(9579), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [283027] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4575), 1,
      sym__identifier_token,
    STATE(5200), 1,
      sym__reserved_identifier,
    STATE(5219), 1,
      sym_identifier,
    STATE(5253), 1,
      sym__simple_name,
    STATE(5408), 1,
      sym_generic_name,
    STATE(7229), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4577), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [283108] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4337), 1,
      sym__identifier_token,
    STATE(3584), 1,
      sym_identifier,
    STATE(3648), 1,
      sym_generic_name,
    STATE(3673), 1,
      sym__simple_name,
    STATE(3939), 1,
      sym__reserved_identifier,
    STATE(7230), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4339), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [283189] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4337), 1,
      sym__identifier_token,
    STATE(3562), 1,
      sym_identifier,
    STATE(3597), 1,
      sym_generic_name,
    STATE(3599), 1,
      sym__simple_name,
    STATE(3939), 1,
      sym__reserved_identifier,
    STATE(7231), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4339), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [283270] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(7411), 1,
      anon_sym_LBRACK,
    ACTIONS(7415), 1,
      anon_sym_STAR,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8491), 1,
      sym_identifier,
    STATE(7232), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [283351] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9549), 1,
      sym__identifier_token,
    STATE(2749), 1,
      sym_generic_name,
    STATE(2753), 1,
      sym_identifier,
    STATE(2812), 1,
      sym__reserved_identifier,
    STATE(2910), 1,
      sym__simple_name,
    STATE(7233), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(9551), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [283432] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9581), 1,
      anon_sym_RBRACE,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8600), 1,
      sym_with_initializer,
    STATE(9107), 1,
      sym_identifier,
    STATE(7234), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [283513] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9549), 1,
      sym__identifier_token,
    STATE(2749), 1,
      sym_generic_name,
    STATE(2753), 1,
      sym_identifier,
    STATE(2782), 1,
      sym__simple_name,
    STATE(2812), 1,
      sym__reserved_identifier,
    STATE(7235), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(9551), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [283594] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(2753), 1,
      sym_identifier,
    STATE(2895), 1,
      sym__simple_name,
    STATE(7236), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [283675] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4337), 1,
      sym__identifier_token,
    STATE(3894), 1,
      sym_identifier,
    STATE(3939), 1,
      sym__reserved_identifier,
    STATE(3959), 1,
      sym_generic_name,
    STATE(4131), 1,
      sym__simple_name,
    STATE(7237), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4339), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [283756] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4248), 1,
      sym__identifier_token,
    STATE(3894), 1,
      sym_identifier,
    STATE(3911), 1,
      sym__reserved_identifier,
    STATE(3959), 1,
      sym_generic_name,
    STATE(4051), 1,
      sym__simple_name,
    STATE(7238), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4250), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [283837] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9549), 1,
      sym__identifier_token,
    STATE(2749), 1,
      sym_generic_name,
    STATE(2753), 1,
      sym_identifier,
    STATE(2812), 1,
      sym__reserved_identifier,
    STATE(2889), 1,
      sym__simple_name,
    STATE(7239), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(9551), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [283918] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9549), 1,
      sym__identifier_token,
    STATE(2749), 1,
      sym_generic_name,
    STATE(2753), 1,
      sym_identifier,
    STATE(2757), 1,
      sym__simple_name,
    STATE(2812), 1,
      sym__reserved_identifier,
    STATE(7240), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(9551), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [283999] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(2753), 1,
      sym_identifier,
    STATE(2983), 1,
      sym__simple_name,
    STATE(7241), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [284080] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7467), 1,
      sym__identifier_token,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(7521), 1,
      sym_identifier,
    ACTIONS(9583), 2,
      anon_sym_class,
      anon_sym_struct,
    STATE(7242), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [284159] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9557), 1,
      sym__identifier_token,
    STATE(4786), 1,
      sym_identifier,
    STATE(5014), 1,
      sym__simple_name,
    STATE(5019), 1,
      sym_generic_name,
    STATE(6711), 1,
      sym__reserved_identifier,
    STATE(7243), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(9559), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [284240] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4337), 1,
      sym__identifier_token,
    STATE(3894), 1,
      sym_identifier,
    STATE(3939), 1,
      sym__reserved_identifier,
    STATE(3959), 1,
      sym_generic_name,
    STATE(4051), 1,
      sym__simple_name,
    STATE(7244), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4339), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [284321] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9549), 1,
      sym__identifier_token,
    STATE(2749), 1,
      sym_generic_name,
    STATE(2753), 1,
      sym_identifier,
    STATE(2812), 1,
      sym__reserved_identifier,
    STATE(2819), 1,
      sym__simple_name,
    STATE(7245), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(9551), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [284402] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4536), 1,
      sym__identifier_token,
    STATE(2928), 1,
      sym__reserved_identifier,
    STATE(2938), 1,
      sym_identifier,
    STATE(2944), 1,
      sym_generic_name,
    STATE(2972), 1,
      sym__simple_name,
    STATE(7246), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4538), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [284483] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(2753), 1,
      sym_identifier,
    STATE(2757), 1,
      sym__simple_name,
    STATE(7247), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [284564] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(2753), 1,
      sym_identifier,
    STATE(2834), 1,
      sym__simple_name,
    STATE(7248), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [284645] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9549), 1,
      sym__identifier_token,
    STATE(2749), 1,
      sym_generic_name,
    STATE(2753), 1,
      sym_identifier,
    STATE(2797), 1,
      sym__simple_name,
    STATE(2812), 1,
      sym__reserved_identifier,
    STATE(7249), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(9551), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [284726] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(2753), 1,
      sym_identifier,
    STATE(2851), 1,
      sym__simple_name,
    STATE(7250), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [284807] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4337), 1,
      sym__identifier_token,
    STATE(3562), 1,
      sym_identifier,
    STATE(3597), 1,
      sym_generic_name,
    STATE(3723), 1,
      sym__simple_name,
    STATE(3939), 1,
      sym__reserved_identifier,
    STATE(7251), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4339), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [284888] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3193), 1,
      sym__identifier_token,
    STATE(4513), 1,
      sym__reserved_identifier,
    STATE(4786), 1,
      sym_identifier,
    STATE(5019), 1,
      sym_generic_name,
    STATE(5128), 1,
      sym__simple_name,
    STATE(7252), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3197), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [284969] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7467), 1,
      sym__identifier_token,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(7524), 1,
      sym_identifier,
    ACTIONS(9585), 2,
      anon_sym_class,
      anon_sym_struct,
    STATE(7253), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [285048] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9549), 1,
      sym__identifier_token,
    STATE(2749), 1,
      sym_generic_name,
    STATE(2753), 1,
      sym_identifier,
    STATE(2812), 1,
      sym__reserved_identifier,
    STATE(2851), 1,
      sym__simple_name,
    STATE(7254), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(9551), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [285129] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(2753), 1,
      sym_identifier,
    STATE(2899), 1,
      sym__simple_name,
    STATE(7255), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [285210] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(2753), 1,
      sym_identifier,
    STATE(2939), 1,
      sym__simple_name,
    STATE(7256), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [285291] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4337), 1,
      sym__identifier_token,
    STATE(3850), 1,
      sym_identifier,
    STATE(3900), 1,
      sym_generic_name,
    STATE(3939), 1,
      sym__reserved_identifier,
    STATE(4047), 1,
      sym__simple_name,
    STATE(7257), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4339), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [285372] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(2753), 1,
      sym_identifier,
    STATE(2797), 1,
      sym__simple_name,
    STATE(7258), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [285453] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9577), 1,
      sym__identifier_token,
    STATE(2938), 1,
      sym_identifier,
    STATE(2944), 1,
      sym_generic_name,
    STATE(2969), 1,
      sym__simple_name,
    STATE(3183), 1,
      sym__reserved_identifier,
    STATE(7259), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(9579), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [285534] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9549), 1,
      sym__identifier_token,
    STATE(2749), 1,
      sym_generic_name,
    STATE(2812), 1,
      sym__reserved_identifier,
    STATE(5128), 1,
      sym__simple_name,
    STATE(5387), 1,
      sym_identifier,
    STATE(7260), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(9551), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [285615] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9587), 1,
      anon_sym_RBRACE,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8579), 1,
      sym_with_initializer,
    STATE(9107), 1,
      sym_identifier,
    STATE(7261), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [285696] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9549), 1,
      sym__identifier_token,
    STATE(2749), 1,
      sym_generic_name,
    STATE(2753), 1,
      sym_identifier,
    STATE(2759), 1,
      sym__simple_name,
    STATE(2812), 1,
      sym__reserved_identifier,
    STATE(7262), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(9551), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [285777] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(2753), 1,
      sym_identifier,
    STATE(2766), 1,
      sym__simple_name,
    STATE(7263), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [285858] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(2753), 1,
      sym_identifier,
    STATE(2900), 1,
      sym__simple_name,
    STATE(7264), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [285939] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(2753), 1,
      sym_identifier,
    STATE(2954), 1,
      sym__simple_name,
    STATE(7265), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [286020] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9589), 1,
      sym__identifier_token,
    STATE(3860), 1,
      sym_identifier,
    STATE(3899), 1,
      sym__reserved_identifier,
    STATE(3902), 1,
      sym__simple_name,
    STATE(3934), 1,
      sym_generic_name,
    STATE(7266), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(9591), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [286101] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4248), 1,
      sym__identifier_token,
    STATE(3894), 1,
      sym_identifier,
    STATE(3911), 1,
      sym__reserved_identifier,
    STATE(3959), 1,
      sym_generic_name,
    STATE(4131), 1,
      sym__simple_name,
    STATE(7267), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4250), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [286182] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(5128), 1,
      sym__simple_name,
    STATE(5387), 1,
      sym_identifier,
    STATE(7268), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [286263] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9535), 1,
      sym__identifier_token,
    STATE(2808), 1,
      sym_identifier,
    STATE(2822), 1,
      sym_generic_name,
    STATE(2825), 1,
      sym__reserved_identifier,
    STATE(2863), 1,
      sym__simple_name,
    STATE(7269), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(9537), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [286344] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9549), 1,
      sym__identifier_token,
    STATE(2749), 1,
      sym_generic_name,
    STATE(2812), 1,
      sym__reserved_identifier,
    STATE(5014), 1,
      sym__simple_name,
    STATE(5387), 1,
      sym_identifier,
    STATE(7270), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(9551), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [286425] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(2753), 1,
      sym_identifier,
    STATE(2878), 1,
      sym__simple_name,
    STATE(7271), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [286506] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9569), 1,
      sym__identifier_token,
    STATE(3203), 1,
      sym_identifier,
    STATE(3236), 1,
      sym__simple_name,
    STATE(3326), 1,
      sym_generic_name,
    STATE(3386), 1,
      sym__reserved_identifier,
    STATE(7272), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(9571), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [286587] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9593), 1,
      anon_sym_RBRACE,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8554), 1,
      sym_with_initializer,
    STATE(9107), 1,
      sym_identifier,
    STATE(7273), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [286668] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(2753), 1,
      sym_identifier,
    STATE(2782), 1,
      sym__simple_name,
    STATE(7274), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [286749] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7467), 1,
      sym__identifier_token,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(7518), 1,
      sym_identifier,
    ACTIONS(9595), 2,
      anon_sym_class,
      anon_sym_struct,
    STATE(7275), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [286828] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9549), 1,
      sym__identifier_token,
    STATE(2749), 1,
      sym_generic_name,
    STATE(2753), 1,
      sym_identifier,
    STATE(2812), 1,
      sym__reserved_identifier,
    STATE(2850), 1,
      sym__simple_name,
    STATE(7276), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(9551), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [286909] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7467), 1,
      sym__identifier_token,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(3195), 1,
      sym_identifier,
    STATE(3298), 1,
      sym__simple_name,
    STATE(3329), 1,
      sym_generic_name,
    STATE(7277), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [286990] = 17,
    ACTIONS(8337), 1,
      sym__identifier_token,
    ACTIONS(9597), 1,
      sym_integer_literal,
    ACTIONS(9599), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    STATE(7808), 1,
      sym__reserved_identifier,
    STATE(8425), 1,
      sym_identifier,
    STATE(7278), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(8339), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [287071] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(2753), 1,
      sym_identifier,
    STATE(2850), 1,
      sym__simple_name,
    STATE(7279), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [287152] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(2753), 1,
      sym_identifier,
    STATE(2853), 1,
      sym__simple_name,
    STATE(7280), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [287233] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9621), 1,
      anon_sym_operator,
    ACTIONS(9623), 1,
      anon_sym_this,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(7683), 1,
      sym_identifier,
    STATE(7281), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [287314] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(2753), 1,
      sym_identifier,
    STATE(2916), 1,
      sym__simple_name,
    STATE(7282), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [287395] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(2753), 1,
      sym_identifier,
    STATE(2892), 1,
      sym__simple_name,
    STATE(7283), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [287476] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9625), 1,
      anon_sym_RBRACE,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8454), 1,
      sym_with_initializer,
    STATE(9107), 1,
      sym_identifier,
    STATE(7284), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [287557] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9549), 1,
      sym__identifier_token,
    STATE(2749), 1,
      sym_generic_name,
    STATE(2753), 1,
      sym_identifier,
    STATE(2762), 1,
      sym__simple_name,
    STATE(2812), 1,
      sym__reserved_identifier,
    STATE(7285), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(9551), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [287638] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(2753), 1,
      sym_identifier,
    STATE(2889), 1,
      sym__simple_name,
    STATE(7286), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [287719] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4337), 1,
      sym__identifier_token,
    STATE(3562), 1,
      sym_identifier,
    STATE(3593), 1,
      sym__simple_name,
    STATE(3597), 1,
      sym_generic_name,
    STATE(3939), 1,
      sym__reserved_identifier,
    STATE(7287), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(4339), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [287800] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(2753), 1,
      sym_identifier,
    STATE(3564), 1,
      sym__simple_name,
    STATE(7288), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [287881] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9549), 1,
      sym__identifier_token,
    STATE(2749), 1,
      sym_generic_name,
    STATE(2753), 1,
      sym_identifier,
    STATE(2812), 1,
      sym__reserved_identifier,
    STATE(2868), 1,
      sym__simple_name,
    STATE(7289), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(9551), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [287962] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(2749), 1,
      sym_generic_name,
    STATE(2753), 1,
      sym_identifier,
    STATE(2762), 1,
      sym__simple_name,
    STATE(7290), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [288043] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5721), 1,
      anon_sym_LBRACK,
    STATE(7291), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5719), 25,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_in,
      anon_sym_out,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [288115] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5725), 1,
      anon_sym_LBRACK,
    STATE(7292), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5723), 25,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_in,
      anon_sym_out,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [288187] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8725), 1,
      sym_with_initializer,
    STATE(9107), 1,
      sym_identifier,
    STATE(7293), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [288265] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5699), 1,
      anon_sym_LBRACK,
    STATE(7294), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5697), 25,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_in,
      anon_sym_out,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [288337] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8486), 1,
      sym_identifier,
    STATE(8737), 1,
      sym_using_variable_declarator,
    STATE(7295), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [288415] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9627), 1,
      anon_sym_RPAREN,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9190), 1,
      sym_identifier,
    STATE(7296), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [288493] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    ACTIONS(9383), 1,
      anon_sym_COMMA,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8455), 1,
      sym_identifier,
    STATE(7297), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [288571] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8337), 1,
      sym__identifier_token,
    ACTIONS(9629), 1,
      sym_integer_literal,
    STATE(7808), 1,
      sym__reserved_identifier,
    STATE(8944), 1,
      sym_identifier,
    STATE(7298), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(8339), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [288649] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5713), 1,
      anon_sym_LBRACK,
    STATE(7299), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5711), 25,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_in,
      anon_sym_out,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [288721] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5703), 1,
      anon_sym_LBRACK,
    STATE(7300), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(5701), 25,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_in,
      anon_sym_out,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [288793] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7467), 1,
      sym__identifier_token,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(7580), 1,
      sym_identifier,
    STATE(7301), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [288868] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(7467), 1,
      sym_identifier,
    STATE(7302), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [288943] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7467), 1,
      sym__identifier_token,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(7541), 1,
      sym_identifier,
    STATE(7303), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [289018] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8273), 1,
      sym_identifier,
    STATE(7304), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [289093] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7467), 1,
      sym__identifier_token,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(7514), 1,
      sym_identifier,
    STATE(7305), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [289168] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(7487), 1,
      sym_identifier,
    STATE(7306), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [289243] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(7455), 1,
      sym_identifier,
    STATE(7307), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [289318] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(7461), 1,
      sym_identifier,
    STATE(7308), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [289393] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7467), 1,
      sym__identifier_token,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(8279), 1,
      sym_identifier,
    STATE(7309), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [289468] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7467), 1,
      sym__identifier_token,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(7586), 1,
      sym_identifier,
    STATE(7310), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [289543] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7467), 1,
      sym__identifier_token,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(7532), 1,
      sym_identifier,
    STATE(7311), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [289618] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7467), 1,
      sym__identifier_token,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(7545), 1,
      sym_identifier,
    STATE(7312), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [289693] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(7482), 1,
      sym_identifier,
    STATE(7313), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [289768] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8376), 1,
      sym_identifier,
    STATE(7314), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [289843] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7467), 1,
      sym__identifier_token,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(7538), 1,
      sym_identifier,
    STATE(7315), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [289918] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8283), 1,
      sym_identifier,
    STATE(7316), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [289993] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7467), 1,
      sym__identifier_token,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(7517), 1,
      sym_identifier,
    STATE(7317), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [290068] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7467), 1,
      sym__identifier_token,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(7539), 1,
      sym_identifier,
    STATE(7318), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [290143] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7467), 1,
      sym__identifier_token,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(7528), 1,
      sym_identifier,
    STATE(7319), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [290218] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7467), 1,
      sym__identifier_token,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(8284), 1,
      sym_identifier,
    STATE(7320), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [290293] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7467), 1,
      sym__identifier_token,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(7591), 1,
      sym_identifier,
    STATE(7321), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [290368] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8274), 1,
      sym_identifier,
    STATE(7322), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [290443] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(7485), 1,
      sym_identifier,
    STATE(7323), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [290518] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7467), 1,
      sym__identifier_token,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(8285), 1,
      sym_identifier,
    STATE(7324), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [290593] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7467), 1,
      sym__identifier_token,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(7525), 1,
      sym_identifier,
    STATE(7325), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [290668] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8304), 1,
      sym_identifier,
    STATE(7326), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [290743] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7467), 1,
      sym__identifier_token,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(7515), 1,
      sym_identifier,
    STATE(7327), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [290818] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7467), 1,
      sym__identifier_token,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(7637), 1,
      sym_identifier,
    STATE(7328), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [290893] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7467), 1,
      sym__identifier_token,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(7529), 1,
      sym_identifier,
    STATE(7329), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [290968] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8735), 1,
      sym_identifier,
    STATE(7330), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [291043] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3193), 1,
      sym__identifier_token,
    STATE(4513), 1,
      sym__reserved_identifier,
    STATE(8874), 1,
      sym_identifier,
    STATE(7331), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3197), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [291118] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8287), 1,
      sym_identifier,
    STATE(7332), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [291193] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(7460), 1,
      sym_identifier,
    STATE(7333), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [291268] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(7492), 1,
      sym_identifier,
    STATE(7334), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [291343] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(7506), 1,
      sym_identifier,
    STATE(7335), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [291418] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(7491), 1,
      sym_identifier,
    STATE(7336), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [291493] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8573), 1,
      sym_identifier,
    STATE(7337), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [291568] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7467), 1,
      sym__identifier_token,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(8262), 1,
      sym_identifier,
    STATE(7338), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [291643] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7467), 1,
      sym__identifier_token,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(9101), 1,
      sym_identifier,
    STATE(7339), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [291718] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8307), 1,
      sym_identifier,
    STATE(7340), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [291793] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9661), 1,
      sym_identifier,
    STATE(7341), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [291868] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(7488), 1,
      sym_identifier,
    STATE(7342), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [291943] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(7508), 1,
      sym_identifier,
    STATE(7343), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [292018] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7467), 1,
      sym__identifier_token,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(7523), 1,
      sym_identifier,
    STATE(7344), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [292093] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8344), 1,
      sym_identifier,
    STATE(7345), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [292168] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7467), 1,
      sym__identifier_token,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(7549), 1,
      sym_identifier,
    STATE(7346), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [292243] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(7736), 1,
      sym_identifier,
    STATE(7347), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [292318] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7467), 1,
      sym__identifier_token,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(7533), 1,
      sym_identifier,
    STATE(7348), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [292393] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7467), 1,
      sym__identifier_token,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(7531), 1,
      sym_identifier,
    STATE(7349), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [292468] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7467), 1,
      sym__identifier_token,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(8266), 1,
      sym_identifier,
    STATE(7350), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [292543] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7467), 1,
      sym__identifier_token,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(7619), 1,
      sym_identifier,
    STATE(7351), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [292618] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7467), 1,
      sym__identifier_token,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(7516), 1,
      sym_identifier,
    STATE(7352), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [292693] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7467), 1,
      sym__identifier_token,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(7544), 1,
      sym_identifier,
    STATE(7353), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [292768] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8268), 1,
      sym_identifier,
    STATE(7354), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [292843] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7467), 1,
      sym__identifier_token,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(7519), 1,
      sym_identifier,
    STATE(7355), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [292918] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7467), 1,
      sym__identifier_token,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(7548), 1,
      sym_identifier,
    STATE(7356), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [292993] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7467), 1,
      sym__identifier_token,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(8270), 1,
      sym_identifier,
    STATE(7357), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [293068] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7467), 1,
      sym__identifier_token,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(7627), 1,
      sym_identifier,
    STATE(7358), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [293143] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7467), 1,
      sym__identifier_token,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(9116), 1,
      sym_identifier,
    STATE(7359), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [293218] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(7499), 1,
      sym_identifier,
    STATE(7360), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [293293] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7467), 1,
      sym__identifier_token,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(7547), 1,
      sym_identifier,
    STATE(7361), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [293368] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7467), 1,
      sym__identifier_token,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(7540), 1,
      sym_identifier,
    STATE(7362), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [293443] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8275), 1,
      sym_identifier,
    STATE(7363), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [293518] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7467), 1,
      sym__identifier_token,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(7513), 1,
      sym_identifier,
    STATE(7364), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [293593] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7467), 1,
      sym__identifier_token,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(7543), 1,
      sym_identifier,
    STATE(7365), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [293668] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7467), 1,
      sym__identifier_token,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(8276), 1,
      sym_identifier,
    STATE(7366), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [293743] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7467), 1,
      sym__identifier_token,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(7631), 1,
      sym_identifier,
    STATE(7367), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [293818] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7467), 1,
      sym__identifier_token,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(7546), 1,
      sym_identifier,
    STATE(7368), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [293893] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7467), 1,
      sym__identifier_token,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(7534), 1,
      sym_identifier,
    STATE(7369), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [293968] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8280), 1,
      sym_identifier,
    STATE(7370), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [294043] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7467), 1,
      sym__identifier_token,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(7522), 1,
      sym_identifier,
    STATE(7371), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [294118] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8817), 1,
      sym_identifier,
    STATE(7372), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [294193] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7467), 1,
      sym__identifier_token,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(7639), 1,
      sym_identifier,
    STATE(7373), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [294268] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8506), 1,
      sym_identifier,
    STATE(7374), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [294343] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8363), 1,
      sym_identifier,
    STATE(7375), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [294418] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7467), 1,
      sym__identifier_token,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(7536), 1,
      sym_identifier,
    STATE(7376), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [294493] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8253), 1,
      sym_identifier,
    STATE(7377), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [294568] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(7457), 1,
      sym_identifier,
    STATE(7378), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [294643] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(7474), 1,
      sym_identifier,
    STATE(7379), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [294718] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8314), 1,
      sym_identifier,
    STATE(7380), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [294793] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7467), 1,
      sym__identifier_token,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(8249), 1,
      sym_identifier,
    STATE(7381), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [294868] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7467), 1,
      sym__identifier_token,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(7535), 1,
      sym_identifier,
    STATE(7382), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [294943] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3193), 1,
      sym__identifier_token,
    STATE(4513), 1,
      sym__reserved_identifier,
    STATE(8947), 1,
      sym_identifier,
    STATE(7383), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(3197), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [295018] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7467), 1,
      sym__identifier_token,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(8263), 1,
      sym_identifier,
    STATE(7384), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [295093] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7467), 1,
      sym__identifier_token,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(9399), 1,
      sym_identifier,
    STATE(7385), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [295168] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8529), 1,
      sym_identifier,
    STATE(7386), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [295243] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(7473), 1,
      sym_identifier,
    STATE(7387), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [295318] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9446), 1,
      sym_identifier,
    STATE(7388), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [295393] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(7453), 1,
      sym_identifier,
    STATE(7389), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [295468] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7467), 1,
      sym__identifier_token,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(7521), 1,
      sym_identifier,
    STATE(7390), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [295543] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8827), 1,
      sym_identifier,
    STATE(7391), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [295618] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(7484), 1,
      sym_identifier,
    STATE(7392), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [295693] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8382), 1,
      sym_identifier,
    STATE(7393), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [295768] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(9417), 1,
      sym_identifier,
    STATE(7394), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [295843] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(7495), 1,
      sym_identifier,
    STATE(7395), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [295918] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(8312), 1,
      sym_identifier,
    STATE(7396), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [295993] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7467), 1,
      sym__identifier_token,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(7618), 1,
      sym_identifier,
    STATE(7397), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [296068] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(25), 1,
      sym__identifier_token,
    STATE(2744), 1,
      sym__reserved_identifier,
    STATE(7496), 1,
      sym_identifier,
    STATE(7398), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(29), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [296143] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7467), 1,
      sym__identifier_token,
    STATE(3165), 1,
      sym__reserved_identifier,
    STATE(7542), 1,
      sym_identifier,
    STATE(7399), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(7469), 22,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
  [296218] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9633), 1,
      anon_sym_checked,
    ACTIONS(9631), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_GT_GT,
    STATE(7400), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(9635), 16,
      anon_sym_TILDE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_true,
      anon_sym_false,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [296290] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9639), 1,
      anon_sym_checked,
    ACTIONS(9637), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_GT_GT,
    STATE(7401), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(9641), 16,
      anon_sym_TILDE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_true,
      anon_sym_false,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [296362] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9645), 1,
      anon_sym_checked,
    ACTIONS(9643), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_GT_GT,
    STATE(7402), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(9647), 16,
      anon_sym_TILDE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_true,
      anon_sym_false,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [296434] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9651), 1,
      anon_sym_checked,
    ACTIONS(9649), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_GT_GT,
    STATE(7403), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(9653), 16,
      anon_sym_TILDE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_true,
      anon_sym_false,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [296506] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9657), 1,
      anon_sym_checked,
    ACTIONS(9655), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_GT_GT,
    STATE(7404), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(9659), 16,
      anon_sym_TILDE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_true,
      anon_sym_false,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [296578] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9663), 1,
      anon_sym_checked,
    ACTIONS(9661), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_GT_GT,
    STATE(7405), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(9665), 16,
      anon_sym_TILDE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_true,
      anon_sym_false,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [296650] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9655), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_GT_GT,
    STATE(7406), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(9659), 16,
      anon_sym_TILDE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_true,
      anon_sym_false,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [296719] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9667), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_GT_GT,
    STATE(7407), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(9669), 16,
      anon_sym_TILDE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_true,
      anon_sym_false,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [296788] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9649), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_GT_GT,
    STATE(7408), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(9653), 16,
      anon_sym_TILDE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_true,
      anon_sym_false,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [296857] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9671), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_GT_GT,
    STATE(7409), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(9673), 16,
      anon_sym_TILDE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_true,
      anon_sym_false,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [296926] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9643), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_GT_GT,
    STATE(7410), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(9647), 16,
      anon_sym_TILDE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_true,
      anon_sym_false,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [296995] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    STATE(7411), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(9675), 23,
      anon_sym_alias,
      anon_sym_global,
      anon_sym_file,
      anon_sym_where,
      anon_sym_notnull,
      anon_sym_unmanaged,
      anon_sym_scoped,
      anon_sym_var,
      anon_sym_yield,
      anon_sym_when,
      anon_sym_from,
      anon_sym_into,
      anon_sym_join,
      anon_sym_on,
      anon_sym_equals,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_ascending,
      anon_sym_descending,
      anon_sym_group,
      anon_sym_by,
      anon_sym_select,
      sym__identifier_token,
  [297062] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9677), 7,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_BANG,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_GT_GT,
    STATE(7412), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
    ACTIONS(9679), 16,
      anon_sym_TILDE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_true,
      anon_sym_false,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT_EQ,
      anon_sym_LT_EQ,
  [297131] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9691), 1,
      anon_sym_group,
    ACTIONS(9693), 1,
      anon_sym_select,
    STATE(3695), 1,
      sym__query_body,
    STATE(4985), 1,
      sym__select_or_group_clause,
    STATE(7479), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3666), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7413), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [297217] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9691), 1,
      anon_sym_group,
    ACTIONS(9693), 1,
      anon_sym_select,
    STATE(3736), 1,
      sym__query_body,
    STATE(4985), 1,
      sym__select_or_group_clause,
    STATE(7479), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3666), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7414), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [297303] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9695), 1,
      anon_sym_group,
    ACTIONS(9697), 1,
      anon_sym_select,
    STATE(4078), 1,
      sym__query_body,
    STATE(6101), 1,
      sym__select_or_group_clause,
    STATE(7503), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3967), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7415), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [297389] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9699), 1,
      anon_sym_group,
    ACTIONS(9701), 1,
      anon_sym_select,
    STATE(3695), 1,
      sym__query_body,
    STATE(4978), 1,
      sym__select_or_group_clause,
    STATE(7476), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3666), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7416), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [297475] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9699), 1,
      anon_sym_group,
    ACTIONS(9701), 1,
      anon_sym_select,
    STATE(3736), 1,
      sym__query_body,
    STATE(4978), 1,
      sym__select_or_group_clause,
    STATE(7476), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3666), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7417), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [297561] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9703), 1,
      anon_sym_group,
    ACTIONS(9705), 1,
      anon_sym_select,
    STATE(4078), 1,
      sym__query_body,
    STATE(4571), 1,
      sym__select_or_group_clause,
    STATE(7454), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3967), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7418), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [297647] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9707), 1,
      anon_sym_group,
    ACTIONS(9709), 1,
      anon_sym_select,
    STATE(4295), 1,
      sym__query_body,
    STATE(6107), 1,
      sym__select_or_group_clause,
    STATE(7471), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3967), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7419), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [297733] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9711), 1,
      anon_sym_group,
    ACTIONS(9713), 1,
      anon_sym_select,
    STATE(4564), 1,
      sym__query_body,
    STATE(4803), 1,
      sym__select_or_group_clause,
    STATE(7477), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(4565), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7420), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [297819] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9715), 1,
      anon_sym_group,
    ACTIONS(9717), 1,
      anon_sym_select,
    STATE(3736), 1,
      sym__query_body,
    STATE(5753), 1,
      sym__select_or_group_clause,
    STATE(7475), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3666), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7421), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [297905] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9719), 1,
      anon_sym_group,
    ACTIONS(9721), 1,
      anon_sym_select,
    STATE(3736), 1,
      sym__query_body,
    STATE(6679), 1,
      sym__select_or_group_clause,
    STATE(7500), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3666), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7422), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [297991] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9723), 1,
      anon_sym_group,
    ACTIONS(9725), 1,
      anon_sym_select,
    STATE(4295), 1,
      sym__query_body,
    STATE(6112), 1,
      sym__select_or_group_clause,
    STATE(7504), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3967), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7423), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [298077] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9703), 1,
      anon_sym_group,
    ACTIONS(9705), 1,
      anon_sym_select,
    STATE(4295), 1,
      sym__query_body,
    STATE(4571), 1,
      sym__select_or_group_clause,
    STATE(7454), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3967), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7424), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [298163] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9727), 1,
      anon_sym_group,
    ACTIONS(9729), 1,
      anon_sym_select,
    STATE(3695), 1,
      sym__query_body,
    STATE(5107), 1,
      sym__select_or_group_clause,
    STATE(7450), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3666), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7425), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [298249] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9731), 1,
      anon_sym_group,
    ACTIONS(9733), 1,
      anon_sym_select,
    STATE(3736), 1,
      sym__query_body,
    STATE(6648), 1,
      sym__select_or_group_clause,
    STATE(7449), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3666), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7426), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [298335] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9695), 1,
      anon_sym_group,
    ACTIONS(9697), 1,
      anon_sym_select,
    STATE(4295), 1,
      sym__query_body,
    STATE(6101), 1,
      sym__select_or_group_clause,
    STATE(7503), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3967), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7427), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [298421] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9735), 1,
      anon_sym_group,
    ACTIONS(9737), 1,
      anon_sym_select,
    STATE(4295), 1,
      sym__query_body,
    STATE(5192), 1,
      sym__select_or_group_clause,
    STATE(7483), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3967), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7428), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [298507] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9739), 1,
      anon_sym_group,
    ACTIONS(9741), 1,
      anon_sym_select,
    STATE(5388), 1,
      sym__select_or_group_clause,
    STATE(5541), 1,
      sym__query_body,
    STATE(7451), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(5542), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7429), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [298593] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9731), 1,
      anon_sym_group,
    ACTIONS(9733), 1,
      anon_sym_select,
    STATE(3695), 1,
      sym__query_body,
    STATE(6648), 1,
      sym__select_or_group_clause,
    STATE(7449), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3666), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7430), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [298679] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9743), 1,
      anon_sym_group,
    ACTIONS(9745), 1,
      anon_sym_select,
    STATE(3695), 1,
      sym__query_body,
    STATE(6672), 1,
      sym__select_or_group_clause,
    STATE(7468), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3666), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7431), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [298765] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9735), 1,
      anon_sym_group,
    ACTIONS(9737), 1,
      anon_sym_select,
    STATE(4078), 1,
      sym__query_body,
    STATE(5192), 1,
      sym__select_or_group_clause,
    STATE(7483), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3967), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7432), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [298851] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9747), 1,
      anon_sym_group,
    ACTIONS(9749), 1,
      anon_sym_select,
    STATE(4295), 1,
      sym__query_body,
    STATE(5755), 1,
      sym__select_or_group_clause,
    STATE(7465), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3967), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7433), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [298937] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9751), 1,
      anon_sym_group,
    ACTIONS(9753), 1,
      anon_sym_select,
    STATE(4477), 1,
      sym__select_or_group_clause,
    STATE(4564), 1,
      sym__query_body,
    STATE(7481), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(4565), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7434), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [299023] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9743), 1,
      anon_sym_group,
    ACTIONS(9745), 1,
      anon_sym_select,
    STATE(3736), 1,
      sym__query_body,
    STATE(6672), 1,
      sym__select_or_group_clause,
    STATE(7468), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3666), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7435), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [299109] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9755), 1,
      anon_sym_group,
    ACTIONS(9757), 1,
      anon_sym_select,
    STATE(4295), 1,
      sym__query_body,
    STATE(6118), 1,
      sym__select_or_group_clause,
    STATE(7472), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3967), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7436), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [299195] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9719), 1,
      anon_sym_group,
    ACTIONS(9721), 1,
      anon_sym_select,
    STATE(3695), 1,
      sym__query_body,
    STATE(6679), 1,
      sym__select_or_group_clause,
    STATE(7500), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3666), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7437), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [299281] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9707), 1,
      anon_sym_group,
    ACTIONS(9709), 1,
      anon_sym_select,
    STATE(4078), 1,
      sym__query_body,
    STATE(6107), 1,
      sym__select_or_group_clause,
    STATE(7471), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3967), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7438), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [299367] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9759), 1,
      anon_sym_group,
    ACTIONS(9761), 1,
      anon_sym_select,
    STATE(4078), 1,
      sym__query_body,
    STATE(5778), 1,
      sym__select_or_group_clause,
    STATE(7507), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3967), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7439), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [299453] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9763), 1,
      anon_sym_group,
    ACTIONS(9765), 1,
      anon_sym_select,
    STATE(3695), 1,
      sym__query_body,
    STATE(6663), 1,
      sym__select_or_group_clause,
    STATE(7459), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3666), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7440), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [299539] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9763), 1,
      anon_sym_group,
    ACTIONS(9765), 1,
      anon_sym_select,
    STATE(3736), 1,
      sym__query_body,
    STATE(6663), 1,
      sym__select_or_group_clause,
    STATE(7459), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3666), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7441), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [299625] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9755), 1,
      anon_sym_group,
    ACTIONS(9757), 1,
      anon_sym_select,
    STATE(4078), 1,
      sym__query_body,
    STATE(6118), 1,
      sym__select_or_group_clause,
    STATE(7472), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3967), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7442), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [299711] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9715), 1,
      anon_sym_group,
    ACTIONS(9717), 1,
      anon_sym_select,
    STATE(3695), 1,
      sym__query_body,
    STATE(5753), 1,
      sym__select_or_group_clause,
    STATE(7475), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3666), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7443), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [299797] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9727), 1,
      anon_sym_group,
    ACTIONS(9729), 1,
      anon_sym_select,
    STATE(3736), 1,
      sym__query_body,
    STATE(5107), 1,
      sym__select_or_group_clause,
    STATE(7450), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3666), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7444), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [299883] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9767), 1,
      anon_sym_group,
    ACTIONS(9769), 1,
      anon_sym_select,
    STATE(5541), 1,
      sym__query_body,
    STATE(5807), 1,
      sym__select_or_group_clause,
    STATE(7456), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(5542), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7445), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [299969] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9723), 1,
      anon_sym_group,
    ACTIONS(9725), 1,
      anon_sym_select,
    STATE(4078), 1,
      sym__query_body,
    STATE(6112), 1,
      sym__select_or_group_clause,
    STATE(7504), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3967), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7446), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [300055] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9759), 1,
      anon_sym_group,
    ACTIONS(9761), 1,
      anon_sym_select,
    STATE(4295), 1,
      sym__query_body,
    STATE(5778), 1,
      sym__select_or_group_clause,
    STATE(7507), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3967), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7447), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [300141] = 24,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9747), 1,
      anon_sym_group,
    ACTIONS(9749), 1,
      anon_sym_select,
    STATE(4078), 1,
      sym__query_body,
    STATE(5755), 1,
      sym__select_or_group_clause,
    STATE(7465), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3967), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7448), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [300227] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9731), 1,
      anon_sym_group,
    ACTIONS(9733), 1,
      anon_sym_select,
    STATE(6491), 1,
      sym__select_or_group_clause,
    STATE(7512), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3666), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7449), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [300310] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9727), 1,
      anon_sym_group,
    ACTIONS(9729), 1,
      anon_sym_select,
    STATE(5125), 1,
      sym__select_or_group_clause,
    STATE(7512), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3666), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7450), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [300393] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9739), 1,
      anon_sym_group,
    ACTIONS(9741), 1,
      anon_sym_select,
    STATE(5390), 1,
      sym__select_or_group_clause,
    STATE(7512), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(5542), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7451), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [300476] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9743), 1,
      anon_sym_group,
    ACTIONS(9745), 1,
      anon_sym_select,
    STATE(3667), 1,
      sym__select_or_group_clause,
    STATE(7512), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3666), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7452), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [300559] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9719), 1,
      anon_sym_group,
    ACTIONS(9721), 1,
      anon_sym_select,
    STATE(3701), 1,
      sym__select_or_group_clause,
    STATE(7463), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3666), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7453), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [300642] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9703), 1,
      anon_sym_group,
    ACTIONS(9705), 1,
      anon_sym_select,
    STATE(4584), 1,
      sym__select_or_group_clause,
    STATE(7512), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3967), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7454), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [300725] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9723), 1,
      anon_sym_group,
    ACTIONS(9725), 1,
      anon_sym_select,
    STATE(4022), 1,
      sym__select_or_group_clause,
    STATE(7493), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3967), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7455), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [300808] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9767), 1,
      anon_sym_group,
    ACTIONS(9769), 1,
      anon_sym_select,
    STATE(5836), 1,
      sym__select_or_group_clause,
    STATE(7512), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(5542), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7456), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [300891] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9711), 1,
      anon_sym_group,
    ACTIONS(9713), 1,
      anon_sym_select,
    STATE(4664), 1,
      sym__select_or_group_clause,
    STATE(7498), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(4565), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7457), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [300974] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9703), 1,
      anon_sym_group,
    ACTIONS(9705), 1,
      anon_sym_select,
    STATE(4075), 1,
      sym__select_or_group_clause,
    STATE(7512), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3967), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7458), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [301057] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9763), 1,
      anon_sym_group,
    ACTIONS(9765), 1,
      anon_sym_select,
    STATE(6637), 1,
      sym__select_or_group_clause,
    STATE(7512), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3666), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7459), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [301140] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9739), 1,
      anon_sym_group,
    ACTIONS(9741), 1,
      anon_sym_select,
    STATE(5607), 1,
      sym__select_or_group_clause,
    STATE(7462), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(5542), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7460), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [301223] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9707), 1,
      anon_sym_group,
    ACTIONS(9709), 1,
      anon_sym_select,
    STATE(4022), 1,
      sym__select_or_group_clause,
    STATE(7464), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3967), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7461), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [301306] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9739), 1,
      anon_sym_group,
    ACTIONS(9741), 1,
      anon_sym_select,
    STATE(5635), 1,
      sym__select_or_group_clause,
    STATE(7512), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(5542), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7462), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [301389] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9719), 1,
      anon_sym_group,
    ACTIONS(9721), 1,
      anon_sym_select,
    STATE(3667), 1,
      sym__select_or_group_clause,
    STATE(7512), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3666), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7463), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [301472] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9707), 1,
      anon_sym_group,
    ACTIONS(9709), 1,
      anon_sym_select,
    STATE(4075), 1,
      sym__select_or_group_clause,
    STATE(7512), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3967), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7464), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [301555] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9747), 1,
      anon_sym_group,
    ACTIONS(9749), 1,
      anon_sym_select,
    STATE(5757), 1,
      sym__select_or_group_clause,
    STATE(7512), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3967), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7465), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [301638] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9691), 1,
      anon_sym_group,
    ACTIONS(9693), 1,
      anon_sym_select,
    STATE(3667), 1,
      sym__select_or_group_clause,
    STATE(7512), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3666), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7466), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [301721] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9731), 1,
      anon_sym_group,
    ACTIONS(9733), 1,
      anon_sym_select,
    STATE(3701), 1,
      sym__select_or_group_clause,
    STATE(7497), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3666), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7467), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [301804] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9743), 1,
      anon_sym_group,
    ACTIONS(9745), 1,
      anon_sym_select,
    STATE(6645), 1,
      sym__select_or_group_clause,
    STATE(7512), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3666), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7468), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [301887] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9759), 1,
      anon_sym_group,
    ACTIONS(9761), 1,
      anon_sym_select,
    STATE(4075), 1,
      sym__select_or_group_clause,
    STATE(7512), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3967), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7469), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [301970] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9735), 1,
      anon_sym_group,
    ACTIONS(9737), 1,
      anon_sym_select,
    STATE(4075), 1,
      sym__select_or_group_clause,
    STATE(7512), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3967), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7470), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [302053] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9707), 1,
      anon_sym_group,
    ACTIONS(9709), 1,
      anon_sym_select,
    STATE(6109), 1,
      sym__select_or_group_clause,
    STATE(7512), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3967), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7471), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [302136] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9755), 1,
      anon_sym_group,
    ACTIONS(9757), 1,
      anon_sym_select,
    STATE(6120), 1,
      sym__select_or_group_clause,
    STATE(7512), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3967), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7472), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [302219] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9759), 1,
      anon_sym_group,
    ACTIONS(9761), 1,
      anon_sym_select,
    STATE(4022), 1,
      sym__select_or_group_clause,
    STATE(7469), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3967), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7473), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [302302] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9743), 1,
      anon_sym_group,
    ACTIONS(9745), 1,
      anon_sym_select,
    STATE(3701), 1,
      sym__select_or_group_clause,
    STATE(7452), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3666), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7474), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [302385] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9715), 1,
      anon_sym_group,
    ACTIONS(9717), 1,
      anon_sym_select,
    STATE(5614), 1,
      sym__select_or_group_clause,
    STATE(7512), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3666), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7475), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [302468] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9699), 1,
      anon_sym_group,
    ACTIONS(9701), 1,
      anon_sym_select,
    STATE(4966), 1,
      sym__select_or_group_clause,
    STATE(7512), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3666), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7476), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [302551] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9711), 1,
      anon_sym_group,
    ACTIONS(9713), 1,
      anon_sym_select,
    STATE(4813), 1,
      sym__select_or_group_clause,
    STATE(7512), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(4565), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7477), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [302634] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9767), 1,
      anon_sym_group,
    ACTIONS(9769), 1,
      anon_sym_select,
    STATE(5635), 1,
      sym__select_or_group_clause,
    STATE(7512), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(5542), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7478), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [302717] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9691), 1,
      anon_sym_group,
    ACTIONS(9693), 1,
      anon_sym_select,
    STATE(4957), 1,
      sym__select_or_group_clause,
    STATE(7512), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3666), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7479), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [302800] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9715), 1,
      anon_sym_group,
    ACTIONS(9717), 1,
      anon_sym_select,
    STATE(3667), 1,
      sym__select_or_group_clause,
    STATE(7512), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3666), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7480), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [302883] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9751), 1,
      anon_sym_group,
    ACTIONS(9753), 1,
      anon_sym_select,
    STATE(4479), 1,
      sym__select_or_group_clause,
    STATE(7512), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(4565), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7481), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [302966] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9727), 1,
      anon_sym_group,
    ACTIONS(9729), 1,
      anon_sym_select,
    STATE(3701), 1,
      sym__select_or_group_clause,
    STATE(7502), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3666), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7482), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [303049] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9735), 1,
      anon_sym_group,
    ACTIONS(9737), 1,
      anon_sym_select,
    STATE(5194), 1,
      sym__select_or_group_clause,
    STATE(7512), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3967), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7483), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [303132] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9751), 1,
      anon_sym_group,
    ACTIONS(9753), 1,
      anon_sym_select,
    STATE(4664), 1,
      sym__select_or_group_clause,
    STATE(7489), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(4565), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7484), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [303215] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9755), 1,
      anon_sym_group,
    ACTIONS(9757), 1,
      anon_sym_select,
    STATE(4022), 1,
      sym__select_or_group_clause,
    STATE(7494), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3967), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7485), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [303298] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9747), 1,
      anon_sym_group,
    ACTIONS(9749), 1,
      anon_sym_select,
    STATE(4075), 1,
      sym__select_or_group_clause,
    STATE(7512), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3967), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7486), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [303381] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9767), 1,
      anon_sym_group,
    ACTIONS(9769), 1,
      anon_sym_select,
    STATE(5607), 1,
      sym__select_or_group_clause,
    STATE(7478), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(5542), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7487), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [303464] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9699), 1,
      anon_sym_group,
    ACTIONS(9701), 1,
      anon_sym_select,
    STATE(3701), 1,
      sym__select_or_group_clause,
    STATE(7490), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3666), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7488), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [303547] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9751), 1,
      anon_sym_group,
    ACTIONS(9753), 1,
      anon_sym_select,
    STATE(4629), 1,
      sym__select_or_group_clause,
    STATE(7512), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(4565), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7489), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [303630] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9699), 1,
      anon_sym_group,
    ACTIONS(9701), 1,
      anon_sym_select,
    STATE(3667), 1,
      sym__select_or_group_clause,
    STATE(7512), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3666), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7490), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [303713] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9703), 1,
      anon_sym_group,
    ACTIONS(9705), 1,
      anon_sym_select,
    STATE(4022), 1,
      sym__select_or_group_clause,
    STATE(7458), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3967), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7491), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [303796] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9735), 1,
      anon_sym_group,
    ACTIONS(9737), 1,
      anon_sym_select,
    STATE(4022), 1,
      sym__select_or_group_clause,
    STATE(7470), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3967), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7492), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [303879] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9723), 1,
      anon_sym_group,
    ACTIONS(9725), 1,
      anon_sym_select,
    STATE(4075), 1,
      sym__select_or_group_clause,
    STATE(7512), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3967), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7493), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [303962] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9755), 1,
      anon_sym_group,
    ACTIONS(9757), 1,
      anon_sym_select,
    STATE(4075), 1,
      sym__select_or_group_clause,
    STATE(7512), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3967), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7494), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [304045] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9747), 1,
      anon_sym_group,
    ACTIONS(9749), 1,
      anon_sym_select,
    STATE(4022), 1,
      sym__select_or_group_clause,
    STATE(7486), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3967), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7495), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [304128] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9695), 1,
      anon_sym_group,
    ACTIONS(9697), 1,
      anon_sym_select,
    STATE(4022), 1,
      sym__select_or_group_clause,
    STATE(7501), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3967), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7496), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [304211] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9731), 1,
      anon_sym_group,
    ACTIONS(9733), 1,
      anon_sym_select,
    STATE(3667), 1,
      sym__select_or_group_clause,
    STATE(7512), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3666), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7497), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [304294] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9711), 1,
      anon_sym_group,
    ACTIONS(9713), 1,
      anon_sym_select,
    STATE(4629), 1,
      sym__select_or_group_clause,
    STATE(7512), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(4565), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7498), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [304377] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9763), 1,
      anon_sym_group,
    ACTIONS(9765), 1,
      anon_sym_select,
    STATE(3701), 1,
      sym__select_or_group_clause,
    STATE(7505), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3666), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7499), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [304460] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9719), 1,
      anon_sym_group,
    ACTIONS(9721), 1,
      anon_sym_select,
    STATE(6658), 1,
      sym__select_or_group_clause,
    STATE(7512), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3666), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7500), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [304543] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9695), 1,
      anon_sym_group,
    ACTIONS(9697), 1,
      anon_sym_select,
    STATE(4075), 1,
      sym__select_or_group_clause,
    STATE(7512), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3967), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7501), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [304626] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9727), 1,
      anon_sym_group,
    ACTIONS(9729), 1,
      anon_sym_select,
    STATE(3667), 1,
      sym__select_or_group_clause,
    STATE(7512), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3666), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7502), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [304709] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9695), 1,
      anon_sym_group,
    ACTIONS(9697), 1,
      anon_sym_select,
    STATE(6103), 1,
      sym__select_or_group_clause,
    STATE(7512), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3967), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7503), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [304792] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9723), 1,
      anon_sym_group,
    ACTIONS(9725), 1,
      anon_sym_select,
    STATE(6114), 1,
      sym__select_or_group_clause,
    STATE(7512), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3967), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7504), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [304875] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9763), 1,
      anon_sym_group,
    ACTIONS(9765), 1,
      anon_sym_select,
    STATE(3667), 1,
      sym__select_or_group_clause,
    STATE(7512), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3666), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7505), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [304958] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9691), 1,
      anon_sym_group,
    ACTIONS(9693), 1,
      anon_sym_select,
    STATE(3701), 1,
      sym__select_or_group_clause,
    STATE(7466), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3666), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7506), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [305041] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9759), 1,
      anon_sym_group,
    ACTIONS(9761), 1,
      anon_sym_select,
    STATE(5780), 1,
      sym__select_or_group_clause,
    STATE(7512), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3967), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7507), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [305124] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9681), 1,
      anon_sym_where,
    ACTIONS(9683), 1,
      anon_sym_from,
    ACTIONS(9685), 1,
      anon_sym_join,
    ACTIONS(9687), 1,
      anon_sym_let,
    ACTIONS(9689), 1,
      anon_sym_orderby,
    ACTIONS(9715), 1,
      anon_sym_group,
    ACTIONS(9717), 1,
      anon_sym_select,
    STATE(3701), 1,
      sym__select_or_group_clause,
    STATE(7480), 1,
      aux_sym__query_body_repeat1,
    STATE(7738), 1,
      sym__query_clause,
    STATE(3666), 2,
      sym_group_clause,
      sym_select_clause,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7508), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [305207] = 26,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4140), 1,
      anon_sym_DOT,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(7465), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9773), 1,
      anon_sym_EQ,
    ACTIONS(9775), 1,
      anon_sym_LBRACE,
    ACTIONS(9777), 1,
      anon_sym_LT,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    STATE(2746), 1,
      sym_type_argument_list,
    STATE(3174), 1,
      sym_accessor_list,
    STATE(7653), 1,
      sym_parameter_list,
    STATE(8523), 1,
      sym_bracketed_argument_list,
    STATE(8950), 1,
      sym_type_parameter_list,
    STATE(9245), 1,
      sym_arrow_expression_clause,
    ACTIONS(9771), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    STATE(7509), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [305295] = 26,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4140), 1,
      anon_sym_DOT,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(7465), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9773), 1,
      anon_sym_EQ,
    ACTIONS(9775), 1,
      anon_sym_LBRACE,
    ACTIONS(9777), 1,
      anon_sym_LT,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    STATE(2746), 1,
      sym_type_argument_list,
    STATE(3215), 1,
      sym_accessor_list,
    STATE(7617), 1,
      sym_parameter_list,
    STATE(8523), 1,
      sym_bracketed_argument_list,
    STATE(8732), 1,
      sym_type_parameter_list,
    STATE(9260), 1,
      sym_arrow_expression_clause,
    ACTIONS(9771), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    STATE(7510), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [305383] = 26,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4140), 1,
      anon_sym_DOT,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(7465), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9773), 1,
      anon_sym_EQ,
    ACTIONS(9775), 1,
      anon_sym_LBRACE,
    ACTIONS(9777), 1,
      anon_sym_LT,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    STATE(2746), 1,
      sym_type_argument_list,
    STATE(3182), 1,
      sym_accessor_list,
    STATE(7638), 1,
      sym_parameter_list,
    STATE(8523), 1,
      sym_bracketed_argument_list,
    STATE(8720), 1,
      sym_type_parameter_list,
    STATE(9388), 1,
      sym_arrow_expression_clause,
    ACTIONS(9771), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    STATE(7511), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [305471] = 19,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9781), 1,
      anon_sym_where,
    ACTIONS(9784), 1,
      anon_sym_from,
    ACTIONS(9787), 1,
      anon_sym_join,
    ACTIONS(9790), 1,
      anon_sym_let,
    ACTIONS(9793), 1,
      anon_sym_orderby,
    STATE(7738), 1,
      sym__query_clause,
    ACTIONS(9796), 2,
      anon_sym_group,
      anon_sym_select,
    STATE(7737), 5,
      sym_from_clause,
      sym_join_clause,
      sym_let_clause,
      sym_order_by_clause,
      sym_where_clause,
    STATE(7512), 10,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
      aux_sym__query_body_repeat1,
  [305543] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9798), 1,
      anon_sym_SEMI,
    ACTIONS(9800), 1,
      anon_sym_COLON,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9804), 1,
      anon_sym_LT,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7565), 1,
      sym_type_parameter_list,
    STATE(7677), 1,
      sym_parameter_list,
    STATE(7818), 1,
      sym_record_base,
    STATE(7819), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9937), 1,
      sym_declaration_list,
    STATE(7513), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [305621] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9800), 1,
      anon_sym_COLON,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9804), 1,
      anon_sym_LT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9808), 1,
      anon_sym_SEMI,
    STATE(7564), 1,
      sym_type_parameter_list,
    STATE(7681), 1,
      sym_parameter_list,
    STATE(7786), 1,
      sym_record_base,
    STATE(7788), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9262), 1,
      sym_declaration_list,
    STATE(7514), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [305699] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9800), 1,
      anon_sym_COLON,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9804), 1,
      anon_sym_LT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9810), 1,
      anon_sym_SEMI,
    STATE(7556), 1,
      sym_type_parameter_list,
    STATE(7706), 1,
      sym_parameter_list,
    STATE(7883), 1,
      sym_record_base,
    STATE(7889), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9102), 1,
      sym_declaration_list,
    STATE(7515), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [305777] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9800), 1,
      anon_sym_COLON,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9804), 1,
      anon_sym_LT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9812), 1,
      anon_sym_SEMI,
    STATE(7561), 1,
      sym_type_parameter_list,
    STATE(7685), 1,
      sym_parameter_list,
    STATE(7781), 1,
      sym_record_base,
    STATE(7782), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9650), 1,
      sym_declaration_list,
    STATE(7516), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [305855] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9800), 1,
      anon_sym_COLON,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9804), 1,
      anon_sym_LT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9814), 1,
      anon_sym_SEMI,
    STATE(7550), 1,
      sym_type_parameter_list,
    STATE(7700), 1,
      sym_parameter_list,
    STATE(7820), 1,
      sym_record_base,
    STATE(7827), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9747), 1,
      sym_declaration_list,
    STATE(7517), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [305933] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9800), 1,
      anon_sym_COLON,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9804), 1,
      anon_sym_LT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9816), 1,
      anon_sym_SEMI,
    STATE(7562), 1,
      sym_type_parameter_list,
    STATE(7689), 1,
      sym_parameter_list,
    STATE(7877), 1,
      sym_record_base,
    STATE(7885), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9723), 1,
      sym_declaration_list,
    STATE(7518), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [306011] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9800), 1,
      anon_sym_COLON,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9804), 1,
      anon_sym_LT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9818), 1,
      anon_sym_SEMI,
    STATE(7553), 1,
      sym_type_parameter_list,
    STATE(7678), 1,
      sym_parameter_list,
    STATE(7803), 1,
      sym_record_base,
    STATE(7805), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9726), 1,
      sym_declaration_list,
    STATE(7519), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [306089] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9800), 1,
      anon_sym_COLON,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9804), 1,
      anon_sym_LT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9820), 1,
      anon_sym_SEMI,
    STATE(7551), 1,
      sym_type_parameter_list,
    STATE(7708), 1,
      sym_parameter_list,
    STATE(7799), 1,
      sym_record_base,
    STATE(7800), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9567), 1,
      sym_declaration_list,
    STATE(7520), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [306167] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9800), 1,
      anon_sym_COLON,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9804), 1,
      anon_sym_LT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9822), 1,
      anon_sym_SEMI,
    STATE(7552), 1,
      sym_type_parameter_list,
    STATE(7688), 1,
      sym_parameter_list,
    STATE(7851), 1,
      aux_sym_class_declaration_repeat3,
    STATE(7945), 1,
      sym_record_base,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9868), 1,
      sym_declaration_list,
    STATE(7521), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [306245] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9800), 1,
      anon_sym_COLON,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9804), 1,
      anon_sym_LT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9824), 1,
      anon_sym_SEMI,
    STATE(7557), 1,
      sym_type_parameter_list,
    STATE(7686), 1,
      sym_parameter_list,
    STATE(7829), 1,
      sym_record_base,
    STATE(7830), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9404), 1,
      sym_declaration_list,
    STATE(7522), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [306323] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9800), 1,
      anon_sym_COLON,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9804), 1,
      anon_sym_LT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9826), 1,
      anon_sym_SEMI,
    STATE(7554), 1,
      sym_type_parameter_list,
    STATE(7702), 1,
      sym_parameter_list,
    STATE(7783), 1,
      sym_record_base,
    STATE(7938), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9285), 1,
      sym_declaration_list,
    STATE(7523), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [306401] = 23,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9800), 1,
      anon_sym_COLON,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9804), 1,
      anon_sym_LT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9828), 1,
      anon_sym_SEMI,
    STATE(7563), 1,
      sym_type_parameter_list,
    STATE(7697), 1,
      sym_parameter_list,
    STATE(7824), 1,
      aux_sym_class_declaration_repeat3,
    STATE(7828), 1,
      sym_record_base,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9603), 1,
      sym_declaration_list,
    STATE(7524), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [306479] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9804), 1,
      anon_sym_LT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(7596), 1,
      sym_type_parameter_list,
    STATE(7759), 1,
      sym_parameter_list,
    STATE(8075), 1,
      sym_base_list,
    STATE(8077), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9842), 1,
      sym_declaration_list,
    STATE(7525), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [306554] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4140), 1,
      anon_sym_DOT,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(7463), 1,
      anon_sym_LT,
    ACTIONS(7465), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9771), 1,
      anon_sym_COMMA,
    ACTIONS(9775), 1,
      anon_sym_LBRACE,
    ACTIONS(9832), 1,
      anon_sym_SEMI,
    ACTIONS(9835), 1,
      anon_sym_EQ,
    STATE(2746), 1,
      sym_type_argument_list,
    STATE(3275), 1,
      sym_accessor_list,
    STATE(8523), 1,
      sym_bracketed_argument_list,
    STATE(7526), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [306629] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4140), 1,
      anon_sym_DOT,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(7463), 1,
      anon_sym_LT,
    ACTIONS(7465), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9771), 1,
      anon_sym_COMMA,
    ACTIONS(9775), 1,
      anon_sym_LBRACE,
    ACTIONS(9835), 1,
      anon_sym_EQ,
    ACTIONS(9837), 1,
      anon_sym_SEMI,
    STATE(2746), 1,
      sym_type_argument_list,
    STATE(3313), 1,
      sym_accessor_list,
    STATE(8523), 1,
      sym_bracketed_argument_list,
    STATE(7527), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [306704] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9804), 1,
      anon_sym_LT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(7595), 1,
      sym_type_parameter_list,
    STATE(7744), 1,
      sym_parameter_list,
    STATE(7953), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8233), 1,
      sym_base_list,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9749), 1,
      sym_declaration_list,
    STATE(7528), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [306779] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9804), 1,
      anon_sym_LT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(7582), 1,
      sym_type_parameter_list,
    STATE(7774), 1,
      sym_parameter_list,
    STATE(7965), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8220), 1,
      sym_base_list,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9318), 1,
      sym_declaration_list,
    STATE(7529), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [306854] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9840), 5,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_where,
      anon_sym_EQ_GT,
    ACTIONS(3993), 6,
      anon_sym_LBRACK,
      anon_sym_LT,
      anon_sym_QMARK,
      anon_sym_STAR,
      anon_sym_DOT,
      anon_sym_COLON_COLON,
    STATE(7530), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [306911] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9804), 1,
      anon_sym_LT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(7625), 1,
      sym_type_parameter_list,
    STATE(7763), 1,
      sym_parameter_list,
    STATE(7989), 1,
      sym_base_list,
    STATE(7993), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9558), 1,
      sym_declaration_list,
    STATE(7531), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [306986] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9804), 1,
      anon_sym_LT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(7620), 1,
      sym_type_parameter_list,
    STATE(7755), 1,
      sym_parameter_list,
    STATE(7956), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8242), 1,
      sym_base_list,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9611), 1,
      sym_declaration_list,
    STATE(7532), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [307061] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9804), 1,
      anon_sym_LT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(7624), 1,
      sym_type_parameter_list,
    STATE(7760), 1,
      sym_parameter_list,
    STATE(7979), 1,
      sym_base_list,
    STATE(7986), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9555), 1,
      sym_declaration_list,
    STATE(7533), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [307136] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9804), 1,
      anon_sym_LT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(7635), 1,
      sym_type_parameter_list,
    STATE(7734), 1,
      sym_parameter_list,
    STATE(8235), 1,
      sym_base_list,
    STATE(8243), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9243), 1,
      sym_declaration_list,
    STATE(7534), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [307211] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9804), 1,
      anon_sym_LT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(7656), 1,
      sym_type_parameter_list,
    STATE(7750), 1,
      sym_parameter_list,
    STATE(8140), 1,
      sym_base_list,
    STATE(8170), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9447), 1,
      sym_declaration_list,
    STATE(7535), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [307286] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9804), 1,
      anon_sym_LT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(7600), 1,
      sym_type_parameter_list,
    STATE(7715), 1,
      sym_parameter_list,
    STATE(8217), 1,
      sym_base_list,
    STATE(8226), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9382), 1,
      sym_declaration_list,
    STATE(7536), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [307361] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4140), 1,
      anon_sym_DOT,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(7463), 1,
      anon_sym_LT,
    ACTIONS(7465), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9771), 1,
      anon_sym_COMMA,
    ACTIONS(9775), 1,
      anon_sym_LBRACE,
    ACTIONS(9835), 1,
      anon_sym_EQ,
    ACTIONS(9843), 1,
      anon_sym_SEMI,
    STATE(2746), 1,
      sym_type_argument_list,
    STATE(3358), 1,
      sym_accessor_list,
    STATE(8523), 1,
      sym_bracketed_argument_list,
    STATE(7537), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [307436] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9804), 1,
      anon_sym_LT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(7594), 1,
      sym_type_parameter_list,
    STATE(7730), 1,
      sym_parameter_list,
    STATE(8156), 1,
      sym_base_list,
    STATE(8171), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9697), 1,
      sym_declaration_list,
    STATE(7538), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [307511] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9804), 1,
      anon_sym_LT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(7604), 1,
      sym_type_parameter_list,
    STATE(7714), 1,
      sym_parameter_list,
    STATE(8088), 1,
      sym_base_list,
    STATE(8131), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9907), 1,
      sym_declaration_list,
    STATE(7539), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [307586] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9804), 1,
      anon_sym_LT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(7632), 1,
      sym_type_parameter_list,
    STATE(7770), 1,
      sym_parameter_list,
    STATE(8159), 1,
      sym_base_list,
    STATE(8162), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9928), 1,
      sym_declaration_list,
    STATE(7540), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [307661] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9804), 1,
      anon_sym_LT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(7588), 1,
      sym_type_parameter_list,
    STATE(7742), 1,
      sym_parameter_list,
    STATE(8076), 1,
      sym_base_list,
    STATE(8132), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9314), 1,
      sym_declaration_list,
    STATE(7541), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [307736] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9804), 1,
      anon_sym_LT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(7590), 1,
      sym_type_parameter_list,
    STATE(7762), 1,
      sym_parameter_list,
    STATE(8201), 1,
      sym_base_list,
    STATE(8215), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9485), 1,
      sym_declaration_list,
    STATE(7542), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [307811] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9804), 1,
      anon_sym_LT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(7634), 1,
      sym_type_parameter_list,
    STATE(7720), 1,
      sym_parameter_list,
    STATE(8179), 1,
      sym_base_list,
    STATE(8182), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9939), 1,
      sym_declaration_list,
    STATE(7543), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [307886] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9804), 1,
      anon_sym_LT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(7628), 1,
      sym_type_parameter_list,
    STATE(7775), 1,
      sym_parameter_list,
    STATE(8034), 1,
      sym_base_list,
    STATE(8043), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9688), 1,
      sym_declaration_list,
    STATE(7544), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [307961] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9804), 1,
      anon_sym_LT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(7581), 1,
      sym_type_parameter_list,
    STATE(7710), 1,
      sym_parameter_list,
    STATE(8126), 1,
      sym_base_list,
    STATE(8161), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9294), 1,
      sym_declaration_list,
    STATE(7545), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [308036] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9804), 1,
      anon_sym_LT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(7661), 1,
      sym_type_parameter_list,
    STATE(7768), 1,
      sym_parameter_list,
    STATE(8199), 1,
      sym_base_list,
    STATE(8208), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9651), 1,
      sym_declaration_list,
    STATE(7546), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [308111] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9804), 1,
      anon_sym_LT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(7657), 1,
      sym_type_parameter_list,
    STATE(7747), 1,
      sym_parameter_list,
    STATE(8148), 1,
      sym_base_list,
    STATE(8151), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9469), 1,
      sym_declaration_list,
    STATE(7547), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [308186] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9804), 1,
      anon_sym_LT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(7629), 1,
      sym_type_parameter_list,
    STATE(7761), 1,
      sym_parameter_list,
    STATE(8074), 1,
      sym_base_list,
    STATE(8080), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9847), 1,
      sym_declaration_list,
    STATE(7548), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [308261] = 22,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9804), 1,
      anon_sym_LT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(7672), 1,
      sym_type_parameter_list,
    STATE(7771), 1,
      sym_parameter_list,
    STATE(8214), 1,
      sym_base_list,
    STATE(8223), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9712), 1,
      sym_declaration_list,
    STATE(7549), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [308336] = 21,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9800), 1,
      anon_sym_COLON,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9846), 1,
      anon_sym_SEMI,
    STATE(7705), 1,
      sym_parameter_list,
    STATE(7870), 1,
      aux_sym_class_declaration_repeat3,
    STATE(7871), 1,
      sym_record_base,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9572), 1,
      sym_declaration_list,
    STATE(7550), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [308408] = 21,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9800), 1,
      anon_sym_COLON,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9848), 1,
      anon_sym_SEMI,
    STATE(7679), 1,
      sym_parameter_list,
    STATE(7806), 1,
      aux_sym_class_declaration_repeat3,
    STATE(7807), 1,
      sym_record_base,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9728), 1,
      sym_declaration_list,
    STATE(7551), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [308480] = 21,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9800), 1,
      anon_sym_COLON,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9850), 1,
      anon_sym_SEMI,
    STATE(7707), 1,
      sym_parameter_list,
    STATE(7925), 1,
      aux_sym_class_declaration_repeat3,
    STATE(7926), 1,
      sym_record_base,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9598), 1,
      sym_declaration_list,
    STATE(7552), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [308552] = 21,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9800), 1,
      anon_sym_COLON,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9852), 1,
      anon_sym_SEMI,
    STATE(7680), 1,
      sym_parameter_list,
    STATE(7813), 1,
      aux_sym_class_declaration_repeat3,
    STATE(7814), 1,
      sym_record_base,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9892), 1,
      sym_declaration_list,
    STATE(7553), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [308624] = 21,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9800), 1,
      anon_sym_COLON,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9854), 1,
      anon_sym_SEMI,
    STATE(7691), 1,
      sym_parameter_list,
    STATE(7861), 1,
      aux_sym_class_declaration_repeat3,
    STATE(7862), 1,
      sym_record_base,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9942), 1,
      sym_declaration_list,
    STATE(7554), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [308696] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4145), 1,
      anon_sym_EQ_GT,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9773), 1,
      anon_sym_EQ,
    ACTIONS(9804), 1,
      anon_sym_LT,
    STATE(7665), 1,
      sym_parameter_list,
    STATE(8523), 1,
      sym_bracketed_argument_list,
    STATE(8902), 1,
      sym_type_parameter_list,
    ACTIONS(9771), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    STATE(7555), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [308766] = 21,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9800), 1,
      anon_sym_COLON,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9856), 1,
      anon_sym_SEMI,
    STATE(7709), 1,
      sym_parameter_list,
    STATE(7910), 1,
      aux_sym_class_declaration_repeat3,
    STATE(7914), 1,
      sym_record_base,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9445), 1,
      sym_declaration_list,
    STATE(7556), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [308838] = 21,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9800), 1,
      anon_sym_COLON,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9858), 1,
      anon_sym_SEMI,
    STATE(7687), 1,
      sym_parameter_list,
    STATE(7834), 1,
      aux_sym_class_declaration_repeat3,
    STATE(7835), 1,
      sym_record_base,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9510), 1,
      sym_declaration_list,
    STATE(7557), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [308910] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4145), 1,
      anon_sym_EQ_GT,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9773), 1,
      anon_sym_EQ,
    ACTIONS(9804), 1,
      anon_sym_LT,
    STATE(7576), 1,
      sym_parameter_list,
    STATE(8523), 1,
      sym_bracketed_argument_list,
    STATE(8713), 1,
      sym_type_parameter_list,
    ACTIONS(9771), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    STATE(7558), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [308980] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4145), 1,
      anon_sym_EQ_GT,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9773), 1,
      anon_sym_EQ,
    ACTIONS(9804), 1,
      anon_sym_LT,
    STATE(7651), 1,
      sym_parameter_list,
    STATE(8523), 1,
      sym_bracketed_argument_list,
    STATE(8903), 1,
      sym_type_parameter_list,
    ACTIONS(9771), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    STATE(7559), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [309050] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4145), 1,
      anon_sym_EQ_GT,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9773), 1,
      anon_sym_EQ,
    ACTIONS(9804), 1,
      anon_sym_LT,
    STATE(7659), 1,
      sym_parameter_list,
    STATE(8523), 1,
      sym_bracketed_argument_list,
    STATE(8856), 1,
      sym_type_parameter_list,
    ACTIONS(9771), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    STATE(7560), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [309120] = 21,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9800), 1,
      anon_sym_COLON,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9860), 1,
      anon_sym_SEMI,
    STATE(7704), 1,
      sym_parameter_list,
    STATE(7908), 1,
      aux_sym_class_declaration_repeat3,
    STATE(7909), 1,
      sym_record_base,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9481), 1,
      sym_declaration_list,
    STATE(7561), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [309192] = 21,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9800), 1,
      anon_sym_COLON,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9862), 1,
      anon_sym_SEMI,
    STATE(7682), 1,
      sym_parameter_list,
    STATE(7789), 1,
      aux_sym_class_declaration_repeat3,
    STATE(7790), 1,
      sym_record_base,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9276), 1,
      sym_declaration_list,
    STATE(7562), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [309264] = 21,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9800), 1,
      anon_sym_COLON,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9864), 1,
      anon_sym_SEMI,
    STATE(7696), 1,
      sym_parameter_list,
    STATE(7784), 1,
      aux_sym_class_declaration_repeat3,
    STATE(7793), 1,
      sym_record_base,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9618), 1,
      sym_declaration_list,
    STATE(7563), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [309336] = 21,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9800), 1,
      anon_sym_COLON,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9866), 1,
      anon_sym_SEMI,
    STATE(7693), 1,
      sym_parameter_list,
    STATE(7802), 1,
      aux_sym_class_declaration_repeat3,
    STATE(7804), 1,
      sym_record_base,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9586), 1,
      sym_declaration_list,
    STATE(7564), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [309408] = 21,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9800), 1,
      anon_sym_COLON,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9868), 1,
      anon_sym_SEMI,
    STATE(7684), 1,
      sym_parameter_list,
    STATE(7825), 1,
      aux_sym_class_declaration_repeat3,
    STATE(7826), 1,
      sym_record_base,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9231), 1,
      sym_declaration_list,
    STATE(7565), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [309480] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9870), 1,
      anon_sym_SEMI,
    ACTIONS(9872), 1,
      anon_sym_LBRACE,
    STATE(3160), 1,
      sym_block,
    STATE(3389), 1,
      sym__function_body,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9797), 1,
      sym_arrow_expression_clause,
    STATE(7566), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [309549] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6138), 1,
      anon_sym_LBRACE,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9874), 1,
      anon_sym_SEMI,
    STATE(2677), 1,
      sym__function_body,
    STATE(2707), 1,
      sym_block,
    STATE(7583), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9368), 1,
      sym_arrow_expression_clause,
    STATE(7567), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [309618] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6138), 1,
      anon_sym_LBRACE,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9874), 1,
      anon_sym_SEMI,
    STATE(2679), 1,
      sym__function_body,
    STATE(2707), 1,
      sym_block,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9368), 1,
      sym_arrow_expression_clause,
    STATE(7568), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [309687] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6138), 1,
      anon_sym_LBRACE,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9874), 1,
      anon_sym_SEMI,
    STATE(2680), 1,
      sym__function_body,
    STATE(2707), 1,
      sym_block,
    STATE(7587), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9368), 1,
      sym_arrow_expression_clause,
    STATE(7569), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [309756] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5788), 1,
      anon_sym_LBRACE,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9876), 1,
      anon_sym_SEMI,
    STATE(2476), 1,
      sym__function_body,
    STATE(2505), 1,
      sym_block,
    STATE(7572), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9796), 1,
      sym_arrow_expression_clause,
    STATE(7570), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [309825] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5786), 1,
      anon_sym_LBRACE,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9878), 1,
      anon_sym_SEMI,
    STATE(2291), 1,
      sym__function_body,
    STATE(2305), 1,
      sym_block,
    STATE(7652), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9218), 1,
      sym_arrow_expression_clause,
    STATE(7571), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [309894] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5788), 1,
      anon_sym_LBRACE,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9876), 1,
      anon_sym_SEMI,
    STATE(2436), 1,
      sym__function_body,
    STATE(2505), 1,
      sym_block,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9796), 1,
      sym_arrow_expression_clause,
    STATE(7572), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [309963] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5788), 1,
      anon_sym_LBRACE,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9876), 1,
      anon_sym_SEMI,
    STATE(2478), 1,
      sym__function_body,
    STATE(2505), 1,
      sym_block,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9796), 1,
      sym_arrow_expression_clause,
    STATE(7573), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [310032] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5786), 1,
      anon_sym_LBRACE,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9878), 1,
      anon_sym_SEMI,
    STATE(2236), 1,
      sym__function_body,
    STATE(2305), 1,
      sym_block,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9218), 1,
      sym_arrow_expression_clause,
    STATE(7574), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [310101] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5788), 1,
      anon_sym_LBRACE,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9876), 1,
      anon_sym_SEMI,
    STATE(2485), 1,
      sym__function_body,
    STATE(2505), 1,
      sym_block,
    STATE(7641), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9796), 1,
      sym_arrow_expression_clause,
    STATE(7575), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [310170] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6138), 1,
      anon_sym_LBRACE,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9874), 1,
      anon_sym_SEMI,
    STATE(2707), 1,
      sym_block,
    STATE(2708), 1,
      sym__function_body,
    STATE(7655), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9368), 1,
      sym_arrow_expression_clause,
    STATE(7576), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [310239] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5786), 1,
      anon_sym_LBRACE,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9878), 1,
      anon_sym_SEMI,
    STATE(2237), 1,
      sym__function_body,
    STATE(2305), 1,
      sym_block,
    STATE(7589), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9218), 1,
      sym_arrow_expression_clause,
    STATE(7577), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [310308] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5786), 1,
      anon_sym_LBRACE,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9878), 1,
      anon_sym_SEMI,
    STATE(2238), 1,
      sym__function_body,
    STATE(2305), 1,
      sym_block,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9218), 1,
      sym_arrow_expression_clause,
    STATE(7578), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [310377] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5788), 1,
      anon_sym_LBRACE,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9876), 1,
      anon_sym_SEMI,
    STATE(2486), 1,
      sym__function_body,
    STATE(2505), 1,
      sym_block,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9796), 1,
      sym_arrow_expression_clause,
    STATE(7579), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [310446] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9804), 1,
      anon_sym_LT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(7754), 1,
      sym_type_parameter_list,
    STATE(8061), 1,
      sym_base_list,
    STATE(8066), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9571), 1,
      sym_declaration_list,
    STATE(7580), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [310515] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(7758), 1,
      sym_parameter_list,
    STATE(8064), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8072), 1,
      sym_base_list,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9279), 1,
      sym_declaration_list,
    STATE(7581), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [310584] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(7722), 1,
      sym_parameter_list,
    STATE(8007), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8211), 1,
      sym_base_list,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9373), 1,
      sym_declaration_list,
    STATE(7582), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [310653] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6138), 1,
      anon_sym_LBRACE,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9874), 1,
      anon_sym_SEMI,
    STATE(2666), 1,
      sym__function_body,
    STATE(2707), 1,
      sym_block,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9368), 1,
      sym_arrow_expression_clause,
    STATE(7583), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [310722] = 19,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9804), 1,
      anon_sym_LT,
    ACTIONS(9835), 1,
      anon_sym_EQ,
    STATE(7660), 1,
      sym_parameter_list,
    STATE(8523), 1,
      sym_bracketed_argument_list,
    STATE(8808), 1,
      sym_type_parameter_list,
    ACTIONS(9771), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    STATE(7584), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [310789] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6138), 1,
      anon_sym_LBRACE,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9874), 1,
      anon_sym_SEMI,
    STATE(2692), 1,
      sym__function_body,
    STATE(2707), 1,
      sym_block,
    STATE(7605), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9368), 1,
      sym_arrow_expression_clause,
    STATE(7585), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [310858] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9804), 1,
      anon_sym_LT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(7746), 1,
      sym_type_parameter_list,
    STATE(7968), 1,
      sym_base_list,
    STATE(7977), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9488), 1,
      sym_declaration_list,
    STATE(7586), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [310927] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6138), 1,
      anon_sym_LBRACE,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9874), 1,
      anon_sym_SEMI,
    STATE(2693), 1,
      sym__function_body,
    STATE(2707), 1,
      sym_block,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9368), 1,
      sym_arrow_expression_clause,
    STATE(7587), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [310996] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(7719), 1,
      sym_parameter_list,
    STATE(8009), 1,
      sym_base_list,
    STATE(8022), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9527), 1,
      sym_declaration_list,
    STATE(7588), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [311065] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5786), 1,
      anon_sym_LBRACE,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9878), 1,
      anon_sym_SEMI,
    STATE(2246), 1,
      sym__function_body,
    STATE(2305), 1,
      sym_block,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9218), 1,
      sym_arrow_expression_clause,
    STATE(7589), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [311134] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(7728), 1,
      sym_parameter_list,
    STATE(8099), 1,
      sym_base_list,
    STATE(8133), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9696), 1,
      sym_declaration_list,
    STATE(7590), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [311203] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9804), 1,
      anon_sym_LT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(7752), 1,
      sym_type_parameter_list,
    STATE(7970), 1,
      sym_base_list,
    STATE(7976), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9756), 1,
      sym_declaration_list,
    STATE(7591), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [311272] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6108), 1,
      anon_sym_LBRACE,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9870), 1,
      anon_sym_SEMI,
    STATE(3160), 1,
      sym_block,
    STATE(7610), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(8872), 1,
      sym__function_body,
    STATE(9797), 1,
      sym_arrow_expression_clause,
    STATE(7592), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [311341] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9880), 1,
      anon_sym_COMMA,
    ACTIONS(9883), 7,
      anon_sym_where,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
    STATE(7593), 10,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
      aux_sym_order_by_clause_repeat1,
  [311396] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(7753), 1,
      sym_parameter_list,
    STATE(8035), 1,
      sym_base_list,
    STATE(8040), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9114), 1,
      sym_declaration_list,
    STATE(7594), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [311465] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(7757), 1,
      sym_parameter_list,
    STATE(8063), 1,
      sym_base_list,
    STATE(8067), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9731), 1,
      sym_declaration_list,
    STATE(7595), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [311534] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(7765), 1,
      sym_parameter_list,
    STATE(8139), 1,
      sym_base_list,
    STATE(8149), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9352), 1,
      sym_declaration_list,
    STATE(7596), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [311603] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6108), 1,
      anon_sym_LBRACE,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9870), 1,
      anon_sym_SEMI,
    STATE(3160), 1,
      sym_block,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(8866), 1,
      sym__function_body,
    STATE(9797), 1,
      sym_arrow_expression_clause,
    STATE(7597), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [311672] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6108), 1,
      anon_sym_LBRACE,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9870), 1,
      anon_sym_SEMI,
    STATE(3160), 1,
      sym_block,
    STATE(7613), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(8707), 1,
      sym__function_body,
    STATE(9797), 1,
      sym_arrow_expression_clause,
    STATE(7598), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [311741] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6138), 1,
      anon_sym_LBRACE,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9874), 1,
      anon_sym_SEMI,
    STATE(2707), 1,
      sym_block,
    STATE(2727), 1,
      sym__function_body,
    STATE(7673), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9368), 1,
      sym_arrow_expression_clause,
    STATE(7599), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [311810] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(7740), 1,
      sym_parameter_list,
    STATE(8124), 1,
      sym_base_list,
    STATE(8129), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9386), 1,
      sym_declaration_list,
    STATE(7600), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [311879] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9885), 1,
      anon_sym_COMMA,
    STATE(7616), 1,
      aux_sym_order_by_clause_repeat1,
    ACTIONS(9887), 7,
      anon_sym_where,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
    STATE(7601), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [311936] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5788), 1,
      anon_sym_LBRACE,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9876), 1,
      anon_sym_SEMI,
    STATE(2479), 1,
      sym__function_body,
    STATE(2505), 1,
      sym_block,
    STATE(7662), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9796), 1,
      sym_arrow_expression_clause,
    STATE(7602), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [312005] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5788), 1,
      anon_sym_LBRACE,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9876), 1,
      anon_sym_SEMI,
    STATE(2482), 1,
      sym__function_body,
    STATE(2505), 1,
      sym_block,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9796), 1,
      sym_arrow_expression_clause,
    STATE(7603), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [312074] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(7769), 1,
      sym_parameter_list,
    STATE(8196), 1,
      sym_base_list,
    STATE(8210), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9639), 1,
      sym_declaration_list,
    STATE(7604), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [312143] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6138), 1,
      anon_sym_LBRACE,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9874), 1,
      anon_sym_SEMI,
    STATE(2707), 1,
      sym_block,
    STATE(2711), 1,
      sym__function_body,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9368), 1,
      sym_arrow_expression_clause,
    STATE(7605), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [312212] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9870), 1,
      anon_sym_SEMI,
    ACTIONS(9872), 1,
      anon_sym_LBRACE,
    STATE(3160), 1,
      sym_block,
    STATE(3415), 1,
      sym__function_body,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9797), 1,
      sym_arrow_expression_clause,
    STATE(7606), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [312281] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5788), 1,
      anon_sym_LBRACE,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9876), 1,
      anon_sym_SEMI,
    STATE(2492), 1,
      sym__function_body,
    STATE(2505), 1,
      sym_block,
    STATE(7579), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9796), 1,
      sym_arrow_expression_clause,
    STATE(7607), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [312350] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9870), 1,
      anon_sym_SEMI,
    ACTIONS(9872), 1,
      anon_sym_LBRACE,
    STATE(3160), 1,
      sym_block,
    STATE(3308), 1,
      sym__function_body,
    STATE(7645), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9797), 1,
      sym_arrow_expression_clause,
    STATE(7608), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [312419] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4147), 1,
      anon_sym_COLON_COLON,
    ACTIONS(6803), 1,
      anon_sym_LT,
    STATE(5001), 1,
      sym_type_argument_list,
    ACTIONS(9889), 2,
      anon_sym_COMMA,
      anon_sym_GT,
    ACTIONS(4140), 4,
      anon_sym_LBRACK,
      anon_sym_QMARK,
      anon_sym_STAR,
      anon_sym_DOT,
    STATE(7609), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [312480] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6108), 1,
      anon_sym_LBRACE,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9870), 1,
      anon_sym_SEMI,
    STATE(3160), 1,
      sym_block,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(8714), 1,
      sym__function_body,
    STATE(9797), 1,
      sym_arrow_expression_clause,
    STATE(7610), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [312549] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9870), 1,
      anon_sym_SEMI,
    ACTIONS(9872), 1,
      anon_sym_LBRACE,
    STATE(3160), 1,
      sym_block,
    STATE(3310), 1,
      sym__function_body,
    STATE(7646), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9797), 1,
      sym_arrow_expression_clause,
    STATE(7611), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [312618] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6108), 1,
      anon_sym_LBRACE,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9870), 1,
      anon_sym_SEMI,
    STATE(3160), 1,
      sym_block,
    STATE(7621), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(8801), 1,
      sym__function_body,
    STATE(9797), 1,
      sym_arrow_expression_clause,
    STATE(7612), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [312687] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6108), 1,
      anon_sym_LBRACE,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9870), 1,
      anon_sym_SEMI,
    STATE(3160), 1,
      sym_block,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(8802), 1,
      sym__function_body,
    STATE(9797), 1,
      sym_arrow_expression_clause,
    STATE(7613), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [312756] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9870), 1,
      anon_sym_SEMI,
    ACTIONS(9872), 1,
      anon_sym_LBRACE,
    STATE(3160), 1,
      sym_block,
    STATE(3311), 1,
      sym__function_body,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9797), 1,
      sym_arrow_expression_clause,
    STATE(7614), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [312825] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9894), 1,
      anon_sym_into,
    STATE(7717), 1,
      sym_join_into_clause,
    ACTIONS(9892), 7,
      anon_sym_where,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
    STATE(7615), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [312882] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9885), 1,
      anon_sym_COMMA,
    STATE(7593), 1,
      aux_sym_order_by_clause_repeat1,
    ACTIONS(9896), 7,
      anon_sym_where,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
    STATE(7616), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [312939] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9870), 1,
      anon_sym_SEMI,
    ACTIONS(9872), 1,
      anon_sym_LBRACE,
    STATE(3160), 1,
      sym_block,
    STATE(3315), 1,
      sym__function_body,
    STATE(7650), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9797), 1,
      sym_arrow_expression_clause,
    STATE(7617), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [313008] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9804), 1,
      anon_sym_LT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(7767), 1,
      sym_type_parameter_list,
    STATE(8026), 1,
      sym_base_list,
    STATE(8071), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9051), 1,
      sym_declaration_list,
    STATE(7618), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [313077] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9804), 1,
      anon_sym_LT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(7764), 1,
      sym_type_parameter_list,
    STATE(7996), 1,
      sym_base_list,
    STATE(8005), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9564), 1,
      sym_declaration_list,
    STATE(7619), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [313146] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(7726), 1,
      sym_parameter_list,
    STATE(8191), 1,
      sym_base_list,
    STATE(8209), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9359), 1,
      sym_declaration_list,
    STATE(7620), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [313215] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6108), 1,
      anon_sym_LBRACE,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9870), 1,
      anon_sym_SEMI,
    STATE(3160), 1,
      sym_block,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(8716), 1,
      sym__function_body,
    STATE(9797), 1,
      sym_arrow_expression_clause,
    STATE(7621), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [313284] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5786), 1,
      anon_sym_LBRACE,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9878), 1,
      anon_sym_SEMI,
    STATE(2222), 1,
      sym__function_body,
    STATE(2305), 1,
      sym_block,
    STATE(7666), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9218), 1,
      sym_arrow_expression_clause,
    STATE(7622), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [313353] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9870), 1,
      anon_sym_SEMI,
    ACTIONS(9872), 1,
      anon_sym_LBRACE,
    STATE(3160), 1,
      sym_block,
    STATE(3420), 1,
      sym__function_body,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9797), 1,
      sym_arrow_expression_clause,
    STATE(7623), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [313422] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(7773), 1,
      sym_parameter_list,
    STATE(8029), 1,
      sym_base_list,
    STATE(8031), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9687), 1,
      sym_declaration_list,
    STATE(7624), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [313491] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(7776), 1,
      sym_parameter_list,
    STATE(8045), 1,
      sym_base_list,
    STATE(8047), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9689), 1,
      sym_declaration_list,
    STATE(7625), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [313560] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9870), 1,
      anon_sym_SEMI,
    ACTIONS(9872), 1,
      anon_sym_LBRACE,
    STATE(3160), 1,
      sym_block,
    STATE(3421), 1,
      sym__function_body,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9797), 1,
      sym_arrow_expression_clause,
    STATE(7626), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [313629] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9804), 1,
      anon_sym_LT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(7718), 1,
      sym_type_parameter_list,
    STATE(8084), 1,
      sym_base_list,
    STATE(8086), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9855), 1,
      sym_declaration_list,
    STATE(7627), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [313698] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(7732), 1,
      sym_parameter_list,
    STATE(8098), 1,
      sym_base_list,
    STATE(8107), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9878), 1,
      sym_declaration_list,
    STATE(7628), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [313767] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(7751), 1,
      sym_parameter_list,
    STATE(8144), 1,
      sym_base_list,
    STATE(8150), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9927), 1,
      sym_declaration_list,
    STATE(7629), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [313836] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5788), 1,
      anon_sym_LBRACE,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9876), 1,
      anon_sym_SEMI,
    STATE(2498), 1,
      sym__function_body,
    STATE(2505), 1,
      sym_block,
    STATE(7603), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9796), 1,
      sym_arrow_expression_clause,
    STATE(7630), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [313905] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9804), 1,
      anon_sym_LT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(7723), 1,
      sym_type_parameter_list,
    STATE(8186), 1,
      sym_base_list,
    STATE(8187), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9943), 1,
      sym_declaration_list,
    STATE(7631), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [313974] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(7724), 1,
      sym_parameter_list,
    STATE(8207), 1,
      sym_base_list,
    STATE(8212), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9744), 1,
      sym_declaration_list,
    STATE(7632), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [314043] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6108), 1,
      anon_sym_LBRACE,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9870), 1,
      anon_sym_SEMI,
    STATE(3160), 1,
      sym_block,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(8916), 1,
      sym__function_body,
    STATE(9797), 1,
      sym_arrow_expression_clause,
    STATE(7633), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [314112] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(7731), 1,
      sym_parameter_list,
    STATE(8219), 1,
      sym_base_list,
    STATE(8228), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9237), 1,
      sym_declaration_list,
    STATE(7634), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [314181] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(7743), 1,
      sym_parameter_list,
    STATE(7964), 1,
      sym_base_list,
    STATE(7966), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9166), 1,
      sym_declaration_list,
    STATE(7635), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [314250] = 19,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9804), 1,
      anon_sym_LT,
    ACTIONS(9835), 1,
      anon_sym_EQ,
    STATE(7630), 1,
      sym_parameter_list,
    STATE(8523), 1,
      sym_bracketed_argument_list,
    STATE(8994), 1,
      sym_type_parameter_list,
    ACTIONS(9771), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    STATE(7636), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [314317] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9804), 1,
      anon_sym_LT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(7716), 1,
      sym_type_parameter_list,
    STATE(8198), 1,
      sym_base_list,
    STATE(8200), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9026), 1,
      sym_declaration_list,
    STATE(7637), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [314386] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9870), 1,
      anon_sym_SEMI,
    ACTIONS(9872), 1,
      anon_sym_LBRACE,
    STATE(3160), 1,
      sym_block,
    STATE(3281), 1,
      sym__function_body,
    STATE(7614), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9797), 1,
      sym_arrow_expression_clause,
    STATE(7638), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [314455] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9804), 1,
      anon_sym_LT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(7772), 1,
      sym_type_parameter_list,
    STATE(8221), 1,
      sym_base_list,
    STATE(8225), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9769), 1,
      sym_declaration_list,
    STATE(7639), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [314524] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9870), 1,
      anon_sym_SEMI,
    ACTIONS(9872), 1,
      anon_sym_LBRACE,
    STATE(3160), 1,
      sym_block,
    STATE(3434), 1,
      sym__function_body,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9797), 1,
      sym_arrow_expression_clause,
    STATE(7640), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [314593] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5788), 1,
      anon_sym_LBRACE,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9876), 1,
      anon_sym_SEMI,
    STATE(2505), 1,
      sym_block,
    STATE(2510), 1,
      sym__function_body,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9796), 1,
      sym_arrow_expression_clause,
    STATE(7641), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [314662] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9870), 1,
      anon_sym_SEMI,
    ACTIONS(9872), 1,
      anon_sym_LBRACE,
    STATE(3160), 1,
      sym_block,
    STATE(3394), 1,
      sym__function_body,
    STATE(7606), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9797), 1,
      sym_arrow_expression_clause,
    STATE(7642), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [314731] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9870), 1,
      anon_sym_SEMI,
    ACTIONS(9872), 1,
      anon_sym_LBRACE,
    STATE(3160), 1,
      sym_block,
    STATE(3396), 1,
      sym__function_body,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9797), 1,
      sym_arrow_expression_clause,
    STATE(7643), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [314800] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9870), 1,
      anon_sym_SEMI,
    ACTIONS(9872), 1,
      anon_sym_LBRACE,
    STATE(3160), 1,
      sym_block,
    STATE(3336), 1,
      sym__function_body,
    STATE(7566), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9797), 1,
      sym_arrow_expression_clause,
    STATE(7644), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [314869] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9870), 1,
      anon_sym_SEMI,
    ACTIONS(9872), 1,
      anon_sym_LBRACE,
    STATE(3160), 1,
      sym_block,
    STATE(3337), 1,
      sym__function_body,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9797), 1,
      sym_arrow_expression_clause,
    STATE(7645), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [314938] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9870), 1,
      anon_sym_SEMI,
    ACTIONS(9872), 1,
      anon_sym_LBRACE,
    STATE(3160), 1,
      sym_block,
    STATE(3338), 1,
      sym__function_body,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9797), 1,
      sym_arrow_expression_clause,
    STATE(7646), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [315007] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9870), 1,
      anon_sym_SEMI,
    ACTIONS(9872), 1,
      anon_sym_LBRACE,
    STATE(3160), 1,
      sym_block,
    STATE(3397), 1,
      sym__function_body,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9797), 1,
      sym_arrow_expression_clause,
    STATE(7647), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [315076] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9870), 1,
      anon_sym_SEMI,
    ACTIONS(9872), 1,
      anon_sym_LBRACE,
    STATE(3160), 1,
      sym_block,
    STATE(3353), 1,
      sym__function_body,
    STATE(7643), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9797), 1,
      sym_arrow_expression_clause,
    STATE(7648), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [315145] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9870), 1,
      anon_sym_SEMI,
    ACTIONS(9872), 1,
      anon_sym_LBRACE,
    STATE(3160), 1,
      sym_block,
    STATE(3355), 1,
      sym__function_body,
    STATE(7647), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9797), 1,
      sym_arrow_expression_clause,
    STATE(7649), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [315214] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9870), 1,
      anon_sym_SEMI,
    ACTIONS(9872), 1,
      anon_sym_LBRACE,
    STATE(3160), 1,
      sym_block,
    STATE(3356), 1,
      sym__function_body,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9797), 1,
      sym_arrow_expression_clause,
    STATE(7650), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [315283] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5788), 1,
      anon_sym_LBRACE,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9876), 1,
      anon_sym_SEMI,
    STATE(2505), 1,
      sym_block,
    STATE(2506), 1,
      sym__function_body,
    STATE(7573), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9796), 1,
      sym_arrow_expression_clause,
    STATE(7651), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [315352] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5786), 1,
      anon_sym_LBRACE,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9878), 1,
      anon_sym_SEMI,
    STATE(2226), 1,
      sym__function_body,
    STATE(2305), 1,
      sym_block,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9218), 1,
      sym_arrow_expression_clause,
    STATE(7652), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [315421] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9870), 1,
      anon_sym_SEMI,
    ACTIONS(9872), 1,
      anon_sym_LBRACE,
    STATE(3160), 1,
      sym_block,
    STATE(3364), 1,
      sym__function_body,
    STATE(7670), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9797), 1,
      sym_arrow_expression_clause,
    STATE(7653), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [315490] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6108), 1,
      anon_sym_LBRACE,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9870), 1,
      anon_sym_SEMI,
    STATE(3160), 1,
      sym_block,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(8964), 1,
      sym__function_body,
    STATE(9797), 1,
      sym_arrow_expression_clause,
    STATE(7654), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [315559] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6138), 1,
      anon_sym_LBRACE,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9874), 1,
      anon_sym_SEMI,
    STATE(2707), 1,
      sym_block,
    STATE(2729), 1,
      sym__function_body,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9368), 1,
      sym_arrow_expression_clause,
    STATE(7655), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [315628] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(7745), 1,
      sym_parameter_list,
    STATE(8136), 1,
      sym_base_list,
    STATE(8141), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9414), 1,
      sym_declaration_list,
    STATE(7656), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [315697] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(7735), 1,
      sym_parameter_list,
    STATE(8092), 1,
      sym_base_list,
    STATE(8097), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9290), 1,
      sym_declaration_list,
    STATE(7657), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [315766] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5786), 1,
      anon_sym_LBRACE,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9878), 1,
      anon_sym_SEMI,
    STATE(2303), 1,
      sym__function_body,
    STATE(2305), 1,
      sym_block,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9218), 1,
      sym_arrow_expression_clause,
    STATE(7658), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [315835] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5786), 1,
      anon_sym_LBRACE,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9878), 1,
      anon_sym_SEMI,
    STATE(2232), 1,
      sym__function_body,
    STATE(2305), 1,
      sym_block,
    STATE(7658), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9218), 1,
      sym_arrow_expression_clause,
    STATE(7659), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [315904] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6138), 1,
      anon_sym_LBRACE,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9874), 1,
      anon_sym_SEMI,
    STATE(2674), 1,
      sym__function_body,
    STATE(2707), 1,
      sym_block,
    STATE(7568), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9368), 1,
      sym_arrow_expression_clause,
    STATE(7660), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [315973] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(7748), 1,
      sym_parameter_list,
    STATE(8154), 1,
      sym_base_list,
    STATE(8158), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9491), 1,
      sym_declaration_list,
    STATE(7661), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [316042] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5788), 1,
      anon_sym_LBRACE,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9876), 1,
      anon_sym_SEMI,
    STATE(2471), 1,
      sym__function_body,
    STATE(2505), 1,
      sym_block,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9796), 1,
      sym_arrow_expression_clause,
    STATE(7662), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [316111] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9870), 1,
      anon_sym_SEMI,
    ACTIONS(9872), 1,
      anon_sym_LBRACE,
    STATE(3160), 1,
      sym_block,
    STATE(3404), 1,
      sym__function_body,
    STATE(7623), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9797), 1,
      sym_arrow_expression_clause,
    STATE(7663), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [316180] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5786), 1,
      anon_sym_LBRACE,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9878), 1,
      anon_sym_SEMI,
    STATE(2227), 1,
      sym__function_body,
    STATE(2305), 1,
      sym_block,
    STATE(7574), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9218), 1,
      sym_arrow_expression_clause,
    STATE(7664), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [316249] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6108), 1,
      anon_sym_LBRACE,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9870), 1,
      anon_sym_SEMI,
    STATE(3160), 1,
      sym_block,
    STATE(7654), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(8769), 1,
      sym__function_body,
    STATE(9797), 1,
      sym_arrow_expression_clause,
    STATE(7665), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [316318] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5786), 1,
      anon_sym_LBRACE,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9878), 1,
      anon_sym_SEMI,
    STATE(2228), 1,
      sym__function_body,
    STATE(2305), 1,
      sym_block,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9218), 1,
      sym_arrow_expression_clause,
    STATE(7666), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [316387] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6108), 1,
      anon_sym_LBRACE,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9870), 1,
      anon_sym_SEMI,
    STATE(3160), 1,
      sym_block,
    STATE(7597), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(8715), 1,
      sym__function_body,
    STATE(9797), 1,
      sym_arrow_expression_clause,
    STATE(7667), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [316456] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5786), 1,
      anon_sym_LBRACE,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9878), 1,
      anon_sym_SEMI,
    STATE(2229), 1,
      sym__function_body,
    STATE(2305), 1,
      sym_block,
    STATE(7578), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9218), 1,
      sym_arrow_expression_clause,
    STATE(7668), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [316525] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9870), 1,
      anon_sym_SEMI,
    ACTIONS(9872), 1,
      anon_sym_LBRACE,
    STATE(3160), 1,
      sym_block,
    STATE(3406), 1,
      sym__function_body,
    STATE(7626), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9797), 1,
      sym_arrow_expression_clause,
    STATE(7669), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [316594] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9870), 1,
      anon_sym_SEMI,
    ACTIONS(9872), 1,
      anon_sym_LBRACE,
    STATE(3160), 1,
      sym_block,
    STATE(3412), 1,
      sym__function_body,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9797), 1,
      sym_arrow_expression_clause,
    STATE(7670), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [316663] = 19,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9804), 1,
      anon_sym_LT,
    ACTIONS(9835), 1,
      anon_sym_EQ,
    STATE(7667), 1,
      sym_parameter_list,
    STATE(8523), 1,
      sym_bracketed_argument_list,
    STATE(8963), 1,
      sym_type_parameter_list,
    ACTIONS(9771), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    STATE(7671), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [316730] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(7712), 1,
      sym_parameter_list,
    STATE(8019), 1,
      sym_base_list,
    STATE(8023), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9798), 1,
      sym_declaration_list,
    STATE(7672), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [316799] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6138), 1,
      anon_sym_LBRACE,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9874), 1,
      anon_sym_SEMI,
    STATE(2676), 1,
      sym__function_body,
    STATE(2707), 1,
      sym_block,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9368), 1,
      sym_arrow_expression_clause,
    STATE(7673), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [316868] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6108), 1,
      anon_sym_LBRACE,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9870), 1,
      anon_sym_SEMI,
    STATE(3160), 1,
      sym_block,
    STATE(7633), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(8984), 1,
      sym__function_body,
    STATE(9797), 1,
      sym_arrow_expression_clause,
    STATE(7674), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [316937] = 19,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9804), 1,
      anon_sym_LT,
    ACTIONS(9835), 1,
      anon_sym_EQ,
    STATE(7622), 1,
      sym_parameter_list,
    STATE(8523), 1,
      sym_bracketed_argument_list,
    STATE(8823), 1,
      sym_type_parameter_list,
    ACTIONS(9771), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    STATE(7675), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [317004] = 20,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9870), 1,
      anon_sym_SEMI,
    ACTIONS(9872), 1,
      anon_sym_LBRACE,
    STATE(3160), 1,
      sym_block,
    STATE(3419), 1,
      sym__function_body,
    STATE(7640), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9797), 1,
      sym_arrow_expression_clause,
    STATE(7676), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [317073] = 19,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9800), 1,
      anon_sym_COLON,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9868), 1,
      anon_sym_SEMI,
    STATE(7825), 1,
      aux_sym_class_declaration_repeat3,
    STATE(7826), 1,
      sym_record_base,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9231), 1,
      sym_declaration_list,
    STATE(7677), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [317139] = 19,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9800), 1,
      anon_sym_COLON,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9852), 1,
      anon_sym_SEMI,
    STATE(7813), 1,
      aux_sym_class_declaration_repeat3,
    STATE(7814), 1,
      sym_record_base,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9892), 1,
      sym_declaration_list,
    STATE(7678), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [317205] = 19,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9800), 1,
      anon_sym_COLON,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9898), 1,
      anon_sym_SEMI,
    STATE(7815), 1,
      aux_sym_class_declaration_repeat3,
    STATE(7816), 1,
      sym_record_base,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9894), 1,
      sym_declaration_list,
    STATE(7679), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [317271] = 19,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9800), 1,
      anon_sym_COLON,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9900), 1,
      anon_sym_SEMI,
    STATE(7821), 1,
      aux_sym_class_declaration_repeat3,
    STATE(7822), 1,
      sym_record_base,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9982), 1,
      sym_declaration_list,
    STATE(7680), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [317337] = 19,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9800), 1,
      anon_sym_COLON,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9866), 1,
      anon_sym_SEMI,
    STATE(7802), 1,
      aux_sym_class_declaration_repeat3,
    STATE(7804), 1,
      sym_record_base,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9586), 1,
      sym_declaration_list,
    STATE(7681), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [317403] = 19,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9800), 1,
      anon_sym_COLON,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9902), 1,
      anon_sym_SEMI,
    STATE(7809), 1,
      aux_sym_class_declaration_repeat3,
    STATE(7810), 1,
      sym_record_base,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9591), 1,
      sym_declaration_list,
    STATE(7682), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [317469] = 19,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9775), 1,
      anon_sym_LBRACE,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9804), 1,
      anon_sym_LT,
    STATE(3198), 1,
      sym_accessor_list,
    STATE(7608), 1,
      sym_parameter_list,
    STATE(8798), 1,
      sym_type_parameter_list,
    STATE(9734), 1,
      sym_arrow_expression_clause,
    STATE(7683), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [317535] = 19,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9800), 1,
      anon_sym_COLON,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9904), 1,
      anon_sym_SEMI,
    STATE(7832), 1,
      aux_sym_class_declaration_repeat3,
    STATE(7833), 1,
      sym_record_base,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9136), 1,
      sym_declaration_list,
    STATE(7684), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [317601] = 19,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9800), 1,
      anon_sym_COLON,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9860), 1,
      anon_sym_SEMI,
    STATE(7908), 1,
      aux_sym_class_declaration_repeat3,
    STATE(7909), 1,
      sym_record_base,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9481), 1,
      sym_declaration_list,
    STATE(7685), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [317667] = 19,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9800), 1,
      anon_sym_COLON,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9858), 1,
      anon_sym_SEMI,
    STATE(7834), 1,
      aux_sym_class_declaration_repeat3,
    STATE(7835), 1,
      sym_record_base,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9510), 1,
      sym_declaration_list,
    STATE(7686), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [317733] = 19,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9800), 1,
      anon_sym_COLON,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9906), 1,
      anon_sym_SEMI,
    STATE(7778), 1,
      aux_sym_class_declaration_repeat3,
    STATE(7837), 1,
      sym_record_base,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9150), 1,
      sym_declaration_list,
    STATE(7687), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [317799] = 19,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9800), 1,
      anon_sym_COLON,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9850), 1,
      anon_sym_SEMI,
    STATE(7925), 1,
      aux_sym_class_declaration_repeat3,
    STATE(7926), 1,
      sym_record_base,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9598), 1,
      sym_declaration_list,
    STATE(7688), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [317865] = 19,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9800), 1,
      anon_sym_COLON,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9862), 1,
      anon_sym_SEMI,
    STATE(7789), 1,
      aux_sym_class_declaration_repeat3,
    STATE(7790), 1,
      sym_record_base,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9276), 1,
      sym_declaration_list,
    STATE(7689), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [317931] = 19,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9870), 1,
      anon_sym_SEMI,
    ACTIONS(9872), 1,
      anon_sym_LBRACE,
    ACTIONS(9908), 1,
      anon_sym_COLON,
    STATE(3160), 1,
      sym_block,
    STATE(3285), 1,
      sym__function_body,
    STATE(7792), 1,
      sym_constructor_initializer,
    STATE(9797), 1,
      sym_arrow_expression_clause,
    STATE(7690), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [317997] = 19,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9800), 1,
      anon_sym_COLON,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9910), 1,
      anon_sym_SEMI,
    STATE(7929), 1,
      aux_sym_class_declaration_repeat3,
    STATE(7931), 1,
      sym_record_base,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9620), 1,
      sym_declaration_list,
    STATE(7691), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [318063] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(8544), 1,
      anon_sym_DOT,
    ACTIONS(9914), 1,
      anon_sym_COMMA,
    STATE(8203), 1,
      aux_sym_record_base_repeat1,
    STATE(8359), 1,
      sym_argument_list,
    ACTIONS(9912), 3,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_where,
    STATE(7692), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [318125] = 19,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9800), 1,
      anon_sym_COLON,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9916), 1,
      anon_sym_SEMI,
    STATE(7846), 1,
      aux_sym_class_declaration_repeat3,
    STATE(7848), 1,
      sym_record_base,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9843), 1,
      sym_declaration_list,
    STATE(7693), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [318191] = 19,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9870), 1,
      anon_sym_SEMI,
    ACTIONS(9872), 1,
      anon_sym_LBRACE,
    ACTIONS(9908), 1,
      anon_sym_COLON,
    STATE(3160), 1,
      sym_block,
    STATE(3247), 1,
      sym__function_body,
    STATE(7840), 1,
      sym_constructor_initializer,
    STATE(9797), 1,
      sym_arrow_expression_clause,
    STATE(7694), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [318257] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9883), 8,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
    STATE(7695), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [318309] = 19,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9800), 1,
      anon_sym_COLON,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9918), 1,
      anon_sym_SEMI,
    STATE(7934), 1,
      aux_sym_class_declaration_repeat3,
    STATE(7935), 1,
      sym_record_base,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9663), 1,
      sym_declaration_list,
    STATE(7696), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [318375] = 19,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9800), 1,
      anon_sym_COLON,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9864), 1,
      anon_sym_SEMI,
    STATE(7784), 1,
      aux_sym_class_declaration_repeat3,
    STATE(7793), 1,
      sym_record_base,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9618), 1,
      sym_declaration_list,
    STATE(7697), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [318441] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9920), 8,
      anon_sym_COMMA,
      anon_sym_where,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
    STATE(7698), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [318493] = 19,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9775), 1,
      anon_sym_LBRACE,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9804), 1,
      anon_sym_LT,
    STATE(3218), 1,
      sym_accessor_list,
    STATE(7663), 1,
      sym_parameter_list,
    STATE(8847), 1,
      sym_type_parameter_list,
    STATE(9608), 1,
      sym_arrow_expression_clause,
    STATE(7699), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [318559] = 19,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9800), 1,
      anon_sym_COLON,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9846), 1,
      anon_sym_SEMI,
    STATE(7870), 1,
      aux_sym_class_declaration_repeat3,
    STATE(7871), 1,
      sym_record_base,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9572), 1,
      sym_declaration_list,
    STATE(7700), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [318625] = 19,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9775), 1,
      anon_sym_LBRACE,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9804), 1,
      anon_sym_LT,
    STATE(3176), 1,
      sym_accessor_list,
    STATE(7648), 1,
      sym_parameter_list,
    STATE(8871), 1,
      sym_type_parameter_list,
    STATE(9173), 1,
      sym_arrow_expression_clause,
    STATE(7701), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [318691] = 19,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9800), 1,
      anon_sym_COLON,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9854), 1,
      anon_sym_SEMI,
    STATE(7861), 1,
      aux_sym_class_declaration_repeat3,
    STATE(7862), 1,
      sym_record_base,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9942), 1,
      sym_declaration_list,
    STATE(7702), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [318757] = 19,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9870), 1,
      anon_sym_SEMI,
    ACTIONS(9872), 1,
      anon_sym_LBRACE,
    ACTIONS(9908), 1,
      anon_sym_COLON,
    STATE(3160), 1,
      sym_block,
    STATE(3319), 1,
      sym__function_body,
    STATE(7887), 1,
      sym_constructor_initializer,
    STATE(9797), 1,
      sym_arrow_expression_clause,
    STATE(7703), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [318823] = 19,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9800), 1,
      anon_sym_COLON,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9922), 1,
      anon_sym_SEMI,
    STATE(7850), 1,
      aux_sym_class_declaration_repeat3,
    STATE(7949), 1,
      sym_record_base,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9654), 1,
      sym_declaration_list,
    STATE(7704), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [318889] = 19,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9800), 1,
      anon_sym_COLON,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9924), 1,
      anon_sym_SEMI,
    STATE(7900), 1,
      aux_sym_class_declaration_repeat3,
    STATE(7902), 1,
      sym_record_base,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9323), 1,
      sym_declaration_list,
    STATE(7705), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [318955] = 19,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9800), 1,
      anon_sym_COLON,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9856), 1,
      anon_sym_SEMI,
    STATE(7910), 1,
      aux_sym_class_declaration_repeat3,
    STATE(7914), 1,
      sym_record_base,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9445), 1,
      sym_declaration_list,
    STATE(7706), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [319021] = 19,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9800), 1,
      anon_sym_COLON,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9926), 1,
      anon_sym_SEMI,
    STATE(7865), 1,
      aux_sym_class_declaration_repeat3,
    STATE(7866), 1,
      sym_record_base,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9044), 1,
      sym_declaration_list,
    STATE(7707), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [319087] = 19,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9800), 1,
      anon_sym_COLON,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9848), 1,
      anon_sym_SEMI,
    STATE(7806), 1,
      aux_sym_class_declaration_repeat3,
    STATE(7807), 1,
      sym_record_base,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9728), 1,
      sym_declaration_list,
    STATE(7708), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [319153] = 19,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9800), 1,
      anon_sym_COLON,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9928), 1,
      anon_sym_SEMI,
    STATE(7922), 1,
      aux_sym_class_declaration_repeat3,
    STATE(7923), 1,
      sym_record_base,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9565), 1,
      sym_declaration_list,
    STATE(7709), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [319219] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(8064), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8072), 1,
      sym_base_list,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9279), 1,
      sym_declaration_list,
    STATE(7710), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [319282] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9930), 1,
      anon_sym_catch,
    ACTIONS(9932), 1,
      anon_sym_finally,
    STATE(7727), 1,
      aux_sym_try_statement_repeat1,
    STATE(8313), 1,
      sym_catch_clause,
    STATE(8890), 1,
      sym_finally_clause,
    ACTIONS(3005), 2,
      anon_sym_while,
      anon_sym_else,
    STATE(7711), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [319343] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(8153), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8155), 1,
      sym_base_list,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9486), 1,
      sym_declaration_list,
    STATE(7712), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [319406] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9936), 1,
      sym_interpolation_end_quote,
    ACTIONS(9938), 1,
      sym_interpolation_open_brace,
    STATE(7725), 1,
      aux_sym_interpolated_string_expression_repeat1,
    STATE(8321), 1,
      sym_interpolation,
    STATE(8384), 1,
      sym__interpolated_string_content,
    ACTIONS(9934), 2,
      sym_interpolation_string_content,
      sym_escape_sequence,
    STATE(7713), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [319467] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(8196), 1,
      sym_base_list,
    STATE(8210), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9639), 1,
      sym_declaration_list,
    STATE(7714), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [319530] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(8124), 1,
      sym_base_list,
    STATE(8129), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9386), 1,
      sym_declaration_list,
    STATE(7715), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [319593] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(8229), 1,
      sym_base_list,
    STATE(8232), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9800), 1,
      sym_declaration_list,
    STATE(7716), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [319656] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9940), 7,
      anon_sym_where,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
    STATE(7717), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [319707] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(8164), 1,
      sym_base_list,
    STATE(8165), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9930), 1,
      sym_declaration_list,
    STATE(7718), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [319770] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(7982), 1,
      aux_sym_class_declaration_repeat3,
    STATE(7985), 1,
      sym_base_list,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9808), 1,
      sym_declaration_list,
    STATE(7719), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [319833] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(8219), 1,
      sym_base_list,
    STATE(8228), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9237), 1,
      sym_declaration_list,
    STATE(7720), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [319896] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9938), 1,
      sym_interpolation_open_brace,
    ACTIONS(9942), 1,
      sym_interpolation_end_quote,
    STATE(7741), 1,
      aux_sym_interpolated_string_expression_repeat1,
    STATE(8321), 1,
      sym_interpolation,
    STATE(8384), 1,
      sym__interpolated_string_content,
    ACTIONS(9934), 2,
      sym_interpolation_string_content,
      sym_escape_sequence,
    STATE(7721), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [319957] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(8030), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8033), 1,
      sym_base_list,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9530), 1,
      sym_declaration_list,
    STATE(7722), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [320020] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(8114), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8244), 1,
      sym_base_list,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9325), 1,
      sym_declaration_list,
    STATE(7723), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [320083] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(7958), 1,
      aux_sym_class_declaration_repeat3,
    STATE(7959), 1,
      sym_base_list,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9287), 1,
      sym_declaration_list,
    STATE(7724), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [320146] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9938), 1,
      sym_interpolation_open_brace,
    ACTIONS(9944), 1,
      sym_interpolation_end_quote,
    STATE(7766), 1,
      aux_sym_interpolated_string_expression_repeat1,
    STATE(8321), 1,
      sym_interpolation,
    STATE(8384), 1,
      sym__interpolated_string_content,
    ACTIONS(9934), 2,
      sym_interpolation_string_content,
      sym_escape_sequence,
    STATE(7725), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [320207] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(8112), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8116), 1,
      sym_base_list,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9339), 1,
      sym_declaration_list,
    STATE(7726), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [320270] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9930), 1,
      anon_sym_catch,
    ACTIONS(9932), 1,
      anon_sym_finally,
    STATE(7897), 1,
      aux_sym_try_statement_repeat1,
    STATE(8313), 1,
      sym_catch_clause,
    STATE(8705), 1,
      sym_finally_clause,
    ACTIONS(3013), 2,
      anon_sym_while,
      anon_sym_else,
    STATE(7727), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [320331] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(8028), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8032), 1,
      sym_base_list,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9099), 1,
      sym_declaration_list,
    STATE(7728), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [320394] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9938), 1,
      sym_interpolation_open_brace,
    ACTIONS(9946), 1,
      sym_interpolation_end_quote,
    STATE(7766), 1,
      aux_sym_interpolated_string_expression_repeat1,
    STATE(8321), 1,
      sym_interpolation,
    STATE(8384), 1,
      sym__interpolated_string_content,
    ACTIONS(9934), 2,
      sym_interpolation_string_content,
      sym_escape_sequence,
    STATE(7729), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [320455] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(8035), 1,
      sym_base_list,
    STATE(8040), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9114), 1,
      sym_declaration_list,
    STATE(7730), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [320518] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(7962), 1,
      aux_sym_class_declaration_repeat3,
    STATE(7963), 1,
      sym_base_list,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9160), 1,
      sym_declaration_list,
    STATE(7731), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [320581] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(8190), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8194), 1,
      sym_base_list,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9957), 1,
      sym_declaration_list,
    STATE(7732), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [320644] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9938), 1,
      sym_interpolation_open_brace,
    ACTIONS(9948), 1,
      sym_interpolation_end_quote,
    STATE(7766), 1,
      aux_sym_interpolated_string_expression_repeat1,
    STATE(8321), 1,
      sym_interpolation,
    STATE(8384), 1,
      sym__interpolated_string_content,
    ACTIONS(9934), 2,
      sym_interpolation_string_content,
      sym_escape_sequence,
    STATE(7733), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [320705] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(7964), 1,
      sym_base_list,
    STATE(7966), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9166), 1,
      sym_declaration_list,
    STATE(7734), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [320768] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(8013), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8015), 1,
      sym_base_list,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9694), 1,
      sym_declaration_list,
    STATE(7735), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [320831] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9950), 7,
      anon_sym_where,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
    STATE(7736), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [320882] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9952), 7,
      anon_sym_where,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
    STATE(7737), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [320933] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9954), 7,
      anon_sym_where,
      anon_sym_from,
      anon_sym_join,
      anon_sym_let,
      anon_sym_orderby,
      anon_sym_group,
      anon_sym_select,
    STATE(7738), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [320984] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9938), 1,
      sym_interpolation_open_brace,
    ACTIONS(9956), 1,
      sym_interpolation_end_quote,
    STATE(7749), 1,
      aux_sym_interpolated_string_expression_repeat1,
    STATE(8321), 1,
      sym_interpolation,
    STATE(8384), 1,
      sym__interpolated_string_content,
    ACTIONS(9934), 2,
      sym_interpolation_string_content,
      sym_escape_sequence,
    STATE(7739), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [321045] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(8001), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8003), 1,
      sym_base_list,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9553), 1,
      sym_declaration_list,
    STATE(7740), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [321108] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9938), 1,
      sym_interpolation_open_brace,
    ACTIONS(9958), 1,
      sym_interpolation_end_quote,
    STATE(7766), 1,
      aux_sym_interpolated_string_expression_repeat1,
    STATE(8321), 1,
      sym_interpolation,
    STATE(8384), 1,
      sym__interpolated_string_content,
    ACTIONS(9934), 2,
      sym_interpolation_string_content,
      sym_escape_sequence,
    STATE(7741), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [321169] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(8009), 1,
      sym_base_list,
    STATE(8022), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9527), 1,
      sym_declaration_list,
    STATE(7742), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [321232] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(7974), 1,
      aux_sym_class_declaration_repeat3,
    STATE(7975), 1,
      sym_base_list,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9831), 1,
      sym_declaration_list,
    STATE(7743), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [321295] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(8063), 1,
      sym_base_list,
    STATE(8067), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9731), 1,
      sym_declaration_list,
    STATE(7744), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [321358] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(8090), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8091), 1,
      sym_base_list,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9261), 1,
      sym_declaration_list,
    STATE(7745), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [321421] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(8175), 1,
      sym_base_list,
    STATE(8180), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9711), 1,
      sym_declaration_list,
    STATE(7746), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [321484] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(8092), 1,
      sym_base_list,
    STATE(8097), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9290), 1,
      sym_declaration_list,
    STATE(7747), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [321547] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(8121), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8125), 1,
      sym_base_list,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9303), 1,
      sym_declaration_list,
    STATE(7748), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [321610] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9938), 1,
      sym_interpolation_open_brace,
    ACTIONS(9960), 1,
      sym_interpolation_end_quote,
    STATE(7766), 1,
      aux_sym_interpolated_string_expression_repeat1,
    STATE(8321), 1,
      sym_interpolation,
    STATE(8384), 1,
      sym__interpolated_string_content,
    ACTIONS(9934), 2,
      sym_interpolation_string_content,
      sym_escape_sequence,
    STATE(7749), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [321671] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(8136), 1,
      sym_base_list,
    STATE(8141), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9414), 1,
      sym_declaration_list,
    STATE(7750), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [321734] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(8204), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8206), 1,
      sym_base_list,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9932), 1,
      sym_declaration_list,
    STATE(7751), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [321797] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(8078), 1,
      sym_base_list,
    STATE(8079), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9916), 1,
      sym_declaration_list,
    STATE(7752), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [321860] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(8120), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8127), 1,
      sym_base_list,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9239), 1,
      sym_declaration_list,
    STATE(7753), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [321923] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(8046), 1,
      sym_base_list,
    STATE(8058), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9494), 1,
      sym_declaration_list,
    STATE(7754), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [321986] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(8191), 1,
      sym_base_list,
    STATE(8209), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9359), 1,
      sym_declaration_list,
    STATE(7755), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [322049] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9938), 1,
      sym_interpolation_open_brace,
    ACTIONS(9962), 1,
      sym_interpolation_end_quote,
    STATE(7729), 1,
      aux_sym_interpolated_string_expression_repeat1,
    STATE(8321), 1,
      sym_interpolation,
    STATE(8384), 1,
      sym__interpolated_string_content,
    ACTIONS(9934), 2,
      sym_interpolation_string_content,
      sym_escape_sequence,
    STATE(7756), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [322110] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(8137), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8138), 1,
      sym_base_list,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9326), 1,
      sym_declaration_list,
    STATE(7757), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [322173] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(7995), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8008), 1,
      sym_base_list,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9526), 1,
      sym_declaration_list,
    STATE(7758), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [322236] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(8139), 1,
      sym_base_list,
    STATE(8149), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9352), 1,
      sym_declaration_list,
    STATE(7759), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [322299] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(8029), 1,
      sym_base_list,
    STATE(8031), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9687), 1,
      sym_declaration_list,
    STATE(7760), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [322362] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(8144), 1,
      sym_base_list,
    STATE(8150), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9927), 1,
      sym_declaration_list,
    STATE(7761), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [322425] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(8099), 1,
      sym_base_list,
    STATE(8133), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9696), 1,
      sym_declaration_list,
    STATE(7762), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [322488] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(8045), 1,
      sym_base_list,
    STATE(8047), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9689), 1,
      sym_declaration_list,
    STATE(7763), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [322551] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(8049), 1,
      sym_base_list,
    STATE(8050), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9699), 1,
      sym_declaration_list,
    STATE(7764), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [322614] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(8177), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8178), 1,
      sym_base_list,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9531), 1,
      sym_declaration_list,
    STATE(7765), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [322677] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9967), 1,
      sym_interpolation_end_quote,
    ACTIONS(9969), 1,
      sym_interpolation_open_brace,
    STATE(8321), 1,
      sym_interpolation,
    STATE(8384), 1,
      sym__interpolated_string_content,
    ACTIONS(9964), 2,
      sym_interpolation_string_content,
      sym_escape_sequence,
    STATE(7766), 10,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
      aux_sym_interpolated_string_expression_repeat1,
  [322736] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(8113), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8239), 1,
      sym_base_list,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9442), 1,
      sym_declaration_list,
    STATE(7767), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [322799] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(8154), 1,
      sym_base_list,
    STATE(8158), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9491), 1,
      sym_declaration_list,
    STATE(7768), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [322862] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(8017), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8018), 1,
      sym_base_list,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9684), 1,
      sym_declaration_list,
    STATE(7769), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [322925] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(8207), 1,
      sym_base_list,
    STATE(8212), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9744), 1,
      sym_declaration_list,
    STATE(7770), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [322988] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(8019), 1,
      sym_base_list,
    STATE(8023), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9798), 1,
      sym_declaration_list,
    STATE(7771), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [323051] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(8135), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8241), 1,
      sym_base_list,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9070), 1,
      sym_declaration_list,
    STATE(7772), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [323114] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(8094), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8096), 1,
      sym_base_list,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9877), 1,
      sym_declaration_list,
    STATE(7773), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [323177] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(8007), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8211), 1,
      sym_base_list,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9373), 1,
      sym_declaration_list,
    STATE(7774), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [323240] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(8098), 1,
      sym_base_list,
    STATE(8107), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9878), 1,
      sym_declaration_list,
    STATE(7775), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [323303] = 18,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9830), 1,
      anon_sym_COLON,
    STATE(8108), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8111), 1,
      sym_base_list,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9881), 1,
      sym_declaration_list,
    STATE(7776), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [323366] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9938), 1,
      sym_interpolation_open_brace,
    ACTIONS(9972), 1,
      sym_interpolation_end_quote,
    STATE(7733), 1,
      aux_sym_interpolated_string_expression_repeat1,
    STATE(8321), 1,
      sym_interpolation,
    STATE(8384), 1,
      sym__interpolated_string_content,
    ACTIONS(9934), 2,
      sym_interpolation_string_content,
      sym_escape_sequence,
    STATE(7777), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [323427] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9974), 1,
      anon_sym_SEMI,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9505), 1,
      sym_declaration_list,
    STATE(7778), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [323487] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9870), 1,
      anon_sym_SEMI,
    ACTIONS(9872), 1,
      anon_sym_LBRACE,
    STATE(3160), 1,
      sym_block,
    STATE(3302), 1,
      sym__function_body,
    STATE(9797), 1,
      sym_arrow_expression_clause,
    STATE(7779), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [323547] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9870), 1,
      anon_sym_SEMI,
    ACTIONS(9872), 1,
      anon_sym_LBRACE,
    STATE(3160), 1,
      sym_block,
    STATE(3305), 1,
      sym__function_body,
    STATE(9797), 1,
      sym_arrow_expression_clause,
    STATE(7780), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [323607] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9860), 1,
      anon_sym_SEMI,
    STATE(7908), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9481), 1,
      sym_declaration_list,
    STATE(7781), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [323667] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9860), 1,
      anon_sym_SEMI,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9481), 1,
      sym_declaration_list,
    STATE(7782), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [323727] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9854), 1,
      anon_sym_SEMI,
    STATE(7861), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9942), 1,
      sym_declaration_list,
    STATE(7783), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [323787] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9918), 1,
      anon_sym_SEMI,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9663), 1,
      sym_declaration_list,
    STATE(7784), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [323847] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9976), 1,
      anon_sym_SEMI,
    ACTIONS(9978), 1,
      anon_sym_LBRACE,
    STATE(4347), 1,
      sym__function_body,
    STATE(4356), 1,
      sym_block,
    STATE(9274), 1,
      sym_arrow_expression_clause,
    STATE(7785), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [323907] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9866), 1,
      anon_sym_SEMI,
    STATE(7802), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9586), 1,
      sym_declaration_list,
    STATE(7786), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [323967] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4145), 1,
      anon_sym_EQ_GT,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(9773), 1,
      anon_sym_EQ,
    STATE(8523), 1,
      sym_bracketed_argument_list,
    ACTIONS(9771), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    STATE(7787), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [324025] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9866), 1,
      anon_sym_SEMI,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9586), 1,
      sym_declaration_list,
    STATE(7788), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [324085] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9902), 1,
      anon_sym_SEMI,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9591), 1,
      sym_declaration_list,
    STATE(7789), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [324145] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9902), 1,
      anon_sym_SEMI,
    STATE(7809), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9591), 1,
      sym_declaration_list,
    STATE(7790), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [324205] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9938), 1,
      sym_interpolation_open_brace,
    ACTIONS(9980), 1,
      sym_interpolation_end_quote,
    ACTIONS(9982), 1,
      sym_interpolation_string_content,
    STATE(7843), 1,
      aux_sym_interpolated_string_expression_repeat3,
    STATE(8565), 1,
      sym_interpolation,
    STATE(8567), 1,
      sym__interpolated_raw_string_content,
    STATE(7791), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [324265] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9870), 1,
      anon_sym_SEMI,
    ACTIONS(9872), 1,
      anon_sym_LBRACE,
    STATE(3160), 1,
      sym_block,
    STATE(3317), 1,
      sym__function_body,
    STATE(9797), 1,
      sym_arrow_expression_clause,
    STATE(7792), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [324325] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9918), 1,
      anon_sym_SEMI,
    STATE(7934), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9663), 1,
      sym_declaration_list,
    STATE(7793), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [324385] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9870), 1,
      anon_sym_SEMI,
    ACTIONS(9872), 1,
      anon_sym_LBRACE,
    STATE(3160), 1,
      sym_block,
    STATE(3417), 1,
      sym__function_body,
    STATE(9797), 1,
      sym_arrow_expression_clause,
    STATE(7794), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [324445] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9986), 1,
      anon_sym_COMMA,
    STATE(7888), 1,
      aux_sym_type_parameter_constraints_clause_repeat1,
    ACTIONS(9984), 4,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_where,
      anon_sym_EQ_GT,
    STATE(7795), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [324499] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7463), 1,
      anon_sym_LT,
    ACTIONS(7465), 1,
      anon_sym_COLON_COLON,
    ACTIONS(9988), 1,
      anon_sym_EQ,
    STATE(2746), 1,
      sym_type_argument_list,
    ACTIONS(4140), 2,
      anon_sym_SEMI,
      anon_sym_DOT,
    STATE(7796), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [324557] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4145), 1,
      anon_sym_EQ_GT,
    ACTIONS(9990), 1,
      anon_sym_EQ,
    ACTIONS(4310), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_and,
      anon_sym_or,
    STATE(7797), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [324611] = 13,
    ACTIONS(3993), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    ACTIONS(3995), 5,
      anon_sym_COMMA,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    STATE(7798), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [324663] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9848), 1,
      anon_sym_SEMI,
    STATE(7806), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9728), 1,
      sym_declaration_list,
    STATE(7799), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [324723] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9848), 1,
      anon_sym_SEMI,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9728), 1,
      sym_declaration_list,
    STATE(7800), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [324783] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9870), 1,
      anon_sym_SEMI,
    ACTIONS(9872), 1,
      anon_sym_LBRACE,
    STATE(3160), 1,
      sym_block,
    STATE(3276), 1,
      sym__function_body,
    STATE(9797), 1,
      sym_arrow_expression_clause,
    STATE(7801), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [324843] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9916), 1,
      anon_sym_SEMI,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9843), 1,
      sym_declaration_list,
    STATE(7802), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [324903] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9852), 1,
      anon_sym_SEMI,
    STATE(7813), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9892), 1,
      sym_declaration_list,
    STATE(7803), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [324963] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9916), 1,
      anon_sym_SEMI,
    STATE(7846), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9843), 1,
      sym_declaration_list,
    STATE(7804), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [325023] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9852), 1,
      anon_sym_SEMI,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9892), 1,
      sym_declaration_list,
    STATE(7805), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [325083] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9898), 1,
      anon_sym_SEMI,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9894), 1,
      sym_declaration_list,
    STATE(7806), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [325143] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9898), 1,
      anon_sym_SEMI,
    STATE(7815), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9894), 1,
      sym_declaration_list,
    STATE(7807), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [325203] = 13,
    ACTIONS(4124), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    ACTIONS(4122), 5,
      anon_sym_COMMA,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    STATE(7808), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [325255] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9992), 1,
      anon_sym_SEMI,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9865), 1,
      sym_declaration_list,
    STATE(7809), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [325315] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9992), 1,
      anon_sym_SEMI,
    STATE(7853), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9865), 1,
      sym_declaration_list,
    STATE(7810), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [325375] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9994), 6,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_in,
    STATE(7811), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [325425] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9996), 1,
      anon_sym_SEMI,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9333), 1,
      sym_declaration_list,
    STATE(7812), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [325485] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9900), 1,
      anon_sym_SEMI,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9982), 1,
      sym_declaration_list,
    STATE(7813), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [325545] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9900), 1,
      anon_sym_SEMI,
    STATE(7821), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9982), 1,
      sym_declaration_list,
    STATE(7814), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [325605] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9998), 1,
      anon_sym_SEMI,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9911), 1,
      sym_declaration_list,
    STATE(7815), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [325665] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9998), 1,
      anon_sym_SEMI,
    STATE(7823), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9911), 1,
      sym_declaration_list,
    STATE(7816), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [325725] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10000), 6,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_in,
    STATE(7817), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [325775] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9868), 1,
      anon_sym_SEMI,
    STATE(7825), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9231), 1,
      sym_declaration_list,
    STATE(7818), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [325835] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9868), 1,
      anon_sym_SEMI,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9231), 1,
      sym_declaration_list,
    STATE(7819), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [325895] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9846), 1,
      anon_sym_SEMI,
    STATE(7870), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9572), 1,
      sym_declaration_list,
    STATE(7820), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [325955] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(10002), 1,
      anon_sym_SEMI,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9529), 1,
      sym_declaration_list,
    STATE(7821), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [326015] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(10002), 1,
      anon_sym_SEMI,
    STATE(7831), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9529), 1,
      sym_declaration_list,
    STATE(7822), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [326075] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(10004), 1,
      anon_sym_SEMI,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9557), 1,
      sym_declaration_list,
    STATE(7823), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [326135] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9864), 1,
      anon_sym_SEMI,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9618), 1,
      sym_declaration_list,
    STATE(7824), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [326195] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9904), 1,
      anon_sym_SEMI,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9136), 1,
      sym_declaration_list,
    STATE(7825), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [326255] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9904), 1,
      anon_sym_SEMI,
    STATE(7832), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9136), 1,
      sym_declaration_list,
    STATE(7826), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [326315] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9846), 1,
      anon_sym_SEMI,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9572), 1,
      sym_declaration_list,
    STATE(7827), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [326375] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9864), 1,
      anon_sym_SEMI,
    STATE(7784), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9618), 1,
      sym_declaration_list,
    STATE(7828), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [326435] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9858), 1,
      anon_sym_SEMI,
    STATE(7834), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9510), 1,
      sym_declaration_list,
    STATE(7829), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [326495] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9858), 1,
      anon_sym_SEMI,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9510), 1,
      sym_declaration_list,
    STATE(7830), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [326555] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(10006), 1,
      anon_sym_SEMI,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9621), 1,
      sym_declaration_list,
    STATE(7831), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [326615] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(10008), 1,
      anon_sym_SEMI,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9291), 1,
      sym_declaration_list,
    STATE(7832), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [326675] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(10008), 1,
      anon_sym_SEMI,
    STATE(7836), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9291), 1,
      sym_declaration_list,
    STATE(7833), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [326735] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9906), 1,
      anon_sym_SEMI,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9150), 1,
      sym_declaration_list,
    STATE(7834), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [326795] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9906), 1,
      anon_sym_SEMI,
    STATE(7778), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9150), 1,
      sym_declaration_list,
    STATE(7835), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [326855] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(10010), 1,
      anon_sym_SEMI,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9207), 1,
      sym_declaration_list,
    STATE(7836), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [326915] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9974), 1,
      anon_sym_SEMI,
    STATE(7838), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9505), 1,
      sym_declaration_list,
    STATE(7837), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [326975] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(10012), 1,
      anon_sym_SEMI,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9068), 1,
      sym_declaration_list,
    STATE(7838), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [327035] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9938), 1,
      sym_interpolation_open_brace,
    ACTIONS(9972), 1,
      sym_interpolation_end_quote,
    ACTIONS(10014), 1,
      sym_interpolation_string_content,
    STATE(7890), 1,
      aux_sym_interpolated_string_expression_repeat2,
    STATE(8541), 1,
      sym_interpolation,
    STATE(8556), 1,
      sym__interpolated_verbatim_string_content,
    STATE(7839), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [327095] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9870), 1,
      anon_sym_SEMI,
    ACTIONS(9872), 1,
      anon_sym_LBRACE,
    STATE(3160), 1,
      sym_block,
    STATE(3283), 1,
      sym__function_body,
    STATE(9797), 1,
      sym_arrow_expression_clause,
    STATE(7840), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [327155] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9870), 1,
      anon_sym_SEMI,
    ACTIONS(9872), 1,
      anon_sym_LBRACE,
    STATE(3160), 1,
      sym_block,
    STATE(3391), 1,
      sym__function_body,
    STATE(9797), 1,
      sym_arrow_expression_clause,
    STATE(7841), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [327215] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10016), 1,
      sym_interpolation_end_quote,
    ACTIONS(10018), 1,
      sym_interpolation_open_brace,
    ACTIONS(10021), 1,
      sym_interpolation_string_content,
    STATE(8541), 1,
      sym_interpolation,
    STATE(8556), 1,
      sym__interpolated_verbatim_string_content,
    STATE(7842), 10,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
      aux_sym_interpolated_string_expression_repeat2,
  [327273] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10024), 1,
      sym_interpolation_end_quote,
    ACTIONS(10026), 1,
      sym_interpolation_open_brace,
    ACTIONS(10029), 1,
      sym_interpolation_string_content,
    STATE(8565), 1,
      sym_interpolation,
    STATE(8567), 1,
      sym__interpolated_raw_string_content,
    STATE(7843), 10,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
      aux_sym_interpolated_string_expression_repeat3,
  [327331] = 17,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    ACTIONS(10032), 1,
      anon_sym_DQUOTE,
    ACTIONS(10034), 1,
      aux_sym_string_literal_content_token1,
    ACTIONS(10036), 1,
      aux_sym_string_literal_content_token2,
    ACTIONS(10038), 1,
      sym_escape_sequence,
    STATE(7928), 1,
      aux_sym_string_literal_repeat1,
    STATE(8346), 1,
      sym_string_literal_content,
    STATE(7844), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [327391] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7463), 1,
      anon_sym_LT,
    ACTIONS(7465), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10040), 1,
      anon_sym_EQ,
    STATE(2746), 1,
      sym_type_argument_list,
    ACTIONS(4140), 2,
      anon_sym_SEMI,
      anon_sym_DOT,
    STATE(7845), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [327449] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(10042), 1,
      anon_sym_SEMI,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9177), 1,
      sym_declaration_list,
    STATE(7846), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [327509] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10046), 1,
      anon_sym_QMARK,
    ACTIONS(10044), 5,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_where,
      anon_sym_EQ_GT,
    STATE(7847), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [327561] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(10042), 1,
      anon_sym_SEMI,
    STATE(7893), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9177), 1,
      sym_declaration_list,
    STATE(7848), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [327621] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9986), 1,
      anon_sym_COMMA,
    STATE(7795), 1,
      aux_sym_type_parameter_constraints_clause_repeat1,
    ACTIONS(10048), 4,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_where,
      anon_sym_EQ_GT,
    STATE(7849), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [327675] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(10050), 1,
      anon_sym_SEMI,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9479), 1,
      sym_declaration_list,
    STATE(7850), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [327735] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9850), 1,
      anon_sym_SEMI,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9598), 1,
      sym_declaration_list,
    STATE(7851), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [327795] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9938), 1,
      sym_interpolation_open_brace,
    ACTIONS(9982), 1,
      sym_interpolation_string_content,
    ACTIONS(10052), 1,
      sym_interpolation_end_quote,
    STATE(7892), 1,
      aux_sym_interpolated_string_expression_repeat3,
    STATE(8565), 1,
      sym_interpolation,
    STATE(8567), 1,
      sym__interpolated_raw_string_content,
    STATE(7852), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [327855] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(10054), 1,
      anon_sym_SEMI,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9182), 1,
      sym_declaration_list,
    STATE(7853), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [327915] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9870), 1,
      anon_sym_SEMI,
    ACTIONS(9872), 1,
      anon_sym_LBRACE,
    STATE(3160), 1,
      sym_block,
    STATE(3431), 1,
      sym__function_body,
    STATE(9797), 1,
      sym_arrow_expression_clause,
    STATE(7854), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [327975] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9870), 1,
      anon_sym_SEMI,
    ACTIONS(9872), 1,
      anon_sym_LBRACE,
    STATE(3160), 1,
      sym_block,
    STATE(3413), 1,
      sym__function_body,
    STATE(9797), 1,
      sym_arrow_expression_clause,
    STATE(7855), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [328035] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9870), 1,
      anon_sym_SEMI,
    ACTIONS(9872), 1,
      anon_sym_LBRACE,
    STATE(3160), 1,
      sym_block,
    STATE(3433), 1,
      sym__function_body,
    STATE(9797), 1,
      sym_arrow_expression_clause,
    STATE(7856), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [328095] = 17,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    ACTIONS(10034), 1,
      aux_sym_string_literal_content_token1,
    ACTIONS(10036), 1,
      aux_sym_string_literal_content_token2,
    ACTIONS(10038), 1,
      sym_escape_sequence,
    ACTIONS(10056), 1,
      anon_sym_DQUOTE,
    STATE(7868), 1,
      aux_sym_string_literal_repeat1,
    STATE(8346), 1,
      sym_string_literal_content,
    STATE(7857), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [328155] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9936), 1,
      sym_interpolation_end_quote,
    ACTIONS(9938), 1,
      sym_interpolation_open_brace,
    ACTIONS(10014), 1,
      sym_interpolation_string_content,
    STATE(7878), 1,
      aux_sym_interpolated_string_expression_repeat2,
    STATE(8541), 1,
      sym_interpolation,
    STATE(8556), 1,
      sym__interpolated_verbatim_string_content,
    STATE(7858), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [328215] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9938), 1,
      sym_interpolation_open_brace,
    ACTIONS(9982), 1,
      sym_interpolation_string_content,
    ACTIONS(10058), 1,
      sym_interpolation_end_quote,
    STATE(7880), 1,
      aux_sym_interpolated_string_expression_repeat3,
    STATE(8565), 1,
      sym_interpolation,
    STATE(8567), 1,
      sym__interpolated_raw_string_content,
    STATE(7859), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [328275] = 16,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    ACTIONS(10060), 1,
      anon_sym_DQUOTE,
    ACTIONS(10062), 1,
      aux_sym_string_literal_content_token1,
    ACTIONS(10065), 1,
      aux_sym_string_literal_content_token2,
    ACTIONS(10068), 1,
      sym_escape_sequence,
    STATE(8346), 1,
      sym_string_literal_content,
    STATE(7860), 10,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
      aux_sym_string_literal_repeat1,
  [328333] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9910), 1,
      anon_sym_SEMI,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9620), 1,
      sym_declaration_list,
    STATE(7861), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [328393] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9910), 1,
      anon_sym_SEMI,
    STATE(7929), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9620), 1,
      sym_declaration_list,
    STATE(7862), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [328453] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9870), 1,
      anon_sym_SEMI,
    ACTIONS(9872), 1,
      anon_sym_LBRACE,
    STATE(3160), 1,
      sym_block,
    STATE(3332), 1,
      sym__function_body,
    STATE(9797), 1,
      sym_arrow_expression_clause,
    STATE(7863), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [328513] = 17,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    ACTIONS(10034), 1,
      aux_sym_string_literal_content_token1,
    ACTIONS(10036), 1,
      aux_sym_string_literal_content_token2,
    ACTIONS(10038), 1,
      sym_escape_sequence,
    ACTIONS(10071), 1,
      anon_sym_DQUOTE,
    STATE(7886), 1,
      aux_sym_string_literal_repeat1,
    STATE(8346), 1,
      sym_string_literal_content,
    STATE(7864), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [328573] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(10073), 1,
      anon_sym_SEMI,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9123), 1,
      sym_declaration_list,
    STATE(7865), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [328633] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(10073), 1,
      anon_sym_SEMI,
    STATE(7812), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9123), 1,
      sym_declaration_list,
    STATE(7866), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [328693] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8544), 1,
      anon_sym_DOT,
    ACTIONS(9914), 1,
      anon_sym_COMMA,
    STATE(8134), 1,
      aux_sym_record_base_repeat1,
    ACTIONS(10075), 3,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_where,
    STATE(7867), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [328749] = 17,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    ACTIONS(10034), 1,
      aux_sym_string_literal_content_token1,
    ACTIONS(10036), 1,
      aux_sym_string_literal_content_token2,
    ACTIONS(10038), 1,
      sym_escape_sequence,
    ACTIONS(10077), 1,
      anon_sym_DQUOTE,
    STATE(7860), 1,
      aux_sym_string_literal_repeat1,
    STATE(8346), 1,
      sym_string_literal_content,
    STATE(7868), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [328809] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9870), 1,
      anon_sym_SEMI,
    ACTIONS(9872), 1,
      anon_sym_LBRACE,
    STATE(3160), 1,
      sym_block,
    STATE(3334), 1,
      sym__function_body,
    STATE(9797), 1,
      sym_arrow_expression_clause,
    STATE(7869), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [328869] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9924), 1,
      anon_sym_SEMI,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9323), 1,
      sym_declaration_list,
    STATE(7870), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [328929] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9924), 1,
      anon_sym_SEMI,
    STATE(7900), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9323), 1,
      sym_declaration_list,
    STATE(7871), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [328989] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9976), 1,
      anon_sym_SEMI,
    ACTIONS(9978), 1,
      anon_sym_LBRACE,
    STATE(4353), 1,
      sym__function_body,
    STATE(4356), 1,
      sym_block,
    STATE(9274), 1,
      sym_arrow_expression_clause,
    STATE(7872), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [329049] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(10079), 1,
      anon_sym_SEMI,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9322), 1,
      sym_declaration_list,
    STATE(7873), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [329109] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9938), 1,
      sym_interpolation_open_brace,
    ACTIONS(9942), 1,
      sym_interpolation_end_quote,
    ACTIONS(10014), 1,
      sym_interpolation_string_content,
    STATE(7901), 1,
      aux_sym_interpolated_string_expression_repeat2,
    STATE(8541), 1,
      sym_interpolation,
    STATE(8556), 1,
      sym__interpolated_verbatim_string_content,
    STATE(7874), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [329169] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9938), 1,
      sym_interpolation_open_brace,
    ACTIONS(9982), 1,
      sym_interpolation_string_content,
    ACTIONS(10081), 1,
      sym_interpolation_end_quote,
    STATE(7903), 1,
      aux_sym_interpolated_string_expression_repeat3,
    STATE(8565), 1,
      sym_interpolation,
    STATE(8567), 1,
      sym__interpolated_raw_string_content,
    STATE(7875), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [329229] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9870), 1,
      anon_sym_SEMI,
    ACTIONS(9872), 1,
      anon_sym_LBRACE,
    STATE(3160), 1,
      sym_block,
    STATE(3340), 1,
      sym__function_body,
    STATE(9797), 1,
      sym_arrow_expression_clause,
    STATE(7876), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [329289] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9862), 1,
      anon_sym_SEMI,
    STATE(7789), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9276), 1,
      sym_declaration_list,
    STATE(7877), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [329349] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9938), 1,
      sym_interpolation_open_brace,
    ACTIONS(9944), 1,
      sym_interpolation_end_quote,
    ACTIONS(10014), 1,
      sym_interpolation_string_content,
    STATE(7842), 1,
      aux_sym_interpolated_string_expression_repeat2,
    STATE(8541), 1,
      sym_interpolation,
    STATE(8556), 1,
      sym__interpolated_verbatim_string_content,
    STATE(7878), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [329409] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9870), 1,
      anon_sym_SEMI,
    ACTIONS(9872), 1,
      anon_sym_LBRACE,
    STATE(3160), 1,
      sym_block,
    STATE(3350), 1,
      sym__function_body,
    STATE(9797), 1,
      sym_arrow_expression_clause,
    STATE(7879), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [329469] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9938), 1,
      sym_interpolation_open_brace,
    ACTIONS(9982), 1,
      sym_interpolation_string_content,
    ACTIONS(10083), 1,
      sym_interpolation_end_quote,
    STATE(7843), 1,
      aux_sym_interpolated_string_expression_repeat3,
    STATE(8565), 1,
      sym_interpolation,
    STATE(8567), 1,
      sym__interpolated_raw_string_content,
    STATE(7880), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [329529] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6138), 1,
      anon_sym_LBRACE,
    ACTIONS(10085), 1,
      anon_sym_LPAREN,
    ACTIONS(10087), 1,
      anon_sym_when,
    STATE(2650), 1,
      sym_block,
    STATE(8328), 1,
      sym_catch_declaration,
    STATE(8736), 1,
      sym_catch_filter_clause,
    STATE(7881), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [329589] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4494), 1,
      anon_sym_GT,
    ACTIONS(7411), 1,
      anon_sym_LBRACK,
    ACTIONS(7415), 1,
      anon_sym_STAR,
    ACTIONS(7477), 1,
      anon_sym_DOT,
    ACTIONS(10089), 1,
      anon_sym_COMMA,
    ACTIONS(10091), 1,
      anon_sym_QMARK,
    STATE(7882), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [329649] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9856), 1,
      anon_sym_SEMI,
    STATE(7910), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9445), 1,
      sym_declaration_list,
    STATE(7883), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [329709] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5788), 1,
      anon_sym_LBRACE,
    ACTIONS(10085), 1,
      anon_sym_LPAREN,
    ACTIONS(10087), 1,
      anon_sym_when,
    STATE(2265), 1,
      sym_block,
    STATE(8289), 1,
      sym_catch_declaration,
    STATE(8738), 1,
      sym_catch_filter_clause,
    STATE(7884), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [329769] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9862), 1,
      anon_sym_SEMI,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9276), 1,
      sym_declaration_list,
    STATE(7885), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [329829] = 17,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    ACTIONS(10034), 1,
      aux_sym_string_literal_content_token1,
    ACTIONS(10036), 1,
      aux_sym_string_literal_content_token2,
    ACTIONS(10038), 1,
      sym_escape_sequence,
    ACTIONS(10093), 1,
      anon_sym_DQUOTE,
    STATE(7860), 1,
      aux_sym_string_literal_repeat1,
    STATE(8346), 1,
      sym_string_literal_content,
    STATE(7886), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [329889] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9870), 1,
      anon_sym_SEMI,
    ACTIONS(9872), 1,
      anon_sym_LBRACE,
    STATE(3160), 1,
      sym_block,
    STATE(3367), 1,
      sym__function_body,
    STATE(9797), 1,
      sym_arrow_expression_clause,
    STATE(7887), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [329949] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10097), 1,
      anon_sym_COMMA,
    ACTIONS(10095), 4,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_where,
      anon_sym_EQ_GT,
    STATE(7888), 10,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
      aux_sym_type_parameter_constraints_clause_repeat1,
  [330001] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9856), 1,
      anon_sym_SEMI,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9445), 1,
      sym_declaration_list,
    STATE(7889), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [330061] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9938), 1,
      sym_interpolation_open_brace,
    ACTIONS(9948), 1,
      sym_interpolation_end_quote,
    ACTIONS(10014), 1,
      sym_interpolation_string_content,
    STATE(7842), 1,
      aux_sym_interpolated_string_expression_repeat2,
    STATE(8541), 1,
      sym_interpolation,
    STATE(8556), 1,
      sym__interpolated_verbatim_string_content,
    STATE(7890), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [330121] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4145), 1,
      anon_sym_EQ_GT,
    ACTIONS(9990), 1,
      anon_sym_EQ,
    ACTIONS(10100), 1,
      anon_sym_RPAREN,
    ACTIONS(4310), 3,
      anon_sym_COMMA,
      anon_sym_and,
      anon_sym_or,
    STATE(7891), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [330177] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9938), 1,
      sym_interpolation_open_brace,
    ACTIONS(9982), 1,
      sym_interpolation_string_content,
    ACTIONS(10102), 1,
      sym_interpolation_end_quote,
    STATE(7843), 1,
      aux_sym_interpolated_string_expression_repeat3,
    STATE(8565), 1,
      sym_interpolation,
    STATE(8567), 1,
      sym__interpolated_raw_string_content,
    STATE(7892), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [330237] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(10104), 1,
      anon_sym_SEMI,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9489), 1,
      sym_declaration_list,
    STATE(7893), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [330297] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(10106), 1,
      anon_sym_COMMA,
    STATE(8316), 1,
      sym_argument_list,
    STATE(8323), 1,
      aux_sym_base_list_repeat1,
    ACTIONS(10108), 2,
      anon_sym_LBRACE,
      anon_sym_where,
    STATE(7894), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [330355] = 17,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    ACTIONS(10034), 1,
      aux_sym_string_literal_content_token1,
    ACTIONS(10036), 1,
      aux_sym_string_literal_content_token2,
    ACTIONS(10038), 1,
      sym_escape_sequence,
    ACTIONS(10110), 1,
      anon_sym_DQUOTE,
    STATE(7905), 1,
      aux_sym_string_literal_repeat1,
    STATE(8346), 1,
      sym_string_literal_content,
    STATE(7895), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [330415] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9870), 1,
      anon_sym_SEMI,
    ACTIONS(9872), 1,
      anon_sym_LBRACE,
    STATE(3160), 1,
      sym_block,
    STATE(3401), 1,
      sym__function_body,
    STATE(9797), 1,
      sym_arrow_expression_clause,
    STATE(7896), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [330475] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10112), 1,
      anon_sym_catch,
    STATE(8313), 1,
      sym_catch_clause,
    ACTIONS(3017), 3,
      anon_sym_while,
      anon_sym_finally,
      anon_sym_else,
    STATE(7897), 10,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
      aux_sym_try_statement_repeat1,
  [330529] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9938), 1,
      sym_interpolation_open_brace,
    ACTIONS(9956), 1,
      sym_interpolation_end_quote,
    ACTIONS(10014), 1,
      sym_interpolation_string_content,
    STATE(7912), 1,
      aux_sym_interpolated_string_expression_repeat2,
    STATE(8541), 1,
      sym_interpolation,
    STATE(8556), 1,
      sym__interpolated_verbatim_string_content,
    STATE(7898), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [330589] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9938), 1,
      sym_interpolation_open_brace,
    ACTIONS(9982), 1,
      sym_interpolation_string_content,
    ACTIONS(10115), 1,
      sym_interpolation_end_quote,
    STATE(7913), 1,
      aux_sym_interpolated_string_expression_repeat3,
    STATE(8565), 1,
      sym_interpolation,
    STATE(8567), 1,
      sym__interpolated_raw_string_content,
    STATE(7899), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [330649] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(10117), 1,
      anon_sym_SEMI,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9516), 1,
      sym_declaration_list,
    STATE(7900), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [330709] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9938), 1,
      sym_interpolation_open_brace,
    ACTIONS(9958), 1,
      sym_interpolation_end_quote,
    ACTIONS(10014), 1,
      sym_interpolation_string_content,
    STATE(7842), 1,
      aux_sym_interpolated_string_expression_repeat2,
    STATE(8541), 1,
      sym_interpolation,
    STATE(8556), 1,
      sym__interpolated_verbatim_string_content,
    STATE(7901), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [330769] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(10117), 1,
      anon_sym_SEMI,
    STATE(7918), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9516), 1,
      sym_declaration_list,
    STATE(7902), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [330829] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9938), 1,
      sym_interpolation_open_brace,
    ACTIONS(9982), 1,
      sym_interpolation_string_content,
    ACTIONS(10119), 1,
      sym_interpolation_end_quote,
    STATE(7843), 1,
      aux_sym_interpolated_string_expression_repeat3,
    STATE(8565), 1,
      sym_interpolation,
    STATE(8567), 1,
      sym__interpolated_raw_string_content,
    STATE(7903), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [330889] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9976), 1,
      anon_sym_SEMI,
    ACTIONS(9978), 1,
      anon_sym_LBRACE,
    STATE(4339), 1,
      sym__function_body,
    STATE(4356), 1,
      sym_block,
    STATE(9274), 1,
      sym_arrow_expression_clause,
    STATE(7904), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [330949] = 17,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    ACTIONS(10034), 1,
      aux_sym_string_literal_content_token1,
    ACTIONS(10036), 1,
      aux_sym_string_literal_content_token2,
    ACTIONS(10038), 1,
      sym_escape_sequence,
    ACTIONS(10121), 1,
      anon_sym_DQUOTE,
    STATE(7860), 1,
      aux_sym_string_literal_repeat1,
    STATE(8346), 1,
      sym_string_literal_content,
    STATE(7905), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [331009] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10125), 1,
      anon_sym_where,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    ACTIONS(10123), 3,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ_GT,
    STATE(7906), 10,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
      aux_sym_class_declaration_repeat3,
  [331063] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(10128), 1,
      anon_sym_SEMI,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9746), 1,
      sym_declaration_list,
    STATE(7907), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [331123] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9922), 1,
      anon_sym_SEMI,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9654), 1,
      sym_declaration_list,
    STATE(7908), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [331183] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9922), 1,
      anon_sym_SEMI,
    STATE(7850), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9654), 1,
      sym_declaration_list,
    STATE(7909), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [331243] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9928), 1,
      anon_sym_SEMI,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9565), 1,
      sym_declaration_list,
    STATE(7910), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [331303] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7463), 1,
      anon_sym_LT,
    ACTIONS(7465), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10130), 1,
      anon_sym_EQ,
    STATE(2746), 1,
      sym_type_argument_list,
    ACTIONS(4140), 2,
      anon_sym_SEMI,
      anon_sym_DOT,
    STATE(7911), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [331361] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9938), 1,
      sym_interpolation_open_brace,
    ACTIONS(9960), 1,
      sym_interpolation_end_quote,
    ACTIONS(10014), 1,
      sym_interpolation_string_content,
    STATE(7842), 1,
      aux_sym_interpolated_string_expression_repeat2,
    STATE(8541), 1,
      sym_interpolation,
    STATE(8556), 1,
      sym__interpolated_verbatim_string_content,
    STATE(7912), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [331421] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9938), 1,
      sym_interpolation_open_brace,
    ACTIONS(9982), 1,
      sym_interpolation_string_content,
    ACTIONS(10132), 1,
      sym_interpolation_end_quote,
    STATE(7843), 1,
      aux_sym_interpolated_string_expression_repeat3,
    STATE(8565), 1,
      sym_interpolation,
    STATE(8567), 1,
      sym__interpolated_raw_string_content,
    STATE(7913), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [331481] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9928), 1,
      anon_sym_SEMI,
    STATE(7922), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9565), 1,
      sym_declaration_list,
    STATE(7914), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [331541] = 17,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    ACTIONS(10034), 1,
      aux_sym_string_literal_content_token1,
    ACTIONS(10036), 1,
      aux_sym_string_literal_content_token2,
    ACTIONS(10038), 1,
      sym_escape_sequence,
    ACTIONS(10134), 1,
      anon_sym_DQUOTE,
    STATE(7946), 1,
      aux_sym_string_literal_repeat1,
    STATE(8346), 1,
      sym_string_literal_content,
    STATE(7915), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [331601] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5786), 1,
      anon_sym_LBRACE,
    ACTIONS(10085), 1,
      anon_sym_LPAREN,
    ACTIONS(10087), 1,
      anon_sym_when,
    STATE(2219), 1,
      sym_block,
    STATE(8291), 1,
      sym_catch_declaration,
    STATE(8838), 1,
      sym_catch_filter_clause,
    STATE(7916), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [331661] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7463), 1,
      anon_sym_LT,
    ACTIONS(7465), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10136), 1,
      anon_sym_EQ,
    STATE(2746), 1,
      sym_type_argument_list,
    ACTIONS(4140), 2,
      anon_sym_SEMI,
      anon_sym_DOT,
    STATE(7917), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [331719] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(10138), 1,
      anon_sym_SEMI,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9626), 1,
      sym_declaration_list,
    STATE(7918), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [331779] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9938), 1,
      sym_interpolation_open_brace,
    ACTIONS(9962), 1,
      sym_interpolation_end_quote,
    ACTIONS(10014), 1,
      sym_interpolation_string_content,
    STATE(7941), 1,
      aux_sym_interpolated_string_expression_repeat2,
    STATE(8541), 1,
      sym_interpolation,
    STATE(8556), 1,
      sym__interpolated_verbatim_string_content,
    STATE(7919), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [331839] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9938), 1,
      sym_interpolation_open_brace,
    ACTIONS(9982), 1,
      sym_interpolation_string_content,
    ACTIONS(10140), 1,
      sym_interpolation_end_quote,
    STATE(7791), 1,
      aux_sym_interpolated_string_expression_repeat3,
    STATE(8565), 1,
      sym_interpolation,
    STATE(8567), 1,
      sym__interpolated_raw_string_content,
    STATE(7920), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [331899] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6108), 1,
      anon_sym_LBRACE,
    ACTIONS(10085), 1,
      anon_sym_LPAREN,
    ACTIONS(10087), 1,
      anon_sym_when,
    STATE(8332), 1,
      sym_block,
    STATE(8368), 1,
      sym_catch_declaration,
    STATE(8922), 1,
      sym_catch_filter_clause,
    STATE(7921), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [331959] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(10142), 1,
      anon_sym_SEMI,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9658), 1,
      sym_declaration_list,
    STATE(7922), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [332019] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(10142), 1,
      anon_sym_SEMI,
    STATE(7924), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9658), 1,
      sym_declaration_list,
    STATE(7923), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [332079] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(10144), 1,
      anon_sym_SEMI,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9710), 1,
      sym_declaration_list,
    STATE(7924), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [332139] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9926), 1,
      anon_sym_SEMI,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9044), 1,
      sym_declaration_list,
    STATE(7925), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [332199] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9926), 1,
      anon_sym_SEMI,
    STATE(7865), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9044), 1,
      sym_declaration_list,
    STATE(7926), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [332259] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7463), 1,
      anon_sym_LT,
    ACTIONS(7465), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10146), 1,
      anon_sym_EQ,
    STATE(2746), 1,
      sym_type_argument_list,
    ACTIONS(4140), 2,
      anon_sym_SEMI,
      anon_sym_DOT,
    STATE(7927), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [332317] = 17,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    ACTIONS(10034), 1,
      aux_sym_string_literal_content_token1,
    ACTIONS(10036), 1,
      aux_sym_string_literal_content_token2,
    ACTIONS(10038), 1,
      sym_escape_sequence,
    ACTIONS(10148), 1,
      anon_sym_DQUOTE,
    STATE(7860), 1,
      aux_sym_string_literal_repeat1,
    STATE(8346), 1,
      sym_string_literal_content,
    STATE(7928), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [332377] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(10150), 1,
      anon_sym_SEMI,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9146), 1,
      sym_declaration_list,
    STATE(7929), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [332437] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9870), 1,
      anon_sym_SEMI,
    ACTIONS(9872), 1,
      anon_sym_LBRACE,
    STATE(3160), 1,
      sym_block,
    STATE(3299), 1,
      sym__function_body,
    STATE(9797), 1,
      sym_arrow_expression_clause,
    STATE(7930), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [332497] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(10150), 1,
      anon_sym_SEMI,
    STATE(7933), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9146), 1,
      sym_declaration_list,
    STATE(7931), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [332557] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9870), 1,
      anon_sym_SEMI,
    ACTIONS(9872), 1,
      anon_sym_LBRACE,
    STATE(3160), 1,
      sym_block,
    STATE(3414), 1,
      sym__function_body,
    STATE(9797), 1,
      sym_arrow_expression_clause,
    STATE(7932), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [332617] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(10152), 1,
      anon_sym_SEMI,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9673), 1,
      sym_declaration_list,
    STATE(7933), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [332677] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(10154), 1,
      anon_sym_SEMI,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9091), 1,
      sym_declaration_list,
    STATE(7934), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [332737] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(10154), 1,
      anon_sym_SEMI,
    STATE(7873), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9091), 1,
      sym_declaration_list,
    STATE(7935), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [332797] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10156), 6,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_in,
    STATE(7936), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [332847] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7463), 1,
      anon_sym_LT,
    ACTIONS(7465), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10158), 1,
      anon_sym_EQ,
    STATE(2746), 1,
      sym_type_argument_list,
    ACTIONS(4140), 2,
      anon_sym_SEMI,
      anon_sym_DOT,
    STATE(7937), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [332905] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9854), 1,
      anon_sym_SEMI,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9942), 1,
      sym_declaration_list,
    STATE(7938), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [332965] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10160), 6,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_LBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_in,
    STATE(7939), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [333015] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7463), 1,
      anon_sym_LT,
    ACTIONS(7465), 1,
      anon_sym_COLON_COLON,
    ACTIONS(10162), 1,
      anon_sym_EQ,
    STATE(2746), 1,
      sym_type_argument_list,
    ACTIONS(4140), 2,
      anon_sym_SEMI,
      anon_sym_DOT,
    STATE(7940), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [333073] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9938), 1,
      sym_interpolation_open_brace,
    ACTIONS(9946), 1,
      sym_interpolation_end_quote,
    ACTIONS(10014), 1,
      sym_interpolation_string_content,
    STATE(7842), 1,
      aux_sym_interpolated_string_expression_repeat2,
    STATE(8541), 1,
      sym_interpolation,
    STATE(8556), 1,
      sym__interpolated_verbatim_string_content,
    STATE(7941), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [333133] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9870), 1,
      anon_sym_SEMI,
    ACTIONS(9872), 1,
      anon_sym_LBRACE,
    STATE(3160), 1,
      sym_block,
    STATE(3387), 1,
      sym__function_body,
    STATE(9797), 1,
      sym_arrow_expression_clause,
    STATE(7942), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [333193] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7411), 1,
      anon_sym_LBRACK,
    ACTIONS(7415), 1,
      anon_sym_STAR,
    ACTIONS(7477), 1,
      anon_sym_DOT,
    ACTIONS(10091), 1,
      anon_sym_QMARK,
    ACTIONS(4494), 2,
      anon_sym_COMMA,
      anon_sym_GT,
    STATE(7943), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [333251] = 17,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    ACTIONS(10034), 1,
      aux_sym_string_literal_content_token1,
    ACTIONS(10036), 1,
      aux_sym_string_literal_content_token2,
    ACTIONS(10038), 1,
      sym_escape_sequence,
    ACTIONS(10164), 1,
      anon_sym_DQUOTE,
    STATE(7948), 1,
      aux_sym_string_literal_repeat1,
    STATE(8346), 1,
      sym_string_literal_content,
    STATE(7944), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [333311] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(9850), 1,
      anon_sym_SEMI,
    STATE(7925), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9598), 1,
      sym_declaration_list,
    STATE(7945), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [333371] = 17,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    ACTIONS(10034), 1,
      aux_sym_string_literal_content_token1,
    ACTIONS(10036), 1,
      aux_sym_string_literal_content_token2,
    ACTIONS(10038), 1,
      sym_escape_sequence,
    ACTIONS(10166), 1,
      anon_sym_DQUOTE,
    STATE(7860), 1,
      aux_sym_string_literal_repeat1,
    STATE(8346), 1,
      sym_string_literal_content,
    STATE(7946), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [333431] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    ACTIONS(9870), 1,
      anon_sym_SEMI,
    ACTIONS(9872), 1,
      anon_sym_LBRACE,
    STATE(3160), 1,
      sym_block,
    STATE(3388), 1,
      sym__function_body,
    STATE(9797), 1,
      sym_arrow_expression_clause,
    STATE(7947), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [333491] = 17,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    ACTIONS(10034), 1,
      aux_sym_string_literal_content_token1,
    ACTIONS(10036), 1,
      aux_sym_string_literal_content_token2,
    ACTIONS(10038), 1,
      sym_escape_sequence,
    ACTIONS(10168), 1,
      anon_sym_DQUOTE,
    STATE(7860), 1,
      aux_sym_string_literal_repeat1,
    STATE(8346), 1,
      sym_string_literal_content,
    STATE(7948), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [333551] = 17,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(10050), 1,
      anon_sym_SEMI,
    STATE(7907), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9479), 1,
      sym_declaration_list,
    STATE(7949), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [333611] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9963), 1,
      sym_declaration_list,
    STATE(7950), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [333668] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9302), 1,
      sym_declaration_list,
    STATE(7951), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [333725] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10170), 1,
      anon_sym_COMMA,
    ACTIONS(10172), 1,
      anon_sym_RBRACK,
    ACTIONS(10174), 1,
      anon_sym_and,
    ACTIONS(10176), 1,
      anon_sym_or,
    STATE(8507), 1,
      aux_sym_list_pattern_repeat1,
    STATE(7952), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [333782] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9731), 1,
      sym_declaration_list,
    STATE(7953), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [333839] = 15,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    ACTIONS(10180), 1,
      anon_sym_AMP_AMP,
    ACTIONS(10182), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(10184), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(10178), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    STATE(7954), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [333894] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9602), 1,
      sym_declaration_list,
    STATE(7955), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [333951] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9359), 1,
      sym_declaration_list,
    STATE(7956), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [334008] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9490), 1,
      sym_declaration_list,
    STATE(7957), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [334065] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9039), 1,
      sym_declaration_list,
    STATE(7958), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [334122] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7971), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9039), 1,
      sym_declaration_list,
    STATE(7959), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [334179] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9259), 1,
      aux_sym_preproc_else_token1,
    ACTIONS(9261), 1,
      aux_sym_preproc_elif_token1,
    ACTIONS(10186), 1,
      aux_sym_preproc_if_token3,
    STATE(9321), 2,
      sym_preproc_else_in_enum_member_declaration,
      sym_preproc_elif_in_enum_member_declaration,
    STATE(7960), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [334234] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9458), 1,
      sym_declaration_list,
    STATE(7961), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [334291] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9533), 1,
      sym_declaration_list,
    STATE(7962), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [334348] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7973), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9533), 1,
      sym_declaration_list,
    STATE(7963), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [334405] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7974), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9831), 1,
      sym_declaration_list,
    STATE(7964), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [334462] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9373), 1,
      sym_declaration_list,
    STATE(7965), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [334519] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9831), 1,
      sym_declaration_list,
    STATE(7966), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [334576] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9011), 1,
      sym_declaration_list,
    STATE(7967), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [334633] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(8183), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9714), 1,
      sym_declaration_list,
    STATE(7968), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [334690] = 15,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    ACTIONS(10180), 1,
      anon_sym_AMP_AMP,
    ACTIONS(10182), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(10188), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(10178), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    STATE(7969), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [334745] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(8081), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9953), 1,
      sym_declaration_list,
    STATE(7970), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [334802] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9164), 1,
      sym_declaration_list,
    STATE(7971), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [334859] = 15,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    ACTIONS(10180), 1,
      anon_sym_AMP_AMP,
    ACTIONS(10182), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(10190), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(10178), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    STATE(7972), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [334914] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9219), 1,
      sym_declaration_list,
    STATE(7973), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [334971] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9338), 1,
      sym_declaration_list,
    STATE(7974), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [335028] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7978), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9338), 1,
      sym_declaration_list,
    STATE(7975), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [335085] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9953), 1,
      sym_declaration_list,
    STATE(7976), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [335142] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9714), 1,
      sym_declaration_list,
    STATE(7977), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [335199] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9869), 1,
      sym_declaration_list,
    STATE(7978), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [335256] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(8031), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9687), 1,
      sym_declaration_list,
    STATE(7979), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [335313] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(9835), 1,
      anon_sym_EQ,
    STATE(8523), 1,
      sym_bracketed_argument_list,
    ACTIONS(9771), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    STATE(7980), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [335368] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9138), 1,
      sym_declaration_list,
    STATE(7981), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [335425] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9153), 1,
      sym_declaration_list,
    STATE(7982), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [335482] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9459), 1,
      sym_declaration_list,
    STATE(7983), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [335539] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10192), 5,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_where,
      anon_sym_EQ_GT,
    STATE(7984), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [335588] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(8105), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9153), 1,
      sym_declaration_list,
    STATE(7985), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [335645] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9687), 1,
      sym_declaration_list,
    STATE(7986), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [335702] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10174), 1,
      anon_sym_and,
    ACTIONS(6705), 4,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_or,
    STATE(7987), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [335753] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9159), 1,
      sym_declaration_list,
    STATE(7988), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [335810] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(8047), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9689), 1,
      sym_declaration_list,
    STATE(7989), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [335867] = 13,
    ACTIONS(5682), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    ACTIONS(5684), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    STATE(7990), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [335918] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6108), 1,
      anon_sym_LBRACE,
    ACTIONS(6110), 1,
      anon_sym_STAR,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(3769), 1,
      sym_block,
    STATE(8932), 1,
      sym_parameter_list,
    STATE(7991), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [335975] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6110), 1,
      anon_sym_STAR,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(10194), 1,
      anon_sym_LBRACE,
    STATE(4000), 1,
      sym_block,
    STATE(8819), 1,
      sym_parameter_list,
    STATE(7992), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [336032] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9689), 1,
      sym_declaration_list,
    STATE(7993), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [336089] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10196), 5,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    STATE(7994), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [336138] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9807), 1,
      sym_declaration_list,
    STATE(7995), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [336195] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(8053), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9705), 1,
      sym_declaration_list,
    STATE(7996), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [336252] = 15,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    ACTIONS(10180), 1,
      anon_sym_AMP_AMP,
    ACTIONS(10182), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(10198), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(10178), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    STATE(7997), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [336307] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10200), 5,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_where,
      anon_sym_EQ_GT,
    STATE(7998), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [336356] = 15,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    ACTIONS(10180), 1,
      anon_sym_AMP_AMP,
    ACTIONS(10182), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(10202), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(10178), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    STATE(7999), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [336411] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9439), 1,
      sym_declaration_list,
    STATE(8000), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [336468] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9460), 1,
      sym_declaration_list,
    STATE(8001), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [336525] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    STATE(8566), 1,
      sym_argument_list,
    ACTIONS(10204), 3,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_where,
    STATE(8002), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [336578] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(8146), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9460), 1,
      sym_declaration_list,
    STATE(8003), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [336635] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10206), 5,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_where,
    STATE(8004), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [336684] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9705), 1,
      sym_declaration_list,
    STATE(8005), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [336741] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10044), 5,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_where,
      anon_sym_EQ_GT,
    STATE(8006), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [336790] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9530), 1,
      sym_declaration_list,
    STATE(8007), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [336847] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7981), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9807), 1,
      sym_declaration_list,
    STATE(8008), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [336904] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7982), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9808), 1,
      sym_declaration_list,
    STATE(8009), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [336961] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(10210), 1,
      anon_sym_EQ,
    STATE(8505), 1,
      sym_bracketed_argument_list,
    ACTIONS(10208), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    STATE(8010), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [337016] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10212), 5,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_where,
      anon_sym_EQ_GT,
    STATE(8011), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [337065] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9563), 1,
      sym_declaration_list,
    STATE(8012), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [337122] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9583), 1,
      sym_declaration_list,
    STATE(8013), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [337179] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9259), 1,
      aux_sym_preproc_else_token1,
    ACTIONS(9261), 1,
      aux_sym_preproc_elif_token1,
    ACTIONS(10214), 1,
      aux_sym_preproc_if_token3,
    STATE(9143), 2,
      sym_preproc_else_in_enum_member_declaration,
      sym_preproc_elif_in_enum_member_declaration,
    STATE(8014), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [337234] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(8218), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9583), 1,
      sym_declaration_list,
    STATE(8015), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [337291] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9619), 1,
      sym_declaration_list,
    STATE(8016), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [337348] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9484), 1,
      sym_declaration_list,
    STATE(8017), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [337405] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(8152), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9484), 1,
      sym_declaration_list,
    STATE(8018), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [337462] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(8153), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9486), 1,
      sym_declaration_list,
    STATE(8019), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [337519] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10216), 1,
      anon_sym_RBRACE,
    ACTIONS(10218), 1,
      anon_sym_case,
    ACTIONS(10220), 1,
      anon_sym_default,
    STATE(8227), 1,
      aux_sym_switch_body_repeat1,
    STATE(8661), 1,
      sym_switch_section,
    STATE(8020), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [337576] = 15,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    ACTIONS(10180), 1,
      anon_sym_AMP_AMP,
    ACTIONS(10182), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(10222), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(10178), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    STATE(8021), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [337631] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9808), 1,
      sym_declaration_list,
    STATE(8022), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [337688] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9486), 1,
      sym_declaration_list,
    STATE(8023), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [337745] = 15,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    ACTIONS(10180), 1,
      anon_sym_AMP_AMP,
    ACTIONS(10182), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(10224), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(10178), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    STATE(8024), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [337800] = 15,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    ACTIONS(10180), 1,
      anon_sym_AMP_AMP,
    ACTIONS(10182), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(10226), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(10178), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    STATE(8025), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [337855] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7961), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9461), 1,
      sym_declaration_list,
    STATE(8026), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [337912] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9492), 1,
      sym_declaration_list,
    STATE(8027), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [337969] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9232), 1,
      sym_declaration_list,
    STATE(8028), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [338026] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(8094), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9877), 1,
      sym_declaration_list,
    STATE(8029), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [338083] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9809), 1,
      sym_declaration_list,
    STATE(8030), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [338140] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9877), 1,
      sym_declaration_list,
    STATE(8031), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [338197] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(8110), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9232), 1,
      sym_declaration_list,
    STATE(8032), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [338254] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7988), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9809), 1,
      sym_declaration_list,
    STATE(8033), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [338311] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(8107), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9878), 1,
      sym_declaration_list,
    STATE(8034), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [338368] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(8120), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9239), 1,
      sym_declaration_list,
    STATE(8035), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [338425] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10228), 1,
      anon_sym_RPAREN,
    ACTIONS(10232), 1,
      anon_sym_AMP_AMP,
    ACTIONS(10234), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(10230), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    STATE(8036), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [338480] = 13,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    ACTIONS(10196), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(10236), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    STATE(8037), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [338531] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10218), 1,
      anon_sym_case,
    ACTIONS(10220), 1,
      anon_sym_default,
    ACTIONS(10238), 1,
      anon_sym_RBRACE,
    STATE(8193), 1,
      aux_sym_switch_body_repeat1,
    STATE(8661), 1,
      sym_switch_section,
    STATE(8038), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [338588] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6110), 1,
      anon_sym_STAR,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(10240), 1,
      anon_sym_LBRACE,
    STATE(4251), 1,
      sym_block,
    STATE(8789), 1,
      sym_parameter_list,
    STATE(8039), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [338645] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9239), 1,
      sym_declaration_list,
    STATE(8040), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [338702] = 15,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    ACTIONS(10180), 1,
      anon_sym_AMP_AMP,
    ACTIONS(10182), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(10242), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(10178), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    STATE(8041), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [338757] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9827), 1,
      sym_declaration_list,
    STATE(8042), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [338814] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9878), 1,
      sym_declaration_list,
    STATE(8043), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [338871] = 15,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    ACTIONS(10180), 1,
      anon_sym_AMP_AMP,
    ACTIONS(10182), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(10244), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(10178), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    STATE(8044), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [338926] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(8108), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9881), 1,
      sym_declaration_list,
    STATE(8045), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [338983] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(8042), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9552), 1,
      sym_declaration_list,
    STATE(8046), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [339040] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9881), 1,
      sym_declaration_list,
    STATE(8047), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [339097] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8544), 1,
      anon_sym_DOT,
    ACTIONS(10246), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_where,
    STATE(8048), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [339148] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7950), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9882), 1,
      sym_declaration_list,
    STATE(8049), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [339205] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9882), 1,
      sym_declaration_list,
    STATE(8050), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [339262] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10248), 5,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_where,
      anon_sym_EQ_GT,
    STATE(8051), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [339311] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9270), 1,
      sym_declaration_list,
    STATE(8052), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [339368] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9883), 1,
      sym_declaration_list,
    STATE(8053), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [339425] = 15,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    ACTIONS(10180), 1,
      anon_sym_AMP_AMP,
    ACTIONS(10182), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(10250), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(10178), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    STATE(8054), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [339480] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10252), 1,
      anon_sym_COMMA,
    ACTIONS(10246), 3,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_where,
    STATE(8055), 10,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
      aux_sym_record_base_repeat1,
  [339531] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4494), 1,
      anon_sym_GT,
    ACTIONS(7411), 1,
      anon_sym_LBRACK,
    ACTIONS(7415), 1,
      anon_sym_STAR,
    ACTIONS(10089), 1,
      anon_sym_COMMA,
    ACTIONS(10091), 1,
      anon_sym_QMARK,
    STATE(8056), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [339588] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10255), 5,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_where,
      anon_sym_EQ_GT,
    STATE(8057), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [339637] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9552), 1,
      sym_declaration_list,
    STATE(8058), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [339694] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9562), 1,
      sym_declaration_list,
    STATE(8059), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [339751] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10218), 1,
      anon_sym_case,
    ACTIONS(10220), 1,
      anon_sym_default,
    ACTIONS(10257), 1,
      anon_sym_RBRACE,
    STATE(8020), 1,
      aux_sym_switch_body_repeat1,
    STATE(8661), 1,
      sym_switch_section,
    STATE(8060), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [339808] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(8059), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9541), 1,
      sym_declaration_list,
    STATE(8061), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [339865] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4591), 5,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LBRACE,
      anon_sym_where,
      anon_sym_EQ_GT,
    STATE(8062), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [339914] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(8137), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9326), 1,
      sym_declaration_list,
    STATE(8063), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [339971] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9526), 1,
      sym_declaration_list,
    STATE(8064), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [340028] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10174), 1,
      anon_sym_and,
    ACTIONS(10176), 1,
      anon_sym_or,
    ACTIONS(10259), 1,
      anon_sym_COMMA,
    ACTIONS(10261), 1,
      anon_sym_RBRACK,
    STATE(8614), 1,
      aux_sym_list_pattern_repeat1,
    STATE(8065), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [340085] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9541), 1,
      sym_declaration_list,
    STATE(8066), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [340142] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9326), 1,
      sym_declaration_list,
    STATE(8067), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [340199] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(10263), 1,
      anon_sym_EQ,
    STATE(8389), 1,
      sym_bracketed_argument_list,
    ACTIONS(10208), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(8068), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [340254] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6110), 1,
      anon_sym_STAR,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(10265), 1,
      anon_sym_LBRACE,
    STATE(5538), 1,
      sym_block,
    STATE(8934), 1,
      sym_parameter_list,
    STATE(8069), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [340311] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6110), 1,
      anon_sym_STAR,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(10240), 1,
      anon_sym_LBRACE,
    STATE(4154), 1,
      sym_block,
    STATE(8971), 1,
      sym_parameter_list,
    STATE(8070), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [340368] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9461), 1,
      sym_declaration_list,
    STATE(8071), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [340425] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7995), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9526), 1,
      sym_declaration_list,
    STATE(8072), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [340482] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8544), 1,
      anon_sym_DOT,
    ACTIONS(10267), 1,
      anon_sym_LPAREN,
    STATE(8900), 1,
      sym_attribute_argument_list,
    ACTIONS(9314), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(8073), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [340537] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(8150), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9927), 1,
      sym_declaration_list,
    STATE(8074), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [340594] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(8149), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9352), 1,
      sym_declaration_list,
    STATE(8075), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [340651] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(8022), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9527), 1,
      sym_declaration_list,
    STATE(8076), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [340708] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9352), 1,
      sym_declaration_list,
    STATE(8077), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [340765] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(8157), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9365), 1,
      sym_declaration_list,
    STATE(8078), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [340822] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9365), 1,
      sym_declaration_list,
    STATE(8079), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [340879] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9927), 1,
      sym_declaration_list,
    STATE(8080), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [340936] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9402), 1,
      sym_declaration_list,
    STATE(8081), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [340993] = 15,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    ACTIONS(10180), 1,
      anon_sym_AMP_AMP,
    ACTIONS(10182), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(10269), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(10178), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    STATE(8082), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [341048] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6068), 1,
      anon_sym_LBRACK,
    ACTIONS(10271), 1,
      anon_sym_EQ,
    STATE(8393), 1,
      sym_bracketed_argument_list,
    ACTIONS(9771), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(8083), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [341103] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(8166), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9931), 1,
      sym_declaration_list,
    STATE(8084), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [341160] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10273), 5,
      anon_sym_SEMI,
      anon_sym_COLON,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_where,
    STATE(8085), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [341209] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9931), 1,
      sym_declaration_list,
    STATE(8086), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [341266] = 15,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    ACTIONS(10180), 1,
      anon_sym_AMP_AMP,
    ACTIONS(10182), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(10275), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(10178), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    STATE(8087), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [341321] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(8210), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9639), 1,
      sym_declaration_list,
    STATE(8088), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [341378] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10277), 5,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_where,
      anon_sym_EQ_GT,
    STATE(8089), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [341427] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9682), 1,
      sym_declaration_list,
    STATE(8090), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [341484] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(8012), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9682), 1,
      sym_declaration_list,
    STATE(8091), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [341541] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(8013), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9694), 1,
      sym_declaration_list,
    STATE(8092), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [341598] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10095), 5,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_where,
      anon_sym_EQ_GT,
    STATE(8093), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [341647] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9955), 1,
      sym_declaration_list,
    STATE(8094), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [341704] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10174), 1,
      anon_sym_and,
    ACTIONS(10176), 1,
      anon_sym_or,
    ACTIONS(10279), 1,
      anon_sym_COMMA,
    ACTIONS(10281), 1,
      anon_sym_RBRACK,
    STATE(8561), 1,
      aux_sym_list_pattern_repeat1,
    STATE(8095), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [341761] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(8188), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9955), 1,
      sym_declaration_list,
    STATE(8096), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [341818] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9694), 1,
      sym_declaration_list,
    STATE(8097), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [341875] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(8190), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9957), 1,
      sym_declaration_list,
    STATE(8098), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [341932] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(8028), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9099), 1,
      sym_declaration_list,
    STATE(8099), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [341989] = 13,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    ACTIONS(10285), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(10283), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    STATE(8100), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [342040] = 13,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    ACTIONS(10289), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(10287), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    STATE(8101), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [342091] = 15,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    ACTIONS(10180), 1,
      anon_sym_AMP_AMP,
    ACTIONS(10182), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(10291), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(10178), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    STATE(8102), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [342146] = 14,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    ACTIONS(10289), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(10178), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(10287), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    STATE(8103), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [342199] = 15,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    ACTIONS(10180), 1,
      anon_sym_AMP_AMP,
    ACTIONS(10287), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(10289), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(10178), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    STATE(8104), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [342254] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9463), 1,
      sym_declaration_list,
    STATE(8105), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [342311] = 13,
    ACTIONS(5476), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    ACTIONS(5478), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    STATE(8106), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [342362] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9957), 1,
      sym_declaration_list,
    STATE(8107), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [342419] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9960), 1,
      sym_declaration_list,
    STATE(8108), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [342476] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10285), 5,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    STATE(8109), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [342525] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9501), 1,
      sym_declaration_list,
    STATE(8110), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [342582] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(8197), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9960), 1,
      sym_declaration_list,
    STATE(8111), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [342639] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9547), 1,
      sym_declaration_list,
    STATE(8112), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [342696] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9431), 1,
      sym_declaration_list,
    STATE(8113), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [342753] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9259), 1,
      sym_declaration_list,
    STATE(8114), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [342810] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10218), 1,
      anon_sym_case,
    ACTIONS(10220), 1,
      anon_sym_default,
    ACTIONS(10293), 1,
      anon_sym_RBRACE,
    STATE(8227), 1,
      aux_sym_switch_body_repeat1,
    STATE(8661), 1,
      sym_switch_section,
    STATE(8115), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [342867] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(8000), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9547), 1,
      sym_declaration_list,
    STATE(8116), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [342924] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10289), 5,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    STATE(8117), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [342973] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10230), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(10289), 3,
      anon_sym_RPAREN,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    STATE(8118), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [343024] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10232), 1,
      anon_sym_AMP_AMP,
    ACTIONS(10230), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(10289), 2,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
    STATE(8119), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [343077] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9504), 1,
      sym_declaration_list,
    STATE(8120), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [343134] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9721), 1,
      sym_declaration_list,
    STATE(8121), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [343191] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6110), 1,
      anon_sym_STAR,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(10265), 1,
      anon_sym_LBRACE,
    STATE(5562), 1,
      sym_block,
    STATE(8955), 1,
      sym_parameter_list,
    STATE(8122), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [343248] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10295), 1,
      anon_sym_EQ_GT,
    ACTIONS(10297), 1,
      anon_sym_when,
    ACTIONS(10299), 1,
      anon_sym_and,
    ACTIONS(10301), 1,
      anon_sym_or,
    STATE(9789), 1,
      sym_when_clause,
    STATE(8123), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [343305] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(8001), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9553), 1,
      sym_declaration_list,
    STATE(8124), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [343362] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(8016), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9721), 1,
      sym_declaration_list,
    STATE(8125), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [343419] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(8064), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9279), 1,
      sym_declaration_list,
    STATE(8126), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [343476] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(8174), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9504), 1,
      sym_declaration_list,
    STATE(8127), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [343533] = 15,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    ACTIONS(10180), 1,
      anon_sym_AMP_AMP,
    ACTIONS(10182), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(10303), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(10178), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    STATE(8128), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [343588] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9553), 1,
      sym_declaration_list,
    STATE(8129), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [343645] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6110), 1,
      anon_sym_STAR,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(10305), 1,
      anon_sym_LBRACE,
    STATE(3669), 1,
      sym_block,
    STATE(8786), 1,
      sym_parameter_list,
    STATE(8130), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [343702] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9639), 1,
      sym_declaration_list,
    STATE(8131), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [343759] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9527), 1,
      sym_declaration_list,
    STATE(8132), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [343816] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9099), 1,
      sym_declaration_list,
    STATE(8133), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [343873] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9914), 1,
      anon_sym_COMMA,
    STATE(8055), 1,
      aux_sym_record_base_repeat1,
    ACTIONS(10307), 3,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_where,
    STATE(8134), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [343926] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9426), 1,
      sym_declaration_list,
    STATE(8135), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [343983] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(8090), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9261), 1,
      sym_declaration_list,
    STATE(8136), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [344040] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9518), 1,
      sym_declaration_list,
    STATE(8137), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [344097] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(8176), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9518), 1,
      sym_declaration_list,
    STATE(8138), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [344154] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(8177), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9531), 1,
      sym_declaration_list,
    STATE(8139), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [344211] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(8141), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9414), 1,
      sym_declaration_list,
    STATE(8140), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [344268] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9261), 1,
      sym_declaration_list,
    STATE(8141), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [344325] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9910), 1,
      sym_declaration_list,
    STATE(8142), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [344382] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9609), 1,
      sym_declaration_list,
    STATE(8143), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [344439] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(8204), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9932), 1,
      sym_declaration_list,
    STATE(8144), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [344496] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6108), 1,
      anon_sym_LBRACE,
    ACTIONS(6110), 1,
      anon_sym_STAR,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(3759), 1,
      sym_block,
    STATE(8980), 1,
      sym_parameter_list,
    STATE(8145), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [344553] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9780), 1,
      sym_declaration_list,
    STATE(8146), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [344610] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9528), 1,
      sym_declaration_list,
    STATE(8147), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [344667] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(8097), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9290), 1,
      sym_declaration_list,
    STATE(8148), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [344724] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9531), 1,
      sym_declaration_list,
    STATE(8149), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [344781] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9932), 1,
      sym_declaration_list,
    STATE(8150), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [344838] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9290), 1,
      sym_declaration_list,
    STATE(8151), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [344895] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9795), 1,
      sym_declaration_list,
    STATE(8152), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [344952] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9057), 1,
      sym_declaration_list,
    STATE(8153), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [345009] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(8121), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9303), 1,
      sym_declaration_list,
    STATE(8154), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [345066] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(8147), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9057), 1,
      sym_declaration_list,
    STATE(8155), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [345123] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(8040), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9114), 1,
      sym_declaration_list,
    STATE(8156), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [345180] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9532), 1,
      sym_declaration_list,
    STATE(8157), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [345237] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9303), 1,
      sym_declaration_list,
    STATE(8158), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [345294] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(8212), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9744), 1,
      sym_declaration_list,
    STATE(8159), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [345351] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6110), 1,
      anon_sym_STAR,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(10305), 1,
      anon_sym_LBRACE,
    STATE(3672), 1,
      sym_block,
    STATE(8883), 1,
      sym_parameter_list,
    STATE(8160), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [345408] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9279), 1,
      sym_declaration_list,
    STATE(8161), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [345465] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9744), 1,
      sym_declaration_list,
    STATE(8162), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [345522] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7411), 1,
      anon_sym_LBRACK,
    ACTIONS(7413), 1,
      anon_sym_QMARK,
    ACTIONS(7415), 1,
      anon_sym_STAR,
    ACTIONS(7477), 1,
      anon_sym_DOT,
    ACTIONS(10089), 1,
      anon_sym_COMMA,
    STATE(8163), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [345579] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(8213), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9025), 1,
      sym_declaration_list,
    STATE(8164), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [345636] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9025), 1,
      sym_declaration_list,
    STATE(8165), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [345693] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9048), 1,
      sym_declaration_list,
    STATE(8166), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [345750] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4145), 1,
      anon_sym_EQ_GT,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9804), 1,
      anon_sym_LT,
    STATE(7660), 1,
      sym_parameter_list,
    STATE(8808), 1,
      sym_type_parameter_list,
    STATE(8167), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [345807] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10218), 1,
      anon_sym_case,
    ACTIONS(10220), 1,
      anon_sym_default,
    ACTIONS(10309), 1,
      anon_sym_RBRACE,
    STATE(8115), 1,
      aux_sym_switch_body_repeat1,
    STATE(8661), 1,
      sym_switch_section,
    STATE(8168), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [345864] = 15,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    ACTIONS(10180), 1,
      anon_sym_AMP_AMP,
    ACTIONS(10182), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(10311), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(10178), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    STATE(8169), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [345919] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9414), 1,
      sym_declaration_list,
    STATE(8170), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [345976] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9114), 1,
      sym_declaration_list,
    STATE(8171), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [346033] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4145), 1,
      anon_sym_EQ_GT,
    ACTIONS(4310), 4,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_and,
      anon_sym_or,
    STATE(8172), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [346084] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7411), 1,
      anon_sym_LBRACK,
    ACTIONS(7415), 1,
      anon_sym_STAR,
    ACTIONS(10091), 1,
      anon_sym_QMARK,
    ACTIONS(4494), 2,
      anon_sym_COMMA,
      anon_sym_GT,
    STATE(8173), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [346139] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9577), 1,
      sym_declaration_list,
    STATE(8174), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [346196] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(8052), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9206), 1,
      sym_declaration_list,
    STATE(8175), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [346253] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9640), 1,
      sym_declaration_list,
    STATE(8176), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [346310] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9642), 1,
      sym_declaration_list,
    STATE(8177), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [346367] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(8185), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9642), 1,
      sym_declaration_list,
    STATE(8178), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [346424] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(8228), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9237), 1,
      sym_declaration_list,
    STATE(8179), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [346481] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9206), 1,
      sym_declaration_list,
    STATE(8180), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [346538] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10218), 1,
      anon_sym_case,
    ACTIONS(10220), 1,
      anon_sym_default,
    ACTIONS(10313), 1,
      anon_sym_RBRACE,
    STATE(8222), 1,
      aux_sym_switch_body_repeat1,
    STATE(8661), 1,
      sym_switch_section,
    STATE(8181), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [346595] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9237), 1,
      sym_declaration_list,
    STATE(8182), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [346652] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9212), 1,
      sym_declaration_list,
    STATE(8183), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [346709] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10315), 5,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_where,
      anon_sym_EQ_GT,
    STATE(8184), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [346758] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9683), 1,
      sym_declaration_list,
    STATE(8185), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [346815] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7951), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9327), 1,
      sym_declaration_list,
    STATE(8186), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [346872] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9327), 1,
      sym_declaration_list,
    STATE(8187), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [346929] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9408), 1,
      sym_declaration_list,
    STATE(8188), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [346986] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6110), 1,
      anon_sym_STAR,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(10317), 1,
      anon_sym_LBRACE,
    STATE(4648), 1,
      sym_block,
    STATE(8853), 1,
      sym_parameter_list,
    STATE(8189), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [347043] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9502), 1,
      sym_declaration_list,
    STATE(8190), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [347100] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(8112), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9339), 1,
      sym_declaration_list,
    STATE(8191), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [347157] = 15,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    ACTIONS(10180), 1,
      anon_sym_AMP_AMP,
    ACTIONS(10182), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(10319), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(10178), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    STATE(8192), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [347212] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10218), 1,
      anon_sym_case,
    ACTIONS(10220), 1,
      anon_sym_default,
    ACTIONS(10321), 1,
      anon_sym_RBRACE,
    STATE(8227), 1,
      aux_sym_switch_body_repeat1,
    STATE(8661), 1,
      sym_switch_section,
    STATE(8193), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [347269] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7955), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9502), 1,
      sym_declaration_list,
    STATE(8194), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [347326] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6110), 1,
      anon_sym_STAR,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(10317), 1,
      anon_sym_LBRACE,
    STATE(4673), 1,
      sym_block,
    STATE(8917), 1,
      sym_parameter_list,
    STATE(8195), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [347383] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(8017), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9684), 1,
      sym_declaration_list,
    STATE(8196), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [347440] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9509), 1,
      sym_declaration_list,
    STATE(8197), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [347497] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(8238), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9810), 1,
      sym_declaration_list,
    STATE(8198), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [347554] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(8158), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9491), 1,
      sym_declaration_list,
    STATE(8199), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [347611] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9810), 1,
      sym_declaration_list,
    STATE(8200), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [347668] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(8133), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9696), 1,
      sym_declaration_list,
    STATE(8201), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [347725] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4145), 1,
      anon_sym_EQ_GT,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9804), 1,
      anon_sym_LT,
    STATE(7667), 1,
      sym_parameter_list,
    STATE(8963), 1,
      sym_type_parameter_list,
    STATE(8202), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [347782] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9914), 1,
      anon_sym_COMMA,
    STATE(8055), 1,
      aux_sym_record_base_repeat1,
    ACTIONS(10323), 3,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_where,
    STATE(8203), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [347835] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9201), 1,
      sym_declaration_list,
    STATE(8204), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [347892] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10232), 1,
      anon_sym_AMP_AMP,
    ACTIONS(10234), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(10325), 1,
      anon_sym_RPAREN,
    ACTIONS(10230), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    STATE(8205), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [347947] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7957), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9201), 1,
      sym_declaration_list,
    STATE(8206), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [348004] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7958), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9287), 1,
      sym_declaration_list,
    STATE(8207), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [348061] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9491), 1,
      sym_declaration_list,
    STATE(8208), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [348118] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9339), 1,
      sym_declaration_list,
    STATE(8209), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [348175] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9684), 1,
      sym_declaration_list,
    STATE(8210), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [348232] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(8030), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9530), 1,
      sym_declaration_list,
    STATE(8211), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [348289] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9287), 1,
      sym_declaration_list,
    STATE(8212), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [348346] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9358), 1,
      sym_declaration_list,
    STATE(8213), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [348403] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(8023), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9798), 1,
      sym_declaration_list,
    STATE(8214), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [348460] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9696), 1,
      sym_declaration_list,
    STATE(8215), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [348517] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4145), 1,
      anon_sym_EQ_GT,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9804), 1,
      anon_sym_LT,
    STATE(7630), 1,
      sym_parameter_list,
    STATE(8994), 1,
      sym_type_parameter_list,
    STATE(8216), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [348574] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(8129), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9386), 1,
      sym_declaration_list,
    STATE(8217), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [348631] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9306), 1,
      sym_declaration_list,
    STATE(8218), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [348688] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7962), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9160), 1,
      sym_declaration_list,
    STATE(8219), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [348745] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(8007), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9373), 1,
      sym_declaration_list,
    STATE(8220), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [348802] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7983), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9227), 1,
      sym_declaration_list,
    STATE(8221), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [348859] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10218), 1,
      anon_sym_case,
    ACTIONS(10220), 1,
      anon_sym_default,
    ACTIONS(10327), 1,
      anon_sym_RBRACE,
    STATE(8227), 1,
      aux_sym_switch_body_repeat1,
    STATE(8661), 1,
      sym_switch_section,
    STATE(8222), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [348916] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9798), 1,
      sym_declaration_list,
    STATE(8223), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [348973] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9093), 1,
      anon_sym_COLON,
    ACTIONS(10329), 1,
      anon_sym_when,
    ACTIONS(10331), 1,
      anon_sym_and,
    ACTIONS(10333), 1,
      anon_sym_or,
    STATE(9187), 1,
      sym_when_clause,
    STATE(8224), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [349030] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9227), 1,
      sym_declaration_list,
    STATE(8225), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [349087] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9386), 1,
      sym_declaration_list,
    STATE(8226), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [349144] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10335), 1,
      anon_sym_RBRACE,
    ACTIONS(10337), 1,
      anon_sym_case,
    ACTIONS(10340), 1,
      anon_sym_default,
    STATE(8661), 1,
      sym_switch_section,
    STATE(8227), 10,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
      aux_sym_switch_body_repeat1,
  [349199] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9160), 1,
      sym_declaration_list,
    STATE(8228), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [349256] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(8027), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9849), 1,
      sym_declaration_list,
    STATE(8229), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [349313] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10174), 1,
      anon_sym_and,
    ACTIONS(10176), 1,
      anon_sym_or,
    ACTIONS(10343), 1,
      anon_sym_COMMA,
    ACTIONS(10345), 1,
      anon_sym_RBRACK,
    STATE(8636), 1,
      aux_sym_list_pattern_repeat1,
    STATE(8230), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [349370] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4145), 1,
      anon_sym_EQ_GT,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9804), 1,
      anon_sym_LT,
    STATE(7622), 1,
      sym_parameter_list,
    STATE(8823), 1,
      sym_type_parameter_list,
    STATE(8231), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [349427] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9849), 1,
      sym_declaration_list,
    STATE(8232), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [349484] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(8067), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9731), 1,
      sym_declaration_list,
    STATE(8233), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [349541] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10174), 1,
      anon_sym_and,
    ACTIONS(10176), 1,
      anon_sym_or,
    ACTIONS(10347), 1,
      anon_sym_COMMA,
    ACTIONS(10349), 1,
      anon_sym_RBRACK,
    STATE(8698), 1,
      aux_sym_list_pattern_repeat1,
    STATE(8234), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [349598] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7966), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9166), 1,
      sym_declaration_list,
    STATE(8235), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [349655] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6110), 1,
      anon_sym_STAR,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(10194), 1,
      anon_sym_LBRACE,
    STATE(3955), 1,
      sym_block,
    STATE(8966), 1,
      sym_parameter_list,
    STATE(8236), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [349712] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10174), 1,
      anon_sym_and,
    ACTIONS(10176), 1,
      anon_sym_or,
    ACTIONS(6592), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    STATE(8237), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [349765] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9874), 1,
      sym_declaration_list,
    STATE(8238), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [349822] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(8143), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9431), 1,
      sym_declaration_list,
    STATE(8239), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [349879] = 13,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    ACTIONS(10353), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(10351), 4,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    STATE(8240), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [349930] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(8142), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9426), 1,
      sym_declaration_list,
    STATE(8241), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [349987] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(8209), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9359), 1,
      sym_declaration_list,
    STATE(8242), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [350044] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9166), 1,
      sym_declaration_list,
    STATE(8243), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [350101] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(9806), 1,
      anon_sym_where,
    STATE(7967), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(9259), 1,
      sym_declaration_list,
    STATE(8244), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [350158] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6108), 1,
      anon_sym_LBRACE,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(10355), 1,
      anon_sym_STAR,
    STATE(3769), 1,
      sym_block,
    STATE(8932), 1,
      sym_parameter_list,
    STATE(8245), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [350215] = 16,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    ACTIONS(10108), 1,
      anon_sym_LBRACE,
    ACTIONS(10357), 1,
      anon_sym_COMMA,
    STATE(8612), 1,
      sym_argument_list,
    STATE(8613), 1,
      aux_sym_base_list_repeat1,
    STATE(8246), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [350272] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10353), 5,
      anon_sym_RPAREN,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    STATE(8247), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [350321] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10359), 1,
      anon_sym_COMMA,
    ACTIONS(10362), 2,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
    STATE(8248), 10,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
      aux_sym_bracketed_parameter_list_repeat1,
  [350371] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10364), 1,
      anon_sym_COLON,
    ACTIONS(10366), 1,
      anon_sym_LBRACE,
    STATE(8894), 1,
      sym_base_list,
    STATE(9680), 1,
      sym_enum_member_declaration_list,
    STATE(8249), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [350425] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(10368), 1,
      anon_sym_SEMI,
    STATE(8254), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(8250), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [350479] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(10370), 1,
      anon_sym_SEMI,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(8251), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [350533] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(10372), 1,
      anon_sym_SEMI,
    STATE(8256), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(8252), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [350587] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9804), 1,
      anon_sym_LT,
    STATE(8378), 1,
      sym_parameter_list,
    STATE(8958), 1,
      sym_type_parameter_list,
    STATE(8253), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [350641] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(10374), 1,
      anon_sym_SEMI,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(8254), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [350695] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(10376), 1,
      anon_sym_SEMI,
    STATE(8257), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(8255), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [350749] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(10378), 1,
      anon_sym_SEMI,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(8256), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [350803] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(10380), 1,
      anon_sym_SEMI,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(8257), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [350857] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10382), 4,
      sym_interpolation_end_quote,
      sym_interpolation_open_brace,
      sym_interpolation_string_content,
      sym_escape_sequence,
    STATE(8258), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [350905] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10384), 1,
      anon_sym_and,
    ACTIONS(10386), 1,
      anon_sym_or,
    ACTIONS(6592), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(8259), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [350957] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(10388), 1,
      anon_sym_SEMI,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(8260), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [351011] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9775), 1,
      anon_sym_LBRACE,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    STATE(3314), 1,
      sym_accessor_list,
    STATE(9145), 1,
      sym_arrow_expression_clause,
    STATE(8261), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [351065] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10364), 1,
      anon_sym_COLON,
    ACTIONS(10366), 1,
      anon_sym_LBRACE,
    STATE(8974), 1,
      sym_base_list,
    STATE(9319), 1,
      sym_enum_member_declaration_list,
    STATE(8262), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [351119] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10364), 1,
      anon_sym_COLON,
    ACTIONS(10366), 1,
      anon_sym_LBRACE,
    STATE(8912), 1,
      sym_base_list,
    STATE(9724), 1,
      sym_enum_member_declaration_list,
    STATE(8263), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [351173] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10390), 1,
      anon_sym_COMMA,
    ACTIONS(9912), 3,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_where,
    STATE(8264), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [351223] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4145), 1,
      anon_sym_EQ_GT,
    ACTIONS(10392), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
    STATE(8265), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [351273] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10364), 1,
      anon_sym_COLON,
    ACTIONS(10366), 1,
      anon_sym_LBRACE,
    STATE(8854), 1,
      sym_base_list,
    STATE(9559), 1,
      sym_enum_member_declaration_list,
    STATE(8266), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [351327] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10394), 4,
      sym_interpolation_end_quote,
      sym_interpolation_open_brace,
      sym_interpolation_string_content,
      sym_escape_sequence,
    STATE(8267), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [351375] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9804), 1,
      anon_sym_LT,
    STATE(8365), 1,
      sym_parameter_list,
    STATE(8992), 1,
      sym_type_parameter_list,
    STATE(8268), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [351429] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5861), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(5964), 2,
      anon_sym_and,
      anon_sym_or,
    STATE(8269), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [351479] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10364), 1,
      anon_sym_COLON,
    ACTIONS(10366), 1,
      anon_sym_LBRACE,
    STATE(8840), 1,
      sym_base_list,
    STATE(9854), 1,
      sym_enum_member_declaration_list,
    STATE(8270), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [351533] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4484), 4,
      anon_sym_LBRACK,
      anon_sym_COMMA,
      anon_sym_GT,
      anon_sym_STAR,
    STATE(8271), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [351581] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(10396), 1,
      anon_sym_SEMI,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(8272), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [351635] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9804), 1,
      anon_sym_LT,
    STATE(8297), 1,
      sym_parameter_list,
    STATE(8741), 1,
      sym_type_parameter_list,
    STATE(8273), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [351689] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9804), 1,
      anon_sym_LT,
    STATE(8343), 1,
      sym_parameter_list,
    STATE(8807), 1,
      sym_type_parameter_list,
    STATE(8274), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [351743] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9804), 1,
      anon_sym_LT,
    STATE(8381), 1,
      sym_parameter_list,
    STATE(8785), 1,
      sym_type_parameter_list,
    STATE(8275), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [351797] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10364), 1,
      anon_sym_COLON,
    ACTIONS(10366), 1,
      anon_sym_LBRACE,
    STATE(8794), 1,
      sym_base_list,
    STATE(9941), 1,
      sym_enum_member_declaration_list,
    STATE(8276), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [351851] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10398), 1,
      anon_sym_COMMA,
    ACTIONS(10401), 2,
      anon_sym_RBRACK,
      anon_sym_GT,
    STATE(8277), 10,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
      aux_sym_type_argument_list_repeat1,
  [351901] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9775), 1,
      anon_sym_LBRACE,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    STATE(3280), 1,
      sym_accessor_list,
    STATE(9623), 1,
      sym_arrow_expression_clause,
    STATE(8278), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [351955] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10364), 1,
      anon_sym_COLON,
    ACTIONS(10366), 1,
      anon_sym_LBRACE,
    STATE(8860), 1,
      sym_base_list,
    STATE(9487), 1,
      sym_enum_member_declaration_list,
    STATE(8279), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [352009] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9804), 1,
      anon_sym_LT,
    STATE(8330), 1,
      sym_parameter_list,
    STATE(8809), 1,
      sym_type_parameter_list,
    STATE(8280), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [352063] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10403), 1,
      anon_sym_EQ,
    ACTIONS(10405), 3,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
    STATE(8281), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [352113] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10384), 1,
      anon_sym_and,
    ACTIONS(10386), 1,
      anon_sym_or,
    ACTIONS(10407), 1,
      anon_sym_COMMA,
    ACTIONS(10409), 1,
      anon_sym_RPAREN,
    STATE(8282), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [352167] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9804), 1,
      anon_sym_LT,
    STATE(8366), 1,
      sym_parameter_list,
    STATE(8911), 1,
      sym_type_parameter_list,
    STATE(8283), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [352221] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10364), 1,
      anon_sym_COLON,
    ACTIONS(10366), 1,
      anon_sym_LBRACE,
    STATE(8712), 1,
      sym_base_list,
    STATE(9752), 1,
      sym_enum_member_declaration_list,
    STATE(8284), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [352275] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10364), 1,
      anon_sym_COLON,
    ACTIONS(10366), 1,
      anon_sym_LBRACE,
    STATE(8836), 1,
      sym_base_list,
    STATE(9418), 1,
      sym_enum_member_declaration_list,
    STATE(8285), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [352329] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10411), 1,
      anon_sym_EQ,
    ACTIONS(10413), 3,
      aux_sym_preproc_if_token3,
      aux_sym_preproc_else_token1,
      aux_sym_preproc_elif_token1,
    STATE(8286), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [352379] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9804), 1,
      anon_sym_LT,
    STATE(7607), 1,
      sym_parameter_list,
    STATE(8816), 1,
      sym_type_parameter_list,
    STATE(8287), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [352433] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10331), 1,
      anon_sym_and,
    ACTIONS(10333), 1,
      anon_sym_or,
    ACTIONS(6592), 2,
      anon_sym_COLON,
      anon_sym_when,
    STATE(8288), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [352485] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5788), 1,
      anon_sym_LBRACE,
    ACTIONS(10087), 1,
      anon_sym_when,
    STATE(2274), 1,
      sym_block,
    STATE(8946), 1,
      sym_catch_filter_clause,
    STATE(8289), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [352539] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4500), 4,
      anon_sym_LBRACK,
      anon_sym_COMMA,
      anon_sym_GT,
      anon_sym_STAR,
    STATE(8290), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [352587] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5786), 1,
      anon_sym_LBRACE,
    ACTIONS(10087), 1,
      anon_sym_when,
    STATE(2214), 1,
      sym_block,
    STATE(8926), 1,
      sym_catch_filter_clause,
    STATE(8291), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [352641] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10415), 4,
      sym_interpolation_end_quote,
      sym_interpolation_open_brace,
      sym_interpolation_string_content,
      sym_escape_sequence,
    STATE(8292), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [352689] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10417), 1,
      anon_sym_LPAREN,
    ACTIONS(10421), 1,
      sym_integer_literal,
    ACTIONS(10419), 2,
      anon_sym_default,
      anon_sym_hidden,
    STATE(8293), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [352741] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4504), 4,
      anon_sym_LBRACK,
      anon_sym_COMMA,
      anon_sym_GT,
      anon_sym_STAR,
    STATE(8294), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [352789] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4145), 1,
      anon_sym_EQ_GT,
    ACTIONS(10423), 1,
      anon_sym_EQ,
    ACTIONS(10425), 1,
      anon_sym_COMMA,
    ACTIONS(10428), 1,
      anon_sym_RPAREN,
    STATE(8295), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [352843] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10384), 1,
      anon_sym_and,
    ACTIONS(10386), 1,
      anon_sym_or,
    ACTIONS(10407), 1,
      anon_sym_COMMA,
    ACTIONS(10430), 1,
      anon_sym_RPAREN,
    STATE(8296), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [352897] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(10432), 1,
      anon_sym_SEMI,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(8357), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8297), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [352951] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10106), 1,
      anon_sym_COMMA,
    STATE(8299), 1,
      aux_sym_base_list_repeat1,
    ACTIONS(10434), 2,
      anon_sym_LBRACE,
      anon_sym_where,
    STATE(8298), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [353003] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10436), 1,
      anon_sym_COMMA,
    ACTIONS(10204), 2,
      anon_sym_LBRACE,
      anon_sym_where,
    STATE(8299), 10,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
      aux_sym_base_list_repeat1,
  [353053] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(10439), 1,
      anon_sym_SEMI,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(8300), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [353107] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4145), 1,
      anon_sym_EQ_GT,
    ACTIONS(9990), 1,
      anon_sym_EQ,
    ACTIONS(10100), 1,
      anon_sym_RPAREN,
    ACTIONS(10441), 1,
      anon_sym_COMMA,
    STATE(8301), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [353161] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(10445), 1,
      anon_sym_SEMI,
    STATE(8260), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(8302), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [353215] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10447), 1,
      anon_sym_LT,
    ACTIONS(10449), 1,
      anon_sym_unmanaged,
    ACTIONS(10451), 1,
      anon_sym_managed,
    STATE(9909), 1,
      sym_calling_convention,
    STATE(8303), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [353269] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9804), 1,
      anon_sym_LT,
    STATE(8252), 1,
      sym_parameter_list,
    STATE(8835), 1,
      sym_type_parameter_list,
    STATE(8304), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [353323] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(10453), 1,
      anon_sym_SEMI,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(8351), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8305), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [353377] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(10455), 1,
      anon_sym_SEMI,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(8306), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [353431] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10457), 1,
      anon_sym_EQ,
    ACTIONS(10459), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
    STATE(8307), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [353481] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(10461), 1,
      anon_sym_SEMI,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(8308), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [353535] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4480), 4,
      anon_sym_LBRACK,
      anon_sym_COMMA,
      anon_sym_GT,
      anon_sym_STAR,
    STATE(8309), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [353583] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4145), 1,
      anon_sym_EQ_GT,
    ACTIONS(10463), 1,
      anon_sym_EQ,
    ACTIONS(10465), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(8310), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [353635] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9775), 1,
      anon_sym_LBRACE,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    STATE(3352), 1,
      sym_accessor_list,
    STATE(9803), 1,
      sym_arrow_expression_clause,
    STATE(8311), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [353689] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10467), 1,
      anon_sym_EQ,
    ACTIONS(10465), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
    STATE(8312), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [353739] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3047), 4,
      anon_sym_while,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_else,
    STATE(8313), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [353787] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9804), 1,
      anon_sym_LT,
    STATE(7668), 1,
      sym_parameter_list,
    STATE(8850), 1,
      sym_type_parameter_list,
    STATE(8314), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [353841] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(10469), 1,
      anon_sym_SEMI,
    STATE(8272), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(8315), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [353895] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10106), 1,
      anon_sym_COMMA,
    STATE(8298), 1,
      aux_sym_base_list_repeat1,
    ACTIONS(10471), 2,
      anon_sym_LBRACE,
      anon_sym_where,
    STATE(8316), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [353947] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4488), 4,
      anon_sym_LBRACK,
      anon_sym_COMMA,
      anon_sym_GT,
      anon_sym_STAR,
    STATE(8317), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [353995] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7411), 1,
      anon_sym_LBRACK,
    ACTIONS(7413), 1,
      anon_sym_QMARK,
    ACTIONS(7415), 1,
      anon_sym_STAR,
    ACTIONS(7477), 1,
      anon_sym_DOT,
    STATE(8318), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [354049] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8544), 1,
      anon_sym_DOT,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(10473), 1,
      anon_sym_SEMI,
    STATE(9269), 1,
      sym_declaration_list,
    STATE(8319), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [354103] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(10475), 1,
      anon_sym_SEMI,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(8320), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [354157] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10477), 4,
      sym_interpolation_end_quote,
      sym_interpolation_open_brace,
      sym_interpolation_string_content,
      sym_escape_sequence,
    STATE(8321), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [354205] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9775), 1,
      anon_sym_LBRACE,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    STATE(3359), 1,
      sym_accessor_list,
    STATE(9556), 1,
      sym_arrow_expression_clause,
    STATE(8322), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [354259] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10106), 1,
      anon_sym_COMMA,
    STATE(8299), 1,
      aux_sym_base_list_repeat1,
    ACTIONS(10471), 2,
      anon_sym_LBRACE,
      anon_sym_where,
    STATE(8323), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [354311] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(10479), 1,
      anon_sym_SEMI,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(8324), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [354365] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10174), 1,
      anon_sym_and,
    ACTIONS(10176), 1,
      anon_sym_or,
    ACTIONS(1873), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(8325), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [354417] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10174), 1,
      anon_sym_and,
    ACTIONS(10176), 1,
      anon_sym_or,
    ACTIONS(10481), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    STATE(8326), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [354469] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10384), 1,
      anon_sym_and,
    ACTIONS(10386), 1,
      anon_sym_or,
    ACTIONS(10407), 1,
      anon_sym_COMMA,
    ACTIONS(10483), 1,
      anon_sym_RPAREN,
    STATE(8327), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [354523] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6138), 1,
      anon_sym_LBRACE,
    ACTIONS(10087), 1,
      anon_sym_when,
    STATE(2652), 1,
      sym_block,
    STATE(8862), 1,
      sym_catch_filter_clause,
    STATE(8328), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [354577] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(10485), 1,
      anon_sym_SEMI,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(8329), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [354631] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(10487), 1,
      anon_sym_SEMI,
    STATE(8329), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(8330), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [354685] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4494), 1,
      anon_sym_GT,
    ACTIONS(7411), 1,
      anon_sym_LBRACK,
    ACTIONS(10089), 1,
      anon_sym_COMMA,
    ACTIONS(10091), 1,
      anon_sym_QMARK,
    STATE(8331), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [354739] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3043), 4,
      anon_sym_while,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_else,
    STATE(8332), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [354787] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10174), 1,
      anon_sym_and,
    ACTIONS(10176), 1,
      anon_sym_or,
    ACTIONS(10407), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    STATE(8333), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [354839] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10384), 1,
      anon_sym_and,
    ACTIONS(10386), 1,
      anon_sym_or,
    ACTIONS(10407), 1,
      anon_sym_COMMA,
    ACTIONS(10489), 1,
      anon_sym_RPAREN,
    STATE(8334), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [354893] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10299), 1,
      anon_sym_and,
    ACTIONS(10301), 1,
      anon_sym_or,
    ACTIONS(6592), 2,
      anon_sym_EQ_GT,
      anon_sym_when,
    STATE(8335), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [354945] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10491), 4,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_where,
      anon_sym_EQ_GT,
    STATE(8336), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [354993] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(10493), 1,
      anon_sym_SEMI,
    STATE(8300), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(8337), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [355047] = 13,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    ACTIONS(10497), 1,
      aux_sym_string_literal_content_token1,
    ACTIONS(10495), 3,
      anon_sym_DQUOTE,
      aux_sym_string_literal_content_token2,
      sym_escape_sequence,
    STATE(8338), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [355097] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(10499), 1,
      anon_sym_SEMI,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(8339), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [355151] = 13,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    ACTIONS(10497), 1,
      aux_sym_string_literal_content_token1,
    ACTIONS(10495), 3,
      anon_sym_DQUOTE,
      aux_sym_string_literal_content_token2,
      sym_escape_sequence,
    STATE(8340), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [355201] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7411), 1,
      anon_sym_LBRACK,
    ACTIONS(7413), 1,
      anon_sym_QMARK,
    ACTIONS(7415), 1,
      anon_sym_STAR,
    ACTIONS(10089), 1,
      anon_sym_COMMA,
    STATE(8341), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [355255] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10449), 1,
      anon_sym_unmanaged,
    ACTIONS(10451), 1,
      anon_sym_managed,
    ACTIONS(10501), 1,
      anon_sym_LT,
    STATE(9511), 1,
      sym_calling_convention,
    STATE(8342), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [355309] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(10503), 1,
      anon_sym_SEMI,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(8339), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8343), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [355363] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9804), 1,
      anon_sym_LT,
    STATE(7569), 1,
      sym_parameter_list,
    STATE(8924), 1,
      sym_type_parameter_list,
    STATE(8344), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [355417] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4494), 1,
      anon_sym_GT,
    ACTIONS(7411), 1,
      anon_sym_LBRACK,
    ACTIONS(7415), 1,
      anon_sym_STAR,
    ACTIONS(10089), 1,
      anon_sym_COMMA,
    STATE(8345), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [355471] = 13,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    ACTIONS(10507), 1,
      aux_sym_string_literal_content_token1,
    ACTIONS(10505), 3,
      anon_sym_DQUOTE,
      aux_sym_string_literal_content_token2,
      sym_escape_sequence,
    STATE(8346), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [355521] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7411), 1,
      anon_sym_LBRACK,
    ACTIONS(10091), 1,
      anon_sym_QMARK,
    ACTIONS(4494), 2,
      anon_sym_COMMA,
      anon_sym_GT,
    STATE(8347), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [355573] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10331), 1,
      anon_sym_and,
    ACTIONS(6705), 3,
      anon_sym_COLON,
      anon_sym_when,
      anon_sym_or,
    STATE(8348), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [355623] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10384), 1,
      anon_sym_and,
    ACTIONS(10386), 1,
      anon_sym_or,
    ACTIONS(10407), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(8349), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [355675] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10384), 1,
      anon_sym_and,
    ACTIONS(10386), 1,
      anon_sym_or,
    ACTIONS(10481), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(8350), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [355727] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(10509), 1,
      anon_sym_SEMI,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(8351), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [355781] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9775), 1,
      anon_sym_LBRACE,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    STATE(3403), 1,
      sym_accessor_list,
    STATE(9703), 1,
      sym_arrow_expression_clause,
    STATE(8352), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [355835] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(10511), 1,
      anon_sym_SEMI,
    STATE(8308), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(8353), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [355889] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(10513), 1,
      anon_sym_SEMI,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(8354), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [355943] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(10515), 1,
      anon_sym_SEMI,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(8373), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8355), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [355997] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10384), 1,
      anon_sym_and,
    ACTIONS(6705), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_or,
    STATE(8356), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [356047] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(10517), 1,
      anon_sym_SEMI,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(8357), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [356101] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3032), 4,
      anon_sym_while,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_else,
    STATE(8358), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [356149] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10519), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_where,
    STATE(8359), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [356197] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9775), 1,
      anon_sym_LBRACE,
    ACTIONS(9779), 1,
      anon_sym_EQ_GT,
    STATE(3307), 1,
      sym_accessor_list,
    STATE(9078), 1,
      sym_arrow_expression_clause,
    STATE(8360), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [356251] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8544), 1,
      anon_sym_DOT,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    ACTIONS(10521), 1,
      anon_sym_SEMI,
    STATE(9554), 1,
      sym_declaration_list,
    STATE(8361), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [356305] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10449), 1,
      anon_sym_unmanaged,
    ACTIONS(10451), 1,
      anon_sym_managed,
    ACTIONS(10523), 1,
      anon_sym_LT,
    STATE(9700), 1,
      sym_calling_convention,
    STATE(8362), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [356359] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10525), 1,
      anon_sym_EQ,
    ACTIONS(10100), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
    STATE(8363), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [356409] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10527), 1,
      anon_sym_COMMA,
    ACTIONS(7913), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(8364), 10,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
      aux_sym_for_statement_repeat1,
  [356459] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(10530), 1,
      anon_sym_SEMI,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(8380), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8365), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [356513] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(10532), 1,
      anon_sym_SEMI,
    STATE(8251), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(8366), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [356567] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10449), 1,
      anon_sym_unmanaged,
    ACTIONS(10451), 1,
      anon_sym_managed,
    ACTIONS(10534), 1,
      anon_sym_LT,
    STATE(9760), 1,
      sym_calling_convention,
    STATE(8367), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [356621] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6108), 1,
      anon_sym_LBRACE,
    ACTIONS(10087), 1,
      anon_sym_when,
    STATE(8377), 1,
      sym_block,
    STATE(8978), 1,
      sym_catch_filter_clause,
    STATE(8368), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [356675] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(10536), 1,
      anon_sym_SEMI,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(8354), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8369), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [356729] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10449), 1,
      anon_sym_unmanaged,
    ACTIONS(10451), 1,
      anon_sym_managed,
    ACTIONS(10538), 1,
      anon_sym_LT,
    STATE(9802), 1,
      sym_calling_convention,
    STATE(8370), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [356783] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10449), 1,
      anon_sym_unmanaged,
    ACTIONS(10451), 1,
      anon_sym_managed,
    ACTIONS(10540), 1,
      anon_sym_LT,
    STATE(9826), 1,
      sym_calling_convention,
    STATE(8371), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [356837] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10384), 1,
      anon_sym_and,
    ACTIONS(10386), 1,
      anon_sym_or,
    ACTIONS(10407), 1,
      anon_sym_COMMA,
    ACTIONS(10542), 1,
      anon_sym_RPAREN,
    STATE(8372), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [356891] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(10544), 1,
      anon_sym_SEMI,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(8373), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [356945] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10449), 1,
      anon_sym_unmanaged,
    ACTIONS(10451), 1,
      anon_sym_managed,
    ACTIONS(10546), 1,
      anon_sym_LT,
    STATE(9846), 1,
      sym_calling_convention,
    STATE(8374), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [356999] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10449), 1,
      anon_sym_unmanaged,
    ACTIONS(10451), 1,
      anon_sym_managed,
    ACTIONS(10548), 1,
      anon_sym_LT,
    STATE(9864), 1,
      sym_calling_convention,
    STATE(8375), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [357053] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9804), 1,
      anon_sym_LT,
    STATE(7598), 1,
      sym_parameter_list,
    STATE(8991), 1,
      sym_type_parameter_list,
    STATE(8376), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [357107] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3028), 4,
      anon_sym_while,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_else,
    STATE(8377), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [357155] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(10550), 1,
      anon_sym_SEMI,
    STATE(8306), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(8378), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [357209] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(10552), 1,
      anon_sym_SEMI,
    STATE(8324), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(8379), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [357263] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(10554), 1,
      anon_sym_SEMI,
    STATE(7906), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(8380), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [357317] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9806), 1,
      anon_sym_where,
    ACTIONS(10556), 1,
      anon_sym_SEMI,
    STATE(8320), 1,
      aux_sym_class_declaration_repeat3,
    STATE(8336), 1,
      sym_type_parameter_constraints_clause,
    STATE(8381), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [357371] = 15,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    ACTIONS(9804), 1,
      anon_sym_LT,
    STATE(8369), 1,
      sym_parameter_list,
    STATE(8897), 1,
      sym_type_parameter_list,
    STATE(8382), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [357425] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10299), 1,
      anon_sym_and,
    ACTIONS(6705), 3,
      anon_sym_EQ_GT,
      anon_sym_when,
      anon_sym_or,
    STATE(8383), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [357475] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10558), 4,
      sym_interpolation_end_quote,
      sym_interpolation_open_brace,
      sym_interpolation_string_content,
      sym_escape_sequence,
    STATE(8384), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [357523] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(2677), 1,
      anon_sym_COMMA,
    ACTIONS(7968), 1,
      anon_sym_RBRACK,
    STATE(8628), 1,
      aux_sym_array_rank_specifier_repeat1,
    STATE(8385), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [357574] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10560), 1,
      anon_sym_COMMA,
    ACTIONS(10563), 1,
      anon_sym_RBRACK,
    STATE(8386), 10,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
      aux_sym_calling_convention_repeat1,
  [357623] = 13,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    ACTIONS(10565), 1,
      anon_sym_COMMA,
    ACTIONS(10568), 1,
      aux_sym_preproc_if_token2,
    STATE(8387), 10,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
      aux_sym_preproc_pragma_repeat1,
  [357672] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5743), 1,
      anon_sym_COMMA,
    ACTIONS(10570), 1,
      anon_sym_RBRACK,
    STATE(8277), 1,
      aux_sym_type_argument_list_repeat1,
    STATE(8388), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [357723] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10572), 1,
      anon_sym_EQ,
    ACTIONS(10574), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(8389), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [357772] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10576), 1,
      anon_sym_COMMA,
    ACTIONS(10578), 1,
      anon_sym_RPAREN,
    STATE(8418), 1,
      aux_sym_argument_list_repeat1,
    STATE(8390), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [357823] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10580), 1,
      anon_sym_COMMA,
    ACTIONS(10582), 1,
      anon_sym_RPAREN,
    STATE(8415), 1,
      aux_sym_variable_declaration_repeat1,
    STATE(8391), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [357874] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10584), 1,
      anon_sym_SEMI,
    ACTIONS(10586), 1,
      anon_sym_COMMA,
    STATE(8509), 1,
      aux_sym_variable_declaration_repeat1,
    STATE(8392), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [357925] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10588), 1,
      anon_sym_EQ,
    ACTIONS(10590), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(8393), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [357974] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9352), 1,
      anon_sym_RBRACK,
    ACTIONS(10592), 1,
      anon_sym_COMMA,
    STATE(8459), 1,
      aux_sym_global_attribute_repeat1,
    STATE(8394), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [358025] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10594), 1,
      anon_sym_COMMA,
    ACTIONS(10596), 1,
      anon_sym_RPAREN,
    STATE(8435), 1,
      aux_sym_parenthesized_variable_designation_repeat1,
    STATE(8395), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [358076] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7962), 1,
      anon_sym_COMMA,
    ACTIONS(10598), 1,
      anon_sym_RPAREN,
    STATE(8364), 1,
      aux_sym_for_statement_repeat1,
    STATE(8396), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [358127] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7962), 1,
      anon_sym_COMMA,
    ACTIONS(10600), 1,
      anon_sym_RPAREN,
    STATE(8364), 1,
      aux_sym_for_statement_repeat1,
    STATE(8397), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [358178] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9302), 1,
      anon_sym_RBRACK,
    ACTIONS(10602), 1,
      anon_sym_COMMA,
    STATE(8459), 1,
      aux_sym_global_attribute_repeat1,
    STATE(8398), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [358229] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9352), 1,
      anon_sym_RBRACK,
    ACTIONS(10592), 1,
      anon_sym_COMMA,
    STATE(8414), 1,
      aux_sym_global_attribute_repeat1,
    STATE(8399), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [358280] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9302), 1,
      anon_sym_RBRACK,
    ACTIONS(10602), 1,
      anon_sym_COMMA,
    STATE(8461), 1,
      aux_sym_global_attribute_repeat1,
    STATE(8400), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [358331] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10604), 1,
      anon_sym_COMMA,
    ACTIONS(10606), 1,
      anon_sym_RBRACE,
    STATE(8559), 1,
      aux_sym_with_expression_repeat1,
    STATE(8401), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [358382] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(2677), 1,
      anon_sym_COMMA,
    ACTIONS(8161), 1,
      anon_sym_RBRACK,
    STATE(8628), 1,
      aux_sym_array_rank_specifier_repeat1,
    STATE(8402), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [358433] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(2641), 1,
      anon_sym_RBRACK,
    ACTIONS(10608), 1,
      anon_sym_COMMA,
    STATE(8471), 1,
      aux_sym_argument_list_repeat1,
    STATE(8403), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [358484] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(2747), 1,
      anon_sym_RBRACE,
    ACTIONS(10610), 1,
      anon_sym_COMMA,
    STATE(8657), 1,
      aux_sym_anonymous_object_creation_expression_repeat1,
    STATE(8404), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [358535] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(2677), 1,
      anon_sym_COMMA,
    ACTIONS(8085), 1,
      anon_sym_RBRACK,
    STATE(8628), 1,
      aux_sym_array_rank_specifier_repeat1,
    STATE(8405), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [358586] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7962), 1,
      anon_sym_COMMA,
    ACTIONS(10612), 1,
      anon_sym_RPAREN,
    STATE(8364), 1,
      aux_sym_for_statement_repeat1,
    STATE(8406), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [358637] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7913), 1,
      anon_sym_SEMI,
    ACTIONS(10614), 1,
      anon_sym_COMMA,
    STATE(8407), 10,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
      aux_sym_for_statement_repeat1,
  [358686] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10576), 1,
      anon_sym_COMMA,
    ACTIONS(10617), 1,
      anon_sym_RPAREN,
    STATE(8417), 1,
      aux_sym_argument_list_repeat1,
    STATE(8408), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [358737] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(2677), 1,
      anon_sym_COMMA,
    ACTIONS(10619), 1,
      anon_sym_RBRACK,
    STATE(8628), 1,
      aux_sym_array_rank_specifier_repeat1,
    STATE(8409), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [358788] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10621), 1,
      anon_sym_COMMA,
    ACTIONS(10623), 1,
      anon_sym_RBRACK,
    STATE(8609), 1,
      aux_sym_global_attribute_repeat1,
    STATE(8410), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [358839] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7962), 1,
      anon_sym_COMMA,
    ACTIONS(10625), 1,
      anon_sym_RPAREN,
    STATE(8364), 1,
      aux_sym_for_statement_repeat1,
    STATE(8411), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [358890] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10627), 1,
      anon_sym_COMMA,
    ACTIONS(10629), 1,
      anon_sym_RBRACE,
    STATE(8601), 1,
      aux_sym_switch_expression_repeat1,
    STATE(8412), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [358941] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7962), 1,
      anon_sym_COMMA,
    ACTIONS(10631), 1,
      anon_sym_RPAREN,
    STATE(8364), 1,
      aux_sym_for_statement_repeat1,
    STATE(8413), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [358992] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9348), 1,
      anon_sym_RBRACK,
    ACTIONS(10633), 1,
      anon_sym_COMMA,
    STATE(8459), 1,
      aux_sym_global_attribute_repeat1,
    STATE(8414), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [359043] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10635), 1,
      anon_sym_COMMA,
    ACTIONS(10638), 1,
      anon_sym_RPAREN,
    STATE(8415), 10,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
      aux_sym_variable_declaration_repeat1,
  [359092] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10640), 1,
      anon_sym_COMMA,
    ACTIONS(10642), 1,
      anon_sym_RBRACE,
    STATE(8428), 1,
      aux_sym_switch_expression_repeat1,
    STATE(8416), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [359143] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10644), 1,
      anon_sym_COMMA,
    ACTIONS(10647), 1,
      anon_sym_RPAREN,
    STATE(8417), 10,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
      aux_sym_argument_list_repeat1,
  [359192] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10576), 1,
      anon_sym_COMMA,
    ACTIONS(10649), 1,
      anon_sym_RPAREN,
    STATE(8417), 1,
      aux_sym_argument_list_repeat1,
    STATE(8418), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [359243] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10651), 1,
      anon_sym_COMMA,
    ACTIONS(10653), 1,
      anon_sym_RPAREN,
    STATE(8500), 1,
      aux_sym_tuple_type_repeat1,
    STATE(8419), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [359294] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4145), 1,
      anon_sym_EQ_GT,
    ACTIONS(10392), 1,
      anon_sym_RPAREN,
    ACTIONS(10655), 1,
      anon_sym_COMMA,
    STATE(8420), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [359345] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10658), 1,
      anon_sym_COMMA,
    ACTIONS(10660), 1,
      anon_sym_GT,
    STATE(8594), 1,
      aux_sym_type_argument_list_repeat2,
    STATE(8421), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [359396] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7962), 1,
      anon_sym_COMMA,
    ACTIONS(10662), 1,
      anon_sym_RPAREN,
    STATE(8364), 1,
      aux_sym_for_statement_repeat1,
    STATE(8422), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [359447] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10651), 1,
      anon_sym_COMMA,
    ACTIONS(10664), 1,
      anon_sym_RPAREN,
    STATE(8500), 1,
      aux_sym_tuple_type_repeat1,
    STATE(8423), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [359498] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7962), 1,
      anon_sym_COMMA,
    ACTIONS(10666), 1,
      anon_sym_RPAREN,
    STATE(8364), 1,
      aux_sym_for_statement_repeat1,
    STATE(8424), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [359549] = 14,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    ACTIONS(10668), 1,
      anon_sym_COMMA,
    ACTIONS(10670), 1,
      aux_sym_preproc_if_token2,
    STATE(8429), 1,
      aux_sym_preproc_pragma_repeat1,
    STATE(8425), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [359600] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5743), 1,
      anon_sym_COMMA,
    ACTIONS(10660), 1,
      anon_sym_GT,
    STATE(8277), 1,
      aux_sym_type_argument_list_repeat1,
    STATE(8426), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [359651] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10672), 1,
      anon_sym_COMMA,
    ACTIONS(10674), 1,
      anon_sym_RPAREN,
    STATE(8248), 1,
      aux_sym_bracketed_parameter_list_repeat1,
    STATE(8427), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [359702] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(2275), 1,
      anon_sym_RBRACE,
    ACTIONS(10676), 1,
      anon_sym_COMMA,
    STATE(8533), 1,
      aux_sym_switch_expression_repeat1,
    STATE(8428), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [359753] = 14,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    ACTIONS(10668), 1,
      anon_sym_COMMA,
    ACTIONS(10678), 1,
      aux_sym_preproc_if_token2,
    STATE(8387), 1,
      aux_sym_preproc_pragma_repeat1,
    STATE(8429), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [359804] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10604), 1,
      anon_sym_COMMA,
    ACTIONS(10680), 1,
      anon_sym_RBRACE,
    STATE(8401), 1,
      aux_sym_with_expression_repeat1,
    STATE(8430), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [359855] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(2677), 1,
      anon_sym_COMMA,
    ACTIONS(8223), 1,
      anon_sym_RBRACK,
    STATE(8628), 1,
      aux_sym_array_rank_specifier_repeat1,
    STATE(8431), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [359906] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5743), 1,
      anon_sym_COMMA,
    ACTIONS(10682), 1,
      anon_sym_RBRACK,
    STATE(8439), 1,
      aux_sym_type_argument_list_repeat1,
    STATE(8432), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [359957] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(2923), 1,
      anon_sym_RBRACE,
    ACTIONS(10684), 1,
      anon_sym_COMMA,
    STATE(8364), 1,
      aux_sym_for_statement_repeat1,
    STATE(8433), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [360008] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(2209), 1,
      anon_sym_RBRACE,
    ACTIONS(10686), 1,
      anon_sym_COMMA,
    STATE(8533), 1,
      aux_sym_switch_expression_repeat1,
    STATE(8434), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [360059] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10688), 1,
      anon_sym_COMMA,
    ACTIONS(10691), 1,
      anon_sym_RPAREN,
    STATE(8435), 10,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
      aux_sym_parenthesized_variable_designation_repeat1,
  [360108] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10693), 1,
      anon_sym_COMMA,
    ACTIONS(10695), 1,
      anon_sym_RPAREN,
    STATE(8447), 1,
      aux_sym_using_variable_declaration_repeat1,
    STATE(8436), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [360159] = 13,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    ACTIONS(10697), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(10699), 2,
      anon_sym_annotations,
      anon_sym_warnings,
    STATE(8437), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [360208] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7421), 1,
      anon_sym_COLON,
    ACTIONS(10701), 1,
      sym_interpolation_close_brace,
    STATE(9872), 1,
      sym_interpolation_format_clause,
    STATE(8438), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [360259] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5743), 1,
      anon_sym_COMMA,
    ACTIONS(10703), 1,
      anon_sym_RBRACK,
    STATE(8277), 1,
      aux_sym_type_argument_list_repeat1,
    STATE(8439), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [360310] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10672), 1,
      anon_sym_COMMA,
    ACTIONS(10705), 1,
      anon_sym_RPAREN,
    STATE(8248), 1,
      aux_sym_bracketed_parameter_list_repeat1,
    STATE(8440), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [360361] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(2633), 1,
      anon_sym_RBRACK,
    ACTIONS(10707), 1,
      anon_sym_COMMA,
    STATE(8471), 1,
      aux_sym_argument_list_repeat1,
    STATE(8441), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [360412] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7962), 1,
      anon_sym_COMMA,
    ACTIONS(10709), 1,
      anon_sym_RPAREN,
    STATE(8364), 1,
      aux_sym_for_statement_repeat1,
    STATE(8442), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [360463] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10576), 1,
      anon_sym_COMMA,
    ACTIONS(10711), 1,
      anon_sym_RPAREN,
    STATE(8417), 1,
      aux_sym_argument_list_repeat1,
    STATE(8443), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [360514] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9282), 1,
      anon_sym_RPAREN,
    ACTIONS(10713), 1,
      anon_sym_COMMA,
    STATE(8667), 1,
      aux_sym_tuple_pattern_repeat1,
    STATE(8444), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [360565] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10715), 1,
      anon_sym_COMMA,
    ACTIONS(10717), 1,
      anon_sym_RBRACK,
    STATE(8398), 1,
      aux_sym_global_attribute_repeat1,
    STATE(8445), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [360616] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10719), 1,
      anon_sym_COMMA,
    ACTIONS(10722), 1,
      anon_sym_GT,
    STATE(8446), 10,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
      aux_sym_type_parameter_list_repeat1,
  [360665] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10693), 1,
      anon_sym_COMMA,
    ACTIONS(10724), 1,
      anon_sym_RPAREN,
    STATE(8516), 1,
      aux_sym_using_variable_declaration_repeat1,
    STATE(8447), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [360716] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10726), 1,
      anon_sym_COMMA,
    ACTIONS(10728), 1,
      anon_sym_RBRACK,
    STATE(8450), 1,
      aux_sym_global_attribute_repeat1,
    STATE(8448), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [360767] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10730), 1,
      anon_sym_COMMA,
    ACTIONS(10733), 1,
      anon_sym_RPAREN,
    STATE(8449), 10,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
      aux_sym_tuple_pattern_repeat1,
  [360816] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9344), 1,
      anon_sym_RBRACK,
    ACTIONS(10735), 1,
      anon_sym_COMMA,
    STATE(8459), 1,
      aux_sym_global_attribute_repeat1,
    STATE(8450), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [360867] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10651), 1,
      anon_sym_COMMA,
    ACTIONS(10737), 1,
      anon_sym_RPAREN,
    STATE(8500), 1,
      aux_sym_tuple_type_repeat1,
    STATE(8451), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [360918] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(2773), 1,
      anon_sym_RBRACE,
    ACTIONS(10739), 1,
      anon_sym_COMMA,
    STATE(8657), 1,
      aux_sym_anonymous_object_creation_expression_repeat1,
    STATE(8452), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [360969] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10741), 1,
      anon_sym_COMMA,
    ACTIONS(10744), 1,
      anon_sym_RBRACE,
    STATE(8453), 10,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
      aux_sym_enum_member_declaration_list_repeat1,
  [361018] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10604), 1,
      anon_sym_COMMA,
    ACTIONS(10746), 1,
      anon_sym_RBRACE,
    STATE(8624), 1,
      aux_sym_with_expression_repeat1,
    STATE(8454), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [361069] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10100), 1,
      anon_sym_RPAREN,
    ACTIONS(10525), 1,
      anon_sym_EQ,
    ACTIONS(10748), 1,
      anon_sym_COMMA,
    STATE(8455), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [361120] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10651), 1,
      anon_sym_COMMA,
    ACTIONS(10751), 1,
      anon_sym_RPAREN,
    STATE(8500), 1,
      aux_sym_tuple_type_repeat1,
    STATE(8456), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [361171] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5743), 1,
      anon_sym_COMMA,
    ACTIONS(10753), 1,
      anon_sym_RBRACK,
    STATE(8463), 1,
      aux_sym_type_argument_list_repeat1,
    STATE(8457), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [361222] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(2677), 1,
      anon_sym_COMMA,
    ACTIONS(7917), 1,
      anon_sym_RBRACK,
    STATE(8628), 1,
      aux_sym_array_rank_specifier_repeat1,
    STATE(8458), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [361273] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10755), 1,
      anon_sym_COMMA,
    ACTIONS(10758), 1,
      anon_sym_RBRACK,
    STATE(8459), 10,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
      aux_sym_global_attribute_repeat1,
  [361322] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10760), 1,
      anon_sym_COMMA,
    ACTIONS(10762), 1,
      anon_sym_RPAREN,
    STATE(8598), 1,
      aux_sym_attribute_argument_list_repeat1,
    STATE(8460), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [361373] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9369), 1,
      anon_sym_RBRACK,
    ACTIONS(10764), 1,
      anon_sym_COMMA,
    STATE(8459), 1,
      aux_sym_global_attribute_repeat1,
    STATE(8461), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [361424] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7962), 1,
      anon_sym_COMMA,
    ACTIONS(10766), 1,
      anon_sym_RPAREN,
    STATE(8364), 1,
      aux_sym_for_statement_repeat1,
    STATE(8462), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [361475] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5743), 1,
      anon_sym_COMMA,
    ACTIONS(10768), 1,
      anon_sym_RBRACK,
    STATE(8277), 1,
      aux_sym_type_argument_list_repeat1,
    STATE(8463), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [361526] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5786), 1,
      anon_sym_LBRACE,
    ACTIONS(10770), 1,
      anon_sym_LPAREN,
    STATE(2273), 1,
      sym_block,
    STATE(8464), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [361577] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7962), 1,
      anon_sym_COMMA,
    ACTIONS(10772), 1,
      anon_sym_RPAREN,
    STATE(8364), 1,
      aux_sym_for_statement_repeat1,
    STATE(8465), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [361628] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10774), 1,
      anon_sym_COMMA,
    ACTIONS(10776), 1,
      anon_sym_RBRACK,
    STATE(8441), 1,
      aux_sym_argument_list_repeat1,
    STATE(8466), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [361679] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10647), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
    STATE(8467), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [361726] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10658), 1,
      anon_sym_COMMA,
    ACTIONS(10778), 1,
      anon_sym_GT,
    STATE(8498), 1,
      aux_sym_type_argument_list_repeat2,
    STATE(8468), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [361777] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10658), 1,
      anon_sym_COMMA,
    ACTIONS(10780), 1,
      anon_sym_GT,
    STATE(8479), 1,
      aux_sym_type_argument_list_repeat2,
    STATE(8469), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [361828] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5743), 1,
      anon_sym_COMMA,
    ACTIONS(10780), 1,
      anon_sym_GT,
    STATE(8277), 1,
      aux_sym_type_argument_list_repeat1,
    STATE(8470), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [361879] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10647), 1,
      anon_sym_RBRACK,
    ACTIONS(10782), 1,
      anon_sym_COMMA,
    STATE(8471), 10,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
      aux_sym_argument_list_repeat1,
  [361928] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8012), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
    STATE(8472), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [361975] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(2677), 1,
      anon_sym_COMMA,
    ACTIONS(10785), 1,
      anon_sym_RBRACK,
    STATE(8628), 1,
      aux_sym_array_rank_specifier_repeat1,
    STATE(8473), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [362026] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10576), 1,
      anon_sym_COMMA,
    ACTIONS(10787), 1,
      anon_sym_RPAREN,
    STATE(8549), 1,
      aux_sym_argument_list_repeat1,
    STATE(8474), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [362077] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10658), 1,
      anon_sym_COMMA,
    ACTIONS(10789), 1,
      anon_sym_GT,
    STATE(8597), 1,
      aux_sym_type_argument_list_repeat2,
    STATE(8475), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [362128] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10760), 1,
      anon_sym_COMMA,
    ACTIONS(10791), 1,
      anon_sym_RPAREN,
    STATE(8460), 1,
      aux_sym_attribute_argument_list_repeat1,
    STATE(8476), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [362179] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10793), 1,
      anon_sym_COMMA,
    ACTIONS(10796), 1,
      anon_sym_RBRACE,
    STATE(8477), 10,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
      aux_sym_positional_pattern_clause_repeat1,
  [362228] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10798), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
    STATE(8478), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [362275] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10658), 1,
      anon_sym_COMMA,
    ACTIONS(10800), 1,
      anon_sym_GT,
    STATE(8498), 1,
      aux_sym_type_argument_list_repeat2,
    STATE(8479), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [362326] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5743), 1,
      anon_sym_COMMA,
    ACTIONS(10789), 1,
      anon_sym_GT,
    STATE(8277), 1,
      aux_sym_type_argument_list_repeat1,
    STATE(8480), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [362377] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5743), 1,
      anon_sym_COMMA,
    ACTIONS(10802), 1,
      anon_sym_RBRACK,
    STATE(8485), 1,
      aux_sym_type_argument_list_repeat1,
    STATE(8481), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [362428] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10804), 1,
      anon_sym_COMMA,
    ACTIONS(10806), 1,
      anon_sym_RBRACK,
    STATE(8386), 1,
      aux_sym_calling_convention_repeat1,
    STATE(8482), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [362479] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10808), 1,
      anon_sym_COMMA,
    ACTIONS(10810), 1,
      anon_sym_RBRACK,
    STATE(8510), 1,
      aux_sym_global_attribute_repeat1,
    STATE(8483), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [362530] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10812), 1,
      anon_sym_COMMA,
    ACTIONS(10814), 1,
      anon_sym_RBRACK,
    STATE(8513), 1,
      aux_sym_argument_list_repeat1,
    STATE(8484), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [362581] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5743), 1,
      anon_sym_COMMA,
    ACTIONS(10816), 1,
      anon_sym_RBRACK,
    STATE(8277), 1,
      aux_sym_type_argument_list_repeat1,
    STATE(8485), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [362632] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10818), 1,
      anon_sym_EQ,
    ACTIONS(10428), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(8486), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [362681] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7477), 1,
      anon_sym_DOT,
    ACTIONS(4455), 2,
      anon_sym_COMMA,
      anon_sym_GT,
    STATE(8487), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [362730] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8233), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
    STATE(8488), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [362777] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7962), 1,
      anon_sym_COMMA,
    ACTIONS(10820), 1,
      anon_sym_RPAREN,
    STATE(8364), 1,
      aux_sym_for_statement_repeat1,
    STATE(8489), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [362828] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8235), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
    STATE(8490), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [362875] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10822), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
    STATE(8491), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [362922] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10824), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
    STATE(8492), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [362969] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10826), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
    STATE(8493), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [363016] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10828), 1,
      anon_sym_COMMA,
    ACTIONS(10830), 1,
      anon_sym_RBRACE,
    STATE(8553), 1,
      aux_sym_anonymous_object_creation_expression_repeat1,
    STATE(8494), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [363067] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10672), 1,
      anon_sym_COMMA,
    ACTIONS(10832), 1,
      anon_sym_RBRACK,
    STATE(8248), 1,
      aux_sym_bracketed_parameter_list_repeat1,
    STATE(8495), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [363118] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10672), 1,
      anon_sym_COMMA,
    ACTIONS(10834), 1,
      anon_sym_RBRACK,
    STATE(8248), 1,
      aux_sym_bracketed_parameter_list_repeat1,
    STATE(8496), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [363169] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8544), 1,
      anon_sym_DOT,
    ACTIONS(9802), 1,
      anon_sym_LBRACE,
    STATE(9282), 1,
      sym_declaration_list,
    STATE(8497), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [363220] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10836), 1,
      anon_sym_COMMA,
    ACTIONS(10839), 1,
      anon_sym_GT,
    STATE(8498), 10,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
      aux_sym_type_argument_list_repeat2,
  [363269] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10713), 1,
      anon_sym_COMMA,
    ACTIONS(10841), 1,
      anon_sym_RPAREN,
    STATE(8659), 1,
      aux_sym_tuple_pattern_repeat1,
    STATE(8499), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [363320] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10843), 1,
      anon_sym_COMMA,
    ACTIONS(10846), 1,
      anon_sym_RPAREN,
    STATE(8500), 10,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
      aux_sym_tuple_type_repeat1,
  [363369] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10658), 1,
      anon_sym_COMMA,
    ACTIONS(10848), 1,
      anon_sym_GT,
    STATE(8532), 1,
      aux_sym_type_argument_list_repeat2,
    STATE(8501), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [363420] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10850), 3,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_EQ_GT,
    STATE(8502), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [363467] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(2815), 1,
      anon_sym_RBRACE,
    ACTIONS(10852), 1,
      anon_sym_COMMA,
    STATE(8657), 1,
      aux_sym_anonymous_object_creation_expression_repeat1,
    STATE(8503), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [363518] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7962), 1,
      anon_sym_COMMA,
    ACTIONS(10854), 1,
      anon_sym_RPAREN,
    STATE(8364), 1,
      aux_sym_for_statement_repeat1,
    STATE(8504), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [363569] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10856), 1,
      anon_sym_EQ,
    ACTIONS(10574), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    STATE(8505), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [363618] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9775), 1,
      anon_sym_LBRACE,
    ACTIONS(10858), 1,
      anon_sym_SEMI,
    STATE(3349), 1,
      sym_accessor_list,
    STATE(8506), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [363669] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(2315), 1,
      anon_sym_RBRACK,
    ACTIONS(10860), 1,
      anon_sym_COMMA,
    STATE(8544), 1,
      aux_sym_list_pattern_repeat1,
    STATE(8507), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [363720] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5788), 1,
      anon_sym_LBRACE,
    ACTIONS(10770), 1,
      anon_sym_LPAREN,
    STATE(2435), 1,
      sym_block,
    STATE(8508), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [363771] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10582), 1,
      anon_sym_SEMI,
    ACTIONS(10586), 1,
      anon_sym_COMMA,
    STATE(8697), 1,
      aux_sym_variable_declaration_repeat1,
    STATE(8509), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [363822] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9324), 1,
      anon_sym_RBRACK,
    ACTIONS(10862), 1,
      anon_sym_COMMA,
    STATE(8459), 1,
      aux_sym_global_attribute_repeat1,
    STATE(8510), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [363873] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5743), 1,
      anon_sym_COMMA,
    ACTIONS(10848), 1,
      anon_sym_GT,
    STATE(8277), 1,
      aux_sym_type_argument_list_repeat1,
    STATE(8511), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [363924] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9324), 1,
      anon_sym_RBRACK,
    ACTIONS(10862), 1,
      anon_sym_COMMA,
    STATE(8542), 1,
      aux_sym_global_attribute_repeat1,
    STATE(8512), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [363975] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(2639), 1,
      anon_sym_RBRACK,
    ACTIONS(10864), 1,
      anon_sym_COMMA,
    STATE(8471), 1,
      aux_sym_argument_list_repeat1,
    STATE(8513), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [364026] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10576), 1,
      anon_sym_COMMA,
    ACTIONS(10866), 1,
      anon_sym_RPAREN,
    STATE(8417), 1,
      aux_sym_argument_list_repeat1,
    STATE(8514), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [364077] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10868), 1,
      anon_sym_COMMA,
    ACTIONS(10870), 1,
      anon_sym_RBRACK,
    STATE(8584), 1,
      aux_sym_global_attribute_repeat1,
    STATE(8515), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [364128] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10872), 1,
      anon_sym_COMMA,
    ACTIONS(10875), 1,
      anon_sym_RPAREN,
    STATE(8516), 10,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
      aux_sym_using_variable_declaration_repeat1,
  [364177] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10651), 1,
      anon_sym_COMMA,
    ACTIONS(10877), 1,
      anon_sym_RPAREN,
    STATE(8500), 1,
      aux_sym_tuple_type_repeat1,
    STATE(8517), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [364228] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10879), 1,
      anon_sym_COMMA,
    ACTIONS(10881), 1,
      anon_sym_RBRACK,
    STATE(8589), 1,
      aux_sym_argument_list_repeat1,
    STATE(8518), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [364279] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(2913), 1,
      anon_sym_RBRACE,
    ACTIONS(10883), 1,
      anon_sym_COMMA,
    STATE(8364), 1,
      aux_sym_for_statement_repeat1,
    STATE(8519), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [364330] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10576), 1,
      anon_sym_COMMA,
    ACTIONS(10885), 1,
      anon_sym_RPAREN,
    STATE(8545), 1,
      aux_sym_argument_list_repeat1,
    STATE(8520), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [364381] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(2677), 1,
      anon_sym_COMMA,
    ACTIONS(10887), 1,
      anon_sym_RBRACK,
    STATE(8628), 1,
      aux_sym_array_rank_specifier_repeat1,
    STATE(8521), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [364432] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10889), 1,
      anon_sym_COMMA,
    ACTIONS(10891), 1,
      anon_sym_RBRACE,
    STATE(8546), 1,
      aux_sym_anonymous_object_creation_expression_repeat1,
    STATE(8522), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [364483] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10893), 1,
      anon_sym_EQ,
    ACTIONS(10590), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    STATE(8523), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [364532] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10895), 3,
      anon_sym_disable,
      anon_sym_restore,
      anon_sym_enable,
    STATE(8524), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [364579] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(2677), 1,
      anon_sym_COMMA,
    ACTIONS(10897), 1,
      anon_sym_RBRACK,
    STATE(8628), 1,
      aux_sym_array_rank_specifier_repeat1,
    STATE(8525), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [364630] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10604), 1,
      anon_sym_COMMA,
    ACTIONS(10899), 1,
      anon_sym_RBRACE,
    STATE(8559), 1,
      aux_sym_with_expression_repeat1,
    STATE(8526), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [364681] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7411), 1,
      anon_sym_LBRACK,
    ACTIONS(7413), 1,
      anon_sym_QMARK,
    ACTIONS(7415), 1,
      anon_sym_STAR,
    STATE(8527), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [364732] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(2677), 1,
      anon_sym_COMMA,
    ACTIONS(8024), 1,
      anon_sym_RBRACK,
    STATE(8628), 1,
      aux_sym_array_rank_specifier_repeat1,
    STATE(8528), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [364783] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9775), 1,
      anon_sym_LBRACE,
    ACTIONS(10901), 1,
      anon_sym_SEMI,
    STATE(3400), 1,
      sym_accessor_list,
    STATE(8529), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [364834] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(2677), 1,
      anon_sym_COMMA,
    ACTIONS(10903), 1,
      anon_sym_RBRACK,
    STATE(8628), 1,
      aux_sym_array_rank_specifier_repeat1,
    STATE(8530), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [364885] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10905), 1,
      sym_integer_literal,
    ACTIONS(10907), 1,
      anon_sym_DQUOTE,
    STATE(9286), 1,
      sym_string_literal,
    STATE(8531), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [364936] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10658), 1,
      anon_sym_COMMA,
    ACTIONS(10909), 1,
      anon_sym_GT,
    STATE(8498), 1,
      aux_sym_type_argument_list_repeat2,
    STATE(8532), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [364987] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10911), 1,
      anon_sym_COMMA,
    ACTIONS(10914), 1,
      anon_sym_RBRACE,
    STATE(8533), 10,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
      aux_sym_switch_expression_repeat1,
  [365036] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10916), 1,
      anon_sym_COMMA,
    ACTIONS(10918), 1,
      anon_sym_GT,
    STATE(8446), 1,
      aux_sym_type_parameter_list_repeat1,
    STATE(8534), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [365087] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10920), 1,
      anon_sym_COMMA,
    ACTIONS(10922), 1,
      anon_sym_RBRACE,
    STATE(8434), 1,
      aux_sym_switch_expression_repeat1,
    STATE(8535), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [365138] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10658), 1,
      anon_sym_COMMA,
    ACTIONS(10924), 1,
      anon_sym_GT,
    STATE(8555), 1,
      aux_sym_type_argument_list_repeat2,
    STATE(8536), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [365189] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5743), 1,
      anon_sym_COMMA,
    ACTIONS(10924), 1,
      anon_sym_GT,
    STATE(8277), 1,
      aux_sym_type_argument_list_repeat1,
    STATE(8537), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [365240] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5743), 1,
      anon_sym_COMMA,
    ACTIONS(10926), 1,
      anon_sym_RBRACK,
    STATE(8676), 1,
      aux_sym_type_argument_list_repeat1,
    STATE(8538), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [365291] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10658), 1,
      anon_sym_COMMA,
    ACTIONS(10928), 1,
      anon_sym_GT,
    STATE(8543), 1,
      aux_sym_type_argument_list_repeat2,
    STATE(8539), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [365342] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5743), 1,
      anon_sym_COMMA,
    ACTIONS(10928), 1,
      anon_sym_GT,
    STATE(8277), 1,
      aux_sym_type_argument_list_repeat1,
    STATE(8540), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [365393] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10930), 3,
      sym_interpolation_end_quote,
      sym_interpolation_open_brace,
      sym_interpolation_string_content,
    STATE(8541), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [365440] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9300), 1,
      anon_sym_RBRACK,
    ACTIONS(10932), 1,
      anon_sym_COMMA,
    STATE(8459), 1,
      aux_sym_global_attribute_repeat1,
    STATE(8542), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [365491] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10658), 1,
      anon_sym_COMMA,
    ACTIONS(10934), 1,
      anon_sym_GT,
    STATE(8498), 1,
      aux_sym_type_argument_list_repeat2,
    STATE(8543), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [365542] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(1873), 1,
      anon_sym_RBRACK,
    ACTIONS(10936), 1,
      anon_sym_COMMA,
    STATE(8544), 10,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
      aux_sym_list_pattern_repeat1,
  [365591] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10576), 1,
      anon_sym_COMMA,
    ACTIONS(10939), 1,
      anon_sym_RPAREN,
    STATE(8417), 1,
      aux_sym_argument_list_repeat1,
    STATE(8545), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [365642] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(2759), 1,
      anon_sym_RBRACE,
    ACTIONS(10941), 1,
      anon_sym_COMMA,
    STATE(8657), 1,
      aux_sym_anonymous_object_creation_expression_repeat1,
    STATE(8546), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [365693] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(2677), 1,
      anon_sym_COMMA,
    ACTIONS(10943), 1,
      anon_sym_RBRACK,
    STATE(8628), 1,
      aux_sym_array_rank_specifier_repeat1,
    STATE(8547), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [365744] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10796), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(8548), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [365791] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10576), 1,
      anon_sym_COMMA,
    ACTIONS(10945), 1,
      anon_sym_RPAREN,
    STATE(8417), 1,
      aux_sym_argument_list_repeat1,
    STATE(8549), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [365842] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10947), 1,
      anon_sym_COMMA,
    ACTIONS(10949), 1,
      anon_sym_RBRACE,
    STATE(8560), 1,
      aux_sym_switch_expression_repeat1,
    STATE(8550), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [365893] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10796), 1,
      anon_sym_RPAREN,
    ACTIONS(10951), 1,
      anon_sym_COMMA,
    STATE(8551), 10,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
      aux_sym_positional_pattern_clause_repeat1,
  [365942] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8205), 1,
      anon_sym_COMMA,
    ACTIONS(10954), 1,
      anon_sym_SEMI,
    STATE(8407), 1,
      aux_sym_for_statement_repeat1,
    STATE(8552), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [365993] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(2775), 1,
      anon_sym_RBRACE,
    ACTIONS(10956), 1,
      anon_sym_COMMA,
    STATE(8657), 1,
      aux_sym_anonymous_object_creation_expression_repeat1,
    STATE(8553), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [366044] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10604), 1,
      anon_sym_COMMA,
    ACTIONS(10958), 1,
      anon_sym_RBRACE,
    STATE(8564), 1,
      aux_sym_with_expression_repeat1,
    STATE(8554), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [366095] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10658), 1,
      anon_sym_COMMA,
    ACTIONS(10960), 1,
      anon_sym_GT,
    STATE(8498), 1,
      aux_sym_type_argument_list_repeat2,
    STATE(8555), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [366146] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10962), 3,
      sym_interpolation_end_quote,
      sym_interpolation_open_brace,
      sym_interpolation_string_content,
    STATE(8556), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [366193] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7962), 1,
      anon_sym_COMMA,
    ACTIONS(10964), 1,
      anon_sym_RPAREN,
    STATE(8364), 1,
      aux_sym_for_statement_repeat1,
    STATE(8557), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [366244] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10966), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_GT,
    STATE(8558), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [366291] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10968), 1,
      anon_sym_COMMA,
    ACTIONS(10971), 1,
      anon_sym_RBRACE,
    STATE(8559), 10,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
      aux_sym_with_expression_repeat1,
  [366340] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(2147), 1,
      anon_sym_RBRACE,
    ACTIONS(10973), 1,
      anon_sym_COMMA,
    STATE(8533), 1,
      aux_sym_switch_expression_repeat1,
    STATE(8560), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [366391] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(2287), 1,
      anon_sym_RBRACK,
    ACTIONS(10975), 1,
      anon_sym_COMMA,
    STATE(8544), 1,
      aux_sym_list_pattern_repeat1,
    STATE(8561), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [366442] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10594), 1,
      anon_sym_COMMA,
    ACTIONS(10977), 1,
      anon_sym_RPAREN,
    STATE(8568), 1,
      aux_sym_parenthesized_variable_designation_repeat1,
    STATE(8562), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [366493] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10979), 1,
      anon_sym_COMMA,
    ACTIONS(10981), 1,
      anon_sym_RBRACE,
    STATE(8452), 1,
      aux_sym_anonymous_object_creation_expression_repeat1,
    STATE(8563), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [366544] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10604), 1,
      anon_sym_COMMA,
    ACTIONS(10983), 1,
      anon_sym_RBRACE,
    STATE(8559), 1,
      aux_sym_with_expression_repeat1,
    STATE(8564), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [366595] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10985), 3,
      sym_interpolation_end_quote,
      sym_interpolation_open_brace,
      sym_interpolation_string_content,
    STATE(8565), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [366642] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10987), 3,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_where,
    STATE(8566), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [366689] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10989), 3,
      sym_interpolation_end_quote,
      sym_interpolation_open_brace,
      sym_interpolation_string_content,
    STATE(8567), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [366736] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10594), 1,
      anon_sym_COMMA,
    ACTIONS(10991), 1,
      anon_sym_RPAREN,
    STATE(8435), 1,
      aux_sym_parenthesized_variable_designation_repeat1,
    STATE(8568), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [366787] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6108), 1,
      anon_sym_LBRACE,
    ACTIONS(10770), 1,
      anon_sym_LPAREN,
    STATE(8936), 1,
      sym_block,
    STATE(8569), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [366838] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10672), 1,
      anon_sym_COMMA,
    ACTIONS(10993), 1,
      anon_sym_RPAREN,
    STATE(8427), 1,
      aux_sym_bracketed_parameter_list_repeat1,
    STATE(8570), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [366889] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5743), 1,
      anon_sym_COMMA,
    ACTIONS(10995), 1,
      anon_sym_RBRACK,
    STATE(8388), 1,
      aux_sym_type_argument_list_repeat1,
    STATE(8571), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [366940] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10672), 1,
      anon_sym_COMMA,
    ACTIONS(10997), 1,
      anon_sym_RPAREN,
    STATE(8440), 1,
      aux_sym_bracketed_parameter_list_repeat1,
    STATE(8572), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [366991] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9775), 1,
      anon_sym_LBRACE,
    ACTIONS(10999), 1,
      anon_sym_SEMI,
    STATE(3301), 1,
      sym_accessor_list,
    STATE(8573), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [367042] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11001), 1,
      anon_sym_COMMA,
    ACTIONS(11003), 1,
      anon_sym_RPAREN,
    STATE(8551), 1,
      aux_sym_positional_pattern_clause_repeat1,
    STATE(8574), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [367093] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(2677), 1,
      anon_sym_COMMA,
    ACTIONS(11005), 1,
      anon_sym_RBRACK,
    STATE(8628), 1,
      aux_sym_array_rank_specifier_repeat1,
    STATE(8575), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [367144] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10916), 1,
      anon_sym_COMMA,
    ACTIONS(11007), 1,
      anon_sym_GT,
    STATE(8534), 1,
      aux_sym_type_parameter_list_repeat1,
    STATE(8576), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [367195] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11009), 1,
      anon_sym_COMMA,
    ACTIONS(11011), 1,
      anon_sym_RBRACE,
    STATE(8606), 1,
      aux_sym_positional_pattern_clause_repeat1,
    STATE(8577), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [367246] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7962), 1,
      anon_sym_COMMA,
    ACTIONS(11013), 1,
      anon_sym_RPAREN,
    STATE(8364), 1,
      aux_sym_for_statement_repeat1,
    STATE(8578), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [367297] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10604), 1,
      anon_sym_COMMA,
    ACTIONS(11015), 1,
      anon_sym_RBRACE,
    STATE(8526), 1,
      aux_sym_with_expression_repeat1,
    STATE(8579), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [367348] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11017), 1,
      anon_sym_COMMA,
    ACTIONS(11019), 1,
      anon_sym_RBRACE,
    STATE(8635), 1,
      aux_sym_switch_expression_repeat1,
    STATE(8580), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [367399] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7962), 1,
      anon_sym_COMMA,
    ACTIONS(11021), 1,
      anon_sym_RPAREN,
    STATE(8364), 1,
      aux_sym_for_statement_repeat1,
    STATE(8581), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [367450] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11023), 1,
      anon_sym_COMMA,
    ACTIONS(11025), 1,
      anon_sym_RBRACK,
    STATE(8616), 1,
      aux_sym_global_attribute_repeat1,
    STATE(8582), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [367501] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11027), 1,
      anon_sym_COMMA,
    ACTIONS(11029), 1,
      anon_sym_RBRACK,
    STATE(8619), 1,
      aux_sym_argument_list_repeat1,
    STATE(8583), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [367552] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9298), 1,
      anon_sym_RBRACK,
    ACTIONS(11031), 1,
      anon_sym_COMMA,
    STATE(8459), 1,
      aux_sym_global_attribute_repeat1,
    STATE(8584), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [367603] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11033), 1,
      anon_sym_COMMA,
    ACTIONS(11035), 1,
      anon_sym_RBRACE,
    STATE(8642), 1,
      aux_sym_positional_pattern_clause_repeat1,
    STATE(8585), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [367654] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9298), 1,
      anon_sym_RBRACK,
    ACTIONS(11031), 1,
      anon_sym_COMMA,
    STATE(8693), 1,
      aux_sym_global_attribute_repeat1,
    STATE(8586), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [367705] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9326), 1,
      anon_sym_RBRACE,
    ACTIONS(11037), 1,
      anon_sym_COMMA,
    STATE(8453), 1,
      aux_sym_enum_member_declaration_list_repeat1,
    STATE(8587), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [367756] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11039), 1,
      anon_sym_EQ,
    ACTIONS(10413), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    STATE(8588), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [367805] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(2657), 1,
      anon_sym_RBRACK,
    ACTIONS(11041), 1,
      anon_sym_COMMA,
    STATE(8471), 1,
      aux_sym_argument_list_repeat1,
    STATE(8589), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [367856] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10658), 1,
      anon_sym_COMMA,
    ACTIONS(11043), 1,
      anon_sym_GT,
    STATE(8593), 1,
      aux_sym_type_argument_list_repeat2,
    STATE(8590), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [367907] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5743), 1,
      anon_sym_COMMA,
    ACTIONS(11043), 1,
      anon_sym_GT,
    STATE(8277), 1,
      aux_sym_type_argument_list_repeat1,
    STATE(8591), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [367958] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10576), 1,
      anon_sym_COMMA,
    ACTIONS(11045), 1,
      anon_sym_RPAREN,
    STATE(8417), 1,
      aux_sym_argument_list_repeat1,
    STATE(8592), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [368009] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10658), 1,
      anon_sym_COMMA,
    ACTIONS(11047), 1,
      anon_sym_GT,
    STATE(8498), 1,
      aux_sym_type_argument_list_repeat2,
    STATE(8593), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [368060] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10658), 1,
      anon_sym_COMMA,
    ACTIONS(11049), 1,
      anon_sym_GT,
    STATE(8498), 1,
      aux_sym_type_argument_list_repeat2,
    STATE(8594), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [368111] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10651), 1,
      anon_sym_COMMA,
    ACTIONS(11051), 1,
      anon_sym_RPAREN,
    STATE(8500), 1,
      aux_sym_tuple_type_repeat1,
    STATE(8595), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [368162] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(2917), 1,
      anon_sym_RBRACE,
    ACTIONS(11053), 1,
      anon_sym_COMMA,
    STATE(8364), 1,
      aux_sym_for_statement_repeat1,
    STATE(8596), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [368213] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10658), 1,
      anon_sym_COMMA,
    ACTIONS(11055), 1,
      anon_sym_GT,
    STATE(8498), 1,
      aux_sym_type_argument_list_repeat2,
    STATE(8597), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [368264] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11057), 1,
      anon_sym_COMMA,
    ACTIONS(11060), 1,
      anon_sym_RPAREN,
    STATE(8598), 10,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
      aux_sym_attribute_argument_list_repeat1,
  [368313] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10594), 1,
      anon_sym_COMMA,
    ACTIONS(11062), 1,
      anon_sym_RPAREN,
    STATE(8435), 1,
      aux_sym_parenthesized_variable_designation_repeat1,
    STATE(8599), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [368364] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10604), 1,
      anon_sym_COMMA,
    ACTIONS(11064), 1,
      anon_sym_RBRACE,
    STATE(8652), 1,
      aux_sym_with_expression_repeat1,
    STATE(8600), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [368415] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(2277), 1,
      anon_sym_RBRACE,
    ACTIONS(11066), 1,
      anon_sym_COMMA,
    STATE(8533), 1,
      aux_sym_switch_expression_repeat1,
    STATE(8601), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [368466] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5743), 1,
      anon_sym_COMMA,
    ACTIONS(11068), 1,
      anon_sym_RBRACK,
    STATE(8654), 1,
      aux_sym_type_argument_list_repeat1,
    STATE(8602), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [368517] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10580), 1,
      anon_sym_COMMA,
    ACTIONS(10584), 1,
      anon_sym_RPAREN,
    STATE(8391), 1,
      aux_sym_variable_declaration_repeat1,
    STATE(8603), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [368568] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10658), 1,
      anon_sym_COMMA,
    ACTIONS(11070), 1,
      anon_sym_GT,
    STATE(8498), 1,
      aux_sym_type_argument_list_repeat2,
    STATE(8604), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [368619] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6138), 1,
      anon_sym_LBRACE,
    ACTIONS(10770), 1,
      anon_sym_LPAREN,
    STATE(2665), 1,
      sym_block,
    STATE(8605), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [368670] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(2145), 1,
      anon_sym_RBRACE,
    ACTIONS(11072), 1,
      anon_sym_COMMA,
    STATE(8477), 1,
      aux_sym_positional_pattern_clause_repeat1,
    STATE(8606), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [368721] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10576), 1,
      anon_sym_COMMA,
    ACTIONS(11074), 1,
      anon_sym_RPAREN,
    STATE(8701), 1,
      aux_sym_argument_list_repeat1,
    STATE(8607), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [368772] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11076), 1,
      anon_sym_COMMA,
    ACTIONS(11078), 1,
      anon_sym_RBRACE,
    STATE(8404), 1,
      aux_sym_anonymous_object_creation_expression_repeat1,
    STATE(8608), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [368823] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9346), 1,
      anon_sym_RBRACK,
    ACTIONS(11080), 1,
      anon_sym_COMMA,
    STATE(8459), 1,
      aux_sym_global_attribute_repeat1,
    STATE(8609), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [368874] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7411), 1,
      anon_sym_LBRACK,
    ACTIONS(7413), 1,
      anon_sym_QMARK,
    ACTIONS(10089), 1,
      anon_sym_COMMA,
    STATE(8610), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [368925] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7411), 1,
      anon_sym_LBRACK,
    ACTIONS(7415), 1,
      anon_sym_STAR,
    ACTIONS(10089), 1,
      anon_sym_COMMA,
    STATE(8611), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [368976] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10357), 1,
      anon_sym_COMMA,
    ACTIONS(10471), 1,
      anon_sym_LBRACE,
    STATE(8677), 1,
      aux_sym_base_list_repeat1,
    STATE(8612), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [369027] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10357), 1,
      anon_sym_COMMA,
    ACTIONS(10471), 1,
      anon_sym_LBRACE,
    STATE(8680), 1,
      aux_sym_base_list_repeat1,
    STATE(8613), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [369078] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(2285), 1,
      anon_sym_RBRACK,
    ACTIONS(11082), 1,
      anon_sym_COMMA,
    STATE(8544), 1,
      aux_sym_list_pattern_repeat1,
    STATE(8614), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [369129] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8205), 1,
      anon_sym_COMMA,
    ACTIONS(11084), 1,
      anon_sym_SEMI,
    STATE(8407), 1,
      aux_sym_for_statement_repeat1,
    STATE(8615), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [369180] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9320), 1,
      anon_sym_RBRACK,
    ACTIONS(11086), 1,
      anon_sym_COMMA,
    STATE(8459), 1,
      aux_sym_global_attribute_repeat1,
    STATE(8616), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [369231] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9320), 1,
      anon_sym_RBRACK,
    ACTIONS(11086), 1,
      anon_sym_COMMA,
    STATE(8655), 1,
      aux_sym_global_attribute_repeat1,
    STATE(8617), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [369282] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10594), 1,
      anon_sym_COMMA,
    ACTIONS(11088), 1,
      anon_sym_RPAREN,
    STATE(8395), 1,
      aux_sym_parenthesized_variable_designation_repeat1,
    STATE(8618), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [369333] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(2625), 1,
      anon_sym_RBRACK,
    ACTIONS(11090), 1,
      anon_sym_COMMA,
    STATE(8471), 1,
      aux_sym_argument_list_repeat1,
    STATE(8619), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [369384] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10576), 1,
      anon_sym_COMMA,
    ACTIONS(11092), 1,
      anon_sym_RPAREN,
    STATE(8417), 1,
      aux_sym_argument_list_repeat1,
    STATE(8620), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [369435] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10651), 1,
      anon_sym_COMMA,
    ACTIONS(11094), 1,
      anon_sym_RPAREN,
    STATE(8500), 1,
      aux_sym_tuple_type_repeat1,
    STATE(8621), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [369486] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10804), 1,
      anon_sym_COMMA,
    ACTIONS(11096), 1,
      anon_sym_RBRACK,
    STATE(8482), 1,
      aux_sym_calling_convention_repeat1,
    STATE(8622), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [369537] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(2889), 1,
      anon_sym_RBRACE,
    ACTIONS(11098), 1,
      anon_sym_COMMA,
    STATE(8364), 1,
      aux_sym_for_statement_repeat1,
    STATE(8623), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [369588] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10604), 1,
      anon_sym_COMMA,
    ACTIONS(11100), 1,
      anon_sym_RBRACE,
    STATE(8559), 1,
      aux_sym_with_expression_repeat1,
    STATE(8624), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [369639] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10576), 1,
      anon_sym_COMMA,
    ACTIONS(11102), 1,
      anon_sym_RPAREN,
    STATE(8666), 1,
      aux_sym_argument_list_repeat1,
    STATE(8625), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [369690] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(2677), 1,
      anon_sym_COMMA,
    ACTIONS(8089), 1,
      anon_sym_RBRACK,
    STATE(8628), 1,
      aux_sym_array_rank_specifier_repeat1,
    STATE(8626), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [369741] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11104), 1,
      anon_sym_COMMA,
    ACTIONS(11106), 1,
      anon_sym_RBRACE,
    STATE(8670), 1,
      aux_sym_anonymous_object_creation_expression_repeat1,
    STATE(8627), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [369792] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8542), 1,
      anon_sym_RBRACK,
    ACTIONS(11108), 1,
      anon_sym_COMMA,
    STATE(8628), 10,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
      aux_sym_array_rank_specifier_repeat1,
  [369841] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10672), 1,
      anon_sym_COMMA,
    ACTIONS(11111), 1,
      anon_sym_RBRACK,
    STATE(8495), 1,
      aux_sym_bracketed_parameter_list_repeat1,
    STATE(8629), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [369892] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10658), 1,
      anon_sym_COMMA,
    ACTIONS(11113), 1,
      anon_sym_GT,
    STATE(8633), 1,
      aux_sym_type_argument_list_repeat2,
    STATE(8630), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [369943] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(2677), 1,
      anon_sym_COMMA,
    ACTIONS(8305), 1,
      anon_sym_RBRACK,
    STATE(8628), 1,
      aux_sym_array_rank_specifier_repeat1,
    STATE(8631), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [369994] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5743), 1,
      anon_sym_COMMA,
    ACTIONS(11113), 1,
      anon_sym_GT,
    STATE(8277), 1,
      aux_sym_type_argument_list_repeat1,
    STATE(8632), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [370045] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10658), 1,
      anon_sym_COMMA,
    ACTIONS(11115), 1,
      anon_sym_GT,
    STATE(8498), 1,
      aux_sym_type_argument_list_repeat2,
    STATE(8633), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [370096] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10672), 1,
      anon_sym_COMMA,
    ACTIONS(11117), 1,
      anon_sym_RBRACK,
    STATE(8496), 1,
      aux_sym_bracketed_parameter_list_repeat1,
    STATE(8634), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [370147] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(2273), 1,
      anon_sym_RBRACE,
    ACTIONS(11119), 1,
      anon_sym_COMMA,
    STATE(8533), 1,
      aux_sym_switch_expression_repeat1,
    STATE(8635), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [370198] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(2307), 1,
      anon_sym_RBRACK,
    ACTIONS(11121), 1,
      anon_sym_COMMA,
    STATE(8544), 1,
      aux_sym_list_pattern_repeat1,
    STATE(8636), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [370249] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11001), 1,
      anon_sym_COMMA,
    ACTIONS(11123), 1,
      anon_sym_RPAREN,
    STATE(8551), 1,
      aux_sym_positional_pattern_clause_repeat1,
    STATE(8637), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [370300] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10594), 1,
      anon_sym_COMMA,
    ACTIONS(11125), 1,
      anon_sym_RPAREN,
    STATE(8435), 1,
      aux_sym_parenthesized_variable_designation_repeat1,
    STATE(8638), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [370351] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7962), 1,
      anon_sym_COMMA,
    ACTIONS(11127), 1,
      anon_sym_RPAREN,
    STATE(8364), 1,
      aux_sym_for_statement_repeat1,
    STATE(8639), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [370402] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11129), 1,
      anon_sym_COMMA,
    ACTIONS(11131), 1,
      anon_sym_RBRACK,
    STATE(8394), 1,
      aux_sym_global_attribute_repeat1,
    STATE(8640), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [370453] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11133), 1,
      anon_sym_COMMA,
    ACTIONS(11135), 1,
      anon_sym_RBRACK,
    STATE(8403), 1,
      aux_sym_argument_list_repeat1,
    STATE(8641), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [370504] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(2207), 1,
      anon_sym_RBRACE,
    ACTIONS(11137), 1,
      anon_sym_COMMA,
    STATE(8477), 1,
      aux_sym_positional_pattern_clause_repeat1,
    STATE(8642), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [370555] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10658), 1,
      anon_sym_COMMA,
    ACTIONS(11139), 1,
      anon_sym_GT,
    STATE(8689), 1,
      aux_sym_type_argument_list_repeat2,
    STATE(8643), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [370606] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5743), 1,
      anon_sym_COMMA,
    ACTIONS(11139), 1,
      anon_sym_GT,
    STATE(8277), 1,
      aux_sym_type_argument_list_repeat1,
    STATE(8644), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [370657] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10594), 1,
      anon_sym_COMMA,
    ACTIONS(11141), 1,
      anon_sym_RPAREN,
    STATE(8638), 1,
      aux_sym_parenthesized_variable_designation_repeat1,
    STATE(8645), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [370708] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7962), 1,
      anon_sym_COMMA,
    ACTIONS(11143), 1,
      anon_sym_RPAREN,
    STATE(8364), 1,
      aux_sym_for_statement_repeat1,
    STATE(8646), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [370759] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10594), 1,
      anon_sym_COMMA,
    ACTIONS(11145), 1,
      anon_sym_RPAREN,
    STATE(8704), 1,
      aux_sym_parenthesized_variable_designation_repeat1,
    STATE(8647), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [370810] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10658), 1,
      anon_sym_COMMA,
    ACTIONS(11147), 1,
      anon_sym_GT,
    STATE(8650), 1,
      aux_sym_type_argument_list_repeat2,
    STATE(8648), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [370861] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5743), 1,
      anon_sym_COMMA,
    ACTIONS(11147), 1,
      anon_sym_GT,
    STATE(8277), 1,
      aux_sym_type_argument_list_repeat1,
    STATE(8649), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [370912] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10658), 1,
      anon_sym_COMMA,
    ACTIONS(11149), 1,
      anon_sym_GT,
    STATE(8498), 1,
      aux_sym_type_argument_list_repeat2,
    STATE(8650), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [370963] = 14,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    ACTIONS(11151), 1,
      anon_sym_DQUOTE,
    ACTIONS(11153), 1,
      aux_sym_preproc_if_token2,
    STATE(9215), 1,
      sym_string_literal,
    STATE(8651), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [371014] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10604), 1,
      anon_sym_COMMA,
    ACTIONS(11155), 1,
      anon_sym_RBRACE,
    STATE(8559), 1,
      aux_sym_with_expression_repeat1,
    STATE(8652), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [371065] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7962), 1,
      anon_sym_COMMA,
    ACTIONS(11157), 1,
      anon_sym_RPAREN,
    STATE(8364), 1,
      aux_sym_for_statement_repeat1,
    STATE(8653), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [371116] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5743), 1,
      anon_sym_COMMA,
    ACTIONS(11159), 1,
      anon_sym_RBRACK,
    STATE(8277), 1,
      aux_sym_type_argument_list_repeat1,
    STATE(8654), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [371167] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9342), 1,
      anon_sym_RBRACK,
    ACTIONS(11161), 1,
      anon_sym_COMMA,
    STATE(8459), 1,
      aux_sym_global_attribute_repeat1,
    STATE(8655), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [371218] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7962), 1,
      anon_sym_COMMA,
    ACTIONS(11163), 1,
      anon_sym_RPAREN,
    STATE(8364), 1,
      aux_sym_for_statement_repeat1,
    STATE(8656), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [371269] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11165), 1,
      anon_sym_COMMA,
    ACTIONS(11168), 1,
      anon_sym_RBRACE,
    STATE(8657), 10,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
      aux_sym_anonymous_object_creation_expression_repeat1,
  [371318] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7962), 1,
      anon_sym_COMMA,
    ACTIONS(11170), 1,
      anon_sym_RPAREN,
    STATE(8364), 1,
      aux_sym_for_statement_repeat1,
    STATE(8658), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [371369] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10713), 1,
      anon_sym_COMMA,
    ACTIONS(11172), 1,
      anon_sym_RPAREN,
    STATE(8449), 1,
      aux_sym_tuple_pattern_repeat1,
    STATE(8659), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [371420] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(2933), 1,
      anon_sym_RBRACE,
    ACTIONS(11174), 1,
      anon_sym_COMMA,
    STATE(8364), 1,
      aux_sym_for_statement_repeat1,
    STATE(8660), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [371471] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11176), 3,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
    STATE(8661), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [371518] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10658), 1,
      anon_sym_COMMA,
    ACTIONS(11178), 1,
      anon_sym_GT,
    STATE(8668), 1,
      aux_sym_type_argument_list_repeat2,
    STATE(8662), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [371569] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8205), 1,
      anon_sym_COMMA,
    ACTIONS(11180), 1,
      anon_sym_SEMI,
    STATE(8407), 1,
      aux_sym_for_statement_repeat1,
    STATE(8663), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [371620] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5743), 1,
      anon_sym_COMMA,
    ACTIONS(11178), 1,
      anon_sym_GT,
    STATE(8277), 1,
      aux_sym_type_argument_list_repeat1,
    STATE(8664), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [371671] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7962), 1,
      anon_sym_COMMA,
    ACTIONS(11182), 1,
      anon_sym_RPAREN,
    STATE(8364), 1,
      aux_sym_for_statement_repeat1,
    STATE(8665), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [371722] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10576), 1,
      anon_sym_COMMA,
    ACTIONS(11184), 1,
      anon_sym_RPAREN,
    STATE(8417), 1,
      aux_sym_argument_list_repeat1,
    STATE(8666), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [371773] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10713), 1,
      anon_sym_COMMA,
    ACTIONS(11186), 1,
      anon_sym_RPAREN,
    STATE(8449), 1,
      aux_sym_tuple_pattern_repeat1,
    STATE(8667), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [371824] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10658), 1,
      anon_sym_COMMA,
    ACTIONS(11188), 1,
      anon_sym_GT,
    STATE(8498), 1,
      aux_sym_type_argument_list_repeat2,
    STATE(8668), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [371875] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11190), 1,
      anon_sym_COMMA,
    ACTIONS(11192), 1,
      anon_sym_RBRACE,
    STATE(8587), 1,
      aux_sym_enum_member_declaration_list_repeat1,
    STATE(8669), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [371926] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(2819), 1,
      anon_sym_RBRACE,
    ACTIONS(11194), 1,
      anon_sym_COMMA,
    STATE(8657), 1,
      aux_sym_anonymous_object_creation_expression_repeat1,
    STATE(8670), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [371977] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7962), 1,
      anon_sym_COMMA,
    ACTIONS(11196), 1,
      anon_sym_RPAREN,
    STATE(8364), 1,
      aux_sym_for_statement_repeat1,
    STATE(8671), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [372028] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11198), 1,
      anon_sym_EQ,
    ACTIONS(10405), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    STATE(8672), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [372077] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8205), 1,
      anon_sym_COMMA,
    ACTIONS(11200), 1,
      anon_sym_SEMI,
    STATE(8407), 1,
      aux_sym_for_statement_repeat1,
    STATE(8673), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [372128] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10658), 1,
      anon_sym_COMMA,
    ACTIONS(11202), 1,
      anon_sym_GT,
    STATE(8468), 1,
      aux_sym_type_argument_list_repeat2,
    STATE(8674), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [372179] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5743), 1,
      anon_sym_COMMA,
    ACTIONS(11202), 1,
      anon_sym_GT,
    STATE(8277), 1,
      aux_sym_type_argument_list_repeat1,
    STATE(8675), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [372230] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5743), 1,
      anon_sym_COMMA,
    ACTIONS(11204), 1,
      anon_sym_RBRACK,
    STATE(8277), 1,
      aux_sym_type_argument_list_repeat1,
    STATE(8676), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [372281] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10357), 1,
      anon_sym_COMMA,
    ACTIONS(10434), 1,
      anon_sym_LBRACE,
    STATE(8680), 1,
      aux_sym_base_list_repeat1,
    STATE(8677), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [372332] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10658), 1,
      anon_sym_COMMA,
    ACTIONS(11206), 1,
      anon_sym_GT,
    STATE(8683), 1,
      aux_sym_type_argument_list_repeat2,
    STATE(8678), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [372383] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5743), 1,
      anon_sym_COMMA,
    ACTIONS(11206), 1,
      anon_sym_GT,
    STATE(8277), 1,
      aux_sym_type_argument_list_repeat1,
    STATE(8679), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [372434] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10204), 1,
      anon_sym_LBRACE,
    ACTIONS(11208), 1,
      anon_sym_COMMA,
    STATE(8680), 10,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
      aux_sym_base_list_repeat1,
  [372483] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10658), 1,
      anon_sym_COMMA,
    ACTIONS(11211), 1,
      anon_sym_GT,
    STATE(8604), 1,
      aux_sym_type_argument_list_repeat2,
    STATE(8681), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [372534] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(2677), 1,
      anon_sym_COMMA,
    ACTIONS(11213), 1,
      anon_sym_RBRACK,
    STATE(8628), 1,
      aux_sym_array_rank_specifier_repeat1,
    STATE(8682), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [372585] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10658), 1,
      anon_sym_COMMA,
    ACTIONS(11215), 1,
      anon_sym_GT,
    STATE(8498), 1,
      aux_sym_type_argument_list_repeat2,
    STATE(8683), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [372636] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11217), 1,
      anon_sym_COMMA,
    ACTIONS(11219), 1,
      anon_sym_RBRACE,
    STATE(8696), 1,
      aux_sym_switch_expression_repeat1,
    STATE(8684), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [372687] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7962), 1,
      anon_sym_COMMA,
    ACTIONS(11221), 1,
      anon_sym_RPAREN,
    STATE(8364), 1,
      aux_sym_for_statement_repeat1,
    STATE(8685), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [372738] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8083), 3,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_RPAREN,
    STATE(8686), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [372785] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10604), 1,
      anon_sym_COMMA,
    ACTIONS(11223), 1,
      anon_sym_RBRACE,
    STATE(8700), 1,
      aux_sym_with_expression_repeat1,
    STATE(8687), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [372836] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11225), 1,
      anon_sym_COMMA,
    ACTIONS(11227), 1,
      anon_sym_RBRACK,
    STATE(8690), 1,
      aux_sym_argument_list_repeat1,
    STATE(8688), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [372887] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10658), 1,
      anon_sym_COMMA,
    ACTIONS(11229), 1,
      anon_sym_GT,
    STATE(8498), 1,
      aux_sym_type_argument_list_repeat2,
    STATE(8689), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [372938] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(2651), 1,
      anon_sym_RBRACK,
    ACTIONS(11231), 1,
      anon_sym_COMMA,
    STATE(8471), 1,
      aux_sym_argument_list_repeat1,
    STATE(8690), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [372989] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10651), 1,
      anon_sym_COMMA,
    ACTIONS(11233), 1,
      anon_sym_RPAREN,
    STATE(8500), 1,
      aux_sym_tuple_type_repeat1,
    STATE(8691), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [373040] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(2963), 1,
      anon_sym_RBRACE,
    ACTIONS(11235), 1,
      anon_sym_COMMA,
    STATE(8364), 1,
      aux_sym_for_statement_repeat1,
    STATE(8692), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [373091] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9322), 1,
      anon_sym_RBRACK,
    ACTIONS(11237), 1,
      anon_sym_COMMA,
    STATE(8459), 1,
      aux_sym_global_attribute_repeat1,
    STATE(8693), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [373142] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10638), 3,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(8694), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [373189] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7962), 1,
      anon_sym_COMMA,
    ACTIONS(11239), 1,
      anon_sym_RPAREN,
    STATE(8364), 1,
      aux_sym_for_statement_repeat1,
    STATE(8695), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [373240] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(2253), 1,
      anon_sym_RBRACE,
    ACTIONS(11241), 1,
      anon_sym_COMMA,
    STATE(8533), 1,
      aux_sym_switch_expression_repeat1,
    STATE(8696), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [373291] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10638), 1,
      anon_sym_SEMI,
    ACTIONS(11243), 1,
      anon_sym_COMMA,
    STATE(8697), 10,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
      aux_sym_variable_declaration_repeat1,
  [373340] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(2297), 1,
      anon_sym_RBRACK,
    ACTIONS(11246), 1,
      anon_sym_COMMA,
    STATE(8544), 1,
      aux_sym_list_pattern_repeat1,
    STATE(8698), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [373391] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10594), 1,
      anon_sym_COMMA,
    ACTIONS(11248), 1,
      anon_sym_RPAREN,
    STATE(8599), 1,
      aux_sym_parenthesized_variable_designation_repeat1,
    STATE(8699), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [373442] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10604), 1,
      anon_sym_COMMA,
    ACTIONS(11250), 1,
      anon_sym_RBRACE,
    STATE(8559), 1,
      aux_sym_with_expression_repeat1,
    STATE(8700), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [373493] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10576), 1,
      anon_sym_COMMA,
    ACTIONS(11252), 1,
      anon_sym_RPAREN,
    STATE(8417), 1,
      aux_sym_argument_list_repeat1,
    STATE(8701), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [373544] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11254), 1,
      anon_sym_COMMA,
    ACTIONS(11256), 1,
      anon_sym_RBRACE,
    STATE(8503), 1,
      aux_sym_anonymous_object_creation_expression_repeat1,
    STATE(8702), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [373595] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5743), 1,
      anon_sym_COMMA,
    ACTIONS(11211), 1,
      anon_sym_GT,
    STATE(8277), 1,
      aux_sym_type_argument_list_repeat1,
    STATE(8703), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [373646] = 14,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10594), 1,
      anon_sym_COMMA,
    ACTIONS(11258), 1,
      anon_sym_RPAREN,
    STATE(8435), 1,
      aux_sym_parenthesized_variable_designation_repeat1,
    STATE(8704), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [373697] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3387), 2,
      anon_sym_while,
      anon_sym_else,
    STATE(8705), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [373743] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10907), 1,
      anon_sym_DQUOTE,
    STATE(9288), 1,
      sym_string_literal,
    STATE(8706), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [373791] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3083), 2,
      anon_sym_while,
      anon_sym_else,
    STATE(8707), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [373837] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(1691), 1,
      anon_sym_LBRACE,
    STATE(4732), 1,
      sym_initializer_expression,
    STATE(8708), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [373885] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8544), 1,
      anon_sym_DOT,
    ACTIONS(11260), 1,
      anon_sym_SEMI,
    STATE(8709), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [373933] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11001), 1,
      anon_sym_COMMA,
    STATE(8574), 1,
      aux_sym_positional_pattern_clause_repeat1,
    STATE(8710), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [373981] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3367), 2,
      anon_sym_while,
      anon_sym_else,
    STATE(8711), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [374027] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10366), 1,
      anon_sym_LBRACE,
    STATE(9857), 1,
      sym_enum_member_declaration_list,
    STATE(8712), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [374075] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(7599), 1,
      sym_parameter_list,
    STATE(8713), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [374123] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3111), 2,
      anon_sym_while,
      anon_sym_else,
    STATE(8714), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [374169] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3055), 2,
      anon_sym_while,
      anon_sym_else,
    STATE(8715), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [374215] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3151), 2,
      anon_sym_while,
      anon_sym_else,
    STATE(8716), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [374261] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7411), 1,
      anon_sym_LBRACK,
    ACTIONS(7415), 1,
      anon_sym_STAR,
    STATE(8717), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [374309] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(1501), 1,
      anon_sym_LBRACE,
    STATE(3766), 1,
      sym_initializer_expression,
    STATE(8718), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [374357] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10907), 1,
      anon_sym_DQUOTE,
    STATE(9438), 1,
      sym_string_literal,
    STATE(8719), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [374405] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(7611), 1,
      sym_parameter_list,
    STATE(8720), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [374453] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11262), 1,
      anon_sym_LPAREN,
    STATE(8768), 1,
      sym_tuple_expression,
    STATE(8721), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [374501] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4145), 1,
      anon_sym_EQ_GT,
    ACTIONS(11264), 1,
      anon_sym_in,
    STATE(8722), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [374549] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3371), 2,
      anon_sym_while,
      anon_sym_else,
    STATE(8723), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [374595] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11266), 1,
      anon_sym_LBRACK,
    STATE(5272), 1,
      sym_array_rank_specifier,
    STATE(8724), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [374643] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10971), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    STATE(8725), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [374689] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3179), 2,
      anon_sym_while,
      anon_sym_else,
    STATE(8726), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [374735] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5776), 1,
      anon_sym_LPAREN,
    STATE(8502), 1,
      sym_argument_list,
    STATE(8727), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [374783] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11268), 2,
      anon_sym_this,
      anon_sym_base,
    STATE(8728), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [374829] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11270), 1,
      anon_sym_LBRACE,
    STATE(2721), 1,
      sym_switch_body,
    STATE(8729), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [374877] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8544), 1,
      anon_sym_DOT,
    ACTIONS(11272), 1,
      anon_sym_SEMI,
    STATE(8730), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [374925] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10839), 2,
      anon_sym_COMMA,
      anon_sym_GT,
    STATE(8731), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [374971] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(7649), 1,
      sym_parameter_list,
    STATE(8732), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [375019] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11274), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    STATE(8733), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [375065] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11276), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    STATE(8734), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [375111] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(7876), 1,
      sym_parameter_list,
    STATE(8735), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [375159] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6138), 1,
      anon_sym_LBRACE,
    STATE(2652), 1,
      sym_block,
    STATE(8736), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [375207] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10875), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(8737), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [375253] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5788), 1,
      anon_sym_LBRACE,
    STATE(2274), 1,
      sym_block,
    STATE(8738), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [375301] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3183), 2,
      anon_sym_while,
      anon_sym_else,
    STATE(8739), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [375347] = 13,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    ACTIONS(11278), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(11280), 1,
      sym_preproc_arg,
    STATE(8740), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [375395] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(8355), 1,
      sym_parameter_list,
    STATE(8741), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [375443] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3315), 2,
      anon_sym_while,
      anon_sym_else,
    STATE(8742), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [375489] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3187), 2,
      anon_sym_while,
      anon_sym_else,
    STATE(8743), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [375535] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11282), 2,
      anon_sym_LBRACE,
      anon_sym_when,
    STATE(8744), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [375581] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(1691), 1,
      anon_sym_LBRACE,
    STATE(4701), 1,
      sym_initializer_expression,
    STATE(8745), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [375629] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(1691), 1,
      anon_sym_LBRACE,
    STATE(4684), 1,
      sym_initializer_expression,
    STATE(8746), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [375677] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4494), 1,
      anon_sym_GT,
    ACTIONS(10089), 1,
      anon_sym_COMMA,
    STATE(8747), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [375725] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6108), 1,
      anon_sym_LBRACE,
    STATE(7711), 1,
      sym_block,
    STATE(8748), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [375773] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10576), 1,
      anon_sym_COMMA,
    STATE(8408), 1,
      aux_sym_argument_list_repeat1,
    STATE(8749), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [375821] = 13,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    ACTIONS(11284), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(11286), 1,
      sym_preproc_arg,
    STATE(8750), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [375869] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3375), 2,
      anon_sym_while,
      anon_sym_else,
    STATE(8751), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [375915] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3379), 2,
      anon_sym_while,
      anon_sym_else,
    STATE(8752), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [375961] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11288), 1,
      anon_sym_LBRACK,
    STATE(2948), 1,
      sym_array_rank_specifier,
    STATE(8753), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [376009] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10576), 1,
      anon_sym_COMMA,
    STATE(8620), 1,
      aux_sym_argument_list_repeat1,
    STATE(8754), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [376057] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3383), 2,
      anon_sym_while,
      anon_sym_else,
    STATE(8755), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [376103] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11290), 1,
      anon_sym_LBRACK,
    STATE(3501), 1,
      sym_array_rank_specifier,
    STATE(8756), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [376151] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3391), 2,
      anon_sym_while,
      anon_sym_else,
    STATE(8757), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [376197] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11292), 1,
      anon_sym_on,
    STATE(7615), 1,
      sym__join_body,
    STATE(8758), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [376245] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10651), 1,
      anon_sym_COMMA,
    STATE(8621), 1,
      aux_sym_tuple_type_repeat1,
    STATE(8759), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [376293] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11294), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(8760), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [376339] = 12,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    ACTIONS(11296), 2,
      sym_character_literal_content,
      sym_escape_sequence,
    STATE(8761), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [376385] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5788), 1,
      anon_sym_LBRACE,
    STATE(2437), 1,
      sym_block,
    STATE(8762), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [376433] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(145), 1,
      anon_sym_DQUOTE,
    STATE(8784), 1,
      sym_string_literal,
    STATE(8763), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [376481] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11298), 1,
      anon_sym_LPAREN,
    STATE(8943), 1,
      sym_tuple_expression,
    STATE(8764), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [376529] = 12,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    ACTIONS(11300), 2,
      sym_character_literal_content,
      sym_escape_sequence,
    STATE(8765), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [376575] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(1501), 1,
      anon_sym_LBRACE,
    STATE(3745), 1,
      sym_initializer_expression,
    STATE(8766), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [376623] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11302), 2,
      anon_sym_COMMA,
      anon_sym_GT,
    STATE(8767), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [376669] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11304), 1,
      anon_sym_LBRACE,
    STATE(2481), 1,
      sym_switch_body,
    STATE(8768), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [376717] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3095), 2,
      anon_sym_while,
      anon_sym_else,
    STATE(8769), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [376763] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10651), 1,
      anon_sym_COMMA,
    STATE(8691), 1,
      aux_sym_tuple_type_repeat1,
    STATE(8770), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [376811] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11306), 2,
      anon_sym_disable,
      anon_sym_restore,
    STATE(8771), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [376857] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3191), 2,
      anon_sym_while,
      anon_sym_else,
    STATE(8772), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [376903] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(7856), 1,
      sym_parameter_list,
    STATE(8773), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [376951] = 12,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    ACTIONS(11308), 2,
      sym_character_literal_content,
      sym_escape_sequence,
    STATE(8774), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [376997] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(7794), 1,
      sym_parameter_list,
    STATE(8775), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [377045] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10576), 1,
      anon_sym_COMMA,
    STATE(8592), 1,
      aux_sym_argument_list_repeat1,
    STATE(8776), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [377093] = 13,
    ACTIONS(5382), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    ACTIONS(11310), 1,
      sym_string_literal_encoding,
    STATE(8777), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [377141] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10651), 1,
      anon_sym_COMMA,
    STATE(8595), 1,
      aux_sym_tuple_type_repeat1,
    STATE(8778), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [377189] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5786), 1,
      anon_sym_LBRACE,
    STATE(2209), 1,
      sym_block,
    STATE(8779), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [377237] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3275), 2,
      anon_sym_while,
      anon_sym_else,
    STATE(8780), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [377283] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11312), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(8781), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [377329] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11314), 1,
      anon_sym_LBRACK,
    STATE(8261), 1,
      sym_bracketed_parameter_list,
    STATE(8782), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [377377] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(7863), 1,
      sym_parameter_list,
    STATE(8783), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [377425] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(145), 1,
      anon_sym_DQUOTE,
    STATE(8719), 1,
      sym_string_literal,
    STATE(8784), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [377473] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(8315), 1,
      sym_parameter_list,
    STATE(8785), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [377521] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10305), 1,
      anon_sym_LBRACE,
    STATE(3670), 1,
      sym_block,
    STATE(8786), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [377569] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4494), 2,
      anon_sym_COMMA,
      anon_sym_GT,
    STATE(8787), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [377615] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11316), 1,
      anon_sym_LBRACE,
    STATE(8887), 1,
      sym_switch_body,
    STATE(8788), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [377663] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10240), 1,
      anon_sym_LBRACE,
    STATE(4323), 1,
      sym_block,
    STATE(8789), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [377711] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10576), 1,
      anon_sym_COMMA,
    STATE(8443), 1,
      aux_sym_argument_list_repeat1,
    STATE(8790), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [377759] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(7942), 1,
      sym_parameter_list,
    STATE(8791), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [377807] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8544), 1,
      anon_sym_DOT,
    ACTIONS(11318), 1,
      anon_sym_SEMI,
    STATE(8792), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [377855] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11314), 1,
      anon_sym_LBRACK,
    STATE(8360), 1,
      sym_bracketed_parameter_list,
    STATE(8793), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [377903] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10366), 1,
      anon_sym_LBRACE,
    STATE(9299), 1,
      sym_enum_member_declaration_list,
    STATE(8794), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [377951] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3329), 2,
      anon_sym_while,
      anon_sym_else,
    STATE(8795), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [377997] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8544), 1,
      anon_sym_DOT,
    ACTIONS(11320), 1,
      anon_sym_SEMI,
    STATE(8796), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [378045] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11322), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(8797), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [378091] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(7644), 1,
      sym_parameter_list,
    STATE(8798), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [378139] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(7879), 1,
      sym_parameter_list,
    STATE(8799), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [378187] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11324), 2,
      anon_sym_LBRACE,
      anon_sym_EQ_GT,
    STATE(8800), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [378233] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3115), 2,
      anon_sym_while,
      anon_sym_else,
    STATE(8801), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [378279] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3119), 2,
      anon_sym_while,
      anon_sym_else,
    STATE(8802), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [378325] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(1411), 1,
      anon_sym_LBRACE,
    STATE(5567), 1,
      sym_initializer_expression,
    STATE(8803), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [378373] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(1165), 1,
      anon_sym_LBRACE,
    STATE(4014), 1,
      sym_initializer_expression,
    STATE(8804), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [378421] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11326), 1,
      anon_sym_LBRACK,
    STATE(3620), 1,
      sym_array_rank_specifier,
    STATE(8805), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [378469] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11328), 2,
      anon_sym_LBRACE,
      anon_sym_EQ_GT,
    STATE(8806), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [378515] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(8337), 1,
      sym_parameter_list,
    STATE(8807), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [378563] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(7567), 1,
      sym_parameter_list,
    STATE(8808), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [378611] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(8302), 1,
      sym_parameter_list,
    STATE(8809), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [378659] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11330), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    STATE(8810), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [378705] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(7947), 1,
      sym_parameter_list,
    STATE(8811), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [378753] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10651), 1,
      anon_sym_COMMA,
    STATE(8423), 1,
      aux_sym_tuple_type_repeat1,
    STATE(8812), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [378801] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11332), 1,
      anon_sym_LPAREN,
    STATE(8931), 1,
      sym_tuple_expression,
    STATE(8813), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [378849] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8544), 1,
      anon_sym_DOT,
    ACTIONS(11334), 1,
      anon_sym_SEMI,
    STATE(8814), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [378897] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3123), 2,
      anon_sym_while,
      anon_sym_else,
    STATE(8815), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [378943] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(7575), 1,
      sym_parameter_list,
    STATE(8816), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [378991] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(7801), 1,
      sym_parameter_list,
    STATE(8817), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [379039] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8544), 1,
      anon_sym_DOT,
    ACTIONS(11336), 1,
      anon_sym_SEMI,
    STATE(8818), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [379087] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10194), 1,
      anon_sym_LBRACE,
    STATE(4008), 1,
      sym_block,
    STATE(8819), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [379135] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6138), 1,
      anon_sym_LBRACE,
    STATE(2470), 1,
      sym_block,
    STATE(8820), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [379183] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(7869), 1,
      sym_parameter_list,
    STATE(8821), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [379231] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3127), 2,
      anon_sym_while,
      anon_sym_else,
    STATE(8822), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [379277] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(7664), 1,
      sym_parameter_list,
    STATE(8823), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [379325] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11314), 1,
      anon_sym_LBRACK,
    STATE(8278), 1,
      sym_bracketed_parameter_list,
    STATE(8824), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [379373] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5786), 1,
      anon_sym_LBRACE,
    STATE(2300), 1,
      sym_block,
    STATE(8825), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [379421] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11338), 1,
      anon_sym_warning,
    ACTIONS(11340), 1,
      anon_sym_checksum,
    STATE(8826), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [379469] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(7930), 1,
      sym_parameter_list,
    STATE(8827), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [379517] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4455), 2,
      anon_sym_COMMA,
      anon_sym_GT,
    STATE(8828), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [379563] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11342), 1,
      anon_sym_LBRACK,
    STATE(3697), 1,
      sym_array_rank_specifier,
    STATE(8829), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [379611] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4145), 1,
      anon_sym_EQ_GT,
    ACTIONS(11344), 1,
      anon_sym_in,
    STATE(8830), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [379659] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3131), 2,
      anon_sym_while,
      anon_sym_else,
    STATE(8831), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [379705] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(1411), 1,
      anon_sym_LBRACE,
    STATE(5572), 1,
      sym_initializer_expression,
    STATE(8832), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [379753] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11346), 2,
      anon_sym_LBRACE,
      anon_sym_EQ_GT,
    STATE(8833), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [379799] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4145), 1,
      anon_sym_EQ_GT,
    ACTIONS(11348), 1,
      anon_sym_in,
    STATE(8834), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [379847] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(8255), 1,
      sym_parameter_list,
    STATE(8835), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [379895] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10366), 1,
      anon_sym_LBRACE,
    STATE(9764), 1,
      sym_enum_member_declaration_list,
    STATE(8836), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [379943] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10846), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(8837), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [379989] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5786), 1,
      anon_sym_LBRACE,
    STATE(2214), 1,
      sym_block,
    STATE(8838), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [380037] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(1165), 1,
      anon_sym_LBRACE,
    STATE(3956), 1,
      sym_initializer_expression,
    STATE(8839), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [380085] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10366), 1,
      anon_sym_LBRACE,
    STATE(9929), 1,
      sym_enum_member_declaration_list,
    STATE(8840), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [380133] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(1501), 1,
      anon_sym_LBRACE,
    STATE(3756), 1,
      sym_initializer_expression,
    STATE(8841), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [380181] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11304), 1,
      anon_sym_LBRACE,
    STATE(2458), 1,
      sym_switch_body,
    STATE(8842), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [380229] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3087), 2,
      anon_sym_while,
      anon_sym_else,
    STATE(8843), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [380275] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3333), 2,
      anon_sym_while,
      anon_sym_else,
    STATE(8844), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [380321] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3135), 2,
      anon_sym_while,
      anon_sym_else,
    STATE(8845), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [380367] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(1245), 1,
      anon_sym_LBRACE,
    STATE(3649), 1,
      sym_initializer_expression,
    STATE(8846), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [380415] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(7676), 1,
      sym_parameter_list,
    STATE(8847), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [380463] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10651), 1,
      anon_sym_COMMA,
    STATE(8456), 1,
      aux_sym_tuple_type_repeat1,
    STATE(8848), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [380511] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4468), 2,
      anon_sym_COMMA,
      anon_sym_GT,
    STATE(8849), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [380557] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(7577), 1,
      sym_parameter_list,
    STATE(8850), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [380605] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11001), 1,
      anon_sym_COMMA,
    STATE(8637), 1,
      aux_sym_positional_pattern_clause_repeat1,
    STATE(8851), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [380653] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11350), 1,
      anon_sym_LBRACK,
    STATE(5250), 1,
      sym_array_rank_specifier,
    STATE(8852), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [380701] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10317), 1,
      anon_sym_LBRACE,
    STATE(4721), 1,
      sym_block,
    STATE(8853), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [380749] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10366), 1,
      anon_sym_LBRACE,
    STATE(9690), 1,
      sym_enum_member_declaration_list,
    STATE(8854), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [380797] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6108), 1,
      anon_sym_LBRACE,
    STATE(8755), 1,
      sym_block,
    STATE(8855), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [380845] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(7571), 1,
      sym_parameter_list,
    STATE(8856), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [380893] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(1245), 1,
      anon_sym_LBRACE,
    STATE(3675), 1,
      sym_initializer_expression,
    STATE(8857), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [380941] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3279), 2,
      anon_sym_while,
      anon_sym_else,
    STATE(8858), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [380987] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(7780), 1,
      sym_parameter_list,
    STATE(8859), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [381035] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10366), 1,
      anon_sym_LBRACE,
    STATE(9702), 1,
      sym_enum_member_declaration_list,
    STATE(8860), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [381083] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3059), 2,
      anon_sym_while,
      anon_sym_else,
    STATE(8861), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [381129] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6138), 1,
      anon_sym_LBRACE,
    STATE(2653), 1,
      sym_block,
    STATE(8862), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [381177] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3337), 2,
      anon_sym_while,
      anon_sym_else,
    STATE(8863), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [381223] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8544), 1,
      anon_sym_DOT,
    ACTIONS(11352), 1,
      anon_sym_SEMI,
    STATE(8864), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [381271] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3311), 2,
      anon_sym_while,
      anon_sym_else,
    STATE(8865), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [381317] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3079), 2,
      anon_sym_while,
      anon_sym_else,
    STATE(8866), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [381363] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11354), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(8867), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [381409] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10722), 2,
      anon_sym_COMMA,
      anon_sym_GT,
    STATE(8868), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [381455] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10651), 1,
      anon_sym_COMMA,
    STATE(8419), 1,
      aux_sym_tuple_type_repeat1,
    STATE(8869), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [381503] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4472), 2,
      anon_sym_COMMA,
      anon_sym_GT,
    STATE(8870), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [381549] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(7642), 1,
      sym_parameter_list,
    STATE(8871), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [381597] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3075), 2,
      anon_sym_while,
      anon_sym_else,
    STATE(8872), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [381643] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11356), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(8873), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [381689] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11358), 2,
      anon_sym_COMMA,
      anon_sym_GT,
    STATE(8874), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [381735] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11360), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(8875), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [381781] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3091), 2,
      anon_sym_while,
      anon_sym_else,
    STATE(8876), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [381827] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(7855), 1,
      sym_parameter_list,
    STATE(8877), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [381875] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3155), 2,
      anon_sym_while,
      anon_sym_else,
    STATE(8878), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [381921] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3271), 2,
      anon_sym_while,
      anon_sym_else,
    STATE(8879), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [381967] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3407), 2,
      anon_sym_while,
      anon_sym_else,
    STATE(8880), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [382013] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3063), 2,
      anon_sym_while,
      anon_sym_else,
    STATE(8881), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [382059] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(1327), 1,
      anon_sym_LBRACE,
    STATE(4097), 1,
      sym_initializer_expression,
    STATE(8882), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [382107] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10305), 1,
      anon_sym_LBRACE,
    STATE(3645), 1,
      sym_block,
    STATE(8883), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [382155] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8544), 1,
      anon_sym_DOT,
    ACTIONS(11362), 1,
      anon_sym_SEMI,
    STATE(8884), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [382203] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3345), 2,
      anon_sym_while,
      anon_sym_else,
    STATE(8885), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [382249] = 12,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    ACTIONS(11364), 2,
      sym_character_literal_content,
      sym_escape_sequence,
    STATE(8886), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [382295] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3349), 2,
      anon_sym_while,
      anon_sym_else,
    STATE(8887), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [382341] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3353), 2,
      anon_sym_while,
      anon_sym_else,
    STATE(8888), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [382387] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3103), 2,
      anon_sym_while,
      anon_sym_else,
    STATE(8889), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [382433] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3013), 2,
      anon_sym_while,
      anon_sym_else,
    STATE(8890), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [382479] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3107), 2,
      anon_sym_while,
      anon_sym_else,
    STATE(8891), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [382525] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3139), 2,
      anon_sym_while,
      anon_sym_else,
    STATE(8892), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [382571] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11366), 1,
      anon_sym_LBRACK,
    STATE(3921), 1,
      sym_array_rank_specifier,
    STATE(8893), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [382619] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10366), 1,
      anon_sym_LBRACE,
    STATE(9895), 1,
      sym_enum_member_declaration_list,
    STATE(8894), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [382667] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11168), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    STATE(8895), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [382713] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3159), 2,
      anon_sym_while,
      anon_sym_else,
    STATE(8896), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [382759] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(8353), 1,
      sym_parameter_list,
    STATE(8897), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [382807] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3361), 2,
      anon_sym_while,
      anon_sym_else,
    STATE(8898), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [382853] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10758), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(8899), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [382899] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11368), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(8900), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [382945] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(1327), 1,
      anon_sym_LBRACE,
    STATE(4109), 1,
      sym_initializer_expression,
    STATE(8901), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [382993] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(7674), 1,
      sym_parameter_list,
    STATE(8902), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [383041] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(7570), 1,
      sym_parameter_list,
    STATE(8903), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [383089] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11370), 2,
      anon_sym_LBRACE,
      anon_sym_when,
    STATE(8904), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [383135] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3283), 2,
      anon_sym_while,
      anon_sym_else,
    STATE(8905), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [383181] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4145), 1,
      anon_sym_EQ_GT,
    ACTIONS(11372), 1,
      anon_sym_in,
    STATE(8906), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [383229] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5788), 1,
      anon_sym_LBRACE,
    STATE(2212), 1,
      sym_block,
    STATE(8907), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [383277] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4145), 1,
      anon_sym_EQ_GT,
    ACTIONS(11374), 1,
      anon_sym_in,
    STATE(8908), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [383325] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3287), 2,
      anon_sym_while,
      anon_sym_else,
    STATE(8909), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [383371] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(1245), 1,
      anon_sym_LBRACE,
    STATE(3660), 1,
      sym_initializer_expression,
    STATE(8910), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [383419] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(8250), 1,
      sym_parameter_list,
    STATE(8911), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [383467] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10366), 1,
      anon_sym_LBRACE,
    STATE(9397), 1,
      sym_enum_member_declaration_list,
    STATE(8912), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [383515] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3163), 2,
      anon_sym_while,
      anon_sym_else,
    STATE(8913), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [383561] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11314), 1,
      anon_sym_LBRACK,
    STATE(8311), 1,
      sym_bracketed_parameter_list,
    STATE(8914), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [383609] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3167), 2,
      anon_sym_while,
      anon_sym_else,
    STATE(8915), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [383655] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3071), 2,
      anon_sym_while,
      anon_sym_else,
    STATE(8916), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [383701] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10317), 1,
      anon_sym_LBRACE,
    STATE(4590), 1,
      sym_block,
    STATE(8917), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [383749] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8544), 1,
      anon_sym_DOT,
    ACTIONS(11376), 1,
      anon_sym_SEMI,
    STATE(8918), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [383797] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11316), 1,
      anon_sym_LBRACE,
    STATE(8961), 1,
      sym_switch_body,
    STATE(8919), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [383845] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3143), 2,
      anon_sym_while,
      anon_sym_else,
    STATE(8920), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [383891] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3147), 2,
      anon_sym_while,
      anon_sym_else,
    STATE(8921), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [383937] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6108), 1,
      anon_sym_LBRACE,
    STATE(8377), 1,
      sym_block,
    STATE(8922), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [383985] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11378), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    STATE(8923), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [384031] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(7585), 1,
      sym_parameter_list,
    STATE(8924), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [384079] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3099), 2,
      anon_sym_while,
      anon_sym_else,
    STATE(8925), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [384125] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5786), 1,
      anon_sym_LBRACE,
    STATE(2216), 1,
      sym_block,
    STATE(8926), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [384173] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(7854), 1,
      sym_parameter_list,
    STATE(8927), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [384221] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4145), 1,
      anon_sym_EQ_GT,
    ACTIONS(11380), 1,
      anon_sym_in,
    STATE(8928), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [384269] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4145), 1,
      anon_sym_EQ_GT,
    ACTIONS(11382), 1,
      anon_sym_in,
    STATE(8929), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [384317] = 13,
    ACTIONS(5363), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    ACTIONS(11384), 1,
      sym_string_literal_encoding,
    STATE(8930), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [384365] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11270), 1,
      anon_sym_LBRACE,
    STATE(2689), 1,
      sym_switch_body,
    STATE(8931), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [384413] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6108), 1,
      anon_sym_LBRACE,
    STATE(3760), 1,
      sym_block,
    STATE(8932), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [384461] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(7896), 1,
      sym_parameter_list,
    STATE(8933), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [384509] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10265), 1,
      anon_sym_LBRACE,
    STATE(5548), 1,
      sym_block,
    STATE(8934), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [384557] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10914), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    STATE(8935), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [384603] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3291), 2,
      anon_sym_while,
      anon_sym_else,
    STATE(8936), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [384649] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(7932), 1,
      sym_parameter_list,
    STATE(8937), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [384697] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10744), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    STATE(8938), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [384743] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11386), 1,
      anon_sym_LPAREN,
    STATE(8788), 1,
      sym_tuple_expression,
    STATE(8939), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [384791] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11314), 1,
      anon_sym_LBRACK,
    STATE(8322), 1,
      sym_bracketed_parameter_list,
    STATE(8940), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [384839] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11388), 1,
      anon_sym_LBRACK,
    STATE(3977), 1,
      sym_array_rank_specifier,
    STATE(8941), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [384887] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11314), 1,
      anon_sym_LBRACK,
    STATE(8352), 1,
      sym_bracketed_parameter_list,
    STATE(8942), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [384935] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11390), 1,
      anon_sym_LBRACE,
    STATE(2289), 1,
      sym_switch_body,
    STATE(8943), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [384983] = 13,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    ACTIONS(10568), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(11392), 1,
      anon_sym_COMMA,
    STATE(8944), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [385031] = 12,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    ACTIONS(11394), 2,
      sym_character_literal_content,
      sym_escape_sequence,
    STATE(8945), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [385077] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(5788), 1,
      anon_sym_LBRACE,
    STATE(2299), 1,
      sym_block,
    STATE(8946), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [385125] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11396), 2,
      anon_sym_COMMA,
      anon_sym_GT,
    STATE(8947), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [385171] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3247), 2,
      anon_sym_while,
      anon_sym_else,
    STATE(8948), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [385217] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4145), 1,
      anon_sym_EQ_GT,
    ACTIONS(11398), 1,
      anon_sym_in,
    STATE(8949), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [385265] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(7669), 1,
      sym_parameter_list,
    STATE(8950), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [385313] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(7779), 1,
      sym_parameter_list,
    STATE(8951), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [385361] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11400), 2,
      anon_sym_LBRACE,
      anon_sym_EQ_GT,
    STATE(8952), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [385407] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11390), 1,
      anon_sym_LBRACE,
    STATE(2264), 1,
      sym_switch_body,
    STATE(8953), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [385455] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3171), 2,
      anon_sym_while,
      anon_sym_else,
    STATE(8954), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [385501] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10265), 1,
      anon_sym_LBRACE,
    STATE(5583), 1,
      sym_block,
    STATE(8955), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [385549] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11402), 1,
      anon_sym_LBRACK,
    ACTIONS(11404), 1,
      anon_sym_LT,
    STATE(8956), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [385597] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3251), 2,
      anon_sym_while,
      anon_sym_else,
    STATE(8957), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [385643] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(8305), 1,
      sym_parameter_list,
    STATE(8958), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [385691] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11406), 2,
      anon_sym_LBRACE,
      anon_sym_EQ_GT,
    STATE(8959), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [385737] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3255), 2,
      anon_sym_while,
      anon_sym_else,
    STATE(8960), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [385783] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3263), 2,
      anon_sym_while,
      anon_sym_else,
    STATE(8961), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [385829] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3295), 2,
      anon_sym_while,
      anon_sym_else,
    STATE(8962), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [385875] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(7592), 1,
      sym_parameter_list,
    STATE(8963), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [385923] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3395), 2,
      anon_sym_while,
      anon_sym_else,
    STATE(8964), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [385969] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3267), 2,
      anon_sym_while,
      anon_sym_else,
    STATE(8965), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [386015] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10194), 1,
      anon_sym_LBRACE,
    STATE(4064), 1,
      sym_block,
    STATE(8966), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [386063] = 12,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    ACTIONS(11408), 2,
      sym_character_literal_content,
      sym_escape_sequence,
    STATE(8967), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [386109] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8544), 1,
      anon_sym_DOT,
    ACTIONS(11410), 1,
      anon_sym_SEMI,
    STATE(8968), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [386157] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6138), 1,
      anon_sym_LBRACE,
    STATE(2703), 1,
      sym_block,
    STATE(8969), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [386205] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3307), 2,
      anon_sym_while,
      anon_sym_else,
    STATE(8970), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [386251] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10240), 1,
      anon_sym_LBRACE,
    STATE(4287), 1,
      sym_block,
    STATE(8971), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [386299] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3319), 1,
      anon_sym_while,
    ACTIONS(11412), 1,
      anon_sym_else,
    STATE(8972), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [386347] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(1165), 1,
      anon_sym_LBRACE,
    STATE(4009), 1,
      sym_initializer_expression,
    STATE(8973), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [386395] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10366), 1,
      anon_sym_LBRACE,
    STATE(9472), 1,
      sym_enum_member_declaration_list,
    STATE(8974), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [386443] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3299), 2,
      anon_sym_while,
      anon_sym_else,
    STATE(8975), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [386489] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3303), 2,
      anon_sym_while,
      anon_sym_else,
    STATE(8976), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [386535] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10651), 1,
      anon_sym_COMMA,
    STATE(8451), 1,
      aux_sym_tuple_type_repeat1,
    STATE(8977), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [386583] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6108), 1,
      anon_sym_LBRACE,
    STATE(8358), 1,
      sym_block,
    STATE(8978), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [386631] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3325), 2,
      anon_sym_while,
      anon_sym_else,
    STATE(8979), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [386677] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6108), 1,
      anon_sym_LBRACE,
    STATE(3782), 1,
      sym_block,
    STATE(8980), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [386725] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3175), 2,
      anon_sym_while,
      anon_sym_else,
    STATE(8981), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [386771] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10576), 1,
      anon_sym_COMMA,
    STATE(8514), 1,
      aux_sym_argument_list_repeat1,
    STATE(8982), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [386819] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3341), 2,
      anon_sym_while,
      anon_sym_else,
    STATE(8983), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [386865] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3357), 2,
      anon_sym_while,
      anon_sym_else,
    STATE(8984), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [386911] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11060), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    STATE(8985), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [386957] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10651), 1,
      anon_sym_COMMA,
    STATE(8517), 1,
      aux_sym_tuple_type_repeat1,
    STATE(8986), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [387005] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(1411), 1,
      anon_sym_LBRACE,
    STATE(5586), 1,
      sym_initializer_expression,
    STATE(8987), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [387053] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10563), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(8988), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [387099] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11414), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    STATE(8989), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [387145] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(3067), 2,
      anon_sym_while,
      anon_sym_else,
    STATE(8990), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [387191] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(7612), 1,
      sym_parameter_list,
    STATE(8991), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [387239] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(8379), 1,
      sym_parameter_list,
    STATE(8992), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [387287] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(1327), 1,
      anon_sym_LBRACE,
    STATE(4304), 1,
      sym_initializer_expression,
    STATE(8993), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [387335] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(7602), 1,
      sym_parameter_list,
    STATE(8994), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [387383] = 13,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9385), 1,
      anon_sym_LPAREN,
    STATE(7841), 1,
      sym_parameter_list,
    STATE(8995), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [387431] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11416), 1,
      anon_sym_SEMI,
    STATE(8996), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [387476] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11418), 1,
      anon_sym_EQ_GT,
    STATE(8997), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [387521] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11420), 1,
      anon_sym_EQ_GT,
    STATE(8998), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [387566] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11422), 1,
      anon_sym_SEMI,
    STATE(8999), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [387611] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11424), 1,
      anon_sym_EQ_GT,
    STATE(9000), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [387656] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11426), 1,
      anon_sym_EQ_GT,
    STATE(9001), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [387701] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11428), 1,
      anon_sym_EQ_GT,
    STATE(9002), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [387746] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11430), 1,
      sym__optional_semi,
    STATE(9003), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [387791] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11432), 1,
      anon_sym_EQ_GT,
    STATE(9004), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [387836] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11434), 1,
      anon_sym_SEMI,
    STATE(9005), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [387881] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11436), 1,
      anon_sym_EQ_GT,
    STATE(9006), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [387926] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11438), 1,
      aux_sym_preproc_if_token3,
    STATE(9007), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [387971] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11440), 1,
      anon_sym_RPAREN,
    STATE(9008), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [388016] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11442), 1,
      anon_sym_LT,
    STATE(9009), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [388061] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11444), 1,
      anon_sym_SEMI,
    STATE(9010), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [388106] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11446), 1,
      sym__optional_semi,
    STATE(9011), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [388151] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11448), 1,
      anon_sym_EQ_GT,
    STATE(9012), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [388196] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11450), 1,
      anon_sym_EQ_GT,
    STATE(9013), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [388241] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11452), 1,
      anon_sym_GT,
    STATE(9014), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [388286] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11454), 1,
      anon_sym_RBRACK,
    STATE(9015), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [388331] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11456), 1,
      sym_integer_literal,
    STATE(9016), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [388376] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11458), 1,
      anon_sym_LPAREN,
    STATE(9017), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [388421] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11460), 1,
      anon_sym_EQ_GT,
    STATE(9018), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [388466] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11462), 1,
      anon_sym_LBRACE,
    STATE(9019), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [388511] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11464), 1,
      anon_sym_LBRACE,
    STATE(9020), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [388556] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11466), 1,
      anon_sym_EQ_GT,
    STATE(9021), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [388601] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11468), 1,
      aux_sym_preproc_if_token3,
    STATE(9022), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [388646] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11470), 1,
      anon_sym_EQ_GT,
    STATE(9023), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [388691] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11472), 1,
      anon_sym_EQ_GT,
    STATE(9024), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [388736] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11474), 1,
      sym__optional_semi,
    STATE(9025), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [388781] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11476), 1,
      sym__optional_semi,
    STATE(9026), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [388826] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11478), 1,
      anon_sym_GT,
    STATE(9027), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [388871] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11480), 1,
      anon_sym_GT,
    STATE(9028), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [388916] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11482), 1,
      anon_sym_EQ_GT,
    STATE(9029), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [388961] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11484), 1,
      anon_sym_SEMI,
    STATE(9030), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [389006] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11486), 1,
      anon_sym_EQ_GT,
    STATE(9031), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [389051] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8020), 1,
      anon_sym_RBRACE,
    STATE(9032), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [389096] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11488), 1,
      anon_sym_EQ_GT,
    STATE(9033), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [389141] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11256), 1,
      anon_sym_RBRACE,
    STATE(9034), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [389186] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11490), 1,
      anon_sym_EQ_GT,
    STATE(9035), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [389231] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11492), 1,
      anon_sym_EQ_GT,
    STATE(9036), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [389276] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11494), 1,
      anon_sym_EQ_GT,
    STATE(9037), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [389321] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11496), 1,
      anon_sym_SEMI,
    STATE(9038), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [389366] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11498), 1,
      sym__optional_semi,
    STATE(9039), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [389411] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11500), 1,
      anon_sym_EQ_GT,
    STATE(9040), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [389456] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11502), 1,
      anon_sym_LT,
    STATE(9041), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [389501] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11504), 1,
      sym__optional_semi,
    STATE(9042), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [389546] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11506), 1,
      anon_sym_GT,
    STATE(9043), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [389591] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11508), 1,
      sym__optional_semi,
    STATE(9044), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [389636] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8952), 1,
      anon_sym_RPAREN,
    STATE(9045), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [389681] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11510), 1,
      anon_sym_EQ_GT,
    STATE(9046), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [389726] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11512), 1,
      anon_sym_EQ_GT,
    STATE(9047), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [389771] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11514), 1,
      sym__optional_semi,
    STATE(9048), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [389816] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11516), 1,
      anon_sym_EQ_GT,
    STATE(9049), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [389861] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11518), 1,
      anon_sym_EQ_GT,
    STATE(9050), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [389906] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11520), 1,
      sym__optional_semi,
    STATE(9051), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [389951] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10830), 1,
      anon_sym_RBRACE,
    STATE(9052), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [389996] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11522), 1,
      aux_sym_preproc_if_token3,
    STATE(9053), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [390041] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11524), 1,
      aux_sym_preproc_if_token3,
    STATE(9054), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [390086] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11526), 1,
      sym__optional_semi,
    STATE(9055), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [390131] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11528), 1,
      anon_sym_SQUOTE,
    STATE(9056), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [390176] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11530), 1,
      sym__optional_semi,
    STATE(9057), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [390221] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11532), 1,
      anon_sym_EQ_GT,
    STATE(9058), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [390266] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11534), 1,
      anon_sym_EQ_GT,
    STATE(9059), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [390311] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11011), 1,
      anon_sym_RBRACE,
    STATE(9060), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [390356] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11536), 1,
      anon_sym_EQ_GT,
    STATE(9061), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [390401] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11538), 1,
      aux_sym_preproc_if_token3,
    STATE(9062), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [390446] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11540), 1,
      anon_sym_LPAREN,
    STATE(9063), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [390491] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11542), 1,
      anon_sym_EQ_GT,
    STATE(9064), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [390536] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11544), 1,
      anon_sym_EQ_GT,
    STATE(9065), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [390581] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11546), 1,
      anon_sym_EQ_GT,
    STATE(9066), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [390626] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11548), 1,
      anon_sym_EQ_GT,
    STATE(9067), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [390671] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11550), 1,
      sym__optional_semi,
    STATE(9068), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [390716] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11552), 1,
      anon_sym_SEMI,
    STATE(9069), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [390761] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11554), 1,
      sym__optional_semi,
    STATE(9070), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [390806] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11556), 1,
      anon_sym_STAR,
    STATE(9071), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [390851] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11558), 1,
      anon_sym_RPAREN,
    STATE(9072), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [390896] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11560), 1,
      anon_sym_EQ_GT,
    STATE(9073), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [390941] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11562), 1,
      anon_sym_COLON,
    STATE(9074), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [390986] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11564), 1,
      anon_sym_SEMI,
    STATE(9075), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [391031] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11566), 1,
      anon_sym_EQ_GT,
    STATE(9076), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [391076] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11568), 1,
      anon_sym_EQ_GT,
    STATE(9077), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [391121] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11570), 1,
      anon_sym_SEMI,
    STATE(9078), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [391166] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11572), 1,
      anon_sym_operator,
    STATE(9079), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [391211] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11574), 1,
      sym__optional_semi,
    STATE(9080), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [391256] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11576), 1,
      anon_sym_DOT,
    STATE(9081), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [391301] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11578), 1,
      anon_sym_EQ_GT,
    STATE(9082), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [391346] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11580), 1,
      anon_sym_EQ_GT,
    STATE(9083), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [391391] = 12,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    ACTIONS(11582), 1,
      sym_preproc_arg,
    STATE(9084), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [391436] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11584), 1,
      sym__optional_semi,
    STATE(9085), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [391481] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11586), 1,
      anon_sym_EQ_GT,
    STATE(9086), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [391526] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11588), 1,
      sym__optional_semi,
    STATE(9087), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [391571] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11590), 1,
      anon_sym_EQ_GT,
    STATE(9088), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [391616] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11592), 1,
      anon_sym_EQ_GT,
    STATE(9089), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [391661] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11594), 1,
      anon_sym_LBRACE,
    STATE(9090), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [391706] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11596), 1,
      sym__optional_semi,
    STATE(9091), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [391751] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11598), 1,
      anon_sym_EQ_GT,
    STATE(9092), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [391796] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11600), 1,
      anon_sym_LPAREN,
    STATE(9093), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [391841] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11602), 1,
      anon_sym_EQ_GT,
    STATE(9094), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [391886] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11604), 1,
      anon_sym_EQ_GT,
    STATE(9095), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [391931] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11606), 1,
      anon_sym_EQ_GT,
    STATE(9096), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [391976] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11608), 1,
      aux_sym_preproc_if_token3,
    STATE(9097), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [392021] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11610), 1,
      ts_builtin_sym_end,
    STATE(9098), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [392066] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11612), 1,
      sym__optional_semi,
    STATE(9099), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [392111] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11614), 1,
      anon_sym_EQ_GT,
    STATE(9100), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [392156] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11616), 1,
      anon_sym_in,
    STATE(9101), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [392201] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11618), 1,
      sym__optional_semi,
    STATE(9102), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [392246] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11620), 1,
      anon_sym_GT,
    STATE(9103), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [392291] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11622), 1,
      sym__optional_semi,
    STATE(9104), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [392336] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11624), 1,
      sym__optional_semi,
    STATE(9105), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [392381] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11626), 1,
      anon_sym_EQ_GT,
    STATE(9106), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [392426] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11628), 1,
      anon_sym_EQ,
    STATE(9107), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [392471] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11630), 1,
      anon_sym_EQ_GT,
    STATE(9108), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [392516] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11632), 1,
      anon_sym_EQ_GT,
    STATE(9109), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [392561] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11634), 1,
      anon_sym_EQ_GT,
    STATE(9110), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [392606] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11636), 1,
      aux_sym_preproc_if_token3,
    STATE(9111), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [392651] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11638), 1,
      sym_raw_string_end,
    STATE(9112), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [392696] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11640), 1,
      anon_sym_SEMI,
    STATE(9113), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [392741] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11642), 1,
      sym__optional_semi,
    STATE(9114), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [392786] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11644), 1,
      anon_sym_SEMI,
    STATE(9115), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [392831] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11646), 1,
      anon_sym_in,
    STATE(9116), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [392876] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11648), 1,
      anon_sym_SEMI,
    STATE(9117), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [392921] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11650), 1,
      anon_sym_EQ_GT,
    STATE(9118), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [392966] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(4145), 1,
      anon_sym_EQ_GT,
    STATE(9119), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [393011] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11652), 1,
      anon_sym_EQ_GT,
    STATE(9120), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [393056] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11654), 1,
      anon_sym_EQ_GT,
    STATE(9121), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [393101] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11656), 1,
      anon_sym_EQ_GT,
    STATE(9122), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [393146] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11658), 1,
      sym__optional_semi,
    STATE(9123), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [393191] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11660), 1,
      anon_sym_EQ_GT,
    STATE(9124), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [393236] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11662), 1,
      anon_sym_EQ_GT,
    STATE(9125), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [393281] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11664), 1,
      anon_sym_LPAREN,
    STATE(9126), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [393326] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11666), 1,
      anon_sym_EQ_GT,
    STATE(9127), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [393371] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11668), 1,
      anon_sym_EQ_GT,
    STATE(9128), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [393416] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11670), 1,
      anon_sym_EQ_GT,
    STATE(9129), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [393461] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8770), 1,
      anon_sym_RPAREN,
    STATE(9130), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [393506] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11672), 1,
      anon_sym_EQ_GT,
    STATE(9131), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [393551] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11674), 1,
      anon_sym_EQ_GT,
    STATE(9132), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [393596] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11676), 1,
      sym__optional_semi,
    STATE(9133), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [393641] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11678), 1,
      anon_sym_EQ_GT,
    STATE(9134), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [393686] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8203), 1,
      anon_sym_SEMI,
    STATE(9135), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [393731] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11680), 1,
      sym__optional_semi,
    STATE(9136), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [393776] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11682), 1,
      anon_sym_EQ_GT,
    STATE(9137), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [393821] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11684), 1,
      sym__optional_semi,
    STATE(9138), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [393866] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11686), 1,
      anon_sym_EQ_GT,
    STATE(9139), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [393911] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11688), 1,
      anon_sym_EQ_GT,
    STATE(9140), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [393956] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11690), 1,
      aux_sym_preproc_if_token3,
    STATE(9141), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [394001] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11692), 1,
      sym__optional_semi,
    STATE(9142), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [394046] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11694), 1,
      aux_sym_preproc_if_token3,
    STATE(9143), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [394091] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11696), 1,
      sym__optional_semi,
    STATE(9144), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [394136] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11698), 1,
      anon_sym_SEMI,
    STATE(9145), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [394181] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11700), 1,
      sym__optional_semi,
    STATE(9146), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [394226] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11702), 1,
      anon_sym_EQ_GT,
    STATE(9147), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [394271] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11704), 1,
      anon_sym_EQ_GT,
    STATE(9148), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [394316] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11706), 1,
      aux_sym_preproc_if_token3,
    STATE(9149), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [394361] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11708), 1,
      sym__optional_semi,
    STATE(9150), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [394406] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10981), 1,
      anon_sym_RBRACE,
    STATE(9151), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [394451] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11710), 1,
      sym__optional_semi,
    STATE(9152), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [394496] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11712), 1,
      sym__optional_semi,
    STATE(9153), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [394541] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11714), 1,
      anon_sym_LPAREN,
    STATE(9154), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [394586] = 12,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    ACTIONS(11716), 1,
      aux_sym_preproc_if_token2,
    STATE(9155), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [394631] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11718), 1,
      anon_sym_EQ_GT,
    STATE(9156), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [394676] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11720), 1,
      anon_sym_EQ_GT,
    STATE(9157), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [394721] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11722), 1,
      anon_sym_EQ_GT,
    STATE(9158), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [394766] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11724), 1,
      sym__optional_semi,
    STATE(9159), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [394811] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11726), 1,
      sym__optional_semi,
    STATE(9160), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [394856] = 12,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    ACTIONS(11728), 1,
      aux_sym_preproc_if_token2,
    STATE(9161), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [394901] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10642), 1,
      anon_sym_RBRACE,
    STATE(9162), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [394946] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11730), 1,
      anon_sym_EQ_GT,
    STATE(9163), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [394991] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11732), 1,
      sym__optional_semi,
    STATE(9164), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [395036] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11734), 1,
      anon_sym_EQ_GT,
    STATE(9165), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [395081] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11736), 1,
      sym__optional_semi,
    STATE(9166), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [395126] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11738), 1,
      sym__optional_semi,
    STATE(9167), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [395171] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11740), 1,
      anon_sym_EQ_GT,
    STATE(9168), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [395216] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11742), 1,
      anon_sym_EQ_GT,
    STATE(9169), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [395261] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11744), 1,
      anon_sym_EQ_GT,
    STATE(9170), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [395306] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11746), 1,
      anon_sym_EQ_GT,
    STATE(9171), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [395351] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11748), 1,
      sym__optional_semi,
    STATE(9172), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [395396] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11750), 1,
      anon_sym_SEMI,
    STATE(9173), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [395441] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11752), 1,
      anon_sym_EQ_GT,
    STATE(9174), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [395486] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11754), 1,
      anon_sym_EQ_GT,
    STATE(9175), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [395531] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11756), 1,
      anon_sym_EQ_GT,
    STATE(9176), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [395576] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11758), 1,
      sym__optional_semi,
    STATE(9177), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [395621] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10891), 1,
      anon_sym_RBRACE,
    STATE(9178), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [395666] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11760), 1,
      sym__optional_semi,
    STATE(9179), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [395711] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11762), 1,
      anon_sym_SEMI,
    STATE(9180), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [395756] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11764), 1,
      anon_sym_RPAREN,
    STATE(9181), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [395801] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11766), 1,
      sym__optional_semi,
    STATE(9182), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [395846] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11768), 1,
      anon_sym_EQ_GT,
    STATE(9183), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [395891] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11770), 1,
      anon_sym_EQ_GT,
    STATE(9184), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [395936] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11772), 1,
      anon_sym_EQ_GT,
    STATE(9185), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [395981] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11774), 1,
      anon_sym_RPAREN,
    STATE(9186), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [396026] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11776), 1,
      anon_sym_COLON,
    STATE(9187), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [396071] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11778), 1,
      anon_sym_EQ_GT,
    STATE(9188), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [396116] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11780), 1,
      anon_sym_EQ_GT,
    STATE(9189), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [396161] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11782), 1,
      anon_sym_RPAREN,
    STATE(9190), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [396206] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11784), 1,
      anon_sym_EQ_GT,
    STATE(9191), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [396251] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11786), 1,
      anon_sym_RPAREN,
    STATE(9192), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [396296] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11788), 1,
      anon_sym_EQ_GT,
    STATE(9193), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [396341] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11790), 1,
      anon_sym_RPAREN,
    STATE(9194), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [396386] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11792), 1,
      anon_sym_EQ_GT,
    STATE(9195), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [396431] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11794), 1,
      anon_sym_EQ_GT,
    STATE(9196), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [396476] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11796), 1,
      anon_sym_EQ_GT,
    STATE(9197), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [396521] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11798), 1,
      anon_sym_RBRACK,
    STATE(9198), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [396566] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11800), 1,
      anon_sym_EQ_GT,
    STATE(9199), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [396611] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11802), 1,
      anon_sym_EQ_GT,
    STATE(9200), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [396656] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11804), 1,
      sym__optional_semi,
    STATE(9201), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [396701] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11806), 1,
      anon_sym_EQ_GT,
    STATE(9202), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [396746] = 12,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    ACTIONS(11808), 1,
      sym_preproc_arg,
    STATE(9203), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [396791] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11810), 1,
      anon_sym_EQ_GT,
    STATE(9204), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [396836] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11812), 1,
      anon_sym_EQ_GT,
    STATE(9205), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [396881] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11814), 1,
      sym__optional_semi,
    STATE(9206), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [396926] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11816), 1,
      sym__optional_semi,
    STATE(9207), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [396971] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10922), 1,
      anon_sym_RBRACE,
    STATE(9208), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [397016] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11818), 1,
      anon_sym_EQ_GT,
    STATE(9209), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [397061] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11820), 1,
      anon_sym_EQ_GT,
    STATE(9210), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [397106] = 12,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    ACTIONS(11822), 1,
      aux_sym_preproc_if_token2,
    STATE(9211), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [397151] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11824), 1,
      sym__optional_semi,
    STATE(9212), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [397196] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7974), 1,
      anon_sym_RBRACE,
    STATE(9213), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [397241] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11826), 1,
      sym__optional_semi,
    STATE(9214), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [397286] = 12,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    ACTIONS(11828), 1,
      aux_sym_preproc_if_token2,
    STATE(9215), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [397331] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11830), 1,
      anon_sym_SEMI,
    STATE(9216), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [397376] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11832), 1,
      sym_raw_string_content,
    STATE(9217), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [397421] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11834), 1,
      anon_sym_SEMI,
    STATE(9218), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [397466] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11836), 1,
      sym__optional_semi,
    STATE(9219), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [397511] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11838), 1,
      anon_sym_EQ_GT,
    STATE(9220), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [397556] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11840), 1,
      anon_sym_STAR,
    STATE(9221), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [397601] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11842), 1,
      anon_sym_EQ_GT,
    STATE(9222), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [397646] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11844), 1,
      anon_sym_EQ_GT,
    STATE(9223), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [397691] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11846), 1,
      sym__optional_semi,
    STATE(9224), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [397736] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11848), 1,
      anon_sym_DASH,
    STATE(9225), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [397781] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11850), 1,
      anon_sym_EQ_GT,
    STATE(9226), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [397826] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11852), 1,
      sym__optional_semi,
    STATE(9227), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [397871] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11854), 1,
      anon_sym_SEMI,
    STATE(9228), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [397916] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11856), 1,
      sym__optional_semi,
    STATE(9229), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [397961] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11858), 1,
      anon_sym_EQ_GT,
    STATE(9230), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [398006] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11860), 1,
      sym__optional_semi,
    STATE(9231), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [398051] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11862), 1,
      sym__optional_semi,
    STATE(9232), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [398096] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11864), 1,
      anon_sym_EQ_GT,
    STATE(9233), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [398141] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11866), 1,
      anon_sym_EQ_GT,
    STATE(9234), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [398186] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11868), 1,
      anon_sym_EQ_GT,
    STATE(9235), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [398231] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11870), 1,
      anon_sym_EQ_GT,
    STATE(9236), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [398276] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11872), 1,
      sym__optional_semi,
    STATE(9237), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [398321] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11874), 1,
      anon_sym_EQ_GT,
    STATE(9238), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [398366] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11876), 1,
      sym__optional_semi,
    STATE(9239), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [398411] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11878), 1,
      anon_sym_RPAREN,
    STATE(9240), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [398456] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11880), 1,
      anon_sym_SQUOTE,
    STATE(9241), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [398501] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10629), 1,
      anon_sym_RBRACE,
    STATE(9242), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [398546] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11882), 1,
      sym__optional_semi,
    STATE(9243), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [398591] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11884), 1,
      anon_sym_EQ_GT,
    STATE(9244), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [398636] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11886), 1,
      anon_sym_SEMI,
    STATE(9245), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [398681] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11888), 1,
      anon_sym_EQ_GT,
    STATE(9246), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [398726] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11890), 1,
      anon_sym_EQ_GT,
    STATE(9247), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [398771] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11892), 1,
      anon_sym_EQ_GT,
    STATE(9248), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [398816] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11894), 1,
      anon_sym_EQ_GT,
    STATE(9249), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [398861] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11896), 1,
      anon_sym_EQ_GT,
    STATE(9250), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [398906] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11898), 1,
      anon_sym_EQ_GT,
    STATE(9251), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [398951] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11900), 1,
      anon_sym_EQ_GT,
    STATE(9252), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [398996] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11902), 1,
      sym_integer_literal,
    STATE(9253), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [399041] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11904), 1,
      anon_sym_EQ_GT,
    STATE(9254), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [399086] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11906), 1,
      anon_sym_EQ_GT,
    STATE(9255), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [399131] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11908), 1,
      anon_sym_EQ_GT,
    STATE(9256), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [399176] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11910), 1,
      anon_sym_SEMI,
    STATE(9257), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [399221] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11912), 1,
      anon_sym_EQ_GT,
    STATE(9258), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [399266] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11914), 1,
      sym__optional_semi,
    STATE(9259), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [399311] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11916), 1,
      anon_sym_SEMI,
    STATE(9260), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [399356] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11918), 1,
      sym__optional_semi,
    STATE(9261), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [399401] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11920), 1,
      sym__optional_semi,
    STATE(9262), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [399446] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11922), 1,
      anon_sym_GT,
    STATE(9263), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [399491] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11924), 1,
      anon_sym_EQ_GT,
    STATE(9264), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [399536] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11926), 1,
      anon_sym_EQ_GT,
    STATE(9265), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [399581] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11928), 1,
      anon_sym_EQ_GT,
    STATE(9266), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [399626] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11930), 1,
      anon_sym_EQ_GT,
    STATE(9267), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [399671] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11932), 1,
      anon_sym_EQ_GT,
    STATE(9268), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [399716] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11934), 1,
      sym__optional_semi,
    STATE(9269), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [399761] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11936), 1,
      sym__optional_semi,
    STATE(9270), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [399806] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11938), 1,
      sym__optional_semi,
    STATE(9271), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [399851] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11940), 1,
      aux_sym_preproc_if_token3,
    STATE(9272), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [399896] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11942), 1,
      anon_sym_EQ_GT,
    STATE(9273), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [399941] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11944), 1,
      anon_sym_SEMI,
    STATE(9274), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [399986] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11946), 1,
      anon_sym_GT,
    STATE(9275), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [400031] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11948), 1,
      sym__optional_semi,
    STATE(9276), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [400076] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10949), 1,
      anon_sym_RBRACE,
    STATE(9277), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [400121] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11950), 1,
      anon_sym_EQ_GT,
    STATE(9278), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [400166] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11952), 1,
      sym__optional_semi,
    STATE(9279), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [400211] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11954), 1,
      aux_sym_preproc_if_token3,
    STATE(9280), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [400256] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11956), 1,
      anon_sym_EQ_GT,
    STATE(9281), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [400301] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11958), 1,
      sym__optional_semi,
    STATE(9282), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [400346] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11960), 1,
      anon_sym_EQ_GT,
    STATE(9283), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [400391] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11962), 1,
      anon_sym_EQ_GT,
    STATE(9284), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [400436] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11964), 1,
      sym__optional_semi,
    STATE(9285), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [400481] = 12,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    ACTIONS(11966), 1,
      aux_sym_preproc_if_token2,
    STATE(9286), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [400526] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11968), 1,
      sym__optional_semi,
    STATE(9287), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [400571] = 12,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    ACTIONS(11970), 1,
      aux_sym_preproc_if_token2,
    STATE(9288), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [400616] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11972), 1,
      anon_sym_EQ_GT,
    STATE(9289), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [400661] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11974), 1,
      sym__optional_semi,
    STATE(9290), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [400706] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11976), 1,
      sym__optional_semi,
    STATE(9291), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [400751] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11978), 1,
      anon_sym_EQ_GT,
    STATE(9292), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [400796] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11980), 1,
      anon_sym_EQ_GT,
    STATE(9293), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [400841] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11982), 1,
      sym__optional_semi,
    STATE(9294), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [400886] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11984), 1,
      sym__optional_semi,
    STATE(9295), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [400931] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11986), 1,
      anon_sym_EQ_GT,
    STATE(9296), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [400976] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11988), 1,
      anon_sym_EQ_GT,
    STATE(9297), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [401021] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11990), 1,
      anon_sym_RBRACE,
    STATE(9298), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [401066] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11992), 1,
      sym__optional_semi,
    STATE(9299), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [401111] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11994), 1,
      anon_sym_RBRACE,
    STATE(9300), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [401156] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11996), 1,
      anon_sym_GT,
    STATE(9301), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [401201] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11998), 1,
      sym__optional_semi,
    STATE(9302), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [401246] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12000), 1,
      sym__optional_semi,
    STATE(9303), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [401291] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12002), 1,
      anon_sym_EQ_GT,
    STATE(9304), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [401336] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12004), 1,
      anon_sym_RPAREN,
    STATE(9305), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [401381] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12006), 1,
      sym__optional_semi,
    STATE(9306), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [401426] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12008), 1,
      anon_sym_SEMI,
    STATE(9307), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [401471] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12010), 1,
      aux_sym_preproc_if_token3,
    STATE(9308), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [401516] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12012), 1,
      anon_sym_EQ_GT,
    STATE(9309), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [401561] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12014), 1,
      anon_sym_EQ_GT,
    STATE(9310), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [401606] = 12,
    ACTIONS(5660), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    STATE(9311), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [401651] = 12,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    ACTIONS(12016), 1,
      sym_preproc_arg,
    STATE(9312), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [401696] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12018), 1,
      aux_sym_preproc_if_token3,
    STATE(9313), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [401741] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12020), 1,
      sym__optional_semi,
    STATE(9314), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [401786] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12022), 1,
      anon_sym_EQ_GT,
    STATE(9315), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [401831] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12024), 1,
      anon_sym_EQ_GT,
    STATE(9316), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [401876] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8852), 1,
      anon_sym_RPAREN,
    STATE(9317), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [401921] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12026), 1,
      sym__optional_semi,
    STATE(9318), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [401966] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12028), 1,
      sym__optional_semi,
    STATE(9319), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [402011] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12030), 1,
      anon_sym_EQ_GT,
    STATE(9320), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [402056] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12032), 1,
      aux_sym_preproc_if_token3,
    STATE(9321), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [402101] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12034), 1,
      sym__optional_semi,
    STATE(9322), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [402146] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12036), 1,
      sym__optional_semi,
    STATE(9323), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [402191] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12038), 1,
      anon_sym_EQ_GT,
    STATE(9324), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [402236] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12040), 1,
      sym__optional_semi,
    STATE(9325), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [402281] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12042), 1,
      sym__optional_semi,
    STATE(9326), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [402326] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12044), 1,
      sym__optional_semi,
    STATE(9327), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [402371] = 12,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    ACTIONS(12046), 1,
      sym_preproc_arg,
    STATE(9328), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [402416] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12048), 1,
      anon_sym_RPAREN,
    STATE(9329), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [402461] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12050), 1,
      sym__optional_semi,
    STATE(9330), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [402506] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8910), 1,
      anon_sym_RPAREN,
    STATE(9331), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [402551] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12052), 1,
      anon_sym_GT,
    STATE(9332), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [402596] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12054), 1,
      sym__optional_semi,
    STATE(9333), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [402641] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12056), 1,
      anon_sym_EQ_GT,
    STATE(9334), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [402686] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12058), 1,
      anon_sym_EQ_GT,
    STATE(9335), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [402731] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12060), 1,
      anon_sym_EQ_GT,
    STATE(9336), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [402776] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12062), 1,
      anon_sym_EQ_GT,
    STATE(9337), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [402821] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12064), 1,
      sym__optional_semi,
    STATE(9338), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [402866] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12066), 1,
      sym__optional_semi,
    STATE(9339), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [402911] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12068), 1,
      anon_sym_SEMI,
    STATE(9340), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [402956] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12070), 1,
      anon_sym_EQ_GT,
    STATE(9341), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [403001] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12072), 1,
      anon_sym_EQ_GT,
    STATE(9342), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [403046] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12074), 1,
      sym__optional_semi,
    STATE(9343), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [403091] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12076), 1,
      anon_sym_EQ_GT,
    STATE(9344), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [403136] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12078), 1,
      anon_sym_SEMI,
    STATE(9345), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [403181] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12080), 1,
      anon_sym_SEMI,
    STATE(9346), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [403226] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12082), 1,
      anon_sym_GT,
    STATE(9347), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [403271] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12084), 1,
      anon_sym_EQ_GT,
    STATE(9348), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [403316] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12086), 1,
      anon_sym_COLON,
    STATE(9349), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [403361] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12088), 1,
      anon_sym_EQ_GT,
    STATE(9350), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [403406] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12090), 1,
      aux_sym_preproc_if_token3,
    STATE(9351), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [403451] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12092), 1,
      sym__optional_semi,
    STATE(9352), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [403496] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12094), 1,
      aux_sym_preproc_if_token3,
    STATE(9353), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [403541] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12096), 1,
      anon_sym_RPAREN,
    STATE(9354), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [403586] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12098), 1,
      sym_integer_literal,
    STATE(9355), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [403631] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(6110), 1,
      anon_sym_STAR,
    STATE(9356), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [403676] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12100), 1,
      anon_sym_EQ_GT,
    STATE(9357), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [403721] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12102), 1,
      sym__optional_semi,
    STATE(9358), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [403766] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12104), 1,
      sym__optional_semi,
    STATE(9359), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [403811] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12106), 1,
      anon_sym_SEMI,
    STATE(9360), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [403856] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12108), 1,
      anon_sym_RPAREN,
    STATE(9361), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [403901] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12110), 1,
      anon_sym_EQ_GT,
    STATE(9362), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [403946] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12112), 1,
      anon_sym_EQ_GT,
    STATE(9363), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [403991] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12114), 1,
      anon_sym_EQ_GT,
    STATE(9364), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [404036] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12116), 1,
      sym__optional_semi,
    STATE(9365), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [404081] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12118), 1,
      anon_sym_LPAREN,
    STATE(9366), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [404126] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12120), 1,
      anon_sym_STAR,
    STATE(9367), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [404171] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12122), 1,
      anon_sym_SEMI,
    STATE(9368), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [404216] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12124), 1,
      anon_sym_EQ_GT,
    STATE(9369), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [404261] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12126), 1,
      anon_sym_EQ_GT,
    STATE(9370), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [404306] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12128), 1,
      anon_sym_EQ_GT,
    STATE(9371), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [404351] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12130), 1,
      sym__optional_semi,
    STATE(9372), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [404396] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12132), 1,
      sym__optional_semi,
    STATE(9373), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [404441] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12134), 1,
      anon_sym_EQ_GT,
    STATE(9374), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [404486] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12136), 1,
      anon_sym_EQ_GT,
    STATE(9375), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [404531] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12138), 1,
      sym_interpolation_start_quote,
    STATE(9376), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [404576] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12140), 1,
      sym_interpolation_start_quote,
    STATE(9377), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [404621] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12142), 1,
      anon_sym_SEMI,
    STATE(9378), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [404666] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12144), 1,
      anon_sym_RPAREN,
    STATE(9379), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [404711] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12146), 1,
      sym_interpolation_start_quote,
    STATE(9380), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [404756] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12148), 1,
      sym_raw_string_content,
    STATE(9381), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [404801] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12150), 1,
      sym__optional_semi,
    STATE(9382), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [404846] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12152), 1,
      sym_raw_string_end,
    STATE(9383), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [404891] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12154), 1,
      sym_interpolation_start_quote,
    STATE(9384), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [404936] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12156), 1,
      sym__optional_semi,
    STATE(9385), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [404981] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12158), 1,
      sym__optional_semi,
    STATE(9386), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [405026] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12160), 1,
      anon_sym_SEMI,
    STATE(9387), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [405071] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12162), 1,
      anon_sym_SEMI,
    STATE(9388), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [405116] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12164), 1,
      sym_interpolation_start_quote,
    STATE(9389), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [405161] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12166), 1,
      anon_sym_EQ_GT,
    STATE(9390), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [405206] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11019), 1,
      anon_sym_RBRACE,
    STATE(9391), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [405251] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12168), 1,
      sym_interpolation_start_quote,
    STATE(9392), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [405296] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12170), 1,
      anon_sym_RPAREN,
    STATE(9393), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [405341] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12172), 1,
      anon_sym_EQ_GT,
    STATE(9394), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [405386] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12174), 1,
      anon_sym_EQ_GT,
    STATE(9395), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [405431] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12176), 1,
      anon_sym_GT,
    STATE(9396), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [405476] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12178), 1,
      sym__optional_semi,
    STATE(9397), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [405521] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12180), 1,
      anon_sym_RPAREN,
    STATE(9398), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [405566] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12182), 1,
      anon_sym_COLON,
    STATE(9399), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [405611] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12184), 1,
      sym_raw_string_content,
    STATE(9400), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [405656] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12186), 1,
      anon_sym_SEMI,
    STATE(9401), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [405701] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12188), 1,
      sym__optional_semi,
    STATE(9402), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [405746] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9057), 1,
      anon_sym_RPAREN,
    STATE(9403), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [405791] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12190), 1,
      sym__optional_semi,
    STATE(9404), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [405836] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12192), 1,
      anon_sym_RBRACE,
    STATE(9405), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [405881] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12194), 1,
      anon_sym_SEMI,
    STATE(9406), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [405926] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12196), 1,
      anon_sym_SEMI,
    STATE(9407), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [405971] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12198), 1,
      sym__optional_semi,
    STATE(9408), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [406016] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12200), 1,
      anon_sym_operator,
    STATE(9409), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [406061] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12202), 1,
      sym__optional_semi,
    STATE(9410), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [406106] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12204), 1,
      anon_sym_LPAREN,
    STATE(9411), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [406151] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12206), 1,
      anon_sym_EQ_GT,
    STATE(9412), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [406196] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12208), 1,
      aux_sym_preproc_if_token3,
    STATE(9413), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [406241] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12210), 1,
      sym__optional_semi,
    STATE(9414), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [406286] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12212), 1,
      anon_sym_LPAREN,
    STATE(9415), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [406331] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12214), 1,
      anon_sym_LPAREN,
    STATE(9416), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [406376] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12216), 1,
      anon_sym_EQ,
    STATE(9417), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [406421] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12218), 1,
      sym__optional_semi,
    STATE(9418), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [406466] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12220), 1,
      sym_interpolation_start_quote,
    STATE(9419), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [406511] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8299), 1,
      anon_sym_RBRACE,
    STATE(9420), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [406556] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12222), 1,
      sym_interpolation_start_quote,
    STATE(9421), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [406601] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12224), 1,
      anon_sym_EQ_GT,
    STATE(9422), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [406646] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12226), 1,
      sym_interpolation_start_quote,
    STATE(9423), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [406691] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12228), 1,
      anon_sym_EQ_GT,
    STATE(9424), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [406736] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12230), 1,
      sym_raw_string_content,
    STATE(9425), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [406781] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12232), 1,
      sym__optional_semi,
    STATE(9426), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [406826] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12234), 1,
      anon_sym_EQ_GT,
    STATE(9427), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [406871] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12236), 1,
      aux_sym_preproc_if_token3,
    STATE(9428), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [406916] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12238), 1,
      aux_sym_preproc_if_token3,
    STATE(9429), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [406961] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12240), 1,
      anon_sym_LBRACE,
    STATE(9430), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [407006] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12242), 1,
      sym__optional_semi,
    STATE(9431), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [407051] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12244), 1,
      anon_sym_LPAREN,
    STATE(9432), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [407096] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12246), 1,
      anon_sym_SEMI,
    STATE(9433), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [407141] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12248), 1,
      anon_sym_EQ_GT,
    STATE(9434), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [407186] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12250), 1,
      aux_sym_preproc_if_token3,
    STATE(9435), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [407231] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12252), 1,
      anon_sym_operator,
    STATE(9436), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [407276] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12254), 1,
      sym__optional_semi,
    STATE(9437), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [407321] = 12,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    ACTIONS(10678), 1,
      aux_sym_preproc_if_token2,
    STATE(9438), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [407366] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12256), 1,
      sym__optional_semi,
    STATE(9439), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [407411] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12258), 1,
      anon_sym_SQUOTE,
    STATE(9440), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [407456] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12260), 1,
      anon_sym_SQUOTE,
    STATE(9441), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [407501] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12262), 1,
      sym__optional_semi,
    STATE(9442), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [407546] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12264), 1,
      anon_sym_STAR,
    STATE(9443), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [407591] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12266), 1,
      anon_sym_EQ_GT,
    STATE(9444), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [407636] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12268), 1,
      sym__optional_semi,
    STATE(9445), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [407681] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12270), 1,
      anon_sym_SEMI,
    STATE(9446), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [407726] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12272), 1,
      sym__optional_semi,
    STATE(9447), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [407771] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12274), 1,
      anon_sym_EQ_GT,
    STATE(9448), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [407816] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12276), 1,
      anon_sym_EQ_GT,
    STATE(9449), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [407861] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12278), 1,
      anon_sym_LPAREN,
    STATE(9450), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [407906] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12280), 1,
      anon_sym_LPAREN,
    STATE(9451), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [407951] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12282), 1,
      anon_sym_LPAREN,
    STATE(9452), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [407996] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12284), 1,
      anon_sym_EQ_GT,
    STATE(9453), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [408041] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12286), 1,
      anon_sym_LPAREN,
    STATE(9454), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [408086] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12288), 1,
      anon_sym_LPAREN,
    STATE(9455), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [408131] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12290), 1,
      anon_sym_LPAREN,
    STATE(9456), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [408176] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12292), 1,
      anon_sym_LPAREN,
    STATE(9457), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [408221] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12294), 1,
      sym__optional_semi,
    STATE(9458), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [408266] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12296), 1,
      sym__optional_semi,
    STATE(9459), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [408311] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12298), 1,
      sym__optional_semi,
    STATE(9460), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [408356] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12300), 1,
      sym__optional_semi,
    STATE(9461), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [408401] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12302), 1,
      anon_sym_COMMA,
    STATE(9462), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [408446] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12304), 1,
      sym__optional_semi,
    STATE(9463), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [408491] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12306), 1,
      anon_sym_COLON,
    STATE(9464), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [408536] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12308), 1,
      anon_sym_GT,
    STATE(9465), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [408581] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12310), 1,
      anon_sym_LPAREN,
    STATE(9466), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [408626] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12312), 1,
      anon_sym_RPAREN,
    STATE(9467), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [408671] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12314), 1,
      anon_sym_SEMI,
    STATE(9468), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [408716] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12316), 1,
      sym__optional_semi,
    STATE(9469), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [408761] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12318), 1,
      anon_sym_EQ_GT,
    STATE(9470), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [408806] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12320), 1,
      anon_sym_EQ_GT,
    STATE(9471), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [408851] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12322), 1,
      sym__optional_semi,
    STATE(9472), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [408896] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12324), 1,
      aux_sym_preproc_if_token3,
    STATE(9473), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [408941] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12326), 1,
      aux_sym_preproc_if_token3,
    STATE(9474), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [408986] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12328), 1,
      aux_sym_preproc_if_token3,
    STATE(9475), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [409031] = 12,
    ACTIONS(5382), 1,
      aux_sym_preproc_if_token2,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    STATE(9476), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [409076] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12330), 1,
      sym__optional_semi,
    STATE(9477), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [409121] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12332), 1,
      sym__optional_semi,
    STATE(9478), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [409166] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12334), 1,
      sym__optional_semi,
    STATE(9479), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [409211] = 12,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    ACTIONS(12336), 1,
      aux_sym_preproc_if_token2,
    STATE(9480), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [409256] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12338), 1,
      sym__optional_semi,
    STATE(9481), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [409301] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12340), 1,
      anon_sym_EQ_GT,
    STATE(9482), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [409346] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12342), 1,
      sym__optional_semi,
    STATE(9483), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [409391] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12344), 1,
      sym__optional_semi,
    STATE(9484), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [409436] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12346), 1,
      sym__optional_semi,
    STATE(9485), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [409481] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12348), 1,
      sym__optional_semi,
    STATE(9486), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [409526] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12350), 1,
      sym__optional_semi,
    STATE(9487), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [409571] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12352), 1,
      sym__optional_semi,
    STATE(9488), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [409616] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12354), 1,
      sym__optional_semi,
    STATE(9489), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [409661] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12356), 1,
      sym__optional_semi,
    STATE(9490), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [409706] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12358), 1,
      sym__optional_semi,
    STATE(9491), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [409751] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12360), 1,
      sym__optional_semi,
    STATE(9492), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [409796] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12362), 1,
      anon_sym_EQ_GT,
    STATE(9493), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [409841] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12364), 1,
      sym__optional_semi,
    STATE(9494), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [409886] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12366), 1,
      anon_sym_EQ_GT,
    STATE(9495), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [409931] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12368), 1,
      sym__optional_semi,
    STATE(9496), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [409976] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12370), 1,
      anon_sym_SEMI,
    STATE(9497), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [410021] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12372), 1,
      anon_sym_EQ_GT,
    STATE(9498), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [410066] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12374), 1,
      anon_sym_SEMI,
    STATE(9499), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [410111] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11078), 1,
      anon_sym_RBRACE,
    STATE(9500), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [410156] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12376), 1,
      sym__optional_semi,
    STATE(9501), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [410201] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12378), 1,
      sym__optional_semi,
    STATE(9502), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [410246] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12380), 1,
      anon_sym_RPAREN,
    STATE(9503), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [410291] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12382), 1,
      sym__optional_semi,
    STATE(9504), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [410336] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12384), 1,
      sym__optional_semi,
    STATE(9505), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [410381] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12386), 1,
      anon_sym_SEMI,
    STATE(9506), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [410426] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12388), 1,
      sym__optional_semi,
    STATE(9507), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [410471] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12390), 1,
      sym__optional_semi,
    STATE(9508), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [410516] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12392), 1,
      sym__optional_semi,
    STATE(9509), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [410561] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12394), 1,
      sym__optional_semi,
    STATE(9510), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [410606] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12396), 1,
      anon_sym_LT,
    STATE(9511), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [410651] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8301), 1,
      anon_sym_SEMI,
    STATE(9512), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [410696] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10089), 1,
      anon_sym_COMMA,
    STATE(9513), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [410741] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12398), 1,
      sym__optional_semi,
    STATE(9514), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [410786] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10770), 1,
      anon_sym_LPAREN,
    STATE(9515), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [410831] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12400), 1,
      sym__optional_semi,
    STATE(9516), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [410876] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12402), 1,
      anon_sym_DOT,
    STATE(9517), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [410921] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12404), 1,
      sym__optional_semi,
    STATE(9518), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [410966] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12406), 1,
      anon_sym_RPAREN,
    STATE(9519), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [411011] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9135), 1,
      anon_sym_RPAREN,
    STATE(9520), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [411056] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12408), 1,
      anon_sym_RBRACK,
    STATE(9521), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [411101] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12410), 1,
      anon_sym_GT,
    STATE(9522), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [411146] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12412), 1,
      anon_sym_GT,
    STATE(9523), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [411191] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12414), 1,
      anon_sym_SEMI,
    STATE(9524), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [411236] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12416), 1,
      anon_sym_RPAREN,
    STATE(9525), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [411281] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12418), 1,
      sym__optional_semi,
    STATE(9526), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [411326] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12420), 1,
      sym__optional_semi,
    STATE(9527), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [411371] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12422), 1,
      sym__optional_semi,
    STATE(9528), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [411416] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12424), 1,
      sym__optional_semi,
    STATE(9529), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [411461] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12426), 1,
      sym__optional_semi,
    STATE(9530), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [411506] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12428), 1,
      sym__optional_semi,
    STATE(9531), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [411551] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12430), 1,
      sym__optional_semi,
    STATE(9532), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [411596] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12432), 1,
      sym__optional_semi,
    STATE(9533), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [411641] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12434), 1,
      anon_sym_EQ_GT,
    STATE(9534), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [411686] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11344), 1,
      anon_sym_in,
    STATE(9535), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [411731] = 12,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    ACTIONS(12436), 1,
      aux_sym_interpolation_format_clause_token1,
    STATE(9536), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [411776] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12438), 1,
      anon_sym_SEMI,
    STATE(9537), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [411821] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12440), 1,
      anon_sym_STAR,
    STATE(9538), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [411866] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12442), 1,
      anon_sym_LBRACE,
    STATE(9539), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [411911] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12444), 1,
      anon_sym_LBRACE,
    STATE(9540), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [411956] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12446), 1,
      sym__optional_semi,
    STATE(9541), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [412001] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12448), 1,
      anon_sym_RPAREN,
    STATE(9542), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [412046] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12450), 1,
      anon_sym_RPAREN,
    STATE(9543), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [412091] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12452), 1,
      anon_sym_EQ_GT,
    STATE(9544), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [412136] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11348), 1,
      anon_sym_in,
    STATE(9545), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [412181] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12454), 1,
      anon_sym_EQ_GT,
    STATE(9546), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [412226] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12456), 1,
      sym__optional_semi,
    STATE(9547), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [412271] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12458), 1,
      anon_sym_SEMI,
    STATE(9548), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [412316] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12460), 1,
      anon_sym_GT,
    STATE(9549), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [412361] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12462), 1,
      anon_sym_EQ_GT,
    STATE(9550), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [412406] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12464), 1,
      sym__optional_semi,
    STATE(9551), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [412451] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12466), 1,
      sym__optional_semi,
    STATE(9552), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [412496] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12468), 1,
      sym__optional_semi,
    STATE(9553), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [412541] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12470), 1,
      sym__optional_semi,
    STATE(9554), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [412586] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12472), 1,
      sym__optional_semi,
    STATE(9555), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [412631] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12474), 1,
      anon_sym_SEMI,
    STATE(9556), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [412676] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12476), 1,
      sym__optional_semi,
    STATE(9557), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [412721] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12478), 1,
      sym__optional_semi,
    STATE(9558), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [412766] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12480), 1,
      sym__optional_semi,
    STATE(9559), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [412811] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10701), 1,
      sym_interpolation_close_brace,
    STATE(9560), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [412856] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12482), 1,
      anon_sym_EQ_GT,
    STATE(9561), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [412901] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12484), 1,
      sym__optional_semi,
    STATE(9562), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [412946] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12486), 1,
      sym__optional_semi,
    STATE(9563), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [412991] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12488), 1,
      sym__optional_semi,
    STATE(9564), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [413036] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12490), 1,
      sym__optional_semi,
    STATE(9565), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [413081] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12492), 1,
      sym__optional_semi,
    STATE(9566), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [413126] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12494), 1,
      sym__optional_semi,
    STATE(9567), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [413171] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12496), 1,
      anon_sym_RPAREN,
    STATE(9568), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [413216] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12498), 1,
      anon_sym_LPAREN,
    STATE(9569), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [413261] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12500), 1,
      anon_sym_GT,
    STATE(9570), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [413306] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12502), 1,
      sym__optional_semi,
    STATE(9571), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [413351] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12504), 1,
      sym__optional_semi,
    STATE(9572), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [413396] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12506), 1,
      anon_sym_EQ_GT,
    STATE(9573), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [413441] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12508), 1,
      anon_sym_EQ_GT,
    STATE(9574), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [413486] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12510), 1,
      anon_sym_LPAREN,
    STATE(9575), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [413531] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11106), 1,
      anon_sym_RBRACE,
    STATE(9576), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [413576] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12512), 1,
      sym__optional_semi,
    STATE(9577), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [413621] = 12,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    ACTIONS(12514), 1,
      aux_sym_preproc_if_token2,
    STATE(9578), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [413666] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12516), 1,
      anon_sym_SEMI,
    STATE(9579), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [413711] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12518), 1,
      anon_sym_EQ_GT,
    STATE(9580), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [413756] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12520), 1,
      sym__optional_semi,
    STATE(9581), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [413801] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12522), 1,
      anon_sym_EQ_GT,
    STATE(9582), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [413846] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12524), 1,
      sym__optional_semi,
    STATE(9583), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [413891] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12526), 1,
      sym__optional_semi,
    STATE(9584), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [413936] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12528), 1,
      sym_raw_string_end,
    STATE(9585), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [413981] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12530), 1,
      sym__optional_semi,
    STATE(9586), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [414026] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12532), 1,
      anon_sym_RPAREN,
    STATE(9587), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [414071] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12534), 1,
      sym__optional_semi,
    STATE(9588), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [414116] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12536), 1,
      anon_sym_COMMA,
    STATE(9589), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [414161] = 12,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    ACTIONS(12538), 1,
      aux_sym_preproc_if_token2,
    STATE(9590), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [414206] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12540), 1,
      sym__optional_semi,
    STATE(9591), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [414251] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12542), 1,
      anon_sym_EQ_GT,
    STATE(9592), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [414296] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12544), 1,
      anon_sym_EQ_GT,
    STATE(9593), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [414341] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12546), 1,
      anon_sym_SEMI,
    STATE(9594), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [414386] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12548), 1,
      sym_integer_literal,
    STATE(9595), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [414431] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12550), 1,
      anon_sym_RPAREN,
    STATE(9596), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [414476] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12552), 1,
      anon_sym_RPAREN,
    STATE(9597), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [414521] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12554), 1,
      sym__optional_semi,
    STATE(9598), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [414566] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12556), 1,
      anon_sym_SEMI,
    STATE(9599), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [414611] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11192), 1,
      anon_sym_RBRACE,
    STATE(9600), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [414656] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12558), 1,
      sym__optional_semi,
    STATE(9601), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [414701] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12560), 1,
      sym__optional_semi,
    STATE(9602), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [414746] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12562), 1,
      sym__optional_semi,
    STATE(9603), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [414791] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12564), 1,
      anon_sym_EQ_GT,
    STATE(9604), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [414836] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12566), 1,
      sym__optional_semi,
    STATE(9605), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [414881] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12568), 1,
      anon_sym_EQ_GT,
    STATE(9606), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [414926] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12570), 1,
      anon_sym_EQ_GT,
    STATE(9607), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [414971] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12572), 1,
      anon_sym_SEMI,
    STATE(9608), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [415016] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12574), 1,
      sym__optional_semi,
    STATE(9609), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [415061] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12576), 1,
      anon_sym_SEMI,
    STATE(9610), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [415106] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12578), 1,
      sym__optional_semi,
    STATE(9611), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [415151] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12580), 1,
      anon_sym_EQ_GT,
    STATE(9612), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [415196] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12582), 1,
      sym__optional_semi,
    STATE(9613), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [415241] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12584), 1,
      anon_sym_RPAREN,
    STATE(9614), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [415286] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12586), 1,
      sym__optional_semi,
    STATE(9615), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [415331] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12588), 1,
      aux_sym_preproc_if_token3,
    STATE(9616), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [415376] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12590), 1,
      aux_sym_preproc_if_token3,
    STATE(9617), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [415421] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12592), 1,
      sym__optional_semi,
    STATE(9618), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [415466] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12594), 1,
      sym__optional_semi,
    STATE(9619), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [415511] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12596), 1,
      sym__optional_semi,
    STATE(9620), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [415556] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12598), 1,
      sym__optional_semi,
    STATE(9621), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [415601] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12600), 1,
      anon_sym_RBRACK,
    STATE(9622), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [415646] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12602), 1,
      anon_sym_SEMI,
    STATE(9623), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [415691] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12604), 1,
      sym__optional_semi,
    STATE(9624), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [415736] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12606), 1,
      anon_sym_EQ_GT,
    STATE(9625), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [415781] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12608), 1,
      sym__optional_semi,
    STATE(9626), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [415826] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12610), 1,
      anon_sym_EQ_GT,
    STATE(9627), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [415871] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12612), 1,
      anon_sym_EQ_GT,
    STATE(9628), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [415916] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12614), 1,
      anon_sym_COMMA,
    STATE(9629), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [415961] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12616), 1,
      anon_sym_EQ_GT,
    STATE(9630), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [416006] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12618), 1,
      anon_sym_EQ_GT,
    STATE(9631), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [416051] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12620), 1,
      anon_sym_EQ_GT,
    STATE(9632), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [416096] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12622), 1,
      anon_sym_LPAREN,
    STATE(9633), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [416141] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12624), 1,
      anon_sym_EQ_GT,
    STATE(9634), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [416186] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12626), 1,
      anon_sym_SEMI,
    STATE(9635), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [416231] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12628), 1,
      anon_sym_EQ_GT,
    STATE(9636), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [416276] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12630), 1,
      anon_sym_EQ_GT,
    STATE(9637), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [416321] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12632), 1,
      anon_sym_EQ_GT,
    STATE(9638), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [416366] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12634), 1,
      sym__optional_semi,
    STATE(9639), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [416411] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12636), 1,
      sym__optional_semi,
    STATE(9640), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [416456] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12638), 1,
      anon_sym_EQ_GT,
    STATE(9641), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [416501] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12640), 1,
      sym__optional_semi,
    STATE(9642), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [416546] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12642), 1,
      anon_sym_LBRACE,
    STATE(9643), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [416591] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12644), 1,
      sym__optional_semi,
    STATE(9644), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [416636] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12646), 1,
      anon_sym_EQ_GT,
    STATE(9645), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [416681] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12648), 1,
      anon_sym_EQ_GT,
    STATE(9646), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [416726] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8950), 1,
      anon_sym_RPAREN,
    STATE(9647), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [416771] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12650), 1,
      anon_sym_EQ_GT,
    STATE(9648), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [416816] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12652), 1,
      anon_sym_EQ_GT,
    STATE(9649), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [416861] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12654), 1,
      sym__optional_semi,
    STATE(9650), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [416906] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12656), 1,
      sym__optional_semi,
    STATE(9651), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [416951] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12658), 1,
      anon_sym_EQ_GT,
    STATE(9652), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [416996] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12660), 1,
      sym__optional_semi,
    STATE(9653), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [417041] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12662), 1,
      sym__optional_semi,
    STATE(9654), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [417086] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12664), 1,
      anon_sym_EQ_GT,
    STATE(9655), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [417131] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12666), 1,
      anon_sym_RBRACK,
    STATE(9656), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [417176] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12668), 1,
      anon_sym_EQ_GT,
    STATE(9657), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [417221] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12670), 1,
      sym__optional_semi,
    STATE(9658), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [417266] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12672), 1,
      anon_sym_STAR,
    STATE(9659), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [417311] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12674), 1,
      anon_sym_EQ_GT,
    STATE(9660), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [417356] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12676), 1,
      anon_sym_SEMI,
    STATE(9661), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [417401] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12678), 1,
      sym__optional_semi,
    STATE(9662), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [417446] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12680), 1,
      sym__optional_semi,
    STATE(9663), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [417491] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12682), 1,
      sym__optional_semi,
    STATE(9664), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [417536] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12684), 1,
      anon_sym_LPAREN,
    STATE(9665), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [417581] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12686), 1,
      anon_sym_LPAREN,
    STATE(9666), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [417626] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12688), 1,
      anon_sym_LPAREN,
    STATE(9667), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [417671] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12690), 1,
      anon_sym_LPAREN,
    STATE(9668), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [417716] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12692), 1,
      anon_sym_LPAREN,
    STATE(9669), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [417761] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12694), 1,
      anon_sym_LPAREN,
    STATE(9670), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [417806] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12696), 1,
      anon_sym_LPAREN,
    STATE(9671), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [417851] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12698), 1,
      anon_sym_EQ_GT,
    STATE(9672), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [417896] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12700), 1,
      sym__optional_semi,
    STATE(9673), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [417941] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12702), 1,
      anon_sym_SEMI,
    STATE(9674), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [417986] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12704), 1,
      anon_sym_LPAREN,
    STATE(9675), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [418031] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12706), 1,
      anon_sym_EQ_GT,
    STATE(9676), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [418076] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12708), 1,
      anon_sym_LBRACE,
    STATE(9677), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [418121] = 12,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    ACTIONS(12710), 1,
      aux_sym_preproc_if_token2,
    STATE(9678), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [418166] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12712), 1,
      anon_sym_EQ_GT,
    STATE(9679), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [418211] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12714), 1,
      sym__optional_semi,
    STATE(9680), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [418256] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12716), 1,
      anon_sym_RPAREN,
    STATE(9681), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [418301] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12718), 1,
      sym__optional_semi,
    STATE(9682), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [418346] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12720), 1,
      sym__optional_semi,
    STATE(9683), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [418391] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12722), 1,
      sym__optional_semi,
    STATE(9684), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [418436] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12724), 1,
      anon_sym_EQ_GT,
    STATE(9685), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [418481] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12726), 1,
      anon_sym_COMMA,
    STATE(9686), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [418526] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12728), 1,
      sym__optional_semi,
    STATE(9687), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [418571] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12730), 1,
      sym__optional_semi,
    STATE(9688), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [418616] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12732), 1,
      sym__optional_semi,
    STATE(9689), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [418661] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12734), 1,
      sym__optional_semi,
    STATE(9690), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [418706] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12736), 1,
      anon_sym_LBRACE,
    STATE(9691), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [418751] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12738), 1,
      anon_sym_EQ_GT,
    STATE(9692), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [418796] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12740), 1,
      anon_sym_EQ_GT,
    STATE(9693), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [418841] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12742), 1,
      sym__optional_semi,
    STATE(9694), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [418886] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12744), 1,
      anon_sym_EQ_GT,
    STATE(9695), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [418931] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12746), 1,
      sym__optional_semi,
    STATE(9696), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [418976] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12748), 1,
      sym__optional_semi,
    STATE(9697), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [419021] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12750), 1,
      anon_sym_EQ_GT,
    STATE(9698), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [419066] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12752), 1,
      sym__optional_semi,
    STATE(9699), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [419111] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12754), 1,
      anon_sym_LT,
    STATE(9700), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [419156] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8307), 1,
      anon_sym_SEMI,
    STATE(9701), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [419201] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12756), 1,
      sym__optional_semi,
    STATE(9702), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [419246] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12758), 1,
      anon_sym_SEMI,
    STATE(9703), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [419291] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8041), 1,
      anon_sym_RBRACE,
    STATE(9704), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [419336] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12760), 1,
      sym__optional_semi,
    STATE(9705), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [419381] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12762), 1,
      anon_sym_EQ_GT,
    STATE(9706), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [419426] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12764), 1,
      anon_sym_EQ_GT,
    STATE(9707), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [419471] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12766), 1,
      sym__optional_semi,
    STATE(9708), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [419516] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12768), 1,
      anon_sym_EQ_GT,
    STATE(9709), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [419561] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12770), 1,
      sym__optional_semi,
    STATE(9710), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [419606] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12772), 1,
      sym__optional_semi,
    STATE(9711), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [419651] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12774), 1,
      sym__optional_semi,
    STATE(9712), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [419696] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12776), 1,
      aux_sym_preproc_if_token3,
    STATE(9713), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [419741] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12778), 1,
      sym__optional_semi,
    STATE(9714), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [419786] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12780), 1,
      anon_sym_GT,
    STATE(9715), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [419831] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12782), 1,
      anon_sym_EQ_GT,
    STATE(9716), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [419876] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12784), 1,
      sym_raw_string_end,
    STATE(9717), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [419921] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11372), 1,
      anon_sym_in,
    STATE(9718), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [419966] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12786), 1,
      anon_sym_EQ_GT,
    STATE(9719), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [420011] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12788), 1,
      anon_sym_EQ_GT,
    STATE(9720), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [420056] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12790), 1,
      sym__optional_semi,
    STATE(9721), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [420101] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11374), 1,
      anon_sym_in,
    STATE(9722), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [420146] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12792), 1,
      sym__optional_semi,
    STATE(9723), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [420191] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12794), 1,
      sym__optional_semi,
    STATE(9724), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [420236] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12796), 1,
      sym__optional_semi,
    STATE(9725), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [420281] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12798), 1,
      sym__optional_semi,
    STATE(9726), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [420326] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12800), 1,
      sym__optional_semi,
    STATE(9727), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [420371] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12802), 1,
      sym__optional_semi,
    STATE(9728), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [420416] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12804), 1,
      sym__optional_semi,
    STATE(9729), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [420461] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12806), 1,
      sym__optional_semi,
    STATE(9730), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [420506] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12808), 1,
      sym__optional_semi,
    STATE(9731), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [420551] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12810), 1,
      anon_sym_SEMI,
    STATE(9732), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [420596] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12812), 1,
      anon_sym_EQ_GT,
    STATE(9733), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [420641] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12814), 1,
      anon_sym_SEMI,
    STATE(9734), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [420686] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12816), 1,
      anon_sym_LPAREN,
    STATE(9735), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [420731] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12818), 1,
      anon_sym_LPAREN,
    STATE(9736), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [420776] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12820), 1,
      anon_sym_LPAREN,
    STATE(9737), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [420821] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12822), 1,
      anon_sym_LPAREN,
    STATE(9738), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [420866] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12824), 1,
      anon_sym_LPAREN,
    STATE(9739), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [420911] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12826), 1,
      anon_sym_LPAREN,
    STATE(9740), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [420956] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12828), 1,
      anon_sym_LPAREN,
    STATE(9741), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [421001] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12830), 1,
      sym_interpolation_start_quote,
    STATE(9742), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [421046] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12832), 1,
      sym__optional_semi,
    STATE(9743), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [421091] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12834), 1,
      sym__optional_semi,
    STATE(9744), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [421136] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12836), 1,
      anon_sym_LPAREN,
    STATE(9745), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [421181] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12838), 1,
      sym__optional_semi,
    STATE(9746), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [421226] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12840), 1,
      sym__optional_semi,
    STATE(9747), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [421271] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12842), 1,
      sym_interpolation_start_quote,
    STATE(9748), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [421316] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12844), 1,
      sym__optional_semi,
    STATE(9749), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [421361] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12846), 1,
      sym_interpolation_start_quote,
    STATE(9750), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [421406] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12848), 1,
      sym_interpolation_start_quote,
    STATE(9751), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [421451] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12850), 1,
      sym__optional_semi,
    STATE(9752), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [421496] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12852), 1,
      sym_raw_string_content,
    STATE(9753), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [421541] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12854), 1,
      anon_sym_RPAREN,
    STATE(9754), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [421586] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(9191), 1,
      anon_sym_RPAREN,
    STATE(9755), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [421631] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12856), 1,
      sym__optional_semi,
    STATE(9756), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [421676] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12858), 1,
      anon_sym_EQ_GT,
    STATE(9757), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [421721] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12860), 1,
      anon_sym_EQ_GT,
    STATE(9758), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [421766] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12862), 1,
      anon_sym_SEMI,
    STATE(9759), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [421811] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12864), 1,
      anon_sym_LT,
    STATE(9760), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [421856] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8309), 1,
      anon_sym_SEMI,
    STATE(9761), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [421901] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12866), 1,
      anon_sym_LPAREN,
    STATE(9762), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [421946] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12868), 1,
      anon_sym_EQ_GT,
    STATE(9763), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [421991] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12870), 1,
      sym__optional_semi,
    STATE(9764), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [422036] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12872), 1,
      anon_sym_EQ_GT,
    STATE(9765), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [422081] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12874), 1,
      sym__optional_semi,
    STATE(9766), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [422126] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12876), 1,
      aux_sym_preproc_if_token3,
    STATE(9767), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [422171] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12878), 1,
      anon_sym_EQ_GT,
    STATE(9768), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [422216] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12880), 1,
      sym__optional_semi,
    STATE(9769), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [422261] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11380), 1,
      anon_sym_in,
    STATE(9770), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [422306] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12882), 1,
      sym_interpolation_start_quote,
    STATE(9771), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [422351] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11382), 1,
      anon_sym_in,
    STATE(9772), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [422396] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12884), 1,
      anon_sym_EQ_GT,
    STATE(9773), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [422441] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12886), 1,
      anon_sym_EQ_GT,
    STATE(9774), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [422486] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12888), 1,
      anon_sym_COMMA,
    STATE(9775), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [422531] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12890), 1,
      anon_sym_SEMI,
    STATE(9776), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [422576] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12892), 1,
      anon_sym_EQ_GT,
    STATE(9777), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [422621] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12894), 1,
      anon_sym_EQ_GT,
    STATE(9778), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [422666] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12896), 1,
      anon_sym_SEMI,
    STATE(9779), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [422711] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12898), 1,
      sym__optional_semi,
    STATE(9780), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [422756] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12900), 1,
      anon_sym_EQ_GT,
    STATE(9781), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [422801] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12902), 1,
      sym_interpolation_start_quote,
    STATE(9782), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [422846] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12904), 1,
      aux_sym_preproc_if_token3,
    STATE(9783), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [422891] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12906), 1,
      anon_sym_LPAREN,
    STATE(9784), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [422936] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12908), 1,
      anon_sym_LPAREN,
    STATE(9785), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [422981] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12910), 1,
      anon_sym_LPAREN,
    STATE(9786), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [423026] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12912), 1,
      anon_sym_LPAREN,
    STATE(9787), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [423071] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12914), 1,
      anon_sym_LBRACE,
    STATE(9788), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [423116] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12916), 1,
      anon_sym_EQ_GT,
    STATE(9789), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [423161] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12918), 1,
      anon_sym_LPAREN,
    STATE(9790), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [423206] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12920), 1,
      anon_sym_LBRACE,
    STATE(9791), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [423251] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12922), 1,
      sym_interpolation_close_brace,
    STATE(9792), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [423296] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12924), 1,
      anon_sym_EQ_GT,
    STATE(9793), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [423341] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12926), 1,
      anon_sym_EQ_GT,
    STATE(9794), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [423386] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12928), 1,
      sym__optional_semi,
    STATE(9795), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [423431] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12930), 1,
      anon_sym_SEMI,
    STATE(9796), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [423476] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12932), 1,
      anon_sym_SEMI,
    STATE(9797), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [423521] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12934), 1,
      sym__optional_semi,
    STATE(9798), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [423566] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12936), 1,
      anon_sym_EQ_GT,
    STATE(9799), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [423611] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12938), 1,
      sym__optional_semi,
    STATE(9800), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [423656] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12940), 1,
      anon_sym_while,
    STATE(9801), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [423701] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12942), 1,
      anon_sym_LT,
    STATE(9802), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [423746] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12944), 1,
      anon_sym_SEMI,
    STATE(9803), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [423791] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11219), 1,
      anon_sym_RBRACE,
    STATE(9804), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [423836] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12946), 1,
      anon_sym_EQ_GT,
    STATE(9805), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [423881] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12948), 1,
      anon_sym_STAR,
    STATE(9806), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [423926] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12950), 1,
      sym__optional_semi,
    STATE(9807), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [423971] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12952), 1,
      sym__optional_semi,
    STATE(9808), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [424016] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12954), 1,
      sym__optional_semi,
    STATE(9809), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [424061] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12956), 1,
      sym__optional_semi,
    STATE(9810), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [424106] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12958), 1,
      anon_sym_RBRACK,
    STATE(9811), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [424151] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12960), 1,
      anon_sym_LPAREN,
    STATE(9812), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [424196] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12962), 1,
      anon_sym_LPAREN,
    STATE(9813), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [424241] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12964), 1,
      anon_sym_GT,
    STATE(9814), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [424286] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12966), 1,
      anon_sym_LPAREN,
    STATE(9815), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [424331] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12968), 1,
      anon_sym_SQUOTE,
    STATE(9816), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [424376] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12970), 1,
      anon_sym_EQ_GT,
    STATE(9817), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [424421] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12972), 1,
      anon_sym_EQ_GT,
    STATE(9818), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [424466] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12974), 1,
      anon_sym_EQ_GT,
    STATE(9819), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [424511] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11264), 1,
      anon_sym_in,
    STATE(9820), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [424556] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12976), 1,
      anon_sym_EQ_GT,
    STATE(9821), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [424601] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12978), 1,
      anon_sym_RBRACE,
    STATE(9822), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [424646] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12980), 1,
      anon_sym_EQ_GT,
    STATE(9823), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [424691] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12982), 1,
      aux_sym_preproc_if_token3,
    STATE(9824), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [424736] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12984), 1,
      anon_sym_LPAREN,
    STATE(9825), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [424781] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12986), 1,
      anon_sym_LT,
    STATE(9826), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [424826] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12988), 1,
      sym__optional_semi,
    STATE(9827), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [424871] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12990), 1,
      anon_sym_GT,
    STATE(9828), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [424916] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12992), 1,
      anon_sym_EQ_GT,
    STATE(9829), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [424961] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12994), 1,
      anon_sym_EQ_GT,
    STATE(9830), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [425006] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12996), 1,
      sym__optional_semi,
    STATE(9831), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [425051] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(12998), 1,
      anon_sym_EQ_GT,
    STATE(9832), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [425096] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13000), 1,
      sym__optional_semi,
    STATE(9833), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [425141] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13002), 1,
      anon_sym_EQ_GT,
    STATE(9834), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [425186] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11398), 1,
      anon_sym_in,
    STATE(9835), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [425231] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13004), 1,
      anon_sym_LBRACE,
    STATE(9836), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [425276] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13006), 1,
      anon_sym_LBRACE,
    STATE(9837), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [425321] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13008), 1,
      anon_sym_EQ_GT,
    STATE(9838), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [425366] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13010), 1,
      anon_sym_EQ_GT,
    STATE(9839), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [425411] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13012), 1,
      anon_sym_COLON,
    STATE(9840), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [425456] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13014), 1,
      anon_sym_EQ_GT,
    STATE(9841), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [425501] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13016), 1,
      sym__optional_semi,
    STATE(9842), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [425546] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13018), 1,
      sym__optional_semi,
    STATE(9843), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [425591] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13020), 1,
      anon_sym_GT,
    STATE(9844), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [425636] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13022), 1,
      anon_sym_EQ_GT,
    STATE(9845), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [425681] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13024), 1,
      anon_sym_LT,
    STATE(9846), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [425726] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13026), 1,
      sym__optional_semi,
    STATE(9847), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [425771] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13028), 1,
      anon_sym_EQ_GT,
    STATE(9848), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [425816] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13030), 1,
      sym__optional_semi,
    STATE(9849), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [425861] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11404), 1,
      anon_sym_LT,
    STATE(9850), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [425906] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(11035), 1,
      anon_sym_RBRACE,
    STATE(9851), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [425951] = 12,
    ACTIONS(9601), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(9603), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(9605), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9607), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(9609), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(9611), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(9613), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(9615), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(9617), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(9619), 1,
      sym_comment,
    ACTIONS(11153), 1,
      aux_sym_preproc_if_token2,
    STATE(9852), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [425996] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13032), 1,
      anon_sym_EQ_GT,
    STATE(9853), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [426041] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13034), 1,
      sym__optional_semi,
    STATE(9854), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [426086] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13036), 1,
      sym__optional_semi,
    STATE(9855), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [426131] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13038), 1,
      anon_sym_EQ_GT,
    STATE(9856), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [426176] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13040), 1,
      sym__optional_semi,
    STATE(9857), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [426221] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13042), 1,
      anon_sym_STAR,
    STATE(9858), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [426266] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(7654), 1,
      anon_sym_RBRACE,
    STATE(9859), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [426311] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13044), 1,
      anon_sym_EQ_GT,
    STATE(9860), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [426356] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(8159), 1,
      anon_sym_RBRACE,
    STATE(9861), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [426401] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13046), 1,
      anon_sym_EQ_GT,
    STATE(9862), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [426446] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13048), 1,
      sym__optional_semi,
    STATE(9863), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [426491] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13050), 1,
      anon_sym_LT,
    STATE(9864), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [426536] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13052), 1,
      sym__optional_semi,
    STATE(9865), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [426581] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13054), 1,
      anon_sym_EQ_GT,
    STATE(9866), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [426626] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13056), 1,
      anon_sym_EQ_GT,
    STATE(9867), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [426671] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13058), 1,
      sym__optional_semi,
    STATE(9868), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [426716] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13060), 1,
      sym__optional_semi,
    STATE(9869), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [426761] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13062), 1,
      anon_sym_EQ_GT,
    STATE(9870), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [426806] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13064), 1,
      sym__optional_semi,
    STATE(9871), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [426851] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13066), 1,
      sym_interpolation_close_brace,
    STATE(9872), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [426896] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13068), 1,
      anon_sym_SEMI,
    STATE(9873), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [426941] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13070), 1,
      sym__optional_semi,
    STATE(9874), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [426986] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13072), 1,
      anon_sym_EQ_GT,
    STATE(9875), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [427031] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13074), 1,
      anon_sym_EQ_GT,
    STATE(9876), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [427076] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13076), 1,
      sym__optional_semi,
    STATE(9877), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [427121] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13078), 1,
      sym__optional_semi,
    STATE(9878), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [427166] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13080), 1,
      anon_sym_EQ_GT,
    STATE(9879), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [427211] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13082), 1,
      anon_sym_SQUOTE,
    STATE(9880), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [427256] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13084), 1,
      sym__optional_semi,
    STATE(9881), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [427301] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13086), 1,
      sym__optional_semi,
    STATE(9882), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [427346] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13088), 1,
      sym__optional_semi,
    STATE(9883), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [427391] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13090), 1,
      anon_sym_EQ_GT,
    STATE(9884), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [427436] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13092), 1,
      anon_sym_EQ_GT,
    STATE(9885), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [427481] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13094), 1,
      anon_sym_GT,
    STATE(9886), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [427526] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13096), 1,
      anon_sym_EQ_GT,
    STATE(9887), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [427571] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13098), 1,
      anon_sym_EQ_GT,
    STATE(9888), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [427616] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13100), 1,
      anon_sym_SEMI,
    STATE(9889), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [427661] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13102), 1,
      anon_sym_EQ_GT,
    STATE(9890), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [427706] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13104), 1,
      sym__optional_semi,
    STATE(9891), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [427751] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13106), 1,
      sym__optional_semi,
    STATE(9892), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [427796] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13108), 1,
      sym__optional_semi,
    STATE(9893), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [427841] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13110), 1,
      sym__optional_semi,
    STATE(9894), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [427886] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13112), 1,
      sym__optional_semi,
    STATE(9895), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [427931] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13114), 1,
      aux_sym_preproc_if_token3,
    STATE(9896), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [427976] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13116), 1,
      sym_raw_string_end,
    STATE(9897), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [428021] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13118), 1,
      anon_sym_EQ_GT,
    STATE(9898), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [428066] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13120), 1,
      anon_sym_SEMI,
    STATE(9899), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [428111] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13122), 1,
      anon_sym_EQ_GT,
    STATE(9900), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [428156] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13124), 1,
      anon_sym_RPAREN,
    STATE(9901), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [428201] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13126), 1,
      aux_sym_preproc_if_token3,
    STATE(9902), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [428246] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13128), 1,
      aux_sym_preproc_if_token3,
    STATE(9903), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [428291] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13130), 1,
      anon_sym_LPAREN,
    STATE(9904), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [428336] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13132), 1,
      anon_sym_EQ_GT,
    STATE(9905), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [428381] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13134), 1,
      anon_sym_STAR,
    STATE(9906), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [428426] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13136), 1,
      sym__optional_semi,
    STATE(9907), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [428471] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13138), 1,
      anon_sym_EQ_GT,
    STATE(9908), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [428516] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13140), 1,
      anon_sym_LT,
    STATE(9909), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [428561] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13142), 1,
      sym__optional_semi,
    STATE(9910), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [428606] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13144), 1,
      sym__optional_semi,
    STATE(9911), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [428651] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13146), 1,
      anon_sym_EQ_GT,
    STATE(9912), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [428696] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13148), 1,
      anon_sym_EQ_GT,
    STATE(9913), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [428741] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13150), 1,
      anon_sym_EQ_GT,
    STATE(9914), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [428786] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13152), 1,
      anon_sym_LPAREN,
    STATE(9915), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [428831] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13154), 1,
      sym__optional_semi,
    STATE(9916), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [428876] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13156), 1,
      anon_sym_EQ_GT,
    STATE(9917), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [428921] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13158), 1,
      anon_sym_EQ_GT,
    STATE(9918), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [428966] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13160), 1,
      anon_sym_EQ_GT,
    STATE(9919), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [429011] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13162), 1,
      anon_sym_EQ_GT,
    STATE(9920), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [429056] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13164), 1,
      anon_sym_GT,
    STATE(9921), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [429101] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13166), 1,
      anon_sym_EQ_GT,
    STATE(9922), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [429146] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13168), 1,
      anon_sym_EQ_GT,
    STATE(9923), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [429191] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13170), 1,
      sym__optional_semi,
    STATE(9924), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [429236] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13172), 1,
      anon_sym_EQ_GT,
    STATE(9925), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [429281] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13174), 1,
      anon_sym_EQ_GT,
    STATE(9926), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [429326] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13176), 1,
      sym__optional_semi,
    STATE(9927), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [429371] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13178), 1,
      sym__optional_semi,
    STATE(9928), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [429416] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13180), 1,
      sym__optional_semi,
    STATE(9929), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [429461] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13182), 1,
      sym__optional_semi,
    STATE(9930), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [429506] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13184), 1,
      sym__optional_semi,
    STATE(9931), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [429551] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13186), 1,
      sym__optional_semi,
    STATE(9932), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [429596] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13188), 1,
      anon_sym_GT,
    STATE(9933), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [429641] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13190), 1,
      anon_sym_LPAREN,
    STATE(9934), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [429686] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13192), 1,
      anon_sym_STAR,
    STATE(9935), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [429731] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13194), 1,
      sym__optional_semi,
    STATE(9936), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [429776] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13196), 1,
      sym__optional_semi,
    STATE(9937), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [429821] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13198), 1,
      anon_sym_EQ_GT,
    STATE(9938), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [429866] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13200), 1,
      sym__optional_semi,
    STATE(9939), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [429911] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13202), 1,
      anon_sym_LPAREN,
    STATE(9940), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [429956] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13204), 1,
      sym__optional_semi,
    STATE(9941), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [430001] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13206), 1,
      sym__optional_semi,
    STATE(9942), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [430046] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13208), 1,
      sym__optional_semi,
    STATE(9943), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [430091] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13210), 1,
      anon_sym_EQ_GT,
    STATE(9944), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [430136] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13212), 1,
      anon_sym_EQ_GT,
    STATE(9945), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [430181] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13214), 1,
      anon_sym_LPAREN,
    STATE(9946), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [430226] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13216), 1,
      anon_sym_STAR,
    STATE(9947), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [430271] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13218), 1,
      sym__optional_semi,
    STATE(9948), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [430316] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13220), 1,
      sym__optional_semi,
    STATE(9949), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [430361] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13222), 1,
      anon_sym_LPAREN,
    STATE(9950), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [430406] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13224), 1,
      anon_sym_SEMI,
    STATE(9951), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [430451] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13226), 1,
      anon_sym_EQ_GT,
    STATE(9952), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [430496] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13228), 1,
      sym__optional_semi,
    STATE(9953), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [430541] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13230), 1,
      anon_sym_STAR,
    STATE(9954), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [430586] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13232), 1,
      sym__optional_semi,
    STATE(9955), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [430631] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13234), 1,
      anon_sym_STAR,
    STATE(9956), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [430676] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13236), 1,
      sym__optional_semi,
    STATE(9957), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [430721] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13238), 1,
      anon_sym_STAR,
    STATE(9958), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [430766] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(10355), 1,
      anon_sym_STAR,
    STATE(9959), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [430811] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13240), 1,
      sym__optional_semi,
    STATE(9960), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [430856] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13242), 1,
      anon_sym_LPAREN,
    STATE(9961), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [430901] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13244), 1,
      anon_sym_LPAREN,
    STATE(9962), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [430946] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13246), 1,
      sym__optional_semi,
    STATE(9963), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [430991] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13248), 1,
      anon_sym_EQ_GT,
    STATE(9964), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [431036] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13250), 1,
      anon_sym_while,
    STATE(9965), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [431081] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13252), 1,
      anon_sym_LPAREN,
    STATE(9966), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [431126] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13254), 1,
      anon_sym_GT,
    STATE(9967), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [431171] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13256), 1,
      anon_sym_EQ_GT,
    STATE(9968), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [431216] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13258), 1,
      anon_sym_EQ_GT,
    STATE(9969), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [431261] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13260), 1,
      anon_sym_EQ_GT,
    STATE(9970), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [431306] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13262), 1,
      anon_sym_LPAREN,
    STATE(9971), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [431351] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13264), 1,
      anon_sym_LPAREN,
    STATE(9972), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [431396] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13266), 1,
      anon_sym_while,
    STATE(9973), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [431441] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13268), 1,
      anon_sym_LPAREN,
    STATE(9974), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [431486] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13270), 1,
      anon_sym_LPAREN,
    STATE(9975), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [431531] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13272), 1,
      anon_sym_LPAREN,
    STATE(9976), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [431576] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13274), 1,
      anon_sym_while,
    STATE(9977), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [431621] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13276), 1,
      anon_sym_LPAREN,
    STATE(9978), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [431666] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13278), 1,
      anon_sym_LPAREN,
    STATE(9979), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [431711] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13280), 1,
      anon_sym_LPAREN,
    STATE(9980), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [431756] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13282), 1,
      sym__optional_semi,
    STATE(9981), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [431801] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13284), 1,
      sym__optional_semi,
    STATE(9982), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [431846] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13286), 1,
      sym__optional_semi,
    STATE(9983), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [431891] = 12,
    ACTIONS(3), 1,
      aux_sym_preproc_region_token1,
    ACTIONS(5), 1,
      aux_sym_preproc_endregion_token1,
    ACTIONS(7), 1,
      aux_sym_preproc_line_token1,
    ACTIONS(9), 1,
      aux_sym_preproc_pragma_token1,
    ACTIONS(11), 1,
      aux_sym_preproc_nullable_token1,
    ACTIONS(13), 1,
      aux_sym_preproc_error_token1,
    ACTIONS(15), 1,
      aux_sym_preproc_warning_token1,
    ACTIONS(17), 1,
      aux_sym_preproc_define_token1,
    ACTIONS(19), 1,
      aux_sym_preproc_undef_token1,
    ACTIONS(21), 1,
      sym_comment,
    ACTIONS(13288), 1,
      sym__optional_semi,
    STATE(9984), 9,
      sym_preproc_region,
      sym_preproc_endregion,
      sym_preproc_line,
      sym_preproc_pragma,
      sym_preproc_nullable,
      sym_preproc_error,
      sym_preproc_warning,
      sym_preproc_define,
      sym_preproc_undef,
  [431936] = 1,
    ACTIONS(13290), 1,
      ts_builtin_sym_end,
  [431940] = 1,
    ACTIONS(13292), 1,
      ts_builtin_sym_end,
  [431944] = 1,
    ACTIONS(13294), 1,
      ts_builtin_sym_end,
  [431948] = 1,
    ACTIONS(13296), 1,
      ts_builtin_sym_end,
  [431952] = 1,
    ACTIONS(13298), 1,
      ts_builtin_sym_end,
  [431956] = 1,
    ACTIONS(13300), 1,
      ts_builtin_sym_end,
  [431960] = 1,
    ACTIONS(13302), 1,
      ts_builtin_sym_end,
  [431964] = 1,
    ACTIONS(13304), 1,
      ts_builtin_sym_end,
  [431968] = 1,
    ACTIONS(13306), 1,
      ts_builtin_sym_end,
  [431972] = 1,
    ACTIONS(13308), 1,
      ts_builtin_sym_end,
  [431976] = 1,
    ACTIONS(13310), 1,
      ts_builtin_sym_end,
  [431980] = 1,
    ACTIONS(13312), 1,
      ts_builtin_sym_end,
  [431984] = 1,
    ACTIONS(13314), 1,
      ts_builtin_sym_end,
  [431988] = 1,
    ACTIONS(13316), 1,
      ts_builtin_sym_end,
  [431992] = 1,
    ACTIONS(13318), 1,
      ts_builtin_sym_end,
  [431996] = 1,
    ACTIONS(13320), 1,
      ts_builtin_sym_end,
  [432000] = 1,
    ACTIONS(13322), 1,
      ts_builtin_sym_end,
};

static const uint32_t ts_small_parse_table_map[] = {
  [SMALL_STATE(4750)] = 0,
  [SMALL_STATE(4751)] = 127,
  [SMALL_STATE(4752)] = 236,
  [SMALL_STATE(4753)] = 381,
  [SMALL_STATE(4754)] = 508,
  [SMALL_STATE(4755)] = 603,
  [SMALL_STATE(4756)] = 730,
  [SMALL_STATE(4757)] = 875,
  [SMALL_STATE(4758)] = 1002,
  [SMALL_STATE(4759)] = 1129,
  [SMALL_STATE(4760)] = 1256,
  [SMALL_STATE(4761)] = 1383,
  [SMALL_STATE(4762)] = 1510,
  [SMALL_STATE(4763)] = 1637,
  [SMALL_STATE(4764)] = 1764,
  [SMALL_STATE(4765)] = 1891,
  [SMALL_STATE(4766)] = 1986,
  [SMALL_STATE(4767)] = 2113,
  [SMALL_STATE(4768)] = 2260,
  [SMALL_STATE(4769)] = 2407,
  [SMALL_STATE(4770)] = 2554,
  [SMALL_STATE(4771)] = 2701,
  [SMALL_STATE(4772)] = 2848,
  [SMALL_STATE(4773)] = 2995,
  [SMALL_STATE(4774)] = 3142,
  [SMALL_STATE(4775)] = 3289,
  [SMALL_STATE(4776)] = 3436,
  [SMALL_STATE(4777)] = 3571,
  [SMALL_STATE(4778)] = 3708,
  [SMALL_STATE(4779)] = 3841,
  [SMALL_STATE(4780)] = 3972,
  [SMALL_STATE(4781)] = 4111,
  [SMALL_STATE(4782)] = 4252,
  [SMALL_STATE(4783)] = 4397,
  [SMALL_STATE(4784)] = 4524,
  [SMALL_STATE(4785)] = 4651,
  [SMALL_STATE(4786)] = 4778,
  [SMALL_STATE(4787)] = 4873,
  [SMALL_STATE(4788)] = 5018,
  [SMALL_STATE(4789)] = 5145,
  [SMALL_STATE(4790)] = 5272,
  [SMALL_STATE(4791)] = 5399,
  [SMALL_STATE(4792)] = 5526,
  [SMALL_STATE(4793)] = 5653,
  [SMALL_STATE(4794)] = 5780,
  [SMALL_STATE(4795)] = 5907,
  [SMALL_STATE(4796)] = 6034,
  [SMALL_STATE(4797)] = 6161,
  [SMALL_STATE(4798)] = 6288,
  [SMALL_STATE(4799)] = 6415,
  [SMALL_STATE(4800)] = 6560,
  [SMALL_STATE(4801)] = 6687,
  [SMALL_STATE(4802)] = 6814,
  [SMALL_STATE(4803)] = 6941,
  [SMALL_STATE(4804)] = 7036,
  [SMALL_STATE(4805)] = 7131,
  [SMALL_STATE(4806)] = 7258,
  [SMALL_STATE(4807)] = 7385,
  [SMALL_STATE(4808)] = 7512,
  [SMALL_STATE(4809)] = 7657,
  [SMALL_STATE(4810)] = 7784,
  [SMALL_STATE(4811)] = 7911,
  [SMALL_STATE(4812)] = 8058,
  [SMALL_STATE(4813)] = 8185,
  [SMALL_STATE(4814)] = 8280,
  [SMALL_STATE(4815)] = 8407,
  [SMALL_STATE(4816)] = 8554,
  [SMALL_STATE(4817)] = 8671,
  [SMALL_STATE(4818)] = 8798,
  [SMALL_STATE(4819)] = 8925,
  [SMALL_STATE(4820)] = 9052,
  [SMALL_STATE(4821)] = 9179,
  [SMALL_STATE(4822)] = 9306,
  [SMALL_STATE(4823)] = 9433,
  [SMALL_STATE(4824)] = 9560,
  [SMALL_STATE(4825)] = 9671,
  [SMALL_STATE(4826)] = 9816,
  [SMALL_STATE(4827)] = 9943,
  [SMALL_STATE(4828)] = 10070,
  [SMALL_STATE(4829)] = 10197,
  [SMALL_STATE(4830)] = 10324,
  [SMALL_STATE(4831)] = 10451,
  [SMALL_STATE(4832)] = 10588,
  [SMALL_STATE(4833)] = 10735,
  [SMALL_STATE(4834)] = 10882,
  [SMALL_STATE(4835)] = 11029,
  [SMALL_STATE(4836)] = 11176,
  [SMALL_STATE(4837)] = 11303,
  [SMALL_STATE(4838)] = 11436,
  [SMALL_STATE(4839)] = 11563,
  [SMALL_STATE(4840)] = 11702,
  [SMALL_STATE(4841)] = 11829,
  [SMALL_STATE(4842)] = 11974,
  [SMALL_STATE(4843)] = 12101,
  [SMALL_STATE(4844)] = 12228,
  [SMALL_STATE(4845)] = 12355,
  [SMALL_STATE(4846)] = 12482,
  [SMALL_STATE(4847)] = 12609,
  [SMALL_STATE(4848)] = 12756,
  [SMALL_STATE(4849)] = 12883,
  [SMALL_STATE(4850)] = 13010,
  [SMALL_STATE(4851)] = 13151,
  [SMALL_STATE(4852)] = 13278,
  [SMALL_STATE(4853)] = 13425,
  [SMALL_STATE(4854)] = 13524,
  [SMALL_STATE(4855)] = 13651,
  [SMALL_STATE(4856)] = 13746,
  [SMALL_STATE(4857)] = 13891,
  [SMALL_STATE(4858)] = 14018,
  [SMALL_STATE(4859)] = 14145,
  [SMALL_STATE(4860)] = 14272,
  [SMALL_STATE(4861)] = 14399,
  [SMALL_STATE(4862)] = 14526,
  [SMALL_STATE(4863)] = 14653,
  [SMALL_STATE(4864)] = 14780,
  [SMALL_STATE(4865)] = 14907,
  [SMALL_STATE(4866)] = 15030,
  [SMALL_STATE(4867)] = 15157,
  [SMALL_STATE(4868)] = 15302,
  [SMALL_STATE(4869)] = 15447,
  [SMALL_STATE(4870)] = 15574,
  [SMALL_STATE(4871)] = 15701,
  [SMALL_STATE(4872)] = 15828,
  [SMALL_STATE(4873)] = 15955,
  [SMALL_STATE(4874)] = 16082,
  [SMALL_STATE(4875)] = 16209,
  [SMALL_STATE(4876)] = 16336,
  [SMALL_STATE(4877)] = 16463,
  [SMALL_STATE(4878)] = 16590,
  [SMALL_STATE(4879)] = 16703,
  [SMALL_STATE(4880)] = 16830,
  [SMALL_STATE(4881)] = 16971,
  [SMALL_STATE(4882)] = 17098,
  [SMALL_STATE(4883)] = 17225,
  [SMALL_STATE(4884)] = 17352,
  [SMALL_STATE(4885)] = 17461,
  [SMALL_STATE(4886)] = 17588,
  [SMALL_STATE(4887)] = 17733,
  [SMALL_STATE(4888)] = 17860,
  [SMALL_STATE(4889)] = 17987,
  [SMALL_STATE(4890)] = 18134,
  [SMALL_STATE(4891)] = 18279,
  [SMALL_STATE(4892)] = 18406,
  [SMALL_STATE(4893)] = 18533,
  [SMALL_STATE(4894)] = 18680,
  [SMALL_STATE(4895)] = 18827,
  [SMALL_STATE(4896)] = 18954,
  [SMALL_STATE(4897)] = 19081,
  [SMALL_STATE(4898)] = 19174,
  [SMALL_STATE(4899)] = 19269,
  [SMALL_STATE(4900)] = 19392,
  [SMALL_STATE(4901)] = 19501,
  [SMALL_STATE(4902)] = 19628,
  [SMALL_STATE(4903)] = 19775,
  [SMALL_STATE(4904)] = 19902,
  [SMALL_STATE(4905)] = 20029,
  [SMALL_STATE(4906)] = 20176,
  [SMALL_STATE(4907)] = 20299,
  [SMALL_STATE(4908)] = 20416,
  [SMALL_STATE(4909)] = 20529,
  [SMALL_STATE(4910)] = 20648,
  [SMALL_STATE(4911)] = 20795,
  [SMALL_STATE(4912)] = 20922,
  [SMALL_STATE(4913)] = 21049,
  [SMALL_STATE(4914)] = 21158,
  [SMALL_STATE(4915)] = 21275,
  [SMALL_STATE(4916)] = 21402,
  [SMALL_STATE(4917)] = 21515,
  [SMALL_STATE(4918)] = 21662,
  [SMALL_STATE(4919)] = 21797,
  [SMALL_STATE(4920)] = 21944,
  [SMALL_STATE(4921)] = 22071,
  [SMALL_STATE(4922)] = 22190,
  [SMALL_STATE(4923)] = 22327,
  [SMALL_STATE(4924)] = 22460,
  [SMALL_STATE(4925)] = 22579,
  [SMALL_STATE(4926)] = 22672,
  [SMALL_STATE(4927)] = 22765,
  [SMALL_STATE(4928)] = 22860,
  [SMALL_STATE(4929)] = 22991,
  [SMALL_STATE(4930)] = 23118,
  [SMALL_STATE(4931)] = 23217,
  [SMALL_STATE(4932)] = 23344,
  [SMALL_STATE(4933)] = 23471,
  [SMALL_STATE(4934)] = 23598,
  [SMALL_STATE(4935)] = 23745,
  [SMALL_STATE(4936)] = 23872,
  [SMALL_STATE(4937)] = 23999,
  [SMALL_STATE(4938)] = 24126,
  [SMALL_STATE(4939)] = 24261,
  [SMALL_STATE(4940)] = 24370,
  [SMALL_STATE(4941)] = 24497,
  [SMALL_STATE(4942)] = 24624,
  [SMALL_STATE(4943)] = 24751,
  [SMALL_STATE(4944)] = 24860,
  [SMALL_STATE(4945)] = 24999,
  [SMALL_STATE(4946)] = 25130,
  [SMALL_STATE(4947)] = 25225,
  [SMALL_STATE(4948)] = 25321,
  [SMALL_STATE(4949)] = 25413,
  [SMALL_STATE(4950)] = 25559,
  [SMALL_STATE(4951)] = 25697,
  [SMALL_STATE(4952)] = 25803,
  [SMALL_STATE(4953)] = 25949,
  [SMALL_STATE(4954)] = 26095,
  [SMALL_STATE(4955)] = 26187,
  [SMALL_STATE(4956)] = 26327,
  [SMALL_STATE(4957)] = 26471,
  [SMALL_STATE(4958)] = 26565,
  [SMALL_STATE(4959)] = 26663,
  [SMALL_STATE(4960)] = 26809,
  [SMALL_STATE(4961)] = 26917,
  [SMALL_STATE(4962)] = 27011,
  [SMALL_STATE(4963)] = 27103,
  [SMALL_STATE(4964)] = 27249,
  [SMALL_STATE(4965)] = 27395,
  [SMALL_STATE(4966)] = 27489,
  [SMALL_STATE(4967)] = 27583,
  [SMALL_STATE(4968)] = 27729,
  [SMALL_STATE(4969)] = 27823,
  [SMALL_STATE(4970)] = 27945,
  [SMALL_STATE(4971)] = 28061,
  [SMALL_STATE(4972)] = 28155,
  [SMALL_STATE(4973)] = 28261,
  [SMALL_STATE(4974)] = 28369,
  [SMALL_STATE(4975)] = 28515,
  [SMALL_STATE(4976)] = 28627,
  [SMALL_STATE(4977)] = 28733,
  [SMALL_STATE(4978)] = 28867,
  [SMALL_STATE(4979)] = 28961,
  [SMALL_STATE(4980)] = 29071,
  [SMALL_STATE(4981)] = 29207,
  [SMALL_STATE(4982)] = 29339,
  [SMALL_STATE(4983)] = 29457,
  [SMALL_STATE(4984)] = 29603,
  [SMALL_STATE(4985)] = 29749,
  [SMALL_STATE(4986)] = 29843,
  [SMALL_STATE(4987)] = 29989,
  [SMALL_STATE(4988)] = 30119,
  [SMALL_STATE(4989)] = 30211,
  [SMALL_STATE(4990)] = 30354,
  [SMALL_STATE(4991)] = 30447,
  [SMALL_STATE(4992)] = 30578,
  [SMALL_STATE(4993)] = 30671,
  [SMALL_STATE(4994)] = 30760,
  [SMALL_STATE(4995)] = 30897,
  [SMALL_STATE(4996)] = 30986,
  [SMALL_STATE(4997)] = 31129,
  [SMALL_STATE(4998)] = 31272,
  [SMALL_STATE(4999)] = 31361,
  [SMALL_STATE(5000)] = 31504,
  [SMALL_STATE(5001)] = 31597,
  [SMALL_STATE(5002)] = 31686,
  [SMALL_STATE(5003)] = 31775,
  [SMALL_STATE(5004)] = 31918,
  [SMALL_STATE(5005)] = 32007,
  [SMALL_STATE(5006)] = 32096,
  [SMALL_STATE(5007)] = 32211,
  [SMALL_STATE(5008)] = 32300,
  [SMALL_STATE(5009)] = 32417,
  [SMALL_STATE(5010)] = 32560,
  [SMALL_STATE(5011)] = 32651,
  [SMALL_STATE(5012)] = 32758,
  [SMALL_STATE(5013)] = 32847,
  [SMALL_STATE(5014)] = 32976,
  [SMALL_STATE(5015)] = 33065,
  [SMALL_STATE(5016)] = 33208,
  [SMALL_STATE(5017)] = 33315,
  [SMALL_STATE(5018)] = 33454,
  [SMALL_STATE(5019)] = 33565,
  [SMALL_STATE(5020)] = 33654,
  [SMALL_STATE(5021)] = 33743,
  [SMALL_STATE(5022)] = 33832,
  [SMALL_STATE(5023)] = 33921,
  [SMALL_STATE(5024)] = 34010,
  [SMALL_STATE(5025)] = 34153,
  [SMALL_STATE(5026)] = 34242,
  [SMALL_STATE(5027)] = 34331,
  [SMALL_STATE(5028)] = 34420,
  [SMALL_STATE(5029)] = 34563,
  [SMALL_STATE(5030)] = 34652,
  [SMALL_STATE(5031)] = 34795,
  [SMALL_STATE(5032)] = 34938,
  [SMALL_STATE(5033)] = 35027,
  [SMALL_STATE(5034)] = 35116,
  [SMALL_STATE(5035)] = 35205,
  [SMALL_STATE(5036)] = 35294,
  [SMALL_STATE(5037)] = 35383,
  [SMALL_STATE(5038)] = 35476,
  [SMALL_STATE(5039)] = 35611,
  [SMALL_STATE(5040)] = 35700,
  [SMALL_STATE(5041)] = 35843,
  [SMALL_STATE(5042)] = 35976,
  [SMALL_STATE(5043)] = 36119,
  [SMALL_STATE(5044)] = 36262,
  [SMALL_STATE(5045)] = 36351,
  [SMALL_STATE(5046)] = 36440,
  [SMALL_STATE(5047)] = 36529,
  [SMALL_STATE(5048)] = 36650,
  [SMALL_STATE(5049)] = 36757,
  [SMALL_STATE(5050)] = 36893,
  [SMALL_STATE(5051)] = 37025,
  [SMALL_STATE(5052)] = 37167,
  [SMALL_STATE(5053)] = 37257,
  [SMALL_STATE(5054)] = 37399,
  [SMALL_STATE(5055)] = 37541,
  [SMALL_STATE(5056)] = 37661,
  [SMALL_STATE(5057)] = 37803,
  [SMALL_STATE(5058)] = 37909,
  [SMALL_STATE(5059)] = 38043,
  [SMALL_STATE(5060)] = 38135,
  [SMALL_STATE(5061)] = 38227,
  [SMALL_STATE(5062)] = 38319,
  [SMALL_STATE(5063)] = 38461,
  [SMALL_STATE(5064)] = 38603,
  [SMALL_STATE(5065)] = 38745,
  [SMALL_STATE(5066)] = 38841,
  [SMALL_STATE(5067)] = 38947,
  [SMALL_STATE(5068)] = 39089,
  [SMALL_STATE(5069)] = 39203,
  [SMALL_STATE(5070)] = 39313,
  [SMALL_STATE(5071)] = 39445,
  [SMALL_STATE(5072)] = 39587,
  [SMALL_STATE(5073)] = 39721,
  [SMALL_STATE(5074)] = 39851,
  [SMALL_STATE(5075)] = 39981,
  [SMALL_STATE(5076)] = 40097,
  [SMALL_STATE(5077)] = 40191,
  [SMALL_STATE(5078)] = 40319,
  [SMALL_STATE(5079)] = 40461,
  [SMALL_STATE(5080)] = 40603,
  [SMALL_STATE(5081)] = 40709,
  [SMALL_STATE(5082)] = 40851,
  [SMALL_STATE(5083)] = 40993,
  [SMALL_STATE(5084)] = 41085,
  [SMALL_STATE(5085)] = 41201,
  [SMALL_STATE(5086)] = 41343,
  [SMALL_STATE(5087)] = 41471,
  [SMALL_STATE(5088)] = 41607,
  [SMALL_STATE(5089)] = 41743,
  [SMALL_STATE(5090)] = 41881,
  [SMALL_STATE(5091)] = 42023,
  [SMALL_STATE(5092)] = 42161,
  [SMALL_STATE(5093)] = 42253,
  [SMALL_STATE(5094)] = 42395,
  [SMALL_STATE(5095)] = 42537,
  [SMALL_STATE(5096)] = 42679,
  [SMALL_STATE(5097)] = 42821,
  [SMALL_STATE(5098)] = 42927,
  [SMALL_STATE(5099)] = 43069,
  [SMALL_STATE(5100)] = 43211,
  [SMALL_STATE(5101)] = 43353,
  [SMALL_STATE(5102)] = 43495,
  [SMALL_STATE(5103)] = 43601,
  [SMALL_STATE(5104)] = 43707,
  [SMALL_STATE(5105)] = 43849,
  [SMALL_STATE(5106)] = 43991,
  [SMALL_STATE(5107)] = 44133,
  [SMALL_STATE(5108)] = 44225,
  [SMALL_STATE(5109)] = 44367,
  [SMALL_STATE(5110)] = 44477,
  [SMALL_STATE(5111)] = 44597,
  [SMALL_STATE(5112)] = 44711,
  [SMALL_STATE(5113)] = 44821,
  [SMALL_STATE(5114)] = 44953,
  [SMALL_STATE(5115)] = 45087,
  [SMALL_STATE(5116)] = 45217,
  [SMALL_STATE(5117)] = 45359,
  [SMALL_STATE(5118)] = 45475,
  [SMALL_STATE(5119)] = 45603,
  [SMALL_STATE(5120)] = 45695,
  [SMALL_STATE(5121)] = 45815,
  [SMALL_STATE(5122)] = 45953,
  [SMALL_STATE(5123)] = 46095,
  [SMALL_STATE(5124)] = 46237,
  [SMALL_STATE(5125)] = 46379,
  [SMALL_STATE(5126)] = 46471,
  [SMALL_STATE(5127)] = 46613,
  [SMALL_STATE(5128)] = 46755,
  [SMALL_STATE(5129)] = 46843,
  [SMALL_STATE(5130)] = 46985,
  [SMALL_STATE(5131)] = 47127,
  [SMALL_STATE(5132)] = 47269,
  [SMALL_STATE(5133)] = 47411,
  [SMALL_STATE(5134)] = 47553,
  [SMALL_STATE(5135)] = 47673,
  [SMALL_STATE(5136)] = 47815,
  [SMALL_STATE(5137)] = 47929,
  [SMALL_STATE(5138)] = 48071,
  [SMALL_STATE(5139)] = 48161,
  [SMALL_STATE(5140)] = 48253,
  [SMALL_STATE(5141)] = 48395,
  [SMALL_STATE(5142)] = 48490,
  [SMALL_STATE(5143)] = 48631,
  [SMALL_STATE(5144)] = 48772,
  [SMALL_STATE(5145)] = 48885,
  [SMALL_STATE(5146)] = 48994,
  [SMALL_STATE(5147)] = 49125,
  [SMALL_STATE(5148)] = 49214,
  [SMALL_STATE(5149)] = 49355,
  [SMALL_STATE(5150)] = 49460,
  [SMALL_STATE(5151)] = 49601,
  [SMALL_STATE(5152)] = 49706,
  [SMALL_STATE(5153)] = 49839,
  [SMALL_STATE(5154)] = 49944,
  [SMALL_STATE(5155)] = 50073,
  [SMALL_STATE(5156)] = 50178,
  [SMALL_STATE(5157)] = 50281,
  [SMALL_STATE(5158)] = 50396,
  [SMALL_STATE(5159)] = 50501,
  [SMALL_STATE(5160)] = 50628,
  [SMALL_STATE(5161)] = 50737,
  [SMALL_STATE(5162)] = 50878,
  [SMALL_STATE(5163)] = 51019,
  [SMALL_STATE(5164)] = 51124,
  [SMALL_STATE(5165)] = 51265,
  [SMALL_STATE(5166)] = 51368,
  [SMALL_STATE(5167)] = 51483,
  [SMALL_STATE(5168)] = 51570,
  [SMALL_STATE(5169)] = 51705,
  [SMALL_STATE(5170)] = 51846,
  [SMALL_STATE(5171)] = 51987,
  [SMALL_STATE(5172)] = 52102,
  [SMALL_STATE(5173)] = 52243,
  [SMALL_STATE(5174)] = 52330,
  [SMALL_STATE(5175)] = 52449,
  [SMALL_STATE(5176)] = 52564,
  [SMALL_STATE(5177)] = 52677,
  [SMALL_STATE(5178)] = 52772,
  [SMALL_STATE(5179)] = 52901,
  [SMALL_STATE(5180)] = 53006,
  [SMALL_STATE(5181)] = 53141,
  [SMALL_STATE(5182)] = 53282,
  [SMALL_STATE(5183)] = 53423,
  [SMALL_STATE(5184)] = 53532,
  [SMALL_STATE(5185)] = 53625,
  [SMALL_STATE(5186)] = 53766,
  [SMALL_STATE(5187)] = 53907,
  [SMALL_STATE(5188)] = 54022,
  [SMALL_STATE(5189)] = 54163,
  [SMALL_STATE(5190)] = 54250,
  [SMALL_STATE(5191)] = 54391,
  [SMALL_STATE(5192)] = 54510,
  [SMALL_STATE(5193)] = 54601,
  [SMALL_STATE(5194)] = 54692,
  [SMALL_STATE(5195)] = 54783,
  [SMALL_STATE(5196)] = 54872,
  [SMALL_STATE(5197)] = 54963,
  [SMALL_STATE(5198)] = 55100,
  [SMALL_STATE(5199)] = 55241,
  [SMALL_STATE(5200)] = 55382,
  [SMALL_STATE(5201)] = 55469,
  [SMALL_STATE(5202)] = 55600,
  [SMALL_STATE(5203)] = 55715,
  [SMALL_STATE(5204)] = 55806,
  [SMALL_STATE(5205)] = 55947,
  [SMALL_STATE(5206)] = 56060,
  [SMALL_STATE(5207)] = 56191,
  [SMALL_STATE(5208)] = 56332,
  [SMALL_STATE(5209)] = 56465,
  [SMALL_STATE(5210)] = 56606,
  [SMALL_STATE(5211)] = 56709,
  [SMALL_STATE(5212)] = 56838,
  [SMALL_STATE(5213)] = 56979,
  [SMALL_STATE(5214)] = 57120,
  [SMALL_STATE(5215)] = 57253,
  [SMALL_STATE(5216)] = 57368,
  [SMALL_STATE(5217)] = 57509,
  [SMALL_STATE(5218)] = 57650,
  [SMALL_STATE(5219)] = 57791,
  [SMALL_STATE(5220)] = 57882,
  [SMALL_STATE(5221)] = 58009,
  [SMALL_STATE(5222)] = 58100,
  [SMALL_STATE(5223)] = 58241,
  [SMALL_STATE(5224)] = 58356,
  [SMALL_STATE(5225)] = 58497,
  [SMALL_STATE(5226)] = 58632,
  [SMALL_STATE(5227)] = 58773,
  [SMALL_STATE(5228)] = 58914,
  [SMALL_STATE(5229)] = 59019,
  [SMALL_STATE(5230)] = 59160,
  [SMALL_STATE(5231)] = 59301,
  [SMALL_STATE(5232)] = 59420,
  [SMALL_STATE(5233)] = 59557,
  [SMALL_STATE(5234)] = 59698,
  [SMALL_STATE(5235)] = 59825,
  [SMALL_STATE(5236)] = 59966,
  [SMALL_STATE(5237)] = 60107,
  [SMALL_STATE(5238)] = 60248,
  [SMALL_STATE(5239)] = 60363,
  [SMALL_STATE(5240)] = 60504,
  [SMALL_STATE(5241)] = 60591,
  [SMALL_STATE(5242)] = 60732,
  [SMALL_STATE(5243)] = 60869,
  [SMALL_STATE(5244)] = 60955,
  [SMALL_STATE(5245)] = 61101,
  [SMALL_STATE(5246)] = 61241,
  [SMALL_STATE(5247)] = 61381,
  [SMALL_STATE(5248)] = 61489,
  [SMALL_STATE(5249)] = 61623,
  [SMALL_STATE(5250)] = 61763,
  [SMALL_STATE(5251)] = 61849,
  [SMALL_STATE(5252)] = 61939,
  [SMALL_STATE(5253)] = 62075,
  [SMALL_STATE(5254)] = 62161,
  [SMALL_STATE(5255)] = 62247,
  [SMALL_STATE(5256)] = 62339,
  [SMALL_STATE(5257)] = 62479,
  [SMALL_STATE(5258)] = 62619,
  [SMALL_STATE(5259)] = 62707,
  [SMALL_STATE(5260)] = 62793,
  [SMALL_STATE(5261)] = 62911,
  [SMALL_STATE(5262)] = 63057,
  [SMALL_STATE(5263)] = 63147,
  [SMALL_STATE(5264)] = 63287,
  [SMALL_STATE(5265)] = 63377,
  [SMALL_STATE(5266)] = 63489,
  [SMALL_STATE(5267)] = 63603,
  [SMALL_STATE(5268)] = 63743,
  [SMALL_STATE(5269)] = 63829,
  [SMALL_STATE(5270)] = 63933,
  [SMALL_STATE(5271)] = 64027,
  [SMALL_STATE(5272)] = 64141,
  [SMALL_STATE(5273)] = 64227,
  [SMALL_STATE(5274)] = 64367,
  [SMALL_STATE(5275)] = 64481,
  [SMALL_STATE(5276)] = 64621,
  [SMALL_STATE(5277)] = 64761,
  [SMALL_STATE(5278)] = 64907,
  [SMALL_STATE(5279)] = 64993,
  [SMALL_STATE(5280)] = 65101,
  [SMALL_STATE(5281)] = 65213,
  [SMALL_STATE(5282)] = 65353,
  [SMALL_STATE(5283)] = 65493,
  [SMALL_STATE(5284)] = 65607,
  [SMALL_STATE(5285)] = 65747,
  [SMALL_STATE(5286)] = 65887,
  [SMALL_STATE(5287)] = 65973,
  [SMALL_STATE(5288)] = 66113,
  [SMALL_STATE(5289)] = 66231,
  [SMALL_STATE(5290)] = 66371,
  [SMALL_STATE(5291)] = 66457,
  [SMALL_STATE(5292)] = 66597,
  [SMALL_STATE(5293)] = 66737,
  [SMALL_STATE(5294)] = 66877,
  [SMALL_STATE(5295)] = 67017,
  [SMALL_STATE(5296)] = 67109,
  [SMALL_STATE(5297)] = 67221,
  [SMALL_STATE(5298)] = 67361,
  [SMALL_STATE(5299)] = 67451,
  [SMALL_STATE(5300)] = 67569,
  [SMALL_STATE(5301)] = 67677,
  [SMALL_STATE(5302)] = 67817,
  [SMALL_STATE(5303)] = 67905,
  [SMALL_STATE(5304)] = 68045,
  [SMALL_STATE(5305)] = 68185,
  [SMALL_STATE(5306)] = 68333,
  [SMALL_STATE(5307)] = 68473,
  [SMALL_STATE(5308)] = 68613,
  [SMALL_STATE(5309)] = 68759,
  [SMALL_STATE(5310)] = 68889,
  [SMALL_STATE(5311)] = 68993,
  [SMALL_STATE(5312)] = 69125,
  [SMALL_STATE(5313)] = 69253,
  [SMALL_STATE(5314)] = 69383,
  [SMALL_STATE(5315)] = 69515,
  [SMALL_STATE(5316)] = 69655,
  [SMALL_STATE(5317)] = 69783,
  [SMALL_STATE(5318)] = 69923,
  [SMALL_STATE(5319)] = 70049,
  [SMALL_STATE(5320)] = 70189,
  [SMALL_STATE(5321)] = 70329,
  [SMALL_STATE(5322)] = 70421,
  [SMALL_STATE(5323)] = 70555,
  [SMALL_STATE(5324)] = 70695,
  [SMALL_STATE(5325)] = 70813,
  [SMALL_STATE(5326)] = 70899,
  [SMALL_STATE(5327)] = 71033,
  [SMALL_STATE(5328)] = 71169,
  [SMALL_STATE(5329)] = 71309,
  [SMALL_STATE(5330)] = 71449,
  [SMALL_STATE(5331)] = 71589,
  [SMALL_STATE(5332)] = 71719,
  [SMALL_STATE(5333)] = 71859,
  [SMALL_STATE(5334)] = 71999,
  [SMALL_STATE(5335)] = 72085,
  [SMALL_STATE(5336)] = 72171,
  [SMALL_STATE(5337)] = 72257,
  [SMALL_STATE(5338)] = 72361,
  [SMALL_STATE(5339)] = 72447,
  [SMALL_STATE(5340)] = 72533,
  [SMALL_STATE(5341)] = 72673,
  [SMALL_STATE(5342)] = 72759,
  [SMALL_STATE(5343)] = 72845,
  [SMALL_STATE(5344)] = 72933,
  [SMALL_STATE(5345)] = 73073,
  [SMALL_STATE(5346)] = 73159,
  [SMALL_STATE(5347)] = 73251,
  [SMALL_STATE(5348)] = 73355,
  [SMALL_STATE(5349)] = 73443,
  [SMALL_STATE(5350)] = 73529,
  [SMALL_STATE(5351)] = 73669,
  [SMALL_STATE(5352)] = 73781,
  [SMALL_STATE(5353)] = 73869,
  [SMALL_STATE(5354)] = 73955,
  [SMALL_STATE(5355)] = 74041,
  [SMALL_STATE(5356)] = 74181,
  [SMALL_STATE(5357)] = 74285,
  [SMALL_STATE(5358)] = 74371,
  [SMALL_STATE(5359)] = 74507,
  [SMALL_STATE(5360)] = 74593,
  [SMALL_STATE(5361)] = 74679,
  [SMALL_STATE(5362)] = 74765,
  [SMALL_STATE(5363)] = 74911,
  [SMALL_STATE(5364)] = 75025,
  [SMALL_STATE(5365)] = 75129,
  [SMALL_STATE(5366)] = 75223,
  [SMALL_STATE(5367)] = 75311,
  [SMALL_STATE(5368)] = 75399,
  [SMALL_STATE(5369)] = 75545,
  [SMALL_STATE(5370)] = 75685,
  [SMALL_STATE(5371)] = 75825,
  [SMALL_STATE(5372)] = 75913,
  [SMALL_STATE(5373)] = 76053,
  [SMALL_STATE(5374)] = 76157,
  [SMALL_STATE(5375)] = 76261,
  [SMALL_STATE(5376)] = 76373,
  [SMALL_STATE(5377)] = 76481,
  [SMALL_STATE(5378)] = 76567,
  [SMALL_STATE(5379)] = 76707,
  [SMALL_STATE(5380)] = 76795,
  [SMALL_STATE(5381)] = 76935,
  [SMALL_STATE(5382)] = 77075,
  [SMALL_STATE(5383)] = 77211,
  [SMALL_STATE(5384)] = 77297,
  [SMALL_STATE(5385)] = 77383,
  [SMALL_STATE(5386)] = 77473,
  [SMALL_STATE(5387)] = 77603,
  [SMALL_STATE(5388)] = 77693,
  [SMALL_STATE(5389)] = 77783,
  [SMALL_STATE(5390)] = 77873,
  [SMALL_STATE(5391)] = 77963,
  [SMALL_STATE(5392)] = 78051,
  [SMALL_STATE(5393)] = 78141,
  [SMALL_STATE(5394)] = 78269,
  [SMALL_STATE(5395)] = 78395,
  [SMALL_STATE(5396)] = 78499,
  [SMALL_STATE(5397)] = 78639,
  [SMALL_STATE(5398)] = 78779,
  [SMALL_STATE(5399)] = 78905,
  [SMALL_STATE(5400)] = 79037,
  [SMALL_STATE(5401)] = 79183,
  [SMALL_STATE(5402)] = 79311,
  [SMALL_STATE(5403)] = 79401,
  [SMALL_STATE(5404)] = 79541,
  [SMALL_STATE(5405)] = 79673,
  [SMALL_STATE(5406)] = 79813,
  [SMALL_STATE(5407)] = 79927,
  [SMALL_STATE(5408)] = 80031,
  [SMALL_STATE(5409)] = 80117,
  [SMALL_STATE(5410)] = 80207,
  [SMALL_STATE(5411)] = 80347,
  [SMALL_STATE(5412)] = 80473,
  [SMALL_STATE(5413)] = 80607,
  [SMALL_STATE(5414)] = 80747,
  [SMALL_STATE(5415)] = 80887,
  [SMALL_STATE(5416)] = 81014,
  [SMALL_STATE(5417)] = 81153,
  [SMALL_STATE(5418)] = 81270,
  [SMALL_STATE(5419)] = 81381,
  [SMALL_STATE(5420)] = 81510,
  [SMALL_STATE(5421)] = 81641,
  [SMALL_STATE(5422)] = 81768,
  [SMALL_STATE(5423)] = 81881,
  [SMALL_STATE(5424)] = 82006,
  [SMALL_STATE(5425)] = 82139,
  [SMALL_STATE(5426)] = 82274,
  [SMALL_STATE(5427)] = 82413,
  [SMALL_STATE(5428)] = 82498,
  [SMALL_STATE(5429)] = 82583,
  [SMALL_STATE(5430)] = 82668,
  [SMALL_STATE(5431)] = 82753,
  [SMALL_STATE(5432)] = 82838,
  [SMALL_STATE(5433)] = 82923,
  [SMALL_STATE(5434)] = 83008,
  [SMALL_STATE(5435)] = 83109,
  [SMALL_STATE(5436)] = 83194,
  [SMALL_STATE(5437)] = 83279,
  [SMALL_STATE(5438)] = 83364,
  [SMALL_STATE(5439)] = 83449,
  [SMALL_STATE(5440)] = 83534,
  [SMALL_STATE(5441)] = 83673,
  [SMALL_STATE(5442)] = 83802,
  [SMALL_STATE(5443)] = 83933,
  [SMALL_STATE(5444)] = 84060,
  [SMALL_STATE(5445)] = 84185,
  [SMALL_STATE(5446)] = 84288,
  [SMALL_STATE(5447)] = 84421,
  [SMALL_STATE(5448)] = 84556,
  [SMALL_STATE(5449)] = 84695,
  [SMALL_STATE(5450)] = 84834,
  [SMALL_STATE(5451)] = 84973,
  [SMALL_STATE(5452)] = 85112,
  [SMALL_STATE(5453)] = 85251,
  [SMALL_STATE(5454)] = 85344,
  [SMALL_STATE(5455)] = 85483,
  [SMALL_STATE(5456)] = 85622,
  [SMALL_STATE(5457)] = 85761,
  [SMALL_STATE(5458)] = 85900,
  [SMALL_STATE(5459)] = 86039,
  [SMALL_STATE(5460)] = 86168,
  [SMALL_STATE(5461)] = 86299,
  [SMALL_STATE(5462)] = 86426,
  [SMALL_STATE(5463)] = 86551,
  [SMALL_STATE(5464)] = 86684,
  [SMALL_STATE(5465)] = 86819,
  [SMALL_STATE(5466)] = 86958,
  [SMALL_STATE(5467)] = 87099,
  [SMALL_STATE(5468)] = 87184,
  [SMALL_STATE(5469)] = 87285,
  [SMALL_STATE(5470)] = 87372,
  [SMALL_STATE(5471)] = 87459,
  [SMALL_STATE(5472)] = 87604,
  [SMALL_STATE(5473)] = 87693,
  [SMALL_STATE(5474)] = 87782,
  [SMALL_STATE(5475)] = 87921,
  [SMALL_STATE(5476)] = 88038,
  [SMALL_STATE(5477)] = 88149,
  [SMALL_STATE(5478)] = 88262,
  [SMALL_STATE(5479)] = 88363,
  [SMALL_STATE(5480)] = 88448,
  [SMALL_STATE(5481)] = 88565,
  [SMALL_STATE(5482)] = 88676,
  [SMALL_STATE(5483)] = 88805,
  [SMALL_STATE(5484)] = 88936,
  [SMALL_STATE(5485)] = 89063,
  [SMALL_STATE(5486)] = 89176,
  [SMALL_STATE(5487)] = 89301,
  [SMALL_STATE(5488)] = 89434,
  [SMALL_STATE(5489)] = 89569,
  [SMALL_STATE(5490)] = 89708,
  [SMALL_STATE(5491)] = 89847,
  [SMALL_STATE(5492)] = 89950,
  [SMALL_STATE(5493)] = 90089,
  [SMALL_STATE(5494)] = 90228,
  [SMALL_STATE(5495)] = 90367,
  [SMALL_STATE(5496)] = 90506,
  [SMALL_STATE(5497)] = 90645,
  [SMALL_STATE(5498)] = 90784,
  [SMALL_STATE(5499)] = 90923,
  [SMALL_STATE(5500)] = 91062,
  [SMALL_STATE(5501)] = 91201,
  [SMALL_STATE(5502)] = 91304,
  [SMALL_STATE(5503)] = 91395,
  [SMALL_STATE(5504)] = 91480,
  [SMALL_STATE(5505)] = 91567,
  [SMALL_STATE(5506)] = 91684,
  [SMALL_STATE(5507)] = 91795,
  [SMALL_STATE(5508)] = 91908,
  [SMALL_STATE(5509)] = 92011,
  [SMALL_STATE(5510)] = 92096,
  [SMALL_STATE(5511)] = 92213,
  [SMALL_STATE(5512)] = 92324,
  [SMALL_STATE(5513)] = 92431,
  [SMALL_STATE(5514)] = 92560,
  [SMALL_STATE(5515)] = 92691,
  [SMALL_STATE(5516)] = 92818,
  [SMALL_STATE(5517)] = 92931,
  [SMALL_STATE(5518)] = 93056,
  [SMALL_STATE(5519)] = 93159,
  [SMALL_STATE(5520)] = 93292,
  [SMALL_STATE(5521)] = 93427,
  [SMALL_STATE(5522)] = 93566,
  [SMALL_STATE(5523)] = 93705,
  [SMALL_STATE(5524)] = 93844,
  [SMALL_STATE(5525)] = 93983,
  [SMALL_STATE(5526)] = 94122,
  [SMALL_STATE(5527)] = 94261,
  [SMALL_STATE(5528)] = 94400,
  [SMALL_STATE(5529)] = 94539,
  [SMALL_STATE(5530)] = 94624,
  [SMALL_STATE(5531)] = 94711,
  [SMALL_STATE(5532)] = 94796,
  [SMALL_STATE(5533)] = 94913,
  [SMALL_STATE(5534)] = 95024,
  [SMALL_STATE(5535)] = 95137,
  [SMALL_STATE(5536)] = 95240,
  [SMALL_STATE(5537)] = 95325,
  [SMALL_STATE(5538)] = 95410,
  [SMALL_STATE(5539)] = 95495,
  [SMALL_STATE(5540)] = 95580,
  [SMALL_STATE(5541)] = 95665,
  [SMALL_STATE(5542)] = 95750,
  [SMALL_STATE(5543)] = 95835,
  [SMALL_STATE(5544)] = 95920,
  [SMALL_STATE(5545)] = 96005,
  [SMALL_STATE(5546)] = 96090,
  [SMALL_STATE(5547)] = 96175,
  [SMALL_STATE(5548)] = 96260,
  [SMALL_STATE(5549)] = 96345,
  [SMALL_STATE(5550)] = 96430,
  [SMALL_STATE(5551)] = 96515,
  [SMALL_STATE(5552)] = 96600,
  [SMALL_STATE(5553)] = 96685,
  [SMALL_STATE(5554)] = 96802,
  [SMALL_STATE(5555)] = 96913,
  [SMALL_STATE(5556)] = 97026,
  [SMALL_STATE(5557)] = 97129,
  [SMALL_STATE(5558)] = 97214,
  [SMALL_STATE(5559)] = 97299,
  [SMALL_STATE(5560)] = 97384,
  [SMALL_STATE(5561)] = 97523,
  [SMALL_STATE(5562)] = 97608,
  [SMALL_STATE(5563)] = 97693,
  [SMALL_STATE(5564)] = 97778,
  [SMALL_STATE(5565)] = 97863,
  [SMALL_STATE(5566)] = 97948,
  [SMALL_STATE(5567)] = 98033,
  [SMALL_STATE(5568)] = 98118,
  [SMALL_STATE(5569)] = 98203,
  [SMALL_STATE(5570)] = 98288,
  [SMALL_STATE(5571)] = 98373,
  [SMALL_STATE(5572)] = 98458,
  [SMALL_STATE(5573)] = 98543,
  [SMALL_STATE(5574)] = 98628,
  [SMALL_STATE(5575)] = 98713,
  [SMALL_STATE(5576)] = 98798,
  [SMALL_STATE(5577)] = 98883,
  [SMALL_STATE(5578)] = 98968,
  [SMALL_STATE(5579)] = 99053,
  [SMALL_STATE(5580)] = 99138,
  [SMALL_STATE(5581)] = 99223,
  [SMALL_STATE(5582)] = 99312,
  [SMALL_STATE(5583)] = 99397,
  [SMALL_STATE(5584)] = 99482,
  [SMALL_STATE(5585)] = 99567,
  [SMALL_STATE(5586)] = 99652,
  [SMALL_STATE(5587)] = 99737,
  [SMALL_STATE(5588)] = 99822,
  [SMALL_STATE(5589)] = 99907,
  [SMALL_STATE(5590)] = 99992,
  [SMALL_STATE(5591)] = 100093,
  [SMALL_STATE(5592)] = 100178,
  [SMALL_STATE(5593)] = 100295,
  [SMALL_STATE(5594)] = 100406,
  [SMALL_STATE(5595)] = 100513,
  [SMALL_STATE(5596)] = 100642,
  [SMALL_STATE(5597)] = 100773,
  [SMALL_STATE(5598)] = 100900,
  [SMALL_STATE(5599)] = 101013,
  [SMALL_STATE(5600)] = 101138,
  [SMALL_STATE(5601)] = 101277,
  [SMALL_STATE(5602)] = 101380,
  [SMALL_STATE(5603)] = 101513,
  [SMALL_STATE(5604)] = 101648,
  [SMALL_STATE(5605)] = 101787,
  [SMALL_STATE(5606)] = 101872,
  [SMALL_STATE(5607)] = 102011,
  [SMALL_STATE(5608)] = 102096,
  [SMALL_STATE(5609)] = 102199,
  [SMALL_STATE(5610)] = 102338,
  [SMALL_STATE(5611)] = 102477,
  [SMALL_STATE(5612)] = 102616,
  [SMALL_STATE(5613)] = 102755,
  [SMALL_STATE(5614)] = 102844,
  [SMALL_STATE(5615)] = 102933,
  [SMALL_STATE(5616)] = 103018,
  [SMALL_STATE(5617)] = 103105,
  [SMALL_STATE(5618)] = 103194,
  [SMALL_STATE(5619)] = 103279,
  [SMALL_STATE(5620)] = 103418,
  [SMALL_STATE(5621)] = 103557,
  [SMALL_STATE(5622)] = 103660,
  [SMALL_STATE(5623)] = 103799,
  [SMALL_STATE(5624)] = 103884,
  [SMALL_STATE(5625)] = 104023,
  [SMALL_STATE(5626)] = 104112,
  [SMALL_STATE(5627)] = 104201,
  [SMALL_STATE(5628)] = 104340,
  [SMALL_STATE(5629)] = 104479,
  [SMALL_STATE(5630)] = 104564,
  [SMALL_STATE(5631)] = 104703,
  [SMALL_STATE(5632)] = 104788,
  [SMALL_STATE(5633)] = 104873,
  [SMALL_STATE(5634)] = 105012,
  [SMALL_STATE(5635)] = 105097,
  [SMALL_STATE(5636)] = 105182,
  [SMALL_STATE(5637)] = 105289,
  [SMALL_STATE(5638)] = 105428,
  [SMALL_STATE(5639)] = 105567,
  [SMALL_STATE(5640)] = 105652,
  [SMALL_STATE(5641)] = 105791,
  [SMALL_STATE(5642)] = 105930,
  [SMALL_STATE(5643)] = 106069,
  [SMALL_STATE(5644)] = 106208,
  [SMALL_STATE(5645)] = 106347,
  [SMALL_STATE(5646)] = 106486,
  [SMALL_STATE(5647)] = 106625,
  [SMALL_STATE(5648)] = 106764,
  [SMALL_STATE(5649)] = 106903,
  [SMALL_STATE(5650)] = 107042,
  [SMALL_STATE(5651)] = 107129,
  [SMALL_STATE(5652)] = 107214,
  [SMALL_STATE(5653)] = 107353,
  [SMALL_STATE(5654)] = 107456,
  [SMALL_STATE(5655)] = 107595,
  [SMALL_STATE(5656)] = 107702,
  [SMALL_STATE(5657)] = 107841,
  [SMALL_STATE(5658)] = 107944,
  [SMALL_STATE(5659)] = 108083,
  [SMALL_STATE(5660)] = 108212,
  [SMALL_STATE(5661)] = 108343,
  [SMALL_STATE(5662)] = 108468,
  [SMALL_STATE(5663)] = 108601,
  [SMALL_STATE(5664)] = 108736,
  [SMALL_STATE(5665)] = 108875,
  [SMALL_STATE(5666)] = 109014,
  [SMALL_STATE(5667)] = 109153,
  [SMALL_STATE(5668)] = 109292,
  [SMALL_STATE(5669)] = 109431,
  [SMALL_STATE(5670)] = 109570,
  [SMALL_STATE(5671)] = 109709,
  [SMALL_STATE(5672)] = 109848,
  [SMALL_STATE(5673)] = 109987,
  [SMALL_STATE(5674)] = 110126,
  [SMALL_STATE(5675)] = 110211,
  [SMALL_STATE(5676)] = 110350,
  [SMALL_STATE(5677)] = 110489,
  [SMALL_STATE(5678)] = 110592,
  [SMALL_STATE(5679)] = 110731,
  [SMALL_STATE(5680)] = 110870,
  [SMALL_STATE(5681)] = 111009,
  [SMALL_STATE(5682)] = 111148,
  [SMALL_STATE(5683)] = 111287,
  [SMALL_STATE(5684)] = 111426,
  [SMALL_STATE(5685)] = 111533,
  [SMALL_STATE(5686)] = 111672,
  [SMALL_STATE(5687)] = 111811,
  [SMALL_STATE(5688)] = 111940,
  [SMALL_STATE(5689)] = 112071,
  [SMALL_STATE(5690)] = 112198,
  [SMALL_STATE(5691)] = 112323,
  [SMALL_STATE(5692)] = 112456,
  [SMALL_STATE(5693)] = 112591,
  [SMALL_STATE(5694)] = 112730,
  [SMALL_STATE(5695)] = 112869,
  [SMALL_STATE(5696)] = 113008,
  [SMALL_STATE(5697)] = 113147,
  [SMALL_STATE(5698)] = 113286,
  [SMALL_STATE(5699)] = 113425,
  [SMALL_STATE(5700)] = 113564,
  [SMALL_STATE(5701)] = 113703,
  [SMALL_STATE(5702)] = 113842,
  [SMALL_STATE(5703)] = 113981,
  [SMALL_STATE(5704)] = 114120,
  [SMALL_STATE(5705)] = 114259,
  [SMALL_STATE(5706)] = 114398,
  [SMALL_STATE(5707)] = 114537,
  [SMALL_STATE(5708)] = 114676,
  [SMALL_STATE(5709)] = 114815,
  [SMALL_STATE(5710)] = 114922,
  [SMALL_STATE(5711)] = 115061,
  [SMALL_STATE(5712)] = 115200,
  [SMALL_STATE(5713)] = 115339,
  [SMALL_STATE(5714)] = 115442,
  [SMALL_STATE(5715)] = 115545,
  [SMALL_STATE(5716)] = 115652,
  [SMALL_STATE(5717)] = 115769,
  [SMALL_STATE(5718)] = 115880,
  [SMALL_STATE(5719)] = 115987,
  [SMALL_STATE(5720)] = 116100,
  [SMALL_STATE(5721)] = 116189,
  [SMALL_STATE(5722)] = 116278,
  [SMALL_STATE(5723)] = 116417,
  [SMALL_STATE(5724)] = 116556,
  [SMALL_STATE(5725)] = 116659,
  [SMALL_STATE(5726)] = 116766,
  [SMALL_STATE(5727)] = 116905,
  [SMALL_STATE(5728)] = 117008,
  [SMALL_STATE(5729)] = 117111,
  [SMALL_STATE(5730)] = 117214,
  [SMALL_STATE(5731)] = 117299,
  [SMALL_STATE(5732)] = 117384,
  [SMALL_STATE(5733)] = 117523,
  [SMALL_STATE(5734)] = 117662,
  [SMALL_STATE(5735)] = 117791,
  [SMALL_STATE(5736)] = 117922,
  [SMALL_STATE(5737)] = 118049,
  [SMALL_STATE(5738)] = 118174,
  [SMALL_STATE(5739)] = 118307,
  [SMALL_STATE(5740)] = 118442,
  [SMALL_STATE(5741)] = 118581,
  [SMALL_STATE(5742)] = 118720,
  [SMALL_STATE(5743)] = 118859,
  [SMALL_STATE(5744)] = 118998,
  [SMALL_STATE(5745)] = 119083,
  [SMALL_STATE(5746)] = 119222,
  [SMALL_STATE(5747)] = 119361,
  [SMALL_STATE(5748)] = 119448,
  [SMALL_STATE(5749)] = 119587,
  [SMALL_STATE(5750)] = 119726,
  [SMALL_STATE(5751)] = 119865,
  [SMALL_STATE(5752)] = 119950,
  [SMALL_STATE(5753)] = 120051,
  [SMALL_STATE(5754)] = 120140,
  [SMALL_STATE(5755)] = 120251,
  [SMALL_STATE(5756)] = 120340,
  [SMALL_STATE(5757)] = 120429,
  [SMALL_STATE(5758)] = 120518,
  [SMALL_STATE(5759)] = 120605,
  [SMALL_STATE(5760)] = 120694,
  [SMALL_STATE(5761)] = 120811,
  [SMALL_STATE(5762)] = 120922,
  [SMALL_STATE(5763)] = 121029,
  [SMALL_STATE(5764)] = 121158,
  [SMALL_STATE(5765)] = 121289,
  [SMALL_STATE(5766)] = 121416,
  [SMALL_STATE(5767)] = 121529,
  [SMALL_STATE(5768)] = 121654,
  [SMALL_STATE(5769)] = 121757,
  [SMALL_STATE(5770)] = 121890,
  [SMALL_STATE(5771)] = 122025,
  [SMALL_STATE(5772)] = 122164,
  [SMALL_STATE(5773)] = 122249,
  [SMALL_STATE(5774)] = 122334,
  [SMALL_STATE(5775)] = 122419,
  [SMALL_STATE(5776)] = 122504,
  [SMALL_STATE(5777)] = 122643,
  [SMALL_STATE(5778)] = 122728,
  [SMALL_STATE(5779)] = 122817,
  [SMALL_STATE(5780)] = 122906,
  [SMALL_STATE(5781)] = 122995,
  [SMALL_STATE(5782)] = 123082,
  [SMALL_STATE(5783)] = 123171,
  [SMALL_STATE(5784)] = 123310,
  [SMALL_STATE(5785)] = 123395,
  [SMALL_STATE(5786)] = 123480,
  [SMALL_STATE(5787)] = 123619,
  [SMALL_STATE(5788)] = 123758,
  [SMALL_STATE(5789)] = 123897,
  [SMALL_STATE(5790)] = 124036,
  [SMALL_STATE(5791)] = 124174,
  [SMALL_STATE(5792)] = 124312,
  [SMALL_STATE(5793)] = 124450,
  [SMALL_STATE(5794)] = 124536,
  [SMALL_STATE(5795)] = 124678,
  [SMALL_STATE(5796)] = 124780,
  [SMALL_STATE(5797)] = 124892,
  [SMALL_STATE(5798)] = 125008,
  [SMALL_STATE(5799)] = 125118,
  [SMALL_STATE(5800)] = 125246,
  [SMALL_STATE(5801)] = 125376,
  [SMALL_STATE(5802)] = 125502,
  [SMALL_STATE(5803)] = 125614,
  [SMALL_STATE(5804)] = 125738,
  [SMALL_STATE(5805)] = 125870,
  [SMALL_STATE(5806)] = 126004,
  [SMALL_STATE(5807)] = 126142,
  [SMALL_STATE(5808)] = 126230,
  [SMALL_STATE(5809)] = 126332,
  [SMALL_STATE(5810)] = 126470,
  [SMALL_STATE(5811)] = 126608,
  [SMALL_STATE(5812)] = 126710,
  [SMALL_STATE(5813)] = 126848,
  [SMALL_STATE(5814)] = 126986,
  [SMALL_STATE(5815)] = 127124,
  [SMALL_STATE(5816)] = 127262,
  [SMALL_STATE(5817)] = 127400,
  [SMALL_STATE(5818)] = 127538,
  [SMALL_STATE(5819)] = 127676,
  [SMALL_STATE(5820)] = 127814,
  [SMALL_STATE(5821)] = 127952,
  [SMALL_STATE(5822)] = 128094,
  [SMALL_STATE(5823)] = 128236,
  [SMALL_STATE(5824)] = 128374,
  [SMALL_STATE(5825)] = 128512,
  [SMALL_STATE(5826)] = 128650,
  [SMALL_STATE(5827)] = 128792,
  [SMALL_STATE(5828)] = 128908,
  [SMALL_STATE(5829)] = 129046,
  [SMALL_STATE(5830)] = 129156,
  [SMALL_STATE(5831)] = 129262,
  [SMALL_STATE(5832)] = 129390,
  [SMALL_STATE(5833)] = 129520,
  [SMALL_STATE(5834)] = 129632,
  [SMALL_STATE(5835)] = 129758,
  [SMALL_STATE(5836)] = 129846,
  [SMALL_STATE(5837)] = 129934,
  [SMALL_STATE(5838)] = 130046,
  [SMALL_STATE(5839)] = 130184,
  [SMALL_STATE(5840)] = 130326,
  [SMALL_STATE(5841)] = 130450,
  [SMALL_STATE(5842)] = 130566,
  [SMALL_STATE(5843)] = 130676,
  [SMALL_STATE(5844)] = 130804,
  [SMALL_STATE(5845)] = 130934,
  [SMALL_STATE(5846)] = 131060,
  [SMALL_STATE(5847)] = 131172,
  [SMALL_STATE(5848)] = 131296,
  [SMALL_STATE(5849)] = 131428,
  [SMALL_STATE(5850)] = 131562,
  [SMALL_STATE(5851)] = 131700,
  [SMALL_STATE(5852)] = 131802,
  [SMALL_STATE(5853)] = 131934,
  [SMALL_STATE(5854)] = 132068,
  [SMALL_STATE(5855)] = 132206,
  [SMALL_STATE(5856)] = 132344,
  [SMALL_STATE(5857)] = 132446,
  [SMALL_STATE(5858)] = 132584,
  [SMALL_STATE(5859)] = 132722,
  [SMALL_STATE(5860)] = 132860,
  [SMALL_STATE(5861)] = 132998,
  [SMALL_STATE(5862)] = 133136,
  [SMALL_STATE(5863)] = 133274,
  [SMALL_STATE(5864)] = 133412,
  [SMALL_STATE(5865)] = 133550,
  [SMALL_STATE(5866)] = 133688,
  [SMALL_STATE(5867)] = 133826,
  [SMALL_STATE(5868)] = 133964,
  [SMALL_STATE(5869)] = 134102,
  [SMALL_STATE(5870)] = 134240,
  [SMALL_STATE(5871)] = 134382,
  [SMALL_STATE(5872)] = 134524,
  [SMALL_STATE(5873)] = 134666,
  [SMALL_STATE(5874)] = 134804,
  [SMALL_STATE(5875)] = 134916,
  [SMALL_STATE(5876)] = 135028,
  [SMALL_STATE(5877)] = 135144,
  [SMALL_STATE(5878)] = 135254,
  [SMALL_STATE(5879)] = 135382,
  [SMALL_STATE(5880)] = 135512,
  [SMALL_STATE(5881)] = 135638,
  [SMALL_STATE(5882)] = 135750,
  [SMALL_STATE(5883)] = 135874,
  [SMALL_STATE(5884)] = 136006,
  [SMALL_STATE(5885)] = 136140,
  [SMALL_STATE(5886)] = 136278,
  [SMALL_STATE(5887)] = 136364,
  [SMALL_STATE(5888)] = 136506,
  [SMALL_STATE(5889)] = 136608,
  [SMALL_STATE(5890)] = 136746,
  [SMALL_STATE(5891)] = 136884,
  [SMALL_STATE(5892)] = 137022,
  [SMALL_STATE(5893)] = 137160,
  [SMALL_STATE(5894)] = 137298,
  [SMALL_STATE(5895)] = 137436,
  [SMALL_STATE(5896)] = 137574,
  [SMALL_STATE(5897)] = 137712,
  [SMALL_STATE(5898)] = 137850,
  [SMALL_STATE(5899)] = 137938,
  [SMALL_STATE(5900)] = 138054,
  [SMALL_STATE(5901)] = 138166,
  [SMALL_STATE(5902)] = 138276,
  [SMALL_STATE(5903)] = 138382,
  [SMALL_STATE(5904)] = 138494,
  [SMALL_STATE(5905)] = 138622,
  [SMALL_STATE(5906)] = 138764,
  [SMALL_STATE(5907)] = 138876,
  [SMALL_STATE(5908)] = 139006,
  [SMALL_STATE(5909)] = 139146,
  [SMALL_STATE(5910)] = 139258,
  [SMALL_STATE(5911)] = 139384,
  [SMALL_STATE(5912)] = 139496,
  [SMALL_STATE(5913)] = 139608,
  [SMALL_STATE(5914)] = 139732,
  [SMALL_STATE(5915)] = 139864,
  [SMALL_STATE(5916)] = 139998,
  [SMALL_STATE(5917)] = 140138,
  [SMALL_STATE(5918)] = 140276,
  [SMALL_STATE(5919)] = 140414,
  [SMALL_STATE(5920)] = 140556,
  [SMALL_STATE(5921)] = 140698,
  [SMALL_STATE(5922)] = 140840,
  [SMALL_STATE(5923)] = 140956,
  [SMALL_STATE(5924)] = 141066,
  [SMALL_STATE(5925)] = 141172,
  [SMALL_STATE(5926)] = 141300,
  [SMALL_STATE(5927)] = 141430,
  [SMALL_STATE(5928)] = 141556,
  [SMALL_STATE(5929)] = 141668,
  [SMALL_STATE(5930)] = 141792,
  [SMALL_STATE(5931)] = 141902,
  [SMALL_STATE(5932)] = 142040,
  [SMALL_STATE(5933)] = 142178,
  [SMALL_STATE(5934)] = 142262,
  [SMALL_STATE(5935)] = 142374,
  [SMALL_STATE(5936)] = 142512,
  [SMALL_STATE(5937)] = 142604,
  [SMALL_STATE(5938)] = 142690,
  [SMALL_STATE(5939)] = 142806,
  [SMALL_STATE(5940)] = 142916,
  [SMALL_STATE(5941)] = 143044,
  [SMALL_STATE(5942)] = 143174,
  [SMALL_STATE(5943)] = 143300,
  [SMALL_STATE(5944)] = 143412,
  [SMALL_STATE(5945)] = 143536,
  [SMALL_STATE(5946)] = 143668,
  [SMALL_STATE(5947)] = 143802,
  [SMALL_STATE(5948)] = 143940,
  [SMALL_STATE(5949)] = 144052,
  [SMALL_STATE(5950)] = 144194,
  [SMALL_STATE(5951)] = 144296,
  [SMALL_STATE(5952)] = 144428,
  [SMALL_STATE(5953)] = 144562,
  [SMALL_STATE(5954)] = 144700,
  [SMALL_STATE(5955)] = 144838,
  [SMALL_STATE(5956)] = 144976,
  [SMALL_STATE(5957)] = 145114,
  [SMALL_STATE(5958)] = 145256,
  [SMALL_STATE(5959)] = 145398,
  [SMALL_STATE(5960)] = 145536,
  [SMALL_STATE(5961)] = 145638,
  [SMALL_STATE(5962)] = 145776,
  [SMALL_STATE(5963)] = 145914,
  [SMALL_STATE(5964)] = 146052,
  [SMALL_STATE(5965)] = 146190,
  [SMALL_STATE(5966)] = 146328,
  [SMALL_STATE(5967)] = 146466,
  [SMALL_STATE(5968)] = 146604,
  [SMALL_STATE(5969)] = 146742,
  [SMALL_STATE(5970)] = 146880,
  [SMALL_STATE(5971)] = 147018,
  [SMALL_STATE(5972)] = 147156,
  [SMALL_STATE(5973)] = 147298,
  [SMALL_STATE(5974)] = 147440,
  [SMALL_STATE(5975)] = 147582,
  [SMALL_STATE(5976)] = 147694,
  [SMALL_STATE(5977)] = 147832,
  [SMALL_STATE(5978)] = 147970,
  [SMALL_STATE(5979)] = 148112,
  [SMALL_STATE(5980)] = 148254,
  [SMALL_STATE(5981)] = 148396,
  [SMALL_STATE(5982)] = 148534,
  [SMALL_STATE(5983)] = 148676,
  [SMALL_STATE(5984)] = 148788,
  [SMALL_STATE(5985)] = 148926,
  [SMALL_STATE(5986)] = 149064,
  [SMALL_STATE(5987)] = 149202,
  [SMALL_STATE(5988)] = 149314,
  [SMALL_STATE(5989)] = 149430,
  [SMALL_STATE(5990)] = 149540,
  [SMALL_STATE(5991)] = 149668,
  [SMALL_STATE(5992)] = 149798,
  [SMALL_STATE(5993)] = 149940,
  [SMALL_STATE(5994)] = 150082,
  [SMALL_STATE(5995)] = 150208,
  [SMALL_STATE(5996)] = 150320,
  [SMALL_STATE(5997)] = 150444,
  [SMALL_STATE(5998)] = 150576,
  [SMALL_STATE(5999)] = 150710,
  [SMALL_STATE(6000)] = 150848,
  [SMALL_STATE(6001)] = 150990,
  [SMALL_STATE(6002)] = 151128,
  [SMALL_STATE(6003)] = 151230,
  [SMALL_STATE(6004)] = 151342,
  [SMALL_STATE(6005)] = 151480,
  [SMALL_STATE(6006)] = 151618,
  [SMALL_STATE(6007)] = 151720,
  [SMALL_STATE(6008)] = 151858,
  [SMALL_STATE(6009)] = 151996,
  [SMALL_STATE(6010)] = 152134,
  [SMALL_STATE(6011)] = 152272,
  [SMALL_STATE(6012)] = 152410,
  [SMALL_STATE(6013)] = 152548,
  [SMALL_STATE(6014)] = 152686,
  [SMALL_STATE(6015)] = 152824,
  [SMALL_STATE(6016)] = 152962,
  [SMALL_STATE(6017)] = 153100,
  [SMALL_STATE(6018)] = 153242,
  [SMALL_STATE(6019)] = 153384,
  [SMALL_STATE(6020)] = 153472,
  [SMALL_STATE(6021)] = 153556,
  [SMALL_STATE(6022)] = 153694,
  [SMALL_STATE(6023)] = 153780,
  [SMALL_STATE(6024)] = 153882,
  [SMALL_STATE(6025)] = 153994,
  [SMALL_STATE(6026)] = 154132,
  [SMALL_STATE(6027)] = 154270,
  [SMALL_STATE(6028)] = 154356,
  [SMALL_STATE(6029)] = 154498,
  [SMALL_STATE(6030)] = 154636,
  [SMALL_STATE(6031)] = 154778,
  [SMALL_STATE(6032)] = 154920,
  [SMALL_STATE(6033)] = 155062,
  [SMALL_STATE(6034)] = 155172,
  [SMALL_STATE(6035)] = 155284,
  [SMALL_STATE(6036)] = 155422,
  [SMALL_STATE(6037)] = 155560,
  [SMALL_STATE(6038)] = 155672,
  [SMALL_STATE(6039)] = 155810,
  [SMALL_STATE(6040)] = 155952,
  [SMALL_STATE(6041)] = 156058,
  [SMALL_STATE(6042)] = 156196,
  [SMALL_STATE(6043)] = 156298,
  [SMALL_STATE(6044)] = 156386,
  [SMALL_STATE(6045)] = 156524,
  [SMALL_STATE(6046)] = 156662,
  [SMALL_STATE(6047)] = 156774,
  [SMALL_STATE(6048)] = 156912,
  [SMALL_STATE(6049)] = 157018,
  [SMALL_STATE(6050)] = 157120,
  [SMALL_STATE(6051)] = 157232,
  [SMALL_STATE(6052)] = 157370,
  [SMALL_STATE(6053)] = 157482,
  [SMALL_STATE(6054)] = 157588,
  [SMALL_STATE(6055)] = 157690,
  [SMALL_STATE(6056)] = 157802,
  [SMALL_STATE(6057)] = 157940,
  [SMALL_STATE(6058)] = 158046,
  [SMALL_STATE(6059)] = 158148,
  [SMALL_STATE(6060)] = 158260,
  [SMALL_STATE(6061)] = 158398,
  [SMALL_STATE(6062)] = 158504,
  [SMALL_STATE(6063)] = 158606,
  [SMALL_STATE(6064)] = 158746,
  [SMALL_STATE(6065)] = 158884,
  [SMALL_STATE(6066)] = 158976,
  [SMALL_STATE(6067)] = 159114,
  [SMALL_STATE(6068)] = 159252,
  [SMALL_STATE(6069)] = 159368,
  [SMALL_STATE(6070)] = 159478,
  [SMALL_STATE(6071)] = 159606,
  [SMALL_STATE(6072)] = 159736,
  [SMALL_STATE(6073)] = 159862,
  [SMALL_STATE(6074)] = 159974,
  [SMALL_STATE(6075)] = 160098,
  [SMALL_STATE(6076)] = 160186,
  [SMALL_STATE(6077)] = 160328,
  [SMALL_STATE(6078)] = 160470,
  [SMALL_STATE(6079)] = 160602,
  [SMALL_STATE(6080)] = 160736,
  [SMALL_STATE(6081)] = 160874,
  [SMALL_STATE(6082)] = 161016,
  [SMALL_STATE(6083)] = 161128,
  [SMALL_STATE(6084)] = 161234,
  [SMALL_STATE(6085)] = 161336,
  [SMALL_STATE(6086)] = 161478,
  [SMALL_STATE(6087)] = 161616,
  [SMALL_STATE(6088)] = 161718,
  [SMALL_STATE(6089)] = 161856,
  [SMALL_STATE(6090)] = 161994,
  [SMALL_STATE(6091)] = 162132,
  [SMALL_STATE(6092)] = 162270,
  [SMALL_STATE(6093)] = 162408,
  [SMALL_STATE(6094)] = 162496,
  [SMALL_STATE(6095)] = 162634,
  [SMALL_STATE(6096)] = 162776,
  [SMALL_STATE(6097)] = 162918,
  [SMALL_STATE(6098)] = 163056,
  [SMALL_STATE(6099)] = 163194,
  [SMALL_STATE(6100)] = 163332,
  [SMALL_STATE(6101)] = 163470,
  [SMALL_STATE(6102)] = 163558,
  [SMALL_STATE(6103)] = 163646,
  [SMALL_STATE(6104)] = 163734,
  [SMALL_STATE(6105)] = 163820,
  [SMALL_STATE(6106)] = 163908,
  [SMALL_STATE(6107)] = 164020,
  [SMALL_STATE(6108)] = 164108,
  [SMALL_STATE(6109)] = 164196,
  [SMALL_STATE(6110)] = 164284,
  [SMALL_STATE(6111)] = 164370,
  [SMALL_STATE(6112)] = 164458,
  [SMALL_STATE(6113)] = 164546,
  [SMALL_STATE(6114)] = 164634,
  [SMALL_STATE(6115)] = 164722,
  [SMALL_STATE(6116)] = 164808,
  [SMALL_STATE(6117)] = 164896,
  [SMALL_STATE(6118)] = 165038,
  [SMALL_STATE(6119)] = 165126,
  [SMALL_STATE(6120)] = 165214,
  [SMALL_STATE(6121)] = 165302,
  [SMALL_STATE(6122)] = 165388,
  [SMALL_STATE(6123)] = 165476,
  [SMALL_STATE(6124)] = 165618,
  [SMALL_STATE(6125)] = 165760,
  [SMALL_STATE(6126)] = 165859,
  [SMALL_STATE(6127)] = 165996,
  [SMALL_STATE(6128)] = 166095,
  [SMALL_STATE(6129)] = 166232,
  [SMALL_STATE(6130)] = 166369,
  [SMALL_STATE(6131)] = 166468,
  [SMALL_STATE(6132)] = 166567,
  [SMALL_STATE(6133)] = 166704,
  [SMALL_STATE(6134)] = 166813,
  [SMALL_STATE(6135)] = 166950,
  [SMALL_STATE(6136)] = 167061,
  [SMALL_STATE(6137)] = 167184,
  [SMALL_STATE(6138)] = 167283,
  [SMALL_STATE(6139)] = 167414,
  [SMALL_STATE(6140)] = 167517,
  [SMALL_STATE(6141)] = 167650,
  [SMALL_STATE(6142)] = 167787,
  [SMALL_STATE(6143)] = 167924,
  [SMALL_STATE(6144)] = 168061,
  [SMALL_STATE(6145)] = 168198,
  [SMALL_STATE(6146)] = 168335,
  [SMALL_STATE(6147)] = 168422,
  [SMALL_STATE(6148)] = 168509,
  [SMALL_STATE(6149)] = 168646,
  [SMALL_STATE(6150)] = 168733,
  [SMALL_STATE(6151)] = 168842,
  [SMALL_STATE(6152)] = 168979,
  [SMALL_STATE(6153)] = 169116,
  [SMALL_STATE(6154)] = 169253,
  [SMALL_STATE(6155)] = 169354,
  [SMALL_STATE(6156)] = 169491,
  [SMALL_STATE(6157)] = 169628,
  [SMALL_STATE(6158)] = 169713,
  [SMALL_STATE(6159)] = 169816,
  [SMALL_STATE(6160)] = 169903,
  [SMALL_STATE(6161)] = 170018,
  [SMALL_STATE(6162)] = 170123,
  [SMALL_STATE(6163)] = 170260,
  [SMALL_STATE(6164)] = 170369,
  [SMALL_STATE(6165)] = 170456,
  [SMALL_STATE(6166)] = 170593,
  [SMALL_STATE(6167)] = 170692,
  [SMALL_STATE(6168)] = 170829,
  [SMALL_STATE(6169)] = 170916,
  [SMALL_STATE(6170)] = 171053,
  [SMALL_STATE(6171)] = 171152,
  [SMALL_STATE(6172)] = 171251,
  [SMALL_STATE(6173)] = 171378,
  [SMALL_STATE(6174)] = 171477,
  [SMALL_STATE(6175)] = 171614,
  [SMALL_STATE(6176)] = 171713,
  [SMALL_STATE(6177)] = 171850,
  [SMALL_STATE(6178)] = 171951,
  [SMALL_STATE(6179)] = 172080,
  [SMALL_STATE(6180)] = 172219,
  [SMALL_STATE(6181)] = 172344,
  [SMALL_STATE(6182)] = 172453,
  [SMALL_STATE(6183)] = 172590,
  [SMALL_STATE(6184)] = 172691,
  [SMALL_STATE(6185)] = 172776,
  [SMALL_STATE(6186)] = 172913,
  [SMALL_STATE(6187)] = 173012,
  [SMALL_STATE(6188)] = 173149,
  [SMALL_STATE(6189)] = 173286,
  [SMALL_STATE(6190)] = 173387,
  [SMALL_STATE(6191)] = 173524,
  [SMALL_STATE(6192)] = 173661,
  [SMALL_STATE(6193)] = 173798,
  [SMALL_STATE(6194)] = 173935,
  [SMALL_STATE(6195)] = 174034,
  [SMALL_STATE(6196)] = 174133,
  [SMALL_STATE(6197)] = 174220,
  [SMALL_STATE(6198)] = 174305,
  [SMALL_STATE(6199)] = 174392,
  [SMALL_STATE(6200)] = 174479,
  [SMALL_STATE(6201)] = 174616,
  [SMALL_STATE(6202)] = 174753,
  [SMALL_STATE(6203)] = 174838,
  [SMALL_STATE(6204)] = 174975,
  [SMALL_STATE(6205)] = 175066,
  [SMALL_STATE(6206)] = 175165,
  [SMALL_STATE(6207)] = 175250,
  [SMALL_STATE(6208)] = 175349,
  [SMALL_STATE(6209)] = 175486,
  [SMALL_STATE(6210)] = 175623,
  [SMALL_STATE(6211)] = 175762,
  [SMALL_STATE(6212)] = 175899,
  [SMALL_STATE(6213)] = 176036,
  [SMALL_STATE(6214)] = 176173,
  [SMALL_STATE(6215)] = 176300,
  [SMALL_STATE(6216)] = 176429,
  [SMALL_STATE(6217)] = 176554,
  [SMALL_STATE(6218)] = 176677,
  [SMALL_STATE(6219)] = 176808,
  [SMALL_STATE(6220)] = 176941,
  [SMALL_STATE(6221)] = 177078,
  [SMALL_STATE(6222)] = 177171,
  [SMALL_STATE(6223)] = 177308,
  [SMALL_STATE(6224)] = 177445,
  [SMALL_STATE(6225)] = 177582,
  [SMALL_STATE(6226)] = 177715,
  [SMALL_STATE(6227)] = 177854,
  [SMALL_STATE(6228)] = 177969,
  [SMALL_STATE(6229)] = 178068,
  [SMALL_STATE(6230)] = 178205,
  [SMALL_STATE(6231)] = 178290,
  [SMALL_STATE(6232)] = 178427,
  [SMALL_STATE(6233)] = 178536,
  [SMALL_STATE(6234)] = 178635,
  [SMALL_STATE(6235)] = 178734,
  [SMALL_STATE(6236)] = 178871,
  [SMALL_STATE(6237)] = 179008,
  [SMALL_STATE(6238)] = 179095,
  [SMALL_STATE(6239)] = 179182,
  [SMALL_STATE(6240)] = 179319,
  [SMALL_STATE(6241)] = 179424,
  [SMALL_STATE(6242)] = 179509,
  [SMALL_STATE(6243)] = 179594,
  [SMALL_STATE(6244)] = 179695,
  [SMALL_STATE(6245)] = 179832,
  [SMALL_STATE(6246)] = 179969,
  [SMALL_STATE(6247)] = 180106,
  [SMALL_STATE(6248)] = 180233,
  [SMALL_STATE(6249)] = 180370,
  [SMALL_STATE(6250)] = 180507,
  [SMALL_STATE(6251)] = 180644,
  [SMALL_STATE(6252)] = 180729,
  [SMALL_STATE(6253)] = 180866,
  [SMALL_STATE(6254)] = 181003,
  [SMALL_STATE(6255)] = 181118,
  [SMALL_STATE(6256)] = 181227,
  [SMALL_STATE(6257)] = 181332,
  [SMALL_STATE(6258)] = 181443,
  [SMALL_STATE(6259)] = 181580,
  [SMALL_STATE(6260)] = 181717,
  [SMALL_STATE(6261)] = 181828,
  [SMALL_STATE(6262)] = 181921,
  [SMALL_STATE(6263)] = 182050,
  [SMALL_STATE(6264)] = 182159,
  [SMALL_STATE(6265)] = 182296,
  [SMALL_STATE(6266)] = 182397,
  [SMALL_STATE(6267)] = 182534,
  [SMALL_STATE(6268)] = 182633,
  [SMALL_STATE(6269)] = 182732,
  [SMALL_STATE(6270)] = 182831,
  [SMALL_STATE(6271)] = 182968,
  [SMALL_STATE(6272)] = 183105,
  [SMALL_STATE(6273)] = 183204,
  [SMALL_STATE(6274)] = 183303,
  [SMALL_STATE(6275)] = 183440,
  [SMALL_STATE(6276)] = 183577,
  [SMALL_STATE(6277)] = 183714,
  [SMALL_STATE(6278)] = 183839,
  [SMALL_STATE(6279)] = 183926,
  [SMALL_STATE(6280)] = 184011,
  [SMALL_STATE(6281)] = 184110,
  [SMALL_STATE(6282)] = 184233,
  [SMALL_STATE(6283)] = 184370,
  [SMALL_STATE(6284)] = 184507,
  [SMALL_STATE(6285)] = 184644,
  [SMALL_STATE(6286)] = 184781,
  [SMALL_STATE(6287)] = 184880,
  [SMALL_STATE(6288)] = 185019,
  [SMALL_STATE(6289)] = 185118,
  [SMALL_STATE(6290)] = 185255,
  [SMALL_STATE(6291)] = 185392,
  [SMALL_STATE(6292)] = 185491,
  [SMALL_STATE(6293)] = 185622,
  [SMALL_STATE(6294)] = 185755,
  [SMALL_STATE(6295)] = 185892,
  [SMALL_STATE(6296)] = 185993,
  [SMALL_STATE(6297)] = 186132,
  [SMALL_STATE(6298)] = 186269,
  [SMALL_STATE(6299)] = 186370,
  [SMALL_STATE(6300)] = 186485,
  [SMALL_STATE(6301)] = 186594,
  [SMALL_STATE(6302)] = 186699,
  [SMALL_STATE(6303)] = 186826,
  [SMALL_STATE(6304)] = 186955,
  [SMALL_STATE(6305)] = 187042,
  [SMALL_STATE(6306)] = 187167,
  [SMALL_STATE(6307)] = 187278,
  [SMALL_STATE(6308)] = 187401,
  [SMALL_STATE(6309)] = 187538,
  [SMALL_STATE(6310)] = 187675,
  [SMALL_STATE(6311)] = 187806,
  [SMALL_STATE(6312)] = 187943,
  [SMALL_STATE(6313)] = 188028,
  [SMALL_STATE(6314)] = 188164,
  [SMALL_STATE(6315)] = 188250,
  [SMALL_STATE(6316)] = 188386,
  [SMALL_STATE(6317)] = 188500,
  [SMALL_STATE(6318)] = 188636,
  [SMALL_STATE(6319)] = 188744,
  [SMALL_STATE(6320)] = 188848,
  [SMALL_STATE(6321)] = 188974,
  [SMALL_STATE(6322)] = 189102,
  [SMALL_STATE(6323)] = 189226,
  [SMALL_STATE(6324)] = 189336,
  [SMALL_STATE(6325)] = 189458,
  [SMALL_STATE(6326)] = 189558,
  [SMALL_STATE(6327)] = 189688,
  [SMALL_STATE(6328)] = 189820,
  [SMALL_STATE(6329)] = 189956,
  [SMALL_STATE(6330)] = 190092,
  [SMALL_STATE(6331)] = 190228,
  [SMALL_STATE(6332)] = 190312,
  [SMALL_STATE(6333)] = 190448,
  [SMALL_STATE(6334)] = 190584,
  [SMALL_STATE(6335)] = 190720,
  [SMALL_STATE(6336)] = 190856,
  [SMALL_STATE(6337)] = 190992,
  [SMALL_STATE(6338)] = 191128,
  [SMALL_STATE(6339)] = 191264,
  [SMALL_STATE(6340)] = 191400,
  [SMALL_STATE(6341)] = 191536,
  [SMALL_STATE(6342)] = 191672,
  [SMALL_STATE(6343)] = 191808,
  [SMALL_STATE(6344)] = 191944,
  [SMALL_STATE(6345)] = 192036,
  [SMALL_STATE(6346)] = 192172,
  [SMALL_STATE(6347)] = 192308,
  [SMALL_STATE(6348)] = 192392,
  [SMALL_STATE(6349)] = 192528,
  [SMALL_STATE(6350)] = 192664,
  [SMALL_STATE(6351)] = 192800,
  [SMALL_STATE(6352)] = 192884,
  [SMALL_STATE(6353)] = 193020,
  [SMALL_STATE(6354)] = 193156,
  [SMALL_STATE(6355)] = 193292,
  [SMALL_STATE(6356)] = 193428,
  [SMALL_STATE(6357)] = 193564,
  [SMALL_STATE(6358)] = 193700,
  [SMALL_STATE(6359)] = 193836,
  [SMALL_STATE(6360)] = 193972,
  [SMALL_STATE(6361)] = 194108,
  [SMALL_STATE(6362)] = 194244,
  [SMALL_STATE(6363)] = 194380,
  [SMALL_STATE(6364)] = 194516,
  [SMALL_STATE(6365)] = 194652,
  [SMALL_STATE(6366)] = 194788,
  [SMALL_STATE(6367)] = 194924,
  [SMALL_STATE(6368)] = 195060,
  [SMALL_STATE(6369)] = 195196,
  [SMALL_STATE(6370)] = 195332,
  [SMALL_STATE(6371)] = 195468,
  [SMALL_STATE(6372)] = 195604,
  [SMALL_STATE(6373)] = 195740,
  [SMALL_STATE(6374)] = 195876,
  [SMALL_STATE(6375)] = 196012,
  [SMALL_STATE(6376)] = 196148,
  [SMALL_STATE(6377)] = 196284,
  [SMALL_STATE(6378)] = 196420,
  [SMALL_STATE(6379)] = 196556,
  [SMALL_STATE(6380)] = 196692,
  [SMALL_STATE(6381)] = 196828,
  [SMALL_STATE(6382)] = 196964,
  [SMALL_STATE(6383)] = 197100,
  [SMALL_STATE(6384)] = 197236,
  [SMALL_STATE(6385)] = 197372,
  [SMALL_STATE(6386)] = 197508,
  [SMALL_STATE(6387)] = 197644,
  [SMALL_STATE(6388)] = 197780,
  [SMALL_STATE(6389)] = 197916,
  [SMALL_STATE(6390)] = 198052,
  [SMALL_STATE(6391)] = 198136,
  [SMALL_STATE(6392)] = 198222,
  [SMALL_STATE(6393)] = 198358,
  [SMALL_STATE(6394)] = 198494,
  [SMALL_STATE(6395)] = 198630,
  [SMALL_STATE(6396)] = 198756,
  [SMALL_STATE(6397)] = 198884,
  [SMALL_STATE(6398)] = 199008,
  [SMALL_STATE(6399)] = 199130,
  [SMALL_STATE(6400)] = 199260,
  [SMALL_STATE(6401)] = 199392,
  [SMALL_STATE(6402)] = 199528,
  [SMALL_STATE(6403)] = 199664,
  [SMALL_STATE(6404)] = 199800,
  [SMALL_STATE(6405)] = 199936,
  [SMALL_STATE(6406)] = 200072,
  [SMALL_STATE(6407)] = 200208,
  [SMALL_STATE(6408)] = 200344,
  [SMALL_STATE(6409)] = 200480,
  [SMALL_STATE(6410)] = 200616,
  [SMALL_STATE(6411)] = 200752,
  [SMALL_STATE(6412)] = 200888,
  [SMALL_STATE(6413)] = 201024,
  [SMALL_STATE(6414)] = 201160,
  [SMALL_STATE(6415)] = 201296,
  [SMALL_STATE(6416)] = 201432,
  [SMALL_STATE(6417)] = 201568,
  [SMALL_STATE(6418)] = 201672,
  [SMALL_STATE(6419)] = 201808,
  [SMALL_STATE(6420)] = 201944,
  [SMALL_STATE(6421)] = 202080,
  [SMALL_STATE(6422)] = 202216,
  [SMALL_STATE(6423)] = 202352,
  [SMALL_STATE(6424)] = 202488,
  [SMALL_STATE(6425)] = 202572,
  [SMALL_STATE(6426)] = 202708,
  [SMALL_STATE(6427)] = 202822,
  [SMALL_STATE(6428)] = 202958,
  [SMALL_STATE(6429)] = 203066,
  [SMALL_STATE(6430)] = 203202,
  [SMALL_STATE(6431)] = 203338,
  [SMALL_STATE(6432)] = 203474,
  [SMALL_STATE(6433)] = 203610,
  [SMALL_STATE(6434)] = 203714,
  [SMALL_STATE(6435)] = 203840,
  [SMALL_STATE(6436)] = 203968,
  [SMALL_STATE(6437)] = 204092,
  [SMALL_STATE(6438)] = 204202,
  [SMALL_STATE(6439)] = 204324,
  [SMALL_STATE(6440)] = 204424,
  [SMALL_STATE(6441)] = 204554,
  [SMALL_STATE(6442)] = 204686,
  [SMALL_STATE(6443)] = 204822,
  [SMALL_STATE(6444)] = 204958,
  [SMALL_STATE(6445)] = 205094,
  [SMALL_STATE(6446)] = 205230,
  [SMALL_STATE(6447)] = 205366,
  [SMALL_STATE(6448)] = 205502,
  [SMALL_STATE(6449)] = 205638,
  [SMALL_STATE(6450)] = 205774,
  [SMALL_STATE(6451)] = 205910,
  [SMALL_STATE(6452)] = 206046,
  [SMALL_STATE(6453)] = 206182,
  [SMALL_STATE(6454)] = 206318,
  [SMALL_STATE(6455)] = 206454,
  [SMALL_STATE(6456)] = 206590,
  [SMALL_STATE(6457)] = 206726,
  [SMALL_STATE(6458)] = 206862,
  [SMALL_STATE(6459)] = 206998,
  [SMALL_STATE(6460)] = 207134,
  [SMALL_STATE(6461)] = 207270,
  [SMALL_STATE(6462)] = 207354,
  [SMALL_STATE(6463)] = 207490,
  [SMALL_STATE(6464)] = 207626,
  [SMALL_STATE(6465)] = 207762,
  [SMALL_STATE(6466)] = 207898,
  [SMALL_STATE(6467)] = 207996,
  [SMALL_STATE(6468)] = 208080,
  [SMALL_STATE(6469)] = 208216,
  [SMALL_STATE(6470)] = 208302,
  [SMALL_STATE(6471)] = 208438,
  [SMALL_STATE(6472)] = 208574,
  [SMALL_STATE(6473)] = 208710,
  [SMALL_STATE(6474)] = 208846,
  [SMALL_STATE(6475)] = 208932,
  [SMALL_STATE(6476)] = 209068,
  [SMALL_STATE(6477)] = 209204,
  [SMALL_STATE(6478)] = 209340,
  [SMALL_STATE(6479)] = 209476,
  [SMALL_STATE(6480)] = 209612,
  [SMALL_STATE(6481)] = 209748,
  [SMALL_STATE(6482)] = 209884,
  [SMALL_STATE(6483)] = 210020,
  [SMALL_STATE(6484)] = 210156,
  [SMALL_STATE(6485)] = 210260,
  [SMALL_STATE(6486)] = 210396,
  [SMALL_STATE(6487)] = 210532,
  [SMALL_STATE(6488)] = 210668,
  [SMALL_STATE(6489)] = 210754,
  [SMALL_STATE(6490)] = 210890,
  [SMALL_STATE(6491)] = 210976,
  [SMALL_STATE(6492)] = 211062,
  [SMALL_STATE(6493)] = 211198,
  [SMALL_STATE(6494)] = 211334,
  [SMALL_STATE(6495)] = 211420,
  [SMALL_STATE(6496)] = 211504,
  [SMALL_STATE(6497)] = 211590,
  [SMALL_STATE(6498)] = 211726,
  [SMALL_STATE(6499)] = 211862,
  [SMALL_STATE(6500)] = 211998,
  [SMALL_STATE(6501)] = 212082,
  [SMALL_STATE(6502)] = 212196,
  [SMALL_STATE(6503)] = 212332,
  [SMALL_STATE(6504)] = 212440,
  [SMALL_STATE(6505)] = 212544,
  [SMALL_STATE(6506)] = 212670,
  [SMALL_STATE(6507)] = 212798,
  [SMALL_STATE(6508)] = 212922,
  [SMALL_STATE(6509)] = 213032,
  [SMALL_STATE(6510)] = 213154,
  [SMALL_STATE(6511)] = 213254,
  [SMALL_STATE(6512)] = 213384,
  [SMALL_STATE(6513)] = 213516,
  [SMALL_STATE(6514)] = 213652,
  [SMALL_STATE(6515)] = 213788,
  [SMALL_STATE(6516)] = 213924,
  [SMALL_STATE(6517)] = 214060,
  [SMALL_STATE(6518)] = 214148,
  [SMALL_STATE(6519)] = 214284,
  [SMALL_STATE(6520)] = 214420,
  [SMALL_STATE(6521)] = 214556,
  [SMALL_STATE(6522)] = 214656,
  [SMALL_STATE(6523)] = 214792,
  [SMALL_STATE(6524)] = 214878,
  [SMALL_STATE(6525)] = 215014,
  [SMALL_STATE(6526)] = 215150,
  [SMALL_STATE(6527)] = 215286,
  [SMALL_STATE(6528)] = 215422,
  [SMALL_STATE(6529)] = 215508,
  [SMALL_STATE(6530)] = 215644,
  [SMALL_STATE(6531)] = 215780,
  [SMALL_STATE(6532)] = 215916,
  [SMALL_STATE(6533)] = 216016,
  [SMALL_STATE(6534)] = 216152,
  [SMALL_STATE(6535)] = 216236,
  [SMALL_STATE(6536)] = 216372,
  [SMALL_STATE(6537)] = 216508,
  [SMALL_STATE(6538)] = 216644,
  [SMALL_STATE(6539)] = 216780,
  [SMALL_STATE(6540)] = 216916,
  [SMALL_STATE(6541)] = 217052,
  [SMALL_STATE(6542)] = 217188,
  [SMALL_STATE(6543)] = 217274,
  [SMALL_STATE(6544)] = 217410,
  [SMALL_STATE(6545)] = 217496,
  [SMALL_STATE(6546)] = 217632,
  [SMALL_STATE(6547)] = 217768,
  [SMALL_STATE(6548)] = 217904,
  [SMALL_STATE(6549)] = 218004,
  [SMALL_STATE(6550)] = 218140,
  [SMALL_STATE(6551)] = 218226,
  [SMALL_STATE(6552)] = 218362,
  [SMALL_STATE(6553)] = 218448,
  [SMALL_STATE(6554)] = 218584,
  [SMALL_STATE(6555)] = 218720,
  [SMALL_STATE(6556)] = 218820,
  [SMALL_STATE(6557)] = 218956,
  [SMALL_STATE(6558)] = 219092,
  [SMALL_STATE(6559)] = 219228,
  [SMALL_STATE(6560)] = 219364,
  [SMALL_STATE(6561)] = 219500,
  [SMALL_STATE(6562)] = 219600,
  [SMALL_STATE(6563)] = 219736,
  [SMALL_STATE(6564)] = 219872,
  [SMALL_STATE(6565)] = 220008,
  [SMALL_STATE(6566)] = 220144,
  [SMALL_STATE(6567)] = 220280,
  [SMALL_STATE(6568)] = 220416,
  [SMALL_STATE(6569)] = 220552,
  [SMALL_STATE(6570)] = 220688,
  [SMALL_STATE(6571)] = 220824,
  [SMALL_STATE(6572)] = 220960,
  [SMALL_STATE(6573)] = 221096,
  [SMALL_STATE(6574)] = 221232,
  [SMALL_STATE(6575)] = 221368,
  [SMALL_STATE(6576)] = 221504,
  [SMALL_STATE(6577)] = 221640,
  [SMALL_STATE(6578)] = 221776,
  [SMALL_STATE(6579)] = 221912,
  [SMALL_STATE(6580)] = 222048,
  [SMALL_STATE(6581)] = 222132,
  [SMALL_STATE(6582)] = 222216,
  [SMALL_STATE(6583)] = 222320,
  [SMALL_STATE(6584)] = 222404,
  [SMALL_STATE(6585)] = 222518,
  [SMALL_STATE(6586)] = 222654,
  [SMALL_STATE(6587)] = 222790,
  [SMALL_STATE(6588)] = 222926,
  [SMALL_STATE(6589)] = 223062,
  [SMALL_STATE(6590)] = 223170,
  [SMALL_STATE(6591)] = 223306,
  [SMALL_STATE(6592)] = 223410,
  [SMALL_STATE(6593)] = 223536,
  [SMALL_STATE(6594)] = 223664,
  [SMALL_STATE(6595)] = 223788,
  [SMALL_STATE(6596)] = 223924,
  [SMALL_STATE(6597)] = 224060,
  [SMALL_STATE(6598)] = 224174,
  [SMALL_STATE(6599)] = 224282,
  [SMALL_STATE(6600)] = 224386,
  [SMALL_STATE(6601)] = 224496,
  [SMALL_STATE(6602)] = 224596,
  [SMALL_STATE(6603)] = 224732,
  [SMALL_STATE(6604)] = 224868,
  [SMALL_STATE(6605)] = 224978,
  [SMALL_STATE(6606)] = 225114,
  [SMALL_STATE(6607)] = 225236,
  [SMALL_STATE(6608)] = 225336,
  [SMALL_STATE(6609)] = 225466,
  [SMALL_STATE(6610)] = 225598,
  [SMALL_STATE(6611)] = 225734,
  [SMALL_STATE(6612)] = 225870,
  [SMALL_STATE(6613)] = 226006,
  [SMALL_STATE(6614)] = 226142,
  [SMALL_STATE(6615)] = 226278,
  [SMALL_STATE(6616)] = 226414,
  [SMALL_STATE(6617)] = 226550,
  [SMALL_STATE(6618)] = 226686,
  [SMALL_STATE(6619)] = 226822,
  [SMALL_STATE(6620)] = 226958,
  [SMALL_STATE(6621)] = 227094,
  [SMALL_STATE(6622)] = 227230,
  [SMALL_STATE(6623)] = 227366,
  [SMALL_STATE(6624)] = 227502,
  [SMALL_STATE(6625)] = 227638,
  [SMALL_STATE(6626)] = 227774,
  [SMALL_STATE(6627)] = 227910,
  [SMALL_STATE(6628)] = 228046,
  [SMALL_STATE(6629)] = 228182,
  [SMALL_STATE(6630)] = 228318,
  [SMALL_STATE(6631)] = 228454,
  [SMALL_STATE(6632)] = 228590,
  [SMALL_STATE(6633)] = 228726,
  [SMALL_STATE(6634)] = 228862,
  [SMALL_STATE(6635)] = 228998,
  [SMALL_STATE(6636)] = 229134,
  [SMALL_STATE(6637)] = 229220,
  [SMALL_STATE(6638)] = 229306,
  [SMALL_STATE(6639)] = 229390,
  [SMALL_STATE(6640)] = 229476,
  [SMALL_STATE(6641)] = 229612,
  [SMALL_STATE(6642)] = 229748,
  [SMALL_STATE(6643)] = 229884,
  [SMALL_STATE(6644)] = 230020,
  [SMALL_STATE(6645)] = 230106,
  [SMALL_STATE(6646)] = 230192,
  [SMALL_STATE(6647)] = 230276,
  [SMALL_STATE(6648)] = 230362,
  [SMALL_STATE(6649)] = 230448,
  [SMALL_STATE(6650)] = 230584,
  [SMALL_STATE(6651)] = 230720,
  [SMALL_STATE(6652)] = 230856,
  [SMALL_STATE(6653)] = 230992,
  [SMALL_STATE(6654)] = 231128,
  [SMALL_STATE(6655)] = 231264,
  [SMALL_STATE(6656)] = 231400,
  [SMALL_STATE(6657)] = 231536,
  [SMALL_STATE(6658)] = 231622,
  [SMALL_STATE(6659)] = 231708,
  [SMALL_STATE(6660)] = 231792,
  [SMALL_STATE(6661)] = 231878,
  [SMALL_STATE(6662)] = 231992,
  [SMALL_STATE(6663)] = 232082,
  [SMALL_STATE(6664)] = 232168,
  [SMALL_STATE(6665)] = 232304,
  [SMALL_STATE(6666)] = 232440,
  [SMALL_STATE(6667)] = 232548,
  [SMALL_STATE(6668)] = 232652,
  [SMALL_STATE(6669)] = 232778,
  [SMALL_STATE(6670)] = 232906,
  [SMALL_STATE(6671)] = 233030,
  [SMALL_STATE(6672)] = 233140,
  [SMALL_STATE(6673)] = 233226,
  [SMALL_STATE(6674)] = 233362,
  [SMALL_STATE(6675)] = 233484,
  [SMALL_STATE(6676)] = 233584,
  [SMALL_STATE(6677)] = 233720,
  [SMALL_STATE(6678)] = 233850,
  [SMALL_STATE(6679)] = 233982,
  [SMALL_STATE(6680)] = 234068,
  [SMALL_STATE(6681)] = 234204,
  [SMALL_STATE(6682)] = 234340,
  [SMALL_STATE(6683)] = 234476,
  [SMALL_STATE(6684)] = 234612,
  [SMALL_STATE(6685)] = 234748,
  [SMALL_STATE(6686)] = 234848,
  [SMALL_STATE(6687)] = 234984,
  [SMALL_STATE(6688)] = 235120,
  [SMALL_STATE(6689)] = 235204,
  [SMALL_STATE(6690)] = 235340,
  [SMALL_STATE(6691)] = 235476,
  [SMALL_STATE(6692)] = 235567,
  [SMALL_STATE(6693)] = 235700,
  [SMALL_STATE(6694)] = 235801,
  [SMALL_STATE(6695)] = 235934,
  [SMALL_STATE(6696)] = 236067,
  [SMALL_STATE(6697)] = 236148,
  [SMALL_STATE(6698)] = 236281,
  [SMALL_STATE(6699)] = 236370,
  [SMALL_STATE(6700)] = 236451,
  [SMALL_STATE(6701)] = 236584,
  [SMALL_STATE(6702)] = 236717,
  [SMALL_STATE(6703)] = 236798,
  [SMALL_STATE(6704)] = 236931,
  [SMALL_STATE(6705)] = 237064,
  [SMALL_STATE(6706)] = 237197,
  [SMALL_STATE(6707)] = 237330,
  [SMALL_STATE(6708)] = 237463,
  [SMALL_STATE(6709)] = 237596,
  [SMALL_STATE(6710)] = 237729,
  [SMALL_STATE(6711)] = 237810,
  [SMALL_STATE(6712)] = 237891,
  [SMALL_STATE(6713)] = 237982,
  [SMALL_STATE(6714)] = 238115,
  [SMALL_STATE(6715)] = 238206,
  [SMALL_STATE(6716)] = 238339,
  [SMALL_STATE(6717)] = 238436,
  [SMALL_STATE(6718)] = 238569,
  [SMALL_STATE(6719)] = 238702,
  [SMALL_STATE(6720)] = 238835,
  [SMALL_STATE(6721)] = 238918,
  [SMALL_STATE(6722)] = 239019,
  [SMALL_STATE(6723)] = 239152,
  [SMALL_STATE(6724)] = 239285,
  [SMALL_STATE(6725)] = 239382,
  [SMALL_STATE(6726)] = 239473,
  [SMALL_STATE(6727)] = 239606,
  [SMALL_STATE(6728)] = 239739,
  [SMALL_STATE(6729)] = 239830,
  [SMALL_STATE(6730)] = 239963,
  [SMALL_STATE(6731)] = 240054,
  [SMALL_STATE(6732)] = 240143,
  [SMALL_STATE(6733)] = 240276,
  [SMALL_STATE(6734)] = 240373,
  [SMALL_STATE(6735)] = 240506,
  [SMALL_STATE(6736)] = 240639,
  [SMALL_STATE(6737)] = 240772,
  [SMALL_STATE(6738)] = 240855,
  [SMALL_STATE(6739)] = 240948,
  [SMALL_STATE(6740)] = 241029,
  [SMALL_STATE(6741)] = 241162,
  [SMALL_STATE(6742)] = 241295,
  [SMALL_STATE(6743)] = 241428,
  [SMALL_STATE(6744)] = 241517,
  [SMALL_STATE(6745)] = 241650,
  [SMALL_STATE(6746)] = 241731,
  [SMALL_STATE(6747)] = 241828,
  [SMALL_STATE(6748)] = 241961,
  [SMALL_STATE(6749)] = 242043,
  [SMALL_STATE(6750)] = 242133,
  [SMALL_STATE(6751)] = 242223,
  [SMALL_STATE(6752)] = 242321,
  [SMALL_STATE(6753)] = 242415,
  [SMALL_STATE(6754)] = 242515,
  [SMALL_STATE(6755)] = 242613,
  [SMALL_STATE(6756)] = 242695,
  [SMALL_STATE(6757)] = 242785,
  [SMALL_STATE(6758)] = 242875,
  [SMALL_STATE(6759)] = 242975,
  [SMALL_STATE(6760)] = 243065,
  [SMALL_STATE(6761)] = 243155,
  [SMALL_STATE(6762)] = 243253,
  [SMALL_STATE(6763)] = 243341,
  [SMALL_STATE(6764)] = 243431,
  [SMALL_STATE(6765)] = 243521,
  [SMALL_STATE(6766)] = 243611,
  [SMALL_STATE(6767)] = 243698,
  [SMALL_STATE(6768)] = 243789,
  [SMALL_STATE(6769)] = 243880,
  [SMALL_STATE(6770)] = 243965,
  [SMALL_STATE(6771)] = 244060,
  [SMALL_STATE(6772)] = 244147,
  [SMALL_STATE(6773)] = 244242,
  [SMALL_STATE(6774)] = 244329,
  [SMALL_STATE(6775)] = 244424,
  [SMALL_STATE(6776)] = 244505,
  [SMALL_STATE(6777)] = 244600,
  [SMALL_STATE(6778)] = 244697,
  [SMALL_STATE(6779)] = 244789,
  [SMALL_STATE(6780)] = 244881,
  [SMALL_STATE(6781)] = 244973,
  [SMALL_STATE(6782)] = 245065,
  [SMALL_STATE(6783)] = 245157,
  [SMALL_STATE(6784)] = 245249,
  [SMALL_STATE(6785)] = 245341,
  [SMALL_STATE(6786)] = 245433,
  [SMALL_STATE(6787)] = 245525,
  [SMALL_STATE(6788)] = 245617,
  [SMALL_STATE(6789)] = 245709,
  [SMALL_STATE(6790)] = 245801,
  [SMALL_STATE(6791)] = 245895,
  [SMALL_STATE(6792)] = 245987,
  [SMALL_STATE(6793)] = 246079,
  [SMALL_STATE(6794)] = 246171,
  [SMALL_STATE(6795)] = 246263,
  [SMALL_STATE(6796)] = 246349,
  [SMALL_STATE(6797)] = 246441,
  [SMALL_STATE(6798)] = 246533,
  [SMALL_STATE(6799)] = 246625,
  [SMALL_STATE(6800)] = 246717,
  [SMALL_STATE(6801)] = 246809,
  [SMALL_STATE(6802)] = 246901,
  [SMALL_STATE(6803)] = 246995,
  [SMALL_STATE(6804)] = 247087,
  [SMALL_STATE(6805)] = 247179,
  [SMALL_STATE(6806)] = 247259,
  [SMALL_STATE(6807)] = 247351,
  [SMALL_STATE(6808)] = 247443,
  [SMALL_STATE(6809)] = 247535,
  [SMALL_STATE(6810)] = 247624,
  [SMALL_STATE(6811)] = 247713,
  [SMALL_STATE(6812)] = 247802,
  [SMALL_STATE(6813)] = 247891,
  [SMALL_STATE(6814)] = 247976,
  [SMALL_STATE(6815)] = 248067,
  [SMALL_STATE(6816)] = 248156,
  [SMALL_STATE(6817)] = 248245,
  [SMALL_STATE(6818)] = 248334,
  [SMALL_STATE(6819)] = 248423,
  [SMALL_STATE(6820)] = 248512,
  [SMALL_STATE(6821)] = 248597,
  [SMALL_STATE(6822)] = 248688,
  [SMALL_STATE(6823)] = 248777,
  [SMALL_STATE(6824)] = 248854,
  [SMALL_STATE(6825)] = 248945,
  [SMALL_STATE(6826)] = 249034,
  [SMALL_STATE(6827)] = 249115,
  [SMALL_STATE(6828)] = 249204,
  [SMALL_STATE(6829)] = 249293,
  [SMALL_STATE(6830)] = 249383,
  [SMALL_STATE(6831)] = 249473,
  [SMALL_STATE(6832)] = 249563,
  [SMALL_STATE(6833)] = 249653,
  [SMALL_STATE(6834)] = 249739,
  [SMALL_STATE(6835)] = 249829,
  [SMALL_STATE(6836)] = 249915,
  [SMALL_STATE(6837)] = 250001,
  [SMALL_STATE(6838)] = 250091,
  [SMALL_STATE(6839)] = 250181,
  [SMALL_STATE(6840)] = 250271,
  [SMALL_STATE(6841)] = 250361,
  [SMALL_STATE(6842)] = 250451,
  [SMALL_STATE(6843)] = 250541,
  [SMALL_STATE(6844)] = 250631,
  [SMALL_STATE(6845)] = 250717,
  [SMALL_STATE(6846)] = 250807,
  [SMALL_STATE(6847)] = 250897,
  [SMALL_STATE(6848)] = 250983,
  [SMALL_STATE(6849)] = 251073,
  [SMALL_STATE(6850)] = 251159,
  [SMALL_STATE(6851)] = 251245,
  [SMALL_STATE(6852)] = 251331,
  [SMALL_STATE(6853)] = 251417,
  [SMALL_STATE(6854)] = 251507,
  [SMALL_STATE(6855)] = 251597,
  [SMALL_STATE(6856)] = 251683,
  [SMALL_STATE(6857)] = 251773,
  [SMALL_STATE(6858)] = 251863,
  [SMALL_STATE(6859)] = 251953,
  [SMALL_STATE(6860)] = 252043,
  [SMALL_STATE(6861)] = 252133,
  [SMALL_STATE(6862)] = 252223,
  [SMALL_STATE(6863)] = 252313,
  [SMALL_STATE(6864)] = 252403,
  [SMALL_STATE(6865)] = 252491,
  [SMALL_STATE(6866)] = 252581,
  [SMALL_STATE(6867)] = 252671,
  [SMALL_STATE(6868)] = 252761,
  [SMALL_STATE(6869)] = 252847,
  [SMALL_STATE(6870)] = 252937,
  [SMALL_STATE(6871)] = 253027,
  [SMALL_STATE(6872)] = 253117,
  [SMALL_STATE(6873)] = 253207,
  [SMALL_STATE(6874)] = 253297,
  [SMALL_STATE(6875)] = 253387,
  [SMALL_STATE(6876)] = 253473,
  [SMALL_STATE(6877)] = 253563,
  [SMALL_STATE(6878)] = 253653,
  [SMALL_STATE(6879)] = 253743,
  [SMALL_STATE(6880)] = 253829,
  [SMALL_STATE(6881)] = 253919,
  [SMALL_STATE(6882)] = 254009,
  [SMALL_STATE(6883)] = 254099,
  [SMALL_STATE(6884)] = 254189,
  [SMALL_STATE(6885)] = 254279,
  [SMALL_STATE(6886)] = 254369,
  [SMALL_STATE(6887)] = 254459,
  [SMALL_STATE(6888)] = 254549,
  [SMALL_STATE(6889)] = 254639,
  [SMALL_STATE(6890)] = 254717,
  [SMALL_STATE(6891)] = 254807,
  [SMALL_STATE(6892)] = 254897,
  [SMALL_STATE(6893)] = 254987,
  [SMALL_STATE(6894)] = 255077,
  [SMALL_STATE(6895)] = 255167,
  [SMALL_STATE(6896)] = 255257,
  [SMALL_STATE(6897)] = 255347,
  [SMALL_STATE(6898)] = 255433,
  [SMALL_STATE(6899)] = 255523,
  [SMALL_STATE(6900)] = 255613,
  [SMALL_STATE(6901)] = 255703,
  [SMALL_STATE(6902)] = 255781,
  [SMALL_STATE(6903)] = 255871,
  [SMALL_STATE(6904)] = 255961,
  [SMALL_STATE(6905)] = 256047,
  [SMALL_STATE(6906)] = 256137,
  [SMALL_STATE(6907)] = 256227,
  [SMALL_STATE(6908)] = 256317,
  [SMALL_STATE(6909)] = 256407,
  [SMALL_STATE(6910)] = 256497,
  [SMALL_STATE(6911)] = 256582,
  [SMALL_STATE(6912)] = 256667,
  [SMALL_STATE(6913)] = 256752,
  [SMALL_STATE(6914)] = 256837,
  [SMALL_STATE(6915)] = 256922,
  [SMALL_STATE(6916)] = 257007,
  [SMALL_STATE(6917)] = 257092,
  [SMALL_STATE(6918)] = 257177,
  [SMALL_STATE(6919)] = 257262,
  [SMALL_STATE(6920)] = 257349,
  [SMALL_STATE(6921)] = 257434,
  [SMALL_STATE(6922)] = 257519,
  [SMALL_STATE(6923)] = 257604,
  [SMALL_STATE(6924)] = 257679,
  [SMALL_STATE(6925)] = 257766,
  [SMALL_STATE(6926)] = 257851,
  [SMALL_STATE(6927)] = 257936,
  [SMALL_STATE(6928)] = 258021,
  [SMALL_STATE(6929)] = 258106,
  [SMALL_STATE(6930)] = 258193,
  [SMALL_STATE(6931)] = 258276,
  [SMALL_STATE(6932)] = 258363,
  [SMALL_STATE(6933)] = 258448,
  [SMALL_STATE(6934)] = 258533,
  [SMALL_STATE(6935)] = 258618,
  [SMALL_STATE(6936)] = 258705,
  [SMALL_STATE(6937)] = 258790,
  [SMALL_STATE(6938)] = 258875,
  [SMALL_STATE(6939)] = 258960,
  [SMALL_STATE(6940)] = 259035,
  [SMALL_STATE(6941)] = 259118,
  [SMALL_STATE(6942)] = 259203,
  [SMALL_STATE(6943)] = 259288,
  [SMALL_STATE(6944)] = 259373,
  [SMALL_STATE(6945)] = 259456,
  [SMALL_STATE(6946)] = 259537,
  [SMALL_STATE(6947)] = 259624,
  [SMALL_STATE(6948)] = 259705,
  [SMALL_STATE(6949)] = 259790,
  [SMALL_STATE(6950)] = 259877,
  [SMALL_STATE(6951)] = 259962,
  [SMALL_STATE(6952)] = 260049,
  [SMALL_STATE(6953)] = 260136,
  [SMALL_STATE(6954)] = 260219,
  [SMALL_STATE(6955)] = 260306,
  [SMALL_STATE(6956)] = 260391,
  [SMALL_STATE(6957)] = 260475,
  [SMALL_STATE(6958)] = 260559,
  [SMALL_STATE(6959)] = 260641,
  [SMALL_STATE(6960)] = 260725,
  [SMALL_STATE(6961)] = 260809,
  [SMALL_STATE(6962)] = 260893,
  [SMALL_STATE(6963)] = 260977,
  [SMALL_STATE(6964)] = 261059,
  [SMALL_STATE(6965)] = 261143,
  [SMALL_STATE(6966)] = 261227,
  [SMALL_STATE(6967)] = 261311,
  [SMALL_STATE(6968)] = 261395,
  [SMALL_STATE(6969)] = 261477,
  [SMALL_STATE(6970)] = 261561,
  [SMALL_STATE(6971)] = 261637,
  [SMALL_STATE(6972)] = 261721,
  [SMALL_STATE(6973)] = 261805,
  [SMALL_STATE(6974)] = 261889,
  [SMALL_STATE(6975)] = 261971,
  [SMALL_STATE(6976)] = 262055,
  [SMALL_STATE(6977)] = 262139,
  [SMALL_STATE(6978)] = 262223,
  [SMALL_STATE(6979)] = 262307,
  [SMALL_STATE(6980)] = 262391,
  [SMALL_STATE(6981)] = 262473,
  [SMALL_STATE(6982)] = 262557,
  [SMALL_STATE(6983)] = 262641,
  [SMALL_STATE(6984)] = 262725,
  [SMALL_STATE(6985)] = 262809,
  [SMALL_STATE(6986)] = 262891,
  [SMALL_STATE(6987)] = 262975,
  [SMALL_STATE(6988)] = 263059,
  [SMALL_STATE(6989)] = 263143,
  [SMALL_STATE(6990)] = 263225,
  [SMALL_STATE(6991)] = 263309,
  [SMALL_STATE(6992)] = 263393,
  [SMALL_STATE(6993)] = 263477,
  [SMALL_STATE(6994)] = 263559,
  [SMALL_STATE(6995)] = 263643,
  [SMALL_STATE(6996)] = 263727,
  [SMALL_STATE(6997)] = 263811,
  [SMALL_STATE(6998)] = 263893,
  [SMALL_STATE(6999)] = 263977,
  [SMALL_STATE(7000)] = 264061,
  [SMALL_STATE(7001)] = 264145,
  [SMALL_STATE(7002)] = 264229,
  [SMALL_STATE(7003)] = 264311,
  [SMALL_STATE(7004)] = 264395,
  [SMALL_STATE(7005)] = 264479,
  [SMALL_STATE(7006)] = 264561,
  [SMALL_STATE(7007)] = 264645,
  [SMALL_STATE(7008)] = 264727,
  [SMALL_STATE(7009)] = 264811,
  [SMALL_STATE(7010)] = 264895,
  [SMALL_STATE(7011)] = 264979,
  [SMALL_STATE(7012)] = 265061,
  [SMALL_STATE(7013)] = 265145,
  [SMALL_STATE(7014)] = 265229,
  [SMALL_STATE(7015)] = 265313,
  [SMALL_STATE(7016)] = 265395,
  [SMALL_STATE(7017)] = 265479,
  [SMALL_STATE(7018)] = 265563,
  [SMALL_STATE(7019)] = 265647,
  [SMALL_STATE(7020)] = 265729,
  [SMALL_STATE(7021)] = 265813,
  [SMALL_STATE(7022)] = 265897,
  [SMALL_STATE(7023)] = 265981,
  [SMALL_STATE(7024)] = 266063,
  [SMALL_STATE(7025)] = 266147,
  [SMALL_STATE(7026)] = 266231,
  [SMALL_STATE(7027)] = 266315,
  [SMALL_STATE(7028)] = 266399,
  [SMALL_STATE(7029)] = 266481,
  [SMALL_STATE(7030)] = 266565,
  [SMALL_STATE(7031)] = 266649,
  [SMALL_STATE(7032)] = 266733,
  [SMALL_STATE(7033)] = 266817,
  [SMALL_STATE(7034)] = 266899,
  [SMALL_STATE(7035)] = 266983,
  [SMALL_STATE(7036)] = 267067,
  [SMALL_STATE(7037)] = 267151,
  [SMALL_STATE(7038)] = 267233,
  [SMALL_STATE(7039)] = 267317,
  [SMALL_STATE(7040)] = 267401,
  [SMALL_STATE(7041)] = 267485,
  [SMALL_STATE(7042)] = 267567,
  [SMALL_STATE(7043)] = 267651,
  [SMALL_STATE(7044)] = 267735,
  [SMALL_STATE(7045)] = 267819,
  [SMALL_STATE(7046)] = 267901,
  [SMALL_STATE(7047)] = 267985,
  [SMALL_STATE(7048)] = 268069,
  [SMALL_STATE(7049)] = 268151,
  [SMALL_STATE(7050)] = 268235,
  [SMALL_STATE(7051)] = 268317,
  [SMALL_STATE(7052)] = 268401,
  [SMALL_STATE(7053)] = 268485,
  [SMALL_STATE(7054)] = 268569,
  [SMALL_STATE(7055)] = 268651,
  [SMALL_STATE(7056)] = 268735,
  [SMALL_STATE(7057)] = 268819,
  [SMALL_STATE(7058)] = 268903,
  [SMALL_STATE(7059)] = 268985,
  [SMALL_STATE(7060)] = 269069,
  [SMALL_STATE(7061)] = 269153,
  [SMALL_STATE(7062)] = 269237,
  [SMALL_STATE(7063)] = 269319,
  [SMALL_STATE(7064)] = 269403,
  [SMALL_STATE(7065)] = 269487,
  [SMALL_STATE(7066)] = 269571,
  [SMALL_STATE(7067)] = 269653,
  [SMALL_STATE(7068)] = 269737,
  [SMALL_STATE(7069)] = 269821,
  [SMALL_STATE(7070)] = 269905,
  [SMALL_STATE(7071)] = 269987,
  [SMALL_STATE(7072)] = 270071,
  [SMALL_STATE(7073)] = 270155,
  [SMALL_STATE(7074)] = 270239,
  [SMALL_STATE(7075)] = 270321,
  [SMALL_STATE(7076)] = 270405,
  [SMALL_STATE(7077)] = 270489,
  [SMALL_STATE(7078)] = 270573,
  [SMALL_STATE(7079)] = 270655,
  [SMALL_STATE(7080)] = 270739,
  [SMALL_STATE(7081)] = 270823,
  [SMALL_STATE(7082)] = 270907,
  [SMALL_STATE(7083)] = 270989,
  [SMALL_STATE(7084)] = 271073,
  [SMALL_STATE(7085)] = 271157,
  [SMALL_STATE(7086)] = 271241,
  [SMALL_STATE(7087)] = 271323,
  [SMALL_STATE(7088)] = 271407,
  [SMALL_STATE(7089)] = 271491,
  [SMALL_STATE(7090)] = 271575,
  [SMALL_STATE(7091)] = 271659,
  [SMALL_STATE(7092)] = 271743,
  [SMALL_STATE(7093)] = 271825,
  [SMALL_STATE(7094)] = 271909,
  [SMALL_STATE(7095)] = 271993,
  [SMALL_STATE(7096)] = 272077,
  [SMALL_STATE(7097)] = 272159,
  [SMALL_STATE(7098)] = 272243,
  [SMALL_STATE(7099)] = 272327,
  [SMALL_STATE(7100)] = 272411,
  [SMALL_STATE(7101)] = 272493,
  [SMALL_STATE(7102)] = 272577,
  [SMALL_STATE(7103)] = 272661,
  [SMALL_STATE(7104)] = 272745,
  [SMALL_STATE(7105)] = 272829,
  [SMALL_STATE(7106)] = 272913,
  [SMALL_STATE(7107)] = 272995,
  [SMALL_STATE(7108)] = 273079,
  [SMALL_STATE(7109)] = 273163,
  [SMALL_STATE(7110)] = 273247,
  [SMALL_STATE(7111)] = 273331,
  [SMALL_STATE(7112)] = 273415,
  [SMALL_STATE(7113)] = 273499,
  [SMALL_STATE(7114)] = 273583,
  [SMALL_STATE(7115)] = 273667,
  [SMALL_STATE(7116)] = 273751,
  [SMALL_STATE(7117)] = 273835,
  [SMALL_STATE(7118)] = 273919,
  [SMALL_STATE(7119)] = 274003,
  [SMALL_STATE(7120)] = 274087,
  [SMALL_STATE(7121)] = 274171,
  [SMALL_STATE(7122)] = 274253,
  [SMALL_STATE(7123)] = 274337,
  [SMALL_STATE(7124)] = 274421,
  [SMALL_STATE(7125)] = 274505,
  [SMALL_STATE(7126)] = 274589,
  [SMALL_STATE(7127)] = 274673,
  [SMALL_STATE(7128)] = 274757,
  [SMALL_STATE(7129)] = 274841,
  [SMALL_STATE(7130)] = 274925,
  [SMALL_STATE(7131)] = 275007,
  [SMALL_STATE(7132)] = 275091,
  [SMALL_STATE(7133)] = 275173,
  [SMALL_STATE(7134)] = 275257,
  [SMALL_STATE(7135)] = 275341,
  [SMALL_STATE(7136)] = 275425,
  [SMALL_STATE(7137)] = 275509,
  [SMALL_STATE(7138)] = 275593,
  [SMALL_STATE(7139)] = 275677,
  [SMALL_STATE(7140)] = 275761,
  [SMALL_STATE(7141)] = 275845,
  [SMALL_STATE(7142)] = 275929,
  [SMALL_STATE(7143)] = 276013,
  [SMALL_STATE(7144)] = 276097,
  [SMALL_STATE(7145)] = 276179,
  [SMALL_STATE(7146)] = 276263,
  [SMALL_STATE(7147)] = 276347,
  [SMALL_STATE(7148)] = 276431,
  [SMALL_STATE(7149)] = 276515,
  [SMALL_STATE(7150)] = 276599,
  [SMALL_STATE(7151)] = 276683,
  [SMALL_STATE(7152)] = 276767,
  [SMALL_STATE(7153)] = 276849,
  [SMALL_STATE(7154)] = 276933,
  [SMALL_STATE(7155)] = 277017,
  [SMALL_STATE(7156)] = 277101,
  [SMALL_STATE(7157)] = 277183,
  [SMALL_STATE(7158)] = 277267,
  [SMALL_STATE(7159)] = 277351,
  [SMALL_STATE(7160)] = 277435,
  [SMALL_STATE(7161)] = 277517,
  [SMALL_STATE(7162)] = 277601,
  [SMALL_STATE(7163)] = 277685,
  [SMALL_STATE(7164)] = 277769,
  [SMALL_STATE(7165)] = 277853,
  [SMALL_STATE(7166)] = 277935,
  [SMALL_STATE(7167)] = 278019,
  [SMALL_STATE(7168)] = 278100,
  [SMALL_STATE(7169)] = 278181,
  [SMALL_STATE(7170)] = 278262,
  [SMALL_STATE(7171)] = 278343,
  [SMALL_STATE(7172)] = 278422,
  [SMALL_STATE(7173)] = 278503,
  [SMALL_STATE(7174)] = 278584,
  [SMALL_STATE(7175)] = 278665,
  [SMALL_STATE(7176)] = 278746,
  [SMALL_STATE(7177)] = 278827,
  [SMALL_STATE(7178)] = 278908,
  [SMALL_STATE(7179)] = 278987,
  [SMALL_STATE(7180)] = 279068,
  [SMALL_STATE(7181)] = 279149,
  [SMALL_STATE(7182)] = 279230,
  [SMALL_STATE(7183)] = 279311,
  [SMALL_STATE(7184)] = 279392,
  [SMALL_STATE(7185)] = 279471,
  [SMALL_STATE(7186)] = 279552,
  [SMALL_STATE(7187)] = 279633,
  [SMALL_STATE(7188)] = 279714,
  [SMALL_STATE(7189)] = 279795,
  [SMALL_STATE(7190)] = 279876,
  [SMALL_STATE(7191)] = 279957,
  [SMALL_STATE(7192)] = 280038,
  [SMALL_STATE(7193)] = 280119,
  [SMALL_STATE(7194)] = 280200,
  [SMALL_STATE(7195)] = 280281,
  [SMALL_STATE(7196)] = 280362,
  [SMALL_STATE(7197)] = 280443,
  [SMALL_STATE(7198)] = 280524,
  [SMALL_STATE(7199)] = 280605,
  [SMALL_STATE(7200)] = 280686,
  [SMALL_STATE(7201)] = 280767,
  [SMALL_STATE(7202)] = 280848,
  [SMALL_STATE(7203)] = 280929,
  [SMALL_STATE(7204)] = 281010,
  [SMALL_STATE(7205)] = 281091,
  [SMALL_STATE(7206)] = 281172,
  [SMALL_STATE(7207)] = 281251,
  [SMALL_STATE(7208)] = 281332,
  [SMALL_STATE(7209)] = 281411,
  [SMALL_STATE(7210)] = 281492,
  [SMALL_STATE(7211)] = 281573,
  [SMALL_STATE(7212)] = 281654,
  [SMALL_STATE(7213)] = 281735,
  [SMALL_STATE(7214)] = 281814,
  [SMALL_STATE(7215)] = 281895,
  [SMALL_STATE(7216)] = 281976,
  [SMALL_STATE(7217)] = 282057,
  [SMALL_STATE(7218)] = 282136,
  [SMALL_STATE(7219)] = 282217,
  [SMALL_STATE(7220)] = 282298,
  [SMALL_STATE(7221)] = 282379,
  [SMALL_STATE(7222)] = 282460,
  [SMALL_STATE(7223)] = 282541,
  [SMALL_STATE(7224)] = 282622,
  [SMALL_STATE(7225)] = 282703,
  [SMALL_STATE(7226)] = 282784,
  [SMALL_STATE(7227)] = 282865,
  [SMALL_STATE(7228)] = 282946,
  [SMALL_STATE(7229)] = 283027,
  [SMALL_STATE(7230)] = 283108,
  [SMALL_STATE(7231)] = 283189,
  [SMALL_STATE(7232)] = 283270,
  [SMALL_STATE(7233)] = 283351,
  [SMALL_STATE(7234)] = 283432,
  [SMALL_STATE(7235)] = 283513,
  [SMALL_STATE(7236)] = 283594,
  [SMALL_STATE(7237)] = 283675,
  [SMALL_STATE(7238)] = 283756,
  [SMALL_STATE(7239)] = 283837,
  [SMALL_STATE(7240)] = 283918,
  [SMALL_STATE(7241)] = 283999,
  [SMALL_STATE(7242)] = 284080,
  [SMALL_STATE(7243)] = 284159,
  [SMALL_STATE(7244)] = 284240,
  [SMALL_STATE(7245)] = 284321,
  [SMALL_STATE(7246)] = 284402,
  [SMALL_STATE(7247)] = 284483,
  [SMALL_STATE(7248)] = 284564,
  [SMALL_STATE(7249)] = 284645,
  [SMALL_STATE(7250)] = 284726,
  [SMALL_STATE(7251)] = 284807,
  [SMALL_STATE(7252)] = 284888,
  [SMALL_STATE(7253)] = 284969,
  [SMALL_STATE(7254)] = 285048,
  [SMALL_STATE(7255)] = 285129,
  [SMALL_STATE(7256)] = 285210,
  [SMALL_STATE(7257)] = 285291,
  [SMALL_STATE(7258)] = 285372,
  [SMALL_STATE(7259)] = 285453,
  [SMALL_STATE(7260)] = 285534,
  [SMALL_STATE(7261)] = 285615,
  [SMALL_STATE(7262)] = 285696,
  [SMALL_STATE(7263)] = 285777,
  [SMALL_STATE(7264)] = 285858,
  [SMALL_STATE(7265)] = 285939,
  [SMALL_STATE(7266)] = 286020,
  [SMALL_STATE(7267)] = 286101,
  [SMALL_STATE(7268)] = 286182,
  [SMALL_STATE(7269)] = 286263,
  [SMALL_STATE(7270)] = 286344,
  [SMALL_STATE(7271)] = 286425,
  [SMALL_STATE(7272)] = 286506,
  [SMALL_STATE(7273)] = 286587,
  [SMALL_STATE(7274)] = 286668,
  [SMALL_STATE(7275)] = 286749,
  [SMALL_STATE(7276)] = 286828,
  [SMALL_STATE(7277)] = 286909,
  [SMALL_STATE(7278)] = 286990,
  [SMALL_STATE(7279)] = 287071,
  [SMALL_STATE(7280)] = 287152,
  [SMALL_STATE(7281)] = 287233,
  [SMALL_STATE(7282)] = 287314,
  [SMALL_STATE(7283)] = 287395,
  [SMALL_STATE(7284)] = 287476,
  [SMALL_STATE(7285)] = 287557,
  [SMALL_STATE(7286)] = 287638,
  [SMALL_STATE(7287)] = 287719,
  [SMALL_STATE(7288)] = 287800,
  [SMALL_STATE(7289)] = 287881,
  [SMALL_STATE(7290)] = 287962,
  [SMALL_STATE(7291)] = 288043,
  [SMALL_STATE(7292)] = 288115,
  [SMALL_STATE(7293)] = 288187,
  [SMALL_STATE(7294)] = 288265,
  [SMALL_STATE(7295)] = 288337,
  [SMALL_STATE(7296)] = 288415,
  [SMALL_STATE(7297)] = 288493,
  [SMALL_STATE(7298)] = 288571,
  [SMALL_STATE(7299)] = 288649,
  [SMALL_STATE(7300)] = 288721,
  [SMALL_STATE(7301)] = 288793,
  [SMALL_STATE(7302)] = 288868,
  [SMALL_STATE(7303)] = 288943,
  [SMALL_STATE(7304)] = 289018,
  [SMALL_STATE(7305)] = 289093,
  [SMALL_STATE(7306)] = 289168,
  [SMALL_STATE(7307)] = 289243,
  [SMALL_STATE(7308)] = 289318,
  [SMALL_STATE(7309)] = 289393,
  [SMALL_STATE(7310)] = 289468,
  [SMALL_STATE(7311)] = 289543,
  [SMALL_STATE(7312)] = 289618,
  [SMALL_STATE(7313)] = 289693,
  [SMALL_STATE(7314)] = 289768,
  [SMALL_STATE(7315)] = 289843,
  [SMALL_STATE(7316)] = 289918,
  [SMALL_STATE(7317)] = 289993,
  [SMALL_STATE(7318)] = 290068,
  [SMALL_STATE(7319)] = 290143,
  [SMALL_STATE(7320)] = 290218,
  [SMALL_STATE(7321)] = 290293,
  [SMALL_STATE(7322)] = 290368,
  [SMALL_STATE(7323)] = 290443,
  [SMALL_STATE(7324)] = 290518,
  [SMALL_STATE(7325)] = 290593,
  [SMALL_STATE(7326)] = 290668,
  [SMALL_STATE(7327)] = 290743,
  [SMALL_STATE(7328)] = 290818,
  [SMALL_STATE(7329)] = 290893,
  [SMALL_STATE(7330)] = 290968,
  [SMALL_STATE(7331)] = 291043,
  [SMALL_STATE(7332)] = 291118,
  [SMALL_STATE(7333)] = 291193,
  [SMALL_STATE(7334)] = 291268,
  [SMALL_STATE(7335)] = 291343,
  [SMALL_STATE(7336)] = 291418,
  [SMALL_STATE(7337)] = 291493,
  [SMALL_STATE(7338)] = 291568,
  [SMALL_STATE(7339)] = 291643,
  [SMALL_STATE(7340)] = 291718,
  [SMALL_STATE(7341)] = 291793,
  [SMALL_STATE(7342)] = 291868,
  [SMALL_STATE(7343)] = 291943,
  [SMALL_STATE(7344)] = 292018,
  [SMALL_STATE(7345)] = 292093,
  [SMALL_STATE(7346)] = 292168,
  [SMALL_STATE(7347)] = 292243,
  [SMALL_STATE(7348)] = 292318,
  [SMALL_STATE(7349)] = 292393,
  [SMALL_STATE(7350)] = 292468,
  [SMALL_STATE(7351)] = 292543,
  [SMALL_STATE(7352)] = 292618,
  [SMALL_STATE(7353)] = 292693,
  [SMALL_STATE(7354)] = 292768,
  [SMALL_STATE(7355)] = 292843,
  [SMALL_STATE(7356)] = 292918,
  [SMALL_STATE(7357)] = 292993,
  [SMALL_STATE(7358)] = 293068,
  [SMALL_STATE(7359)] = 293143,
  [SMALL_STATE(7360)] = 293218,
  [SMALL_STATE(7361)] = 293293,
  [SMALL_STATE(7362)] = 293368,
  [SMALL_STATE(7363)] = 293443,
  [SMALL_STATE(7364)] = 293518,
  [SMALL_STATE(7365)] = 293593,
  [SMALL_STATE(7366)] = 293668,
  [SMALL_STATE(7367)] = 293743,
  [SMALL_STATE(7368)] = 293818,
  [SMALL_STATE(7369)] = 293893,
  [SMALL_STATE(7370)] = 293968,
  [SMALL_STATE(7371)] = 294043,
  [SMALL_STATE(7372)] = 294118,
  [SMALL_STATE(7373)] = 294193,
  [SMALL_STATE(7374)] = 294268,
  [SMALL_STATE(7375)] = 294343,
  [SMALL_STATE(7376)] = 294418,
  [SMALL_STATE(7377)] = 294493,
  [SMALL_STATE(7378)] = 294568,
  [SMALL_STATE(7379)] = 294643,
  [SMALL_STATE(7380)] = 294718,
  [SMALL_STATE(7381)] = 294793,
  [SMALL_STATE(7382)] = 294868,
  [SMALL_STATE(7383)] = 294943,
  [SMALL_STATE(7384)] = 295018,
  [SMALL_STATE(7385)] = 295093,
  [SMALL_STATE(7386)] = 295168,
  [SMALL_STATE(7387)] = 295243,
  [SMALL_STATE(7388)] = 295318,
  [SMALL_STATE(7389)] = 295393,
  [SMALL_STATE(7390)] = 295468,
  [SMALL_STATE(7391)] = 295543,
  [SMALL_STATE(7392)] = 295618,
  [SMALL_STATE(7393)] = 295693,
  [SMALL_STATE(7394)] = 295768,
  [SMALL_STATE(7395)] = 295843,
  [SMALL_STATE(7396)] = 295918,
  [SMALL_STATE(7397)] = 295993,
  [SMALL_STATE(7398)] = 296068,
  [SMALL_STATE(7399)] = 296143,
  [SMALL_STATE(7400)] = 296218,
  [SMALL_STATE(7401)] = 296290,
  [SMALL_STATE(7402)] = 296362,
  [SMALL_STATE(7403)] = 296434,
  [SMALL_STATE(7404)] = 296506,
  [SMALL_STATE(7405)] = 296578,
  [SMALL_STATE(7406)] = 296650,
  [SMALL_STATE(7407)] = 296719,
  [SMALL_STATE(7408)] = 296788,
  [SMALL_STATE(7409)] = 296857,
  [SMALL_STATE(7410)] = 296926,
  [SMALL_STATE(7411)] = 296995,
  [SMALL_STATE(7412)] = 297062,
  [SMALL_STATE(7413)] = 297131,
  [SMALL_STATE(7414)] = 297217,
  [SMALL_STATE(7415)] = 297303,
  [SMALL_STATE(7416)] = 297389,
  [SMALL_STATE(7417)] = 297475,
  [SMALL_STATE(7418)] = 297561,
  [SMALL_STATE(7419)] = 297647,
  [SMALL_STATE(7420)] = 297733,
  [SMALL_STATE(7421)] = 297819,
  [SMALL_STATE(7422)] = 297905,
  [SMALL_STATE(7423)] = 297991,
  [SMALL_STATE(7424)] = 298077,
  [SMALL_STATE(7425)] = 298163,
  [SMALL_STATE(7426)] = 298249,
  [SMALL_STATE(7427)] = 298335,
  [SMALL_STATE(7428)] = 298421,
  [SMALL_STATE(7429)] = 298507,
  [SMALL_STATE(7430)] = 298593,
  [SMALL_STATE(7431)] = 298679,
  [SMALL_STATE(7432)] = 298765,
  [SMALL_STATE(7433)] = 298851,
  [SMALL_STATE(7434)] = 298937,
  [SMALL_STATE(7435)] = 299023,
  [SMALL_STATE(7436)] = 299109,
  [SMALL_STATE(7437)] = 299195,
  [SMALL_STATE(7438)] = 299281,
  [SMALL_STATE(7439)] = 299367,
  [SMALL_STATE(7440)] = 299453,
  [SMALL_STATE(7441)] = 299539,
  [SMALL_STATE(7442)] = 299625,
  [SMALL_STATE(7443)] = 299711,
  [SMALL_STATE(7444)] = 299797,
  [SMALL_STATE(7445)] = 299883,
  [SMALL_STATE(7446)] = 299969,
  [SMALL_STATE(7447)] = 300055,
  [SMALL_STATE(7448)] = 300141,
  [SMALL_STATE(7449)] = 300227,
  [SMALL_STATE(7450)] = 300310,
  [SMALL_STATE(7451)] = 300393,
  [SMALL_STATE(7452)] = 300476,
  [SMALL_STATE(7453)] = 300559,
  [SMALL_STATE(7454)] = 300642,
  [SMALL_STATE(7455)] = 300725,
  [SMALL_STATE(7456)] = 300808,
  [SMALL_STATE(7457)] = 300891,
  [SMALL_STATE(7458)] = 300974,
  [SMALL_STATE(7459)] = 301057,
  [SMALL_STATE(7460)] = 301140,
  [SMALL_STATE(7461)] = 301223,
  [SMALL_STATE(7462)] = 301306,
  [SMALL_STATE(7463)] = 301389,
  [SMALL_STATE(7464)] = 301472,
  [SMALL_STATE(7465)] = 301555,
  [SMALL_STATE(7466)] = 301638,
  [SMALL_STATE(7467)] = 301721,
  [SMALL_STATE(7468)] = 301804,
  [SMALL_STATE(7469)] = 301887,
  [SMALL_STATE(7470)] = 301970,
  [SMALL_STATE(7471)] = 302053,
  [SMALL_STATE(7472)] = 302136,
  [SMALL_STATE(7473)] = 302219,
  [SMALL_STATE(7474)] = 302302,
  [SMALL_STATE(7475)] = 302385,
  [SMALL_STATE(7476)] = 302468,
  [SMALL_STATE(7477)] = 302551,
  [SMALL_STATE(7478)] = 302634,
  [SMALL_STATE(7479)] = 302717,
  [SMALL_STATE(7480)] = 302800,
  [SMALL_STATE(7481)] = 302883,
  [SMALL_STATE(7482)] = 302966,
  [SMALL_STATE(7483)] = 303049,
  [SMALL_STATE(7484)] = 303132,
  [SMALL_STATE(7485)] = 303215,
  [SMALL_STATE(7486)] = 303298,
  [SMALL_STATE(7487)] = 303381,
  [SMALL_STATE(7488)] = 303464,
  [SMALL_STATE(7489)] = 303547,
  [SMALL_STATE(7490)] = 303630,
  [SMALL_STATE(7491)] = 303713,
  [SMALL_STATE(7492)] = 303796,
  [SMALL_STATE(7493)] = 303879,
  [SMALL_STATE(7494)] = 303962,
  [SMALL_STATE(7495)] = 304045,
  [SMALL_STATE(7496)] = 304128,
  [SMALL_STATE(7497)] = 304211,
  [SMALL_STATE(7498)] = 304294,
  [SMALL_STATE(7499)] = 304377,
  [SMALL_STATE(7500)] = 304460,
  [SMALL_STATE(7501)] = 304543,
  [SMALL_STATE(7502)] = 304626,
  [SMALL_STATE(7503)] = 304709,
  [SMALL_STATE(7504)] = 304792,
  [SMALL_STATE(7505)] = 304875,
  [SMALL_STATE(7506)] = 304958,
  [SMALL_STATE(7507)] = 305041,
  [SMALL_STATE(7508)] = 305124,
  [SMALL_STATE(7509)] = 305207,
  [SMALL_STATE(7510)] = 305295,
  [SMALL_STATE(7511)] = 305383,
  [SMALL_STATE(7512)] = 305471,
  [SMALL_STATE(7513)] = 305543,
  [SMALL_STATE(7514)] = 305621,
  [SMALL_STATE(7515)] = 305699,
  [SMALL_STATE(7516)] = 305777,
  [SMALL_STATE(7517)] = 305855,
  [SMALL_STATE(7518)] = 305933,
  [SMALL_STATE(7519)] = 306011,
  [SMALL_STATE(7520)] = 306089,
  [SMALL_STATE(7521)] = 306167,
  [SMALL_STATE(7522)] = 306245,
  [SMALL_STATE(7523)] = 306323,
  [SMALL_STATE(7524)] = 306401,
  [SMALL_STATE(7525)] = 306479,
  [SMALL_STATE(7526)] = 306554,
  [SMALL_STATE(7527)] = 306629,
  [SMALL_STATE(7528)] = 306704,
  [SMALL_STATE(7529)] = 306779,
  [SMALL_STATE(7530)] = 306854,
  [SMALL_STATE(7531)] = 306911,
  [SMALL_STATE(7532)] = 306986,
  [SMALL_STATE(7533)] = 307061,
  [SMALL_STATE(7534)] = 307136,
  [SMALL_STATE(7535)] = 307211,
  [SMALL_STATE(7536)] = 307286,
  [SMALL_STATE(7537)] = 307361,
  [SMALL_STATE(7538)] = 307436,
  [SMALL_STATE(7539)] = 307511,
  [SMALL_STATE(7540)] = 307586,
  [SMALL_STATE(7541)] = 307661,
  [SMALL_STATE(7542)] = 307736,
  [SMALL_STATE(7543)] = 307811,
  [SMALL_STATE(7544)] = 307886,
  [SMALL_STATE(7545)] = 307961,
  [SMALL_STATE(7546)] = 308036,
  [SMALL_STATE(7547)] = 308111,
  [SMALL_STATE(7548)] = 308186,
  [SMALL_STATE(7549)] = 308261,
  [SMALL_STATE(7550)] = 308336,
  [SMALL_STATE(7551)] = 308408,
  [SMALL_STATE(7552)] = 308480,
  [SMALL_STATE(7553)] = 308552,
  [SMALL_STATE(7554)] = 308624,
  [SMALL_STATE(7555)] = 308696,
  [SMALL_STATE(7556)] = 308766,
  [SMALL_STATE(7557)] = 308838,
  [SMALL_STATE(7558)] = 308910,
  [SMALL_STATE(7559)] = 308980,
  [SMALL_STATE(7560)] = 309050,
  [SMALL_STATE(7561)] = 309120,
  [SMALL_STATE(7562)] = 309192,
  [SMALL_STATE(7563)] = 309264,
  [SMALL_STATE(7564)] = 309336,
  [SMALL_STATE(7565)] = 309408,
  [SMALL_STATE(7566)] = 309480,
  [SMALL_STATE(7567)] = 309549,
  [SMALL_STATE(7568)] = 309618,
  [SMALL_STATE(7569)] = 309687,
  [SMALL_STATE(7570)] = 309756,
  [SMALL_STATE(7571)] = 309825,
  [SMALL_STATE(7572)] = 309894,
  [SMALL_STATE(7573)] = 309963,
  [SMALL_STATE(7574)] = 310032,
  [SMALL_STATE(7575)] = 310101,
  [SMALL_STATE(7576)] = 310170,
  [SMALL_STATE(7577)] = 310239,
  [SMALL_STATE(7578)] = 310308,
  [SMALL_STATE(7579)] = 310377,
  [SMALL_STATE(7580)] = 310446,
  [SMALL_STATE(7581)] = 310515,
  [SMALL_STATE(7582)] = 310584,
  [SMALL_STATE(7583)] = 310653,
  [SMALL_STATE(7584)] = 310722,
  [SMALL_STATE(7585)] = 310789,
  [SMALL_STATE(7586)] = 310858,
  [SMALL_STATE(7587)] = 310927,
  [SMALL_STATE(7588)] = 310996,
  [SMALL_STATE(7589)] = 311065,
  [SMALL_STATE(7590)] = 311134,
  [SMALL_STATE(7591)] = 311203,
  [SMALL_STATE(7592)] = 311272,
  [SMALL_STATE(7593)] = 311341,
  [SMALL_STATE(7594)] = 311396,
  [SMALL_STATE(7595)] = 311465,
  [SMALL_STATE(7596)] = 311534,
  [SMALL_STATE(7597)] = 311603,
  [SMALL_STATE(7598)] = 311672,
  [SMALL_STATE(7599)] = 311741,
  [SMALL_STATE(7600)] = 311810,
  [SMALL_STATE(7601)] = 311879,
  [SMALL_STATE(7602)] = 311936,
  [SMALL_STATE(7603)] = 312005,
  [SMALL_STATE(7604)] = 312074,
  [SMALL_STATE(7605)] = 312143,
  [SMALL_STATE(7606)] = 312212,
  [SMALL_STATE(7607)] = 312281,
  [SMALL_STATE(7608)] = 312350,
  [SMALL_STATE(7609)] = 312419,
  [SMALL_STATE(7610)] = 312480,
  [SMALL_STATE(7611)] = 312549,
  [SMALL_STATE(7612)] = 312618,
  [SMALL_STATE(7613)] = 312687,
  [SMALL_STATE(7614)] = 312756,
  [SMALL_STATE(7615)] = 312825,
  [SMALL_STATE(7616)] = 312882,
  [SMALL_STATE(7617)] = 312939,
  [SMALL_STATE(7618)] = 313008,
  [SMALL_STATE(7619)] = 313077,
  [SMALL_STATE(7620)] = 313146,
  [SMALL_STATE(7621)] = 313215,
  [SMALL_STATE(7622)] = 313284,
  [SMALL_STATE(7623)] = 313353,
  [SMALL_STATE(7624)] = 313422,
  [SMALL_STATE(7625)] = 313491,
  [SMALL_STATE(7626)] = 313560,
  [SMALL_STATE(7627)] = 313629,
  [SMALL_STATE(7628)] = 313698,
  [SMALL_STATE(7629)] = 313767,
  [SMALL_STATE(7630)] = 313836,
  [SMALL_STATE(7631)] = 313905,
  [SMALL_STATE(7632)] = 313974,
  [SMALL_STATE(7633)] = 314043,
  [SMALL_STATE(7634)] = 314112,
  [SMALL_STATE(7635)] = 314181,
  [SMALL_STATE(7636)] = 314250,
  [SMALL_STATE(7637)] = 314317,
  [SMALL_STATE(7638)] = 314386,
  [SMALL_STATE(7639)] = 314455,
  [SMALL_STATE(7640)] = 314524,
  [SMALL_STATE(7641)] = 314593,
  [SMALL_STATE(7642)] = 314662,
  [SMALL_STATE(7643)] = 314731,
  [SMALL_STATE(7644)] = 314800,
  [SMALL_STATE(7645)] = 314869,
  [SMALL_STATE(7646)] = 314938,
  [SMALL_STATE(7647)] = 315007,
  [SMALL_STATE(7648)] = 315076,
  [SMALL_STATE(7649)] = 315145,
  [SMALL_STATE(7650)] = 315214,
  [SMALL_STATE(7651)] = 315283,
  [SMALL_STATE(7652)] = 315352,
  [SMALL_STATE(7653)] = 315421,
  [SMALL_STATE(7654)] = 315490,
  [SMALL_STATE(7655)] = 315559,
  [SMALL_STATE(7656)] = 315628,
  [SMALL_STATE(7657)] = 315697,
  [SMALL_STATE(7658)] = 315766,
  [SMALL_STATE(7659)] = 315835,
  [SMALL_STATE(7660)] = 315904,
  [SMALL_STATE(7661)] = 315973,
  [SMALL_STATE(7662)] = 316042,
  [SMALL_STATE(7663)] = 316111,
  [SMALL_STATE(7664)] = 316180,
  [SMALL_STATE(7665)] = 316249,
  [SMALL_STATE(7666)] = 316318,
  [SMALL_STATE(7667)] = 316387,
  [SMALL_STATE(7668)] = 316456,
  [SMALL_STATE(7669)] = 316525,
  [SMALL_STATE(7670)] = 316594,
  [SMALL_STATE(7671)] = 316663,
  [SMALL_STATE(7672)] = 316730,
  [SMALL_STATE(7673)] = 316799,
  [SMALL_STATE(7674)] = 316868,
  [SMALL_STATE(7675)] = 316937,
  [SMALL_STATE(7676)] = 317004,
  [SMALL_STATE(7677)] = 317073,
  [SMALL_STATE(7678)] = 317139,
  [SMALL_STATE(7679)] = 317205,
  [SMALL_STATE(7680)] = 317271,
  [SMALL_STATE(7681)] = 317337,
  [SMALL_STATE(7682)] = 317403,
  [SMALL_STATE(7683)] = 317469,
  [SMALL_STATE(7684)] = 317535,
  [SMALL_STATE(7685)] = 317601,
  [SMALL_STATE(7686)] = 317667,
  [SMALL_STATE(7687)] = 317733,
  [SMALL_STATE(7688)] = 317799,
  [SMALL_STATE(7689)] = 317865,
  [SMALL_STATE(7690)] = 317931,
  [SMALL_STATE(7691)] = 317997,
  [SMALL_STATE(7692)] = 318063,
  [SMALL_STATE(7693)] = 318125,
  [SMALL_STATE(7694)] = 318191,
  [SMALL_STATE(7695)] = 318257,
  [SMALL_STATE(7696)] = 318309,
  [SMALL_STATE(7697)] = 318375,
  [SMALL_STATE(7698)] = 318441,
  [SMALL_STATE(7699)] = 318493,
  [SMALL_STATE(7700)] = 318559,
  [SMALL_STATE(7701)] = 318625,
  [SMALL_STATE(7702)] = 318691,
  [SMALL_STATE(7703)] = 318757,
  [SMALL_STATE(7704)] = 318823,
  [SMALL_STATE(7705)] = 318889,
  [SMALL_STATE(7706)] = 318955,
  [SMALL_STATE(7707)] = 319021,
  [SMALL_STATE(7708)] = 319087,
  [SMALL_STATE(7709)] = 319153,
  [SMALL_STATE(7710)] = 319219,
  [SMALL_STATE(7711)] = 319282,
  [SMALL_STATE(7712)] = 319343,
  [SMALL_STATE(7713)] = 319406,
  [SMALL_STATE(7714)] = 319467,
  [SMALL_STATE(7715)] = 319530,
  [SMALL_STATE(7716)] = 319593,
  [SMALL_STATE(7717)] = 319656,
  [SMALL_STATE(7718)] = 319707,
  [SMALL_STATE(7719)] = 319770,
  [SMALL_STATE(7720)] = 319833,
  [SMALL_STATE(7721)] = 319896,
  [SMALL_STATE(7722)] = 319957,
  [SMALL_STATE(7723)] = 320020,
  [SMALL_STATE(7724)] = 320083,
  [SMALL_STATE(7725)] = 320146,
  [SMALL_STATE(7726)] = 320207,
  [SMALL_STATE(7727)] = 320270,
  [SMALL_STATE(7728)] = 320331,
  [SMALL_STATE(7729)] = 320394,
  [SMALL_STATE(7730)] = 320455,
  [SMALL_STATE(7731)] = 320518,
  [SMALL_STATE(7732)] = 320581,
  [SMALL_STATE(7733)] = 320644,
  [SMALL_STATE(7734)] = 320705,
  [SMALL_STATE(7735)] = 320768,
  [SMALL_STATE(7736)] = 320831,
  [SMALL_STATE(7737)] = 320882,
  [SMALL_STATE(7738)] = 320933,
  [SMALL_STATE(7739)] = 320984,
  [SMALL_STATE(7740)] = 321045,
  [SMALL_STATE(7741)] = 321108,
  [SMALL_STATE(7742)] = 321169,
  [SMALL_STATE(7743)] = 321232,
  [SMALL_STATE(7744)] = 321295,
  [SMALL_STATE(7745)] = 321358,
  [SMALL_STATE(7746)] = 321421,
  [SMALL_STATE(7747)] = 321484,
  [SMALL_STATE(7748)] = 321547,
  [SMALL_STATE(7749)] = 321610,
  [SMALL_STATE(7750)] = 321671,
  [SMALL_STATE(7751)] = 321734,
  [SMALL_STATE(7752)] = 321797,
  [SMALL_STATE(7753)] = 321860,
  [SMALL_STATE(7754)] = 321923,
  [SMALL_STATE(7755)] = 321986,
  [SMALL_STATE(7756)] = 322049,
  [SMALL_STATE(7757)] = 322110,
  [SMALL_STATE(7758)] = 322173,
  [SMALL_STATE(7759)] = 322236,
  [SMALL_STATE(7760)] = 322299,
  [SMALL_STATE(7761)] = 322362,
  [SMALL_STATE(7762)] = 322425,
  [SMALL_STATE(7763)] = 322488,
  [SMALL_STATE(7764)] = 322551,
  [SMALL_STATE(7765)] = 322614,
  [SMALL_STATE(7766)] = 322677,
  [SMALL_STATE(7767)] = 322736,
  [SMALL_STATE(7768)] = 322799,
  [SMALL_STATE(7769)] = 322862,
  [SMALL_STATE(7770)] = 322925,
  [SMALL_STATE(7771)] = 322988,
  [SMALL_STATE(7772)] = 323051,
  [SMALL_STATE(7773)] = 323114,
  [SMALL_STATE(7774)] = 323177,
  [SMALL_STATE(7775)] = 323240,
  [SMALL_STATE(7776)] = 323303,
  [SMALL_STATE(7777)] = 323366,
  [SMALL_STATE(7778)] = 323427,
  [SMALL_STATE(7779)] = 323487,
  [SMALL_STATE(7780)] = 323547,
  [SMALL_STATE(7781)] = 323607,
  [SMALL_STATE(7782)] = 323667,
  [SMALL_STATE(7783)] = 323727,
  [SMALL_STATE(7784)] = 323787,
  [SMALL_STATE(7785)] = 323847,
  [SMALL_STATE(7786)] = 323907,
  [SMALL_STATE(7787)] = 323967,
  [SMALL_STATE(7788)] = 324025,
  [SMALL_STATE(7789)] = 324085,
  [SMALL_STATE(7790)] = 324145,
  [SMALL_STATE(7791)] = 324205,
  [SMALL_STATE(7792)] = 324265,
  [SMALL_STATE(7793)] = 324325,
  [SMALL_STATE(7794)] = 324385,
  [SMALL_STATE(7795)] = 324445,
  [SMALL_STATE(7796)] = 324499,
  [SMALL_STATE(7797)] = 324557,
  [SMALL_STATE(7798)] = 324611,
  [SMALL_STATE(7799)] = 324663,
  [SMALL_STATE(7800)] = 324723,
  [SMALL_STATE(7801)] = 324783,
  [SMALL_STATE(7802)] = 324843,
  [SMALL_STATE(7803)] = 324903,
  [SMALL_STATE(7804)] = 324963,
  [SMALL_STATE(7805)] = 325023,
  [SMALL_STATE(7806)] = 325083,
  [SMALL_STATE(7807)] = 325143,
  [SMALL_STATE(7808)] = 325203,
  [SMALL_STATE(7809)] = 325255,
  [SMALL_STATE(7810)] = 325315,
  [SMALL_STATE(7811)] = 325375,
  [SMALL_STATE(7812)] = 325425,
  [SMALL_STATE(7813)] = 325485,
  [SMALL_STATE(7814)] = 325545,
  [SMALL_STATE(7815)] = 325605,
  [SMALL_STATE(7816)] = 325665,
  [SMALL_STATE(7817)] = 325725,
  [SMALL_STATE(7818)] = 325775,
  [SMALL_STATE(7819)] = 325835,
  [SMALL_STATE(7820)] = 325895,
  [SMALL_STATE(7821)] = 325955,
  [SMALL_STATE(7822)] = 326015,
  [SMALL_STATE(7823)] = 326075,
  [SMALL_STATE(7824)] = 326135,
  [SMALL_STATE(7825)] = 326195,
  [SMALL_STATE(7826)] = 326255,
  [SMALL_STATE(7827)] = 326315,
  [SMALL_STATE(7828)] = 326375,
  [SMALL_STATE(7829)] = 326435,
  [SMALL_STATE(7830)] = 326495,
  [SMALL_STATE(7831)] = 326555,
  [SMALL_STATE(7832)] = 326615,
  [SMALL_STATE(7833)] = 326675,
  [SMALL_STATE(7834)] = 326735,
  [SMALL_STATE(7835)] = 326795,
  [SMALL_STATE(7836)] = 326855,
  [SMALL_STATE(7837)] = 326915,
  [SMALL_STATE(7838)] = 326975,
  [SMALL_STATE(7839)] = 327035,
  [SMALL_STATE(7840)] = 327095,
  [SMALL_STATE(7841)] = 327155,
  [SMALL_STATE(7842)] = 327215,
  [SMALL_STATE(7843)] = 327273,
  [SMALL_STATE(7844)] = 327331,
  [SMALL_STATE(7845)] = 327391,
  [SMALL_STATE(7846)] = 327449,
  [SMALL_STATE(7847)] = 327509,
  [SMALL_STATE(7848)] = 327561,
  [SMALL_STATE(7849)] = 327621,
  [SMALL_STATE(7850)] = 327675,
  [SMALL_STATE(7851)] = 327735,
  [SMALL_STATE(7852)] = 327795,
  [SMALL_STATE(7853)] = 327855,
  [SMALL_STATE(7854)] = 327915,
  [SMALL_STATE(7855)] = 327975,
  [SMALL_STATE(7856)] = 328035,
  [SMALL_STATE(7857)] = 328095,
  [SMALL_STATE(7858)] = 328155,
  [SMALL_STATE(7859)] = 328215,
  [SMALL_STATE(7860)] = 328275,
  [SMALL_STATE(7861)] = 328333,
  [SMALL_STATE(7862)] = 328393,
  [SMALL_STATE(7863)] = 328453,
  [SMALL_STATE(7864)] = 328513,
  [SMALL_STATE(7865)] = 328573,
  [SMALL_STATE(7866)] = 328633,
  [SMALL_STATE(7867)] = 328693,
  [SMALL_STATE(7868)] = 328749,
  [SMALL_STATE(7869)] = 328809,
  [SMALL_STATE(7870)] = 328869,
  [SMALL_STATE(7871)] = 328929,
  [SMALL_STATE(7872)] = 328989,
  [SMALL_STATE(7873)] = 329049,
  [SMALL_STATE(7874)] = 329109,
  [SMALL_STATE(7875)] = 329169,
  [SMALL_STATE(7876)] = 329229,
  [SMALL_STATE(7877)] = 329289,
  [SMALL_STATE(7878)] = 329349,
  [SMALL_STATE(7879)] = 329409,
  [SMALL_STATE(7880)] = 329469,
  [SMALL_STATE(7881)] = 329529,
  [SMALL_STATE(7882)] = 329589,
  [SMALL_STATE(7883)] = 329649,
  [SMALL_STATE(7884)] = 329709,
  [SMALL_STATE(7885)] = 329769,
  [SMALL_STATE(7886)] = 329829,
  [SMALL_STATE(7887)] = 329889,
  [SMALL_STATE(7888)] = 329949,
  [SMALL_STATE(7889)] = 330001,
  [SMALL_STATE(7890)] = 330061,
  [SMALL_STATE(7891)] = 330121,
  [SMALL_STATE(7892)] = 330177,
  [SMALL_STATE(7893)] = 330237,
  [SMALL_STATE(7894)] = 330297,
  [SMALL_STATE(7895)] = 330355,
  [SMALL_STATE(7896)] = 330415,
  [SMALL_STATE(7897)] = 330475,
  [SMALL_STATE(7898)] = 330529,
  [SMALL_STATE(7899)] = 330589,
  [SMALL_STATE(7900)] = 330649,
  [SMALL_STATE(7901)] = 330709,
  [SMALL_STATE(7902)] = 330769,
  [SMALL_STATE(7903)] = 330829,
  [SMALL_STATE(7904)] = 330889,
  [SMALL_STATE(7905)] = 330949,
  [SMALL_STATE(7906)] = 331009,
  [SMALL_STATE(7907)] = 331063,
  [SMALL_STATE(7908)] = 331123,
  [SMALL_STATE(7909)] = 331183,
  [SMALL_STATE(7910)] = 331243,
  [SMALL_STATE(7911)] = 331303,
  [SMALL_STATE(7912)] = 331361,
  [SMALL_STATE(7913)] = 331421,
  [SMALL_STATE(7914)] = 331481,
  [SMALL_STATE(7915)] = 331541,
  [SMALL_STATE(7916)] = 331601,
  [SMALL_STATE(7917)] = 331661,
  [SMALL_STATE(7918)] = 331719,
  [SMALL_STATE(7919)] = 331779,
  [SMALL_STATE(7920)] = 331839,
  [SMALL_STATE(7921)] = 331899,
  [SMALL_STATE(7922)] = 331959,
  [SMALL_STATE(7923)] = 332019,
  [SMALL_STATE(7924)] = 332079,
  [SMALL_STATE(7925)] = 332139,
  [SMALL_STATE(7926)] = 332199,
  [SMALL_STATE(7927)] = 332259,
  [SMALL_STATE(7928)] = 332317,
  [SMALL_STATE(7929)] = 332377,
  [SMALL_STATE(7930)] = 332437,
  [SMALL_STATE(7931)] = 332497,
  [SMALL_STATE(7932)] = 332557,
  [SMALL_STATE(7933)] = 332617,
  [SMALL_STATE(7934)] = 332677,
  [SMALL_STATE(7935)] = 332737,
  [SMALL_STATE(7936)] = 332797,
  [SMALL_STATE(7937)] = 332847,
  [SMALL_STATE(7938)] = 332905,
  [SMALL_STATE(7939)] = 332965,
  [SMALL_STATE(7940)] = 333015,
  [SMALL_STATE(7941)] = 333073,
  [SMALL_STATE(7942)] = 333133,
  [SMALL_STATE(7943)] = 333193,
  [SMALL_STATE(7944)] = 333251,
  [SMALL_STATE(7945)] = 333311,
  [SMALL_STATE(7946)] = 333371,
  [SMALL_STATE(7947)] = 333431,
  [SMALL_STATE(7948)] = 333491,
  [SMALL_STATE(7949)] = 333551,
  [SMALL_STATE(7950)] = 333611,
  [SMALL_STATE(7951)] = 333668,
  [SMALL_STATE(7952)] = 333725,
  [SMALL_STATE(7953)] = 333782,
  [SMALL_STATE(7954)] = 333839,
  [SMALL_STATE(7955)] = 333894,
  [SMALL_STATE(7956)] = 333951,
  [SMALL_STATE(7957)] = 334008,
  [SMALL_STATE(7958)] = 334065,
  [SMALL_STATE(7959)] = 334122,
  [SMALL_STATE(7960)] = 334179,
  [SMALL_STATE(7961)] = 334234,
  [SMALL_STATE(7962)] = 334291,
  [SMALL_STATE(7963)] = 334348,
  [SMALL_STATE(7964)] = 334405,
  [SMALL_STATE(7965)] = 334462,
  [SMALL_STATE(7966)] = 334519,
  [SMALL_STATE(7967)] = 334576,
  [SMALL_STATE(7968)] = 334633,
  [SMALL_STATE(7969)] = 334690,
  [SMALL_STATE(7970)] = 334745,
  [SMALL_STATE(7971)] = 334802,
  [SMALL_STATE(7972)] = 334859,
  [SMALL_STATE(7973)] = 334914,
  [SMALL_STATE(7974)] = 334971,
  [SMALL_STATE(7975)] = 335028,
  [SMALL_STATE(7976)] = 335085,
  [SMALL_STATE(7977)] = 335142,
  [SMALL_STATE(7978)] = 335199,
  [SMALL_STATE(7979)] = 335256,
  [SMALL_STATE(7980)] = 335313,
  [SMALL_STATE(7981)] = 335368,
  [SMALL_STATE(7982)] = 335425,
  [SMALL_STATE(7983)] = 335482,
  [SMALL_STATE(7984)] = 335539,
  [SMALL_STATE(7985)] = 335588,
  [SMALL_STATE(7986)] = 335645,
  [SMALL_STATE(7987)] = 335702,
  [SMALL_STATE(7988)] = 335753,
  [SMALL_STATE(7989)] = 335810,
  [SMALL_STATE(7990)] = 335867,
  [SMALL_STATE(7991)] = 335918,
  [SMALL_STATE(7992)] = 335975,
  [SMALL_STATE(7993)] = 336032,
  [SMALL_STATE(7994)] = 336089,
  [SMALL_STATE(7995)] = 336138,
  [SMALL_STATE(7996)] = 336195,
  [SMALL_STATE(7997)] = 336252,
  [SMALL_STATE(7998)] = 336307,
  [SMALL_STATE(7999)] = 336356,
  [SMALL_STATE(8000)] = 336411,
  [SMALL_STATE(8001)] = 336468,
  [SMALL_STATE(8002)] = 336525,
  [SMALL_STATE(8003)] = 336578,
  [SMALL_STATE(8004)] = 336635,
  [SMALL_STATE(8005)] = 336684,
  [SMALL_STATE(8006)] = 336741,
  [SMALL_STATE(8007)] = 336790,
  [SMALL_STATE(8008)] = 336847,
  [SMALL_STATE(8009)] = 336904,
  [SMALL_STATE(8010)] = 336961,
  [SMALL_STATE(8011)] = 337016,
  [SMALL_STATE(8012)] = 337065,
  [SMALL_STATE(8013)] = 337122,
  [SMALL_STATE(8014)] = 337179,
  [SMALL_STATE(8015)] = 337234,
  [SMALL_STATE(8016)] = 337291,
  [SMALL_STATE(8017)] = 337348,
  [SMALL_STATE(8018)] = 337405,
  [SMALL_STATE(8019)] = 337462,
  [SMALL_STATE(8020)] = 337519,
  [SMALL_STATE(8021)] = 337576,
  [SMALL_STATE(8022)] = 337631,
  [SMALL_STATE(8023)] = 337688,
  [SMALL_STATE(8024)] = 337745,
  [SMALL_STATE(8025)] = 337800,
  [SMALL_STATE(8026)] = 337855,
  [SMALL_STATE(8027)] = 337912,
  [SMALL_STATE(8028)] = 337969,
  [SMALL_STATE(8029)] = 338026,
  [SMALL_STATE(8030)] = 338083,
  [SMALL_STATE(8031)] = 338140,
  [SMALL_STATE(8032)] = 338197,
  [SMALL_STATE(8033)] = 338254,
  [SMALL_STATE(8034)] = 338311,
  [SMALL_STATE(8035)] = 338368,
  [SMALL_STATE(8036)] = 338425,
  [SMALL_STATE(8037)] = 338480,
  [SMALL_STATE(8038)] = 338531,
  [SMALL_STATE(8039)] = 338588,
  [SMALL_STATE(8040)] = 338645,
  [SMALL_STATE(8041)] = 338702,
  [SMALL_STATE(8042)] = 338757,
  [SMALL_STATE(8043)] = 338814,
  [SMALL_STATE(8044)] = 338871,
  [SMALL_STATE(8045)] = 338926,
  [SMALL_STATE(8046)] = 338983,
  [SMALL_STATE(8047)] = 339040,
  [SMALL_STATE(8048)] = 339097,
  [SMALL_STATE(8049)] = 339148,
  [SMALL_STATE(8050)] = 339205,
  [SMALL_STATE(8051)] = 339262,
  [SMALL_STATE(8052)] = 339311,
  [SMALL_STATE(8053)] = 339368,
  [SMALL_STATE(8054)] = 339425,
  [SMALL_STATE(8055)] = 339480,
  [SMALL_STATE(8056)] = 339531,
  [SMALL_STATE(8057)] = 339588,
  [SMALL_STATE(8058)] = 339637,
  [SMALL_STATE(8059)] = 339694,
  [SMALL_STATE(8060)] = 339751,
  [SMALL_STATE(8061)] = 339808,
  [SMALL_STATE(8062)] = 339865,
  [SMALL_STATE(8063)] = 339914,
  [SMALL_STATE(8064)] = 339971,
  [SMALL_STATE(8065)] = 340028,
  [SMALL_STATE(8066)] = 340085,
  [SMALL_STATE(8067)] = 340142,
  [SMALL_STATE(8068)] = 340199,
  [SMALL_STATE(8069)] = 340254,
  [SMALL_STATE(8070)] = 340311,
  [SMALL_STATE(8071)] = 340368,
  [SMALL_STATE(8072)] = 340425,
  [SMALL_STATE(8073)] = 340482,
  [SMALL_STATE(8074)] = 340537,
  [SMALL_STATE(8075)] = 340594,
  [SMALL_STATE(8076)] = 340651,
  [SMALL_STATE(8077)] = 340708,
  [SMALL_STATE(8078)] = 340765,
  [SMALL_STATE(8079)] = 340822,
  [SMALL_STATE(8080)] = 340879,
  [SMALL_STATE(8081)] = 340936,
  [SMALL_STATE(8082)] = 340993,
  [SMALL_STATE(8083)] = 341048,
  [SMALL_STATE(8084)] = 341103,
  [SMALL_STATE(8085)] = 341160,
  [SMALL_STATE(8086)] = 341209,
  [SMALL_STATE(8087)] = 341266,
  [SMALL_STATE(8088)] = 341321,
  [SMALL_STATE(8089)] = 341378,
  [SMALL_STATE(8090)] = 341427,
  [SMALL_STATE(8091)] = 341484,
  [SMALL_STATE(8092)] = 341541,
  [SMALL_STATE(8093)] = 341598,
  [SMALL_STATE(8094)] = 341647,
  [SMALL_STATE(8095)] = 341704,
  [SMALL_STATE(8096)] = 341761,
  [SMALL_STATE(8097)] = 341818,
  [SMALL_STATE(8098)] = 341875,
  [SMALL_STATE(8099)] = 341932,
  [SMALL_STATE(8100)] = 341989,
  [SMALL_STATE(8101)] = 342040,
  [SMALL_STATE(8102)] = 342091,
  [SMALL_STATE(8103)] = 342146,
  [SMALL_STATE(8104)] = 342199,
  [SMALL_STATE(8105)] = 342254,
  [SMALL_STATE(8106)] = 342311,
  [SMALL_STATE(8107)] = 342362,
  [SMALL_STATE(8108)] = 342419,
  [SMALL_STATE(8109)] = 342476,
  [SMALL_STATE(8110)] = 342525,
  [SMALL_STATE(8111)] = 342582,
  [SMALL_STATE(8112)] = 342639,
  [SMALL_STATE(8113)] = 342696,
  [SMALL_STATE(8114)] = 342753,
  [SMALL_STATE(8115)] = 342810,
  [SMALL_STATE(8116)] = 342867,
  [SMALL_STATE(8117)] = 342924,
  [SMALL_STATE(8118)] = 342973,
  [SMALL_STATE(8119)] = 343024,
  [SMALL_STATE(8120)] = 343077,
  [SMALL_STATE(8121)] = 343134,
  [SMALL_STATE(8122)] = 343191,
  [SMALL_STATE(8123)] = 343248,
  [SMALL_STATE(8124)] = 343305,
  [SMALL_STATE(8125)] = 343362,
  [SMALL_STATE(8126)] = 343419,
  [SMALL_STATE(8127)] = 343476,
  [SMALL_STATE(8128)] = 343533,
  [SMALL_STATE(8129)] = 343588,
  [SMALL_STATE(8130)] = 343645,
  [SMALL_STATE(8131)] = 343702,
  [SMALL_STATE(8132)] = 343759,
  [SMALL_STATE(8133)] = 343816,
  [SMALL_STATE(8134)] = 343873,
  [SMALL_STATE(8135)] = 343926,
  [SMALL_STATE(8136)] = 343983,
  [SMALL_STATE(8137)] = 344040,
  [SMALL_STATE(8138)] = 344097,
  [SMALL_STATE(8139)] = 344154,
  [SMALL_STATE(8140)] = 344211,
  [SMALL_STATE(8141)] = 344268,
  [SMALL_STATE(8142)] = 344325,
  [SMALL_STATE(8143)] = 344382,
  [SMALL_STATE(8144)] = 344439,
  [SMALL_STATE(8145)] = 344496,
  [SMALL_STATE(8146)] = 344553,
  [SMALL_STATE(8147)] = 344610,
  [SMALL_STATE(8148)] = 344667,
  [SMALL_STATE(8149)] = 344724,
  [SMALL_STATE(8150)] = 344781,
  [SMALL_STATE(8151)] = 344838,
  [SMALL_STATE(8152)] = 344895,
  [SMALL_STATE(8153)] = 344952,
  [SMALL_STATE(8154)] = 345009,
  [SMALL_STATE(8155)] = 345066,
  [SMALL_STATE(8156)] = 345123,
  [SMALL_STATE(8157)] = 345180,
  [SMALL_STATE(8158)] = 345237,
  [SMALL_STATE(8159)] = 345294,
  [SMALL_STATE(8160)] = 345351,
  [SMALL_STATE(8161)] = 345408,
  [SMALL_STATE(8162)] = 345465,
  [SMALL_STATE(8163)] = 345522,
  [SMALL_STATE(8164)] = 345579,
  [SMALL_STATE(8165)] = 345636,
  [SMALL_STATE(8166)] = 345693,
  [SMALL_STATE(8167)] = 345750,
  [SMALL_STATE(8168)] = 345807,
  [SMALL_STATE(8169)] = 345864,
  [SMALL_STATE(8170)] = 345919,
  [SMALL_STATE(8171)] = 345976,
  [SMALL_STATE(8172)] = 346033,
  [SMALL_STATE(8173)] = 346084,
  [SMALL_STATE(8174)] = 346139,
  [SMALL_STATE(8175)] = 346196,
  [SMALL_STATE(8176)] = 346253,
  [SMALL_STATE(8177)] = 346310,
  [SMALL_STATE(8178)] = 346367,
  [SMALL_STATE(8179)] = 346424,
  [SMALL_STATE(8180)] = 346481,
  [SMALL_STATE(8181)] = 346538,
  [SMALL_STATE(8182)] = 346595,
  [SMALL_STATE(8183)] = 346652,
  [SMALL_STATE(8184)] = 346709,
  [SMALL_STATE(8185)] = 346758,
  [SMALL_STATE(8186)] = 346815,
  [SMALL_STATE(8187)] = 346872,
  [SMALL_STATE(8188)] = 346929,
  [SMALL_STATE(8189)] = 346986,
  [SMALL_STATE(8190)] = 347043,
  [SMALL_STATE(8191)] = 347100,
  [SMALL_STATE(8192)] = 347157,
  [SMALL_STATE(8193)] = 347212,
  [SMALL_STATE(8194)] = 347269,
  [SMALL_STATE(8195)] = 347326,
  [SMALL_STATE(8196)] = 347383,
  [SMALL_STATE(8197)] = 347440,
  [SMALL_STATE(8198)] = 347497,
  [SMALL_STATE(8199)] = 347554,
  [SMALL_STATE(8200)] = 347611,
  [SMALL_STATE(8201)] = 347668,
  [SMALL_STATE(8202)] = 347725,
  [SMALL_STATE(8203)] = 347782,
  [SMALL_STATE(8204)] = 347835,
  [SMALL_STATE(8205)] = 347892,
  [SMALL_STATE(8206)] = 347947,
  [SMALL_STATE(8207)] = 348004,
  [SMALL_STATE(8208)] = 348061,
  [SMALL_STATE(8209)] = 348118,
  [SMALL_STATE(8210)] = 348175,
  [SMALL_STATE(8211)] = 348232,
  [SMALL_STATE(8212)] = 348289,
  [SMALL_STATE(8213)] = 348346,
  [SMALL_STATE(8214)] = 348403,
  [SMALL_STATE(8215)] = 348460,
  [SMALL_STATE(8216)] = 348517,
  [SMALL_STATE(8217)] = 348574,
  [SMALL_STATE(8218)] = 348631,
  [SMALL_STATE(8219)] = 348688,
  [SMALL_STATE(8220)] = 348745,
  [SMALL_STATE(8221)] = 348802,
  [SMALL_STATE(8222)] = 348859,
  [SMALL_STATE(8223)] = 348916,
  [SMALL_STATE(8224)] = 348973,
  [SMALL_STATE(8225)] = 349030,
  [SMALL_STATE(8226)] = 349087,
  [SMALL_STATE(8227)] = 349144,
  [SMALL_STATE(8228)] = 349199,
  [SMALL_STATE(8229)] = 349256,
  [SMALL_STATE(8230)] = 349313,
  [SMALL_STATE(8231)] = 349370,
  [SMALL_STATE(8232)] = 349427,
  [SMALL_STATE(8233)] = 349484,
  [SMALL_STATE(8234)] = 349541,
  [SMALL_STATE(8235)] = 349598,
  [SMALL_STATE(8236)] = 349655,
  [SMALL_STATE(8237)] = 349712,
  [SMALL_STATE(8238)] = 349765,
  [SMALL_STATE(8239)] = 349822,
  [SMALL_STATE(8240)] = 349879,
  [SMALL_STATE(8241)] = 349930,
  [SMALL_STATE(8242)] = 349987,
  [SMALL_STATE(8243)] = 350044,
  [SMALL_STATE(8244)] = 350101,
  [SMALL_STATE(8245)] = 350158,
  [SMALL_STATE(8246)] = 350215,
  [SMALL_STATE(8247)] = 350272,
  [SMALL_STATE(8248)] = 350321,
  [SMALL_STATE(8249)] = 350371,
  [SMALL_STATE(8250)] = 350425,
  [SMALL_STATE(8251)] = 350479,
  [SMALL_STATE(8252)] = 350533,
  [SMALL_STATE(8253)] = 350587,
  [SMALL_STATE(8254)] = 350641,
  [SMALL_STATE(8255)] = 350695,
  [SMALL_STATE(8256)] = 350749,
  [SMALL_STATE(8257)] = 350803,
  [SMALL_STATE(8258)] = 350857,
  [SMALL_STATE(8259)] = 350905,
  [SMALL_STATE(8260)] = 350957,
  [SMALL_STATE(8261)] = 351011,
  [SMALL_STATE(8262)] = 351065,
  [SMALL_STATE(8263)] = 351119,
  [SMALL_STATE(8264)] = 351173,
  [SMALL_STATE(8265)] = 351223,
  [SMALL_STATE(8266)] = 351273,
  [SMALL_STATE(8267)] = 351327,
  [SMALL_STATE(8268)] = 351375,
  [SMALL_STATE(8269)] = 351429,
  [SMALL_STATE(8270)] = 351479,
  [SMALL_STATE(8271)] = 351533,
  [SMALL_STATE(8272)] = 351581,
  [SMALL_STATE(8273)] = 351635,
  [SMALL_STATE(8274)] = 351689,
  [SMALL_STATE(8275)] = 351743,
  [SMALL_STATE(8276)] = 351797,
  [SMALL_STATE(8277)] = 351851,
  [SMALL_STATE(8278)] = 351901,
  [SMALL_STATE(8279)] = 351955,
  [SMALL_STATE(8280)] = 352009,
  [SMALL_STATE(8281)] = 352063,
  [SMALL_STATE(8282)] = 352113,
  [SMALL_STATE(8283)] = 352167,
  [SMALL_STATE(8284)] = 352221,
  [SMALL_STATE(8285)] = 352275,
  [SMALL_STATE(8286)] = 352329,
  [SMALL_STATE(8287)] = 352379,
  [SMALL_STATE(8288)] = 352433,
  [SMALL_STATE(8289)] = 352485,
  [SMALL_STATE(8290)] = 352539,
  [SMALL_STATE(8291)] = 352587,
  [SMALL_STATE(8292)] = 352641,
  [SMALL_STATE(8293)] = 352689,
  [SMALL_STATE(8294)] = 352741,
  [SMALL_STATE(8295)] = 352789,
  [SMALL_STATE(8296)] = 352843,
  [SMALL_STATE(8297)] = 352897,
  [SMALL_STATE(8298)] = 352951,
  [SMALL_STATE(8299)] = 353003,
  [SMALL_STATE(8300)] = 353053,
  [SMALL_STATE(8301)] = 353107,
  [SMALL_STATE(8302)] = 353161,
  [SMALL_STATE(8303)] = 353215,
  [SMALL_STATE(8304)] = 353269,
  [SMALL_STATE(8305)] = 353323,
  [SMALL_STATE(8306)] = 353377,
  [SMALL_STATE(8307)] = 353431,
  [SMALL_STATE(8308)] = 353481,
  [SMALL_STATE(8309)] = 353535,
  [SMALL_STATE(8310)] = 353583,
  [SMALL_STATE(8311)] = 353635,
  [SMALL_STATE(8312)] = 353689,
  [SMALL_STATE(8313)] = 353739,
  [SMALL_STATE(8314)] = 353787,
  [SMALL_STATE(8315)] = 353841,
  [SMALL_STATE(8316)] = 353895,
  [SMALL_STATE(8317)] = 353947,
  [SMALL_STATE(8318)] = 353995,
  [SMALL_STATE(8319)] = 354049,
  [SMALL_STATE(8320)] = 354103,
  [SMALL_STATE(8321)] = 354157,
  [SMALL_STATE(8322)] = 354205,
  [SMALL_STATE(8323)] = 354259,
  [SMALL_STATE(8324)] = 354311,
  [SMALL_STATE(8325)] = 354365,
  [SMALL_STATE(8326)] = 354417,
  [SMALL_STATE(8327)] = 354469,
  [SMALL_STATE(8328)] = 354523,
  [SMALL_STATE(8329)] = 354577,
  [SMALL_STATE(8330)] = 354631,
  [SMALL_STATE(8331)] = 354685,
  [SMALL_STATE(8332)] = 354739,
  [SMALL_STATE(8333)] = 354787,
  [SMALL_STATE(8334)] = 354839,
  [SMALL_STATE(8335)] = 354893,
  [SMALL_STATE(8336)] = 354945,
  [SMALL_STATE(8337)] = 354993,
  [SMALL_STATE(8338)] = 355047,
  [SMALL_STATE(8339)] = 355097,
  [SMALL_STATE(8340)] = 355151,
  [SMALL_STATE(8341)] = 355201,
  [SMALL_STATE(8342)] = 355255,
  [SMALL_STATE(8343)] = 355309,
  [SMALL_STATE(8344)] = 355363,
  [SMALL_STATE(8345)] = 355417,
  [SMALL_STATE(8346)] = 355471,
  [SMALL_STATE(8347)] = 355521,
  [SMALL_STATE(8348)] = 355573,
  [SMALL_STATE(8349)] = 355623,
  [SMALL_STATE(8350)] = 355675,
  [SMALL_STATE(8351)] = 355727,
  [SMALL_STATE(8352)] = 355781,
  [SMALL_STATE(8353)] = 355835,
  [SMALL_STATE(8354)] = 355889,
  [SMALL_STATE(8355)] = 355943,
  [SMALL_STATE(8356)] = 355997,
  [SMALL_STATE(8357)] = 356047,
  [SMALL_STATE(8358)] = 356101,
  [SMALL_STATE(8359)] = 356149,
  [SMALL_STATE(8360)] = 356197,
  [SMALL_STATE(8361)] = 356251,
  [SMALL_STATE(8362)] = 356305,
  [SMALL_STATE(8363)] = 356359,
  [SMALL_STATE(8364)] = 356409,
  [SMALL_STATE(8365)] = 356459,
  [SMALL_STATE(8366)] = 356513,
  [SMALL_STATE(8367)] = 356567,
  [SMALL_STATE(8368)] = 356621,
  [SMALL_STATE(8369)] = 356675,
  [SMALL_STATE(8370)] = 356729,
  [SMALL_STATE(8371)] = 356783,
  [SMALL_STATE(8372)] = 356837,
  [SMALL_STATE(8373)] = 356891,
  [SMALL_STATE(8374)] = 356945,
  [SMALL_STATE(8375)] = 356999,
  [SMALL_STATE(8376)] = 357053,
  [SMALL_STATE(8377)] = 357107,
  [SMALL_STATE(8378)] = 357155,
  [SMALL_STATE(8379)] = 357209,
  [SMALL_STATE(8380)] = 357263,
  [SMALL_STATE(8381)] = 357317,
  [SMALL_STATE(8382)] = 357371,
  [SMALL_STATE(8383)] = 357425,
  [SMALL_STATE(8384)] = 357475,
  [SMALL_STATE(8385)] = 357523,
  [SMALL_STATE(8386)] = 357574,
  [SMALL_STATE(8387)] = 357623,
  [SMALL_STATE(8388)] = 357672,
  [SMALL_STATE(8389)] = 357723,
  [SMALL_STATE(8390)] = 357772,
  [SMALL_STATE(8391)] = 357823,
  [SMALL_STATE(8392)] = 357874,
  [SMALL_STATE(8393)] = 357925,
  [SMALL_STATE(8394)] = 357974,
  [SMALL_STATE(8395)] = 358025,
  [SMALL_STATE(8396)] = 358076,
  [SMALL_STATE(8397)] = 358127,
  [SMALL_STATE(8398)] = 358178,
  [SMALL_STATE(8399)] = 358229,
  [SMALL_STATE(8400)] = 358280,
  [SMALL_STATE(8401)] = 358331,
  [SMALL_STATE(8402)] = 358382,
  [SMALL_STATE(8403)] = 358433,
  [SMALL_STATE(8404)] = 358484,
  [SMALL_STATE(8405)] = 358535,
  [SMALL_STATE(8406)] = 358586,
  [SMALL_STATE(8407)] = 358637,
  [SMALL_STATE(8408)] = 358686,
  [SMALL_STATE(8409)] = 358737,
  [SMALL_STATE(8410)] = 358788,
  [SMALL_STATE(8411)] = 358839,
  [SMALL_STATE(8412)] = 358890,
  [SMALL_STATE(8413)] = 358941,
  [SMALL_STATE(8414)] = 358992,
  [SMALL_STATE(8415)] = 359043,
  [SMALL_STATE(8416)] = 359092,
  [SMALL_STATE(8417)] = 359143,
  [SMALL_STATE(8418)] = 359192,
  [SMALL_STATE(8419)] = 359243,
  [SMALL_STATE(8420)] = 359294,
  [SMALL_STATE(8421)] = 359345,
  [SMALL_STATE(8422)] = 359396,
  [SMALL_STATE(8423)] = 359447,
  [SMALL_STATE(8424)] = 359498,
  [SMALL_STATE(8425)] = 359549,
  [SMALL_STATE(8426)] = 359600,
  [SMALL_STATE(8427)] = 359651,
  [SMALL_STATE(8428)] = 359702,
  [SMALL_STATE(8429)] = 359753,
  [SMALL_STATE(8430)] = 359804,
  [SMALL_STATE(8431)] = 359855,
  [SMALL_STATE(8432)] = 359906,
  [SMALL_STATE(8433)] = 359957,
  [SMALL_STATE(8434)] = 360008,
  [SMALL_STATE(8435)] = 360059,
  [SMALL_STATE(8436)] = 360108,
  [SMALL_STATE(8437)] = 360159,
  [SMALL_STATE(8438)] = 360208,
  [SMALL_STATE(8439)] = 360259,
  [SMALL_STATE(8440)] = 360310,
  [SMALL_STATE(8441)] = 360361,
  [SMALL_STATE(8442)] = 360412,
  [SMALL_STATE(8443)] = 360463,
  [SMALL_STATE(8444)] = 360514,
  [SMALL_STATE(8445)] = 360565,
  [SMALL_STATE(8446)] = 360616,
  [SMALL_STATE(8447)] = 360665,
  [SMALL_STATE(8448)] = 360716,
  [SMALL_STATE(8449)] = 360767,
  [SMALL_STATE(8450)] = 360816,
  [SMALL_STATE(8451)] = 360867,
  [SMALL_STATE(8452)] = 360918,
  [SMALL_STATE(8453)] = 360969,
  [SMALL_STATE(8454)] = 361018,
  [SMALL_STATE(8455)] = 361069,
  [SMALL_STATE(8456)] = 361120,
  [SMALL_STATE(8457)] = 361171,
  [SMALL_STATE(8458)] = 361222,
  [SMALL_STATE(8459)] = 361273,
  [SMALL_STATE(8460)] = 361322,
  [SMALL_STATE(8461)] = 361373,
  [SMALL_STATE(8462)] = 361424,
  [SMALL_STATE(8463)] = 361475,
  [SMALL_STATE(8464)] = 361526,
  [SMALL_STATE(8465)] = 361577,
  [SMALL_STATE(8466)] = 361628,
  [SMALL_STATE(8467)] = 361679,
  [SMALL_STATE(8468)] = 361726,
  [SMALL_STATE(8469)] = 361777,
  [SMALL_STATE(8470)] = 361828,
  [SMALL_STATE(8471)] = 361879,
  [SMALL_STATE(8472)] = 361928,
  [SMALL_STATE(8473)] = 361975,
  [SMALL_STATE(8474)] = 362026,
  [SMALL_STATE(8475)] = 362077,
  [SMALL_STATE(8476)] = 362128,
  [SMALL_STATE(8477)] = 362179,
  [SMALL_STATE(8478)] = 362228,
  [SMALL_STATE(8479)] = 362275,
  [SMALL_STATE(8480)] = 362326,
  [SMALL_STATE(8481)] = 362377,
  [SMALL_STATE(8482)] = 362428,
  [SMALL_STATE(8483)] = 362479,
  [SMALL_STATE(8484)] = 362530,
  [SMALL_STATE(8485)] = 362581,
  [SMALL_STATE(8486)] = 362632,
  [SMALL_STATE(8487)] = 362681,
  [SMALL_STATE(8488)] = 362730,
  [SMALL_STATE(8489)] = 362777,
  [SMALL_STATE(8490)] = 362828,
  [SMALL_STATE(8491)] = 362875,
  [SMALL_STATE(8492)] = 362922,
  [SMALL_STATE(8493)] = 362969,
  [SMALL_STATE(8494)] = 363016,
  [SMALL_STATE(8495)] = 363067,
  [SMALL_STATE(8496)] = 363118,
  [SMALL_STATE(8497)] = 363169,
  [SMALL_STATE(8498)] = 363220,
  [SMALL_STATE(8499)] = 363269,
  [SMALL_STATE(8500)] = 363320,
  [SMALL_STATE(8501)] = 363369,
  [SMALL_STATE(8502)] = 363420,
  [SMALL_STATE(8503)] = 363467,
  [SMALL_STATE(8504)] = 363518,
  [SMALL_STATE(8505)] = 363569,
  [SMALL_STATE(8506)] = 363618,
  [SMALL_STATE(8507)] = 363669,
  [SMALL_STATE(8508)] = 363720,
  [SMALL_STATE(8509)] = 363771,
  [SMALL_STATE(8510)] = 363822,
  [SMALL_STATE(8511)] = 363873,
  [SMALL_STATE(8512)] = 363924,
  [SMALL_STATE(8513)] = 363975,
  [SMALL_STATE(8514)] = 364026,
  [SMALL_STATE(8515)] = 364077,
  [SMALL_STATE(8516)] = 364128,
  [SMALL_STATE(8517)] = 364177,
  [SMALL_STATE(8518)] = 364228,
  [SMALL_STATE(8519)] = 364279,
  [SMALL_STATE(8520)] = 364330,
  [SMALL_STATE(8521)] = 364381,
  [SMALL_STATE(8522)] = 364432,
  [SMALL_STATE(8523)] = 364483,
  [SMALL_STATE(8524)] = 364532,
  [SMALL_STATE(8525)] = 364579,
  [SMALL_STATE(8526)] = 364630,
  [SMALL_STATE(8527)] = 364681,
  [SMALL_STATE(8528)] = 364732,
  [SMALL_STATE(8529)] = 364783,
  [SMALL_STATE(8530)] = 364834,
  [SMALL_STATE(8531)] = 364885,
  [SMALL_STATE(8532)] = 364936,
  [SMALL_STATE(8533)] = 364987,
  [SMALL_STATE(8534)] = 365036,
  [SMALL_STATE(8535)] = 365087,
  [SMALL_STATE(8536)] = 365138,
  [SMALL_STATE(8537)] = 365189,
  [SMALL_STATE(8538)] = 365240,
  [SMALL_STATE(8539)] = 365291,
  [SMALL_STATE(8540)] = 365342,
  [SMALL_STATE(8541)] = 365393,
  [SMALL_STATE(8542)] = 365440,
  [SMALL_STATE(8543)] = 365491,
  [SMALL_STATE(8544)] = 365542,
  [SMALL_STATE(8545)] = 365591,
  [SMALL_STATE(8546)] = 365642,
  [SMALL_STATE(8547)] = 365693,
  [SMALL_STATE(8548)] = 365744,
  [SMALL_STATE(8549)] = 365791,
  [SMALL_STATE(8550)] = 365842,
  [SMALL_STATE(8551)] = 365893,
  [SMALL_STATE(8552)] = 365942,
  [SMALL_STATE(8553)] = 365993,
  [SMALL_STATE(8554)] = 366044,
  [SMALL_STATE(8555)] = 366095,
  [SMALL_STATE(8556)] = 366146,
  [SMALL_STATE(8557)] = 366193,
  [SMALL_STATE(8558)] = 366244,
  [SMALL_STATE(8559)] = 366291,
  [SMALL_STATE(8560)] = 366340,
  [SMALL_STATE(8561)] = 366391,
  [SMALL_STATE(8562)] = 366442,
  [SMALL_STATE(8563)] = 366493,
  [SMALL_STATE(8564)] = 366544,
  [SMALL_STATE(8565)] = 366595,
  [SMALL_STATE(8566)] = 366642,
  [SMALL_STATE(8567)] = 366689,
  [SMALL_STATE(8568)] = 366736,
  [SMALL_STATE(8569)] = 366787,
  [SMALL_STATE(8570)] = 366838,
  [SMALL_STATE(8571)] = 366889,
  [SMALL_STATE(8572)] = 366940,
  [SMALL_STATE(8573)] = 366991,
  [SMALL_STATE(8574)] = 367042,
  [SMALL_STATE(8575)] = 367093,
  [SMALL_STATE(8576)] = 367144,
  [SMALL_STATE(8577)] = 367195,
  [SMALL_STATE(8578)] = 367246,
  [SMALL_STATE(8579)] = 367297,
  [SMALL_STATE(8580)] = 367348,
  [SMALL_STATE(8581)] = 367399,
  [SMALL_STATE(8582)] = 367450,
  [SMALL_STATE(8583)] = 367501,
  [SMALL_STATE(8584)] = 367552,
  [SMALL_STATE(8585)] = 367603,
  [SMALL_STATE(8586)] = 367654,
  [SMALL_STATE(8587)] = 367705,
  [SMALL_STATE(8588)] = 367756,
  [SMALL_STATE(8589)] = 367805,
  [SMALL_STATE(8590)] = 367856,
  [SMALL_STATE(8591)] = 367907,
  [SMALL_STATE(8592)] = 367958,
  [SMALL_STATE(8593)] = 368009,
  [SMALL_STATE(8594)] = 368060,
  [SMALL_STATE(8595)] = 368111,
  [SMALL_STATE(8596)] = 368162,
  [SMALL_STATE(8597)] = 368213,
  [SMALL_STATE(8598)] = 368264,
  [SMALL_STATE(8599)] = 368313,
  [SMALL_STATE(8600)] = 368364,
  [SMALL_STATE(8601)] = 368415,
  [SMALL_STATE(8602)] = 368466,
  [SMALL_STATE(8603)] = 368517,
  [SMALL_STATE(8604)] = 368568,
  [SMALL_STATE(8605)] = 368619,
  [SMALL_STATE(8606)] = 368670,
  [SMALL_STATE(8607)] = 368721,
  [SMALL_STATE(8608)] = 368772,
  [SMALL_STATE(8609)] = 368823,
  [SMALL_STATE(8610)] = 368874,
  [SMALL_STATE(8611)] = 368925,
  [SMALL_STATE(8612)] = 368976,
  [SMALL_STATE(8613)] = 369027,
  [SMALL_STATE(8614)] = 369078,
  [SMALL_STATE(8615)] = 369129,
  [SMALL_STATE(8616)] = 369180,
  [SMALL_STATE(8617)] = 369231,
  [SMALL_STATE(8618)] = 369282,
  [SMALL_STATE(8619)] = 369333,
  [SMALL_STATE(8620)] = 369384,
  [SMALL_STATE(8621)] = 369435,
  [SMALL_STATE(8622)] = 369486,
  [SMALL_STATE(8623)] = 369537,
  [SMALL_STATE(8624)] = 369588,
  [SMALL_STATE(8625)] = 369639,
  [SMALL_STATE(8626)] = 369690,
  [SMALL_STATE(8627)] = 369741,
  [SMALL_STATE(8628)] = 369792,
  [SMALL_STATE(8629)] = 369841,
  [SMALL_STATE(8630)] = 369892,
  [SMALL_STATE(8631)] = 369943,
  [SMALL_STATE(8632)] = 369994,
  [SMALL_STATE(8633)] = 370045,
  [SMALL_STATE(8634)] = 370096,
  [SMALL_STATE(8635)] = 370147,
  [SMALL_STATE(8636)] = 370198,
  [SMALL_STATE(8637)] = 370249,
  [SMALL_STATE(8638)] = 370300,
  [SMALL_STATE(8639)] = 370351,
  [SMALL_STATE(8640)] = 370402,
  [SMALL_STATE(8641)] = 370453,
  [SMALL_STATE(8642)] = 370504,
  [SMALL_STATE(8643)] = 370555,
  [SMALL_STATE(8644)] = 370606,
  [SMALL_STATE(8645)] = 370657,
  [SMALL_STATE(8646)] = 370708,
  [SMALL_STATE(8647)] = 370759,
  [SMALL_STATE(8648)] = 370810,
  [SMALL_STATE(8649)] = 370861,
  [SMALL_STATE(8650)] = 370912,
  [SMALL_STATE(8651)] = 370963,
  [SMALL_STATE(8652)] = 371014,
  [SMALL_STATE(8653)] = 371065,
  [SMALL_STATE(8654)] = 371116,
  [SMALL_STATE(8655)] = 371167,
  [SMALL_STATE(8656)] = 371218,
  [SMALL_STATE(8657)] = 371269,
  [SMALL_STATE(8658)] = 371318,
  [SMALL_STATE(8659)] = 371369,
  [SMALL_STATE(8660)] = 371420,
  [SMALL_STATE(8661)] = 371471,
  [SMALL_STATE(8662)] = 371518,
  [SMALL_STATE(8663)] = 371569,
  [SMALL_STATE(8664)] = 371620,
  [SMALL_STATE(8665)] = 371671,
  [SMALL_STATE(8666)] = 371722,
  [SMALL_STATE(8667)] = 371773,
  [SMALL_STATE(8668)] = 371824,
  [SMALL_STATE(8669)] = 371875,
  [SMALL_STATE(8670)] = 371926,
  [SMALL_STATE(8671)] = 371977,
  [SMALL_STATE(8672)] = 372028,
  [SMALL_STATE(8673)] = 372077,
  [SMALL_STATE(8674)] = 372128,
  [SMALL_STATE(8675)] = 372179,
  [SMALL_STATE(8676)] = 372230,
  [SMALL_STATE(8677)] = 372281,
  [SMALL_STATE(8678)] = 372332,
  [SMALL_STATE(8679)] = 372383,
  [SMALL_STATE(8680)] = 372434,
  [SMALL_STATE(8681)] = 372483,
  [SMALL_STATE(8682)] = 372534,
  [SMALL_STATE(8683)] = 372585,
  [SMALL_STATE(8684)] = 372636,
  [SMALL_STATE(8685)] = 372687,
  [SMALL_STATE(8686)] = 372738,
  [SMALL_STATE(8687)] = 372785,
  [SMALL_STATE(8688)] = 372836,
  [SMALL_STATE(8689)] = 372887,
  [SMALL_STATE(8690)] = 372938,
  [SMALL_STATE(8691)] = 372989,
  [SMALL_STATE(8692)] = 373040,
  [SMALL_STATE(8693)] = 373091,
  [SMALL_STATE(8694)] = 373142,
  [SMALL_STATE(8695)] = 373189,
  [SMALL_STATE(8696)] = 373240,
  [SMALL_STATE(8697)] = 373291,
  [SMALL_STATE(8698)] = 373340,
  [SMALL_STATE(8699)] = 373391,
  [SMALL_STATE(8700)] = 373442,
  [SMALL_STATE(8701)] = 373493,
  [SMALL_STATE(8702)] = 373544,
  [SMALL_STATE(8703)] = 373595,
  [SMALL_STATE(8704)] = 373646,
  [SMALL_STATE(8705)] = 373697,
  [SMALL_STATE(8706)] = 373743,
  [SMALL_STATE(8707)] = 373791,
  [SMALL_STATE(8708)] = 373837,
  [SMALL_STATE(8709)] = 373885,
  [SMALL_STATE(8710)] = 373933,
  [SMALL_STATE(8711)] = 373981,
  [SMALL_STATE(8712)] = 374027,
  [SMALL_STATE(8713)] = 374075,
  [SMALL_STATE(8714)] = 374123,
  [SMALL_STATE(8715)] = 374169,
  [SMALL_STATE(8716)] = 374215,
  [SMALL_STATE(8717)] = 374261,
  [SMALL_STATE(8718)] = 374309,
  [SMALL_STATE(8719)] = 374357,
  [SMALL_STATE(8720)] = 374405,
  [SMALL_STATE(8721)] = 374453,
  [SMALL_STATE(8722)] = 374501,
  [SMALL_STATE(8723)] = 374549,
  [SMALL_STATE(8724)] = 374595,
  [SMALL_STATE(8725)] = 374643,
  [SMALL_STATE(8726)] = 374689,
  [SMALL_STATE(8727)] = 374735,
  [SMALL_STATE(8728)] = 374783,
  [SMALL_STATE(8729)] = 374829,
  [SMALL_STATE(8730)] = 374877,
  [SMALL_STATE(8731)] = 374925,
  [SMALL_STATE(8732)] = 374971,
  [SMALL_STATE(8733)] = 375019,
  [SMALL_STATE(8734)] = 375065,
  [SMALL_STATE(8735)] = 375111,
  [SMALL_STATE(8736)] = 375159,
  [SMALL_STATE(8737)] = 375207,
  [SMALL_STATE(8738)] = 375253,
  [SMALL_STATE(8739)] = 375301,
  [SMALL_STATE(8740)] = 375347,
  [SMALL_STATE(8741)] = 375395,
  [SMALL_STATE(8742)] = 375443,
  [SMALL_STATE(8743)] = 375489,
  [SMALL_STATE(8744)] = 375535,
  [SMALL_STATE(8745)] = 375581,
  [SMALL_STATE(8746)] = 375629,
  [SMALL_STATE(8747)] = 375677,
  [SMALL_STATE(8748)] = 375725,
  [SMALL_STATE(8749)] = 375773,
  [SMALL_STATE(8750)] = 375821,
  [SMALL_STATE(8751)] = 375869,
  [SMALL_STATE(8752)] = 375915,
  [SMALL_STATE(8753)] = 375961,
  [SMALL_STATE(8754)] = 376009,
  [SMALL_STATE(8755)] = 376057,
  [SMALL_STATE(8756)] = 376103,
  [SMALL_STATE(8757)] = 376151,
  [SMALL_STATE(8758)] = 376197,
  [SMALL_STATE(8759)] = 376245,
  [SMALL_STATE(8760)] = 376293,
  [SMALL_STATE(8761)] = 376339,
  [SMALL_STATE(8762)] = 376385,
  [SMALL_STATE(8763)] = 376433,
  [SMALL_STATE(8764)] = 376481,
  [SMALL_STATE(8765)] = 376529,
  [SMALL_STATE(8766)] = 376575,
  [SMALL_STATE(8767)] = 376623,
  [SMALL_STATE(8768)] = 376669,
  [SMALL_STATE(8769)] = 376717,
  [SMALL_STATE(8770)] = 376763,
  [SMALL_STATE(8771)] = 376811,
  [SMALL_STATE(8772)] = 376857,
  [SMALL_STATE(8773)] = 376903,
  [SMALL_STATE(8774)] = 376951,
  [SMALL_STATE(8775)] = 376997,
  [SMALL_STATE(8776)] = 377045,
  [SMALL_STATE(8777)] = 377093,
  [SMALL_STATE(8778)] = 377141,
  [SMALL_STATE(8779)] = 377189,
  [SMALL_STATE(8780)] = 377237,
  [SMALL_STATE(8781)] = 377283,
  [SMALL_STATE(8782)] = 377329,
  [SMALL_STATE(8783)] = 377377,
  [SMALL_STATE(8784)] = 377425,
  [SMALL_STATE(8785)] = 377473,
  [SMALL_STATE(8786)] = 377521,
  [SMALL_STATE(8787)] = 377569,
  [SMALL_STATE(8788)] = 377615,
  [SMALL_STATE(8789)] = 377663,
  [SMALL_STATE(8790)] = 377711,
  [SMALL_STATE(8791)] = 377759,
  [SMALL_STATE(8792)] = 377807,
  [SMALL_STATE(8793)] = 377855,
  [SMALL_STATE(8794)] = 377903,
  [SMALL_STATE(8795)] = 377951,
  [SMALL_STATE(8796)] = 377997,
  [SMALL_STATE(8797)] = 378045,
  [SMALL_STATE(8798)] = 378091,
  [SMALL_STATE(8799)] = 378139,
  [SMALL_STATE(8800)] = 378187,
  [SMALL_STATE(8801)] = 378233,
  [SMALL_STATE(8802)] = 378279,
  [SMALL_STATE(8803)] = 378325,
  [SMALL_STATE(8804)] = 378373,
  [SMALL_STATE(8805)] = 378421,
  [SMALL_STATE(8806)] = 378469,
  [SMALL_STATE(8807)] = 378515,
  [SMALL_STATE(8808)] = 378563,
  [SMALL_STATE(8809)] = 378611,
  [SMALL_STATE(8810)] = 378659,
  [SMALL_STATE(8811)] = 378705,
  [SMALL_STATE(8812)] = 378753,
  [SMALL_STATE(8813)] = 378801,
  [SMALL_STATE(8814)] = 378849,
  [SMALL_STATE(8815)] = 378897,
  [SMALL_STATE(8816)] = 378943,
  [SMALL_STATE(8817)] = 378991,
  [SMALL_STATE(8818)] = 379039,
  [SMALL_STATE(8819)] = 379087,
  [SMALL_STATE(8820)] = 379135,
  [SMALL_STATE(8821)] = 379183,
  [SMALL_STATE(8822)] = 379231,
  [SMALL_STATE(8823)] = 379277,
  [SMALL_STATE(8824)] = 379325,
  [SMALL_STATE(8825)] = 379373,
  [SMALL_STATE(8826)] = 379421,
  [SMALL_STATE(8827)] = 379469,
  [SMALL_STATE(8828)] = 379517,
  [SMALL_STATE(8829)] = 379563,
  [SMALL_STATE(8830)] = 379611,
  [SMALL_STATE(8831)] = 379659,
  [SMALL_STATE(8832)] = 379705,
  [SMALL_STATE(8833)] = 379753,
  [SMALL_STATE(8834)] = 379799,
  [SMALL_STATE(8835)] = 379847,
  [SMALL_STATE(8836)] = 379895,
  [SMALL_STATE(8837)] = 379943,
  [SMALL_STATE(8838)] = 379989,
  [SMALL_STATE(8839)] = 380037,
  [SMALL_STATE(8840)] = 380085,
  [SMALL_STATE(8841)] = 380133,
  [SMALL_STATE(8842)] = 380181,
  [SMALL_STATE(8843)] = 380229,
  [SMALL_STATE(8844)] = 380275,
  [SMALL_STATE(8845)] = 380321,
  [SMALL_STATE(8846)] = 380367,
  [SMALL_STATE(8847)] = 380415,
  [SMALL_STATE(8848)] = 380463,
  [SMALL_STATE(8849)] = 380511,
  [SMALL_STATE(8850)] = 380557,
  [SMALL_STATE(8851)] = 380605,
  [SMALL_STATE(8852)] = 380653,
  [SMALL_STATE(8853)] = 380701,
  [SMALL_STATE(8854)] = 380749,
  [SMALL_STATE(8855)] = 380797,
  [SMALL_STATE(8856)] = 380845,
  [SMALL_STATE(8857)] = 380893,
  [SMALL_STATE(8858)] = 380941,
  [SMALL_STATE(8859)] = 380987,
  [SMALL_STATE(8860)] = 381035,
  [SMALL_STATE(8861)] = 381083,
  [SMALL_STATE(8862)] = 381129,
  [SMALL_STATE(8863)] = 381177,
  [SMALL_STATE(8864)] = 381223,
  [SMALL_STATE(8865)] = 381271,
  [SMALL_STATE(8866)] = 381317,
  [SMALL_STATE(8867)] = 381363,
  [SMALL_STATE(8868)] = 381409,
  [SMALL_STATE(8869)] = 381455,
  [SMALL_STATE(8870)] = 381503,
  [SMALL_STATE(8871)] = 381549,
  [SMALL_STATE(8872)] = 381597,
  [SMALL_STATE(8873)] = 381643,
  [SMALL_STATE(8874)] = 381689,
  [SMALL_STATE(8875)] = 381735,
  [SMALL_STATE(8876)] = 381781,
  [SMALL_STATE(8877)] = 381827,
  [SMALL_STATE(8878)] = 381875,
  [SMALL_STATE(8879)] = 381921,
  [SMALL_STATE(8880)] = 381967,
  [SMALL_STATE(8881)] = 382013,
  [SMALL_STATE(8882)] = 382059,
  [SMALL_STATE(8883)] = 382107,
  [SMALL_STATE(8884)] = 382155,
  [SMALL_STATE(8885)] = 382203,
  [SMALL_STATE(8886)] = 382249,
  [SMALL_STATE(8887)] = 382295,
  [SMALL_STATE(8888)] = 382341,
  [SMALL_STATE(8889)] = 382387,
  [SMALL_STATE(8890)] = 382433,
  [SMALL_STATE(8891)] = 382479,
  [SMALL_STATE(8892)] = 382525,
  [SMALL_STATE(8893)] = 382571,
  [SMALL_STATE(8894)] = 382619,
  [SMALL_STATE(8895)] = 382667,
  [SMALL_STATE(8896)] = 382713,
  [SMALL_STATE(8897)] = 382759,
  [SMALL_STATE(8898)] = 382807,
  [SMALL_STATE(8899)] = 382853,
  [SMALL_STATE(8900)] = 382899,
  [SMALL_STATE(8901)] = 382945,
  [SMALL_STATE(8902)] = 382993,
  [SMALL_STATE(8903)] = 383041,
  [SMALL_STATE(8904)] = 383089,
  [SMALL_STATE(8905)] = 383135,
  [SMALL_STATE(8906)] = 383181,
  [SMALL_STATE(8907)] = 383229,
  [SMALL_STATE(8908)] = 383277,
  [SMALL_STATE(8909)] = 383325,
  [SMALL_STATE(8910)] = 383371,
  [SMALL_STATE(8911)] = 383419,
  [SMALL_STATE(8912)] = 383467,
  [SMALL_STATE(8913)] = 383515,
  [SMALL_STATE(8914)] = 383561,
  [SMALL_STATE(8915)] = 383609,
  [SMALL_STATE(8916)] = 383655,
  [SMALL_STATE(8917)] = 383701,
  [SMALL_STATE(8918)] = 383749,
  [SMALL_STATE(8919)] = 383797,
  [SMALL_STATE(8920)] = 383845,
  [SMALL_STATE(8921)] = 383891,
  [SMALL_STATE(8922)] = 383937,
  [SMALL_STATE(8923)] = 383985,
  [SMALL_STATE(8924)] = 384031,
  [SMALL_STATE(8925)] = 384079,
  [SMALL_STATE(8926)] = 384125,
  [SMALL_STATE(8927)] = 384173,
  [SMALL_STATE(8928)] = 384221,
  [SMALL_STATE(8929)] = 384269,
  [SMALL_STATE(8930)] = 384317,
  [SMALL_STATE(8931)] = 384365,
  [SMALL_STATE(8932)] = 384413,
  [SMALL_STATE(8933)] = 384461,
  [SMALL_STATE(8934)] = 384509,
  [SMALL_STATE(8935)] = 384557,
  [SMALL_STATE(8936)] = 384603,
  [SMALL_STATE(8937)] = 384649,
  [SMALL_STATE(8938)] = 384697,
  [SMALL_STATE(8939)] = 384743,
  [SMALL_STATE(8940)] = 384791,
  [SMALL_STATE(8941)] = 384839,
  [SMALL_STATE(8942)] = 384887,
  [SMALL_STATE(8943)] = 384935,
  [SMALL_STATE(8944)] = 384983,
  [SMALL_STATE(8945)] = 385031,
  [SMALL_STATE(8946)] = 385077,
  [SMALL_STATE(8947)] = 385125,
  [SMALL_STATE(8948)] = 385171,
  [SMALL_STATE(8949)] = 385217,
  [SMALL_STATE(8950)] = 385265,
  [SMALL_STATE(8951)] = 385313,
  [SMALL_STATE(8952)] = 385361,
  [SMALL_STATE(8953)] = 385407,
  [SMALL_STATE(8954)] = 385455,
  [SMALL_STATE(8955)] = 385501,
  [SMALL_STATE(8956)] = 385549,
  [SMALL_STATE(8957)] = 385597,
  [SMALL_STATE(8958)] = 385643,
  [SMALL_STATE(8959)] = 385691,
  [SMALL_STATE(8960)] = 385737,
  [SMALL_STATE(8961)] = 385783,
  [SMALL_STATE(8962)] = 385829,
  [SMALL_STATE(8963)] = 385875,
  [SMALL_STATE(8964)] = 385923,
  [SMALL_STATE(8965)] = 385969,
  [SMALL_STATE(8966)] = 386015,
  [SMALL_STATE(8967)] = 386063,
  [SMALL_STATE(8968)] = 386109,
  [SMALL_STATE(8969)] = 386157,
  [SMALL_STATE(8970)] = 386205,
  [SMALL_STATE(8971)] = 386251,
  [SMALL_STATE(8972)] = 386299,
  [SMALL_STATE(8973)] = 386347,
  [SMALL_STATE(8974)] = 386395,
  [SMALL_STATE(8975)] = 386443,
  [SMALL_STATE(8976)] = 386489,
  [SMALL_STATE(8977)] = 386535,
  [SMALL_STATE(8978)] = 386583,
  [SMALL_STATE(8979)] = 386631,
  [SMALL_STATE(8980)] = 386677,
  [SMALL_STATE(8981)] = 386725,
  [SMALL_STATE(8982)] = 386771,
  [SMALL_STATE(8983)] = 386819,
  [SMALL_STATE(8984)] = 386865,
  [SMALL_STATE(8985)] = 386911,
  [SMALL_STATE(8986)] = 386957,
  [SMALL_STATE(8987)] = 387005,
  [SMALL_STATE(8988)] = 387053,
  [SMALL_STATE(8989)] = 387099,
  [SMALL_STATE(8990)] = 387145,
  [SMALL_STATE(8991)] = 387191,
  [SMALL_STATE(8992)] = 387239,
  [SMALL_STATE(8993)] = 387287,
  [SMALL_STATE(8994)] = 387335,
  [SMALL_STATE(8995)] = 387383,
  [SMALL_STATE(8996)] = 387431,
  [SMALL_STATE(8997)] = 387476,
  [SMALL_STATE(8998)] = 387521,
  [SMALL_STATE(8999)] = 387566,
  [SMALL_STATE(9000)] = 387611,
  [SMALL_STATE(9001)] = 387656,
  [SMALL_STATE(9002)] = 387701,
  [SMALL_STATE(9003)] = 387746,
  [SMALL_STATE(9004)] = 387791,
  [SMALL_STATE(9005)] = 387836,
  [SMALL_STATE(9006)] = 387881,
  [SMALL_STATE(9007)] = 387926,
  [SMALL_STATE(9008)] = 387971,
  [SMALL_STATE(9009)] = 388016,
  [SMALL_STATE(9010)] = 388061,
  [SMALL_STATE(9011)] = 388106,
  [SMALL_STATE(9012)] = 388151,
  [SMALL_STATE(9013)] = 388196,
  [SMALL_STATE(9014)] = 388241,
  [SMALL_STATE(9015)] = 388286,
  [SMALL_STATE(9016)] = 388331,
  [SMALL_STATE(9017)] = 388376,
  [SMALL_STATE(9018)] = 388421,
  [SMALL_STATE(9019)] = 388466,
  [SMALL_STATE(9020)] = 388511,
  [SMALL_STATE(9021)] = 388556,
  [SMALL_STATE(9022)] = 388601,
  [SMALL_STATE(9023)] = 388646,
  [SMALL_STATE(9024)] = 388691,
  [SMALL_STATE(9025)] = 388736,
  [SMALL_STATE(9026)] = 388781,
  [SMALL_STATE(9027)] = 388826,
  [SMALL_STATE(9028)] = 388871,
  [SMALL_STATE(9029)] = 388916,
  [SMALL_STATE(9030)] = 388961,
  [SMALL_STATE(9031)] = 389006,
  [SMALL_STATE(9032)] = 389051,
  [SMALL_STATE(9033)] = 389096,
  [SMALL_STATE(9034)] = 389141,
  [SMALL_STATE(9035)] = 389186,
  [SMALL_STATE(9036)] = 389231,
  [SMALL_STATE(9037)] = 389276,
  [SMALL_STATE(9038)] = 389321,
  [SMALL_STATE(9039)] = 389366,
  [SMALL_STATE(9040)] = 389411,
  [SMALL_STATE(9041)] = 389456,
  [SMALL_STATE(9042)] = 389501,
  [SMALL_STATE(9043)] = 389546,
  [SMALL_STATE(9044)] = 389591,
  [SMALL_STATE(9045)] = 389636,
  [SMALL_STATE(9046)] = 389681,
  [SMALL_STATE(9047)] = 389726,
  [SMALL_STATE(9048)] = 389771,
  [SMALL_STATE(9049)] = 389816,
  [SMALL_STATE(9050)] = 389861,
  [SMALL_STATE(9051)] = 389906,
  [SMALL_STATE(9052)] = 389951,
  [SMALL_STATE(9053)] = 389996,
  [SMALL_STATE(9054)] = 390041,
  [SMALL_STATE(9055)] = 390086,
  [SMALL_STATE(9056)] = 390131,
  [SMALL_STATE(9057)] = 390176,
  [SMALL_STATE(9058)] = 390221,
  [SMALL_STATE(9059)] = 390266,
  [SMALL_STATE(9060)] = 390311,
  [SMALL_STATE(9061)] = 390356,
  [SMALL_STATE(9062)] = 390401,
  [SMALL_STATE(9063)] = 390446,
  [SMALL_STATE(9064)] = 390491,
  [SMALL_STATE(9065)] = 390536,
  [SMALL_STATE(9066)] = 390581,
  [SMALL_STATE(9067)] = 390626,
  [SMALL_STATE(9068)] = 390671,
  [SMALL_STATE(9069)] = 390716,
  [SMALL_STATE(9070)] = 390761,
  [SMALL_STATE(9071)] = 390806,
  [SMALL_STATE(9072)] = 390851,
  [SMALL_STATE(9073)] = 390896,
  [SMALL_STATE(9074)] = 390941,
  [SMALL_STATE(9075)] = 390986,
  [SMALL_STATE(9076)] = 391031,
  [SMALL_STATE(9077)] = 391076,
  [SMALL_STATE(9078)] = 391121,
  [SMALL_STATE(9079)] = 391166,
  [SMALL_STATE(9080)] = 391211,
  [SMALL_STATE(9081)] = 391256,
  [SMALL_STATE(9082)] = 391301,
  [SMALL_STATE(9083)] = 391346,
  [SMALL_STATE(9084)] = 391391,
  [SMALL_STATE(9085)] = 391436,
  [SMALL_STATE(9086)] = 391481,
  [SMALL_STATE(9087)] = 391526,
  [SMALL_STATE(9088)] = 391571,
  [SMALL_STATE(9089)] = 391616,
  [SMALL_STATE(9090)] = 391661,
  [SMALL_STATE(9091)] = 391706,
  [SMALL_STATE(9092)] = 391751,
  [SMALL_STATE(9093)] = 391796,
  [SMALL_STATE(9094)] = 391841,
  [SMALL_STATE(9095)] = 391886,
  [SMALL_STATE(9096)] = 391931,
  [SMALL_STATE(9097)] = 391976,
  [SMALL_STATE(9098)] = 392021,
  [SMALL_STATE(9099)] = 392066,
  [SMALL_STATE(9100)] = 392111,
  [SMALL_STATE(9101)] = 392156,
  [SMALL_STATE(9102)] = 392201,
  [SMALL_STATE(9103)] = 392246,
  [SMALL_STATE(9104)] = 392291,
  [SMALL_STATE(9105)] = 392336,
  [SMALL_STATE(9106)] = 392381,
  [SMALL_STATE(9107)] = 392426,
  [SMALL_STATE(9108)] = 392471,
  [SMALL_STATE(9109)] = 392516,
  [SMALL_STATE(9110)] = 392561,
  [SMALL_STATE(9111)] = 392606,
  [SMALL_STATE(9112)] = 392651,
  [SMALL_STATE(9113)] = 392696,
  [SMALL_STATE(9114)] = 392741,
  [SMALL_STATE(9115)] = 392786,
  [SMALL_STATE(9116)] = 392831,
  [SMALL_STATE(9117)] = 392876,
  [SMALL_STATE(9118)] = 392921,
  [SMALL_STATE(9119)] = 392966,
  [SMALL_STATE(9120)] = 393011,
  [SMALL_STATE(9121)] = 393056,
  [SMALL_STATE(9122)] = 393101,
  [SMALL_STATE(9123)] = 393146,
  [SMALL_STATE(9124)] = 393191,
  [SMALL_STATE(9125)] = 393236,
  [SMALL_STATE(9126)] = 393281,
  [SMALL_STATE(9127)] = 393326,
  [SMALL_STATE(9128)] = 393371,
  [SMALL_STATE(9129)] = 393416,
  [SMALL_STATE(9130)] = 393461,
  [SMALL_STATE(9131)] = 393506,
  [SMALL_STATE(9132)] = 393551,
  [SMALL_STATE(9133)] = 393596,
  [SMALL_STATE(9134)] = 393641,
  [SMALL_STATE(9135)] = 393686,
  [SMALL_STATE(9136)] = 393731,
  [SMALL_STATE(9137)] = 393776,
  [SMALL_STATE(9138)] = 393821,
  [SMALL_STATE(9139)] = 393866,
  [SMALL_STATE(9140)] = 393911,
  [SMALL_STATE(9141)] = 393956,
  [SMALL_STATE(9142)] = 394001,
  [SMALL_STATE(9143)] = 394046,
  [SMALL_STATE(9144)] = 394091,
  [SMALL_STATE(9145)] = 394136,
  [SMALL_STATE(9146)] = 394181,
  [SMALL_STATE(9147)] = 394226,
  [SMALL_STATE(9148)] = 394271,
  [SMALL_STATE(9149)] = 394316,
  [SMALL_STATE(9150)] = 394361,
  [SMALL_STATE(9151)] = 394406,
  [SMALL_STATE(9152)] = 394451,
  [SMALL_STATE(9153)] = 394496,
  [SMALL_STATE(9154)] = 394541,
  [SMALL_STATE(9155)] = 394586,
  [SMALL_STATE(9156)] = 394631,
  [SMALL_STATE(9157)] = 394676,
  [SMALL_STATE(9158)] = 394721,
  [SMALL_STATE(9159)] = 394766,
  [SMALL_STATE(9160)] = 394811,
  [SMALL_STATE(9161)] = 394856,
  [SMALL_STATE(9162)] = 394901,
  [SMALL_STATE(9163)] = 394946,
  [SMALL_STATE(9164)] = 394991,
  [SMALL_STATE(9165)] = 395036,
  [SMALL_STATE(9166)] = 395081,
  [SMALL_STATE(9167)] = 395126,
  [SMALL_STATE(9168)] = 395171,
  [SMALL_STATE(9169)] = 395216,
  [SMALL_STATE(9170)] = 395261,
  [SMALL_STATE(9171)] = 395306,
  [SMALL_STATE(9172)] = 395351,
  [SMALL_STATE(9173)] = 395396,
  [SMALL_STATE(9174)] = 395441,
  [SMALL_STATE(9175)] = 395486,
  [SMALL_STATE(9176)] = 395531,
  [SMALL_STATE(9177)] = 395576,
  [SMALL_STATE(9178)] = 395621,
  [SMALL_STATE(9179)] = 395666,
  [SMALL_STATE(9180)] = 395711,
  [SMALL_STATE(9181)] = 395756,
  [SMALL_STATE(9182)] = 395801,
  [SMALL_STATE(9183)] = 395846,
  [SMALL_STATE(9184)] = 395891,
  [SMALL_STATE(9185)] = 395936,
  [SMALL_STATE(9186)] = 395981,
  [SMALL_STATE(9187)] = 396026,
  [SMALL_STATE(9188)] = 396071,
  [SMALL_STATE(9189)] = 396116,
  [SMALL_STATE(9190)] = 396161,
  [SMALL_STATE(9191)] = 396206,
  [SMALL_STATE(9192)] = 396251,
  [SMALL_STATE(9193)] = 396296,
  [SMALL_STATE(9194)] = 396341,
  [SMALL_STATE(9195)] = 396386,
  [SMALL_STATE(9196)] = 396431,
  [SMALL_STATE(9197)] = 396476,
  [SMALL_STATE(9198)] = 396521,
  [SMALL_STATE(9199)] = 396566,
  [SMALL_STATE(9200)] = 396611,
  [SMALL_STATE(9201)] = 396656,
  [SMALL_STATE(9202)] = 396701,
  [SMALL_STATE(9203)] = 396746,
  [SMALL_STATE(9204)] = 396791,
  [SMALL_STATE(9205)] = 396836,
  [SMALL_STATE(9206)] = 396881,
  [SMALL_STATE(9207)] = 396926,
  [SMALL_STATE(9208)] = 396971,
  [SMALL_STATE(9209)] = 397016,
  [SMALL_STATE(9210)] = 397061,
  [SMALL_STATE(9211)] = 397106,
  [SMALL_STATE(9212)] = 397151,
  [SMALL_STATE(9213)] = 397196,
  [SMALL_STATE(9214)] = 397241,
  [SMALL_STATE(9215)] = 397286,
  [SMALL_STATE(9216)] = 397331,
  [SMALL_STATE(9217)] = 397376,
  [SMALL_STATE(9218)] = 397421,
  [SMALL_STATE(9219)] = 397466,
  [SMALL_STATE(9220)] = 397511,
  [SMALL_STATE(9221)] = 397556,
  [SMALL_STATE(9222)] = 397601,
  [SMALL_STATE(9223)] = 397646,
  [SMALL_STATE(9224)] = 397691,
  [SMALL_STATE(9225)] = 397736,
  [SMALL_STATE(9226)] = 397781,
  [SMALL_STATE(9227)] = 397826,
  [SMALL_STATE(9228)] = 397871,
  [SMALL_STATE(9229)] = 397916,
  [SMALL_STATE(9230)] = 397961,
  [SMALL_STATE(9231)] = 398006,
  [SMALL_STATE(9232)] = 398051,
  [SMALL_STATE(9233)] = 398096,
  [SMALL_STATE(9234)] = 398141,
  [SMALL_STATE(9235)] = 398186,
  [SMALL_STATE(9236)] = 398231,
  [SMALL_STATE(9237)] = 398276,
  [SMALL_STATE(9238)] = 398321,
  [SMALL_STATE(9239)] = 398366,
  [SMALL_STATE(9240)] = 398411,
  [SMALL_STATE(9241)] = 398456,
  [SMALL_STATE(9242)] = 398501,
  [SMALL_STATE(9243)] = 398546,
  [SMALL_STATE(9244)] = 398591,
  [SMALL_STATE(9245)] = 398636,
  [SMALL_STATE(9246)] = 398681,
  [SMALL_STATE(9247)] = 398726,
  [SMALL_STATE(9248)] = 398771,
  [SMALL_STATE(9249)] = 398816,
  [SMALL_STATE(9250)] = 398861,
  [SMALL_STATE(9251)] = 398906,
  [SMALL_STATE(9252)] = 398951,
  [SMALL_STATE(9253)] = 398996,
  [SMALL_STATE(9254)] = 399041,
  [SMALL_STATE(9255)] = 399086,
  [SMALL_STATE(9256)] = 399131,
  [SMALL_STATE(9257)] = 399176,
  [SMALL_STATE(9258)] = 399221,
  [SMALL_STATE(9259)] = 399266,
  [SMALL_STATE(9260)] = 399311,
  [SMALL_STATE(9261)] = 399356,
  [SMALL_STATE(9262)] = 399401,
  [SMALL_STATE(9263)] = 399446,
  [SMALL_STATE(9264)] = 399491,
  [SMALL_STATE(9265)] = 399536,
  [SMALL_STATE(9266)] = 399581,
  [SMALL_STATE(9267)] = 399626,
  [SMALL_STATE(9268)] = 399671,
  [SMALL_STATE(9269)] = 399716,
  [SMALL_STATE(9270)] = 399761,
  [SMALL_STATE(9271)] = 399806,
  [SMALL_STATE(9272)] = 399851,
  [SMALL_STATE(9273)] = 399896,
  [SMALL_STATE(9274)] = 399941,
  [SMALL_STATE(9275)] = 399986,
  [SMALL_STATE(9276)] = 400031,
  [SMALL_STATE(9277)] = 400076,
  [SMALL_STATE(9278)] = 400121,
  [SMALL_STATE(9279)] = 400166,
  [SMALL_STATE(9280)] = 400211,
  [SMALL_STATE(9281)] = 400256,
  [SMALL_STATE(9282)] = 400301,
  [SMALL_STATE(9283)] = 400346,
  [SMALL_STATE(9284)] = 400391,
  [SMALL_STATE(9285)] = 400436,
  [SMALL_STATE(9286)] = 400481,
  [SMALL_STATE(9287)] = 400526,
  [SMALL_STATE(9288)] = 400571,
  [SMALL_STATE(9289)] = 400616,
  [SMALL_STATE(9290)] = 400661,
  [SMALL_STATE(9291)] = 400706,
  [SMALL_STATE(9292)] = 400751,
  [SMALL_STATE(9293)] = 400796,
  [SMALL_STATE(9294)] = 400841,
  [SMALL_STATE(9295)] = 400886,
  [SMALL_STATE(9296)] = 400931,
  [SMALL_STATE(9297)] = 400976,
  [SMALL_STATE(9298)] = 401021,
  [SMALL_STATE(9299)] = 401066,
  [SMALL_STATE(9300)] = 401111,
  [SMALL_STATE(9301)] = 401156,
  [SMALL_STATE(9302)] = 401201,
  [SMALL_STATE(9303)] = 401246,
  [SMALL_STATE(9304)] = 401291,
  [SMALL_STATE(9305)] = 401336,
  [SMALL_STATE(9306)] = 401381,
  [SMALL_STATE(9307)] = 401426,
  [SMALL_STATE(9308)] = 401471,
  [SMALL_STATE(9309)] = 401516,
  [SMALL_STATE(9310)] = 401561,
  [SMALL_STATE(9311)] = 401606,
  [SMALL_STATE(9312)] = 401651,
  [SMALL_STATE(9313)] = 401696,
  [SMALL_STATE(9314)] = 401741,
  [SMALL_STATE(9315)] = 401786,
  [SMALL_STATE(9316)] = 401831,
  [SMALL_STATE(9317)] = 401876,
  [SMALL_STATE(9318)] = 401921,
  [SMALL_STATE(9319)] = 401966,
  [SMALL_STATE(9320)] = 402011,
  [SMALL_STATE(9321)] = 402056,
  [SMALL_STATE(9322)] = 402101,
  [SMALL_STATE(9323)] = 402146,
  [SMALL_STATE(9324)] = 402191,
  [SMALL_STATE(9325)] = 402236,
  [SMALL_STATE(9326)] = 402281,
  [SMALL_STATE(9327)] = 402326,
  [SMALL_STATE(9328)] = 402371,
  [SMALL_STATE(9329)] = 402416,
  [SMALL_STATE(9330)] = 402461,
  [SMALL_STATE(9331)] = 402506,
  [SMALL_STATE(9332)] = 402551,
  [SMALL_STATE(9333)] = 402596,
  [SMALL_STATE(9334)] = 402641,
  [SMALL_STATE(9335)] = 402686,
  [SMALL_STATE(9336)] = 402731,
  [SMALL_STATE(9337)] = 402776,
  [SMALL_STATE(9338)] = 402821,
  [SMALL_STATE(9339)] = 402866,
  [SMALL_STATE(9340)] = 402911,
  [SMALL_STATE(9341)] = 402956,
  [SMALL_STATE(9342)] = 403001,
  [SMALL_STATE(9343)] = 403046,
  [SMALL_STATE(9344)] = 403091,
  [SMALL_STATE(9345)] = 403136,
  [SMALL_STATE(9346)] = 403181,
  [SMALL_STATE(9347)] = 403226,
  [SMALL_STATE(9348)] = 403271,
  [SMALL_STATE(9349)] = 403316,
  [SMALL_STATE(9350)] = 403361,
  [SMALL_STATE(9351)] = 403406,
  [SMALL_STATE(9352)] = 403451,
  [SMALL_STATE(9353)] = 403496,
  [SMALL_STATE(9354)] = 403541,
  [SMALL_STATE(9355)] = 403586,
  [SMALL_STATE(9356)] = 403631,
  [SMALL_STATE(9357)] = 403676,
  [SMALL_STATE(9358)] = 403721,
  [SMALL_STATE(9359)] = 403766,
  [SMALL_STATE(9360)] = 403811,
  [SMALL_STATE(9361)] = 403856,
  [SMALL_STATE(9362)] = 403901,
  [SMALL_STATE(9363)] = 403946,
  [SMALL_STATE(9364)] = 403991,
  [SMALL_STATE(9365)] = 404036,
  [SMALL_STATE(9366)] = 404081,
  [SMALL_STATE(9367)] = 404126,
  [SMALL_STATE(9368)] = 404171,
  [SMALL_STATE(9369)] = 404216,
  [SMALL_STATE(9370)] = 404261,
  [SMALL_STATE(9371)] = 404306,
  [SMALL_STATE(9372)] = 404351,
  [SMALL_STATE(9373)] = 404396,
  [SMALL_STATE(9374)] = 404441,
  [SMALL_STATE(9375)] = 404486,
  [SMALL_STATE(9376)] = 404531,
  [SMALL_STATE(9377)] = 404576,
  [SMALL_STATE(9378)] = 404621,
  [SMALL_STATE(9379)] = 404666,
  [SMALL_STATE(9380)] = 404711,
  [SMALL_STATE(9381)] = 404756,
  [SMALL_STATE(9382)] = 404801,
  [SMALL_STATE(9383)] = 404846,
  [SMALL_STATE(9384)] = 404891,
  [SMALL_STATE(9385)] = 404936,
  [SMALL_STATE(9386)] = 404981,
  [SMALL_STATE(9387)] = 405026,
  [SMALL_STATE(9388)] = 405071,
  [SMALL_STATE(9389)] = 405116,
  [SMALL_STATE(9390)] = 405161,
  [SMALL_STATE(9391)] = 405206,
  [SMALL_STATE(9392)] = 405251,
  [SMALL_STATE(9393)] = 405296,
  [SMALL_STATE(9394)] = 405341,
  [SMALL_STATE(9395)] = 405386,
  [SMALL_STATE(9396)] = 405431,
  [SMALL_STATE(9397)] = 405476,
  [SMALL_STATE(9398)] = 405521,
  [SMALL_STATE(9399)] = 405566,
  [SMALL_STATE(9400)] = 405611,
  [SMALL_STATE(9401)] = 405656,
  [SMALL_STATE(9402)] = 405701,
  [SMALL_STATE(9403)] = 405746,
  [SMALL_STATE(9404)] = 405791,
  [SMALL_STATE(9405)] = 405836,
  [SMALL_STATE(9406)] = 405881,
  [SMALL_STATE(9407)] = 405926,
  [SMALL_STATE(9408)] = 405971,
  [SMALL_STATE(9409)] = 406016,
  [SMALL_STATE(9410)] = 406061,
  [SMALL_STATE(9411)] = 406106,
  [SMALL_STATE(9412)] = 406151,
  [SMALL_STATE(9413)] = 406196,
  [SMALL_STATE(9414)] = 406241,
  [SMALL_STATE(9415)] = 406286,
  [SMALL_STATE(9416)] = 406331,
  [SMALL_STATE(9417)] = 406376,
  [SMALL_STATE(9418)] = 406421,
  [SMALL_STATE(9419)] = 406466,
  [SMALL_STATE(9420)] = 406511,
  [SMALL_STATE(9421)] = 406556,
  [SMALL_STATE(9422)] = 406601,
  [SMALL_STATE(9423)] = 406646,
  [SMALL_STATE(9424)] = 406691,
  [SMALL_STATE(9425)] = 406736,
  [SMALL_STATE(9426)] = 406781,
  [SMALL_STATE(9427)] = 406826,
  [SMALL_STATE(9428)] = 406871,
  [SMALL_STATE(9429)] = 406916,
  [SMALL_STATE(9430)] = 406961,
  [SMALL_STATE(9431)] = 407006,
  [SMALL_STATE(9432)] = 407051,
  [SMALL_STATE(9433)] = 407096,
  [SMALL_STATE(9434)] = 407141,
  [SMALL_STATE(9435)] = 407186,
  [SMALL_STATE(9436)] = 407231,
  [SMALL_STATE(9437)] = 407276,
  [SMALL_STATE(9438)] = 407321,
  [SMALL_STATE(9439)] = 407366,
  [SMALL_STATE(9440)] = 407411,
  [SMALL_STATE(9441)] = 407456,
  [SMALL_STATE(9442)] = 407501,
  [SMALL_STATE(9443)] = 407546,
  [SMALL_STATE(9444)] = 407591,
  [SMALL_STATE(9445)] = 407636,
  [SMALL_STATE(9446)] = 407681,
  [SMALL_STATE(9447)] = 407726,
  [SMALL_STATE(9448)] = 407771,
  [SMALL_STATE(9449)] = 407816,
  [SMALL_STATE(9450)] = 407861,
  [SMALL_STATE(9451)] = 407906,
  [SMALL_STATE(9452)] = 407951,
  [SMALL_STATE(9453)] = 407996,
  [SMALL_STATE(9454)] = 408041,
  [SMALL_STATE(9455)] = 408086,
  [SMALL_STATE(9456)] = 408131,
  [SMALL_STATE(9457)] = 408176,
  [SMALL_STATE(9458)] = 408221,
  [SMALL_STATE(9459)] = 408266,
  [SMALL_STATE(9460)] = 408311,
  [SMALL_STATE(9461)] = 408356,
  [SMALL_STATE(9462)] = 408401,
  [SMALL_STATE(9463)] = 408446,
  [SMALL_STATE(9464)] = 408491,
  [SMALL_STATE(9465)] = 408536,
  [SMALL_STATE(9466)] = 408581,
  [SMALL_STATE(9467)] = 408626,
  [SMALL_STATE(9468)] = 408671,
  [SMALL_STATE(9469)] = 408716,
  [SMALL_STATE(9470)] = 408761,
  [SMALL_STATE(9471)] = 408806,
  [SMALL_STATE(9472)] = 408851,
  [SMALL_STATE(9473)] = 408896,
  [SMALL_STATE(9474)] = 408941,
  [SMALL_STATE(9475)] = 408986,
  [SMALL_STATE(9476)] = 409031,
  [SMALL_STATE(9477)] = 409076,
  [SMALL_STATE(9478)] = 409121,
  [SMALL_STATE(9479)] = 409166,
  [SMALL_STATE(9480)] = 409211,
  [SMALL_STATE(9481)] = 409256,
  [SMALL_STATE(9482)] = 409301,
  [SMALL_STATE(9483)] = 409346,
  [SMALL_STATE(9484)] = 409391,
  [SMALL_STATE(9485)] = 409436,
  [SMALL_STATE(9486)] = 409481,
  [SMALL_STATE(9487)] = 409526,
  [SMALL_STATE(9488)] = 409571,
  [SMALL_STATE(9489)] = 409616,
  [SMALL_STATE(9490)] = 409661,
  [SMALL_STATE(9491)] = 409706,
  [SMALL_STATE(9492)] = 409751,
  [SMALL_STATE(9493)] = 409796,
  [SMALL_STATE(9494)] = 409841,
  [SMALL_STATE(9495)] = 409886,
  [SMALL_STATE(9496)] = 409931,
  [SMALL_STATE(9497)] = 409976,
  [SMALL_STATE(9498)] = 410021,
  [SMALL_STATE(9499)] = 410066,
  [SMALL_STATE(9500)] = 410111,
  [SMALL_STATE(9501)] = 410156,
  [SMALL_STATE(9502)] = 410201,
  [SMALL_STATE(9503)] = 410246,
  [SMALL_STATE(9504)] = 410291,
  [SMALL_STATE(9505)] = 410336,
  [SMALL_STATE(9506)] = 410381,
  [SMALL_STATE(9507)] = 410426,
  [SMALL_STATE(9508)] = 410471,
  [SMALL_STATE(9509)] = 410516,
  [SMALL_STATE(9510)] = 410561,
  [SMALL_STATE(9511)] = 410606,
  [SMALL_STATE(9512)] = 410651,
  [SMALL_STATE(9513)] = 410696,
  [SMALL_STATE(9514)] = 410741,
  [SMALL_STATE(9515)] = 410786,
  [SMALL_STATE(9516)] = 410831,
  [SMALL_STATE(9517)] = 410876,
  [SMALL_STATE(9518)] = 410921,
  [SMALL_STATE(9519)] = 410966,
  [SMALL_STATE(9520)] = 411011,
  [SMALL_STATE(9521)] = 411056,
  [SMALL_STATE(9522)] = 411101,
  [SMALL_STATE(9523)] = 411146,
  [SMALL_STATE(9524)] = 411191,
  [SMALL_STATE(9525)] = 411236,
  [SMALL_STATE(9526)] = 411281,
  [SMALL_STATE(9527)] = 411326,
  [SMALL_STATE(9528)] = 411371,
  [SMALL_STATE(9529)] = 411416,
  [SMALL_STATE(9530)] = 411461,
  [SMALL_STATE(9531)] = 411506,
  [SMALL_STATE(9532)] = 411551,
  [SMALL_STATE(9533)] = 411596,
  [SMALL_STATE(9534)] = 411641,
  [SMALL_STATE(9535)] = 411686,
  [SMALL_STATE(9536)] = 411731,
  [SMALL_STATE(9537)] = 411776,
  [SMALL_STATE(9538)] = 411821,
  [SMALL_STATE(9539)] = 411866,
  [SMALL_STATE(9540)] = 411911,
  [SMALL_STATE(9541)] = 411956,
  [SMALL_STATE(9542)] = 412001,
  [SMALL_STATE(9543)] = 412046,
  [SMALL_STATE(9544)] = 412091,
  [SMALL_STATE(9545)] = 412136,
  [SMALL_STATE(9546)] = 412181,
  [SMALL_STATE(9547)] = 412226,
  [SMALL_STATE(9548)] = 412271,
  [SMALL_STATE(9549)] = 412316,
  [SMALL_STATE(9550)] = 412361,
  [SMALL_STATE(9551)] = 412406,
  [SMALL_STATE(9552)] = 412451,
  [SMALL_STATE(9553)] = 412496,
  [SMALL_STATE(9554)] = 412541,
  [SMALL_STATE(9555)] = 412586,
  [SMALL_STATE(9556)] = 412631,
  [SMALL_STATE(9557)] = 412676,
  [SMALL_STATE(9558)] = 412721,
  [SMALL_STATE(9559)] = 412766,
  [SMALL_STATE(9560)] = 412811,
  [SMALL_STATE(9561)] = 412856,
  [SMALL_STATE(9562)] = 412901,
  [SMALL_STATE(9563)] = 412946,
  [SMALL_STATE(9564)] = 412991,
  [SMALL_STATE(9565)] = 413036,
  [SMALL_STATE(9566)] = 413081,
  [SMALL_STATE(9567)] = 413126,
  [SMALL_STATE(9568)] = 413171,
  [SMALL_STATE(9569)] = 413216,
  [SMALL_STATE(9570)] = 413261,
  [SMALL_STATE(9571)] = 413306,
  [SMALL_STATE(9572)] = 413351,
  [SMALL_STATE(9573)] = 413396,
  [SMALL_STATE(9574)] = 413441,
  [SMALL_STATE(9575)] = 413486,
  [SMALL_STATE(9576)] = 413531,
  [SMALL_STATE(9577)] = 413576,
  [SMALL_STATE(9578)] = 413621,
  [SMALL_STATE(9579)] = 413666,
  [SMALL_STATE(9580)] = 413711,
  [SMALL_STATE(9581)] = 413756,
  [SMALL_STATE(9582)] = 413801,
  [SMALL_STATE(9583)] = 413846,
  [SMALL_STATE(9584)] = 413891,
  [SMALL_STATE(9585)] = 413936,
  [SMALL_STATE(9586)] = 413981,
  [SMALL_STATE(9587)] = 414026,
  [SMALL_STATE(9588)] = 414071,
  [SMALL_STATE(9589)] = 414116,
  [SMALL_STATE(9590)] = 414161,
  [SMALL_STATE(9591)] = 414206,
  [SMALL_STATE(9592)] = 414251,
  [SMALL_STATE(9593)] = 414296,
  [SMALL_STATE(9594)] = 414341,
  [SMALL_STATE(9595)] = 414386,
  [SMALL_STATE(9596)] = 414431,
  [SMALL_STATE(9597)] = 414476,
  [SMALL_STATE(9598)] = 414521,
  [SMALL_STATE(9599)] = 414566,
  [SMALL_STATE(9600)] = 414611,
  [SMALL_STATE(9601)] = 414656,
  [SMALL_STATE(9602)] = 414701,
  [SMALL_STATE(9603)] = 414746,
  [SMALL_STATE(9604)] = 414791,
  [SMALL_STATE(9605)] = 414836,
  [SMALL_STATE(9606)] = 414881,
  [SMALL_STATE(9607)] = 414926,
  [SMALL_STATE(9608)] = 414971,
  [SMALL_STATE(9609)] = 415016,
  [SMALL_STATE(9610)] = 415061,
  [SMALL_STATE(9611)] = 415106,
  [SMALL_STATE(9612)] = 415151,
  [SMALL_STATE(9613)] = 415196,
  [SMALL_STATE(9614)] = 415241,
  [SMALL_STATE(9615)] = 415286,
  [SMALL_STATE(9616)] = 415331,
  [SMALL_STATE(9617)] = 415376,
  [SMALL_STATE(9618)] = 415421,
  [SMALL_STATE(9619)] = 415466,
  [SMALL_STATE(9620)] = 415511,
  [SMALL_STATE(9621)] = 415556,
  [SMALL_STATE(9622)] = 415601,
  [SMALL_STATE(9623)] = 415646,
  [SMALL_STATE(9624)] = 415691,
  [SMALL_STATE(9625)] = 415736,
  [SMALL_STATE(9626)] = 415781,
  [SMALL_STATE(9627)] = 415826,
  [SMALL_STATE(9628)] = 415871,
  [SMALL_STATE(9629)] = 415916,
  [SMALL_STATE(9630)] = 415961,
  [SMALL_STATE(9631)] = 416006,
  [SMALL_STATE(9632)] = 416051,
  [SMALL_STATE(9633)] = 416096,
  [SMALL_STATE(9634)] = 416141,
  [SMALL_STATE(9635)] = 416186,
  [SMALL_STATE(9636)] = 416231,
  [SMALL_STATE(9637)] = 416276,
  [SMALL_STATE(9638)] = 416321,
  [SMALL_STATE(9639)] = 416366,
  [SMALL_STATE(9640)] = 416411,
  [SMALL_STATE(9641)] = 416456,
  [SMALL_STATE(9642)] = 416501,
  [SMALL_STATE(9643)] = 416546,
  [SMALL_STATE(9644)] = 416591,
  [SMALL_STATE(9645)] = 416636,
  [SMALL_STATE(9646)] = 416681,
  [SMALL_STATE(9647)] = 416726,
  [SMALL_STATE(9648)] = 416771,
  [SMALL_STATE(9649)] = 416816,
  [SMALL_STATE(9650)] = 416861,
  [SMALL_STATE(9651)] = 416906,
  [SMALL_STATE(9652)] = 416951,
  [SMALL_STATE(9653)] = 416996,
  [SMALL_STATE(9654)] = 417041,
  [SMALL_STATE(9655)] = 417086,
  [SMALL_STATE(9656)] = 417131,
  [SMALL_STATE(9657)] = 417176,
  [SMALL_STATE(9658)] = 417221,
  [SMALL_STATE(9659)] = 417266,
  [SMALL_STATE(9660)] = 417311,
  [SMALL_STATE(9661)] = 417356,
  [SMALL_STATE(9662)] = 417401,
  [SMALL_STATE(9663)] = 417446,
  [SMALL_STATE(9664)] = 417491,
  [SMALL_STATE(9665)] = 417536,
  [SMALL_STATE(9666)] = 417581,
  [SMALL_STATE(9667)] = 417626,
  [SMALL_STATE(9668)] = 417671,
  [SMALL_STATE(9669)] = 417716,
  [SMALL_STATE(9670)] = 417761,
  [SMALL_STATE(9671)] = 417806,
  [SMALL_STATE(9672)] = 417851,
  [SMALL_STATE(9673)] = 417896,
  [SMALL_STATE(9674)] = 417941,
  [SMALL_STATE(9675)] = 417986,
  [SMALL_STATE(9676)] = 418031,
  [SMALL_STATE(9677)] = 418076,
  [SMALL_STATE(9678)] = 418121,
  [SMALL_STATE(9679)] = 418166,
  [SMALL_STATE(9680)] = 418211,
  [SMALL_STATE(9681)] = 418256,
  [SMALL_STATE(9682)] = 418301,
  [SMALL_STATE(9683)] = 418346,
  [SMALL_STATE(9684)] = 418391,
  [SMALL_STATE(9685)] = 418436,
  [SMALL_STATE(9686)] = 418481,
  [SMALL_STATE(9687)] = 418526,
  [SMALL_STATE(9688)] = 418571,
  [SMALL_STATE(9689)] = 418616,
  [SMALL_STATE(9690)] = 418661,
  [SMALL_STATE(9691)] = 418706,
  [SMALL_STATE(9692)] = 418751,
  [SMALL_STATE(9693)] = 418796,
  [SMALL_STATE(9694)] = 418841,
  [SMALL_STATE(9695)] = 418886,
  [SMALL_STATE(9696)] = 418931,
  [SMALL_STATE(9697)] = 418976,
  [SMALL_STATE(9698)] = 419021,
  [SMALL_STATE(9699)] = 419066,
  [SMALL_STATE(9700)] = 419111,
  [SMALL_STATE(9701)] = 419156,
  [SMALL_STATE(9702)] = 419201,
  [SMALL_STATE(9703)] = 419246,
  [SMALL_STATE(9704)] = 419291,
  [SMALL_STATE(9705)] = 419336,
  [SMALL_STATE(9706)] = 419381,
  [SMALL_STATE(9707)] = 419426,
  [SMALL_STATE(9708)] = 419471,
  [SMALL_STATE(9709)] = 419516,
  [SMALL_STATE(9710)] = 419561,
  [SMALL_STATE(9711)] = 419606,
  [SMALL_STATE(9712)] = 419651,
  [SMALL_STATE(9713)] = 419696,
  [SMALL_STATE(9714)] = 419741,
  [SMALL_STATE(9715)] = 419786,
  [SMALL_STATE(9716)] = 419831,
  [SMALL_STATE(9717)] = 419876,
  [SMALL_STATE(9718)] = 419921,
  [SMALL_STATE(9719)] = 419966,
  [SMALL_STATE(9720)] = 420011,
  [SMALL_STATE(9721)] = 420056,
  [SMALL_STATE(9722)] = 420101,
  [SMALL_STATE(9723)] = 420146,
  [SMALL_STATE(9724)] = 420191,
  [SMALL_STATE(9725)] = 420236,
  [SMALL_STATE(9726)] = 420281,
  [SMALL_STATE(9727)] = 420326,
  [SMALL_STATE(9728)] = 420371,
  [SMALL_STATE(9729)] = 420416,
  [SMALL_STATE(9730)] = 420461,
  [SMALL_STATE(9731)] = 420506,
  [SMALL_STATE(9732)] = 420551,
  [SMALL_STATE(9733)] = 420596,
  [SMALL_STATE(9734)] = 420641,
  [SMALL_STATE(9735)] = 420686,
  [SMALL_STATE(9736)] = 420731,
  [SMALL_STATE(9737)] = 420776,
  [SMALL_STATE(9738)] = 420821,
  [SMALL_STATE(9739)] = 420866,
  [SMALL_STATE(9740)] = 420911,
  [SMALL_STATE(9741)] = 420956,
  [SMALL_STATE(9742)] = 421001,
  [SMALL_STATE(9743)] = 421046,
  [SMALL_STATE(9744)] = 421091,
  [SMALL_STATE(9745)] = 421136,
  [SMALL_STATE(9746)] = 421181,
  [SMALL_STATE(9747)] = 421226,
  [SMALL_STATE(9748)] = 421271,
  [SMALL_STATE(9749)] = 421316,
  [SMALL_STATE(9750)] = 421361,
  [SMALL_STATE(9751)] = 421406,
  [SMALL_STATE(9752)] = 421451,
  [SMALL_STATE(9753)] = 421496,
  [SMALL_STATE(9754)] = 421541,
  [SMALL_STATE(9755)] = 421586,
  [SMALL_STATE(9756)] = 421631,
  [SMALL_STATE(9757)] = 421676,
  [SMALL_STATE(9758)] = 421721,
  [SMALL_STATE(9759)] = 421766,
  [SMALL_STATE(9760)] = 421811,
  [SMALL_STATE(9761)] = 421856,
  [SMALL_STATE(9762)] = 421901,
  [SMALL_STATE(9763)] = 421946,
  [SMALL_STATE(9764)] = 421991,
  [SMALL_STATE(9765)] = 422036,
  [SMALL_STATE(9766)] = 422081,
  [SMALL_STATE(9767)] = 422126,
  [SMALL_STATE(9768)] = 422171,
  [SMALL_STATE(9769)] = 422216,
  [SMALL_STATE(9770)] = 422261,
  [SMALL_STATE(9771)] = 422306,
  [SMALL_STATE(9772)] = 422351,
  [SMALL_STATE(9773)] = 422396,
  [SMALL_STATE(9774)] = 422441,
  [SMALL_STATE(9775)] = 422486,
  [SMALL_STATE(9776)] = 422531,
  [SMALL_STATE(9777)] = 422576,
  [SMALL_STATE(9778)] = 422621,
  [SMALL_STATE(9779)] = 422666,
  [SMALL_STATE(9780)] = 422711,
  [SMALL_STATE(9781)] = 422756,
  [SMALL_STATE(9782)] = 422801,
  [SMALL_STATE(9783)] = 422846,
  [SMALL_STATE(9784)] = 422891,
  [SMALL_STATE(9785)] = 422936,
  [SMALL_STATE(9786)] = 422981,
  [SMALL_STATE(9787)] = 423026,
  [SMALL_STATE(9788)] = 423071,
  [SMALL_STATE(9789)] = 423116,
  [SMALL_STATE(9790)] = 423161,
  [SMALL_STATE(9791)] = 423206,
  [SMALL_STATE(9792)] = 423251,
  [SMALL_STATE(9793)] = 423296,
  [SMALL_STATE(9794)] = 423341,
  [SMALL_STATE(9795)] = 423386,
  [SMALL_STATE(9796)] = 423431,
  [SMALL_STATE(9797)] = 423476,
  [SMALL_STATE(9798)] = 423521,
  [SMALL_STATE(9799)] = 423566,
  [SMALL_STATE(9800)] = 423611,
  [SMALL_STATE(9801)] = 423656,
  [SMALL_STATE(9802)] = 423701,
  [SMALL_STATE(9803)] = 423746,
  [SMALL_STATE(9804)] = 423791,
  [SMALL_STATE(9805)] = 423836,
  [SMALL_STATE(9806)] = 423881,
  [SMALL_STATE(9807)] = 423926,
  [SMALL_STATE(9808)] = 423971,
  [SMALL_STATE(9809)] = 424016,
  [SMALL_STATE(9810)] = 424061,
  [SMALL_STATE(9811)] = 424106,
  [SMALL_STATE(9812)] = 424151,
  [SMALL_STATE(9813)] = 424196,
  [SMALL_STATE(9814)] = 424241,
  [SMALL_STATE(9815)] = 424286,
  [SMALL_STATE(9816)] = 424331,
  [SMALL_STATE(9817)] = 424376,
  [SMALL_STATE(9818)] = 424421,
  [SMALL_STATE(9819)] = 424466,
  [SMALL_STATE(9820)] = 424511,
  [SMALL_STATE(9821)] = 424556,
  [SMALL_STATE(9822)] = 424601,
  [SMALL_STATE(9823)] = 424646,
  [SMALL_STATE(9824)] = 424691,
  [SMALL_STATE(9825)] = 424736,
  [SMALL_STATE(9826)] = 424781,
  [SMALL_STATE(9827)] = 424826,
  [SMALL_STATE(9828)] = 424871,
  [SMALL_STATE(9829)] = 424916,
  [SMALL_STATE(9830)] = 424961,
  [SMALL_STATE(9831)] = 425006,
  [SMALL_STATE(9832)] = 425051,
  [SMALL_STATE(9833)] = 425096,
  [SMALL_STATE(9834)] = 425141,
  [SMALL_STATE(9835)] = 425186,
  [SMALL_STATE(9836)] = 425231,
  [SMALL_STATE(9837)] = 425276,
  [SMALL_STATE(9838)] = 425321,
  [SMALL_STATE(9839)] = 425366,
  [SMALL_STATE(9840)] = 425411,
  [SMALL_STATE(9841)] = 425456,
  [SMALL_STATE(9842)] = 425501,
  [SMALL_STATE(9843)] = 425546,
  [SMALL_STATE(9844)] = 425591,
  [SMALL_STATE(9845)] = 425636,
  [SMALL_STATE(9846)] = 425681,
  [SMALL_STATE(9847)] = 425726,
  [SMALL_STATE(9848)] = 425771,
  [SMALL_STATE(9849)] = 425816,
  [SMALL_STATE(9850)] = 425861,
  [SMALL_STATE(9851)] = 425906,
  [SMALL_STATE(9852)] = 425951,
  [SMALL_STATE(9853)] = 425996,
  [SMALL_STATE(9854)] = 426041,
  [SMALL_STATE(9855)] = 426086,
  [SMALL_STATE(9856)] = 426131,
  [SMALL_STATE(9857)] = 426176,
  [SMALL_STATE(9858)] = 426221,
  [SMALL_STATE(9859)] = 426266,
  [SMALL_STATE(9860)] = 426311,
  [SMALL_STATE(9861)] = 426356,
  [SMALL_STATE(9862)] = 426401,
  [SMALL_STATE(9863)] = 426446,
  [SMALL_STATE(9864)] = 426491,
  [SMALL_STATE(9865)] = 426536,
  [SMALL_STATE(9866)] = 426581,
  [SMALL_STATE(9867)] = 426626,
  [SMALL_STATE(9868)] = 426671,
  [SMALL_STATE(9869)] = 426716,
  [SMALL_STATE(9870)] = 426761,
  [SMALL_STATE(9871)] = 426806,
  [SMALL_STATE(9872)] = 426851,
  [SMALL_STATE(9873)] = 426896,
  [SMALL_STATE(9874)] = 426941,
  [SMALL_STATE(9875)] = 426986,
  [SMALL_STATE(9876)] = 427031,
  [SMALL_STATE(9877)] = 427076,
  [SMALL_STATE(9878)] = 427121,
  [SMALL_STATE(9879)] = 427166,
  [SMALL_STATE(9880)] = 427211,
  [SMALL_STATE(9881)] = 427256,
  [SMALL_STATE(9882)] = 427301,
  [SMALL_STATE(9883)] = 427346,
  [SMALL_STATE(9884)] = 427391,
  [SMALL_STATE(9885)] = 427436,
  [SMALL_STATE(9886)] = 427481,
  [SMALL_STATE(9887)] = 427526,
  [SMALL_STATE(9888)] = 427571,
  [SMALL_STATE(9889)] = 427616,
  [SMALL_STATE(9890)] = 427661,
  [SMALL_STATE(9891)] = 427706,
  [SMALL_STATE(9892)] = 427751,
  [SMALL_STATE(9893)] = 427796,
  [SMALL_STATE(9894)] = 427841,
  [SMALL_STATE(9895)] = 427886,
  [SMALL_STATE(9896)] = 427931,
  [SMALL_STATE(9897)] = 427976,
  [SMALL_STATE(9898)] = 428021,
  [SMALL_STATE(9899)] = 428066,
  [SMALL_STATE(9900)] = 428111,
  [SMALL_STATE(9901)] = 428156,
  [SMALL_STATE(9902)] = 428201,
  [SMALL_STATE(9903)] = 428246,
  [SMALL_STATE(9904)] = 428291,
  [SMALL_STATE(9905)] = 428336,
  [SMALL_STATE(9906)] = 428381,
  [SMALL_STATE(9907)] = 428426,
  [SMALL_STATE(9908)] = 428471,
  [SMALL_STATE(9909)] = 428516,
  [SMALL_STATE(9910)] = 428561,
  [SMALL_STATE(9911)] = 428606,
  [SMALL_STATE(9912)] = 428651,
  [SMALL_STATE(9913)] = 428696,
  [SMALL_STATE(9914)] = 428741,
  [SMALL_STATE(9915)] = 428786,
  [SMALL_STATE(9916)] = 428831,
  [SMALL_STATE(9917)] = 428876,
  [SMALL_STATE(9918)] = 428921,
  [SMALL_STATE(9919)] = 428966,
  [SMALL_STATE(9920)] = 429011,
  [SMALL_STATE(9921)] = 429056,
  [SMALL_STATE(9922)] = 429101,
  [SMALL_STATE(9923)] = 429146,
  [SMALL_STATE(9924)] = 429191,
  [SMALL_STATE(9925)] = 429236,
  [SMALL_STATE(9926)] = 429281,
  [SMALL_STATE(9927)] = 429326,
  [SMALL_STATE(9928)] = 429371,
  [SMALL_STATE(9929)] = 429416,
  [SMALL_STATE(9930)] = 429461,
  [SMALL_STATE(9931)] = 429506,
  [SMALL_STATE(9932)] = 429551,
  [SMALL_STATE(9933)] = 429596,
  [SMALL_STATE(9934)] = 429641,
  [SMALL_STATE(9935)] = 429686,
  [SMALL_STATE(9936)] = 429731,
  [SMALL_STATE(9937)] = 429776,
  [SMALL_STATE(9938)] = 429821,
  [SMALL_STATE(9939)] = 429866,
  [SMALL_STATE(9940)] = 429911,
  [SMALL_STATE(9941)] = 429956,
  [SMALL_STATE(9942)] = 430001,
  [SMALL_STATE(9943)] = 430046,
  [SMALL_STATE(9944)] = 430091,
  [SMALL_STATE(9945)] = 430136,
  [SMALL_STATE(9946)] = 430181,
  [SMALL_STATE(9947)] = 430226,
  [SMALL_STATE(9948)] = 430271,
  [SMALL_STATE(9949)] = 430316,
  [SMALL_STATE(9950)] = 430361,
  [SMALL_STATE(9951)] = 430406,
  [SMALL_STATE(9952)] = 430451,
  [SMALL_STATE(9953)] = 430496,
  [SMALL_STATE(9954)] = 430541,
  [SMALL_STATE(9955)] = 430586,
  [SMALL_STATE(9956)] = 430631,
  [SMALL_STATE(9957)] = 430676,
  [SMALL_STATE(9958)] = 430721,
  [SMALL_STATE(9959)] = 430766,
  [SMALL_STATE(9960)] = 430811,
  [SMALL_STATE(9961)] = 430856,
  [SMALL_STATE(9962)] = 430901,
  [SMALL_STATE(9963)] = 430946,
  [SMALL_STATE(9964)] = 430991,
  [SMALL_STATE(9965)] = 431036,
  [SMALL_STATE(9966)] = 431081,
  [SMALL_STATE(9967)] = 431126,
  [SMALL_STATE(9968)] = 431171,
  [SMALL_STATE(9969)] = 431216,
  [SMALL_STATE(9970)] = 431261,
  [SMALL_STATE(9971)] = 431306,
  [SMALL_STATE(9972)] = 431351,
  [SMALL_STATE(9973)] = 431396,
  [SMALL_STATE(9974)] = 431441,
  [SMALL_STATE(9975)] = 431486,
  [SMALL_STATE(9976)] = 431531,
  [SMALL_STATE(9977)] = 431576,
  [SMALL_STATE(9978)] = 431621,
  [SMALL_STATE(9979)] = 431666,
  [SMALL_STATE(9980)] = 431711,
  [SMALL_STATE(9981)] = 431756,
  [SMALL_STATE(9982)] = 431801,
  [SMALL_STATE(9983)] = 431846,
  [SMALL_STATE(9984)] = 431891,
  [SMALL_STATE(9985)] = 431936,
  [SMALL_STATE(9986)] = 431940,
  [SMALL_STATE(9987)] = 431944,
  [SMALL_STATE(9988)] = 431948,
  [SMALL_STATE(9989)] = 431952,
  [SMALL_STATE(9990)] = 431956,
  [SMALL_STATE(9991)] = 431960,
  [SMALL_STATE(9992)] = 431964,
  [SMALL_STATE(9993)] = 431968,
  [SMALL_STATE(9994)] = 431972,
  [SMALL_STATE(9995)] = 431976,
  [SMALL_STATE(9996)] = 431980,
  [SMALL_STATE(9997)] = 431984,
  [SMALL_STATE(9998)] = 431988,
  [SMALL_STATE(9999)] = 431992,
  [SMALL_STATE(10000)] = 431996,
  [SMALL_STATE(10001)] = 432000,
};

static const TSParseActionEntry ts_parse_actions[] = {
  [0] = {.entry = {.count = 0, .reusable = false}},
  [1] = {.entry = {.count = 1, .reusable = false}}, RECOVER(),
  [3] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8740),
  [5] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8750),
  [7] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8293),
  [9] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8826),
  [11] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8524),
  [13] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9203),
  [15] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9312),
  [17] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9328),
  [19] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9084),
  [21] = {.entry = {.count = 1, .reusable = true}}, SHIFT_EXTRA(),
  [23] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compilation_unit, 0, 0, 0),
  [25] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2744),
  [27] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3995),
  [29] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2743),
  [31] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2464),
  [33] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2897),
  [35] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3110),
  [37] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3856),
  [39] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3988),
  [41] = {.entry = {.count = 1, .reusable = true}}, SHIFT(512),
  [43] = {.entry = {.count = 1, .reusable = true}}, SHIFT(524),
  [45] = {.entry = {.count = 1, .reusable = false}}, SHIFT(933),
  [47] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6897),
  [49] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7382),
  [51] = {.entry = {.count = 1, .reusable = false}}, SHIFT(728),
  [53] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7368),
  [55] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7381),
  [57] = {.entry = {.count = 1, .reusable = true}}, SHIFT(34),
  [59] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7373),
  [61] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4352),
  [63] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7253),
  [65] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3803),
  [67] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2654),
  [69] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3997),
  [71] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2919),
  [73] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8508),
  [75] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1256),
  [77] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4132),
  [79] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1256),
  [81] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1307),
  [83] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3049),
  [85] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2736),
  [87] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3765),
  [89] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2764),
  [91] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5453),
  [93] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9216),
  [95] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9257),
  [97] = {.entry = {.count = 1, .reusable = false}}, SHIFT(68),
  [99] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9154),
  [101] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9569),
  [103] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9762),
  [105] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2875),
  [107] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8721),
  [109] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4176),
  [111] = {.entry = {.count = 1, .reusable = false}}, SHIFT(940),
  [113] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8907),
  [115] = {.entry = {.count = 1, .reusable = false}}, SHIFT(369),
  [117] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9825),
  [119] = {.entry = {.count = 1, .reusable = false}}, SHIFT(663),
  [121] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9126),
  [123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(248),
  [125] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2450),
  [127] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5238),
  [129] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9432),
  [131] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9411),
  [133] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9093),
  [135] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9063),
  [137] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9415),
  [139] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4127),
  [141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8774),
  [143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4127),
  [145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7844),
  [147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6286),
  [149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13),
  [151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9771),
  [153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9782),
  [155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9742),
  [157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9217),
  [159] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4025),
  [161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2269),
  [163] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2827),
  [165] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3119),
  [167] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3855),
  [169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(513),
  [171] = {.entry = {.count = 1, .reusable = false}}, SHIFT(812),
  [173] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6833),
  [175] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7348),
  [177] = {.entry = {.count = 1, .reusable = false}}, SHIFT(727),
  [179] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7349),
  [181] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7350),
  [183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(31),
  [185] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7351),
  [187] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4362),
  [189] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7208),
  [191] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4027),
  [193] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8464),
  [195] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8999),
  [197] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9005),
  [199] = {.entry = {.count = 1, .reusable = false}}, SHIFT(180),
  [201] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9735),
  [203] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9946),
  [205] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9736),
  [207] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2811),
  [209] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8764),
  [211] = {.entry = {.count = 1, .reusable = false}}, SHIFT(993),
  [213] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8779),
  [215] = {.entry = {.count = 1, .reusable = false}}, SHIFT(367),
  [217] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9975),
  [219] = {.entry = {.count = 1, .reusable = false}}, SHIFT(688),
  [221] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9737),
  [223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6272),
  [225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2203),
  [227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20),
  [229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6171),
  [231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2205),
  [233] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_elif_in_top_level, 3, 0, 39),
  [235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2208),
  [237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6720),
  [239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2726),
  [241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19),
  [243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6207),
  [245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2287),
  [247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2474),
  [249] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_elif_in_top_level, 4, 0, 39),
  [251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8983),
  [253] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compilation_unit, 1, 0, 0),
  [255] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_top_level_repeat1, 2, 0, 0), SHIFT_REPEAT(2744),
  [258] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_top_level_repeat1, 2, 0, 0), SHIFT_REPEAT(4025),
  [261] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_top_level_repeat1, 2, 0, 0), SHIFT_REPEAT(2743),
  [264] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_if_in_top_level_repeat1, 2, 0, 0), SHIFT_REPEAT(2269),
  [267] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_top_level_repeat1, 2, 0, 0), SHIFT_REPEAT(2827),
  [270] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_top_level_repeat1, 2, 0, 0), SHIFT_REPEAT(3119),
  [273] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_top_level_repeat1, 2, 0, 0), SHIFT_REPEAT(3855),
  [276] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_top_level_repeat1, 2, 0, 0), SHIFT_REPEAT(3988),
  [279] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_if_in_top_level_repeat1, 2, 0, 0), SHIFT_REPEAT(513),
  [282] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_if_in_top_level_repeat1, 2, 0, 0), SHIFT_REPEAT(524),
  [285] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_top_level_repeat1, 2, 0, 0), SHIFT_REPEAT(812),
  [288] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_top_level_repeat1, 2, 0, 0), SHIFT_REPEAT(6833),
  [291] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_top_level_repeat1, 2, 0, 0), SHIFT_REPEAT(7348),
  [294] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_top_level_repeat1, 2, 0, 0), SHIFT_REPEAT(727),
  [297] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_top_level_repeat1, 2, 0, 0), SHIFT_REPEAT(7349),
  [300] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_top_level_repeat1, 2, 0, 0), SHIFT_REPEAT(7350),
  [303] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_if_in_top_level_repeat1, 2, 0, 0), SHIFT_REPEAT(31),
  [306] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_top_level_repeat1, 2, 0, 0), SHIFT_REPEAT(7351),
  [309] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_top_level_repeat1, 2, 0, 0), SHIFT_REPEAT(4362),
  [312] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_top_level_repeat1, 2, 0, 0), SHIFT_REPEAT(7208),
  [315] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_top_level_repeat1, 2, 0, 0), SHIFT_REPEAT(3803),
  [318] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_top_level_repeat1, 2, 0, 0), SHIFT_REPEAT(2654),
  [321] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_top_level_repeat1, 2, 0, 0), SHIFT_REPEAT(4027),
  [324] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_top_level_repeat1, 2, 0, 0), SHIFT_REPEAT(2919),
  [327] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_top_level_repeat1, 2, 0, 0), SHIFT_REPEAT(8464),
  [330] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_if_in_top_level_repeat1, 2, 0, 0), SHIFT_REPEAT(1256),
  [333] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_top_level_repeat1, 2, 0, 0), SHIFT_REPEAT(4132),
  [336] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_top_level_repeat1, 2, 0, 0), SHIFT_REPEAT(1256),
  [339] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_if_in_top_level_repeat1, 2, 0, 0), SHIFT_REPEAT(1307),
  [342] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_top_level_repeat1, 2, 0, 0), SHIFT_REPEAT(3049),
  [345] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_top_level_repeat1, 2, 0, 0), SHIFT_REPEAT(2736),
  [348] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_top_level_repeat1, 2, 0, 0), SHIFT_REPEAT(3765),
  [351] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_top_level_repeat1, 2, 0, 0), SHIFT_REPEAT(2764),
  [354] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_top_level_repeat1, 2, 0, 0), SHIFT_REPEAT(5453),
  [357] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_top_level_repeat1, 2, 0, 0), SHIFT_REPEAT(8999),
  [360] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_top_level_repeat1, 2, 0, 0), SHIFT_REPEAT(9005),
  [363] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_top_level_repeat1, 2, 0, 0), SHIFT_REPEAT(180),
  [366] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_top_level_repeat1, 2, 0, 0), SHIFT_REPEAT(9735),
  [369] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_top_level_repeat1, 2, 0, 0), SHIFT_REPEAT(9946),
  [372] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_top_level_repeat1, 2, 0, 0), SHIFT_REPEAT(9736),
  [375] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_top_level_repeat1, 2, 0, 0), SHIFT_REPEAT(2811),
  [378] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_top_level_repeat1, 2, 0, 0), SHIFT_REPEAT(8764),
  [381] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_top_level_repeat1, 2, 0, 0), SHIFT_REPEAT(4176),
  [384] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_top_level_repeat1, 2, 0, 0), SHIFT_REPEAT(993),
  [387] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_top_level_repeat1, 2, 0, 0), SHIFT_REPEAT(8779),
  [390] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_top_level_repeat1, 2, 0, 0), SHIFT_REPEAT(367),
  [393] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_top_level_repeat1, 2, 0, 0), SHIFT_REPEAT(9975),
  [396] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_top_level_repeat1, 2, 0, 0), SHIFT_REPEAT(688),
  [399] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_top_level_repeat1, 2, 0, 0), SHIFT_REPEAT(9737),
  [402] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_if_in_top_level_repeat1, 2, 0, 0), SHIFT_REPEAT(248),
  [405] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_top_level_repeat1, 2, 0, 0), SHIFT_REPEAT(2450),
  [408] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_top_level_repeat1, 2, 0, 0), SHIFT_REPEAT(5238),
  [411] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_top_level_repeat1, 2, 0, 0), SHIFT_REPEAT(9432),
  [414] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_top_level_repeat1, 2, 0, 0), SHIFT_REPEAT(9411),
  [417] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_top_level_repeat1, 2, 0, 0), SHIFT_REPEAT(9093),
  [420] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_top_level_repeat1, 2, 0, 0), SHIFT_REPEAT(9063),
  [423] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_top_level_repeat1, 2, 0, 0), SHIFT_REPEAT(9415),
  [426] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_top_level_repeat1, 2, 0, 0), SHIFT_REPEAT(4127),
  [429] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_if_in_top_level_repeat1, 2, 0, 0), SHIFT_REPEAT(8774),
  [432] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_if_in_top_level_repeat1, 2, 0, 0), SHIFT_REPEAT(4127),
  [435] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_if_in_top_level_repeat1, 2, 0, 0), SHIFT_REPEAT(7844),
  [438] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_if_in_top_level_repeat1, 2, 0, 0), SHIFT_REPEAT(6272),
  [441] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_if_in_top_level_repeat1, 2, 0, 0),
  [443] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_if_in_top_level_repeat1, 2, 0, 0), SHIFT_REPEAT(9771),
  [446] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_if_in_top_level_repeat1, 2, 0, 0), SHIFT_REPEAT(9782),
  [449] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_if_in_top_level_repeat1, 2, 0, 0), SHIFT_REPEAT(9742),
  [452] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_preproc_if_in_top_level_repeat1, 2, 0, 0), SHIFT_REPEAT(9217),
  [455] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_compilation_unit, 2, 0, 0),
  [457] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_compilation_unit_repeat1, 2, 0, 0),
  [459] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compilation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(2744),
  [462] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compilation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(3995),
  [465] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compilation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(2743),
  [468] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_compilation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(2464),
  [471] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compilation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(2897),
  [474] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compilation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(3110),
  [477] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compilation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(3856),
  [480] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compilation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(3988),
  [483] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_compilation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(512),
  [486] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_compilation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(524),
  [489] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compilation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(933),
  [492] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compilation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(6897),
  [495] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compilation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(7382),
  [498] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compilation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(728),
  [501] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compilation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(7368),
  [504] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compilation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(7381),
  [507] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_compilation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(34),
  [510] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compilation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(7373),
  [513] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compilation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(4352),
  [516] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compilation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(7253),
  [519] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compilation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(3803),
  [522] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compilation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(2654),
  [525] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compilation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(3997),
  [528] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compilation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(2919),
  [531] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compilation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(8508),
  [534] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_compilation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(1256),
  [537] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compilation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(4132),
  [540] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compilation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(1256),
  [543] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_compilation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(1307),
  [546] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compilation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(3049),
  [549] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compilation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(2736),
  [552] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compilation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(3765),
  [555] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compilation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(2764),
  [558] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compilation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(5453),
  [561] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compilation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(9216),
  [564] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compilation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(9257),
  [567] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compilation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(68),
  [570] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compilation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(9154),
  [573] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compilation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(9569),
  [576] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compilation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(9762),
  [579] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compilation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(2875),
  [582] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compilation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(8721),
  [585] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compilation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(4176),
  [588] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compilation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(940),
  [591] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compilation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(8907),
  [594] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compilation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(369),
  [597] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compilation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(9825),
  [600] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compilation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(663),
  [603] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compilation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(9126),
  [606] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_compilation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(248),
  [609] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compilation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(2450),
  [612] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compilation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(5238),
  [615] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compilation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(9432),
  [618] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compilation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(9411),
  [621] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compilation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(9093),
  [624] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compilation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(9063),
  [627] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compilation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(9415),
  [630] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_compilation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(4127),
  [633] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_compilation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(8774),
  [636] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_compilation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(4127),
  [639] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_compilation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(7844),
  [642] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_compilation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(6286),
  [645] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_compilation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(9771),
  [648] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_compilation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(9782),
  [651] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_compilation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(9742),
  [654] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_compilation_unit_repeat1, 2, 0, 0), SHIFT_REPEAT(9217),
  [657] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_else_in_top_level, 2, 0, 0),
  [659] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_else_in_top_level, 1, 0, 0),
  [661] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4594),
  [663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2658),
  [665] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3099),
  [667] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4370),
  [669] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4572),
  [671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(519),
  [673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9213),
  [675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(565),
  [677] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1109),
  [679] = {.entry = {.count = 1, .reusable = false}}, SHIFT(916),
  [681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(23),
  [683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5503),
  [685] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7991),
  [687] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2731),
  [689] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4603),
  [691] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3104),
  [693] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8605),
  [695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1386),
  [697] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1386),
  [699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1251),
  [701] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9497),
  [703] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9499),
  [705] = {.entry = {.count = 1, .reusable = false}}, SHIFT(181),
  [707] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9450),
  [709] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9904),
  [711] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9451),
  [713] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2828),
  [715] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8813),
  [717] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1131),
  [719] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8820),
  [721] = {.entry = {.count = 1, .reusable = false}}, SHIFT(366),
  [723] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9961),
  [725] = {.entry = {.count = 1, .reusable = false}}, SHIFT(685),
  [727] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9452),
  [729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(245),
  [731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6233),
  [733] = {.entry = {.count = 1, .reusable = false}}, SHIFT(880),
  [735] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_switch_section, 5, 0, 0),
  [737] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_switch_section, 5, 0, 0),
  [739] = {.entry = {.count = 1, .reusable = false}}, SHIFT(822),
  [741] = {.entry = {.count = 1, .reusable = false}}, SHIFT(365),
  [743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9859),
  [745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2207),
  [747] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_switch_section, 3, 0, 0),
  [749] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_switch_section, 3, 0, 0),
  [751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6737),
  [753] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(2744),
  [756] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(4594),
  [759] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(2743),
  [762] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(2658),
  [765] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(3099),
  [768] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(4370),
  [771] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(4572),
  [774] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(519),
  [777] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(524),
  [780] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(1109),
  [783] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(880),
  [786] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(23),
  [789] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0),
  [791] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(7991),
  [794] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(2731),
  [797] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(4603),
  [800] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(3104),
  [803] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(8605),
  [806] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(1256),
  [809] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(4132),
  [812] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(1256),
  [815] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(1307),
  [818] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(3049),
  [821] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(2736),
  [824] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(3765),
  [827] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(2764),
  [830] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(5453),
  [833] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(9497),
  [836] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(9499),
  [839] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(181),
  [842] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(9450),
  [845] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(9904),
  [848] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(9451),
  [851] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(2828),
  [854] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(8813),
  [857] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0),
  [859] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(4176),
  [862] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(822),
  [865] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(8820),
  [868] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(365),
  [871] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(9961),
  [874] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(685),
  [877] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(9452),
  [880] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(248),
  [883] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(2450),
  [886] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(5238),
  [889] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(9432),
  [892] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(9411),
  [895] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(9093),
  [898] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(9063),
  [901] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(9415),
  [904] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(4127),
  [907] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(8774),
  [910] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(4127),
  [913] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(7844),
  [916] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(6233),
  [919] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(9771),
  [922] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(9782),
  [925] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(9742),
  [928] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 2, 0, 0), SHIFT_REPEAT(9217),
  [931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3761),
  [933] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_switch_section, 4, 0, 0),
  [935] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_switch_section, 4, 0, 0),
  [937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2204),
  [939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9704),
  [941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4736),
  [943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9420),
  [945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3704),
  [947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2206),
  [949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9032),
  [951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4230),
  [953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9861),
  [955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4024),
  [957] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_switch_section, 2, 0, 0),
  [959] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_switch_section, 2, 0, 0),
  [961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2651),
  [963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3560),
  [965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2268),
  [967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3724),
  [969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4740),
  [971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2261),
  [973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5467),
  [975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3635),
  [977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3546),
  [979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2215),
  [981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5479),
  [983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2649),
  [985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4290),
  [987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4292),
  [989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4662),
  [991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3294),
  [993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3295),
  [995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2218),
  [997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3965),
  [999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3969),
  [1001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4358),
  [1003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4359),
  [1005] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3102),
  [1007] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4368),
  [1009] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4550),
  [1011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8780),
  [1013] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3114),
  [1015] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4390),
  [1017] = {.entry = {.count = 1, .reusable = false}}, SHIFT(909),
  [1019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(25),
  [1021] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4715),
  [1023] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8569),
  [1025] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9345),
  [1027] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9346),
  [1029] = {.entry = {.count = 1, .reusable = false}}, SHIFT(182),
  [1031] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9665),
  [1033] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9934),
  [1035] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9666),
  [1037] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2877),
  [1039] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8939),
  [1041] = {.entry = {.count = 1, .reusable = false}}, SHIFT(911),
  [1043] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8748),
  [1045] = {.entry = {.count = 1, .reusable = false}}, SHIFT(362),
  [1047] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9971),
  [1049] = {.entry = {.count = 1, .reusable = false}}, SHIFT(677),
  [1051] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9667),
  [1053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6267),
  [1055] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3118),
  [1057] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4415),
  [1059] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4729),
  [1061] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6923),
  [1063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(190),
  [1065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4083),
  [1067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(208),
  [1069] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9349),
  [1071] = {.entry = {.count = 1, .reusable = false}}, SHIFT(648),
  [1073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(322),
  [1075] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4394),
  [1077] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1276),
  [1079] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1122),
  [1081] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9515),
  [1083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1815),
  [1085] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1815),
  [1087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1276),
  [1089] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2737),
  [1091] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2763),
  [1093] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1275),
  [1095] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1282),
  [1097] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4157),
  [1099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(273),
  [1101] = {.entry = {.count = 1, .reusable = false}}, SHIFT(466),
  [1103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6291),
  [1105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(185),
  [1107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2962),
  [1109] = {.entry = {.count = 1, .reusable = false}}, SHIFT(610),
  [1111] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4421),
  [1113] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6823),
  [1115] = {.entry = {.count = 1, .reusable = false}}, SHIFT(611),
  [1117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1893),
  [1119] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1893),
  [1121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1689),
  [1123] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2791),
  [1125] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2735),
  [1127] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5266),
  [1129] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1690),
  [1131] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1691),
  [1133] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8269),
  [1135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(243),
  [1137] = {.entry = {.count = 1, .reusable = false}}, SHIFT(467),
  [1139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5772),
  [1141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(274),
  [1143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6826),
  [1145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5004),
  [1147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(267),
  [1149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4724),
  [1151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(272),
  [1153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4147),
  [1155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(256),
  [1157] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_range_expression, 1, 0, 0),
  [1159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(514),
  [1161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(545),
  [1163] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1028),
  [1165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(680),
  [1167] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8236),
  [1169] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4375),
  [1171] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_range_expression, 1, 0, 0),
  [1173] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9815),
  [1175] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1928),
  [1177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1928),
  [1179] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3996),
  [1181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1927),
  [1183] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3194),
  [1185] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4018),
  [1187] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6930),
  [1189] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4056),
  [1191] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1232),
  [1193] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1233),
  [1195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(191),
  [1197] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5223),
  [1199] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9784),
  [1201] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9785),
  [1203] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9812),
  [1205] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9813),
  [1207] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9980),
  [1209] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4062),
  [1211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8761),
  [1213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4062),
  [1215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7944),
  [1217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6288),
  [1219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9748),
  [1221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9750),
  [1223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9751),
  [1225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9753),
  [1227] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_range_expression, 2, 0, 0),
  [1229] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_range_expression, 2, 0, 0),
  [1231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(212),
  [1233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2987),
  [1235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3196),
  [1237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3542),
  [1239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(515),
  [1241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(527),
  [1243] = {.entry = {.count = 1, .reusable = false}}, SHIFT(971),
  [1245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(678),
  [1247] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8130),
  [1249] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4382),
  [1251] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9675),
  [1253] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1760),
  [1255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1760),
  [1257] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3653),
  [1259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1614),
  [1261] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3020),
  [1263] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3717),
  [1265] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6953),
  [1267] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3722),
  [1269] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1176),
  [1271] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1177),
  [1273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(223),
  [1275] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5171),
  [1277] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9454),
  [1279] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9455),
  [1281] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9670),
  [1283] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9671),
  [1285] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9972),
  [1287] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3727),
  [1289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8945),
  [1291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3727),
  [1293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7895),
  [1295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6268),
  [1297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9376),
  [1299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9377),
  [1301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9380),
  [1303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9381),
  [1305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(187),
  [1307] = {.entry = {.count = 1, .reusable = false}}, SHIFT(631),
  [1309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1958),
  [1311] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2769),
  [1313] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1543),
  [1315] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1544),
  [1317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(307),
  [1319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3534),
  [1321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(520),
  [1323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(533),
  [1325] = {.entry = {.count = 1, .reusable = false}}, SHIFT(896),
  [1327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(669),
  [1329] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8039),
  [1331] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4428),
  [1333] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9790),
  [1335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1816),
  [1337] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3480),
  [1339] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4170),
  [1341] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1350),
  [1343] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1351),
  [1345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(227),
  [1347] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5166),
  [1349] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9786),
  [1351] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9787),
  [1353] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9979),
  [1355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6280),
  [1357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(551),
  [1359] = {.entry = {.count = 1, .reusable = false}}, SHIFT(765),
  [1361] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1932),
  [1363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1932),
  [1365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1933),
  [1367] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1446),
  [1369] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1447),
  [1371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(228),
  [1373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(529),
  [1375] = {.entry = {.count = 1, .reusable = false}}, SHIFT(813),
  [1377] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1463),
  [1379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1463),
  [1381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1761),
  [1383] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1215),
  [1385] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1216),
  [1387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(230),
  [1389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(536),
  [1391] = {.entry = {.count = 1, .reusable = false}}, SHIFT(990),
  [1393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1899),
  [1395] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1521),
  [1397] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1522),
  [1399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(232),
  [1401] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2804),
  [1403] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2803),
  [1405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(518),
  [1407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(549),
  [1409] = {.entry = {.count = 1, .reusable = false}}, SHIFT(967),
  [1411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(656),
  [1413] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8069),
  [1415] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4401),
  [1417] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9745),
  [1419] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2148),
  [1421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2148),
  [1423] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5674),
  [1425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1852),
  [1427] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3922),
  [1429] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2751),
  [1431] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5529),
  [1433] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2824),
  [1435] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6944),
  [1437] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5530),
  [1439] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2031),
  [1441] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2032),
  [1443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(234),
  [1445] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2733),
  [1447] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5187),
  [1449] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9738),
  [1451] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9739),
  [1453] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9740),
  [1455] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9741),
  [1457] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9976),
  [1459] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5531),
  [1461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8967),
  [1463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5531),
  [1465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7857),
  [1467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6273),
  [1469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9419),
  [1471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9421),
  [1473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9423),
  [1475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9425),
  [1477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(560),
  [1479] = {.entry = {.count = 1, .reusable = false}}, SHIFT(986),
  [1481] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4459),
  [1483] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2152),
  [1485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2152),
  [1487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1292),
  [1489] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2069),
  [1491] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2070),
  [1493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(236),
  [1495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(516),
  [1497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(567),
  [1499] = {.entry = {.count = 1, .reusable = false}}, SHIFT(808),
  [1501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(668),
  [1503] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4449),
  [1505] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1252),
  [1507] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1253),
  [1509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(238),
  [1511] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1250),
  [1513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1250),
  [1515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(534),
  [1517] = {.entry = {.count = 1, .reusable = false}}, SHIFT(827),
  [1519] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1906),
  [1521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1906),
  [1523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1855),
  [1525] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1311),
  [1527] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1312),
  [1529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(240),
  [1531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(573),
  [1533] = {.entry = {.count = 1, .reusable = false}}, SHIFT(762),
  [1535] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1910),
  [1537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1910),
  [1539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(544),
  [1541] = {.entry = {.count = 1, .reusable = false}}, SHIFT(757),
  [1543] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1902),
  [1545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1902),
  [1547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1923),
  [1549] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1668),
  [1551] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1669),
  [1553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(260),
  [1555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(568),
  [1557] = {.entry = {.count = 1, .reusable = false}}, SHIFT(970),
  [1559] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1466),
  [1561] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1467),
  [1563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(247),
  [1565] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1957),
  [1567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1957),
  [1569] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1388),
  [1571] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1389),
  [1573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(535),
  [1575] = {.entry = {.count = 1, .reusable = false}}, SHIFT(764),
  [1577] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4396),
  [1579] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1854),
  [1581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1854),
  [1583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1894),
  [1585] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1442),
  [1587] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1443),
  [1589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(249),
  [1591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(555),
  [1593] = {.entry = {.count = 1, .reusable = false}}, SHIFT(991),
  [1595] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4387),
  [1597] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1946),
  [1599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1946),
  [1601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1939),
  [1603] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1525),
  [1605] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1526),
  [1607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(252),
  [1609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(541),
  [1611] = {.entry = {.count = 1, .reusable = false}}, SHIFT(862),
  [1613] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1291),
  [1615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1291),
  [1617] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1332),
  [1619] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1333),
  [1621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(254),
  [1623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(542),
  [1625] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1076),
  [1627] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1898),
  [1629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1898),
  [1631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1921),
  [1633] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1593),
  [1635] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1594),
  [1637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(257),
  [1639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(528),
  [1641] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1111),
  [1643] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1851),
  [1645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1851),
  [1647] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1198),
  [1649] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1199),
  [1651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(259),
  [1653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(564),
  [1655] = {.entry = {.count = 1, .reusable = false}}, SHIFT(845),
  [1657] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1956),
  [1659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1956),
  [1661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1955),
  [1663] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1799),
  [1665] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1800),
  [1667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(263),
  [1669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(561),
  [1671] = {.entry = {.count = 1, .reusable = false}}, SHIFT(895),
  [1673] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1948),
  [1675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1948),
  [1677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1949),
  [1679] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1887),
  [1681] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1888),
  [1683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(265),
  [1685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(517),
  [1687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(547),
  [1689] = {.entry = {.count = 1, .reusable = false}}, SHIFT(951),
  [1691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(690),
  [1693] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8195),
  [1695] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4379),
  [1697] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9466),
  [1699] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2093),
  [1701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2093),
  [1703] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4730),
  [1705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1464),
  [1707] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3579),
  [1709] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4616),
  [1711] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6940),
  [1713] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4620),
  [1715] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1998),
  [1717] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1999),
  [1719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(276),
  [1721] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5175),
  [1723] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9668),
  [1725] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9669),
  [1727] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9456),
  [1729] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9457),
  [1731] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9962),
  [1733] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4626),
  [1735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8765),
  [1737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4626),
  [1739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7864),
  [1741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6234),
  [1743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9384),
  [1745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9389),
  [1747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9392),
  [1749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9400),
  [1751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(543),
  [1753] = {.entry = {.count = 1, .reusable = false}}, SHIFT(968),
  [1755] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4374),
  [1757] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2088),
  [1759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2088),
  [1761] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2036),
  [1763] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2037),
  [1765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(269),
  [1767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(558),
  [1769] = {.entry = {.count = 1, .reusable = false}}, SHIFT(978),
  [1771] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4440),
  [1773] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2094),
  [1775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2094),
  [1777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1915),
  [1779] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2053),
  [1781] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2054),
  [1783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(277),
  [1785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(550),
  [1787] = {.entry = {.count = 1, .reusable = false}}, SHIFT(905),
  [1789] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1934),
  [1791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1934),
  [1793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1931),
  [1795] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1369),
  [1797] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1370),
  [1799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(275),
  [1801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(548),
  [1803] = {.entry = {.count = 1, .reusable = false}}, SHIFT(805),
  [1805] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4385),
  [1807] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1924),
  [1809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1924),
  [1811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1929),
  [1813] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1740),
  [1815] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1741),
  [1817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(281),
  [1819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(562),
  [1821] = {.entry = {.count = 1, .reusable = false}}, SHIFT(758),
  [1823] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4453),
  [1825] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1952),
  [1827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1952),
  [1829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1951),
  [1831] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1672),
  [1833] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1673),
  [1835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(293),
  [1837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(563),
  [1839] = {.entry = {.count = 1, .reusable = false}}, SHIFT(806),
  [1841] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4454),
  [1843] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1954),
  [1845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1954),
  [1847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1953),
  [1849] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1744),
  [1851] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1745),
  [1853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(282),
  [1855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(556),
  [1857] = {.entry = {.count = 1, .reusable = false}}, SHIFT(844),
  [1859] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4400),
  [1861] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1936),
  [1863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1936),
  [1865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1943),
  [1867] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1795),
  [1869] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1796),
  [1871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(284),
  [1873] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_list_pattern_repeat1, 2, 0, 0),
  [1875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(557),
  [1877] = {.entry = {.count = 1, .reusable = false}}, SHIFT(870),
  [1879] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4427),
  [1881] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1940),
  [1883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1940),
  [1885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1945),
  [1887] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1848),
  [1889] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1849),
  [1891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(287),
  [1893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(546),
  [1895] = {.entry = {.count = 1, .reusable = false}}, SHIFT(950),
  [1897] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4439),
  [1899] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2092),
  [1901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2092),
  [1903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1387),
  [1905] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1976),
  [1907] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1977),
  [1909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(292),
  [1911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(559),
  [1913] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1077),
  [1915] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4444),
  [1917] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1944),
  [1919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1944),
  [1921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1947),
  [1923] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1597),
  [1925] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1598),
  [1927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(290),
  [1929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(566),
  [1931] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1108),
  [1933] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4372),
  [1935] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2171),
  [1937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2171),
  [1939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1903),
  [1941] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2155),
  [1943] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2156),
  [1945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(295),
  [1947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9242),
  [1949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(201),
  [1951] = {.entry = {.count = 1, .reusable = false}}, SHIFT(798),
  [1953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5579),
  [1955] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1407),
  [1957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1407),
  [1959] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2783),
  [1961] = {.entry = {.count = 1, .reusable = false}}, SHIFT(465),
  [1963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(521),
  [1965] = {.entry = {.count = 1, .reusable = false}}, SHIFT(789),
  [1967] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1950),
  [1969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1950),
  [1971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1941),
  [1973] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1723),
  [1975] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1724),
  [1977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(297),
  [1979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(576),
  [1981] = {.entry = {.count = 1, .reusable = false}}, SHIFT(731),
  [1983] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1930),
  [1985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1930),
  [1987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1925),
  [1989] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1856),
  [1991] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1857),
  [1993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(302),
  [1995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(539),
  [1997] = {.entry = {.count = 1, .reusable = false}}, SHIFT(807),
  [1999] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1922),
  [2001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1922),
  [2003] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1305),
  [2005] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1306),
  [2007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(318),
  [2009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(569),
  [2011] = {.entry = {.count = 1, .reusable = false}}, SHIFT(997),
  [2013] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2109),
  [2015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2109),
  [2017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9277),
  [2019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4134),
  [2021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9804),
  [2023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3730),
  [2025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2293),
  [2027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(523),
  [2029] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_default_expression, 1, 0, 0),
  [2031] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_default_expression, 1, 0, 0),
  [2033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8898),
  [2035] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_default_expression, 4, 0, 16),
  [2037] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_default_expression, 4, 0, 16),
  [2039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9298),
  [2041] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1045),
  [2043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3024),
  [2045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9060),
  [2047] = {.entry = {.count = 1, .reusable = false}}, SHIFT(885),
  [2049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3004),
  [2051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9208),
  [2053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4058),
  [2055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(526),
  [2057] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1095),
  [2059] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2095),
  [2061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2095),
  [2063] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2085),
  [2065] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2086),
  [2067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(312),
  [2069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2502),
  [2071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9162),
  [2073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3794),
  [2075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9300),
  [2077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3530),
  [2079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2730),
  [2081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9851),
  [2083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3533),
  [2085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9391),
  [2087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4712),
  [2089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(577),
  [2091] = {.entry = {.count = 1, .reusable = false}}, SHIFT(907),
  [2093] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1613),
  [2095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1613),
  [2097] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1157),
  [2099] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1158),
  [2101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(321),
  [2103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9405),
  [2105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3142),
  [2107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9822),
  [2109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3551),
  [2111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(525),
  [2113] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1040),
  [2115] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1541),
  [2117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1541),
  [2119] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1892),
  [2121] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1895),
  [2123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(353),
  [2125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5651),
  [2127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(540),
  [2129] = {.entry = {.count = 1, .reusable = false}}, SHIFT(897),
  [2131] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4451),
  [2133] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1926),
  [2135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1926),
  [2137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1919),
  [2139] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1504),
  [2141] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1505),
  [2143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(327),
  [2145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2996),
  [2147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4106),
  [2149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4112),
  [2151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(553),
  [2153] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1056),
  [2155] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4388),
  [2157] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1938),
  [2159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1938),
  [2161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1935),
  [2163] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1576),
  [2165] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1577),
  [2167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(332),
  [2169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(574),
  [2171] = {.entry = {.count = 1, .reusable = false}}, SHIFT(810),
  [2173] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4404),
  [2175] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1918),
  [2177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1918),
  [2179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1907),
  [2181] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1762),
  [2183] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1763),
  [2185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(334),
  [2187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3014),
  [2189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(570),
  [2191] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1083),
  [2193] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4383),
  [2195] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1688),
  [2197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1688),
  [2199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1542),
  [2201] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1616),
  [2203] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1617),
  [2205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(354),
  [2207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3531),
  [2209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4046),
  [2211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4066),
  [2213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(554),
  [2215] = {.entry = {.count = 1, .reusable = false}}, SHIFT(738),
  [2217] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4393),
  [2219] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1942),
  [2221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1942),
  [2223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1937),
  [2225] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1650),
  [2227] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1651),
  [2229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(340),
  [2231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(575),
  [2233] = {.entry = {.count = 1, .reusable = false}}, SHIFT(848),
  [2235] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4429),
  [2237] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1920),
  [2239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1920),
  [2241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1911),
  [2243] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1817),
  [2245] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1818),
  [2247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(342),
  [2249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4655),
  [2251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3529),
  [2253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3703),
  [2255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3719),
  [2257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3781),
  [2259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(538),
  [2261] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1148),
  [2263] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1914),
  [2265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1914),
  [2267] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1423),
  [2269] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1424),
  [2271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(350),
  [2273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4607),
  [2275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3792),
  [2277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5632),
  [2279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5012),
  [2281] = {.entry = {.count = 1, .reusable = false}}, SHIFT(778),
  [2283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(286),
  [2285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3993),
  [2287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5435),
  [2289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5438),
  [2291] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3116),
  [2293] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3112),
  [2295] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9974),
  [2297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4630),
  [2299] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3098),
  [2301] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9966),
  [2303] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3109),
  [2305] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9978),
  [2307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5020),
  [2309] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3107),
  [2311] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9416),
  [2313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4582),
  [2315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4333),
  [2317] = {.entry = {.count = 1, .reusable = false}}, SHIFT(904),
  [2319] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2741),
  [2321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4117),
  [2323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3982),
  [2325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(194),
  [2327] = {.entry = {.count = 1, .reusable = false}}, SHIFT(898),
  [2329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(309),
  [2331] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1967),
  [2333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1967),
  [2335] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2734),
  [2337] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2777),
  [2339] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2963),
  [2341] = {.entry = {.count = 1, .reusable = false}}, SHIFT(403),
  [2343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(218),
  [2345] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1778),
  [2347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1778),
  [2349] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2742),
  [2351] = {.entry = {.count = 1, .reusable = false}}, SHIFT(446),
  [2353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(186),
  [2355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(202),
  [2357] = {.entry = {.count = 1, .reusable = false}}, SHIFT(999),
  [2359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(316),
  [2361] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8245),
  [2363] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1347),
  [2365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1347),
  [2367] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2740),
  [2369] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2768),
  [2371] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3323),
  [2373] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5744),
  [2375] = {.entry = {.count = 1, .reusable = false}}, SHIFT(378),
  [2377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(184),
  [2379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(197),
  [2381] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1191),
  [2383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1191),
  [2385] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2738),
  [2387] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2988),
  [2389] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4086),
  [2391] = {.entry = {.count = 1, .reusable = false}}, SHIFT(430),
  [2393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(211),
  [2395] = {.entry = {.count = 1, .reusable = false}}, SHIFT(505),
  [2397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(215),
  [2399] = {.entry = {.count = 1, .reusable = false}}, SHIFT(900),
  [2401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(324),
  [2403] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1484),
  [2405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1484),
  [2407] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2752),
  [2409] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2778),
  [2411] = {.entry = {.count = 1, .reusable = false}}, SHIFT(506),
  [2413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(189),
  [2415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(200),
  [2417] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1309),
  [2419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1309),
  [2421] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2773),
  [2423] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3539),
  [2425] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4557),
  [2427] = {.entry = {.count = 1, .reusable = false}}, SHIFT(490),
  [2429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(210),
  [2431] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1172),
  [2433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1172),
  [2435] = {.entry = {.count = 1, .reusable = false}}, SHIFT(412),
  [2437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(216),
  [2439] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1633),
  [2441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1633),
  [2443] = {.entry = {.count = 1, .reusable = false}}, SHIFT(401),
  [2445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(206),
  [2447] = {.entry = {.count = 1, .reusable = false}}, SHIFT(752),
  [2449] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1726),
  [2451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1726),
  [2453] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2739),
  [2455] = {.entry = {.count = 1, .reusable = false}}, SHIFT(387),
  [2457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(205),
  [2459] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1197),
  [2461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1197),
  [2463] = {.entry = {.count = 1, .reusable = false}}, SHIFT(409),
  [2465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(203),
  [2467] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1101),
  [2469] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1507),
  [2471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1507),
  [2473] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2794),
  [2475] = {.entry = {.count = 1, .reusable = false}}, SHIFT(461),
  [2477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(188),
  [2479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(196),
  [2481] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2104),
  [2483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2104),
  [2485] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2786),
  [2487] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3544),
  [2489] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5032),
  [2491] = {.entry = {.count = 1, .reusable = false}}, SHIFT(392),
  [2493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(213),
  [2495] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1872),
  [2497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1872),
  [2499] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2788),
  [2501] = {.entry = {.count = 1, .reusable = false}}, SHIFT(393),
  [2503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(217),
  [2505] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1707),
  [2507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1707),
  [2509] = {.entry = {.count = 1, .reusable = false}}, SHIFT(477),
  [2511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(219),
  [2513] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1833),
  [2515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1833),
  [2517] = {.entry = {.count = 1, .reusable = false}}, SHIFT(396),
  [2519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(207),
  [2521] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1794),
  [2523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1794),
  [2525] = {.entry = {.count = 1, .reusable = false}}, SHIFT(459),
  [2527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(220),
  [2529] = {.entry = {.count = 1, .reusable = false}}, SHIFT(413),
  [2531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(195),
  [2533] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1326),
  [2535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1326),
  [2537] = {.entry = {.count = 1, .reusable = false}}, SHIFT(420),
  [2539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(198),
  [2541] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1230),
  [2543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1230),
  [2545] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2784),
  [2547] = {.entry = {.count = 1, .reusable = false}}, SHIFT(451),
  [2549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(193),
  [2551] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1427),
  [2553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1427),
  [2555] = {.entry = {.count = 1, .reusable = false}}, SHIFT(475),
  [2557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(204),
  [2559] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1579),
  [2561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1579),
  [2563] = {.entry = {.count = 1, .reusable = false}}, SHIFT(424),
  [2565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(199),
  [2567] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1213),
  [2569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1213),
  [2571] = {.entry = {.count = 1, .reusable = false}}, SHIFT(435),
  [2573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(221),
  [2575] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1654),
  [2577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1654),
  [2579] = {.entry = {.count = 1, .reusable = false}}, SHIFT(476),
  [2581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(209),
  [2583] = {.entry = {.count = 1, .reusable = false}}, SHIFT(442),
  [2585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(214),
  [2587] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1559),
  [2589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1559),
  [2591] = {.entry = {.count = 1, .reusable = false}}, SHIFT(503),
  [2593] = {.entry = {.count = 1, .reusable = false}}, SHIFT(860),
  [2595] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1141),
  [2597] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9074),
  [2599] = {.entry = {.count = 1, .reusable = false}}, SHIFT(686),
  [2601] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9464),
  [2603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8062),
  [2605] = {.entry = {.count = 1, .reusable = false}}, SHIFT(612),
  [2607] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2787),
  [2609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4523),
  [2611] = {.entry = {.count = 1, .reusable = false}}, SHIFT(695),
  [2613] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2880),
  [2615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3595),
  [2617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3951),
  [2619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3942),
  [2621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5338),
  [2623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3033),
  [2625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3022),
  [2627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3656),
  [2629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1010),
  [2631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6194),
  [2633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3046),
  [2635] = {.entry = {.count = 1, .reusable = false}}, SHIFT(687),
  [2637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2990),
  [2639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3237),
  [2641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3556),
  [2643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4291),
  [2645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3244),
  [2647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4722),
  [2649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3558),
  [2651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3205),
  [2653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4034),
  [2655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3213),
  [2657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3948),
  [2659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3785),
  [2661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5584),
  [2663] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_elif_in_expression, 3, 0, 39),
  [2665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3884),
  [2667] = {.entry = {.count = 1, .reusable = false}}, SHIFT(826),
  [2669] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__parameter_type_with_modifiers_repeat1, 1, 0, 1),
  [2671] = {.entry = {.count = 1, .reusable = false}}, SHIFT(746),
  [2673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9500),
  [2675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5549),
  [2677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(652),
  [2679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3655),
  [2681] = {.entry = {.count = 1, .reusable = false}}, SHIFT(671),
  [2683] = {.entry = {.count = 1, .reusable = false}}, SHIFT(874),
  [2685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9052),
  [2687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4592),
  [2689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3229),
  [2691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3587),
  [2693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3933),
  [2695] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__parameter_type_with_modifiers_repeat1, 1, 0, 1),
  [2697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9151),
  [2699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3767),
  [2701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5335),
  [2703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9178),
  [2705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4324),
  [2707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9576),
  [2709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3683),
  [2711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2952),
  [2713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9034),
  [2715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4084),
  [2717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4045),
  [2719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5334),
  [2721] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7205),
  [2723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4033),
  [2725] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1041),
  [2727] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2775),
  [2729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3696),
  [2731] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7251),
  [2733] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7267),
  [2735] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7257),
  [2737] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1094),
  [2739] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4843),
  [2741] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7237),
  [2743] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_array_rank_specifier_repeat1, 1, 0, 0),
  [2745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5545),
  [2747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5587),
  [2749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5623),
  [2751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2463),
  [2753] = {.entry = {.count = 1, .reusable = false}}, SHIFT(917),
  [2755] = {.entry = {.count = 1, .reusable = false}}, SHIFT(314),
  [2757] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7204),
  [2759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4309),
  [2761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4103),
  [2763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3776),
  [2765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4300),
  [2767] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4895),
  [2769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8760),
  [2771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1043),
  [2773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3788),
  [2775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4733),
  [2777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8865),
  [2779] = {.entry = {.count = 1, .reusable = false}}, SHIFT(922),
  [2781] = {.entry = {.count = 1, .reusable = false}}, SHIFT(305),
  [2783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3633),
  [2785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4089),
  [2787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4713),
  [2789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2671),
  [2791] = {.entry = {.count = 1, .reusable = false}}, SHIFT(931),
  [2793] = {.entry = {.count = 1, .reusable = false}}, SHIFT(317),
  [2795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2279),
  [2797] = {.entry = {.count = 1, .reusable = false}}, SHIFT(996),
  [2799] = {.entry = {.count = 1, .reusable = false}}, SHIFT(304),
  [2801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4578),
  [2803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3777),
  [2805] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7189),
  [2807] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7167),
  [2809] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7203),
  [2811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(925),
  [2813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1004),
  [2815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3970),
  [2817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1020),
  [2819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3662),
  [2821] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7353),
  [2823] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7361),
  [2825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(33),
  [2827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(81),
  [2829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(133),
  [2831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(35),
  [2833] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4858),
  [2835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(36),
  [2837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(28),
  [2839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(571),
  [2841] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4753),
  [2843] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2754),
  [2845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(134),
  [2847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(32),
  [2849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(141),
  [2851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(159),
  [2853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(160),
  [2855] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2849),
  [2857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21),
  [2859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2272),
  [2861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2670),
  [2863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3793),
  [2865] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4864),
  [2867] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4929),
  [2869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(169),
  [2871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(60),
  [2873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1097),
  [2875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8909),
  [2877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8976),
  [2879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1064),
  [2881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1114),
  [2883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1140),
  [2885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2454),
  [2887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2460),
  [2889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3642),
  [2891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2277),
  [2893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3657),
  [2895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(522),
  [2897] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4817),
  [2899] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2799),
  [2901] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3476),
  [2903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(93),
  [2905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1001),
  [2907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1030),
  [2909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1084),
  [2911] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_else_in_expression, 1, 0, 0),
  [2913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4096),
  [2915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1096),
  [2917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5566),
  [2919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1126),
  [2921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(753),
  [2923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4672),
  [2925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(96),
  [2927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(97),
  [2929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4303),
  [2931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(150),
  [2933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3774),
  [2935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(903),
  [2937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4726),
  [2939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(63),
  [2941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5585),
  [2943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(103),
  [2945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(104),
  [2947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(111),
  [2949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(123),
  [2951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(151),
  [2953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(774),
  [2955] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2845),
  [2957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2664),
  [2959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(66),
  [2961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(67),
  [2963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4006),
  [2965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(126),
  [2967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(127),
  [2969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4073),
  [2971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(73),
  [2973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(74),
  [2975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(532),
  [2977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(572),
  [2979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(530),
  [2981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(531),
  [2983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(537),
  [2985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(552),
  [2987] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_if_in_top_level, 4, 0, 39),
  [2989] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_if_in_top_level, 4, 0, 39),
  [2991] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_if_in_expression, 4, 0, 39),
  [2993] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_if_in_expression, 4, 0, 39),
  [2995] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_block, 2, 0, 0),
  [2997] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block, 2, 0, 0),
  [2999] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_initializer_expression, 2, 0, 0),
  [3001] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_initializer_expression, 2, 0, 0),
  [3003] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_try_statement, 2, 0, 7),
  [3005] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_try_statement, 2, 0, 7),
  [3007] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7916),
  [3009] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8825),
  [3011] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_try_statement, 3, 0, 7),
  [3013] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_try_statement, 3, 0, 7),
  [3015] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_try_statement_repeat1, 2, 0, 0),
  [3017] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_try_statement_repeat1, 2, 0, 0),
  [3019] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_try_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7916),
  [3022] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7884),
  [3024] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8762),
  [3026] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_catch_clause, 3, 0, 57),
  [3028] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_catch_clause, 3, 0, 57),
  [3030] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_catch_clause, 4, 0, 79),
  [3032] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_catch_clause, 4, 0, 79),
  [3034] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_try_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7884),
  [3037] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_block, 3, 0, 0),
  [3039] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block, 3, 0, 0),
  [3041] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_catch_clause, 2, 0, 7),
  [3043] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_catch_clause, 2, 0, 7),
  [3045] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_try_statement_repeat1, 1, 0, 0),
  [3047] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_try_statement_repeat1, 1, 0, 0),
  [3049] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_body, 2, 0, 41),
  [3051] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_body, 2, 0, 41),
  [3053] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_local_function_statement, 5, 0, 68),
  [3055] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_local_function_statement, 5, 0, 68),
  [3057] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 6, 0, 78),
  [3059] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 6, 0, 78),
  [3061] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_using_statement, 6, 0, 78),
  [3063] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_using_statement, 6, 0, 78),
  [3065] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_if_in_top_level, 6, 0, 81),
  [3067] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_if_in_top_level, 6, 0, 81),
  [3069] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_local_function_statement, 6, 0, 82),
  [3071] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_local_function_statement, 6, 0, 82),
  [3073] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_local_function_statement, 6, 0, 88),
  [3075] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_local_function_statement, 6, 0, 88),
  [3077] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_local_function_statement, 6, 0, 89),
  [3079] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_local_function_statement, 6, 0, 89),
  [3081] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_local_function_statement, 6, 0, 90),
  [3083] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_local_function_statement, 6, 0, 90),
  [3085] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_do_statement, 7, 0, 104),
  [3087] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_do_statement, 7, 0, 104),
  [3089] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 7, 0, 105),
  [3091] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 7, 0, 105),
  [3093] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_local_function_statement, 4, 0, 42),
  [3095] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_local_function_statement, 4, 0, 42),
  [3097] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 7, 0, 107),
  [3099] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 7, 0, 107),
  [3101] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_foreach_statement, 7, 0, 108),
  [3103] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_foreach_statement, 7, 0, 108),
  [3105] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 7, 0, 109),
  [3107] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 7, 0, 109),
  [3109] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_local_function_statement, 7, 0, 114),
  [3111] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_local_function_statement, 7, 0, 114),
  [3113] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_local_function_statement, 7, 0, 119),
  [3115] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_local_function_statement, 7, 0, 119),
  [3117] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_local_function_statement, 7, 0, 120),
  [3119] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_local_function_statement, 7, 0, 120),
  [3121] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 8, 0, 140),
  [3123] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 8, 0, 140),
  [3125] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 8, 0, 141),
  [3127] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 8, 0, 141),
  [3129] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 8, 0, 142),
  [3131] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 8, 0, 142),
  [3133] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 8, 0, 143),
  [3135] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 8, 0, 143),
  [3137] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 8, 0, 144),
  [3139] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 8, 0, 144),
  [3141] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_foreach_statement, 8, 0, 145),
  [3143] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_foreach_statement, 8, 0, 145),
  [3145] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_foreach_statement, 8, 0, 146),
  [3147] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_foreach_statement, 8, 0, 146),
  [3149] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_local_function_statement, 8, 0, 152),
  [3151] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_local_function_statement, 8, 0, 152),
  [3153] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 9, 0, 178),
  [3155] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 9, 0, 178),
  [3157] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 9, 0, 179),
  [3159] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 9, 0, 179),
  [3161] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 9, 0, 180),
  [3163] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 9, 0, 180),
  [3165] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 9, 0, 181),
  [3167] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 9, 0, 181),
  [3169] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 9, 0, 182),
  [3171] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 9, 0, 182),
  [3173] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_foreach_statement, 9, 0, 183),
  [3175] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_foreach_statement, 9, 0, 183),
  [3177] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 10, 0, 207),
  [3179] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 10, 0, 207),
  [3181] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 10, 0, 208),
  [3183] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 10, 0, 208),
  [3185] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 10, 0, 209),
  [3187] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 10, 0, 209),
  [3189] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 11, 0, 222),
  [3191] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 11, 0, 222),
  [3193] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4513),
  [3195] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3798),
  [3197] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4529),
  [3199] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6775),
  [3201] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6804),
  [3203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5434),
  [3205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4604),
  [3207] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4583),
  [3209] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6904),
  [3211] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7312),
  [3213] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4520),
  [3215] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7329),
  [3217] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7338),
  [3219] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7301),
  [3221] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4647),
  [3223] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7275),
  [3225] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3321),
  [3227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7372),
  [3229] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6797),
  [3231] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4615),
  [3233] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4765),
  [3235] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5295),
  [3237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6228),
  [3239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3304),
  [3241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2646),
  [3243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6137),
  [3245] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_fixed_statement, 5, 0, 0),
  [3247] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_fixed_statement, 5, 0, 0),
  [3249] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_while_statement, 5, 0, 55),
  [3251] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_while_statement, 5, 0, 55),
  [3253] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lock_statement, 5, 0, 0),
  [3255] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lock_statement, 5, 0, 0),
  [3257] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_elif, 3, 0, 39),
  [3259] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_elif, 4, 0, 39),
  [3261] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_switch_statement, 5, 0, 56),
  [3263] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_switch_statement, 5, 0, 56),
  [3265] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_switch_body, 3, 0, 0),
  [3267] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_switch_body, 3, 0, 0),
  [3269] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_using_statement, 5, 0, 48),
  [3271] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_using_statement, 5, 0, 48),
  [3273] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_empty_statement, 1, 0, 0),
  [3275] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_empty_statement, 1, 0, 0),
  [3277] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_statement, 1, 0, 0),
  [3279] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_statement, 1, 0, 0),
  [3281] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_unsafe_statement, 2, 0, 0),
  [3283] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_unsafe_statement, 2, 0, 0),
  [3285] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_return_statement, 2, 0, 0),
  [3287] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_return_statement, 2, 0, 0),
  [3289] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_checked_statement, 2, 0, 0),
  [3291] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_checked_statement, 2, 0, 0),
  [3293] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_break_statement, 2, 0, 0),
  [3295] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_break_statement, 2, 0, 0),
  [3297] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_continue_statement, 2, 0, 0),
  [3299] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_continue_statement, 2, 0, 0),
  [3301] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_throw_statement, 2, 0, 0),
  [3303] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_throw_statement, 2, 0, 0),
  [3305] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_local_declaration_statement, 5, 0, 0),
  [3307] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_local_declaration_statement, 5, 0, 0),
  [3309] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_goto_statement, 2, 0, 0),
  [3311] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_goto_statement, 2, 0, 0),
  [3313] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_local_declaration_statement, 2, 0, 0),
  [3315] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_local_declaration_statement, 2, 0, 0),
  [3317] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 5, 0, 58),
  [3319] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 5, 0, 58),
  [3321] = {.entry = {.count = 1, .reusable = false}}, SHIFT(129),
  [3323] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_if_in_top_level, 5, 0, 59),
  [3325] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_if_in_top_level, 5, 0, 59),
  [3327] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_expression_statement, 2, 0, 0),
  [3329] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expression_statement, 2, 0, 0),
  [3331] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_local_declaration_statement, 3, 0, 0),
  [3333] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_local_declaration_statement, 3, 0, 0),
  [3335] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_return_statement, 3, 0, 0),
  [3337] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_return_statement, 3, 0, 0),
  [3339] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_if_in_top_level, 5, 0, 39),
  [3341] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_if_in_top_level, 5, 0, 39),
  [3343] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_yield_statement, 3, 0, 0),
  [3345] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_yield_statement, 3, 0, 0),
  [3347] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_switch_statement, 3, 0, 21),
  [3349] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_switch_statement, 3, 0, 21),
  [3351] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_throw_statement, 3, 0, 0),
  [3353] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_throw_statement, 3, 0, 0),
  [3355] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_local_function_statement, 5, 0, 63),
  [3357] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_local_function_statement, 5, 0, 63),
  [3359] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_goto_statement, 3, 0, 0),
  [3361] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_goto_statement, 3, 0, 0),
  [3363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3277),
  [3365] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_labeled_statement, 3, 0, 0),
  [3367] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_labeled_statement, 3, 0, 0),
  [3369] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_local_declaration_statement, 4, 0, 0),
  [3371] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_local_declaration_statement, 4, 0, 0),
  [3373] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_yield_statement, 4, 0, 0),
  [3375] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_yield_statement, 4, 0, 0),
  [3377] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_switch_body, 2, 0, 0),
  [3379] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_switch_body, 2, 0, 0),
  [3381] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_finally_clause, 2, 0, 0),
  [3383] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_finally_clause, 2, 0, 0),
  [3385] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_try_statement, 4, 0, 7),
  [3387] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_try_statement, 4, 0, 7),
  [3389] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_goto_statement, 4, 0, 0),
  [3391] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_goto_statement, 4, 0, 0),
  [3393] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_local_function_statement, 5, 0, 64),
  [3395] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_local_function_statement, 5, 0, 64),
  [3397] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_body, 1, 0, 0),
  [3399] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_body, 1, 0, 0),
  [3401] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_body, 1, 0, 41),
  [3403] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_body, 1, 0, 41),
  [3405] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 7, 0, 106),
  [3407] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 7, 0, 106),
  [3409] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_declaration, 4, 0, 37),
  [3411] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_declaration, 4, 0, 37),
  [3413] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_declaration, 1, 0, 0),
  [3415] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_declaration, 1, 0, 0),
  [3417] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_using_directive, 5, 0, 0),
  [3419] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_using_directive, 5, 0, 0),
  [3421] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_using_directive, 5, 0, 15),
  [3423] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_using_directive, 5, 0, 15),
  [3425] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_declaration, 5, 0, 50),
  [3427] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_declaration, 5, 0, 50),
  [3429] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_struct_declaration, 5, 0, 51),
  [3431] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_declaration, 5, 0, 51),
  [3433] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_struct_declaration, 5, 0, 50),
  [3435] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_declaration, 5, 0, 50),
  [3437] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_declaration, 5, 0, 50),
  [3439] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_declaration, 5, 0, 50),
  [3441] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interface_declaration, 5, 0, 52),
  [3443] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface_declaration, 5, 0, 52),
  [3445] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interface_declaration, 5, 0, 50),
  [3447] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface_declaration, 5, 0, 50),
  [3449] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_delegate_declaration, 5, 0, 54),
  [3451] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_delegate_declaration, 5, 0, 54),
  [3453] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_declaration, 5, 0, 31),
  [3455] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_declaration, 5, 0, 31),
  [3457] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_declaration, 5, 0, 51),
  [3459] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_declaration, 5, 0, 51),
  [3461] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_declaration, 5, 0, 15),
  [3463] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_declaration, 5, 0, 15),
  [3465] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_declaration, 5, 0, 50),
  [3467] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_declaration, 5, 0, 50),
  [3469] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_declaration, 5, 0, 51),
  [3471] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_declaration, 5, 0, 51),
  [3473] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_declaration, 5, 0, 51),
  [3475] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_declaration, 5, 0, 51),
  [3477] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interface_declaration, 5, 0, 51),
  [3479] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface_declaration, 5, 0, 51),
  [3481] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_using_directive, 6, 0, 0),
  [3483] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_using_directive, 6, 0, 0),
  [3485] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_using_directive, 6, 0, 31),
  [3487] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_using_directive, 6, 0, 31),
  [3489] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_preproc_if_in_top_level_repeat1, 1, 0, 0),
  [3491] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_if_in_top_level_repeat1, 1, 0, 0),
  [3493] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_declaration, 6, 0, 72),
  [3495] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_declaration, 6, 0, 72),
  [3497] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_struct_declaration, 6, 0, 73),
  [3499] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_declaration, 6, 0, 73),
  [3501] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_struct_declaration, 6, 0, 72),
  [3503] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_declaration, 6, 0, 72),
  [3505] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interface_declaration, 6, 0, 75),
  [3507] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface_declaration, 6, 0, 75),
  [3509] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interface_declaration, 6, 0, 72),
  [3511] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface_declaration, 6, 0, 72),
  [3513] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_delegate_declaration, 6, 0, 77),
  [3515] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_delegate_declaration, 6, 0, 77),
  [3517] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_delegate_declaration, 6, 0, 54),
  [3519] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_delegate_declaration, 6, 0, 54),
  [3521] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_declaration, 6, 0, 31),
  [3523] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_declaration, 6, 0, 31),
  [3525] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_declaration, 6, 0, 73),
  [3527] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_declaration, 6, 0, 73),
  [3529] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_declaration, 6, 0, 15),
  [3531] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_declaration, 6, 0, 15),
  [3533] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_declaration, 6, 0, 72),
  [3535] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_declaration, 6, 0, 72),
  [3537] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_declaration, 6, 0, 73),
  [3539] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_declaration, 6, 0, 73),
  [3541] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_struct_declaration, 6, 0, 84),
  [3543] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_declaration, 6, 0, 84),
  [3545] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_declaration, 6, 0, 73),
  [3547] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_declaration, 6, 0, 73),
  [3549] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interface_declaration, 6, 0, 85),
  [3551] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface_declaration, 6, 0, 85),
  [3553] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interface_declaration, 6, 0, 73),
  [3555] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface_declaration, 6, 0, 73),
  [3557] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_delegate_declaration, 6, 0, 86),
  [3559] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_delegate_declaration, 6, 0, 86),
  [3561] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_declaration, 6, 0, 87),
  [3563] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_declaration, 6, 0, 87),
  [3565] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_declaration, 6, 0, 84),
  [3567] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_declaration, 6, 0, 84),
  [3569] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_declaration, 6, 0, 84),
  [3571] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_declaration, 6, 0, 84),
  [3573] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_declaration, 6, 0, 84),
  [3575] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_declaration, 6, 0, 84),
  [3577] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interface_declaration, 6, 0, 84),
  [3579] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface_declaration, 6, 0, 84),
  [3581] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_using_directive, 7, 0, 87),
  [3583] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_using_directive, 7, 0, 87),
  [3585] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_declaration, 7, 0, 99),
  [3587] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_declaration, 7, 0, 99),
  [3589] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_struct_declaration, 7, 0, 100),
  [3591] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_declaration, 7, 0, 100),
  [3593] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_struct_declaration, 7, 0, 99),
  [3595] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_declaration, 7, 0, 99),
  [3597] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interface_declaration, 7, 0, 102),
  [3599] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface_declaration, 7, 0, 102),
  [3601] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_delegate_declaration, 7, 0, 77),
  [3603] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_delegate_declaration, 7, 0, 77),
  [3605] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_declaration, 7, 0, 31),
  [3607] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_declaration, 7, 0, 31),
  [3609] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_declaration, 7, 0, 100),
  [3611] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_declaration, 7, 0, 100),
  [3613] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_declaration, 7, 0, 15),
  [3615] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_declaration, 7, 0, 15),
  [3617] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_declaration, 7, 0, 99),
  [3619] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_declaration, 7, 0, 99),
  [3621] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_declaration, 7, 0, 100),
  [3623] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_declaration, 7, 0, 100),
  [3625] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_struct_declaration, 7, 0, 111),
  [3627] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_declaration, 7, 0, 111),
  [3629] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interface_declaration, 7, 0, 112),
  [3631] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface_declaration, 7, 0, 112),
  [3633] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interface_declaration, 7, 0, 100),
  [3635] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface_declaration, 7, 0, 100),
  [3637] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_delegate_declaration, 7, 0, 113),
  [3639] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_delegate_declaration, 7, 0, 113),
  [3641] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_delegate_declaration, 7, 0, 86),
  [3643] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_delegate_declaration, 7, 0, 86),
  [3645] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_declaration, 7, 0, 87),
  [3647] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_declaration, 7, 0, 87),
  [3649] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_declaration, 7, 0, 111),
  [3651] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_declaration, 7, 0, 111),
  [3653] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_declaration, 7, 0, 111),
  [3655] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_declaration, 7, 0, 111),
  [3657] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_struct_declaration, 7, 0, 115),
  [3659] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_declaration, 7, 0, 115),
  [3661] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_declaration, 4, 0, 15),
  [3663] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_declaration, 4, 0, 15),
  [3665] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interface_declaration, 7, 0, 116),
  [3667] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface_declaration, 7, 0, 116),
  [3669] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interface_declaration, 7, 0, 111),
  [3671] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface_declaration, 7, 0, 111),
  [3673] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_delegate_declaration, 7, 0, 117),
  [3675] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_delegate_declaration, 7, 0, 117),
  [3677] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_declaration, 7, 0, 118),
  [3679] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_declaration, 7, 0, 118),
  [3681] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_declaration, 7, 0, 115),
  [3683] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_declaration, 7, 0, 115),
  [3685] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_declaration, 8, 0, 138),
  [3687] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_declaration, 8, 0, 138),
  [3689] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_struct_declaration, 8, 0, 139),
  [3691] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_declaration, 8, 0, 139),
  [3693] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_struct_declaration, 8, 0, 138),
  [3695] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_declaration, 8, 0, 138),
  [3697] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_declaration, 8, 0, 31),
  [3699] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_declaration, 8, 0, 31),
  [3701] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_declaration, 8, 0, 139),
  [3703] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_declaration, 8, 0, 139),
  [3705] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_declaration, 8, 0, 15),
  [3707] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_declaration, 8, 0, 15),
  [3709] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_declaration, 8, 0, 138),
  [3711] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_declaration, 8, 0, 138),
  [3713] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_declaration, 8, 0, 139),
  [3715] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_declaration, 8, 0, 139),
  [3717] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_struct_declaration, 8, 0, 147),
  [3719] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_declaration, 8, 0, 147),
  [3721] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interface_declaration, 8, 0, 148),
  [3723] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface_declaration, 8, 0, 148),
  [3725] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_delegate_declaration, 8, 0, 113),
  [3727] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_delegate_declaration, 8, 0, 113),
  [3729] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_declaration, 8, 0, 87),
  [3731] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_declaration, 8, 0, 87),
  [3733] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_declaration, 8, 0, 147),
  [3735] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_declaration, 8, 0, 147),
  [3737] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_declaration, 8, 0, 147),
  [3739] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_declaration, 8, 0, 147),
  [3741] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_struct_declaration, 8, 0, 149),
  [3743] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_declaration, 8, 0, 149),
  [3745] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interface_declaration, 8, 0, 150),
  [3747] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface_declaration, 8, 0, 150),
  [3749] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interface_declaration, 8, 0, 147),
  [3751] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface_declaration, 8, 0, 147),
  [3753] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_delegate_declaration, 8, 0, 151),
  [3755] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_delegate_declaration, 8, 0, 151),
  [3757] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_delegate_declaration, 8, 0, 117),
  [3759] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_delegate_declaration, 8, 0, 117),
  [3761] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_declaration, 8, 0, 118),
  [3763] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_declaration, 8, 0, 118),
  [3765] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_declaration, 8, 0, 149),
  [3767] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_declaration, 8, 0, 149),
  [3769] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_struct_declaration, 9, 0, 177),
  [3771] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_declaration, 9, 0, 177),
  [3773] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_declaration, 9, 0, 31),
  [3775] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_declaration, 9, 0, 31),
  [3777] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_declaration, 9, 0, 177),
  [3779] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_declaration, 9, 0, 177),
  [3781] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_declaration, 9, 0, 177),
  [3783] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_declaration, 9, 0, 177),
  [3785] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_struct_declaration, 9, 0, 184),
  [3787] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_declaration, 9, 0, 184),
  [3789] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_declaration, 9, 0, 87),
  [3791] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_declaration, 9, 0, 87),
  [3793] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_declaration, 9, 0, 184),
  [3795] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_declaration, 9, 0, 184),
  [3797] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_declaration, 9, 0, 184),
  [3799] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_declaration, 9, 0, 184),
  [3801] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_struct_declaration, 9, 0, 185),
  [3803] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_declaration, 9, 0, 185),
  [3805] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interface_declaration, 9, 0, 186),
  [3807] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface_declaration, 9, 0, 186),
  [3809] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_delegate_declaration, 9, 0, 151),
  [3811] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_delegate_declaration, 9, 0, 151),
  [3813] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_declaration, 9, 0, 118),
  [3815] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_declaration, 9, 0, 118),
  [3817] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_declaration, 9, 0, 185),
  [3819] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_declaration, 9, 0, 185),
  [3821] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_struct_declaration, 10, 0, 210),
  [3823] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_declaration, 10, 0, 210),
  [3825] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_declaration, 10, 0, 87),
  [3827] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_declaration, 10, 0, 87),
  [3829] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_declaration, 10, 0, 210),
  [3831] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_declaration, 10, 0, 210),
  [3833] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_declaration, 10, 0, 210),
  [3835] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_declaration, 10, 0, 210),
  [3837] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_struct_declaration, 10, 0, 211),
  [3839] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_declaration, 10, 0, 211),
  [3841] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_declaration, 10, 0, 118),
  [3843] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_declaration, 10, 0, 118),
  [3845] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_file_scoped_namespace_declaration, 3, 0, 15),
  [3847] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_file_scoped_namespace_declaration, 3, 0, 15),
  [3849] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_declaration, 10, 0, 211),
  [3851] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_declaration, 10, 0, 211),
  [3853] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_struct_declaration, 11, 0, 223),
  [3855] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_declaration, 11, 0, 223),
  [3857] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_declaration, 11, 0, 118),
  [3859] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_declaration, 11, 0, 118),
  [3861] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_declaration, 11, 0, 223),
  [3863] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_declaration, 11, 0, 223),
  [3865] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(4513),
  [3868] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(3798),
  [3871] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(4529),
  [3874] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(6775),
  [3877] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(6804),
  [3880] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(3803),
  [3883] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(5434),
  [3886] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(4604),
  [3889] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(4583),
  [3892] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(6904),
  [3895] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(7312),
  [3898] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(4520),
  [3901] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(7329),
  [3904] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(7338),
  [3907] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_declaration_list_repeat1, 2, 0, 0),
  [3909] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(7301),
  [3912] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(4647),
  [3915] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(7275),
  [3918] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(3321),
  [3921] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(7372),
  [3924] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(6797),
  [3927] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(4615),
  [3930] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(4765),
  [3933] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(5295),
  [3936] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(6228),
  [3939] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_global_attribute, 6, 0, 0),
  [3941] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_global_attribute, 6, 0, 0),
  [3943] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_global_attribute, 7, 0, 0),
  [3945] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_global_attribute, 7, 0, 0),
  [3947] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_extern_alias_directive, 4, 0, 31),
  [3949] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_extern_alias_directive, 4, 0, 31),
  [3951] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_using_directive, 3, 0, 0),
  [3953] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_using_directive, 3, 0, 0),
  [3955] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_global_attribute, 5, 0, 0),
  [3957] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_global_attribute, 5, 0, 0),
  [3959] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_using_directive, 4, 0, 0),
  [3961] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_using_directive, 4, 0, 0),
  [3963] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_namespace_declaration, 4, 0, 37),
  [3965] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_namespace_declaration, 4, 0, 37),
  [3967] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_declaration, 4, 0, 37),
  [3969] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_declaration, 4, 0, 37),
  [3971] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_struct_declaration, 4, 0, 37),
  [3973] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct_declaration, 4, 0, 37),
  [3975] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_declaration, 4, 0, 37),
  [3977] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_declaration, 4, 0, 37),
  [3979] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interface_declaration, 4, 0, 37),
  [3981] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface_declaration, 4, 0, 37),
  [3983] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum_declaration, 7, 0, 111),
  [3985] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_declaration, 7, 0, 111),
  [3987] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__reserved_identifier, 1, 0, 0), SHIFT(4513),
  [3990] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__reserved_identifier, 1, 0, 0), SHIFT(4529),
  [3993] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__reserved_identifier, 1, 0, 0),
  [3995] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__reserved_identifier, 1, 0, 0),
  [3997] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__reserved_identifier, 1, 0, 0), SHIFT(4604),
  [4000] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4696),
  [4002] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9356),
  [4004] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__reserved_identifier, 1, 0, 0), SHIFT(4615),
  [4007] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__reserved_identifier, 1, 0, 0), SHIFT(4765),
  [4010] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7881),
  [4012] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8969),
  [4014] = {.entry = {.count = 1, .reusable = false}}, SHIFT(155),
  [4016] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__top_level_item, 1, 0, 0),
  [4018] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__top_level_item, 1, 0, 0),
  [4020] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_compilation_unit_repeat1, 1, 0, 0),
  [4022] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_compilation_unit_repeat1, 1, 0, 0),
  [4024] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_try_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7881),
  [4027] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_global_statement, 1, 0, 0),
  [4029] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_global_statement, 1, 0, 0),
  [4031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9152),
  [4033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9214),
  [4035] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_else, 1, 0, 0),
  [4037] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_else, 2, 0, 0),
  [4039] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_modifier, 1, 0, 0), REDUCE(sym__reserved_identifier, 1, 0, 0),
  [4042] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_modifier, 1, 0, 0),
  [4044] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_modifier, 1, 0, 0), REDUCE(sym__reserved_identifier, 1, 0, 0),
  [4047] = {.entry = {.count = 1, .reusable = false}}, SHIFT(69),
  [4049] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_block_repeat1, 1, 0, 0),
  [4051] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_block_repeat1, 1, 0, 0),
  [4053] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__reserved_identifier, 1, 0, 0), SHIFT(2928),
  [4056] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__reserved_identifier, 1, 0, 0), SHIFT(2926),
  [4059] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4642),
  [4061] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym__reserved_identifier, 1, 0, 0), REDUCE(aux_sym__parameter_type_with_modifiers_repeat1, 1, 0, 1), SHIFT(2744),
  [4065] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym__reserved_identifier, 1, 0, 0), REDUCE(aux_sym__parameter_type_with_modifiers_repeat1, 1, 0, 1), SHIFT(2743),
  [4069] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__reserved_identifier, 1, 0, 0), REDUCE(aux_sym__parameter_type_with_modifiers_repeat1, 1, 0, 1),
  [4072] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__reserved_identifier, 1, 0, 0), SHIFT(2744),
  [4075] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__reserved_identifier, 1, 0, 0), SHIFT(2743),
  [4078] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4666),
  [4080] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_implicit_type, 1, 1, 0), REDUCE(sym__reserved_identifier, 1, 0, 0), SHIFT(3939),
  [4084] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_implicit_type, 1, 1, 0), REDUCE(sym__reserved_identifier, 1, 0, 0), SHIFT(3936),
  [4088] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_implicit_type, 1, 1, 0), REDUCE(sym__reserved_identifier, 1, 0, 0),
  [4091] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_implicit_type, 1, 1, 0), REDUCE(sym__reserved_identifier, 1, 0, 0),
  [4094] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_implicit_type, 1, 1, 0), REDUCE(sym__reserved_identifier, 1, 0, 0), SHIFT(6843),
  [4098] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_implicit_type, 1, 1, 0), REDUCE(sym__reserved_identifier, 1, 0, 0), SHIFT(3966),
  [4102] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4718),
  [4104] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__reserved_identifier, 1, 0, 0), SHIFT(3178),
  [4107] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__reserved_identifier, 1, 0, 0), SHIFT(3186),
  [4110] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4625),
  [4112] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4678),
  [4114] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_implicit_type, 1, 1, 0), REDUCE(sym__reserved_identifier, 1, 0, 0), SHIFT(6839),
  [4118] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_implicit_type, 1, 1, 0), REDUCE(sym__reserved_identifier, 1, 0, 0), SHIFT(4153),
  [4122] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_identifier, 1, 0, 0),
  [4124] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_identifier, 1, 0, 0),
  [4126] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_argument_list, 3, 0, 0),
  [4128] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_argument_list, 3, 0, 0),
  [4130] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_generic_name, 2, 0, 0),
  [4132] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_generic_name, 2, 0, 0),
  [4134] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_argument_list, 4, 0, 0),
  [4136] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_argument_list, 4, 0, 0),
  [4138] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__simple_name, 1, 0, 0),
  [4140] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__simple_name, 1, 0, 0),
  [4142] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_name, 1, 0, 0), SHIFT(4381),
  [4145] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__lambda_parameters, 1, 0, 3),
  [4147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7176),
  [4149] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_argument_list, 2, 0, 0),
  [4151] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_argument_list, 2, 0, 0),
  [4153] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4734),
  [4155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7168),
  [4157] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__name, 1, 0, 0),
  [4159] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__name, 1, 0, 0), REDUCE(sym_constant_pattern, 1, 0, 0),
  [4162] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lvalue_expression, 1, 0, 0),
  [4164] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym__name, 1, 0, 0), REDUCE(sym_constant_pattern, 1, 0, 0), REDUCE(sym_lvalue_expression, 1, 0, 0),
  [4168] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__name, 1, 0, 0),
  [4170] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym__name, 1, 0, 0), REDUCE(sym_constant_pattern, 1, 0, 0), REDUCE(sym_lvalue_expression, 1, 0, 0),
  [4174] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__name, 1, 0, 0), REDUCE(sym_constant_pattern, 1, 0, 0),
  [4177] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lvalue_expression, 1, 0, 0),
  [4179] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_qualified_name, 3, 0, 23),
  [4181] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_qualified_name, 3, 0, 23),
  [4183] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_member_access_expression, 3, 0, 20),
  [4185] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_qualified_name, 3, 0, 23), REDUCE(sym_member_access_expression, 3, 0, 20),
  [4188] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_qualified_name, 3, 0, 23), REDUCE(sym_member_access_expression, 3, 0, 20),
  [4191] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_member_access_expression, 3, 0, 20),
  [4193] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__name, 1, 0, 0), REDUCE(sym_lvalue_expression, 1, 0, 0),
  [4196] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__name, 1, 0, 0), REDUCE(sym_lvalue_expression, 1, 0, 0),
  [4199] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_implicit_type, 1, 1, 0), REDUCE(sym__reserved_identifier, 1, 0, 0), SHIFT(3165),
  [4203] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_implicit_type, 1, 1, 0), REDUCE(sym__reserved_identifier, 1, 0, 0), SHIFT(3145),
  [4207] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_implicit_type, 1, 1, 0), REDUCE(sym__reserved_identifier, 1, 0, 0), SHIFT(5200),
  [4211] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_implicit_type, 1, 1, 0), REDUCE(sym__reserved_identifier, 1, 0, 0), SHIFT(5189),
  [4215] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_implicit_type, 1, 1, 0), REDUCE(sym__reserved_identifier, 1, 0, 0), SHIFT(6831),
  [4219] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_implicit_type, 1, 1, 0), REDUCE(sym__reserved_identifier, 1, 0, 0), SHIFT(5773),
  [4223] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3871),
  [4225] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3869),
  [4227] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4728),
  [4229] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__reserved_identifier, 1, 0, 0), SHIFT(3869),
  [4232] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_implicit_type, 1, 1, 0), REDUCE(sym__reserved_identifier, 1, 0, 0), SHIFT(2928),
  [4236] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_implicit_type, 1, 1, 0), REDUCE(sym__reserved_identifier, 1, 0, 0), SHIFT(2926),
  [4240] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_implicit_type, 1, 1, 0), REDUCE(sym__reserved_identifier, 1, 0, 0), SHIFT(6890),
  [4244] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_implicit_type, 1, 1, 0), REDUCE(sym__reserved_identifier, 1, 0, 0), SHIFT(4748),
  [4248] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3911),
  [4250] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3907),
  [4252] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4605),
  [4254] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7259),
  [4256] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_implicit_type, 1, 1, 0), REDUCE(sym__reserved_identifier, 1, 0, 0), SHIFT(3911),
  [4260] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_implicit_type, 1, 1, 0), REDUCE(sym__reserved_identifier, 1, 0, 0), SHIFT(3907),
  [4264] = {.entry = {.count = 1, .reusable = false}}, SHIFT(626),
  [4266] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_name, 1, 0, 0), SHIFT(1175),
  [4269] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_parameter, 1, 0, 4), REDUCE(sym__simple_name, 1, 0, 0),
  [4272] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3799),
  [4274] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4731),
  [4276] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7399),
  [4278] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4530),
  [4280] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7303),
  [4282] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7309),
  [4284] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7310),
  [4286] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4743),
  [4288] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7171),
  [4290] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7391),
  [4292] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6807),
  [4294] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_implicit_type, 1, 1, 0), REDUCE(sym__reserved_identifier, 1, 0, 0), SHIFT(3572),
  [4298] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_implicit_type, 1, 1, 0), REDUCE(sym__reserved_identifier, 1, 0, 0), SHIFT(3578),
  [4302] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_implicit_type, 1, 1, 0), REDUCE(sym__reserved_identifier, 1, 0, 0), SHIFT(6885),
  [4306] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_implicit_type, 1, 1, 0), REDUCE(sym__reserved_identifier, 1, 0, 0), SHIFT(5027),
  [4310] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__variable_designation, 1, 0, 4),
  [4312] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_implicit_type, 1, 1, 0), REDUCE(sym__reserved_identifier, 1, 0, 0), SHIFT(3625),
  [4316] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_implicit_type, 1, 1, 0), REDUCE(sym__reserved_identifier, 1, 0, 0), SHIFT(3610),
  [4320] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_lvalue_expression, 1, 0, 0), REDUCE(aux_sym__parameter_type_with_modifiers_repeat1, 1, 0, 1),
  [4323] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_name, 1, 0, 0), SHIFT(4407),
  [4326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7212),
  [4328] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3572),
  [4330] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3578),
  [4332] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4700),
  [4334] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__reserved_identifier, 1, 0, 0), SHIFT(3578),
  [4337] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3939),
  [4339] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3936),
  [4341] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_is_expression, 3, 0, 24),
  [4343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(310),
  [4345] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_is_expression, 3, 0, 24),
  [4347] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3966),
  [4349] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3625),
  [4351] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3610),
  [4353] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4661),
  [4355] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_pattern, 1, 0, 5),
  [4357] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_pattern, 1, 0, 5),
  [4359] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4153),
  [4361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7243),
  [4363] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2113),
  [4365] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9228),
  [4367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3604),
  [4369] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7356),
  [4371] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4535),
  [4373] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7357),
  [4375] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7358),
  [4377] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4746),
  [4379] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7213),
  [4381] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7311),
  [4383] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4533),
  [4385] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7384),
  [4387] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7397),
  [4389] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4710),
  [4391] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7242),
  [4393] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6786),
  [4395] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1962),
  [4397] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9776),
  [4399] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_recursive_pattern, 1, 0, 0),
  [4401] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_recursive_pattern, 1, 0, 0),
  [4403] = {.entry = {.count = 1, .reusable = false}}, SHIFT(117),
  [4405] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_recursive_pattern, 2, 0, 5),
  [4407] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_recursive_pattern, 2, 0, 5),
  [4409] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1367),
  [4411] = {.entry = {.count = 1, .reusable = false}}, SHIFT(176),
  [4413] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4644),
  [4415] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7319),
  [4417] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4532),
  [4419] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7315),
  [4421] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7320),
  [4423] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7321),
  [4425] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4745),
  [4427] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7178),
  [4429] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6791),
  [4431] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_ref_type, 2, 0, 6),
  [4433] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ref_type, 2, 0, 6),
  [4435] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1254),
  [4437] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_recursive_pattern, 2, 0, 0),
  [4439] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_recursive_pattern, 2, 0, 0),
  [4441] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_recursive_pattern, 3, 0, 5),
  [4443] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_recursive_pattern, 3, 0, 5),
  [4445] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1490),
  [4447] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9468),
  [4449] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2099),
  [4451] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9433),
  [4453] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__scoped_base_type, 1, 0, 0),
  [4455] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__scoped_base_type, 1, 0, 0),
  [4457] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5173),
  [4459] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5167),
  [4461] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4632),
  [4463] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__reserved_identifier, 1, 0, 0), SHIFT(5167),
  [4466] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_scoped_type, 2, 0, 6),
  [4468] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_scoped_type, 2, 0, 6),
  [4470] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_ref_type, 3, 0, 16),
  [4472] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ref_type, 3, 0, 16),
  [4474] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4640),
  [4476] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6794),
  [4478] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_nullable_type, 2, 0, 5),
  [4480] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_nullable_type, 2, 0, 5),
  [4482] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_pointer_type, 5, 0, 53),
  [4484] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_pointer_type, 5, 0, 53),
  [4486] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_pointer_type, 2, 0, 5),
  [4488] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pointer_type, 2, 0, 5),
  [4490] = {.entry = {.count = 1, .reusable = false}}, SHIFT(87),
  [4492] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type, 1, 0, 0),
  [4494] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type, 1, 0, 0),
  [4496] = {.entry = {.count = 1, .reusable = false}}, SHIFT(153),
  [4498] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_pointer_type, 6, 0, 76),
  [4500] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_pointer_type, 6, 0, 76),
  [4502] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_pointer_type, 7, 0, 103),
  [4504] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_pointer_type, 7, 0, 103),
  [4506] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8538),
  [4508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(581),
  [4510] = {.entry = {.count = 1, .reusable = true}}, SHIFT(632),
  [4512] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9906),
  [4514] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2796),
  [4516] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3613),
  [4518] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3631),
  [4520] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_name, 1, 0, 0), SHIFT(4395),
  [4523] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4645),
  [4525] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__reserved_identifier, 1, 0, 0), SHIFT(3907),
  [4528] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4716),
  [4530] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4597),
  [4532] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5752),
  [4534] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3796),
  [4536] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2928),
  [4538] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2926),
  [4540] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4579),
  [4542] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4596),
  [4544] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_rank_specifier, 3, 0, 0),
  [4546] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_rank_specifier, 3, 0, 0),
  [4548] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_type, 2, 0, 8),
  [4550] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 8),
  [4552] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_rank_specifier, 2, 0, 0),
  [4554] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_rank_specifier, 2, 0, 0),
  [4556] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_name, 1, 0, 0), SHIFT(4380),
  [4559] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7318),
  [4561] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4542),
  [4563] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7376),
  [4565] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7324),
  [4567] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7328),
  [4569] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4704),
  [4571] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7184),
  [4573] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3652),
  [4575] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5200),
  [4577] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5189),
  [4579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(319),
  [4581] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5773),
  [4583] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_rank_specifier, 4, 0, 0),
  [4585] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_rank_specifier, 4, 0, 0),
  [4587] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_positional_pattern_clause, 2, 0, 0),
  [4589] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_positional_pattern_clause, 2, 0, 0),
  [4591] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_list, 2, 0, 0),
  [4593] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_type, 1, 0, 0), REDUCE(sym__array_base_type, 1, 0, 0),
  [4596] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_type, 1, 0, 0), SHIFT(2898),
  [4599] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_type, 1, 0, 0), REDUCE(sym__pointer_base_type, 1, 0, 0),
  [4602] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7277),
  [4604] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7277),
  [4606] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7365),
  [4608] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4537),
  [4610] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7362),
  [4612] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7366),
  [4614] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7367),
  [4616] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4747),
  [4618] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7217),
  [4620] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_positional_pattern_clause, 4, 0, 0),
  [4622] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_positional_pattern_clause, 4, 0, 0),
  [4624] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_alias_qualified_name, 3, 0, 29),
  [4626] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_alias_qualified_name, 3, 0, 29),
  [4628] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tuple_type, 4, 0, 0),
  [4630] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tuple_type, 4, 0, 0),
  [4632] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4570),
  [4634] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7174),
  [4636] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7174),
  [4638] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4692),
  [4640] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_bracketed_argument_list, 5, 0, 0),
  [4642] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_bracketed_argument_list, 5, 0, 0),
  [4644] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4694),
  [4646] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7246),
  [4648] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4675),
  [4650] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property_pattern_clause, 3, 0, 0),
  [4652] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_pattern_clause, 3, 0, 0),
  [4654] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property_pattern_clause, 4, 0, 0),
  [4656] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_pattern_clause, 4, 0, 0),
  [4658] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4693),
  [4660] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4697),
  [4662] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7290),
  [4664] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7220),
  [4666] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_element_access_expression, 2, 0, 10),
  [4668] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_element_access_expression, 2, 0, 10),
  [4670] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lvalue_expression, 1, 0, 2),
  [4672] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lvalue_expression, 1, 0, 2),
  [4674] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property_pattern_clause, 2, 0, 0),
  [4676] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_pattern_clause, 2, 0, 0),
  [4678] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4558),
  [4680] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__reserved_identifier, 1, 0, 0), SHIFT(3610),
  [4683] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_bracketed_argument_list, 3, 0, 0),
  [4685] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_bracketed_argument_list, 3, 0, 0),
  [4687] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__parenthesized_lvalue_expression, 3, 0, 0),
  [4689] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__parenthesized_lvalue_expression, 3, 0, 0),
  [4691] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4682),
  [4693] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4711),
  [4695] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property_pattern_clause, 5, 0, 0),
  [4697] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_pattern_clause, 5, 0, 0),
  [4699] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__pointer_indirection_expression, 2, 0, 0),
  [4701] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__pointer_indirection_expression, 2, 0, 0),
  [4703] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_conditional_access_expression, 3, 0, 25),
  [4705] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_conditional_access_expression, 3, 0, 25),
  [4707] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_bracketed_argument_list, 4, 0, 0),
  [4709] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_bracketed_argument_list, 4, 0, 0),
  [4711] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tuple_expression, 4, 0, 0),
  [4713] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tuple_expression, 4, 0, 0),
  [4715] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7247),
  [4717] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4748),
  [4719] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5027),
  [4721] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4659),
  [4723] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4622),
  [4725] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4639),
  [4727] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4667),
  [4729] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4735),
  [4731] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4652),
  [4733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(684),
  [4735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(682),
  [4737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(709),
  [4739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(679),
  [4741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(643),
  [4743] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3858),
  [4745] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3844),
  [4747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(714),
  [4749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(718),
  [4751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(642),
  [4753] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3812),
  [4755] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3826),
  [4757] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3915),
  [4759] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_name, 1, 0, 0), SHIFT(4452),
  [4762] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_name, 1, 0, 0), SHIFT(4435),
  [4765] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_initializer_expression, 3, 0, 0),
  [4767] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_initializer_expression, 3, 0, 0),
  [4769] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property_declaration, 5, 0, 133),
  [4771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1722),
  [4773] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_declaration, 5, 0, 133),
  [4775] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property_declaration, 5, 0, 123),
  [4777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1706),
  [4779] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_declaration, 5, 0, 123),
  [4781] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property_declaration, 3, 0, 70),
  [4783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1540),
  [4785] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_declaration, 3, 0, 70),
  [4787] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_name, 1, 0, 0), SHIFT(4398),
  [4790] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property_declaration, 4, 0, 95),
  [4792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1615),
  [4794] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_declaration, 4, 0, 95),
  [4796] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7228),
  [4798] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_accessor_list, 2, 0, 0),
  [4800] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_accessor_list, 2, 0, 0),
  [4802] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_accessor_list, 3, 0, 0),
  [4804] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_accessor_list, 3, 0, 0),
  [4806] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constant_pattern, 1, 0, 0),
  [4808] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_constant_pattern, 1, 0, 0), REDUCE(sym_lvalue_expression, 1, 0, 0),
  [4811] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_constant_pattern, 1, 0, 0), REDUCE(sym_lvalue_expression, 1, 0, 0),
  [4814] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constant_pattern, 1, 0, 0),
  [4816] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7262),
  [4818] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property_declaration, 4, 0, 92),
  [4820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1632),
  [4822] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_declaration, 4, 0, 92),
  [4824] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property_declaration, 6, 0, 163),
  [4826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1781),
  [4828] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_declaration, 6, 0, 163),
  [4830] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7240),
  [4832] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7285),
  [4834] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_event_field_declaration, 3, 1, 0),
  [4836] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_event_field_declaration, 3, 1, 0),
  [4838] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructor_declaration, 3, 0, 71),
  [4840] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_declaration, 3, 0, 71),
  [4842] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_event_declaration, 4, 0, 32),
  [4844] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_event_declaration, 4, 0, 32),
  [4846] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_event_declaration, 4, 0, 92),
  [4848] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_event_declaration, 4, 0, 92),
  [4850] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_destructor_declaration, 4, 0, 93),
  [4852] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_destructor_declaration, 4, 0, 93),
  [4854] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_if, 4, 0, 39),
  [4856] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_if, 4, 0, 39),
  [4858] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_indexer_declaration, 4, 0, 94),
  [4860] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_indexer_declaration, 4, 0, 94),
  [4862] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_declaration, 4, 0, 96),
  [4864] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_declaration, 4, 0, 96),
  [4866] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property_declaration, 4, 0, 97),
  [4868] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_declaration, 4, 0, 97),
  [4870] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructor_declaration, 4, 0, 98),
  [4872] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_declaration, 4, 0, 98),
  [4874] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_event_field_declaration, 4, 1, 0),
  [4876] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_event_field_declaration, 4, 1, 0),
  [4878] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructor_declaration, 4, 0, 93),
  [4880] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_declaration, 4, 0, 93),
  [4882] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_declaration, 4, 0, 0),
  [4884] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration, 4, 0, 0),
  [4886] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_destructor_declaration, 5, 0, 121),
  [4888] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_destructor_declaration, 5, 0, 121),
  [4890] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_event_declaration, 5, 0, 122),
  [4892] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_event_declaration, 5, 0, 122),
  [4894] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_event_declaration, 5, 0, 123),
  [4896] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_event_declaration, 5, 0, 123),
  [4898] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_conversion_operator_declaration, 5, 0, 124),
  [4900] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_conversion_operator_declaration, 5, 0, 124),
  [4902] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_if, 5, 0, 59),
  [4904] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_if, 5, 0, 59),
  [4906] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_if, 5, 0, 39),
  [4908] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_if, 5, 0, 39),
  [4910] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_operator_declaration, 5, 0, 125),
  [4912] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_operator_declaration, 5, 0, 125),
  [4914] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_indexer_declaration, 5, 0, 126),
  [4916] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_indexer_declaration, 5, 0, 126),
  [4918] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_indexer_declaration, 5, 0, 127),
  [4920] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_indexer_declaration, 5, 0, 127),
  [4922] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_declaration, 5, 0, 128),
  [4924] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_declaration, 5, 0, 128),
  [4926] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property_declaration, 5, 0, 129),
  [4928] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_declaration, 5, 0, 129),
  [4930] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_declaration, 5, 0, 131),
  [4932] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_declaration, 5, 0, 131),
  [4934] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_declaration, 5, 0, 132),
  [4936] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_declaration, 5, 0, 132),
  [4938] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_event_declaration, 5, 0, 49),
  [4940] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_event_declaration, 5, 0, 49),
  [4942] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_event_declaration, 5, 0, 133),
  [4944] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_event_declaration, 5, 0, 133),
  [4946] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_indexer_declaration, 5, 0, 134),
  [4948] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_indexer_declaration, 5, 0, 134),
  [4950] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_declaration, 5, 0, 135),
  [4952] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_declaration, 5, 0, 135),
  [4954] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property_declaration, 5, 0, 136),
  [4956] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_declaration, 5, 0, 136),
  [4958] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructor_declaration, 5, 0, 137),
  [4960] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_declaration, 5, 0, 137),
  [4962] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_event_field_declaration, 5, 1, 0),
  [4964] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_event_field_declaration, 5, 1, 0),
  [4966] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructor_declaration, 5, 0, 121),
  [4968] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_declaration, 5, 0, 121),
  [4970] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_type, 1, 0, 0), SHIFT(3370),
  [4973] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7266),
  [4975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7266),
  [4977] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declaration, 1, 0, 0),
  [4979] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declaration, 1, 0, 0),
  [4981] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_declaration_list_repeat1, 1, 0, 0),
  [4983] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_declaration_list_repeat1, 1, 0, 0),
  [4985] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_conversion_operator_declaration, 6, 0, 153),
  [4987] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_conversion_operator_declaration, 6, 0, 153),
  [4989] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_if, 6, 0, 81),
  [4991] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_if, 6, 0, 81),
  [4993] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_operator_declaration, 6, 0, 154),
  [4995] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_operator_declaration, 6, 0, 154),
  [4997] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_indexer_declaration, 6, 0, 155),
  [4999] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_indexer_declaration, 6, 0, 155),
  [5001] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_declaration, 6, 0, 156),
  [5003] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_declaration, 6, 0, 156),
  [5005] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_declaration, 6, 0, 157),
  [5007] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_declaration, 6, 0, 157),
  [5009] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_declaration, 6, 0, 159),
  [5011] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_declaration, 6, 0, 159),
  [5013] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property_declaration, 6, 0, 160),
  [5015] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_declaration, 6, 0, 160),
  [5017] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_destructor_declaration, 6, 0, 161),
  [5019] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_destructor_declaration, 6, 0, 161),
  [5021] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_event_declaration, 6, 0, 162),
  [5023] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_event_declaration, 6, 0, 162),
  [5025] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_event_declaration, 6, 0, 163),
  [5027] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_event_declaration, 6, 0, 163),
  [5029] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_operator_declaration, 6, 0, 164),
  [5031] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_operator_declaration, 6, 0, 164),
  [5033] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_indexer_declaration, 6, 0, 165),
  [5035] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_indexer_declaration, 6, 0, 165),
  [5037] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_indexer_declaration, 6, 0, 166),
  [5039] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_indexer_declaration, 6, 0, 166),
  [5041] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_declaration, 6, 0, 167),
  [5043] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_declaration, 6, 0, 167),
  [5045] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property_declaration, 6, 0, 168),
  [5047] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_declaration, 6, 0, 168),
  [5049] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_declaration, 6, 0, 169),
  [5051] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_declaration, 6, 0, 169),
  [5053] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_declaration, 6, 0, 170),
  [5055] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_declaration, 6, 0, 170),
  [5057] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_event_declaration, 6, 0, 171),
  [5059] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_event_declaration, 6, 0, 171),
  [5061] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_event_declaration, 6, 0, 172),
  [5063] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_event_declaration, 6, 0, 172),
  [5065] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_indexer_declaration, 6, 0, 173),
  [5067] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_indexer_declaration, 6, 0, 173),
  [5069] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_declaration, 6, 0, 174),
  [5071] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_declaration, 6, 0, 174),
  [5073] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7272),
  [5075] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property_declaration, 6, 0, 175),
  [5077] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_declaration, 6, 0, 175),
  [5079] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructor_declaration, 6, 0, 176),
  [5081] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_declaration, 6, 0, 176),
  [5083] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_conversion_operator_declaration, 7, 0, 187),
  [5085] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_conversion_operator_declaration, 7, 0, 187),
  [5087] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_operator_declaration, 7, 0, 188),
  [5089] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_operator_declaration, 7, 0, 188),
  [5091] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_declaration, 7, 0, 189),
  [5093] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_declaration, 7, 0, 189),
  [5095] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property_declaration, 7, 0, 190),
  [5097] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_declaration, 7, 0, 190),
  [5099] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_operator_declaration, 7, 0, 192),
  [5101] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_operator_declaration, 7, 0, 192),
  [5103] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_indexer_declaration, 7, 0, 193),
  [5105] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_indexer_declaration, 7, 0, 193),
  [5107] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_declaration, 7, 0, 194),
  [5109] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_declaration, 7, 0, 194),
  [5111] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_declaration, 7, 0, 195),
  [5113] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_declaration, 7, 0, 195),
  [5115] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_declaration, 7, 0, 196),
  [5117] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_declaration, 7, 0, 196),
  [5119] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property_declaration, 7, 0, 197),
  [5121] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_declaration, 7, 0, 197),
  [5123] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_event_declaration, 7, 0, 198),
  [5125] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_event_declaration, 7, 0, 198),
  [5127] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_event_declaration, 7, 0, 199),
  [5129] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_event_declaration, 7, 0, 199),
  [5131] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_operator_declaration, 7, 0, 200),
  [5133] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_operator_declaration, 7, 0, 200),
  [5135] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_indexer_declaration, 7, 0, 201),
  [5137] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_indexer_declaration, 7, 0, 201),
  [5139] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_indexer_declaration, 7, 0, 202),
  [5141] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_indexer_declaration, 7, 0, 202),
  [5143] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_declaration, 7, 0, 203),
  [5145] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_declaration, 7, 0, 203),
  [5147] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property_declaration, 7, 0, 204),
  [5149] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_declaration, 7, 0, 204),
  [5151] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_declaration, 7, 0, 205),
  [5153] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_declaration, 7, 0, 205),
  [5155] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_declaration, 7, 0, 206),
  [5157] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_declaration, 7, 0, 206),
  [5159] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_conversion_operator_declaration, 8, 0, 212),
  [5161] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_conversion_operator_declaration, 8, 0, 212),
  [5163] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_operator_declaration, 8, 0, 213),
  [5165] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_operator_declaration, 8, 0, 213),
  [5167] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_declaration, 8, 0, 214),
  [5169] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_declaration, 8, 0, 214),
  [5171] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property_declaration, 8, 0, 215),
  [5173] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_declaration, 8, 0, 215),
  [5175] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_operator_declaration, 8, 0, 216),
  [5177] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_operator_declaration, 8, 0, 216),
  [5179] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_indexer_declaration, 8, 0, 217),
  [5181] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_indexer_declaration, 8, 0, 217),
  [5183] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_declaration, 8, 0, 218),
  [5185] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_declaration, 8, 0, 218),
  [5187] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_declaration, 8, 0, 219),
  [5189] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_declaration, 8, 0, 219),
  [5191] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_declaration, 8, 0, 220),
  [5193] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_declaration, 8, 0, 220),
  [5195] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property_declaration, 8, 0, 221),
  [5197] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_declaration, 8, 0, 221),
  [5199] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_conversion_operator_declaration, 9, 0, 224),
  [5201] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_conversion_operator_declaration, 9, 0, 224),
  [5203] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_operator_declaration, 9, 0, 225),
  [5205] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_operator_declaration, 9, 0, 225),
  [5207] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_declaration, 9, 0, 226),
  [5209] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_declaration, 9, 0, 226),
  [5211] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property_declaration, 9, 0, 227),
  [5213] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_declaration, 9, 0, 227),
  [5215] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7195),
  [5217] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7175),
  [5219] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7198),
  [5221] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_declaration, 2, 0, 0),
  [5223] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration, 2, 0, 0),
  [5225] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_declaration, 3, 0, 0),
  [5227] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_declaration, 3, 0, 0),
  [5229] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7250),
  [5231] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7227),
  [5233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7288),
  [5235] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7210),
  [5237] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7254),
  [5239] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7288),
  [5241] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7280),
  [5243] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7271),
  [5245] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7282),
  [5247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7182),
  [5249] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7182),
  [5251] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7179),
  [5253] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7236),
  [5255] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7193),
  [5257] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7264),
  [5259] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7255),
  [5261] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7221),
  [5263] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_creation_expression, 2, 0, 6),
  [5265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(589),
  [5267] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object_creation_expression, 2, 0, 6),
  [5269] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7283),
  [5271] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_prefix_unary_expression, 2, 0, 0),
  [5273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(622),
  [5275] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_prefix_unary_expression, 2, 0, 0),
  [5277] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3640),
  [5279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3640),
  [5281] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_name, 1, 0, 0), SHIFT(4425),
  [5284] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2055),
  [5286] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expression, 1, 0, 0),
  [5288] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_expression, 1, 0, 0),
  [5290] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2055),
  [5292] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_await_expression, 2, 0, 0),
  [5294] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_await_expression, 2, 0, 0),
  [5296] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_stackalloc_expression, 2, 0, 6),
  [5298] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__array_base_type, 1, 0, 0), REDUCE(sym_stackalloc_expression, 2, 0, 6),
  [5301] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_stackalloc_expression, 2, 0, 6),
  [5303] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_creation_expression, 3, 0, 18),
  [5305] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object_creation_expression, 3, 0, 18),
  [5307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5590),
  [5309] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4357),
  [5311] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4126),
  [5313] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5406),
  [5315] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_implicit_object_creation_expression, 2, 0, 0),
  [5317] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_implicit_object_creation_expression, 2, 0, 0),
  [5319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4371),
  [5321] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4123),
  [5323] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8499),
  [5325] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cast_expression, 4, 1, 36),
  [5327] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_cast_expression, 4, 1, 36),
  [5329] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_name, 1, 0, 0), SHIFT(4443),
  [5332] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1245),
  [5334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1245),
  [5336] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_type, 1, 0, 0), REDUCE(sym__array_base_type, 1, 0, 0), REDUCE(sym_array_creation_expression, 2, 17, 6),
  [5340] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_type, 1, 0, 0), REDUCE(sym_array_creation_expression, 2, 17, 6),
  [5343] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_type, 1, 0, 0), SHIFT(668),
  [5346] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_type, 1, 0, 0), REDUCE(sym_array_creation_expression, 2, 17, 6),
  [5349] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_type, 1, 0, 0), REDUCE(sym_array_creation_expression, 2, 17, 6), SHIFT(3654),
  [5353] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_argument_list, 4, 0, 0),
  [5355] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_argument_list, 4, 0, 0),
  [5357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7170),
  [5359] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_argument_list, 2, 0, 0),
  [5361] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_argument_list, 2, 0, 0),
  [5363] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string_literal, 2, 0, 0),
  [5365] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string_literal, 2, 0, 0),
  [5367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3638),
  [5369] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5092),
  [5371] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2012),
  [5373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2012),
  [5375] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_type, 1, 0, 0), SHIFT(3617),
  [5378] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_argument_list, 3, 0, 0),
  [5380] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_argument_list, 3, 0, 0),
  [5382] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string_literal, 3, 0, 0),
  [5384] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string_literal, 3, 0, 0),
  [5386] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3720),
  [5388] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_raw_string_literal, 3, 0, 0),
  [5390] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_raw_string_literal, 3, 0, 0),
  [5392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3634),
  [5394] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_class_declaration_repeat1, 2, 0, 0),
  [5396] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(5434),
  [5399] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_class_declaration_repeat1, 2, 0, 0),
  [5401] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interpolated_string_expression, 4, 0, 30),
  [5403] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interpolated_string_expression, 4, 0, 30),
  [5405] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_type, 1, 0, 0), SHIFT(3654),
  [5408] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_raw_string_literal, 4, 0, 0),
  [5410] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_raw_string_literal, 4, 0, 0),
  [5412] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_with_expression, 4, 0, 0),
  [5414] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_with_expression, 4, 0, 0),
  [5416] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda_expression, 3, 0, 28),
  [5418] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lambda_expression, 3, 0, 28),
  [5420] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_postfix_unary_expression, 2, 0, 0),
  [5422] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_postfix_unary_expression, 2, 0, 0),
  [5424] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda_expression, 4, 0, 46),
  [5426] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lambda_expression, 4, 0, 46),
  [5428] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_initializer_expression, 4, 0, 0),
  [5430] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_initializer_expression, 4, 0, 0),
  [5432] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_accessor_list_repeat1, 2, 0, 0), SHIFT_REPEAT(2744),
  [5435] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_accessor_list_repeat1, 2, 0, 0), SHIFT_REPEAT(4496),
  [5438] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_accessor_list_repeat1, 2, 0, 0), SHIFT_REPEAT(2743),
  [5441] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_accessor_list_repeat1, 2, 0, 0), SHIFT_REPEAT(5478),
  [5444] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_accessor_list_repeat1, 2, 0, 0),
  [5446] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_accessor_list_repeat1, 2, 0, 0), SHIFT_REPEAT(4116),
  [5449] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_accessor_list_repeat1, 2, 0, 0), SHIFT_REPEAT(7785),
  [5452] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_anonymous_method_expression, 4, 0, 47),
  [5454] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_anonymous_method_expression, 4, 0, 47),
  [5456] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4496),
  [5458] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5478),
  [5460] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3202),
  [5462] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4116),
  [5464] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7785),
  [5466] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_implicit_array_creation_expression, 4, 0, 0),
  [5468] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_implicit_array_creation_expression, 4, 0, 0),
  [5470] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_expression, 3, 0, 0),
  [5472] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesized_expression, 3, 0, 0),
  [5474] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_modifier, 1, 0, 0),
  [5476] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_boolean_literal, 1, 0, 0),
  [5478] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_boolean_literal, 1, 0, 0),
  [5480] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_initializer_expression, 5, 0, 0),
  [5482] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_initializer_expression, 5, 0, 0),
  [5484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8833),
  [5486] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_anonymous_object_creation_expression, 4, 0, 0),
  [5488] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_anonymous_object_creation_expression, 4, 0, 0),
  [5490] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_implicit_array_creation_expression, 5, 0, 0),
  [5492] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_implicit_array_creation_expression, 5, 0, 0),
  [5494] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_creation_expression, 4, 0, 38),
  [5496] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object_creation_expression, 4, 0, 38),
  [5498] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_anonymous_object_creation_expression, 5, 0, 0),
  [5500] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_anonymous_object_creation_expression, 5, 0, 0),
  [5502] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_checked_expression, 4, 0, 0),
  [5504] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_checked_expression, 4, 0, 0),
  [5506] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__select_or_group_clause, 1, 0, 0),
  [5508] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__select_or_group_clause, 1, 0, 0),
  [5510] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__query_body_repeat2, 4, 0, 0),
  [5512] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__query_body_repeat2, 4, 0, 0),
  [5514] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_anonymous_method_expression, 2, 0, 0),
  [5516] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_anonymous_method_expression, 2, 0, 0),
  [5518] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_anonymous_method_expression, 3, 0, 17),
  [5520] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_anonymous_method_expression, 3, 0, 17),
  [5522] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_if_in_expression, 5, 0, 39),
  [5524] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_if_in_expression, 5, 0, 39),
  [5526] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_anonymous_method_expression, 3, 0, 0),
  [5528] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_anonymous_method_expression, 3, 0, 0),
  [5530] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_if_in_expression, 5, 0, 59),
  [5532] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_if_in_expression, 5, 0, 59),
  [5534] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_implicit_stackalloc_expression, 4, 0, 0),
  [5536] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_implicit_stackalloc_expression, 4, 0, 0),
  [5538] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sizeof_expression, 4, 0, 16),
  [5540] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_sizeof_expression, 4, 0, 16),
  [5542] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3201),
  [5544] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_switch_expression, 5, 0, 0),
  [5546] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_switch_expression, 5, 0, 0),
  [5548] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_invocation_expression, 2, 0, 9),
  [5550] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_invocation_expression, 2, 0, 9),
  [5552] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_anonymous_object_creation_expression, 3, 0, 0),
  [5554] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_anonymous_object_creation_expression, 3, 0, 0),
  [5556] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_implicit_object_creation_expression, 3, 0, 0),
  [5558] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_implicit_object_creation_expression, 3, 0, 0),
  [5560] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_with_expression, 5, 0, 0),
  [5562] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_with_expression, 5, 0, 0),
  [5564] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_creation_expression, 3, 0, 19),
  [5566] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object_creation_expression, 3, 0, 19),
  [5568] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_creation_expression, 3, 17, 6),
  [5570] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_creation_expression, 3, 17, 6),
  [5572] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda_expression, 5, 0, 67),
  [5574] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lambda_expression, 5, 0, 67),
  [5576] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_stackalloc_expression, 3, 0, 6),
  [5578] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_stackalloc_expression, 3, 0, 6),
  [5580] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_typeof_expression, 4, 0, 16),
  [5582] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_typeof_expression, 4, 0, 16),
  [5584] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda_expression, 5, 0, 69),
  [5586] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lambda_expression, 5, 0, 69),
  [5588] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_conditional_access_expression, 3, 0, 26),
  [5590] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_conditional_access_expression, 3, 0, 26),
  [5592] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_query_expression, 2, 0, 0),
  [5594] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_query_expression, 2, 0, 0),
  [5596] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_anonymous_object_creation_expression, 6, 0, 0),
  [5598] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_anonymous_object_creation_expression, 6, 0, 0),
  [5600] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_refvalue_expression, 6, 0, 80),
  [5602] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_refvalue_expression, 6, 0, 80),
  [5604] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_if_in_expression, 6, 0, 81),
  [5606] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_if_in_expression, 6, 0, 81),
  [5608] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__query_body_repeat2, 3, 0, 0),
  [5610] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__query_body_repeat2, 3, 0, 0),
  [5612] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1308),
  [5614] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1308),
  [5616] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_switch_expression, 6, 0, 0),
  [5618] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_switch_expression, 6, 0, 0),
  [5620] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_with_expression, 6, 0, 0),
  [5622] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_with_expression, 6, 0, 0),
  [5624] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda_expression, 6, 0, 91),
  [5626] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lambda_expression, 6, 0, 91),
  [5628] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expression_statement_expression, 1, 0, 0),
  [5630] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__expression_statement_expression, 1, 0, 0),
  [5632] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_makeref_expression, 4, 0, 0),
  [5634] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_makeref_expression, 4, 0, 0),
  [5636] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_as_expression, 3, 0, 24),
  [5638] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_as_expression, 3, 0, 24),
  [5640] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_reftype_expression, 4, 0, 0),
  [5642] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_reftype_expression, 4, 0, 0),
  [5644] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda_expression, 4, 0, 40),
  [5646] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lambda_expression, 4, 0, 40),
  [5648] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interpolated_string_expression, 4, 0, 0),
  [5650] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interpolated_string_expression, 4, 0, 0),
  [5652] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_non_lvalue_expression, 1, 0, 0),
  [5654] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_non_lvalue_expression, 1, 0, 0),
  [5656] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_switch_expression, 7, 0, 0),
  [5658] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_switch_expression, 7, 0, 0),
  [5660] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string_literal, 4, 0, 0),
  [5662] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string_literal, 4, 0, 0),
  [5664] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interpolated_string_expression, 3, 0, 0),
  [5666] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interpolated_string_expression, 3, 0, 0),
  [5668] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4932),
  [5670] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_member_binding_expression, 2, 0, 15),
  [5672] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_member_binding_expression, 2, 0, 15),
  [5674] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_literal, 1, 0, 0),
  [5676] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_literal, 1, 0, 0),
  [5678] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interpolated_string_expression, 3, 0, 12),
  [5680] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interpolated_string_expression, 3, 0, 12),
  [5682] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_character_literal, 3, 0, 0),
  [5684] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_character_literal, 3, 0, 0),
  [5686] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_switch_expression, 4, 0, 0),
  [5688] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_switch_expression, 4, 0, 0),
  [5690] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_class_declaration_repeat2, 2, 0, 0),
  [5692] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_declaration_repeat2, 2, 0, 0), SHIFT_REPEAT(3803),
  [5695] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_class_declaration_repeat2, 2, 0, 0),
  [5697] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_attribute_list, 3, 0, 0),
  [5699] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attribute_list, 3, 0, 0),
  [5701] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_class_declaration_repeat1, 1, 0, 0),
  [5703] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_class_declaration_repeat1, 1, 0, 0),
  [5705] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1170),
  [5707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1170),
  [5709] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7211),
  [5711] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_attribute_list, 6, 0, 0),
  [5713] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attribute_list, 6, 0, 0),
  [5715] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1189),
  [5717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1189),
  [5719] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_attribute_list, 4, 0, 0),
  [5721] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attribute_list, 4, 0, 0),
  [5723] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_attribute_list, 5, 0, 0),
  [5725] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attribute_list, 5, 0, 0),
  [5727] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2157),
  [5729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2157),
  [5731] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1990),
  [5733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1990),
  [5735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7330),
  [5737] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1425),
  [5739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1425),
  [5741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5468),
  [5743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8558),
  [5745] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4691),
  [5747] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9935),
  [5749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2750),
  [5751] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7383),
  [5753] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5179),
  [5755] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8173),
  [5757] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7872),
  [5759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(591),
  [5761] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_class_declaration_repeat2, 1, 0, 0),
  [5763] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_class_declaration_repeat2, 1, 0, 0),
  [5765] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_name, 1, 0, 0), SHIFT(4445),
  [5768] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7218),
  [5770] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1363),
  [5772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1363),
  [5774] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6836),
  [5776] = {.entry = {.count = 1, .reusable = true}}, SHIFT(602),
  [5778] = {.entry = {.count = 1, .reusable = true}}, SHIFT(609),
  [5780] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4026),
  [5782] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4026),
  [5784] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6847),
  [5786] = {.entry = {.count = 1, .reusable = true}}, SHIFT(47),
  [5788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(43),
  [5790] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2015),
  [5792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2015),
  [5794] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_name, 1, 0, 0), SHIFT(4406),
  [5797] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_type, 1, 0, 0), SHIFT(680),
  [5800] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_type, 1, 0, 0), REDUCE(sym_array_creation_expression, 2, 17, 6), SHIFT(3919),
  [5804] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1459),
  [5806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1459),
  [5808] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_type, 1, 0, 0), SHIFT(3919),
  [5811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4023),
  [5813] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_name, 1, 0, 0), SHIFT(4447),
  [5816] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7226),
  [5818] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2071),
  [5820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2071),
  [5822] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1523),
  [5824] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1523),
  [5826] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7219),
  [5828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4059),
  [5830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(618),
  [5832] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4148),
  [5834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4148),
  [5836] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4071),
  [5838] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1228),
  [5840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1228),
  [5842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3968),
  [5844] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3985),
  [5846] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_recursive_pattern, 4, 0, 83),
  [5848] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_recursive_pattern, 4, 0, 83),
  [5850] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_type, 1, 0, 0), SHIFT(3976),
  [5853] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1537),
  [5855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1537),
  [5857] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1382),
  [5859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1382),
  [5861] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__variable_designation, 1, 0, 0),
  [5863] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__variable_designation, 1, 0, 0),
  [5865] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_var_pattern, 2, 0, 43),
  [5867] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_var_pattern, 2, 0, 43),
  [5869] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_list_pattern, 5, 0, 0),
  [5871] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_list_pattern, 5, 0, 0),
  [5873] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__variable_designation, 1, 0, 4),
  [5875] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_variable_designation, 4, 0, 110),
  [5877] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesized_variable_designation, 4, 0, 110),
  [5879] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_is_pattern_expression, 3, 0, 27),
  [5881] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_is_pattern_expression, 3, 0, 27),
  [5883] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_constant_pattern, 1, 0, 0), REDUCE(sym_non_lvalue_expression, 1, 0, 0),
  [5886] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_constant_pattern, 1, 0, 0), REDUCE(sym_non_lvalue_expression, 1, 0, 0),
  [5889] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_constant_pattern, 1, 0, 0), REDUCE(sym__expression_statement_expression, 1, 0, 0),
  [5892] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_constant_pattern, 1, 0, 0), REDUCE(sym__expression_statement_expression, 1, 0, 0),
  [5895] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_list_pattern, 4, 0, 0),
  [5897] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_list_pattern, 4, 0, 0),
  [5899] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7388),
  [5901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4706),
  [5903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7287),
  [5905] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7341),
  [5907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4638),
  [5909] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_and_pattern, 3, 0, 24),
  [5911] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_and_pattern, 3, 0, 24),
  [5913] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_recursive_pattern, 2, 0, 43),
  [5915] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_recursive_pattern, 2, 0, 43),
  [5917] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2034),
  [5919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2034),
  [5921] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_type, 1, 0, 0), SHIFT(669),
  [5924] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_type, 1, 0, 0), REDUCE(sym_array_creation_expression, 2, 17, 6), SHIFT(3976),
  [5928] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_recursive_pattern, 3, 0, 66),
  [5930] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_recursive_pattern, 3, 0, 66),
  [5932] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_variable_designation, 3, 0, 43),
  [5934] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesized_variable_designation, 3, 0, 43),
  [5936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4818),
  [5938] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_recursive_pattern, 3, 0, 60),
  [5940] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_recursive_pattern, 3, 0, 60),
  [5942] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_list_pattern, 3, 0, 0),
  [5944] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_list_pattern, 3, 0, 0),
  [5946] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_pattern, 3, 0, 0),
  [5948] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesized_pattern, 3, 0, 0),
  [5950] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1324),
  [5952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1324),
  [5954] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4253),
  [5956] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_variable_designation, 2, 0, 0),
  [5958] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesized_variable_designation, 2, 0, 0),
  [5960] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_list_pattern, 2, 0, 0),
  [5962] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_list_pattern, 2, 0, 0),
  [5964] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pattern, 1, 0, 0),
  [5966] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_pattern, 1, 0, 0),
  [5968] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7904),
  [5970] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declaration_pattern, 2, 0, 44),
  [5972] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_declaration_pattern, 2, 0, 44),
  [5974] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8122),
  [5976] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4509),
  [5978] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5120),
  [5980] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5153),
  [5982] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8056),
  [5984] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8145),
  [5986] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7847),
  [5988] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4698),
  [5990] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8006),
  [5992] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9633),
  [5994] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7530),
  [5996] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4979),
  [5998] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1269),
  [6000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1269),
  [6002] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2178),
  [6004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2178),
  [6006] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1345),
  [6008] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1345),
  [6010] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_type, 1, 0, 0), SHIFT(678),
  [6013] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_type, 1, 0, 0), REDUCE(sym_array_creation_expression, 2, 17, 6), SHIFT(3617),
  [6017] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7244),
  [6019] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8189),
  [6021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4758),
  [6023] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1444),
  [6025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1444),
  [6027] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8160),
  [6029] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1595),
  [6031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1595),
  [6033] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1610),
  [6035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1610),
  [6037] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8070),
  [6039] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1685),
  [6041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1685),
  [6043] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1757),
  [6045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1757),
  [6047] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1703),
  [6049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1703),
  [6051] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1812),
  [6053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1812),
  [6055] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7992),
  [6057] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(5478),
  [6060] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2049),
  [6062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2049),
  [6064] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1670),
  [6066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1670),
  [6068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(623),
  [6070] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1742),
  [6072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1742),
  [6074] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_accessor_declaration, 4, 0, 191),
  [6076] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_accessor_declaration, 4, 0, 191),
  [6078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3027),
  [6080] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(5752),
  [6083] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1797),
  [6085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1797),
  [6087] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7231),
  [6089] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1850),
  [6091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1850),
  [6093] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1889),
  [6095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1889),
  [6097] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1211),
  [6099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1211),
  [6101] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_accessor_declaration, 2, 0, 130),
  [6103] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_accessor_declaration, 2, 0, 130),
  [6105] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_declaration_repeat2, 2, 0, 0), SHIFT_REPEAT(4496),
  [6108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(46),
  [6110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8303),
  [6112] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_accessor_declaration, 3, 0, 158),
  [6114] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_accessor_declaration, 3, 0, 158),
  [6116] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_accessor_list_repeat1, 1, 0, 0),
  [6118] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_accessor_list_repeat1, 1, 0, 0),
  [6120] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1402),
  [6122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1402),
  [6124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(608),
  [6126] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1480),
  [6128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1480),
  [6130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3008),
  [6132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5044),
  [6134] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1725),
  [6136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1725),
  [6138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(38),
  [6140] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4350),
  [6142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8602),
  [6144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(583),
  [6146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(635),
  [6148] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9947),
  [6150] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3013),
  [6152] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3573),
  [6154] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3621),
  [6156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(616),
  [6158] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4549),
  [6160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4549),
  [6162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8457),
  [6164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(582),
  [6166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(634),
  [6168] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9956),
  [6170] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2946),
  [6172] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3946),
  [6174] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3962),
  [6176] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8481),
  [6178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(580),
  [6180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(637),
  [6182] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9958),
  [6184] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2770),
  [6186] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3873),
  [6188] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3880),
  [6190] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ref_expression, 2, 0, 0),
  [6192] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2057),
  [6194] = {.entry = {.count = 1, .reusable = false}}, SHIFT(720),
  [6196] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2058),
  [6198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2059),
  [6200] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2059),
  [6202] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2060),
  [6204] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2061),
  [6206] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2062),
  [6208] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2063),
  [6210] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2063),
  [6212] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2064),
  [6214] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2057),
  [6216] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9788),
  [6218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(271),
  [6220] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_ref_expression, 2, 0, 0),
  [6222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2065),
  [6224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2066),
  [6226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2067),
  [6228] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4840),
  [6230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(418),
  [6232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9791),
  [6234] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1506),
  [6236] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1506),
  [6238] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8571),
  [6240] = {.entry = {.count = 1, .reusable = true}}, SHIFT(578),
  [6242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(627),
  [6244] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2979),
  [6246] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2927),
  [6248] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2971),
  [6250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3003),
  [6252] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2793),
  [6254] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3086),
  [6256] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3524),
  [6258] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2997),
  [6260] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3187),
  [6262] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2925),
  [6264] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3091),
  [6266] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_select_clause, 2, 0, 0),
  [6268] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_select_clause, 2, 0, 0),
  [6270] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_group_clause, 4, 0, 0),
  [6272] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_group_clause, 4, 0, 0),
  [6274] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3080),
  [6276] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2957),
  [6278] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2922),
  [6280] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_declaration_repeat2, 2, 0, 0), SHIFT_REPEAT(4594),
  [6283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3438),
  [6285] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1578),
  [6287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1578),
  [6289] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2993),
  [6291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8432),
  [6293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(584),
  [6295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(624),
  [6297] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9954),
  [6299] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2896),
  [6301] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5147),
  [6303] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5321),
  [6305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5377),
  [6307] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3066),
  [6309] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_type, 1, 0, 0), SHIFT(690),
  [6312] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_type, 1, 0, 0), REDUCE(sym_array_creation_expression, 2, 17, 6), SHIFT(2898),
  [6316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3947),
  [6318] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2833),
  [6320] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_throw_expression, 2, 0, 0),
  [6322] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_throw_expression, 2, 0, 0),
  [6324] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assignment_expression, 3, 0, 24),
  [6326] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_assignment_expression, 3, 0, 24),
  [6328] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_range_expression, 3, 0, 0),
  [6330] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_range_expression, 3, 0, 0),
  [6332] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_relational_pattern, 2, 0, 0),
  [6334] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_relational_pattern, 2, 0, 0),
  [6336] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_conditional_expression, 5, 0, 65),
  [6338] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_conditional_expression, 5, 0, 65),
  [6340] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2924),
  [6342] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_binary_expression, 3, 0, 24),
  [6344] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_binary_expression, 3, 0, 24),
  [6346] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3609),
  [6348] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3011),
  [6350] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2774),
  [6352] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3071),
  [6354] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3331),
  [6356] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3897),
  [6358] = {.entry = {.count = 1, .reusable = true}}, SHIFT(579),
  [6360] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3006),
  [6362] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2943),
  [6364] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3664),
  [6366] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2989),
  [6368] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3905),
  [6370] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3998),
  [6372] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3075),
  [6374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3188),
  [6376] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2991),
  [6378] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2998),
  [6380] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3563),
  [6382] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1652),
  [6384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1652),
  [6386] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2884),
  [6388] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2019),
  [6390] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2020),
  [6392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2021),
  [6394] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2021),
  [6396] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2025),
  [6398] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2025),
  [6400] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2026),
  [6402] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2019),
  [6404] = {.entry = {.count = 1, .reusable = true}}, SHIFT(268),
  [6406] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4911),
  [6408] = {.entry = {.count = 1, .reusable = true}}, SHIFT(429),
  [6410] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1234),
  [6412] = {.entry = {.count = 1, .reusable = false}}, SHIFT(670),
  [6414] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1235),
  [6416] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1236),
  [6418] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1236),
  [6420] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1237),
  [6422] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1238),
  [6424] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1239),
  [6426] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1240),
  [6428] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1240),
  [6430] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1241),
  [6432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1234),
  [6434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9019),
  [6436] = {.entry = {.count = 1, .reusable = true}}, SHIFT(192),
  [6438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1242),
  [6440] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1243),
  [6442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1244),
  [6444] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4857),
  [6446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(380),
  [6448] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9020),
  [6450] = {.entry = {.count = 1, .reusable = false}}, SHIFT(701),
  [6452] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2022),
  [6454] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2023),
  [6456] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2024),
  [6458] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2027),
  [6460] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2028),
  [6462] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2029),
  [6464] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4714),
  [6466] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1556),
  [6468] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1556),
  [6470] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2087),
  [6472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2087),
  [6474] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__query_body, 1, 0, 0),
  [6476] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__query_body, 1, 0, 0),
  [6478] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7392),
  [6480] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__query_body, 2, 0, 0),
  [6482] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__query_body, 2, 0, 0),
  [6484] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__query_body_repeat2, 2, 0, 0),
  [6486] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__query_body_repeat2, 2, 0, 0),
  [6488] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__query_body_repeat2, 2, 0, 0), SHIFT_REPEAT(7392),
  [6491] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__query_body, 3, 0, 0),
  [6493] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__query_body, 3, 0, 0),
  [6495] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1869),
  [6497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1869),
  [6499] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1629),
  [6501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1629),
  [6503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4653),
  [6505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4637),
  [6507] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4567),
  [6509] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4783),
  [6511] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1775),
  [6513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1775),
  [6515] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7325),
  [6517] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7369),
  [6519] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_function_pointer_type_repeat1, 2, 0, 0), SHIFT_REPEAT(4513),
  [6522] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_function_pointer_type_repeat1, 2, 0, 0), SHIFT_REPEAT(4529),
  [6525] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_function_pointer_type_repeat1, 2, 0, 0), SHIFT_REPEAT(4604),
  [6528] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_function_pointer_type_repeat1, 2, 0, 0), SHIFT_REPEAT(5120),
  [6531] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_function_pointer_type_repeat1, 2, 0, 0), SHIFT_REPEAT(9356),
  [6534] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_function_pointer_type_repeat1, 2, 0, 0), SHIFT_REPEAT(5092),
  [6537] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_function_pointer_type_repeat1, 2, 0, 0), SHIFT_REPEAT(8341),
  [6540] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1830),
  [6542] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1830),
  [6544] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7346),
  [6546] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1313),
  [6548] = {.entry = {.count = 1, .reusable = false}}, SHIFT(692),
  [6550] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1314),
  [6552] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1315),
  [6554] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1315),
  [6556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1316),
  [6558] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1317),
  [6560] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1318),
  [6562] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1319),
  [6564] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1319),
  [6566] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1320),
  [6568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1313),
  [6570] = {.entry = {.count = 1, .reusable = true}}, SHIFT(299),
  [6572] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1321),
  [6574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1322),
  [6576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1323),
  [6578] = {.entry = {.count = 1, .reusable = true}}, SHIFT(384),
  [6580] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4727),
  [6582] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6580),
  [6584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4741),
  [6586] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4755),
  [6588] = {.entry = {.count = 1, .reusable = true}}, SHIFT(492),
  [6590] = {.entry = {.count = 1, .reusable = false}}, SHIFT(496),
  [6592] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_negated_pattern, 2, 0, 0),
  [6594] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_negated_pattern, 2, 0, 0),
  [6596] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4566),
  [6598] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4891),
  [6600] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5373),
  [6602] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4628),
  [6604] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4859),
  [6606] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7336),
  [6608] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4658),
  [6610] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4904),
  [6612] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5269),
  [6614] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7196),
  [6616] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4915),
  [6618] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4940),
  [6620] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4660),
  [6622] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4937),
  [6624] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4668),
  [6626] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4942),
  [6628] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4737),
  [6630] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4757),
  [6632] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4790),
  [6634] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4788),
  [6636] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3178),
  [6638] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3186),
  [6640] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4665),
  [6642] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9959),
  [6644] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2870),
  [6646] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3179),
  [6648] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3490),
  [6650] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4651),
  [6652] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4800),
  [6654] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4641),
  [6656] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4789),
  [6658] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4826),
  [6660] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2771),
  [6662] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4885),
  [6664] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4822),
  [6666] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4802),
  [6668] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4829),
  [6670] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4836),
  [6672] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4838),
  [6674] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__query_body_repeat2, 2, 0, 0), SHIFT_REPEAT(7336),
  [6677] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4845),
  [6679] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4849),
  [6681] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4766),
  [6683] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4870),
  [6685] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4854),
  [6687] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4861),
  [6689] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4860),
  [6691] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4866),
  [6693] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4873),
  [6695] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4882),
  [6697] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4812),
  [6699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4627),
  [6701] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4846),
  [6703] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2856),
  [6705] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_or_pattern, 3, 0, 24),
  [6707] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_or_pattern, 3, 0, 24),
  [6709] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4844),
  [6711] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4920),
  [6713] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4824),
  [6715] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4842),
  [6717] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4742),
  [6719] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4805),
  [6721] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5016),
  [6723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(222),
  [6725] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1178),
  [6727] = {.entry = {.count = 1, .reusable = false}}, SHIFT(730),
  [6729] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1179),
  [6731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1180),
  [6733] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1180),
  [6735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1181),
  [6737] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1182),
  [6739] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1183),
  [6741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1184),
  [6743] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1184),
  [6745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1185),
  [6747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1178),
  [6749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(323),
  [6751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1186),
  [6753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1187),
  [6755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1188),
  [6757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(385),
  [6759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(421),
  [6761] = {.entry = {.count = 1, .reusable = false}}, SHIFT(422),
  [6763] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2159),
  [6765] = {.entry = {.count = 1, .reusable = false}}, SHIFT(703),
  [6767] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2160),
  [6769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2161),
  [6771] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2161),
  [6773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2162),
  [6775] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2163),
  [6777] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2164),
  [6779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2165),
  [6781] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2165),
  [6783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2166),
  [6785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2159),
  [6787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9677),
  [6789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(294),
  [6791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2167),
  [6793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2168),
  [6795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2169),
  [6797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4759),
  [6799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(511),
  [6801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9691),
  [6803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4367),
  [6805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7378),
  [6807] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1200),
  [6809] = {.entry = {.count = 1, .reusable = false}}, SHIFT(722),
  [6811] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1201),
  [6813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1202),
  [6815] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1202),
  [6817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1203),
  [6819] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1204),
  [6821] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1205),
  [6823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1206),
  [6825] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1206),
  [6827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1207),
  [6829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1200),
  [6831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1208),
  [6833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1209),
  [6835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1210),
  [6837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4791),
  [6839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(501),
  [6841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(431),
  [6843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(432),
  [6845] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__ordering, 1, 0, 0),
  [6847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7698),
  [6849] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__query_body_repeat2, 2, 0, 0), SHIFT_REPEAT(7378),
  [6852] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__query_body_repeat2, 2, 0, 0), SHIFT_REPEAT(7335),
  [6855] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2000),
  [6857] = {.entry = {.count = 1, .reusable = false}}, SHIFT(716),
  [6859] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2001),
  [6861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2002),
  [6863] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2002),
  [6865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2003),
  [6867] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2004),
  [6869] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2005),
  [6871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2006),
  [6873] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2006),
  [6875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2007),
  [6877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2000),
  [6879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9643),
  [6881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(289),
  [6883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2009),
  [6885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2010),
  [6887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2011),
  [6889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4892),
  [6891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(399),
  [6893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9090),
  [6895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7335),
  [6897] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7186),
  [6899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7342),
  [6901] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__query_body_repeat2, 2, 0, 0), SHIFT_REPEAT(7342),
  [6904] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1430),
  [6906] = {.entry = {.count = 1, .reusable = false}}, SHIFT(693),
  [6908] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1431),
  [6910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1432),
  [6912] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1432),
  [6914] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1433),
  [6916] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1434),
  [6918] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1435),
  [6920] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1436),
  [6922] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1436),
  [6924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1437),
  [6926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1430),
  [6928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(351),
  [6930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1438),
  [6932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1439),
  [6934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1440),
  [6936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(417),
  [6938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(454),
  [6940] = {.entry = {.count = 1, .reusable = false}}, SHIFT(457),
  [6942] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__join_body, 4, 0, 0),
  [6944] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1371),
  [6946] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1372),
  [6948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1373),
  [6950] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1373),
  [6952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1374),
  [6954] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1375),
  [6956] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1376),
  [6958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1377),
  [6960] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1377),
  [6962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1378),
  [6964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1371),
  [6966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(231),
  [6968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(416),
  [6970] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1293),
  [6972] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1294),
  [6974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1295),
  [6976] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1295),
  [6978] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1298),
  [6980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1299),
  [6982] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1299),
  [6984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1300),
  [6986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1293),
  [6988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9836),
  [6990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(226),
  [6992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4883),
  [6994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(381),
  [6996] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9837),
  [6998] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1159),
  [7000] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_from_clause, 5, 0, 32),
  [7002] = {.entry = {.count = 1, .reusable = false}}, SHIFT(683),
  [7004] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1160),
  [7006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1161),
  [7008] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1161),
  [7010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1162),
  [7012] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1163),
  [7014] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1164),
  [7016] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1165),
  [7018] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1165),
  [7020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1166),
  [7022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1159),
  [7024] = {.entry = {.count = 1, .reusable = true}}, SHIFT(325),
  [7026] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1167),
  [7028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1168),
  [7030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1169),
  [7032] = {.entry = {.count = 1, .reusable = true}}, SHIFT(494),
  [7034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(395),
  [7036] = {.entry = {.count = 1, .reusable = false}}, SHIFT(699),
  [7038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1296),
  [7040] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1297),
  [7042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1301),
  [7044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1302),
  [7046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1303),
  [7048] = {.entry = {.count = 1, .reusable = false}}, SHIFT(406),
  [7050] = {.entry = {.count = 1, .reusable = true}}, SHIFT(601),
  [7052] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__simple_name, 1, 0, 0), SHIFT(4402),
  [7055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7225),
  [7057] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_where_clause, 2, 0, 0),
  [7059] = {.entry = {.count = 1, .reusable = false}}, SHIFT(673),
  [7061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1379),
  [7063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1380),
  [7065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1381),
  [7067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7313),
  [7069] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_from_clause, 4, 0, 15),
  [7071] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8341),
  [7073] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__query_body_repeat2, 2, 0, 0), SHIFT_REPEAT(7313),
  [7076] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_let_clause, 4, 0, 0),
  [7078] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1968),
  [7080] = {.entry = {.count = 1, .reusable = false}}, SHIFT(689),
  [7082] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1970),
  [7084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1973),
  [7086] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1973),
  [7088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1974),
  [7090] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1986),
  [7092] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1991),
  [7094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1993),
  [7096] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1993),
  [7098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1994),
  [7100] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1968),
  [7102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(229),
  [7104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1996),
  [7106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1997),
  [7108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2008),
  [7110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(493),
  [7112] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1492),
  [7114] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1493),
  [7116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1494),
  [7118] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1494),
  [7120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1495),
  [7122] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1496),
  [7124] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1497),
  [7126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1498),
  [7128] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1498),
  [7130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1499),
  [7132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1492),
  [7134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(233),
  [7136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1500),
  [7138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1501),
  [7140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1502),
  [7142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(394),
  [7144] = {.entry = {.count = 1, .reusable = false}}, SHIFT(665),
  [7146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(620),
  [7148] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5539),
  [7150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5539),
  [7152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(237),
  [7154] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2073),
  [7156] = {.entry = {.count = 1, .reusable = false}}, SHIFT(724),
  [7158] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2074),
  [7160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2075),
  [7162] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2075),
  [7164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2076),
  [7166] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2077),
  [7168] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2078),
  [7170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2079),
  [7172] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2079),
  [7174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2080),
  [7176] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2073),
  [7178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9539),
  [7180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2081),
  [7182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2082),
  [7184] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2083),
  [7186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4851),
  [7188] = {.entry = {.count = 1, .reusable = true}}, SHIFT(419),
  [7190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9540),
  [7192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9811),
  [7194] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8527),
  [7196] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9622),
  [7198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9656),
  [7200] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_type, 1, 0, 0), SHIFT(656),
  [7203] = {.entry = {.count = 3, .reusable = false}}, REDUCE(sym_type, 1, 0, 0), REDUCE(sym_array_creation_expression, 2, 17, 6), SHIFT(5357),
  [7207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9521),
  [7209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7334),
  [7211] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__query_body_repeat2, 2, 0, 0), SHIFT_REPEAT(7334),
  [7214] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9015),
  [7216] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9198),
  [7218] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1891),
  [7220] = {.entry = {.count = 1, .reusable = false}}, SHIFT(657),
  [7222] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2013),
  [7224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2018),
  [7226] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2018),
  [7228] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2033),
  [7230] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2090),
  [7232] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2108),
  [7234] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2121),
  [7236] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2121),
  [7238] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2125),
  [7240] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1891),
  [7242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(255),
  [7244] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2129),
  [7246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2130),
  [7248] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2131),
  [7250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4888),
  [7252] = {.entry = {.count = 1, .reusable = true}}, SHIFT(390),
  [7254] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4313),
  [7256] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1599),
  [7258] = {.entry = {.count = 1, .reusable = false}}, SHIFT(707),
  [7260] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1600),
  [7262] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1601),
  [7264] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1601),
  [7266] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1602),
  [7268] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1603),
  [7270] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1604),
  [7272] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1605),
  [7274] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1605),
  [7276] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1606),
  [7278] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1599),
  [7280] = {.entry = {.count = 1, .reusable = true}}, SHIFT(253),
  [7282] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1607),
  [7284] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1608),
  [7286] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1609),
  [7288] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4869),
  [7290] = {.entry = {.count = 1, .reusable = true}}, SHIFT(443),
  [7292] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1334),
  [7294] = {.entry = {.count = 1, .reusable = false}}, SHIFT(659),
  [7296] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1335),
  [7298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1336),
  [7300] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1336),
  [7302] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1337),
  [7304] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1338),
  [7306] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1339),
  [7308] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1340),
  [7310] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1340),
  [7312] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1341),
  [7314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1334),
  [7316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(241),
  [7318] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1342),
  [7320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1343),
  [7322] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1344),
  [7324] = {.entry = {.count = 1, .reusable = true}}, SHIFT(428),
  [7326] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1448),
  [7328] = {.entry = {.count = 1, .reusable = false}}, SHIFT(705),
  [7330] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1449),
  [7332] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1450),
  [7334] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1450),
  [7336] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1451),
  [7338] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1452),
  [7340] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1453),
  [7342] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1454),
  [7344] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1454),
  [7346] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1455),
  [7348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1448),
  [7350] = {.entry = {.count = 1, .reusable = true}}, SHIFT(278),
  [7352] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1456),
  [7354] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1457),
  [7356] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1458),
  [7358] = {.entry = {.count = 1, .reusable = true}}, SHIFT(391),
  [7360] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_type, 1, 0, 0), SHIFT(5357),
  [7363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7230),
  [7365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(510),
  [7367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3671),
  [7369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(491),
  [7371] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7229),
  [7373] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2038),
  [7375] = {.entry = {.count = 1, .reusable = false}}, SHIFT(702),
  [7377] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2039),
  [7379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2040),
  [7381] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2040),
  [7383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2041),
  [7385] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2042),
  [7387] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2043),
  [7389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2044),
  [7391] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2044),
  [7393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2045),
  [7395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2038),
  [7397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(235),
  [7399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2046),
  [7401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2047),
  [7403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2048),
  [7405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4761),
  [7407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(438),
  [7409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5588),
  [7411] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__array_base_type, 1, 0, 0),
  [7413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2898),
  [7415] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__pointer_base_type, 1, 0, 0),
  [7417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(497),
  [7419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(500),
  [7421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9536),
  [7423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1349),
  [7425] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1217),
  [7427] = {.entry = {.count = 1, .reusable = false}}, SHIFT(694),
  [7429] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1218),
  [7431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1219),
  [7433] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1219),
  [7435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1220),
  [7437] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1221),
  [7439] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1222),
  [7441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1223),
  [7443] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1223),
  [7445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1224),
  [7447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1217),
  [7449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(261),
  [7451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1225),
  [7453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1226),
  [7455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1227),
  [7457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(502),
  [7459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8292),
  [7461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3738),
  [7463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4381),
  [7465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7199),
  [7467] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3165),
  [7469] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3145),
  [7471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(224),
  [7473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5565),
  [7475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4738),
  [7477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7252),
  [7479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5731),
  [7481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5751),
  [7483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3972),
  [7485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7333),
  [7487] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__query_body_repeat2, 2, 0, 0), SHIFT_REPEAT(7333),
  [7490] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_elif_in_expression, 4, 0, 39),
  [7492] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1674),
  [7494] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1675),
  [7496] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1676),
  [7498] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1676),
  [7500] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1680),
  [7502] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1680),
  [7504] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1681),
  [7506] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1674),
  [7508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(280),
  [7510] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4879),
  [7512] = {.entry = {.count = 1, .reusable = true}}, SHIFT(452),
  [7514] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1390),
  [7516] = {.entry = {.count = 1, .reusable = false}}, SHIFT(708),
  [7518] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1392),
  [7520] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1393),
  [7522] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1393),
  [7524] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1394),
  [7526] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1395),
  [7528] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1396),
  [7530] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1397),
  [7532] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1397),
  [7534] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1398),
  [7536] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1390),
  [7538] = {.entry = {.count = 1, .reusable = true}}, SHIFT(242),
  [7540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1399),
  [7542] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1400),
  [7544] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1401),
  [7546] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1413),
  [7548] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1414),
  [7550] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1414),
  [7552] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1418),
  [7554] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1418),
  [7556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(250),
  [7558] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1412),
  [7560] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1417),
  [7562] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1419),
  [7564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1412),
  [7566] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4827),
  [7568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(498),
  [7570] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1415),
  [7572] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1416),
  [7574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1420),
  [7576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1151),
  [7578] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1421),
  [7580] = {.entry = {.count = 1, .reusable = false}}, SHIFT(725),
  [7582] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1352),
  [7584] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1353),
  [7586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1354),
  [7588] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1354),
  [7590] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1357),
  [7592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1358),
  [7594] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1358),
  [7596] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1359),
  [7598] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1352),
  [7600] = {.entry = {.count = 1, .reusable = true}}, SHIFT(262),
  [7602] = {.entry = {.count = 1, .reusable = true}}, SHIFT(400),
  [7604] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1355),
  [7606] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1356),
  [7608] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1360),
  [7610] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1361),
  [7612] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1362),
  [7614] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2202),
  [7616] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1527),
  [7618] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1528),
  [7620] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1528),
  [7622] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1531),
  [7624] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1532),
  [7626] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1532),
  [7628] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1533),
  [7630] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2202),
  [7632] = {.entry = {.count = 1, .reusable = true}}, SHIFT(291),
  [7634] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4877),
  [7636] = {.entry = {.count = 1, .reusable = true}}, SHIFT(449),
  [7638] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1529),
  [7640] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1530),
  [7642] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1534),
  [7644] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1535),
  [7646] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1536),
  [7648] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2290),
  [7650] = {.entry = {.count = 1, .reusable = true}}, SHIFT(504),
  [7652] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1036),
  [7654] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3775),
  [7656] = {.entry = {.count = 1, .reusable = false}}, SHIFT(700),
  [7658] = {.entry = {.count = 1, .reusable = true}}, SHIFT(244),
  [7660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4887),
  [7662] = {.entry = {.count = 1, .reusable = true}}, SHIFT(473),
  [7664] = {.entry = {.count = 1, .reusable = true}}, SHIFT(495),
  [7666] = {.entry = {.count = 1, .reusable = true}}, SHIFT(408),
  [7668] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1258),
  [7670] = {.entry = {.count = 1, .reusable = false}}, SHIFT(698),
  [7672] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1259),
  [7674] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1260),
  [7676] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1260),
  [7678] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1261),
  [7680] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1262),
  [7682] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1263),
  [7684] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1264),
  [7686] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1264),
  [7688] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1265),
  [7690] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1258),
  [7692] = {.entry = {.count = 1, .reusable = true}}, SHIFT(239),
  [7694] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1266),
  [7696] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1267),
  [7698] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1268),
  [7700] = {.entry = {.count = 1, .reusable = true}}, SHIFT(460),
  [7702] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1565),
  [7704] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1566),
  [7706] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1566),
  [7708] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1570),
  [7710] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1570),
  [7712] = {.entry = {.count = 1, .reusable = true}}, SHIFT(258),
  [7714] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1564),
  [7716] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1569),
  [7718] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1571),
  [7720] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1564),
  [7722] = {.entry = {.count = 1, .reusable = true}}, SHIFT(434),
  [7724] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1567),
  [7726] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1568),
  [7728] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1572),
  [7730] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1573),
  [7732] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1574),
  [7734] = {.entry = {.count = 1, .reusable = false}}, SHIFT(704),
  [7736] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7207),
  [7738] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1693),
  [7740] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1694),
  [7742] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1694),
  [7744] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1698),
  [7746] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1698),
  [7748] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1692),
  [7750] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1697),
  [7752] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1699),
  [7754] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1692),
  [7756] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1695),
  [7758] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1696),
  [7760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1700),
  [7762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1701),
  [7764] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1702),
  [7766] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4807),
  [7768] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1747),
  [7770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1748),
  [7772] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1748),
  [7774] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1752),
  [7776] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1752),
  [7778] = {.entry = {.count = 1, .reusable = true}}, SHIFT(283),
  [7780] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1802),
  [7782] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1803),
  [7784] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1803),
  [7786] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1807),
  [7788] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1807),
  [7790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(264),
  [7792] = {.entry = {.count = 1, .reusable = false}}, SHIFT(697),
  [7794] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7343),
  [7796] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__query_body_repeat2, 2, 0, 0), SHIFT_REPEAT(7343),
  [7799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(379),
  [7801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(382),
  [7803] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1801),
  [7805] = {.entry = {.count = 1, .reusable = false}}, SHIFT(655),
  [7807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1804),
  [7809] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1805),
  [7811] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1806),
  [7813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1808),
  [7815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1801),
  [7817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1809),
  [7819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1810),
  [7821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1811),
  [7823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(462),
  [7825] = {.entry = {.count = 1, .reusable = false}}, SHIFT(729),
  [7827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(478),
  [7829] = {.entry = {.count = 1, .reusable = false}}, SHIFT(647),
  [7831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1677),
  [7833] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1678),
  [7835] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1679),
  [7837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1682),
  [7839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1683),
  [7841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1684),
  [7843] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1746),
  [7845] = {.entry = {.count = 1, .reusable = false}}, SHIFT(651),
  [7847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1749),
  [7849] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1750),
  [7851] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1751),
  [7853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1753),
  [7855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1746),
  [7857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1754),
  [7859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1755),
  [7861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1756),
  [7863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4881),
  [7865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(455),
  [7867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(479),
  [7869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7395),
  [7871] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__query_body_repeat2, 2, 0, 0), SHIFT_REPEAT(7395),
  [7874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7387),
  [7876] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__query_body_repeat2, 2, 0, 0), SHIFT_REPEAT(7387),
  [7879] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1875),
  [7881] = {.entry = {.count = 1, .reusable = false}}, SHIFT(660),
  [7883] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1876),
  [7885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1877),
  [7887] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1877),
  [7889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1878),
  [7891] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1879),
  [7893] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1880),
  [7895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1881),
  [7897] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1881),
  [7899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1882),
  [7901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1875),
  [7903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(266),
  [7905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1883),
  [7907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1884),
  [7909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1885),
  [7911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(458),
  [7913] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0),
  [7915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(470),
  [7917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3881),
  [7919] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_tuple_element, 1, 0, 5), REDUCE(sym_type_pattern, 1, 0, 5),
  [7922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2068),
  [7924] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1783),
  [7926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1784),
  [7928] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1784),
  [7930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1788),
  [7932] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1788),
  [7934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(285),
  [7936] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1782),
  [7938] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1787),
  [7940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1789),
  [7942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1782),
  [7944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4875),
  [7946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(453),
  [7948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1785),
  [7950] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1786),
  [7952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1790),
  [7954] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1791),
  [7956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1792),
  [7958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7306),
  [7960] = {.entry = {.count = 1, .reusable = false}}, SHIFT(654),
  [7962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1278),
  [7964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(157),
  [7966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(158),
  [7968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5353),
  [7970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1538),
  [7972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1021),
  [7974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5547),
  [7976] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1837),
  [7978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1838),
  [7980] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1838),
  [7982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1842),
  [7984] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1842),
  [7986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(288),
  [7988] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1836),
  [7990] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1841),
  [7992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1843),
  [7994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1836),
  [7996] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4876),
  [7998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(456),
  [8000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1839),
  [8002] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1840),
  [8004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1844),
  [8006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1845),
  [8008] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1846),
  [8010] = {.entry = {.count = 1, .reusable = false}}, SHIFT(658),
  [8012] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_argument, 4, 0, 4),
  [8014] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter, 4, 0, 13),
  [8016] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter, 4, 0, 15),
  [8018] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1016),
  [8020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4318),
  [8022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(109),
  [8024] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5354),
  [8026] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2050),
  [8028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2084),
  [8030] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__query_body_repeat2, 2, 0, 0), SHIFT_REPEAT(7306),
  [8033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(101),
  [8035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1461),
  [8037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1686),
  [8039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1025),
  [8041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4586),
  [8043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1758),
  [8045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2690),
  [8047] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1468),
  [8049] = {.entry = {.count = 1, .reusable = false}}, SHIFT(713),
  [8051] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1469),
  [8053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1470),
  [8055] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1470),
  [8057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1471),
  [8059] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1472),
  [8061] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1473),
  [8063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1474),
  [8065] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1474),
  [8067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1475),
  [8069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1468),
  [8071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(251),
  [8073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1476),
  [8075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1477),
  [8077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1478),
  [8079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1611),
  [8081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1813),
  [8083] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_argument, 2, 0, 0),
  [8085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3694),
  [8087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(110),
  [8089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3598),
  [8091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1304),
  [8093] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter, 6, 0, 49),
  [8095] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7181),
  [8097] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1979),
  [8099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1980),
  [8101] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1980),
  [8103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1984),
  [8105] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1984),
  [8107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(270),
  [8109] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1978),
  [8111] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1983),
  [8113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1985),
  [8115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1978),
  [8117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4784),
  [8119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(375),
  [8121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1981),
  [8123] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1982),
  [8125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1987),
  [8127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1988),
  [8129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1989),
  [8131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2014),
  [8133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(65),
  [8135] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_member_declaration, 3, 0, 74),
  [8137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(71),
  [8139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(72),
  [8141] = {.entry = {.count = 1, .reusable = false}}, SHIFT(646),
  [8143] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_member_declaration, 4, 0, 101),
  [8145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(79),
  [8147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(80),
  [8149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(85),
  [8151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1246),
  [8153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(125),
  [8155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(102),
  [8157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1117),
  [8159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4019),
  [8161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4055),
  [8163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1383),
  [8165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1422),
  [8167] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1638),
  [8169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1639),
  [8171] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1639),
  [8173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1643),
  [8175] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1643),
  [8177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(246),
  [8179] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1637),
  [8181] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1642),
  [8183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1644),
  [8185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1637),
  [8187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(444),
  [8189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1640),
  [8191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(167),
  [8193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(168),
  [8195] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1641),
  [8197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1645),
  [8199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1646),
  [8201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1647),
  [8203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(908),
  [8205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1257),
  [8207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1503),
  [8209] = {.entry = {.count = 1, .reusable = false}}, SHIFT(726),
  [8211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(131),
  [8213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(132),
  [8215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(474),
  [8217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(388),
  [8219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1575),
  [8221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(439),
  [8223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3240),
  [8225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(139),
  [8227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(140),
  [8229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(145),
  [8231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2052),
  [8233] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_argument, 1, 0, 0),
  [8235] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_argument, 3, 0, 4),
  [8237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1648),
  [8239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(115),
  [8241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(389),
  [8243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1721),
  [8245] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1710),
  [8247] = {.entry = {.count = 1, .reusable = false}}, SHIFT(650),
  [8249] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1711),
  [8251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1712),
  [8253] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1712),
  [8255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1713),
  [8257] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1714),
  [8259] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1715),
  [8261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1716),
  [8263] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1716),
  [8265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1717),
  [8267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1710),
  [8269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(279),
  [8271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1718),
  [8273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1719),
  [8275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1720),
  [8277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4862),
  [8279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(450),
  [8281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2170),
  [8283] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter, 3, 0, 4),
  [8285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1793),
  [8287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1847),
  [8289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1886),
  [8291] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter, 5, 0, 32),
  [8293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(440),
  [8295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(174),
  [8297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(946),
  [8299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3665),
  [8301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(928),
  [8303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1992),
  [8305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2947),
  [8307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1006),
  [8309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1022),
  [8311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7398),
  [8313] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__query_body_repeat2, 2, 0, 0), SHIFT_REPEAT(7398),
  [8316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2030),
  [8318] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7308),
  [8320] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__query_body_repeat2, 2, 0, 0), SHIFT_REPEAT(7308),
  [8323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7307),
  [8325] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__query_body_repeat2, 2, 0, 0), SHIFT_REPEAT(7307),
  [8328] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7323),
  [8330] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__query_body_repeat2, 2, 0, 0), SHIFT_REPEAT(7323),
  [8333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(95),
  [8335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(149),
  [8337] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7808),
  [8339] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7798),
  [8341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6127),
  [8343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6131),
  [8345] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8106),
  [8347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8886),
  [8349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8240),
  [8351] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1656),
  [8353] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1657),
  [8355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1658),
  [8357] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1658),
  [8359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1659),
  [8361] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1660),
  [8363] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1661),
  [8365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1662),
  [8367] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1662),
  [8369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1663),
  [8371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1656),
  [8373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(341),
  [8375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1664),
  [8377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1665),
  [8379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1666),
  [8381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4874),
  [8383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(436),
  [8385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6195),
  [8387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6205),
  [8389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8247),
  [8391] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1509),
  [8393] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1510),
  [8395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1511),
  [8397] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1511),
  [8399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1512),
  [8401] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1513),
  [8403] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1514),
  [8405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1515),
  [8407] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1515),
  [8409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1516),
  [8411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1509),
  [8413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(328),
  [8415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1517),
  [8417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1518),
  [8419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1519),
  [8421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4848),
  [8423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(423),
  [8425] = {.entry = {.count = 1, .reusable = false}}, SHIFT(723),
  [8427] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1582),
  [8429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1583),
  [8431] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1583),
  [8433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(333),
  [8435] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1581),
  [8437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1587),
  [8439] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1587),
  [8441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1581),
  [8443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4872),
  [8445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(427),
  [8447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1584),
  [8449] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1585),
  [8451] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1586),
  [8453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1588),
  [8455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6839),
  [8457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1589),
  [8459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1590),
  [8461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1591),
  [8463] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1728),
  [8465] = {.entry = {.count = 1, .reusable = false}}, SHIFT(653),
  [8467] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1729),
  [8469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1730),
  [8471] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1730),
  [8473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1731),
  [8475] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1732),
  [8477] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1733),
  [8479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1734),
  [8481] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1734),
  [8483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1735),
  [8485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1728),
  [8487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(306),
  [8489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1736),
  [8491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1737),
  [8493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1738),
  [8495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(404),
  [8497] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_switch_expression_arm, 3, 0, 0),
  [8499] = {.entry = {.count = 1, .reusable = false}}, SHIFT(645),
  [8501] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(5590),
  [8504] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_declarator, 3, 0, 0),
  [8506] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interpolation_alignment_clause, 2, 0, 0),
  [8508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(414),
  [8510] = {.entry = {.count = 1, .reusable = true}}, SHIFT(480),
  [8512] = {.entry = {.count = 1, .reusable = true}}, SHIFT(484),
  [8514] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_declarator, 3, 0, 4),
  [8516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(225),
  [8518] = {.entry = {.count = 1, .reusable = true}}, SHIFT(445),
  [8520] = {.entry = {.count = 1, .reusable = true}}, SHIFT(448),
  [8522] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attribute_argument, 1, 0, 0),
  [8524] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_with_initializer, 3, 0, 0),
  [8526] = {.entry = {.count = 1, .reusable = true}}, SHIFT(463),
  [8528] = {.entry = {.count = 1, .reusable = true}}, SHIFT(485),
  [8530] = {.entry = {.count = 1, .reusable = false}}, SHIFT(649),
  [8532] = {.entry = {.count = 1, .reusable = true}}, SHIFT(481),
  [8534] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_using_variable_declarator, 3, 0, 4),
  [8536] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__anonymous_object_member_declarator, 3, 0, 0),
  [8538] = {.entry = {.count = 1, .reusable = true}}, SHIFT(483),
  [8540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(415),
  [8542] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_array_rank_specifier_repeat1, 2, 0, 0),
  [8544] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7268),
  [8546] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7238),
  [8548] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_declarator, 4, 0, 0),
  [8550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8729),
  [8552] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attribute_argument, 3, 0, 0),
  [8554] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_declarator, 4, 0, 4),
  [8556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7274),
  [8558] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__anonymous_object_member_declarator, 1, 0, 0),
  [8560] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8919),
  [8562] = {.entry = {.count = 1, .reusable = true}}, SHIFT(433),
  [8564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(487),
  [8566] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7214),
  [8568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2283),
  [8570] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_switch_expression_arm, 4, 0, 0),
  [8572] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8953),
  [8574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8842),
  [8576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(82),
  [8578] = {.entry = {.count = 1, .reusable = true}}, SHIFT(437),
  [8580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(441),
  [8582] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1618),
  [8584] = {.entry = {.count = 1, .reusable = false}}, SHIFT(640),
  [8586] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1619),
  [8588] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1620),
  [8590] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1620),
  [8592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1621),
  [8594] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1622),
  [8596] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1623),
  [8598] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1624),
  [8600] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1624),
  [8602] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1625),
  [8604] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1618),
  [8606] = {.entry = {.count = 1, .reusable = true}}, SHIFT(336),
  [8608] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1626),
  [8610] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1627),
  [8612] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1628),
  [8614] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4762),
  [8616] = {.entry = {.count = 1, .reusable = true}}, SHIFT(386),
  [8618] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1859),
  [8620] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1860),
  [8622] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1860),
  [8624] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1864),
  [8626] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1864),
  [8628] = {.entry = {.count = 1, .reusable = true}}, SHIFT(298),
  [8630] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1524),
  [8632] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1545),
  [8634] = {.entry = {.count = 1, .reusable = false}}, SHIFT(664),
  [8636] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1546),
  [8638] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1547),
  [8640] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1547),
  [8642] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1548),
  [8644] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1549),
  [8646] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1550),
  [8648] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1551),
  [8650] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1551),
  [8652] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1552),
  [8654] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1545),
  [8656] = {.entry = {.count = 1, .reusable = true}}, SHIFT(300),
  [8658] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1553),
  [8660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1554),
  [8662] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1555),
  [8664] = {.entry = {.count = 1, .reusable = true}}, SHIFT(499),
  [8666] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1858),
  [8668] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1863),
  [8670] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1865),
  [8672] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1858),
  [8674] = {.entry = {.count = 1, .reusable = true}}, SHIFT(447),
  [8676] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1861),
  [8678] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1862),
  [8680] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1866),
  [8682] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1867),
  [8684] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1868),
  [8686] = {.entry = {.count = 1, .reusable = false}}, SHIFT(721),
  [8688] = {.entry = {.count = 1, .reusable = true}}, SHIFT(376),
  [8690] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1194),
  [8692] = {.entry = {.count = 1, .reusable = true}}, SHIFT(112),
  [8694] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1033),
  [8696] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7222),
  [8698] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3750),
  [8700] = {.entry = {.count = 1, .reusable = true}}, SHIFT(147),
  [8702] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2678),
  [8704] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1429),
  [8706] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3423),
  [8708] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1310),
  [8710] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3650),
  [8712] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2686),
  [8714] = {.entry = {.count = 1, .reusable = true}}, SHIFT(148),
  [8716] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1508),
  [8718] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2448),
  [8720] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1764),
  [8722] = {.entry = {.count = 1, .reusable = false}}, SHIFT(717),
  [8724] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1765),
  [8726] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1766),
  [8728] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1766),
  [8730] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1767),
  [8732] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1768),
  [8734] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1769),
  [8736] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1770),
  [8738] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1770),
  [8740] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1771),
  [8742] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1764),
  [8744] = {.entry = {.count = 1, .reusable = true}}, SHIFT(345),
  [8746] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1772),
  [8748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1773),
  [8750] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1774),
  [8752] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1491),
  [8754] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4801),
  [8756] = {.entry = {.count = 1, .reusable = true}}, SHIFT(411),
  [8758] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1348),
  [8760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1596),
  [8762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1671),
  [8764] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1247),
  [8766] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1743),
  [8768] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1384),
  [8770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(177),
  [8772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1462),
  [8774] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1580),
  [8776] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1655),
  [8778] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1539),
  [8780] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1727),
  [8782] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1798),
  [8784] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1853),
  [8786] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1612),
  [8788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1890),
  [8790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1687),
  [8792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4690),
  [8794] = {.entry = {.count = 1, .reusable = true}}, SHIFT(179),
  [8796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1759),
  [8798] = {.entry = {.count = 1, .reusable = true}}, SHIFT(61),
  [8800] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2701),
  [8802] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1814),
  [8804] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2705),
  [8806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(62),
  [8808] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4705),
  [8810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4707),
  [8812] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2132),
  [8814] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1819),
  [8816] = {.entry = {.count = 1, .reusable = false}}, SHIFT(719),
  [8818] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1820),
  [8820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1821),
  [8822] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1821),
  [8824] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1822),
  [8826] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1823),
  [8828] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1824),
  [8830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1825),
  [8832] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1825),
  [8834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1826),
  [8836] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1819),
  [8838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(349),
  [8840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1827),
  [8842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1828),
  [8844] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1829),
  [8846] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__join_header, 3, 0, 0),
  [8848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4830),
  [8850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(425),
  [8852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(124),
  [8854] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2443),
  [8856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4076),
  [8858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2151),
  [8860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2483),
  [8862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1281),
  [8864] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2133),
  [8866] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2134),
  [8868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2135),
  [8870] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2135),
  [8872] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2138),
  [8874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2139),
  [8876] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2139),
  [8878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2140),
  [8880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2133),
  [8882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(313),
  [8884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(482),
  [8886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2136),
  [8888] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2137),
  [8890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2141),
  [8892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2142),
  [8894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2143),
  [8896] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1283),
  [8898] = {.entry = {.count = 1, .reusable = false}}, SHIFT(715),
  [8900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1113),
  [8902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9889),
  [8904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1138),
  [8906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(464),
  [8908] = {.entry = {.count = 1, .reusable = true}}, SHIFT(737),
  [8910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(64),
  [8912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1366),
  [8914] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7148),
  [8916] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7400),
  [8918] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8782),
  [8920] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1331),
  [8922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1274),
  [8924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(183),
  [8926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4108),
  [8928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4115),
  [8930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(397),
  [8932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4118),
  [8934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1214),
  [8936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(75),
  [8938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2444),
  [8940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(76),
  [8942] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_when_clause, 2, 0, 0),
  [8944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1995),
  [8946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(152),
  [8948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2016),
  [8950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(164),
  [8952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(163),
  [8954] = {.entry = {.count = 1, .reusable = true}}, SHIFT(128),
  [8956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2035),
  [8958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2051),
  [8960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(402),
  [8962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2056),
  [8964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2072),
  [8966] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_attribute, 1, 0, 4), REDUCE(sym_type, 1, 0, 0),
  [8969] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_type, 1, 0, 0), SHIFT(672),
  [8972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(507),
  [8974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1408),
  [8976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(405),
  [8978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(407),
  [8980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1410),
  [8982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1029),
  [8984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1404),
  [8986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9075),
  [8988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1079),
  [8990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1093),
  [8992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3398),
  [8994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3436),
  [8996] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3757),
  [8998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(135),
  [9000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3758),
  [9002] = {.entry = {.count = 1, .reusable = true}}, SHIFT(136),
  [9004] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7405),
  [9006] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8940),
  [9008] = {.entry = {.count = 1, .reusable = true}}, SHIFT(171),
  [9010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(142),
  [9012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1486),
  [9014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(508),
  [9016] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1488),
  [9018] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7302),
  [9020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4933),
  [9022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1125),
  [9024] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__query_body_repeat2, 2, 0, 0), SHIFT_REPEAT(7302),
  [9027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9899),
  [9029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(739),
  [9031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(771),
  [9033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5546),
  [9035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1328),
  [9037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2286),
  [9039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1561),
  [9041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(410),
  [9043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1563),
  [9045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1634),
  [9047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4150),
  [9049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1635),
  [9051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(105),
  [9053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(106),
  [9055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3416),
  [9057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(118),
  [9059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1708),
  [9061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(377),
  [9063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1709),
  [9065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5570),
  [9067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3339),
  [9069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1779),
  [9071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(398),
  [9073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1780),
  [9075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9115),
  [9077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1834),
  [9079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1835),
  [9081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(120),
  [9083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(901),
  [9085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1873),
  [9087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1874),
  [9089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(773),
  [9091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(121),
  [9093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(24),
  [9095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1897),
  [9097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1901),
  [9099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2091),
  [9101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1905),
  [9103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1909),
  [9105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9430),
  [9107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1913),
  [9109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2297),
  [9111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(161),
  [9113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(162),
  [9115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1917),
  [9117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1290),
  [9119] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7401),
  [9121] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8824),
  [9123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4581),
  [9125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8863),
  [9127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8888),
  [9129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1445),
  [9131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1969),
  [9133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4797),
  [9135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(88),
  [9137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1971),
  [9139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3663),
  [9141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(90),
  [9143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2150),
  [9145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(91),
  [9147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8751),
  [9149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8757),
  [9151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(92),
  [9153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3711),
  [9155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3713),
  [9157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2302),
  [9159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1173),
  [9161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(154),
  [9163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(122),
  [9165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5575),
  [9167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2158),
  [9169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2154),
  [9171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5576),
  [9173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7360),
  [9175] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__query_body_repeat2, 2, 0, 0), SHIFT_REPEAT(7360),
  [9178] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_else_in_expression, 2, 0, 0),
  [9180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2103),
  [9182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4796),
  [9184] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2105),
  [9186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7379),
  [9188] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__query_body_repeat2, 2, 0, 0), SHIFT_REPEAT(7379),
  [9191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(94),
  [9193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2117),
  [9195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4814),
  [9197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2118),
  [9199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4013),
  [9201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4017),
  [9203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4020),
  [9205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7389),
  [9207] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__query_body_repeat2, 2, 0, 0), SHIFT_REPEAT(7389),
  [9210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4823),
  [9212] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1231),
  [9214] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4828),
  [9216] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__join_header, 4, 0, 5),
  [9218] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arrow_expression_clause, 2, 0, 0),
  [9220] = {.entry = {.count = 1, .reusable = true}}, SHIFT(98),
  [9222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3390),
  [9224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2147),
  [9226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7190),
  [9228] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7249),
  [9230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7248),
  [9232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7245),
  [9234] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7235),
  [9236] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7258),
  [9238] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1249),
  [9240] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter, 2, 0, 15),
  [9242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2499),
  [9244] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1249),
  [9246] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_name, 1, 0, 0), SHIFT(3629),
  [9249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1175),
  [9251] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_parameter, 1, 0, 4), SHIFT(7164),
  [9254] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_parameter, 1, 0, 4), SHIFT(7939),
  [9257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8810),
  [9259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6834),
  [9261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6125),
  [9263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8795),
  [9265] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_elif_in_enum_member_declaration, 3, 0, 39),
  [9267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7279),
  [9269] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter, 1, 0, 4),
  [9271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7188),
  [9273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7276),
  [9275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7289),
  [9277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4794),
  [9279] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__simple_name, 1, 0, 0), SHIFT(7164),
  [9282] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7939),
  [9284] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7270),
  [9286] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7197),
  [9288] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4912),
  [9290] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6784),
  [9292] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9600),
  [9294] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9601),
  [9296] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6269),
  [9298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7291),
  [9300] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4442),
  [9302] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3779),
  [9304] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3746),
  [9306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2424),
  [9308] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6745),
  [9310] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6852),
  [9312] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6828),
  [9314] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attribute, 1, 0, 4),
  [9316] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6835),
  [9318] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6816),
  [9320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4493),
  [9322] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7292),
  [9324] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4455),
  [9326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9729),
  [9328] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4687),
  [9330] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2540),
  [9332] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7299),
  [9334] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6849),
  [9336] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6809),
  [9338] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4403),
  [9340] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4723),
  [9342] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4472),
  [9344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2642),
  [9346] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2423),
  [9348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6702),
  [9350] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9871),
  [9352] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6739),
  [9354] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6875),
  [9356] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6815),
  [9358] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__parameter_type_with_modifiers_repeat1, 2, 0, 0),
  [9360] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__parameter_type_with_modifiers_repeat1, 2, 0, 0),
  [9362] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__parameter_type_with_modifiers_repeat1, 2, 0, 0), SHIFT_REPEAT(6823),
  [9365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4467),
  [9367] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4591),
  [9369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3786),
  [9371] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6868),
  [9373] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1329),
  [9375] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6855),
  [9377] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6844),
  [9379] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1193),
  [9381] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6879),
  [9383] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tuple_element, 1, 0, 5),
  [9385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3629),
  [9387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1871),
  [9389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5429),
  [9391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1405),
  [9393] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_else_in_enum_member_declaration, 1, 0, 0),
  [9395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1271),
  [9397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1365),
  [9399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4130),
  [9401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1174),
  [9403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1171),
  [9405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4082),
  [9407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1229),
  [9409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1441),
  [9411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1739),
  [9413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3580),
  [9415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1777),
  [9417] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7331),
  [9419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(308),
  [9421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1212),
  [9423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1190),
  [9425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1520),
  [9427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1346),
  [9429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1832),
  [9431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1705),
  [9433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5029),
  [9435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7260),
  [9437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4610),
  [9439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1631),
  [9441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1592),
  [9443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1325),
  [9445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1667),
  [9447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1558),
  [9449] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_lambda_expression_repeat1, 2, 0, 0),
  [9451] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_lambda_expression_repeat1, 2, 0, 0), SHIFT_REPEAT(6923),
  [9454] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_lambda_expression_repeat1, 2, 0, 0),
  [9456] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2145),
  [9458] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1482),
  [9460] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7256),
  [9462] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7223),
  [9464] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7286),
  [9466] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7191),
  [9468] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7173),
  [9470] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7233),
  [9472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7187),
  [9474] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7241),
  [9476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7215),
  [9478] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7224),
  [9480] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_lambda_expression_repeat1, 1, 0, 1),
  [9482] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_lambda_expression_repeat1, 1, 0, 1),
  [9484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7183),
  [9486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7216),
  [9488] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7239),
  [9490] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7185),
  [9492] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7202),
  [9494] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7263),
  [9496] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_explicit_interface_specifier, 2, 0, 0), SHIFT(2744),
  [9499] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_explicit_interface_specifier, 2, 0, 0), SHIFT(2743),
  [9502] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_explicit_interface_specifier, 2, 0, 0),
  [9504] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7269),
  [9506] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2426),
  [9508] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_function_pointer_type_repeat1, 2, 0, 0),
  [9510] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_function_pointer_type_repeat1, 2, 0, 0),
  [9512] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2593),
  [9514] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7265),
  [9516] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8988),
  [9518] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8622),
  [9520] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7192),
  [9522] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7172),
  [9524] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(5468),
  [9527] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8873),
  [9529] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7317),
  [9531] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3210),
  [9533] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3221),
  [9535] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2825),
  [9537] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2820),
  [9539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3778),
  [9541] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7327),
  [9543] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3019),
  [9545] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3009),
  [9547] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7344),
  [9549] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2812),
  [9551] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2816),
  [9553] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7402),
  [9555] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8914),
  [9557] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6711),
  [9559] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6710),
  [9561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3636),
  [9563] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7355),
  [9565] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7403),
  [9567] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8942),
  [9569] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3386),
  [9571] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3385),
  [9573] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7364),
  [9575] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7371),
  [9577] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3183),
  [9579] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3224),
  [9581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4717),
  [9583] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7352),
  [9585] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7390),
  [9587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4077),
  [9589] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3899),
  [9591] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3895),
  [9593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4191),
  [9595] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7305),
  [9597] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8425),
  [9599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9988),
  [9601] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8740),
  [9603] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8750),
  [9605] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8293),
  [9607] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8826),
  [9609] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8524),
  [9611] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9203),
  [9613] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9312),
  [9615] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9328),
  [9617] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9084),
  [9619] = {.entry = {.count = 1, .reusable = false}}, SHIFT_EXTRA(),
  [9621] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7404),
  [9623] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8793),
  [9625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5580),
  [9627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8904),
  [9629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8944),
  [9631] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8799),
  [9633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7410),
  [9635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8799),
  [9637] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8859),
  [9639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7406),
  [9641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8859),
  [9643] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8995),
  [9645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7409),
  [9647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8995),
  [9649] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8775),
  [9651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7407),
  [9653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8775),
  [9655] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8821),
  [9657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7412),
  [9659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8821),
  [9661] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8933),
  [9663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7408),
  [9665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8933),
  [9667] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8773),
  [9669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8773),
  [9671] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8937),
  [9673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8937),
  [9675] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_attribute_target_specifier, 2, 0, 0),
  [9677] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8811),
  [9679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8811),
  [9681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1153),
  [9683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4896),
  [9685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4725),
  [9687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7394),
  [9689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1002),
  [9691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1154),
  [9693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1155),
  [9695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2188),
  [9697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1904),
  [9699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2186),
  [9701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2153),
  [9703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2179),
  [9705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1630),
  [9707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2189),
  [9709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1908),
  [9711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2175),
  [9713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1481),
  [9715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2144),
  [9717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1270),
  [9719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2185),
  [9721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1900),
  [9723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2190),
  [9725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1912),
  [9727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2173),
  [9729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1403),
  [9731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2177),
  [9733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1557),
  [9735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2181),
  [9737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1776),
  [9739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2172),
  [9741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2149),
  [9743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2183),
  [9745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1870),
  [9747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2180),
  [9749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1704),
  [9751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2187),
  [9753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2089),
  [9755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2191),
  [9757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1916),
  [9759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2184),
  [9761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1896),
  [9763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2182),
  [9765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1831),
  [9767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1966),
  [9769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2017),
  [9771] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_declarator, 1, 0, 4),
  [9773] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1196),
  [9775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3678),
  [9777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3804),
  [9779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1287),
  [9781] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__query_body_repeat1, 2, 0, 0), SHIFT_REPEAT(1153),
  [9784] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__query_body_repeat1, 2, 0, 0), SHIFT_REPEAT(4896),
  [9787] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__query_body_repeat1, 2, 0, 0), SHIFT_REPEAT(4725),
  [9790] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__query_body_repeat1, 2, 0, 0), SHIFT_REPEAT(7394),
  [9793] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__query_body_repeat1, 2, 0, 0), SHIFT_REPEAT(1002),
  [9796] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__query_body_repeat1, 2, 0, 0),
  [9798] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9936),
  [9800] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6810),
  [9802] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2645),
  [9804] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6814),
  [9806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7385),
  [9808] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9003),
  [9810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9055),
  [9812] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9507),
  [9814] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9743),
  [9816] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9624),
  [9818] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9725),
  [9820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9566),
  [9822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9766),
  [9824] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9343),
  [9826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9949),
  [9828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9080),
  [9830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4764),
  [9832] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_variable_declarator, 1, 0, 4), SHIFT(3274),
  [9835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1196),
  [9837] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_variable_declarator, 1, 0, 4), SHIFT(3312),
  [9840] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_type_parameter_constraint, 1, 0, 0), REDUCE(sym__reserved_identifier, 1, 0, 0),
  [9843] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_variable_declarator, 1, 0, 4), SHIFT(3357),
  [9846] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9496),
  [9848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9727),
  [9850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9581),
  [9852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9891),
  [9854] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9924),
  [9856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9437),
  [9858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9372),
  [9860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9477),
  [9862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9271),
  [9864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9133),
  [9866] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9584),
  [9868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9224),
  [9870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3152),
  [9872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(53),
  [9874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2706),
  [9876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2495),
  [9878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2304),
  [9880] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_order_by_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(923),
  [9883] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_order_by_clause_repeat1, 2, 0, 0),
  [9885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(923),
  [9887] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_order_by_clause, 2, 0, 0),
  [9889] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_type_parameter, 1, 0, 4), REDUCE(sym__simple_name, 1, 0, 0),
  [9892] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_join_clause, 3, 0, 45),
  [9894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7347),
  [9896] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_order_by_clause, 3, 0, 0),
  [9898] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9893),
  [9900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9981),
  [9902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9588),
  [9904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9104),
  [9906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9144),
  [9908] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8728),
  [9910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9615),
  [9912] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_base, 2, 0, 0),
  [9914] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6851),
  [9916] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9833),
  [9918] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9662),
  [9920] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__ordering, 2, 0, 0),
  [9922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9653),
  [9924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9295),
  [9926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9042),
  [9928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9551),
  [9930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7921),
  [9932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8855),
  [9934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8321),
  [9936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4048),
  [9938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1156),
  [9940] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_join_clause, 4, 0, 45),
  [9942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5543),
  [9944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4081),
  [9946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3716),
  [9948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4160),
  [9950] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_join_into_clause, 2, 0, 0),
  [9952] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__query_clause, 1, 0, 0),
  [9954] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__query_body_repeat1, 1, 0, 0),
  [9956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4568),
  [9958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5563),
  [9960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4649),
  [9962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3721),
  [9964] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_interpolated_string_expression_repeat1, 2, 0, 0), SHIFT_REPEAT(8321),
  [9967] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_interpolated_string_expression_repeat1, 2, 0, 0),
  [9969] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_interpolated_string_expression_repeat1, 2, 0, 0), SHIFT_REPEAT(1156),
  [9972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4114),
  [9974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9410),
  [9976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4349),
  [9978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(58),
  [9980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3630),
  [9982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8565),
  [9984] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_parameter_constraints_clause, 5, 0, 0),
  [9986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4100),
  [9988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4821),
  [9990] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1248),
  [9992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9863),
  [9994] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tuple_pattern, 4, 0, 60),
  [9996] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9330),
  [9998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9983),
  [10000] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tuple_pattern, 4, 0, 62),
  [10002] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9514),
  [10004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9984),
  [10006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9613),
  [10008] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9105),
  [10010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9172),
  [10012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9948),
  [10014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8541),
  [10016] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_interpolated_string_expression_repeat2, 2, 0, 0),
  [10018] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_interpolated_string_expression_repeat2, 2, 0, 0), SHIFT_REPEAT(1156),
  [10021] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_interpolated_string_expression_repeat2, 2, 0, 0), SHIFT_REPEAT(8541),
  [10024] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_interpolated_string_expression_repeat3, 2, 0, 0),
  [10026] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_interpolated_string_expression_repeat3, 2, 0, 0), SHIFT_REPEAT(1156),
  [10029] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_interpolated_string_expression_repeat3, 2, 0, 0), SHIFT_REPEAT(8565),
  [10032] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3935),
  [10034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8338),
  [10036] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8340),
  [10038] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8346),
  [10040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4863),
  [10042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9167),
  [10044] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_parameter_constraint, 1, 0, 0),
  [10046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8184),
  [10048] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_parameter_constraints_clause, 4, 0, 0),
  [10050] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9478),
  [10052] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4168),
  [10054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9179),
  [10056] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5366),
  [10058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4049),
  [10060] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_string_literal_repeat1, 2, 0, 0),
  [10062] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_string_literal_repeat1, 2, 0, 0), SHIFT_REPEAT(8338),
  [10065] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_string_literal_repeat1, 2, 0, 0), SHIFT_REPEAT(8340),
  [10068] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_string_literal_repeat1, 2, 0, 0), SHIFT_REPEAT(8346),
  [10071] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4491),
  [10073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9085),
  [10075] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_base, 4, 0, 0),
  [10077] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5367),
  [10079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9229),
  [10081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5544),
  [10083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3980),
  [10085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4901),
  [10087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9366),
  [10089] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__ref_base_type, 1, 0, 0),
  [10091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8309),
  [10093] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4464),
  [10095] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_type_parameter_constraints_clause_repeat1, 2, 0, 0),
  [10097] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_type_parameter_constraints_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(4100),
  [10100] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter, 2, 0, 13),
  [10102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4177),
  [10104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9483),
  [10106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4931),
  [10108] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_base_list, 2, 0, 0),
  [10110] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3600),
  [10112] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_try_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(7921),
  [10115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4569),
  [10117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9508),
  [10119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5564),
  [10121] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3626),
  [10123] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_class_declaration_repeat3, 2, 0, 0),
  [10125] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_declaration_repeat3, 2, 0, 0), SHIFT_REPEAT(7385),
  [10128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9730),
  [10130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4750),
  [10132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4650),
  [10134] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8930),
  [10136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4871),
  [10138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9605),
  [10140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3728),
  [10142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9644),
  [10144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9708),
  [10146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4941),
  [10148] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3913),
  [10150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9142),
  [10152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9664),
  [10154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9087),
  [10156] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tuple_pattern, 3, 0, 0),
  [10158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4795),
  [10160] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tuple_pattern, 3, 0, 15),
  [10162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4798),
  [10164] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3928),
  [10166] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8777),
  [10168] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3883),
  [10170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(371),
  [10172] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4122),
  [10174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(426),
  [10176] = {.entry = {.count = 1, .reusable = true}}, SHIFT(471),
  [10178] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6166),
  [10180] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6173),
  [10182] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6130),
  [10184] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6),
  [10186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8733),
  [10188] = {.entry = {.count = 1, .reusable = true}}, SHIFT(604),
  [10190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(587),
  [10192] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_list, 3, 0, 0),
  [10194] = {.entry = {.count = 1, .reusable = true}}, SHIFT(56),
  [10196] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_unary_expression, 2, 0, 22),
  [10198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2),
  [10200] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_list, 3, 0, 14),
  [10202] = {.entry = {.count = 1, .reusable = true}}, SHIFT(605),
  [10204] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_base_list_repeat1, 2, 0, 0),
  [10206] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_parameter_list, 4, 0, 0),
  [10208] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_declarator, 1, 0, 0),
  [10210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1195),
  [10212] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_parameter_constraint, 1, 0, 5),
  [10214] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_elif_in_enum_member_declaration, 4, 0, 39),
  [10216] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2459),
  [10218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(489),
  [10220] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9840),
  [10222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5),
  [10224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3),
  [10226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(594),
  [10228] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8100),
  [10230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6170),
  [10232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6175),
  [10234] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6186),
  [10236] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_unary_expression, 2, 0, 22),
  [10238] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2702),
  [10240] = {.entry = {.count = 1, .reusable = true}}, SHIFT(50),
  [10242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(599),
  [10244] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2262),
  [10246] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_record_base_repeat1, 2, 0, 0),
  [10248] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_list, 4, 0, 33),
  [10250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2294),
  [10252] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_record_base_repeat1, 2, 0, 0), SHIFT_REPEAT(6851),
  [10255] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_list, 4, 0, 35),
  [10257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2488),
  [10259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(358),
  [10261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4067),
  [10263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1272),
  [10265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(44),
  [10267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(672),
  [10269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11),
  [10271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1273),
  [10273] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_parameter_list, 3, 0, 0),
  [10275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(596),
  [10277] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_constraint, 3, 0, 0),
  [10279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(359),
  [10281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5427),
  [10283] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_parenthesized_expression, 3, 0, 0),
  [10285] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_parenthesized_expression, 3, 0, 0),
  [10287] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_binary_expression, 3, 0, 24),
  [10289] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_binary_expression, 3, 0, 24),
  [10291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6758),
  [10293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2266),
  [10295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1409),
  [10297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1411),
  [10299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(472),
  [10301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(486),
  [10303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6753),
  [10305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(41),
  [10307] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_base, 5, 0, 0),
  [10309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2298),
  [10311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(606),
  [10313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8752),
  [10315] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_parameter_constraint, 2, 0, 0),
  [10317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(52),
  [10319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4),
  [10321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2722),
  [10323] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_base, 3, 0, 0),
  [10325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8109),
  [10327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8965),
  [10329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1286),
  [10331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(509),
  [10333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(383),
  [10335] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_switch_body_repeat1, 2, 0, 0),
  [10337] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_switch_body_repeat1, 2, 0, 0), SHIFT_REPEAT(489),
  [10340] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_switch_body_repeat1, 2, 0, 0), SHIFT_REPEAT(9840),
  [10343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(368),
  [10345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5039),
  [10347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(364),
  [10349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4608),
  [10351] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__preproc_expression, 1, 0, 0),
  [10353] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__preproc_expression, 1, 0, 0),
  [10355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8374),
  [10357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4763),
  [10359] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_bracketed_parameter_list_repeat1, 2, 0, 34), SHIFT_REPEAT(3753),
  [10362] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_bracketed_parameter_list_repeat1, 2, 0, 34),
  [10364] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4903),
  [10366] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6777),
  [10368] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3450),
  [10370] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3451),
  [10372] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3464),
  [10374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3509),
  [10376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3232),
  [10378] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3233),
  [10380] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3256),
  [10382] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interpolation, 4, 0, 0),
  [10384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(468),
  [10386] = {.entry = {.count = 1, .reusable = true}}, SHIFT(469),
  [10388] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2408),
  [10390] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6850),
  [10392] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declaration_expression, 2, 1, 13),
  [10394] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interpolation, 5, 0, 0),
  [10396] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2387),
  [10398] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_type_argument_list_repeat1, 2, 0, 0), SHIFT_REPEAT(8558),
  [10401] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_type_argument_list_repeat1, 2, 0, 0),
  [10403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1284),
  [10405] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_member_declaration, 1, 0, 4),
  [10407] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subpattern, 1, 0, 0),
  [10409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4068),
  [10411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1289),
  [10413] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_member_declaration, 2, 0, 15),
  [10415] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interpolation, 3, 0, 0),
  [10417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9595),
  [10419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9852),
  [10421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8651),
  [10423] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1364),
  [10425] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_using_variable_declarator, 1, 0, 4), REDUCE(sym_tuple_element, 2, 0, 13),
  [10428] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_using_variable_declarator, 1, 0, 4),
  [10430] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4124),
  [10432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3518),
  [10434] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_base_list, 4, 0, 0),
  [10436] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_base_list_repeat1, 2, 0, 0), SHIFT_REPEAT(4931),
  [10439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2518),
  [10441] = {.entry = {.count = 3, .reusable = true}}, REDUCE(sym_parameter, 2, 0, 13), REDUCE(sym_tuple_element, 2, 0, 13), REDUCE(sym_declaration_expression, 2, 1, 13),
  [10445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2394),
  [10447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4094),
  [10449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8956),
  [10451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9850),
  [10453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2525),
  [10455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2526),
  [10457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1460),
  [10459] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter, 4, 0, 49),
  [10461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2571),
  [10463] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1368),
  [10465] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter, 3, 0, 32),
  [10467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1368),
  [10469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2365),
  [10471] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_base_list, 3, 0, 0),
  [10473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2580),
  [10475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2366),
  [10477] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__interpolated_string_content, 1, 0, 0),
  [10479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2356),
  [10481] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subpattern, 3, 0, 0),
  [10483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5428),
  [10485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2395),
  [10487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2374),
  [10489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5046),
  [10491] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_class_declaration_repeat3, 1, 0, 0),
  [10493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2588),
  [10495] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string_literal_content, 1, 0, 0),
  [10497] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string_literal_content, 1, 0, 0),
  [10499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2589),
  [10501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4142),
  [10503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2514),
  [10505] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_string_literal_repeat1, 1, 0, 0),
  [10507] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_string_literal_repeat1, 1, 0, 0),
  [10509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2548),
  [10511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2573),
  [10513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2577),
  [10515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3478),
  [10517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3479),
  [10519] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_primary_constructor_base_type, 2, 0, 5),
  [10521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2417),
  [10523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4172),
  [10525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1248),
  [10527] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1278),
  [10530] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2317),
  [10532] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3293),
  [10534] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4186),
  [10536] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2616),
  [10538] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4194),
  [10540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4203),
  [10542] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4609),
  [10544] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3371),
  [10546] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4211),
  [10548] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4220),
  [10550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2601),
  [10552] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2334),
  [10554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2335),
  [10556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2345),
  [10558] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_interpolated_string_expression_repeat1, 1, 0, 0),
  [10560] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_calling_convention_repeat1, 2, 0, 0), SHIFT_REPEAT(6945),
  [10563] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_calling_convention_repeat1, 2, 0, 0),
  [10565] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_preproc_pragma_repeat1, 2, 0, 0), SHIFT_REPEAT(7298),
  [10568] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_preproc_pragma_repeat1, 2, 0, 0),
  [10570] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8708),
  [10572] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1279),
  [10574] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_declarator, 2, 0, 0),
  [10576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(614),
  [10578] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3908),
  [10580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7118),
  [10582] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_declaration, 3, 0, 5),
  [10584] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_declaration, 2, 0, 5),
  [10586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6972),
  [10588] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1280),
  [10590] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_declarator, 2, 0, 4),
  [10592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6801),
  [10594] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6919),
  [10596] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3986),
  [10598] = {.entry = {.count = 1, .reusable = true}}, SHIFT(137),
  [10600] = {.entry = {.count = 1, .reusable = true}}, SHIFT(138),
  [10602] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6808),
  [10604] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7293),
  [10606] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3734),
  [10608] = {.entry = {.count = 1, .reusable = true}}, SHIFT(597),
  [10610] = {.entry = {.count = 1, .reusable = true}}, SHIFT(662),
  [10612] = {.entry = {.count = 1, .reusable = true}}, SHIFT(143),
  [10614] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_for_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1257),
  [10617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3023),
  [10619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3602),
  [10621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6800),
  [10623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2427),
  [10625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(144),
  [10627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(356),
  [10629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5591),
  [10631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(146),
  [10633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6783),
  [10635] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_variable_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(7118),
  [10638] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_variable_declaration_repeat1, 2, 0, 0),
  [10640] = {.entry = {.count = 1, .reusable = true}}, SHIFT(355),
  [10642] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3755),
  [10644] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_argument_list_repeat1, 2, 0, 0), SHIFT_REPEAT(614),
  [10647] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_argument_list_repeat1, 2, 0, 0),
  [10649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3918),
  [10651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4554),
  [10653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3732),
  [10655] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_tuple_element, 2, 0, 13), REDUCE(sym_declaration_expression, 2, 1, 13),
  [10658] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4806),
  [10660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2745),
  [10662] = {.entry = {.count = 1, .reusable = true}}, SHIFT(165),
  [10664] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3239),
  [10666] = {.entry = {.count = 1, .reusable = true}}, SHIFT(166),
  [10668] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7298),
  [10670] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9990),
  [10672] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3753),
  [10674] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8051),
  [10676] = {.entry = {.count = 1, .reusable = true}}, SHIFT(348),
  [10678] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10001),
  [10680] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3787),
  [10682] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8803),
  [10684] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1055),
  [10686] = {.entry = {.count = 1, .reusable = true}}, SHIFT(339),
  [10688] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_parenthesized_variable_designation_repeat1, 2, 0, 61), SHIFT_REPEAT(6919),
  [10691] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_parenthesized_variable_designation_repeat1, 2, 0, 61),
  [10693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7295),
  [10695] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_using_variable_declaration, 2, 0, 5),
  [10697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9998),
  [10699] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9590),
  [10701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8258),
  [10703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8987),
  [10705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8057),
  [10707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(585),
  [10709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(116),
  [10711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3214),
  [10713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7164),
  [10715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6780),
  [10717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3737),
  [10719] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_type_parameter_list_repeat1, 2, 0, 0), SHIFT_REPEAT(6821),
  [10722] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_type_parameter_list_repeat1, 2, 0, 0),
  [10724] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_using_variable_declaration, 3, 0, 5),
  [10726] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6799),
  [10728] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2604),
  [10730] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_tuple_pattern_repeat1, 2, 0, 61), SHIFT_REPEAT(7164),
  [10733] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_tuple_pattern_repeat1, 2, 0, 61),
  [10735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6792),
  [10737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5240),
  [10739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(691),
  [10741] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_enum_member_declaration_list_repeat1, 2, 0, 0), SHIFT_REPEAT(6824),
  [10744] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_enum_member_declaration_list_repeat1, 2, 0, 0),
  [10746] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5605),
  [10748] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_parameter, 2, 0, 13), REDUCE(sym_tuple_element, 2, 0, 13),
  [10751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3953),
  [10753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8882),
  [10755] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_global_attribute_repeat1, 2, 0, 0), SHIFT_REPEAT(6822),
  [10758] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_global_attribute_repeat1, 2, 0, 0),
  [10760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1011),
  [10762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8781),
  [10764] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6781),
  [10766] = {.entry = {.count = 1, .reusable = true}}, SHIFT(175),
  [10768] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8993),
  [10770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1479),
  [10772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(77),
  [10774] = {.entry = {.count = 1, .reusable = true}}, SHIFT(588),
  [10776] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3054),
  [10778] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3456),
  [10780] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5359),
  [10782] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_argument_list_repeat1, 2, 0, 0), SHIFT_REPEAT(613),
  [10785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3890),
  [10787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3618),
  [10789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2981),
  [10791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8989),
  [10793] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_positional_pattern_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(363),
  [10796] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_positional_pattern_clause_repeat1, 2, 0, 0),
  [10798] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__parameter_array, 4, 0, 49),
  [10800] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5361),
  [10802] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8973),
  [10804] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6945),
  [10806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9041),
  [10808] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6789),
  [10810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4441),
  [10812] = {.entry = {.count = 1, .reusable = true}}, SHIFT(592),
  [10814] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3522),
  [10816] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8839),
  [10818] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1364),
  [10820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(78),
  [10822] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__parameter_array, 3, 0, 32),
  [10824] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_bracketed_parameter_list_repeat1, 2, 0, 0),
  [10826] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_bracketed_parameter_list_repeat1, 2, 0, 14),
  [10828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(676),
  [10830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4686),
  [10832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8952),
  [10834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8959),
  [10836] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_type_argument_list_repeat2, 2, 0, 0), SHIFT_REPEAT(4806),
  [10839] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_type_argument_list_repeat2, 2, 0, 0),
  [10841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7936),
  [10843] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_tuple_type_repeat1, 2, 0, 0), SHIFT_REPEAT(4554),
  [10846] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_tuple_type_repeat1, 2, 0, 0),
  [10848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3614),
  [10850] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_initializer, 3, 0, 0),
  [10852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(641),
  [10854] = {.entry = {.count = 1, .reusable = true}}, SHIFT(156),
  [10856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1285),
  [10858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3342),
  [10860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(373),
  [10862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6779),
  [10864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(595),
  [10866] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3181),
  [10868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6778),
  [10870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7294),
  [10872] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_using_variable_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(7295),
  [10875] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_using_variable_declaration_repeat1, 2, 0, 0),
  [10877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5339),
  [10879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(603),
  [10881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3896),
  [10883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1032),
  [10885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3914),
  [10887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3984),
  [10889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(666),
  [10891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4098),
  [10893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1288),
  [10895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8437),
  [10897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3245),
  [10899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4057),
  [10901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3399),
  [10903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5259),
  [10905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8706),
  [10907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7915),
  [10909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3616),
  [10911] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_switch_expression_repeat1, 2, 0, 0), SHIFT_REPEAT(360),
  [10914] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_switch_expression_repeat1, 2, 0, 0),
  [10916] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6821),
  [10918] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8004),
  [10920] = {.entry = {.count = 1, .reusable = true}}, SHIFT(338),
  [10922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3994),
  [10924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2818),
  [10926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8766),
  [10928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4007),
  [10930] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__interpolated_verbatim_string_content, 1, 0, 0),
  [10932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6796),
  [10934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4010),
  [10936] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_list_pattern_repeat1, 2, 0, 0), SHIFT_REPEAT(488),
  [10939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3941),
  [10941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(667),
  [10943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5268),
  [10945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3589),
  [10947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(330),
  [10949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4332),
  [10951] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_positional_pattern_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(372),
  [10954] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1100),
  [10956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(681),
  [10958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4099),
  [10960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2839),
  [10962] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_interpolated_string_expression_repeat2, 1, 0, 0),
  [10964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(86),
  [10966] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_type_argument_list_repeat1, 1, 0, 0),
  [10968] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_with_expression_repeat1, 2, 0, 0), SHIFT_REPEAT(7293),
  [10971] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_with_expression_repeat1, 2, 0, 0),
  [10973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(331),
  [10975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(361),
  [10977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5436),
  [10979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(675),
  [10981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3747),
  [10983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4110),
  [10985] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__interpolated_raw_string_content, 1, 0, 0),
  [10987] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_base_list_repeat1, 3, 0, 0),
  [10989] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_interpolated_string_expression_repeat3, 1, 0, 0),
  [10991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5439),
  [10993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7984),
  [10995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8746),
  [10997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7998),
  [10999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3300),
  [11001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(372),
  [11003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2968),
  [11005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3726),
  [11007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8085),
  [11009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(329),
  [11011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2995),
  [11013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(172),
  [11015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4003),
  [11017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(352),
  [11019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4744),
  [11021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(173),
  [11023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6787),
  [11025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4503),
  [11027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(586),
  [11029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3007),
  [11031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6788),
  [11033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(337),
  [11035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3528),
  [11037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6802),
  [11039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1465),
  [11041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(607),
  [11043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3010),
  [11045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3882),
  [11047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3017),
  [11049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2747),
  [11051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3603),
  [11053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1078),
  [11055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2941),
  [11057] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attribute_argument_list_repeat1, 2, 0, 0), SHIFT_REPEAT(1011),
  [11060] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_attribute_argument_list_repeat1, 2, 0, 0),
  [11062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4585),
  [11064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4575),
  [11066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(326),
  [11068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8846),
  [11070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4998),
  [11072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(335),
  [11074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5278),
  [11076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(661),
  [11078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5568),
  [11080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6782),
  [11082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(374),
  [11084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(930),
  [11086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6798),
  [11088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4052),
  [11090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(590),
  [11092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3570),
  [11094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2973),
  [11096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9009),
  [11098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(998),
  [11100] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5634),
  [11102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4516),
  [11104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(712),
  [11106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3659),
  [11108] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_array_rank_specifier_repeat1, 2, 0, 0), SHIFT_REPEAT(652),
  [11111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8800),
  [11113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3886),
  [11115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3891),
  [11117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8806),
  [11119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(343),
  [11121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(357),
  [11123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3272),
  [11125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5023),
  [11127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(107),
  [11129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6803),
  [11131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6696),
  [11133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(593),
  [11135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3550),
  [11137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(344),
  [11139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3710),
  [11141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5022),
  [11143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(108),
  [11145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4180),
  [11147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3343),
  [11149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3344),
  [11151] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7915),
  [11153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9999),
  [11155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4602),
  [11157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(100),
  [11159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8910),
  [11161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6806),
  [11163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(113),
  [11165] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_anonymous_object_creation_expression_repeat1, 2, 0, 0), SHIFT_REPEAT(1145),
  [11168] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_anonymous_object_creation_expression_repeat1, 2, 0, 0),
  [11170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(114),
  [11172] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7811),
  [11174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(877),
  [11176] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_switch_body_repeat1, 1, 0, 0),
  [11178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3909),
  [11180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1008),
  [11182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(83),
  [11184] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4507),
  [11186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7817),
  [11188] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3910),
  [11190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6790),
  [11192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9385),
  [11194] = {.entry = {.count = 1, .reusable = true}}, SHIFT(644),
  [11196] = {.entry = {.count = 1, .reusable = true}}, SHIFT(84),
  [11198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1385),
  [11200] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1024),
  [11202] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3444),
  [11204] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8718),
  [11206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3193),
  [11208] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_base_list_repeat1, 2, 0, 0), SHIFT_REPEAT(4763),
  [11211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5025),
  [11213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2961),
  [11215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3216),
  [11217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(346),
  [11219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3679),
  [11221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(130),
  [11223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3685),
  [11225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(598),
  [11227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3175),
  [11229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3651),
  [11231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(600),
  [11233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4054),
  [11235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1128),
  [11237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6793),
  [11239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(70),
  [11241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(347),
  [11243] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_variable_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(6972),
  [11246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(370),
  [11248] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4633),
  [11250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3705),
  [11252] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5383),
  [11254] = {.entry = {.count = 1, .reusable = true}}, SHIFT(710),
  [11256] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4011),
  [11258] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4120),
  [11260] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3504),
  [11262] = {.entry = {.count = 1, .reusable = true}}, SHIFT(617),
  [11264] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1406),
  [11266] = {.entry = {.count = 1, .reusable = true}}, SHIFT(633),
  [11268] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8727),
  [11270] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8038),
  [11272] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2609),
  [11274] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_if_in_enum_member_declaration, 5, 0, 39),
  [11276] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_if_in_enum_member_declaration, 5, 0, 59),
  [11278] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9993),
  [11280] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9155),
  [11282] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_catch_declaration, 4, 0, 32),
  [11284] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9997),
  [11286] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9578),
  [11288] = {.entry = {.count = 1, .reusable = true}}, SHIFT(636),
  [11290] = {.entry = {.count = 1, .reusable = true}}, SHIFT(628),
  [11292] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1327),
  [11294] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attribute_argument_list, 2, 0, 0),
  [11296] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9880),
  [11298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(621),
  [11300] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9241),
  [11302] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_parameter, 1, 0, 4),
  [11304] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8060),
  [11306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7278),
  [11308] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9440),
  [11310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9311),
  [11312] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attribute_argument_list, 4, 0, 0),
  [11314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3658),
  [11316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8181),
  [11318] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2590),
  [11320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3467),
  [11322] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_parenthesized_variable_designation_repeat1, 2, 0, 43),
  [11324] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_bracketed_parameter_list, 3, 0, 0),
  [11326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(629),
  [11328] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_bracketed_parameter_list, 3, 0, 14),
  [11330] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_if_in_enum_member_declaration, 4, 0, 39),
  [11332] = {.entry = {.count = 1, .reusable = true}}, SHIFT(615),
  [11334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3427),
  [11336] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2428),
  [11338] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8771),
  [11340] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8763),
  [11342] = {.entry = {.count = 1, .reusable = true}}, SHIFT(625),
  [11344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1972),
  [11346] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_bracketed_parameter_list, 2, 0, 0),
  [11348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1975),
  [11350] = {.entry = {.count = 1, .reusable = true}}, SHIFT(639),
  [11352] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2640),
  [11354] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tuple_element, 2, 0, 13),
  [11356] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_tuple_pattern_repeat1, 2, 0, 0),
  [11358] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_parameter, 3, 0, 31),
  [11360] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_tuple_pattern_repeat1, 2, 0, 15),
  [11362] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2309),
  [11364] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9816),
  [11366] = {.entry = {.count = 1, .reusable = true}}, SHIFT(630),
  [11368] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attribute, 2, 0, 4),
  [11370] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_catch_declaration, 3, 0, 6),
  [11372] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2106),
  [11374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2107),
  [11376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3491),
  [11378] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_if_in_enum_member_declaration, 6, 0, 81),
  [11380] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2119),
  [11382] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2120),
  [11384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9476),
  [11386] = {.entry = {.count = 1, .reusable = true}}, SHIFT(619),
  [11388] = {.entry = {.count = 1, .reusable = true}}, SHIFT(638),
  [11390] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8168),
  [11392] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_preproc_pragma_repeat1, 2, 0, 0),
  [11394] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9441),
  [11396] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_parameter, 2, 0, 15),
  [11398] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1483),
  [11400] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_bracketed_parameter_list, 4, 0, 33),
  [11402] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6947),
  [11404] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_calling_convention, 1, 0, 0),
  [11406] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_bracketed_parameter_list, 4, 0, 35),
  [11408] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9056),
  [11410] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2325),
  [11412] = {.entry = {.count = 1, .reusable = true}}, SHIFT(99),
  [11414] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attribute_argument_list, 3, 0, 0),
  [11416] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3510),
  [11418] = {.entry = {.count = 1, .reusable = true}}, SHIFT(947),
  [11420] = {.entry = {.count = 1, .reusable = true}}, SHIFT(948),
  [11422] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2275),
  [11424] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1019),
  [11426] = {.entry = {.count = 1, .reusable = true}}, SHIFT(889),
  [11428] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1115),
  [11430] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3519),
  [11432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(934),
  [11434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2276),
  [11436] = {.entry = {.count = 1, .reusable = true}}, SHIFT(949),
  [11438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4042),
  [11440] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5629),
  [11442] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_calling_convention, 4, 0, 0),
  [11444] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2697),
  [11446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2407),
  [11448] = {.entry = {.count = 1, .reusable = true}}, SHIFT(797),
  [11450] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1049),
  [11452] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3892),
  [11454] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8804),
  [11456] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9686),
  [11458] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1255),
  [11460] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1118),
  [11462] = {.entry = {.count = 1, .reusable = true}}, SHIFT(311),
  [11464] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7261),
  [11466] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1123),
  [11468] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2441),
  [11470] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1035),
  [11472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1092),
  [11474] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2363),
  [11476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2634),
  [11478] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2913),
  [11480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3893),
  [11482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1050),
  [11484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2539),
  [11486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1134),
  [11488] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1135),
  [11490] = {.entry = {.count = 1, .reusable = true}}, SHIFT(890),
  [11492] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1051),
  [11494] = {.entry = {.count = 1, .reusable = true}}, SHIFT(891),
  [11496] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2280),
  [11498] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2402),
  [11500] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1139),
  [11502] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_calling_convention, 5, 0, 0),
  [11504] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2572),
  [11506] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4072),
  [11508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2574),
  [11510] = {.entry = {.count = 1, .reusable = true}}, SHIFT(892),
  [11512] = {.entry = {.count = 1, .reusable = true}}, SHIFT(893),
  [11514] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2364),
  [11516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(935),
  [11518] = {.entry = {.count = 1, .reusable = true}}, SHIFT(894),
  [11520] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2639),
  [11522] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5631),
  [11524] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3333),
  [11526] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3466),
  [11528] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5730),
  [11530] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2555),
  [11532] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1052),
  [11534] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1098),
  [11536] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1053),
  [11538] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2225),
  [11540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1649),
  [11542] = {.entry = {.count = 1, .reusable = true}}, SHIFT(914),
  [11544] = {.entry = {.count = 1, .reusable = true}}, SHIFT(768),
  [11546] = {.entry = {.count = 1, .reusable = true}}, SHIFT(936),
  [11548] = {.entry = {.count = 1, .reusable = true}}, SHIFT(748),
  [11550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2421),
  [11552] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3246),
  [11554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2614),
  [11556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3623),
  [11558] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4041),
  [11560] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1054),
  [11562] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6819),
  [11564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8843),
  [11566] = {.entry = {.count = 1, .reusable = true}}, SHIFT(769),
  [11568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(772),
  [11570] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3335),
  [11572] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4591),
  [11574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2564),
  [11576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6983),
  [11578] = {.entry = {.count = 1, .reusable = true}}, SHIFT(749),
  [11580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(751),
  [11582] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9211),
  [11584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2627),
  [11586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(775),
  [11588] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2575),
  [11590] = {.entry = {.count = 1, .reusable = true}}, SHIFT(776),
  [11592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(754),
  [11594] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7177),
  [11596] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2576),
  [11598] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1044),
  [11600] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1636),
  [11602] = {.entry = {.count = 1, .reusable = true}}, SHIFT(777),
  [11604] = {.entry = {.count = 1, .reusable = true}}, SHIFT(755),
  [11606] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1065),
  [11608] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2282),
  [11610] = {.entry = {.count = 1, .reusable = true}},  ACCEPT_INPUT(),
  [11612] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3446),
  [11614] = {.entry = {.count = 1, .reusable = true}}, SHIFT(756),
  [11616] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1277),
  [11618] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3468),
  [11620] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4090),
  [11622] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2388),
  [11624] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2403),
  [11626] = {.entry = {.count = 1, .reusable = true}}, SHIFT(937),
  [11628] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1426),
  [11630] = {.entry = {.count = 1, .reusable = true}}, SHIFT(799),
  [11632] = {.entry = {.count = 1, .reusable = true}}, SHIFT(938),
  [11634] = {.entry = {.count = 1, .reusable = true}}, SHIFT(816),
  [11636] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3791),
  [11638] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5352),
  [11640] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3527),
  [11642] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3447),
  [11644] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2440),
  [11646] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1428),
  [11648] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2285),
  [11650] = {.entry = {.count = 1, .reusable = true}}, SHIFT(939),
  [11652] = {.entry = {.count = 1, .reusable = true}}, SHIFT(817),
  [11654] = {.entry = {.count = 1, .reusable = true}}, SHIFT(820),
  [11656] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1068),
  [11658] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2628),
  [11660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(800),
  [11662] = {.entry = {.count = 1, .reusable = true}}, SHIFT(801),
  [11664] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1562),
  [11666] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1005),
  [11668] = {.entry = {.count = 1, .reusable = true}}, SHIFT(924),
  [11670] = {.entry = {.count = 1, .reusable = true}}, SHIFT(823),
  [11672] = {.entry = {.count = 1, .reusable = true}}, SHIFT(824),
  [11674] = {.entry = {.count = 1, .reusable = true}}, SHIFT(899),
  [11676] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2619),
  [11678] = {.entry = {.count = 1, .reusable = true}}, SHIFT(802),
  [11680] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2389),
  [11682] = {.entry = {.count = 1, .reusable = true}}, SHIFT(825),
  [11684] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3470),
  [11686] = {.entry = {.count = 1, .reusable = true}}, SHIFT(803),
  [11688] = {.entry = {.count = 1, .reusable = true}}, SHIFT(804),
  [11690] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3978),
  [11692] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2556),
  [11694] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_elif_in_enum_member_declaration, 5, 0, 81),
  [11696] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2409),
  [11698] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3351),
  [11700] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2557),
  [11702] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1071),
  [11704] = {.entry = {.count = 1, .reusable = true}}, SHIFT(853),
  [11706] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5589),
  [11708] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2410),
  [11710] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declaration_list, 3, 0, 0),
  [11712] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3471),
  [11714] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1487),
  [11716] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9989),
  [11718] = {.entry = {.count = 1, .reusable = true}}, SHIFT(854),
  [11720] = {.entry = {.count = 1, .reusable = true}}, SHIFT(856),
  [11722] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1147),
  [11724] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3472),
  [11726] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2390),
  [11728] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9992),
  [11730] = {.entry = {.count = 1, .reusable = true}}, SHIFT(857),
  [11732] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2411),
  [11734] = {.entry = {.count = 1, .reusable = true}}, SHIFT(858),
  [11736] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2391),
  [11738] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3473),
  [11740] = {.entry = {.count = 1, .reusable = true}}, SHIFT(794),
  [11742] = {.entry = {.count = 1, .reusable = true}}, SHIFT(859),
  [11744] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1080),
  [11746] = {.entry = {.count = 1, .reusable = true}}, SHIFT(795),
  [11748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2412),
  [11750] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3354),
  [11752] = {.entry = {.count = 1, .reusable = true}}, SHIFT(838),
  [11754] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1081),
  [11756] = {.entry = {.count = 1, .reusable = true}}, SHIFT(878),
  [11758] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3474),
  [11760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3475),
  [11762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3506),
  [11764] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4002),
  [11766] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3477),
  [11768] = {.entry = {.count = 1, .reusable = true}}, SHIFT(873),
  [11770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(879),
  [11772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(881),
  [11774] = {.entry = {.count = 1, .reusable = true}}, SHIFT(170),
  [11776] = {.entry = {.count = 1, .reusable = true}}, SHIFT(30),
  [11778] = {.entry = {.count = 1, .reusable = true}}, SHIFT(732),
  [11780] = {.entry = {.count = 1, .reusable = true}}, SHIFT(796),
  [11782] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8744),
  [11784] = {.entry = {.count = 1, .reusable = true}}, SHIFT(882),
  [11786] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4015),
  [11788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(883),
  [11790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4016),
  [11792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(839),
  [11794] = {.entry = {.count = 1, .reusable = true}}, SHIFT(884),
  [11796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(733),
  [11798] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8841),
  [11800] = {.entry = {.count = 1, .reusable = true}}, SHIFT(840),
  [11802] = {.entry = {.count = 1, .reusable = true}}, SHIFT(963),
  [11804] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2384),
  [11806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(734),
  [11808] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9480),
  [11810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(735),
  [11812] = {.entry = {.count = 1, .reusable = true}}, SHIFT(736),
  [11814] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3448),
  [11816] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2413),
  [11818] = {.entry = {.count = 1, .reusable = true}}, SHIFT(829),
  [11820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(841),
  [11822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9985),
  [11824] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3449),
  [11826] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_declaration_list, 2, 0, 0),
  [11828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9991),
  [11830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2442),
  [11832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9717),
  [11834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2221),
  [11836] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2414),
  [11838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(953),
  [11840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3377),
  [11842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(927),
  [11844] = {.entry = {.count = 1, .reusable = true}}, SHIFT(954),
  [11846] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2367),
  [11848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9575),
  [11850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(837),
  [11852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2615),
  [11854] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2288),
  [11856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2629),
  [11858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(955),
  [11860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2368),
  [11862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3503),
  [11864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(851),
  [11866] = {.entry = {.count = 1, .reusable = true}}, SHIFT(842),
  [11868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(843),
  [11870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(929),
  [11872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2369),
  [11874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(872),
  [11876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3505),
  [11878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3668),
  [11880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4635),
  [11882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2370),
  [11884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(932),
  [11886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3366),
  [11888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(956),
  [11890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(792),
  [11892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(952),
  [11894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1069),
  [11896] = {.entry = {.count = 1, .reusable = true}}, SHIFT(960),
  [11898] = {.entry = {.count = 1, .reusable = true}}, SHIFT(979),
  [11900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(987),
  [11902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9681),
  [11904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(957),
  [11906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(958),
  [11908] = {.entry = {.count = 1, .reusable = true}}, SHIFT(945),
  [11910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2511),
  [11912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(994),
  [11914] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2392),
  [11916] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3316),
  [11918] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2566),
  [11920] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3520),
  [11922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5325),
  [11924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(988),
  [11926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(961),
  [11928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(852),
  [11930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(995),
  [11932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(962),
  [11934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2530),
  [11936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3508),
  [11938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3521),
  [11940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4327),
  [11942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1150),
  [11944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4363),
  [11946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3445),
  [11948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3523),
  [11950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(964),
  [11952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3511),
  [11954] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_elif, 4, 0, 59),
  [11956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(965),
  [11958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3492),
  [11960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(791),
  [11962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(782),
  [11964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2607),
  [11966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9987),
  [11968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2385),
  [11970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10000),
  [11972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(966),
  [11974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2632),
  [11976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2404),
  [11978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(783),
  [11980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(759),
  [11982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3493),
  [11984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3512),
  [11986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(784),
  [11988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(969),
  [11990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2994),
  [11992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2434),
  [11994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3532),
  [11996] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5243),
  [11998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2393),
  [12000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2635),
  [12002] = {.entry = {.count = 1, .reusable = true}}, SHIFT(876),
  [12004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4104),
  [12006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2535),
  [12008] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2278),
  [12010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4105),
  [12012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(785),
  [12014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1132),
  [12016] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9678),
  [12018] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_else_in_enum_member_declaration, 2, 0, 0),
  [12020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3513),
  [12022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(786),
  [12024] = {.entry = {.count = 1, .reusable = true}}, SHIFT(787),
  [12026] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3494),
  [12028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3495),
  [12030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1009),
  [12032] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8923),
  [12034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2630),
  [12036] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3525),
  [12038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(972),
  [12040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2372),
  [12042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3526),
  [12044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2373),
  [12046] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9161),
  [12048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3790),
  [12050] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2536),
  [12052] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5384),
  [12054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2537),
  [12056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(830),
  [12058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(973),
  [12060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(992),
  [12062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(974),
  [12064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2415),
  [12066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2584),
  [12068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2723),
  [12070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(975),
  [12072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(976),
  [12074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2375),
  [12076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(977),
  [12078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8962),
  [12080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8975),
  [12082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2902),
  [12084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(912),
  [12086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7411),
  [12088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(980),
  [12090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2725),
  [12092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3228),
  [12094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4739),
  [12096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3676),
  [12098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9398),
  [12100] = {.entry = {.count = 1, .reusable = true}}, SHIFT(981),
  [12102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2386),
  [12104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2561),
  [12106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8742),
  [12108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3691),
  [12110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(915),
  [12112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1072),
  [12114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(982),
  [12116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3230),
  [12118] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1391),
  [12120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8317),
  [12122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2728),
  [12124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(983),
  [12126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(984),
  [12128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1143),
  [12130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2396),
  [12132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3514),
  [12134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(902),
  [12136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(985),
  [12138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7756),
  [12140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7919),
  [12142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3318),
  [12144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4139),
  [12146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7920),
  [12148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9585),
  [12150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2562),
  [12152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4490),
  [12154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7739),
  [12156] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_member_declaration_list, 3, 0, 0),
  [12158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2643),
  [12160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8844),
  [12162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3282),
  [12164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7898),
  [12166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(831),
  [12168] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7899),
  [12170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4140),
  [12172] = {.entry = {.count = 1, .reusable = true}}, SHIFT(832),
  [12174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(918),
  [12176] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3615),
  [12178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2563),
  [12180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9225),
  [12182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4322),
  [12184] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9383),
  [12186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2449),
  [12188] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3231),
  [12190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2376),
  [12192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3164),
  [12194] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2296),
  [12196] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3284),
  [12198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2377),
  [12200] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4573),
  [12202] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2416),
  [12204] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4785),
  [12206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(886),
  [12208] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2473),
  [12210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2610),
  [12212] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1653),
  [12214] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1192),
  [12216] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1330),
  [12218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2633),
  [12220] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7721),
  [12222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7874),
  [12224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(887),
  [12226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7875),
  [12228] = {.entry = {.count = 1, .reusable = true}}, SHIFT(919),
  [12230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9112),
  [12232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2529),
  [12234] = {.entry = {.count = 1, .reusable = true}}, SHIFT(920),
  [12236] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_elif_in_expression, 5, 0, 81),
  [12238] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_elif_in_top_level, 5, 0, 81),
  [12240] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_catch_filter_clause, 4, 0, 0),
  [12242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2586),
  [12244] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4760),
  [12246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8885),
  [12248] = {.entry = {.count = 1, .reusable = true}}, SHIFT(888),
  [12250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3751),
  [12252] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4687),
  [12254] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3235),
  [12256] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2541),
  [12258] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4125),
  [12260] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3729),
  [12262] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2582),
  [12264] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2903),
  [12266] = {.entry = {.count = 1, .reusable = true}}, SHIFT(921),
  [12268] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3238),
  [12270] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2608),
  [12272] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2531),
  [12274] = {.entry = {.count = 1, .reusable = true}}, SHIFT(833),
  [12276] = {.entry = {.count = 1, .reusable = true}}, SHIFT(906),
  [12278] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1960),
  [12280] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1961),
  [12282] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1963),
  [12284] = {.entry = {.count = 1, .reusable = true}}, SHIFT(855),
  [12286] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4935),
  [12288] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4936),
  [12290] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1964),
  [12292] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1965),
  [12294] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2587),
  [12296] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2538),
  [12298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2542),
  [12300] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2583),
  [12302] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_pointer_parameter, 2, 0, 6),
  [12304] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3241),
  [12306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6818),
  [12308] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3457),
  [12310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1959),
  [12312] = {.entry = {.count = 1, .reusable = true}}, SHIFT(119),
  [12314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2480),
  [12316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2611),
  [12318] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1012),
  [12320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(834),
  [12322] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3515),
  [12324] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_elif_in_top_level, 4, 0, 59),
  [12326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3303),
  [12328] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_elif_in_expression, 4, 0, 59),
  [12330] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2591),
  [12332] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2543),
  [12334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2544),
  [12336] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9994),
  [12338] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2594),
  [12340] = {.entry = {.count = 1, .reusable = true}}, SHIFT(943),
  [12342] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3242),
  [12344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2545),
  [12346] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3248),
  [12348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2546),
  [12350] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3259),
  [12352] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3260),
  [12354] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3243),
  [12356] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2401),
  [12358] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2612),
  [12360] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2547),
  [12362] = {.entry = {.count = 1, .reusable = true}}, SHIFT(835),
  [12364] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3516),
  [12366] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1121),
  [12368] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3452),
  [12370] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2667),
  [12372] = {.entry = {.count = 1, .reusable = true}}, SHIFT(910),
  [12374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2669),
  [12376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3249),
  [12378] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2378),
  [12380] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8089),
  [12382] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3250),
  [12384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2418),
  [12386] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3437),
  [12388] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2605),
  [12390] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3251),
  [12392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2379),
  [12394] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2397),
  [12396] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4144),
  [12398] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2380),
  [12400] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3252),
  [12402] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6936),
  [12404] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3253),
  [12406] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4133),
  [12408] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8832),
  [12410] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2909),
  [12412] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3459),
  [12414] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2672),
  [12416] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5571),
  [12418] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3439),
  [12420] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3440),
  [12422] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2558),
  [12424] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2381),
  [12426] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3441),
  [12428] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3254),
  [12430] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3255),
  [12432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2405),
  [12434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1026),
  [12436] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9792),
  [12438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8723),
  [12440] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3698),
  [12442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(296),
  [12444] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7284),
  [12446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3517),
  [12448] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5573),
  [12450] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5574),
  [12452] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1017),
  [12454] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1047),
  [12456] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2515),
  [12458] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3286),
  [12460] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3718),
  [12462] = {.entry = {.count = 1, .reusable = true}}, SHIFT(926),
  [12464] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3257),
  [12466] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3454),
  [12468] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2516),
  [12470] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2429),
  [12472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2430),
  [12474] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3402),
  [12476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2383),
  [12478] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2431),
  [12480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2432),
  [12482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1023),
  [12484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3469),
  [12486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2623),
  [12488] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2433),
  [12490] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3258),
  [12492] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2371),
  [12494] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2307),
  [12496] = {.entry = {.count = 1, .reusable = true}}, SHIFT(89),
  [12498] = {.entry = {.count = 1, .reusable = true}}, SHIFT(674),
  [12500] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3632),
  [12502] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3496),
  [12504] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3453),
  [12506] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1124),
  [12508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1129),
  [12510] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9016),
  [12512] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3261),
  [12514] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9996),
  [12516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2641),
  [12518] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1112),
  [12520] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2578),
  [12522] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1127),
  [12524] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2624),
  [12526] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3481),
  [12528] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3627),
  [12530] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3487),
  [12532] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4695),
  [12534] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3227),
  [12536] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6939),
  [12538] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9995),
  [12540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3502),
  [12542] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1116),
  [12544] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1130),
  [12546] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2487),
  [12548] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9775),
  [12550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4702),
  [12552] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4703),
  [12554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2579),
  [12556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2684),
  [12558] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_member_declaration_list, 2, 0, 0),
  [12560] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2398),
  [12562] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2565),
  [12564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(864),
  [12566] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3262),
  [12568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1133),
  [12570] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1136),
  [12572] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3405),
  [12574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2517),
  [12576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2603),
  [12578] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2637),
  [12580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1142),
  [12582] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2399),
  [12584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4654),
  [12586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2549),
  [12588] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4656),
  [12590] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2675),
  [12592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2620),
  [12594] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2625),
  [12596] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2550),
  [12598] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2400),
  [12600] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8857),
  [12602] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3306),
  [12604] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3497),
  [12606] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1102),
  [12608] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3263),
  [12610] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1103),
  [12612] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1104),
  [12614] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_pointer_parameter, 1, 0, 5),
  [12616] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1105),
  [12618] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1106),
  [12620] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1107),
  [12622] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9503),
  [12624] = {.entry = {.count = 1, .reusable = true}}, SHIFT(760),
  [12626] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2504),
  [12628] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1137),
  [12630] = {.entry = {.count = 1, .reusable = true}}, SHIFT(793),
  [12632] = {.entry = {.count = 1, .reusable = true}}, SHIFT(761),
  [12634] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2596),
  [12636] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3264),
  [12638] = {.entry = {.count = 1, .reusable = true}}, SHIFT(871),
  [12640] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3265),
  [12642] = {.entry = {.count = 1, .reusable = true}}, SHIFT(315),
  [12644] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3266),
  [12646] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1087),
  [12648] = {.entry = {.count = 1, .reusable = true}}, SHIFT(865),
  [12650] = {.entry = {.count = 1, .reusable = true}}, SHIFT(959),
  [12652] = {.entry = {.count = 1, .reusable = true}}, SHIFT(763),
  [12654] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2606),
  [12656] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2532),
  [12658] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1110),
  [12660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2519),
  [12662] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2520),
  [12664] = {.entry = {.count = 1, .reusable = true}}, SHIFT(866),
  [12666] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8745),
  [12668] = {.entry = {.count = 1, .reusable = true}}, SHIFT(766),
  [12670] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3268),
  [12672] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3923),
  [12674] = {.entry = {.count = 1, .reusable = true}}, SHIFT(767),
  [12676] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2425),
  [12678] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2592),
  [12680] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2595),
  [12682] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2559),
  [12684] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2097),
  [12686] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2098),
  [12688] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2100),
  [12690] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4792),
  [12692] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4793),
  [12694] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2101),
  [12696] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2102),
  [12698] = {.entry = {.count = 1, .reusable = true}}, SHIFT(770),
  [12700] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2560),
  [12702] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2310),
  [12704] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2096),
  [12706] = {.entry = {.count = 1, .reusable = true}}, SHIFT(779),
  [12708] = {.entry = {.count = 1, .reusable = true}}, SHIFT(303),
  [12710] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9986),
  [12712] = {.entry = {.count = 1, .reusable = true}}, SHIFT(867),
  [12714] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2533),
  [12716] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8531),
  [12718] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2567),
  [12720] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3269),
  [12722] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2521),
  [12724] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__lambda_parameters, 1, 0, 0),
  [12726] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9253),
  [12728] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2311),
  [12730] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2312),
  [12732] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2313),
  [12734] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2314),
  [12736] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7201),
  [12738] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1031),
  [12740] = {.entry = {.count = 1, .reusable = true}}, SHIFT(847),
  [12742] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2568),
  [12744] = {.entry = {.count = 1, .reusable = true}}, SHIFT(868),
  [12746] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3288),
  [12748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3289),
  [12750] = {.entry = {.count = 1, .reusable = true}}, SHIFT(849),
  [12752] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2315),
  [12754] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4174),
  [12756] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3290),
  [12758] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3418),
  [12760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2316),
  [12762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(780),
  [12764] = {.entry = {.count = 1, .reusable = true}}, SHIFT(989),
  [12766] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3270),
  [12768] = {.entry = {.count = 1, .reusable = true}}, SHIFT(850),
  [12770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3271),
  [12772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3291),
  [12774] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2597),
  [12776] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_elif, 5, 0, 81),
  [12778] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3292),
  [12780] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8271),
  [12782] = {.entry = {.count = 1, .reusable = true}}, SHIFT(869),
  [12784] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4079),
  [12786] = {.entry = {.count = 1, .reusable = true}}, SHIFT(861),
  [12788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(863),
  [12790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2569),
  [12792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3498),
  [12794] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2638),
  [12796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2318),
  [12798] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2319),
  [12800] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2320),
  [12802] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2321),
  [12804] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_member_declaration_list, 4, 0, 0),
  [12806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2552),
  [12808] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3458),
  [12810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2469),
  [12812] = {.entry = {.count = 1, .reusable = true}}, SHIFT(875),
  [12814] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3309),
  [12816] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2111),
  [12818] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2112),
  [12820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2114),
  [12822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4809),
  [12824] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4810),
  [12826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2115),
  [12828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2116),
  [12830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7852),
  [12832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3296),
  [12834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2362),
  [12836] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2110),
  [12838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2553),
  [12840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3297),
  [12842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7713),
  [12844] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3320),
  [12846] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7858),
  [12848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7859),
  [12850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3322),
  [12852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9897),
  [12854] = {.entry = {.count = 1, .reusable = true}}, SHIFT(178),
  [12856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3325),
  [12858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1057),
  [12860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1082),
  [12862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8970),
  [12864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4188),
  [12866] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1489),
  [12868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(811),
  [12870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2598),
  [12872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1034),
  [12874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2617),
  [12876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8979),
  [12878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1014),
  [12880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2534),
  [12882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7777),
  [12884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1066),
  [12886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(814),
  [12888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9355),
  [12890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2688),
  [12892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(781),
  [12894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1099),
  [12896] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3341),
  [12898] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2551),
  [12900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(815),
  [12902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7839),
  [12904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3674),
  [12906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4819),
  [12908] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4820),
  [12910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2123),
  [12912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2124),
  [12914] = {.entry = {.count = 1, .reusable = true}}, SHIFT(320),
  [12916] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1485),
  [12918] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2122),
  [12920] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7234),
  [12922] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interpolation_format_clause, 2, 0, 0),
  [12924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(818),
  [12926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(819),
  [12928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2554),
  [12930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2477),
  [12932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3166),
  [12934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2522),
  [12936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1146),
  [12938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2599),
  [12940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9017),
  [12942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4196),
  [12944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3392),
  [12946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(821),
  [12948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3979),
  [12950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3345),
  [12952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3346),
  [12954] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3347),
  [12956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2600),
  [12958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8901),
  [12960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2127),
  [12962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2128),
  [12964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3992),
  [12966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2126),
  [12968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7990),
  [12970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1013),
  [12972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1003),
  [12974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(747),
  [12976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1046),
  [12978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3547),
  [12980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1058),
  [12982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8734),
  [12984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1560),
  [12986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4205),
  [12988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3348),
  [12990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3706),
  [12992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1059),
  [12994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(809),
  [12996] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2406),
  [12998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1018),
  [13000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3372),
  [13002] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1060),
  [13004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(301),
  [13006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7273),
  [13008] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1061),
  [13010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1062),
  [13012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(37),
  [13014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1027),
  [13016] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3460),
  [13018] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3378),
  [13020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3619),
  [13022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1067),
  [13024] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4213),
  [13026] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2322),
  [13028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1063),
  [13030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2523),
  [13032] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1070),
  [13034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2323),
  [13036] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2324),
  [13038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(941),
  [13040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3461),
  [13042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5286),
  [13044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1037),
  [13046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1000),
  [13048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3379),
  [13050] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4222),
  [13052] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3383),
  [13054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(740),
  [13056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1038),
  [13058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2618),
  [13060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2419),
  [13062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(741),
  [13064] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_member_declaration_list, 5, 0, 0),
  [13066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8267),
  [13068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2326),
  [13070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2524),
  [13072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(913),
  [13074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(828),
  [13076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2328),
  [13078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2330),
  [13080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(742),
  [13082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3999),
  [13084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2331),
  [13086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2332),
  [13088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2333),
  [13090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(942),
  [13092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(743),
  [13094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8290),
  [13096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1042),
  [13098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(744),
  [13100] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2681),
  [13102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(750),
  [13104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2336),
  [13106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2337),
  [13108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2338),
  [13110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2339),
  [13112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2613),
  [13114] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_elif_in_enum_member_declaration, 4, 0, 59),
  [13116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3937),
  [13118] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1073),
  [13120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2230),
  [13122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(745),
  [13124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3699),
  [13126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3700),
  [13128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8990),
  [13130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(696),
  [13132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1085),
  [13134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8342),
  [13136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2631),
  [13138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1007),
  [13140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4129),
  [13142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2570),
  [13144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2360),
  [13146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1086),
  [13148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1074),
  [13150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1088),
  [13152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2146),
  [13154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3462),
  [13156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(788),
  [13158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1120),
  [13160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(944),
  [13162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1089),
  [13164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3591),
  [13166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(790),
  [13168] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1090),
  [13170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2527),
  [13172] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1091),
  [13174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1119),
  [13176] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2340),
  [13178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2341),
  [13180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2342),
  [13182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2343),
  [13184] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2344),
  [13186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2361),
  [13188] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3887),
  [13190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(706),
  [13192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8362),
  [13194] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2346),
  [13196] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2347),
  [13198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(836),
  [13200] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2348),
  [13202] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2174),
  [13204] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2349),
  [13206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2528),
  [13208] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2350),
  [13210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1075),
  [13212] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1144),
  [13214] = {.entry = {.count = 1, .reusable = true}}, SHIFT(711),
  [13216] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8367),
  [13218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2420),
  [13220] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2602),
  [13222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2176),
  [13224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2351),
  [13226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1149),
  [13228] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3463),
  [13230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8370),
  [13232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2352),
  [13234] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8371),
  [13236] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2353),
  [13238] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8375),
  [13240] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2354),
  [13242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2192),
  [13244] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2193),
  [13246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2355),
  [13248] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1015),
  [13250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9915),
  [13252] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2194),
  [13254] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8294),
  [13256] = {.entry = {.count = 1, .reusable = true}}, SHIFT(846),
  [13258] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1039),
  [13260] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1048),
  [13262] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2195),
  [13264] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2196),
  [13266] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9940),
  [13268] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2197),
  [13270] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2198),
  [13272] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2199),
  [13274] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9950),
  [13276] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2200),
  [13278] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2201),
  [13280] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1152),
  [13282] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2357),
  [13284] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2358),
  [13286] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2359),
  [13288] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2382),
  [13290] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_undef, 3, 0, 0),
  [13292] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_warning, 3, 0, 0),
  [13294] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_line, 14, 0, 0),
  [13296] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_pragma, 4, 0, 0),
  [13298] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_region, 3, 0, 11),
  [13300] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_pragma, 5, 0, 0),
  [13302] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_line, 4, 0, 0),
  [13304] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_define, 3, 0, 0),
  [13306] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_region, 2, 0, 0),
  [13308] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_error, 3, 0, 0),
  [13310] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_nullable, 4, 0, 0),
  [13312] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_endregion, 3, 0, 11),
  [13314] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_endregion, 2, 0, 0),
  [13316] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_nullable, 3, 0, 0),
  [13318] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_line, 3, 0, 0),
  [13320] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_line, 15, 0, 0),
  [13322] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_pragma, 6, 0, 0),
};

enum ts_external_scanner_symbol_identifiers {
  ts_external_token__optional_semi = 0,
  ts_external_token_interpolation_regular_start = 1,
  ts_external_token_interpolation_verbatim_start = 2,
  ts_external_token_interpolation_raw_start = 3,
  ts_external_token_interpolation_start_quote = 4,
  ts_external_token_interpolation_end_quote = 5,
  ts_external_token_interpolation_open_brace = 6,
  ts_external_token_interpolation_close_brace = 7,
  ts_external_token_interpolation_string_content = 8,
  ts_external_token_raw_string_start = 9,
  ts_external_token_raw_string_end = 10,
  ts_external_token_raw_string_content = 11,
};

static const TSSymbol ts_external_scanner_symbol_map[EXTERNAL_TOKEN_COUNT] = {
  [ts_external_token__optional_semi] = sym__optional_semi,
  [ts_external_token_interpolation_regular_start] = sym_interpolation_regular_start,
  [ts_external_token_interpolation_verbatim_start] = sym_interpolation_verbatim_start,
  [ts_external_token_interpolation_raw_start] = sym_interpolation_raw_start,
  [ts_external_token_interpolation_start_quote] = sym_interpolation_start_quote,
  [ts_external_token_interpolation_end_quote] = sym_interpolation_end_quote,
  [ts_external_token_interpolation_open_brace] = sym_interpolation_open_brace,
  [ts_external_token_interpolation_close_brace] = sym_interpolation_close_brace,
  [ts_external_token_interpolation_string_content] = sym_interpolation_string_content,
  [ts_external_token_raw_string_start] = sym_raw_string_start,
  [ts_external_token_raw_string_end] = sym_raw_string_end,
  [ts_external_token_raw_string_content] = sym_raw_string_content,
};

static const bool ts_external_scanner_states[10][EXTERNAL_TOKEN_COUNT] = {
  [1] = {
    [ts_external_token__optional_semi] = true,
    [ts_external_token_interpolation_regular_start] = true,
    [ts_external_token_interpolation_verbatim_start] = true,
    [ts_external_token_interpolation_raw_start] = true,
    [ts_external_token_interpolation_start_quote] = true,
    [ts_external_token_interpolation_end_quote] = true,
    [ts_external_token_interpolation_open_brace] = true,
    [ts_external_token_interpolation_close_brace] = true,
    [ts_external_token_interpolation_string_content] = true,
    [ts_external_token_raw_string_start] = true,
    [ts_external_token_raw_string_end] = true,
    [ts_external_token_raw_string_content] = true,
  },
  [2] = {
    [ts_external_token_interpolation_regular_start] = true,
    [ts_external_token_interpolation_verbatim_start] = true,
    [ts_external_token_interpolation_raw_start] = true,
    [ts_external_token_raw_string_start] = true,
  },
  [3] = {
    [ts_external_token_interpolation_regular_start] = true,
    [ts_external_token_interpolation_verbatim_start] = true,
    [ts_external_token_interpolation_raw_start] = true,
    [ts_external_token_interpolation_close_brace] = true,
    [ts_external_token_raw_string_start] = true,
  },
  [4] = {
    [ts_external_token_interpolation_close_brace] = true,
  },
  [5] = {
    [ts_external_token_interpolation_end_quote] = true,
    [ts_external_token_interpolation_open_brace] = true,
    [ts_external_token_interpolation_string_content] = true,
  },
  [6] = {
    [ts_external_token__optional_semi] = true,
  },
  [7] = {
    [ts_external_token_raw_string_end] = true,
  },
  [8] = {
    [ts_external_token_raw_string_content] = true,
  },
  [9] = {
    [ts_external_token_interpolation_start_quote] = true,
  },
};

#ifdef __cplusplus
extern "C" {
#endif
void *tree_sitter_c_sharp_external_scanner_create(void);
void tree_sitter_c_sharp_external_scanner_destroy(void *);
bool tree_sitter_c_sharp_external_scanner_scan(void *, TSLexer *, const bool *);
unsigned tree_sitter_c_sharp_external_scanner_serialize(void *, char *);
void tree_sitter_c_sharp_external_scanner_deserialize(void *, const char *, unsigned);

#ifdef TREE_SITTER_HIDE_SYMBOLS
#define TS_PUBLIC
#elif defined(_WIN32)
#define TS_PUBLIC __declspec(dllexport)
#else
#define TS_PUBLIC __attribute__((visibility("default")))
#endif

TS_PUBLIC const TSLanguage *tree_sitter_c_sharp(void) {
  static const TSLanguage language = {
    .version = LANGUAGE_VERSION,
    .symbol_count = SYMBOL_COUNT,
    .alias_count = ALIAS_COUNT,
    .token_count = TOKEN_COUNT,
    .external_token_count = EXTERNAL_TOKEN_COUNT,
    .state_count = STATE_COUNT,
    .large_state_count = LARGE_STATE_COUNT,
    .production_id_count = PRODUCTION_ID_COUNT,
    .field_count = FIELD_COUNT,
    .max_alias_sequence_length = MAX_ALIAS_SEQUENCE_LENGTH,
    .parse_table = &ts_parse_table[0][0],
    .small_parse_table = ts_small_parse_table,
    .small_parse_table_map = ts_small_parse_table_map,
    .parse_actions = ts_parse_actions,
    .symbol_names = ts_symbol_names,
    .field_names = ts_field_names,
    .field_map_slices = ts_field_map_slices,
    .field_map_entries = ts_field_map_entries,
    .symbol_metadata = ts_symbol_metadata,
    .public_symbol_map = ts_symbol_map,
    .alias_map = ts_non_terminal_alias_map,
    .alias_sequences = &ts_alias_sequences[0][0],
    .lex_modes = ts_lex_modes,
    .lex_fn = ts_lex,
    .keyword_lex_fn = ts_lex_keywords,
    .keyword_capture_token = sym__identifier_token,
    .external_scanner = {
      &ts_external_scanner_states[0][0],
      ts_external_scanner_symbol_map,
      tree_sitter_c_sharp_external_scanner_create,
      tree_sitter_c_sharp_external_scanner_destroy,
      tree_sitter_c_sharp_external_scanner_scan,
      tree_sitter_c_sharp_external_scanner_serialize,
      tree_sitter_c_sharp_external_scanner_deserialize,
    },
    .primary_state_ids = ts_primary_state_ids,
  };
  return &language;
}
#ifdef __cplusplus
}
#endif
